property_value_alias_blk_long_to_short = {
    "Adlam": "Adlam",
    "Aegean Numbers": "Aegean Numbers",
    "Ahom": "Ahom",
    "Alchemical Symbols": "Alchemical",
    "Alphabetic Presentation Forms": "Alphabetic PF",
    "Anatolian Hieroglyphs": "Anatolian Hieroglyphs",
    "Ancient Greek Musical Notation": "Ancient Greek Music",
    "Ancient Greek Numbers": "Ancient Greek Numbers",
    "Ancient Symbols": "Ancient Symbols",
    "Arabic": "Arabic",
    "Arabic Extended A": "Arabic Ext A",
    "Arabic Mathematical Alphabetic Symbols": "Arabic Math",
    "Arabic Presentation Forms A": "Arabic PF A",
    "Arabic Presentation Forms B": "Arabic PF B",
    "Arabic Supplement": "Arabic Sup",
    "Armenian": "Armenian",
    "Arrows": "Arrows",
    "Avestan": "Avestan",
    "Balinese": "Balinese",
    "Bamum": "Bamum",
    "Bamum Supplement": "Bamum Sup",
    "Basic Latin": "ASCII",
    "Bassa Vah": "Bassa Vah",
    "Batak": "Batak",
    "Bengali": "Bengali",
    "Bhaiksuki": "Bhaiksuki",
    "Block Elements": "Block Elements",
    "Bopomofo": "Bopomofo",
    "Bopomofo Extended": "Bopomofo Ext",
    "Box Drawing": "Box Drawing",
    "Brahmi": "Brahmi",
    "Braille Patterns": "Braille",
    "Buginese": "Buginese",
    "Buhid": "Buhid",
    "Byzantine Musical Symbols": "Byzantine Music",
    "CJK Compatibility": "CJK Compat",
    "CJK Compatibility Forms": "CJK Compat Forms",
    "CJK Compatibility Ideographs": "CJK Compat Ideographs",
    "CJK Compatibility Ideographs Supplement": "CJK Compat Ideographs Sup",
    "CJK Radicals Supplement": "CJK Radicals Sup",
    "CJK Strokes": "CJK Strokes",
    "CJK Symbols And Punctuation": "CJK Symbols",
    "CJK Unified Ideographs": "CJK",
    "CJK Unified Ideographs Extension A": "CJK Ext A",
    "CJK Unified Ideographs Extension B": "CJK Ext B",
    "CJK Unified Ideographs Extension C": "CJK Ext C",
    "CJK Unified Ideographs Extension D": "CJK Ext D",
    "CJK Unified Ideographs Extension E": "CJK Ext E",
    "CJK Unified Ideographs Extension F": "CJK Ext F",
    "CJK Unified Ideographs Extension G": "CJK Ext G",
    "Carian": "Carian",
    "Caucasian Albanian": "Caucasian Albanian",
    "Chakma": "Chakma",
    "Cham": "Cham",
    "Cherokee": "Cherokee",
    "Cherokee Supplement": "Cherokee Sup",
    "Chess Symbols": "Chess Symbols",
    "Chorasmian": "Chorasmian",
    "Combining Diacritical Marks": "Diacriticals",
    "Combining Diacritical Marks Extended": "Diacriticals Ext",
    "Combining Diacritical Marks For Symbols": "Diacriticals For Symbols",
    "Combining Diacritical Marks Supplement": "Diacriticals Sup",
    "Combining Half Marks": "Half Marks",
    "Common Indic Number Forms": "Indic Number Forms",
    "Control Pictures": "Control Pictures",
    "Coptic": "Coptic",
    "Coptic Epact Numbers": "Coptic Epact Numbers",
    "Counting Rod Numerals": "Counting Rod",
    "Cuneiform": "Cuneiform",
    "Cuneiform Numbers And Punctuation": "Cuneiform Numbers",
    "Currency Symbols": "Currency Symbols",
    "Cypriot Syllabary": "Cypriot Syllabary",
    "Cyrillic": "Cyrillic",
    "Cyrillic Extended A": "Cyrillic Ext A",
    "Cyrillic Extended B": "Cyrillic Ext B",
    "Cyrillic Extended C": "Cyrillic Ext C",
    "Cyrillic Supplement": "Cyrillic Sup",
    "Deseret": "Deseret",
    "Devanagari": "Devanagari",
    "Devanagari Extended": "Devanagari Ext",
    "Dingbats": "Dingbats",
    "Dives Akuru": "Dives Akuru",
    "Dogra": "Dogra",
    "Domino Tiles": "Domino",
    "Duployan": "Duployan",
    "Early Dynastic Cuneiform": "Early Dynastic Cuneiform",
    "Egyptian Hieroglyph Format Controls": "Egyptian Hieroglyph Format Controls",
    "Egyptian Hieroglyphs": "Egyptian Hieroglyphs",
    "Elbasan": "Elbasan",
    "Elymaic": "Elymaic",
    "Emoticons": "Emoticons",
    "Enclosed Alphanumeric Supplement": "Enclosed Alphanum Sup",
    "Enclosed Alphanumerics": "Enclosed Alphanum",
    "Enclosed CJK Letters And Months": "Enclosed CJK",
    "Enclosed Ideographic Supplement": "Enclosed Ideographic Sup",
    "Ethiopic": "Ethiopic",
    "Ethiopic Extended": "Ethiopic Ext",
    "Ethiopic Extended A": "Ethiopic Ext A",
    "Ethiopic Supplement": "Ethiopic Sup",
    "General Punctuation": "Punctuation",
    "Geometric Shapes": "Geometric Shapes",
    "Geometric Shapes Extended": "Geometric Shapes Ext",
    "Georgian": "Georgian",
    "Georgian Extended": "Georgian Ext",
    "Georgian Supplement": "Georgian Sup",
    "Glagolitic": "Glagolitic",
    "Glagolitic Supplement": "Glagolitic Sup",
    "Gothic": "Gothic",
    "Grantha": "Grantha",
    "Greek And Coptic": "Greek",
    "Greek Extended": "Greek Ext",
    "Gujarati": "Gujarati",
    "Gunjala Gondi": "Gunjala Gondi",
    "Gurmukhi": "Gurmukhi",
    "Halfwidth And Fullwidth Forms": "Half And Full Forms",
    "Hangul Compatibility Jamo": "Compat Jamo",
    "Hangul Jamo": "Jamo",
    "Hangul Jamo Extended A": "Jamo Ext A",
    "Hangul Jamo Extended B": "Jamo Ext B",
    "Hangul Syllables": "Hangul",
    "Hanifi Rohingya": "Hanifi Rohingya",
    "Hanunoo": "Hanunoo",
    "Hatran": "Hatran",
    "Hebrew": "Hebrew",
    "High Private Use Surrogates": "High PU Surrogates",
    "High Surrogates": "High Surrogates",
    "Hiragana": "Hiragana",
    "IPA Extensions": "IPA Ext",
    "Ideographic Description Characters": "IDC",
    "Ideographic Symbols And Punctuation": "Ideographic Symbols",
    "Imperial Aramaic": "Imperial Aramaic",
    "Indic Siyaq Numbers": "Indic Siyaq Numbers",
    "Inscriptional Pahlavi": "Inscriptional Pahlavi",
    "Inscriptional Parthian": "Inscriptional Parthian",
    "Javanese": "Javanese",
    "Kaithi": "Kaithi",
    "Kana Extended A": "Kana Ext A",
    "Kana Supplement": "Kana Sup",
    "Kanbun": "Kanbun",
    "Kangxi Radicals": "Kangxi",
    "Kannada": "Kannada",
    "Katakana": "Katakana",
    "Katakana Phonetic Extensions": "Katakana Ext",
    "Kayah Li": "Kayah Li",
    "Kharoshthi": "Kharoshthi",
    "Khitan Small Script": "Khitan Small Script",
    "Khmer": "Khmer",
    "Khmer Symbols": "Khmer Symbols",
    "Khojki": "Khojki",
    "Khudawadi": "Khudawadi",
    "Lao": "Lao",
    "Latin 1 Supplement": "Latin 1 Sup",
    "Latin Extended A": "Latin Ext A",
    "Latin Extended Additional": "Latin Ext Additional",
    "Latin Extended B": "Latin Ext B",
    "Latin Extended C": "Latin Ext C",
    "Latin Extended D": "Latin Ext D",
    "Latin Extended E": "Latin Ext E",
    "Lepcha": "Lepcha",
    "Letterlike Symbols": "Letterlike Symbols",
    "Limbu": "Limbu",
    "Linear A": "Linear A",
    "Linear B Ideograms": "Linear B Ideograms",
    "Linear B Syllabary": "Linear B Syllabary",
    "Lisu": "Lisu",
    "Lisu Supplement": "Lisu Sup",
    "Low Surrogates": "Low Surrogates",
    "Lycian": "Lycian",
    "Lydian": "Lydian",
    "Mahajani": "Mahajani",
    "Mahjong Tiles": "Mahjong",
    "Makasar": "Makasar",
    "Malayalam": "Malayalam",
    "Mandaic": "Mandaic",
    "Manichaean": "Manichaean",
    "Marchen": "Marchen",
    "Masaram Gondi": "Masaram Gondi",
    "Mathematical Alphanumeric Symbols": "Math Alphanum",
    "Mathematical Operators": "Math Operators",
    "Mayan Numerals": "Mayan Numerals",
    "Medefaidrin": "Medefaidrin",
    "Meetei Mayek": "Meetei Mayek",
    "Meetei Mayek Extensions": "Meetei Mayek Ext",
    "Mende Kikakui": "Mende Kikakui",
    "Meroitic Cursive": "Meroitic Cursive",
    "Meroitic Hieroglyphs": "Meroitic Hieroglyphs",
    "Miao": "Miao",
    "Miscellaneous Mathematical Symbols A": "Misc Math Symbols A",
    "Miscellaneous Mathematical Symbols B": "Misc Math Symbols B",
    "Miscellaneous Symbols": "Misc Symbols",
    "Miscellaneous Symbols And Arrows": "Misc Arrows",
    "Miscellaneous Symbols And Pictographs": "Misc Pictographs",
    "Miscellaneous Technical": "Misc Technical",
    "Modi": "Modi",
    "Modifier Tone Letters": "Modifier Tone Letters",
    "Mongolian": "Mongolian",
    "Mongolian Supplement": "Mongolian Sup",
    "Mro": "Mro",
    "Multani": "Multani",
    "Musical Symbols": "Music",
    "Myanmar": "Myanmar",
    "Myanmar Extended A": "Myanmar Ext A",
    "Myanmar Extended B": "Myanmar Ext B",
    "NKo": "NKo",
    "Nabataean": "Nabataean",
    "Nandinagari": "Nandinagari",
    "New Tai Lue": "New Tai Lue",
    "Newa": "Newa",
    "No Block": "NB",
    "Number Forms": "Number Forms",
    "Nushu": "Nushu",
    "Nyiakeng Puachue Hmong": "Nyiakeng Puachue Hmong",
    "Ogham": "Ogham",
    "Ol Chiki": "Ol Chiki",
    "Old Hungarian": "Old Hungarian",
    "Old Italic": "Old Italic",
    "Old North Arabian": "Old North Arabian",
    "Old Permic": "Old Permic",
    "Old Persian": "Old Persian",
    "Old Sogdian": "Old Sogdian",
    "Old South Arabian": "Old South Arabian",
    "Old Turkic": "Old Turkic",
    "Optical Character Recognition": "OCR",
    "Oriya": "Oriya",
    "Ornamental Dingbats": "Ornamental Dingbats",
    "Osage": "Osage",
    "Osmanya": "Osmanya",
    "Ottoman Siyaq Numbers": "Ottoman Siyaq Numbers",
    "Pahawh Hmong": "Pahawh Hmong",
    "Palmyrene": "Palmyrene",
    "Pau Cin Hau": "Pau Cin Hau",
    "Phags Pa": "Phags Pa",
    "Phaistos Disc": "Phaistos",
    "Phoenician": "Phoenician",
    "Phonetic Extensions": "Phonetic Ext",
    "Phonetic Extensions Supplement": "Phonetic Ext Sup",
    "Playing Cards": "Playing Cards",
    "Private Use Area": "PUA",
    "Psalter Pahlavi": "Psalter Pahlavi",
    "Rejang": "Rejang",
    "Rumi Numeral Symbols": "Rumi",
    "Runic": "Runic",
    "Samaritan": "Samaritan",
    "Saurashtra": "Saurashtra",
    "Sharada": "Sharada",
    "Shavian": "Shavian",
    "Shorthand Format Controls": "Shorthand Format Controls",
    "Siddham": "Siddham",
    "Sinhala": "Sinhala",
    "Sinhala Archaic Numbers": "Sinhala Archaic Numbers",
    "Small Form Variants": "Small Forms",
    "Small Kana Extension": "Small Kana Ext",
    "Sogdian": "Sogdian",
    "Sora Sompeng": "Sora Sompeng",
    "Soyombo": "Soyombo",
    "Spacing Modifier Letters": "Modifier Letters",
    "Specials": "Specials",
    "Sundanese": "Sundanese",
    "Sundanese Supplement": "Sundanese Sup",
    "Superscripts And Subscripts": "Super And Sub",
    "Supplemental Arrows A": "Sup Arrows A",
    "Supplemental Arrows B": "Sup Arrows B",
    "Supplemental Arrows C": "Sup Arrows C",
    "Supplemental Mathematical Operators": "Sup Math Operators",
    "Supplemental Punctuation": "Sup Punctuation",
    "Supplemental Symbols And Pictographs": "Sup Symbols And Pictographs",
    "Supplementary Private Use Area A": "Sup PUA A",
    "Supplementary Private Use Area B": "Sup PUA B",
    "Sutton SignWriting": "Sutton SignWriting",
    "Syloti Nagri": "Syloti Nagri",
    "Symbols And Pictographs Extended A": "Symbols And Pictographs Ext A",
    "Symbols For Legacy Computing": "Symbols For Legacy Computing",
    "Syriac": "Syriac",
    "Syriac Supplement": "Syriac Sup",
    "Tagalog": "Tagalog",
    "Tagbanwa": "Tagbanwa",
    "Tags": "Tags",
    "Tai Le": "Tai Le",
    "Tai Tham": "Tai Tham",
    "Tai Viet": "Tai Viet",
    "Tai Xuan Jing Symbols": "Tai Xuan Jing",
    "Takri": "Takri",
    "Tamil": "Tamil",
    "Tamil Supplement": "Tamil Sup",
    "Tangut": "Tangut",
    "Tangut Components": "Tangut Components",
    "Tangut Supplement": "Tangut Sup",
    "Telugu": "Telugu",
    "Thaana": "Thaana",
    "Thai": "Thai",
    "Tibetan": "Tibetan",
    "Tifinagh": "Tifinagh",
    "Tirhuta": "Tirhuta",
    "Transport And Map Symbols": "Transport And Map",
    "Ugaritic": "Ugaritic",
    "Unified Canadian Aboriginal Syllabics": "UCAS",
    "Unified Canadian Aboriginal Syllabics Extended": "UCAS Ext",
    "Vai": "Vai",
    "Variation Selectors": "VS",
    "Variation Selectors Supplement": "VS Sup",
    "Vedic Extensions": "Vedic Ext",
    "Vertical Forms": "Vertical Forms",
    "Wancho": "Wancho",
    "Warang Citi": "Warang Citi",
    "Yezidi": "Yezidi",
    "Yi Radicals": "Yi Radicals",
    "Yi Syllables": "Yi Syllables",
    "Yijing Hexagram Symbols": "Yijing",
    "Zanabazar Square": "Zanabazar Square",
}
