prop_list_to_property = {
    9: {"White_Space", "Pattern_White_Space"},
    10: {"White_Space", "Pattern_White_Space"},
    11: {"White_Space", "Pattern_White_Space"},
    12: {"White_Space", "Pattern_White_Space"},
    13: {"White_Space", "Pattern_White_Space"},
    32: {"White_Space", "Pattern_White_Space"},
    33: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    34: {"Pattern_Syntax", "Quotation_Mark"},
    35: {"Pattern_Syntax"},
    36: {"Pattern_Syntax"},
    37: {"Pattern_Syntax"},
    38: {"Pattern_Syntax"},
    39: {"Pattern_Syntax", "Quotation_Mark"},
    40: {"Pattern_Syntax"},
    41: {"Pattern_Syntax"},
    42: {"Pattern_Syntax"},
    43: {"Pattern_Syntax"},
    44: {"Pattern_Syntax", "Terminal_Punctuation"},
    45: {"Pattern_Syntax", "Dash", "Hyphen"},
    46: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    47: {"Pattern_Syntax"},
    48: {"ASCII_Hex_Digit", "Hex_Digit"},
    49: {"ASCII_Hex_Digit", "Hex_Digit"},
    50: {"ASCII_Hex_Digit", "Hex_Digit"},
    51: {"ASCII_Hex_Digit", "Hex_Digit"},
    52: {"ASCII_Hex_Digit", "Hex_Digit"},
    53: {"ASCII_Hex_Digit", "Hex_Digit"},
    54: {"ASCII_Hex_Digit", "Hex_Digit"},
    55: {"ASCII_Hex_Digit", "Hex_Digit"},
    56: {"ASCII_Hex_Digit", "Hex_Digit"},
    57: {"ASCII_Hex_Digit", "Hex_Digit"},
    58: {"Pattern_Syntax", "Terminal_Punctuation"},
    59: {"Pattern_Syntax", "Terminal_Punctuation"},
    60: {"Pattern_Syntax"},
    61: {"Pattern_Syntax"},
    62: {"Pattern_Syntax"},
    63: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    64: {"Pattern_Syntax"},
    65: {"ASCII_Hex_Digit", "Hex_Digit"},
    66: {"ASCII_Hex_Digit", "Hex_Digit"},
    67: {"ASCII_Hex_Digit", "Hex_Digit"},
    68: {"ASCII_Hex_Digit", "Hex_Digit"},
    69: {"ASCII_Hex_Digit", "Hex_Digit"},
    70: {"ASCII_Hex_Digit", "Hex_Digit"},
    91: {"Pattern_Syntax"},
    92: {"Pattern_Syntax"},
    93: {"Pattern_Syntax"},
    94: {"Diacritic", "Pattern_Syntax", "Other_Math"},
    96: {"Diacritic", "Pattern_Syntax"},
    97: {"ASCII_Hex_Digit", "Hex_Digit"},
    98: {"ASCII_Hex_Digit", "Hex_Digit"},
    99: {"ASCII_Hex_Digit", "Hex_Digit"},
    100: {"ASCII_Hex_Digit", "Hex_Digit"},
    101: {"ASCII_Hex_Digit", "Hex_Digit"},
    102: {"ASCII_Hex_Digit", "Hex_Digit"},
    105: {"Soft_Dotted"},
    106: {"Soft_Dotted"},
    123: {"Pattern_Syntax"},
    124: {"Pattern_Syntax"},
    125: {"Pattern_Syntax"},
    126: {"Pattern_Syntax"},
    133: {"White_Space", "Pattern_White_Space"},
    160: {"White_Space"},
    161: {"Pattern_Syntax"},
    162: {"Pattern_Syntax"},
    163: {"Pattern_Syntax"},
    164: {"Pattern_Syntax"},
    165: {"Pattern_Syntax"},
    166: {"Pattern_Syntax"},
    167: {"Pattern_Syntax"},
    168: {"Diacritic"},
    169: {"Pattern_Syntax"},
    170: {"Other_Lowercase"},
    171: {"Pattern_Syntax", "Quotation_Mark"},
    172: {"Pattern_Syntax"},
    173: {"Hyphen"},
    174: {"Pattern_Syntax"},
    175: {"Diacritic"},
    176: {"Pattern_Syntax"},
    177: {"Pattern_Syntax"},
    180: {"Diacritic"},
    182: {"Pattern_Syntax"},
    183: {"Diacritic", "Extender", "Other_ID_Continue"},
    184: {"Diacritic"},
    186: {"Other_Lowercase"},
    187: {"Pattern_Syntax", "Quotation_Mark"},
    191: {"Pattern_Syntax"},
    215: {"Pattern_Syntax"},
    247: {"Pattern_Syntax"},
    303: {"Soft_Dotted"},
    329: {"Deprecated"},
    585: {"Soft_Dotted"},
    616: {"Soft_Dotted"},
    669: {"Soft_Dotted"},
    688: {"Other_Lowercase", "Diacritic"},
    689: {"Other_Lowercase", "Diacritic"},
    690: {"Other_Lowercase", "Diacritic", "Soft_Dotted"},
    691: {"Other_Lowercase", "Diacritic"},
    692: {"Other_Lowercase", "Diacritic"},
    693: {"Other_Lowercase", "Diacritic"},
    694: {"Other_Lowercase", "Diacritic"},
    695: {"Other_Lowercase", "Diacritic"},
    696: {"Other_Lowercase", "Diacritic"},
    697: {"Diacritic"},
    698: {"Diacritic"},
    699: {"Diacritic"},
    700: {"Diacritic"},
    701: {"Diacritic"},
    702: {"Diacritic"},
    703: {"Diacritic"},
    704: {"Other_Lowercase", "Diacritic"},
    705: {"Other_Lowercase", "Diacritic"},
    706: {"Diacritic"},
    707: {"Diacritic"},
    708: {"Diacritic"},
    709: {"Diacritic"},
    710: {"Diacritic"},
    711: {"Diacritic"},
    712: {"Diacritic"},
    713: {"Diacritic"},
    714: {"Diacritic"},
    715: {"Diacritic"},
    716: {"Diacritic"},
    717: {"Diacritic"},
    718: {"Diacritic"},
    719: {"Diacritic"},
    720: {"Diacritic", "Extender"},
    721: {"Diacritic", "Extender"},
    722: {"Diacritic"},
    723: {"Diacritic"},
    724: {"Diacritic"},
    725: {"Diacritic"},
    726: {"Diacritic"},
    727: {"Diacritic"},
    728: {"Diacritic"},
    729: {"Diacritic"},
    730: {"Diacritic"},
    731: {"Diacritic"},
    732: {"Diacritic"},
    733: {"Diacritic"},
    734: {"Diacritic"},
    735: {"Diacritic"},
    736: {"Other_Lowercase", "Diacritic"},
    737: {"Other_Lowercase", "Diacritic"},
    738: {"Other_Lowercase", "Diacritic"},
    739: {"Other_Lowercase", "Diacritic"},
    740: {"Other_Lowercase", "Diacritic"},
    741: {"Diacritic"},
    742: {"Diacritic"},
    743: {"Diacritic"},
    744: {"Diacritic"},
    745: {"Diacritic"},
    746: {"Diacritic"},
    747: {"Diacritic"},
    748: {"Diacritic"},
    749: {"Diacritic"},
    750: {"Diacritic"},
    751: {"Diacritic"},
    752: {"Diacritic"},
    753: {"Diacritic"},
    754: {"Diacritic"},
    755: {"Diacritic"},
    756: {"Diacritic"},
    757: {"Diacritic"},
    758: {"Diacritic"},
    759: {"Diacritic"},
    760: {"Diacritic"},
    761: {"Diacritic"},
    762: {"Diacritic"},
    763: {"Diacritic"},
    764: {"Diacritic"},
    765: {"Diacritic"},
    766: {"Diacritic"},
    767: {"Diacritic"},
    768: {"Diacritic"},
    769: {"Diacritic"},
    770: {"Diacritic"},
    771: {"Diacritic"},
    772: {"Diacritic"},
    773: {"Diacritic"},
    774: {"Diacritic"},
    775: {"Diacritic"},
    776: {"Diacritic"},
    777: {"Diacritic"},
    778: {"Diacritic"},
    779: {"Diacritic"},
    780: {"Diacritic"},
    781: {"Diacritic"},
    782: {"Diacritic"},
    783: {"Diacritic"},
    784: {"Diacritic"},
    785: {"Diacritic"},
    786: {"Diacritic"},
    787: {"Diacritic"},
    788: {"Diacritic"},
    789: {"Diacritic"},
    790: {"Diacritic"},
    791: {"Diacritic"},
    792: {"Diacritic"},
    793: {"Diacritic"},
    794: {"Diacritic"},
    795: {"Diacritic"},
    796: {"Diacritic"},
    797: {"Diacritic"},
    798: {"Diacritic"},
    799: {"Diacritic"},
    800: {"Diacritic"},
    801: {"Diacritic"},
    802: {"Diacritic"},
    803: {"Diacritic"},
    804: {"Diacritic"},
    805: {"Diacritic"},
    806: {"Diacritic"},
    807: {"Diacritic"},
    808: {"Diacritic"},
    809: {"Diacritic"},
    810: {"Diacritic"},
    811: {"Diacritic"},
    812: {"Diacritic"},
    813: {"Diacritic"},
    814: {"Diacritic"},
    815: {"Diacritic"},
    816: {"Diacritic"},
    817: {"Diacritic"},
    818: {"Diacritic"},
    819: {"Diacritic"},
    820: {"Diacritic"},
    821: {"Diacritic"},
    822: {"Diacritic"},
    823: {"Diacritic"},
    824: {"Diacritic"},
    825: {"Diacritic"},
    826: {"Diacritic"},
    827: {"Diacritic"},
    828: {"Diacritic"},
    829: {"Diacritic"},
    830: {"Diacritic"},
    831: {"Diacritic"},
    832: {"Diacritic"},
    833: {"Diacritic"},
    834: {"Diacritic"},
    835: {"Diacritic"},
    836: {"Diacritic"},
    837: {"Other_Lowercase", "Diacritic", "Other_Alphabetic"},
    838: {"Diacritic"},
    839: {"Diacritic"},
    840: {"Diacritic"},
    841: {"Diacritic"},
    842: {"Diacritic"},
    843: {"Diacritic"},
    844: {"Diacritic"},
    845: {"Diacritic"},
    846: {"Diacritic"},
    847: {"Other_Default_Ignorable_Code_Point"},
    848: {"Diacritic"},
    849: {"Diacritic"},
    850: {"Diacritic"},
    851: {"Diacritic"},
    852: {"Diacritic"},
    853: {"Diacritic"},
    854: {"Diacritic"},
    855: {"Diacritic"},
    861: {"Diacritic"},
    862: {"Diacritic"},
    863: {"Diacritic"},
    864: {"Diacritic"},
    865: {"Diacritic"},
    866: {"Diacritic"},
    884: {"Diacritic"},
    885: {"Diacritic"},
    890: {"Other_Lowercase", "Diacritic"},
    894: {"Terminal_Punctuation"},
    900: {"Diacritic"},
    901: {"Diacritic"},
    903: {"Other_ID_Continue", "Terminal_Punctuation"},
    976: {"Other_Math"},
    977: {"Other_Math"},
    978: {"Other_Math"},
    981: {"Other_Math"},
    1008: {"Other_Math"},
    1009: {"Other_Math"},
    1011: {"Soft_Dotted"},
    1012: {"Other_Math"},
    1013: {"Other_Math"},
    1110: {"Soft_Dotted"},
    1112: {"Soft_Dotted"},
    1155: {"Diacritic"},
    1156: {"Diacritic"},
    1157: {"Diacritic"},
    1158: {"Diacritic"},
    1159: {"Diacritic"},
    1369: {"Diacritic"},
    1417: {"Terminal_Punctuation", "Sentence_Terminal"},
    1418: {"Dash", "Hyphen"},
    1425: {"Diacritic"},
    1426: {"Diacritic"},
    1427: {"Diacritic"},
    1428: {"Diacritic"},
    1429: {"Diacritic"},
    1430: {"Diacritic"},
    1431: {"Diacritic"},
    1432: {"Diacritic"},
    1433: {"Diacritic"},
    1434: {"Diacritic"},
    1435: {"Diacritic"},
    1436: {"Diacritic"},
    1437: {"Diacritic"},
    1438: {"Diacritic"},
    1439: {"Diacritic"},
    1440: {"Diacritic"},
    1441: {"Diacritic"},
    1443: {"Diacritic"},
    1444: {"Diacritic"},
    1445: {"Diacritic"},
    1446: {"Diacritic"},
    1447: {"Diacritic"},
    1448: {"Diacritic"},
    1449: {"Diacritic"},
    1450: {"Diacritic"},
    1451: {"Diacritic"},
    1452: {"Diacritic"},
    1453: {"Diacritic"},
    1454: {"Diacritic"},
    1455: {"Diacritic"},
    1456: {"Diacritic", "Other_Alphabetic"},
    1457: {"Diacritic", "Other_Alphabetic"},
    1458: {"Diacritic", "Other_Alphabetic"},
    1459: {"Diacritic", "Other_Alphabetic"},
    1460: {"Diacritic", "Other_Alphabetic"},
    1461: {"Diacritic", "Other_Alphabetic"},
    1462: {"Diacritic", "Other_Alphabetic"},
    1463: {"Diacritic", "Other_Alphabetic"},
    1464: {"Diacritic", "Other_Alphabetic"},
    1465: {"Diacritic", "Other_Alphabetic"},
    1466: {"Diacritic", "Other_Alphabetic"},
    1467: {"Diacritic", "Other_Alphabetic"},
    1468: {"Diacritic", "Other_Alphabetic"},
    1469: {"Diacritic", "Other_Alphabetic"},
    1470: {"Dash"},
    1471: {"Diacritic", "Other_Alphabetic"},
    1473: {"Diacritic", "Other_Alphabetic"},
    1474: {"Diacritic", "Other_Alphabetic"},
    1475: {"Terminal_Punctuation"},
    1476: {"Diacritic", "Other_Alphabetic"},
    1477: {"Other_Alphabetic"},
    1479: {"Other_Alphabetic"},
    1536: {"Prepended_Concatenation_Mark"},
    1537: {"Prepended_Concatenation_Mark"},
    1538: {"Prepended_Concatenation_Mark"},
    1539: {"Prepended_Concatenation_Mark"},
    1540: {"Prepended_Concatenation_Mark"},
    1541: {"Prepended_Concatenation_Mark"},
    1548: {"Terminal_Punctuation"},
    1552: {"Other_Alphabetic"},
    1553: {"Other_Alphabetic"},
    1554: {"Other_Alphabetic"},
    1555: {"Other_Alphabetic"},
    1556: {"Other_Alphabetic"},
    1557: {"Other_Alphabetic"},
    1558: {"Other_Alphabetic"},
    1559: {"Other_Alphabetic"},
    1560: {"Other_Alphabetic"},
    1561: {"Other_Alphabetic"},
    1562: {"Other_Alphabetic"},
    1563: {"Terminal_Punctuation"},
    1564: {"Bidi_Control"},
    1566: {"Terminal_Punctuation", "Sentence_Terminal"},
    1567: {"Terminal_Punctuation", "Sentence_Terminal"},
    1600: {"Extender"},
    1611: {"Diacritic", "Other_Alphabetic"},
    1612: {"Diacritic", "Other_Alphabetic"},
    1613: {"Diacritic", "Other_Alphabetic"},
    1614: {"Diacritic", "Other_Alphabetic"},
    1615: {"Diacritic", "Other_Alphabetic"},
    1616: {"Diacritic", "Other_Alphabetic"},
    1617: {"Diacritic", "Other_Alphabetic"},
    1618: {"Diacritic", "Other_Alphabetic"},
    1619: {"Other_Alphabetic"},
    1620: {"Other_Alphabetic"},
    1621: {"Other_Alphabetic"},
    1622: {"Other_Alphabetic"},
    1623: {"Diacritic", "Other_Alphabetic"},
    1624: {"Diacritic"},
    1625: {"Other_Alphabetic"},
    1626: {"Other_Alphabetic"},
    1627: {"Other_Alphabetic"},
    1628: {"Other_Alphabetic"},
    1629: {"Other_Alphabetic"},
    1630: {"Other_Alphabetic"},
    1631: {"Other_Alphabetic"},
    1648: {"Other_Alphabetic"},
    1651: {"Deprecated"},
    1748: {"Terminal_Punctuation", "Sentence_Terminal"},
    1750: {"Other_Alphabetic"},
    1751: {"Other_Alphabetic"},
    1752: {"Other_Alphabetic"},
    1753: {"Other_Alphabetic"},
    1754: {"Other_Alphabetic"},
    1755: {"Other_Alphabetic"},
    1756: {"Other_Alphabetic"},
    1757: {"Prepended_Concatenation_Mark"},
    1759: {"Diacritic"},
    1760: {"Diacritic"},
    1761: {"Other_Alphabetic"},
    1762: {"Other_Alphabetic"},
    1763: {"Other_Alphabetic"},
    1764: {"Other_Alphabetic"},
    1765: {"Diacritic"},
    1766: {"Diacritic"},
    1767: {"Other_Alphabetic"},
    1768: {"Other_Alphabetic"},
    1770: {"Diacritic"},
    1771: {"Diacritic"},
    1772: {"Diacritic"},
    1773: {"Other_Alphabetic"},
    1792: {"Terminal_Punctuation", "Sentence_Terminal"},
    1793: {"Terminal_Punctuation", "Sentence_Terminal"},
    1794: {"Terminal_Punctuation", "Sentence_Terminal"},
    1795: {"Terminal_Punctuation"},
    1796: {"Terminal_Punctuation"},
    1797: {"Terminal_Punctuation"},
    1798: {"Terminal_Punctuation"},
    1799: {"Terminal_Punctuation"},
    1800: {"Terminal_Punctuation"},
    1801: {"Terminal_Punctuation"},
    1802: {"Terminal_Punctuation"},
    1804: {"Terminal_Punctuation"},
    1807: {"Prepended_Concatenation_Mark"},
    1809: {"Other_Alphabetic"},
    1840: {"Diacritic", "Other_Alphabetic"},
    1841: {"Diacritic", "Other_Alphabetic"},
    1842: {"Diacritic", "Other_Alphabetic"},
    1843: {"Diacritic", "Other_Alphabetic"},
    1844: {"Diacritic", "Other_Alphabetic"},
    1845: {"Diacritic", "Other_Alphabetic"},
    1846: {"Diacritic", "Other_Alphabetic"},
    1847: {"Diacritic", "Other_Alphabetic"},
    1848: {"Diacritic", "Other_Alphabetic"},
    1849: {"Diacritic", "Other_Alphabetic"},
    1850: {"Diacritic", "Other_Alphabetic"},
    1851: {"Diacritic", "Other_Alphabetic"},
    1852: {"Diacritic", "Other_Alphabetic"},
    1853: {"Diacritic", "Other_Alphabetic"},
    1854: {"Diacritic", "Other_Alphabetic"},
    1855: {"Diacritic", "Other_Alphabetic"},
    1856: {"Diacritic"},
    1857: {"Diacritic"},
    1858: {"Diacritic"},
    1859: {"Diacritic"},
    1860: {"Diacritic"},
    1861: {"Diacritic"},
    1862: {"Diacritic"},
    1863: {"Diacritic"},
    1864: {"Diacritic"},
    1865: {"Diacritic"},
    1866: {"Diacritic"},
    1958: {"Diacritic", "Other_Alphabetic"},
    1959: {"Diacritic", "Other_Alphabetic"},
    1960: {"Diacritic", "Other_Alphabetic"},
    1961: {"Diacritic", "Other_Alphabetic"},
    1962: {"Diacritic", "Other_Alphabetic"},
    1963: {"Diacritic", "Other_Alphabetic"},
    1964: {"Diacritic", "Other_Alphabetic"},
    1965: {"Diacritic", "Other_Alphabetic"},
    1966: {"Diacritic", "Other_Alphabetic"},
    1967: {"Diacritic", "Other_Alphabetic"},
    1968: {"Diacritic", "Other_Alphabetic"},
    2027: {"Diacritic"},
    2028: {"Diacritic"},
    2029: {"Diacritic"},
    2030: {"Diacritic"},
    2031: {"Diacritic"},
    2032: {"Diacritic"},
    2033: {"Diacritic"},
    2034: {"Diacritic"},
    2035: {"Diacritic"},
    2036: {"Diacritic"},
    2037: {"Diacritic"},
    2040: {"Terminal_Punctuation"},
    2041: {"Terminal_Punctuation", "Sentence_Terminal"},
    2042: {"Extender"},
    2070: {"Other_Alphabetic"},
    2071: {"Other_Alphabetic"},
    2072: {"Diacritic"},
    2073: {"Diacritic"},
    2075: {"Other_Alphabetic"},
    2076: {"Other_Alphabetic"},
    2077: {"Other_Alphabetic"},
    2078: {"Other_Alphabetic"},
    2079: {"Other_Alphabetic"},
    2080: {"Other_Alphabetic"},
    2081: {"Other_Alphabetic"},
    2082: {"Other_Alphabetic"},
    2083: {"Other_Alphabetic"},
    2085: {"Other_Alphabetic"},
    2086: {"Other_Alphabetic"},
    2087: {"Other_Alphabetic"},
    2089: {"Other_Alphabetic"},
    2090: {"Other_Alphabetic"},
    2091: {"Other_Alphabetic"},
    2092: {"Other_Alphabetic"},
    2096: {"Terminal_Punctuation"},
    2097: {"Terminal_Punctuation"},
    2098: {"Terminal_Punctuation"},
    2099: {"Terminal_Punctuation"},
    2100: {"Terminal_Punctuation"},
    2101: {"Terminal_Punctuation"},
    2102: {"Terminal_Punctuation"},
    2103: {"Terminal_Punctuation", "Sentence_Terminal"},
    2104: {"Terminal_Punctuation"},
    2105: {"Terminal_Punctuation", "Sentence_Terminal"},
    2106: {"Terminal_Punctuation"},
    2107: {"Terminal_Punctuation"},
    2108: {"Terminal_Punctuation"},
    2109: {"Terminal_Punctuation", "Sentence_Terminal"},
    2110: {"Terminal_Punctuation", "Sentence_Terminal"},
    2142: {"Terminal_Punctuation"},
    2260: {"Other_Alphabetic"},
    2261: {"Other_Alphabetic"},
    2262: {"Other_Alphabetic"},
    2263: {"Other_Alphabetic"},
    2264: {"Other_Alphabetic"},
    2265: {"Other_Alphabetic"},
    2266: {"Other_Alphabetic"},
    2267: {"Other_Alphabetic"},
    2268: {"Other_Alphabetic"},
    2269: {"Other_Alphabetic"},
    2270: {"Other_Alphabetic"},
    2271: {"Other_Alphabetic"},
    2274: {"Prepended_Concatenation_Mark"},
    2275: {"Diacritic", "Other_Alphabetic"},
    2276: {"Diacritic", "Other_Alphabetic"},
    2277: {"Diacritic", "Other_Alphabetic"},
    2278: {"Diacritic", "Other_Alphabetic"},
    2279: {"Diacritic", "Other_Alphabetic"},
    2280: {"Diacritic", "Other_Alphabetic"},
    2281: {"Diacritic", "Other_Alphabetic"},
    2282: {"Diacritic"},
    2283: {"Diacritic"},
    2284: {"Diacritic"},
    2285: {"Diacritic"},
    2286: {"Diacritic"},
    2287: {"Diacritic"},
    2288: {"Diacritic", "Other_Alphabetic"},
    2289: {"Diacritic", "Other_Alphabetic"},
    2290: {"Diacritic", "Other_Alphabetic"},
    2291: {"Diacritic", "Other_Alphabetic"},
    2292: {"Diacritic", "Other_Alphabetic"},
    2293: {"Diacritic", "Other_Alphabetic"},
    2294: {"Diacritic", "Other_Alphabetic"},
    2295: {"Diacritic", "Other_Alphabetic"},
    2296: {"Diacritic", "Other_Alphabetic"},
    2297: {"Diacritic", "Other_Alphabetic"},
    2298: {"Diacritic", "Other_Alphabetic"},
    2299: {"Diacritic", "Other_Alphabetic"},
    2300: {"Diacritic", "Other_Alphabetic"},
    2301: {"Diacritic", "Other_Alphabetic"},
    2302: {"Diacritic", "Other_Alphabetic"},
    2303: {"Other_Alphabetic"},
    2304: {"Other_Alphabetic"},
    2305: {"Other_Alphabetic"},
    2306: {"Other_Alphabetic"},
    2307: {"Other_Alphabetic"},
    2362: {"Other_Alphabetic"},
    2363: {"Other_Alphabetic"},
    2364: {"Diacritic"},
    2366: {"Other_Alphabetic"},
    2367: {"Other_Alphabetic"},
    2368: {"Other_Alphabetic"},
    2369: {"Other_Alphabetic"},
    2370: {"Other_Alphabetic"},
    2371: {"Other_Alphabetic"},
    2372: {"Other_Alphabetic"},
    2373: {"Other_Alphabetic"},
    2374: {"Other_Alphabetic"},
    2375: {"Other_Alphabetic"},
    2376: {"Other_Alphabetic"},
    2377: {"Other_Alphabetic"},
    2378: {"Other_Alphabetic"},
    2379: {"Other_Alphabetic"},
    2380: {"Other_Alphabetic"},
    2381: {"Diacritic"},
    2382: {"Other_Alphabetic"},
    2383: {"Other_Alphabetic"},
    2385: {"Diacritic"},
    2386: {"Diacritic"},
    2387: {"Diacritic"},
    2388: {"Diacritic"},
    2389: {"Other_Alphabetic"},
    2390: {"Other_Alphabetic"},
    2391: {"Other_Alphabetic"},
    2402: {"Other_Alphabetic"},
    2403: {"Other_Alphabetic"},
    2404: {"Terminal_Punctuation", "Sentence_Terminal"},
    2405: {"Terminal_Punctuation", "Sentence_Terminal"},
    2417: {"Diacritic"},
    2433: {"Other_Alphabetic"},
    2434: {"Other_Alphabetic"},
    2435: {"Other_Alphabetic"},
    2492: {"Diacritic"},
    2494: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    2495: {"Other_Alphabetic"},
    2496: {"Other_Alphabetic"},
    2497: {"Other_Alphabetic"},
    2498: {"Other_Alphabetic"},
    2499: {"Other_Alphabetic"},
    2500: {"Other_Alphabetic"},
    2503: {"Other_Alphabetic"},
    2504: {"Other_Alphabetic"},
    2507: {"Other_Alphabetic"},
    2508: {"Other_Alphabetic"},
    2509: {"Diacritic"},
    2519: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    2530: {"Other_Alphabetic"},
    2531: {"Other_Alphabetic"},
    2561: {"Other_Alphabetic"},
    2562: {"Other_Alphabetic"},
    2563: {"Other_Alphabetic"},
    2620: {"Diacritic"},
    2622: {"Other_Alphabetic"},
    2623: {"Other_Alphabetic"},
    2624: {"Other_Alphabetic"},
    2625: {"Other_Alphabetic"},
    2626: {"Other_Alphabetic"},
    2631: {"Other_Alphabetic"},
    2632: {"Other_Alphabetic"},
    2635: {"Other_Alphabetic"},
    2636: {"Other_Alphabetic"},
    2637: {"Diacritic"},
    2641: {"Other_Alphabetic"},
    2672: {"Other_Alphabetic"},
    2673: {"Other_Alphabetic"},
    2677: {"Other_Alphabetic"},
    2689: {"Other_Alphabetic"},
    2690: {"Other_Alphabetic"},
    2691: {"Other_Alphabetic"},
    2748: {"Diacritic"},
    2750: {"Other_Alphabetic"},
    2751: {"Other_Alphabetic"},
    2752: {"Other_Alphabetic"},
    2753: {"Other_Alphabetic"},
    2754: {"Other_Alphabetic"},
    2755: {"Other_Alphabetic"},
    2756: {"Other_Alphabetic"},
    2757: {"Other_Alphabetic"},
    2759: {"Other_Alphabetic"},
    2760: {"Other_Alphabetic"},
    2761: {"Other_Alphabetic"},
    2763: {"Other_Alphabetic"},
    2764: {"Other_Alphabetic"},
    2765: {"Diacritic"},
    2786: {"Other_Alphabetic"},
    2787: {"Other_Alphabetic"},
    2810: {"Other_Alphabetic"},
    2811: {"Other_Alphabetic"},
    2812: {"Other_Alphabetic"},
    2813: {"Diacritic"},
    2814: {"Diacritic"},
    2815: {"Diacritic"},
    2817: {"Other_Alphabetic"},
    2818: {"Other_Alphabetic"},
    2819: {"Other_Alphabetic"},
    2876: {"Diacritic"},
    2878: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    2879: {"Other_Alphabetic"},
    2880: {"Other_Alphabetic"},
    2881: {"Other_Alphabetic"},
    2882: {"Other_Alphabetic"},
    2883: {"Other_Alphabetic"},
    2884: {"Other_Alphabetic"},
    2887: {"Other_Alphabetic"},
    2888: {"Other_Alphabetic"},
    2891: {"Other_Alphabetic"},
    2892: {"Other_Alphabetic"},
    2893: {"Diacritic"},
    2901: {"Diacritic", "Extender"},
    2902: {"Other_Alphabetic"},
    2903: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    2914: {"Other_Alphabetic"},
    2915: {"Other_Alphabetic"},
    2946: {"Other_Alphabetic"},
    3006: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3007: {"Other_Alphabetic"},
    3008: {"Other_Alphabetic"},
    3009: {"Other_Alphabetic"},
    3010: {"Other_Alphabetic"},
    3014: {"Other_Alphabetic"},
    3015: {"Other_Alphabetic"},
    3016: {"Other_Alphabetic"},
    3018: {"Other_Alphabetic"},
    3019: {"Other_Alphabetic"},
    3020: {"Other_Alphabetic"},
    3021: {"Diacritic"},
    3031: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3072: {"Other_Alphabetic"},
    3073: {"Other_Alphabetic"},
    3074: {"Other_Alphabetic"},
    3075: {"Other_Alphabetic"},
    3134: {"Other_Alphabetic"},
    3135: {"Other_Alphabetic"},
    3136: {"Other_Alphabetic"},
    3137: {"Other_Alphabetic"},
    3138: {"Other_Alphabetic"},
    3139: {"Other_Alphabetic"},
    3140: {"Other_Alphabetic"},
    3142: {"Other_Alphabetic"},
    3143: {"Other_Alphabetic"},
    3144: {"Other_Alphabetic"},
    3146: {"Other_Alphabetic"},
    3147: {"Other_Alphabetic"},
    3148: {"Other_Alphabetic"},
    3149: {"Diacritic"},
    3157: {"Other_Alphabetic"},
    3158: {"Other_Alphabetic"},
    3170: {"Other_Alphabetic"},
    3171: {"Other_Alphabetic"},
    3201: {"Other_Alphabetic"},
    3202: {"Other_Alphabetic"},
    3203: {"Other_Alphabetic"},
    3260: {"Diacritic"},
    3262: {"Other_Alphabetic"},
    3263: {"Other_Alphabetic"},
    3264: {"Other_Alphabetic"},
    3265: {"Other_Alphabetic"},
    3266: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3267: {"Other_Alphabetic"},
    3268: {"Other_Alphabetic"},
    3270: {"Other_Alphabetic"},
    3271: {"Other_Alphabetic"},
    3272: {"Other_Alphabetic"},
    3274: {"Other_Alphabetic"},
    3275: {"Other_Alphabetic"},
    3276: {"Other_Alphabetic"},
    3277: {"Diacritic"},
    3285: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3286: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3298: {"Other_Alphabetic"},
    3299: {"Other_Alphabetic"},
    3328: {"Other_Alphabetic"},
    3329: {"Other_Alphabetic"},
    3330: {"Other_Alphabetic"},
    3331: {"Other_Alphabetic"},
    3387: {"Diacritic"},
    3388: {"Diacritic"},
    3390: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3391: {"Other_Alphabetic"},
    3392: {"Other_Alphabetic"},
    3393: {"Other_Alphabetic"},
    3394: {"Other_Alphabetic"},
    3395: {"Other_Alphabetic"},
    3396: {"Other_Alphabetic"},
    3398: {"Other_Alphabetic"},
    3399: {"Other_Alphabetic"},
    3400: {"Other_Alphabetic"},
    3402: {"Other_Alphabetic"},
    3403: {"Other_Alphabetic"},
    3404: {"Other_Alphabetic"},
    3405: {"Diacritic"},
    3415: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3426: {"Other_Alphabetic"},
    3427: {"Other_Alphabetic"},
    3457: {"Other_Alphabetic"},
    3458: {"Other_Alphabetic"},
    3459: {"Other_Alphabetic"},
    3530: {"Diacritic"},
    3535: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3536: {"Other_Alphabetic"},
    3537: {"Other_Alphabetic"},
    3538: {"Other_Alphabetic"},
    3539: {"Other_Alphabetic"},
    3540: {"Other_Alphabetic"},
    3542: {"Other_Alphabetic"},
    3544: {"Other_Alphabetic"},
    3545: {"Other_Alphabetic"},
    3546: {"Other_Alphabetic"},
    3547: {"Other_Alphabetic"},
    3548: {"Other_Alphabetic"},
    3549: {"Other_Alphabetic"},
    3550: {"Other_Alphabetic"},
    3551: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    3570: {"Other_Alphabetic"},
    3571: {"Other_Alphabetic"},
    3633: {"Other_Alphabetic"},
    3636: {"Other_Alphabetic"},
    3637: {"Other_Alphabetic"},
    3638: {"Other_Alphabetic"},
    3639: {"Other_Alphabetic"},
    3640: {"Other_Alphabetic"},
    3641: {"Other_Alphabetic"},
    3642: {"Other_Alphabetic"},
    3648: {"Logical_Order_Exception"},
    3649: {"Logical_Order_Exception"},
    3650: {"Logical_Order_Exception"},
    3651: {"Logical_Order_Exception"},
    3652: {"Logical_Order_Exception"},
    3654: {"Extender"},
    3655: {"Diacritic"},
    3656: {"Diacritic"},
    3657: {"Diacritic"},
    3658: {"Diacritic"},
    3659: {"Diacritic"},
    3660: {"Diacritic"},
    3661: {"Other_Alphabetic"},
    3662: {"Diacritic"},
    3674: {"Terminal_Punctuation"},
    3675: {"Terminal_Punctuation"},
    3761: {"Other_Alphabetic"},
    3764: {"Other_Alphabetic"},
    3765: {"Other_Alphabetic"},
    3766: {"Other_Alphabetic"},
    3767: {"Other_Alphabetic"},
    3768: {"Other_Alphabetic"},
    3769: {"Other_Alphabetic"},
    3770: {"Diacritic"},
    3771: {"Other_Alphabetic"},
    3772: {"Other_Alphabetic"},
    3776: {"Logical_Order_Exception"},
    3777: {"Logical_Order_Exception"},
    3778: {"Logical_Order_Exception"},
    3779: {"Logical_Order_Exception"},
    3780: {"Logical_Order_Exception"},
    3782: {"Extender"},
    3784: {"Diacritic"},
    3785: {"Diacritic"},
    3786: {"Diacritic"},
    3787: {"Diacritic"},
    3788: {"Diacritic"},
    3789: {"Other_Alphabetic"},
    3848: {"Terminal_Punctuation"},
    3853: {"Terminal_Punctuation"},
    3854: {"Terminal_Punctuation"},
    3855: {"Terminal_Punctuation"},
    3856: {"Terminal_Punctuation"},
    3857: {"Terminal_Punctuation"},
    3858: {"Terminal_Punctuation"},
    3864: {"Diacritic"},
    3865: {"Diacritic"},
    3893: {"Diacritic"},
    3895: {"Diacritic"},
    3897: {"Diacritic"},
    3902: {"Diacritic"},
    3903: {"Diacritic"},
    3953: {"Other_Alphabetic"},
    3954: {"Other_Alphabetic"},
    3955: {"Other_Alphabetic"},
    3956: {"Other_Alphabetic"},
    3957: {"Other_Alphabetic"},
    3958: {"Other_Alphabetic"},
    3959: {"Other_Alphabetic", "Deprecated"},
    3960: {"Other_Alphabetic"},
    3961: {"Other_Alphabetic", "Deprecated"},
    3962: {"Other_Alphabetic"},
    3963: {"Other_Alphabetic"},
    3964: {"Other_Alphabetic"},
    3965: {"Other_Alphabetic"},
    3966: {"Other_Alphabetic"},
    3967: {"Other_Alphabetic"},
    3968: {"Other_Alphabetic"},
    3969: {"Other_Alphabetic"},
    3970: {"Diacritic"},
    3971: {"Diacritic"},
    3972: {"Diacritic"},
    3974: {"Diacritic"},
    3975: {"Diacritic"},
    3981: {"Other_Alphabetic"},
    3982: {"Other_Alphabetic"},
    3983: {"Other_Alphabetic"},
    3984: {"Other_Alphabetic"},
    3985: {"Other_Alphabetic"},
    3986: {"Other_Alphabetic"},
    3987: {"Other_Alphabetic"},
    3988: {"Other_Alphabetic"},
    3989: {"Other_Alphabetic"},
    3990: {"Other_Alphabetic"},
    3991: {"Other_Alphabetic"},
    3993: {"Other_Alphabetic"},
    3994: {"Other_Alphabetic"},
    3995: {"Other_Alphabetic"},
    3996: {"Other_Alphabetic"},
    3997: {"Other_Alphabetic"},
    3998: {"Other_Alphabetic"},
    3999: {"Other_Alphabetic"},
    4000: {"Other_Alphabetic"},
    4001: {"Other_Alphabetic"},
    4002: {"Other_Alphabetic"},
    4003: {"Other_Alphabetic"},
    4004: {"Other_Alphabetic"},
    4005: {"Other_Alphabetic"},
    4006: {"Other_Alphabetic"},
    4007: {"Other_Alphabetic"},
    4008: {"Other_Alphabetic"},
    4009: {"Other_Alphabetic"},
    4010: {"Other_Alphabetic"},
    4011: {"Other_Alphabetic"},
    4012: {"Other_Alphabetic"},
    4013: {"Other_Alphabetic"},
    4014: {"Other_Alphabetic"},
    4015: {"Other_Alphabetic"},
    4016: {"Other_Alphabetic"},
    4017: {"Other_Alphabetic"},
    4018: {"Other_Alphabetic"},
    4019: {"Other_Alphabetic"},
    4020: {"Other_Alphabetic"},
    4021: {"Other_Alphabetic"},
    4022: {"Other_Alphabetic"},
    4023: {"Other_Alphabetic"},
    4024: {"Other_Alphabetic"},
    4025: {"Other_Alphabetic"},
    4026: {"Other_Alphabetic"},
    4027: {"Other_Alphabetic"},
    4028: {"Other_Alphabetic"},
    4038: {"Diacritic"},
    4139: {"Other_Alphabetic"},
    4140: {"Other_Alphabetic"},
    4141: {"Other_Alphabetic"},
    4142: {"Other_Alphabetic"},
    4143: {"Other_Alphabetic"},
    4144: {"Other_Alphabetic"},
    4145: {"Other_Alphabetic"},
    4146: {"Other_Alphabetic"},
    4147: {"Other_Alphabetic"},
    4148: {"Other_Alphabetic"},
    4149: {"Other_Alphabetic"},
    4150: {"Other_Alphabetic"},
    4151: {"Diacritic"},
    4152: {"Other_Alphabetic"},
    4153: {"Diacritic"},
    4154: {"Diacritic"},
    4155: {"Other_Alphabetic"},
    4156: {"Other_Alphabetic"},
    4157: {"Other_Alphabetic"},
    4158: {"Other_Alphabetic"},
    4170: {"Terminal_Punctuation", "Sentence_Terminal"},
    4171: {"Terminal_Punctuation", "Sentence_Terminal"},
    4182: {"Other_Alphabetic"},
    4183: {"Other_Alphabetic"},
    4184: {"Other_Alphabetic"},
    4185: {"Other_Alphabetic"},
    4190: {"Other_Alphabetic"},
    4191: {"Other_Alphabetic"},
    4192: {"Other_Alphabetic"},
    4194: {"Other_Alphabetic"},
    4195: {"Diacritic", "Other_Alphabetic"},
    4196: {"Diacritic", "Other_Alphabetic"},
    4199: {"Other_Alphabetic"},
    4200: {"Other_Alphabetic"},
    4201: {"Diacritic", "Other_Alphabetic"},
    4202: {"Diacritic", "Other_Alphabetic"},
    4203: {"Diacritic", "Other_Alphabetic"},
    4204: {"Diacritic", "Other_Alphabetic"},
    4205: {"Diacritic", "Other_Alphabetic"},
    4209: {"Other_Alphabetic"},
    4210: {"Other_Alphabetic"},
    4211: {"Other_Alphabetic"},
    4212: {"Other_Alphabetic"},
    4226: {"Other_Alphabetic"},
    4227: {"Other_Alphabetic"},
    4228: {"Other_Alphabetic"},
    4229: {"Other_Alphabetic"},
    4230: {"Other_Alphabetic"},
    4231: {"Diacritic", "Other_Alphabetic"},
    4232: {"Diacritic", "Other_Alphabetic"},
    4233: {"Diacritic", "Other_Alphabetic"},
    4234: {"Diacritic", "Other_Alphabetic"},
    4235: {"Diacritic", "Other_Alphabetic"},
    4236: {"Diacritic", "Other_Alphabetic"},
    4237: {"Diacritic", "Other_Alphabetic"},
    4239: {"Diacritic", "Other_Alphabetic"},
    4250: {"Diacritic", "Other_Alphabetic"},
    4251: {"Diacritic", "Other_Alphabetic"},
    4252: {"Other_Alphabetic"},
    4253: {"Other_Alphabetic"},
    4447: {"Other_Default_Ignorable_Code_Point"},
    4448: {"Other_Default_Ignorable_Code_Point"},
    4957: {"Diacritic"},
    4958: {"Diacritic"},
    4959: {"Diacritic"},
    4961: {"Terminal_Punctuation"},
    4962: {"Terminal_Punctuation", "Sentence_Terminal"},
    4963: {"Terminal_Punctuation"},
    4964: {"Terminal_Punctuation"},
    4965: {"Terminal_Punctuation"},
    4966: {"Terminal_Punctuation"},
    4967: {"Terminal_Punctuation", "Sentence_Terminal"},
    4968: {"Terminal_Punctuation", "Sentence_Terminal"},
    4969: {"Other_ID_Continue"},
    4970: {"Other_ID_Continue"},
    4971: {"Other_ID_Continue"},
    4972: {"Other_ID_Continue"},
    4973: {"Other_ID_Continue"},
    4974: {"Other_ID_Continue"},
    4975: {"Other_ID_Continue"},
    4976: {"Other_ID_Continue"},
    4977: {"Other_ID_Continue"},
    5120: {"Dash"},
    5742: {"Terminal_Punctuation", "Sentence_Terminal"},
    5760: {"White_Space"},
    5867: {"Terminal_Punctuation"},
    5868: {"Terminal_Punctuation"},
    5869: {"Terminal_Punctuation"},
    5906: {"Other_Alphabetic"},
    5907: {"Other_Alphabetic"},
    5938: {"Other_Alphabetic"},
    5939: {"Other_Alphabetic"},
    5941: {"Terminal_Punctuation", "Sentence_Terminal"},
    5942: {"Terminal_Punctuation", "Sentence_Terminal"},
    5970: {"Other_Alphabetic"},
    5971: {"Other_Alphabetic"},
    6002: {"Other_Alphabetic"},
    6003: {"Other_Alphabetic"},
    6051: {"Deprecated"},
    6052: {"Deprecated"},
    6068: {"Other_Default_Ignorable_Code_Point"},
    6069: {"Other_Default_Ignorable_Code_Point"},
    6070: {"Other_Alphabetic"},
    6071: {"Other_Alphabetic"},
    6072: {"Other_Alphabetic"},
    6073: {"Other_Alphabetic"},
    6074: {"Other_Alphabetic"},
    6075: {"Other_Alphabetic"},
    6076: {"Other_Alphabetic"},
    6077: {"Other_Alphabetic"},
    6078: {"Other_Alphabetic"},
    6079: {"Other_Alphabetic"},
    6080: {"Other_Alphabetic"},
    6081: {"Other_Alphabetic"},
    6082: {"Other_Alphabetic"},
    6083: {"Other_Alphabetic"},
    6084: {"Other_Alphabetic"},
    6085: {"Other_Alphabetic"},
    6086: {"Other_Alphabetic"},
    6087: {"Other_Alphabetic"},
    6088: {"Other_Alphabetic"},
    6089: {"Diacritic"},
    6090: {"Diacritic"},
    6091: {"Diacritic"},
    6092: {"Diacritic"},
    6093: {"Diacritic"},
    6094: {"Diacritic"},
    6095: {"Diacritic"},
    6096: {"Diacritic"},
    6097: {"Diacritic"},
    6098: {"Diacritic"},
    6099: {"Diacritic"},
    6100: {"Terminal_Punctuation"},
    6101: {"Terminal_Punctuation"},
    6102: {"Terminal_Punctuation"},
    6106: {"Terminal_Punctuation"},
    6109: {"Diacritic"},
    6146: {"Terminal_Punctuation"},
    6147: {"Terminal_Punctuation", "Sentence_Terminal"},
    6148: {"Terminal_Punctuation"},
    6149: {"Terminal_Punctuation"},
    6150: {"Dash", "Hyphen"},
    6152: {"Terminal_Punctuation"},
    6153: {"Terminal_Punctuation", "Sentence_Terminal"},
    6154: {"Extender"},
    6155: {"Variation_Selector"},
    6156: {"Variation_Selector"},
    6157: {"Variation_Selector"},
    6211: {"Extender"},
    6277: {"Other_ID_Start", "Other_Alphabetic"},
    6278: {"Other_ID_Start", "Other_Alphabetic"},
    6313: {"Other_Alphabetic"},
    6432: {"Other_Alphabetic"},
    6433: {"Other_Alphabetic"},
    6434: {"Other_Alphabetic"},
    6435: {"Other_Alphabetic"},
    6436: {"Other_Alphabetic"},
    6437: {"Other_Alphabetic"},
    6438: {"Other_Alphabetic"},
    6439: {"Other_Alphabetic"},
    6440: {"Other_Alphabetic"},
    6441: {"Other_Alphabetic"},
    6442: {"Other_Alphabetic"},
    6443: {"Other_Alphabetic"},
    6448: {"Other_Alphabetic"},
    6449: {"Other_Alphabetic"},
    6450: {"Other_Alphabetic"},
    6451: {"Other_Alphabetic"},
    6452: {"Other_Alphabetic"},
    6453: {"Other_Alphabetic"},
    6454: {"Other_Alphabetic"},
    6455: {"Other_Alphabetic"},
    6456: {"Other_Alphabetic"},
    6457: {"Diacritic"},
    6458: {"Diacritic"},
    6459: {"Diacritic"},
    6468: {"Terminal_Punctuation", "Sentence_Terminal"},
    6469: {"Terminal_Punctuation", "Sentence_Terminal"},
    6581: {"Logical_Order_Exception"},
    6582: {"Logical_Order_Exception"},
    6583: {"Logical_Order_Exception"},
    6586: {"Logical_Order_Exception"},
    6618: {"Other_ID_Continue"},
    6679: {"Other_Alphabetic"},
    6680: {"Other_Alphabetic"},
    6681: {"Other_Alphabetic"},
    6682: {"Other_Alphabetic"},
    6683: {"Other_Alphabetic"},
    6741: {"Other_Alphabetic"},
    6742: {"Other_Alphabetic"},
    6743: {"Other_Alphabetic"},
    6744: {"Other_Alphabetic"},
    6745: {"Other_Alphabetic"},
    6746: {"Other_Alphabetic"},
    6747: {"Other_Alphabetic"},
    6748: {"Other_Alphabetic"},
    6749: {"Other_Alphabetic"},
    6750: {"Other_Alphabetic"},
    6753: {"Other_Alphabetic"},
    6754: {"Other_Alphabetic"},
    6755: {"Other_Alphabetic"},
    6756: {"Other_Alphabetic"},
    6757: {"Other_Alphabetic"},
    6758: {"Other_Alphabetic"},
    6759: {"Other_Alphabetic"},
    6760: {"Other_Alphabetic"},
    6761: {"Other_Alphabetic"},
    6762: {"Other_Alphabetic"},
    6763: {"Other_Alphabetic"},
    6764: {"Other_Alphabetic"},
    6765: {"Other_Alphabetic"},
    6766: {"Other_Alphabetic"},
    6767: {"Other_Alphabetic"},
    6768: {"Other_Alphabetic"},
    6769: {"Other_Alphabetic"},
    6770: {"Other_Alphabetic"},
    6771: {"Other_Alphabetic"},
    6772: {"Other_Alphabetic"},
    6773: {"Diacritic"},
    6774: {"Diacritic"},
    6775: {"Diacritic"},
    6776: {"Diacritic"},
    6777: {"Diacritic"},
    6778: {"Diacritic"},
    6779: {"Diacritic"},
    6780: {"Diacritic"},
    6783: {"Diacritic"},
    6823: {"Extender"},
    6824: {"Terminal_Punctuation", "Sentence_Terminal"},
    6825: {"Terminal_Punctuation", "Sentence_Terminal"},
    6826: {"Terminal_Punctuation", "Sentence_Terminal"},
    6827: {"Terminal_Punctuation", "Sentence_Terminal"},
    6832: {"Diacritic"},
    6833: {"Diacritic"},
    6834: {"Diacritic"},
    6835: {"Diacritic"},
    6836: {"Diacritic"},
    6837: {"Diacritic"},
    6838: {"Diacritic"},
    6839: {"Diacritic"},
    6840: {"Diacritic"},
    6841: {"Diacritic"},
    6842: {"Diacritic"},
    6843: {"Diacritic"},
    6844: {"Diacritic"},
    6845: {"Diacritic"},
    6847: {"Other_Alphabetic"},
    6848: {"Other_Alphabetic"},
    6912: {"Other_Alphabetic"},
    6913: {"Other_Alphabetic"},
    6914: {"Other_Alphabetic"},
    6915: {"Other_Alphabetic"},
    6916: {"Other_Alphabetic"},
    6964: {"Diacritic"},
    6965: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    6966: {"Other_Alphabetic"},
    6967: {"Other_Alphabetic"},
    6968: {"Other_Alphabetic"},
    6969: {"Other_Alphabetic"},
    6970: {"Other_Alphabetic"},
    6971: {"Other_Alphabetic"},
    6972: {"Other_Alphabetic"},
    6973: {"Other_Alphabetic"},
    6974: {"Other_Alphabetic"},
    6975: {"Other_Alphabetic"},
    6976: {"Other_Alphabetic"},
    6977: {"Other_Alphabetic"},
    6978: {"Other_Alphabetic"},
    6979: {"Other_Alphabetic"},
    6980: {"Diacritic"},
    7002: {"Terminal_Punctuation", "Sentence_Terminal"},
    7003: {"Terminal_Punctuation", "Sentence_Terminal"},
    7005: {"Terminal_Punctuation"},
    7006: {"Terminal_Punctuation", "Sentence_Terminal"},
    7007: {"Terminal_Punctuation", "Sentence_Terminal"},
    7019: {"Diacritic"},
    7020: {"Diacritic"},
    7021: {"Diacritic"},
    7022: {"Diacritic"},
    7023: {"Diacritic"},
    7024: {"Diacritic"},
    7025: {"Diacritic"},
    7026: {"Diacritic"},
    7027: {"Diacritic"},
    7040: {"Other_Alphabetic"},
    7041: {"Other_Alphabetic"},
    7042: {"Other_Alphabetic"},
    7073: {"Other_Alphabetic"},
    7074: {"Other_Alphabetic"},
    7075: {"Other_Alphabetic"},
    7076: {"Other_Alphabetic"},
    7077: {"Other_Alphabetic"},
    7078: {"Other_Alphabetic"},
    7079: {"Other_Alphabetic"},
    7080: {"Other_Alphabetic"},
    7081: {"Other_Alphabetic"},
    7082: {"Diacritic"},
    7083: {"Diacritic"},
    7084: {"Other_Alphabetic"},
    7085: {"Other_Alphabetic"},
    7143: {"Other_Alphabetic"},
    7144: {"Other_Alphabetic"},
    7145: {"Other_Alphabetic"},
    7146: {"Other_Alphabetic"},
    7147: {"Other_Alphabetic"},
    7148: {"Other_Alphabetic"},
    7149: {"Other_Alphabetic"},
    7150: {"Other_Alphabetic"},
    7151: {"Other_Alphabetic"},
    7152: {"Other_Alphabetic"},
    7153: {"Other_Alphabetic"},
    7204: {"Other_Alphabetic"},
    7205: {"Other_Alphabetic"},
    7206: {"Other_Alphabetic"},
    7207: {"Other_Alphabetic"},
    7208: {"Other_Alphabetic"},
    7209: {"Other_Alphabetic"},
    7210: {"Other_Alphabetic"},
    7211: {"Other_Alphabetic"},
    7212: {"Other_Alphabetic"},
    7213: {"Other_Alphabetic"},
    7214: {"Other_Alphabetic"},
    7215: {"Other_Alphabetic"},
    7216: {"Other_Alphabetic"},
    7217: {"Other_Alphabetic"},
    7218: {"Other_Alphabetic"},
    7219: {"Other_Alphabetic"},
    7220: {"Other_Alphabetic"},
    7221: {"Other_Alphabetic"},
    7222: {"Diacritic", "Other_Alphabetic", "Extender"},
    7223: {"Diacritic"},
    7227: {"Terminal_Punctuation", "Sentence_Terminal"},
    7228: {"Terminal_Punctuation", "Sentence_Terminal"},
    7229: {"Terminal_Punctuation"},
    7230: {"Terminal_Punctuation"},
    7231: {"Terminal_Punctuation"},
    7288: {"Diacritic"},
    7289: {"Diacritic"},
    7290: {"Diacritic"},
    7291: {"Diacritic", "Extender"},
    7292: {"Diacritic"},
    7293: {"Diacritic"},
    7294: {"Terminal_Punctuation", "Sentence_Terminal"},
    7295: {"Terminal_Punctuation", "Sentence_Terminal"},
    7376: {"Diacritic"},
    7377: {"Diacritic"},
    7378: {"Diacritic"},
    7379: {"Diacritic"},
    7380: {"Diacritic"},
    7381: {"Diacritic"},
    7382: {"Diacritic"},
    7383: {"Diacritic"},
    7384: {"Diacritic"},
    7385: {"Diacritic"},
    7386: {"Diacritic"},
    7387: {"Diacritic"},
    7388: {"Diacritic"},
    7389: {"Diacritic"},
    7390: {"Diacritic"},
    7391: {"Diacritic"},
    7392: {"Diacritic"},
    7393: {"Diacritic"},
    7394: {"Diacritic"},
    7395: {"Diacritic"},
    7396: {"Diacritic"},
    7397: {"Diacritic"},
    7398: {"Diacritic"},
    7399: {"Diacritic"},
    7400: {"Diacritic"},
    7405: {"Diacritic"},
    7412: {"Diacritic"},
    7415: {"Diacritic"},
    7416: {"Diacritic"},
    7417: {"Diacritic"},
    7468: {"Other_Lowercase", "Diacritic"},
    7469: {"Other_Lowercase", "Diacritic"},
    7470: {"Other_Lowercase", "Diacritic"},
    7471: {"Other_Lowercase", "Diacritic"},
    7472: {"Other_Lowercase", "Diacritic"},
    7473: {"Other_Lowercase", "Diacritic"},
    7474: {"Other_Lowercase", "Diacritic"},
    7475: {"Other_Lowercase", "Diacritic"},
    7476: {"Other_Lowercase", "Diacritic"},
    7477: {"Other_Lowercase", "Diacritic"},
    7478: {"Other_Lowercase", "Diacritic"},
    7479: {"Other_Lowercase", "Diacritic"},
    7480: {"Other_Lowercase", "Diacritic"},
    7481: {"Other_Lowercase", "Diacritic"},
    7482: {"Other_Lowercase", "Diacritic"},
    7483: {"Other_Lowercase", "Diacritic"},
    7484: {"Other_Lowercase", "Diacritic"},
    7485: {"Other_Lowercase", "Diacritic"},
    7486: {"Other_Lowercase", "Diacritic"},
    7487: {"Other_Lowercase", "Diacritic"},
    7488: {"Other_Lowercase", "Diacritic"},
    7489: {"Other_Lowercase", "Diacritic"},
    7490: {"Other_Lowercase", "Diacritic"},
    7491: {"Other_Lowercase", "Diacritic"},
    7492: {"Other_Lowercase", "Diacritic"},
    7493: {"Other_Lowercase", "Diacritic"},
    7494: {"Other_Lowercase", "Diacritic"},
    7495: {"Other_Lowercase", "Diacritic"},
    7496: {"Other_Lowercase", "Diacritic"},
    7497: {"Other_Lowercase", "Diacritic"},
    7498: {"Other_Lowercase", "Diacritic"},
    7499: {"Other_Lowercase", "Diacritic"},
    7500: {"Other_Lowercase", "Diacritic"},
    7501: {"Other_Lowercase", "Diacritic"},
    7502: {"Other_Lowercase", "Diacritic"},
    7503: {"Other_Lowercase", "Diacritic"},
    7504: {"Other_Lowercase", "Diacritic"},
    7505: {"Other_Lowercase", "Diacritic"},
    7506: {"Other_Lowercase", "Diacritic"},
    7507: {"Other_Lowercase", "Diacritic"},
    7508: {"Other_Lowercase", "Diacritic"},
    7509: {"Other_Lowercase", "Diacritic"},
    7510: {"Other_Lowercase", "Diacritic"},
    7511: {"Other_Lowercase", "Diacritic"},
    7512: {"Other_Lowercase", "Diacritic"},
    7513: {"Other_Lowercase", "Diacritic"},
    7514: {"Other_Lowercase", "Diacritic"},
    7515: {"Other_Lowercase", "Diacritic"},
    7516: {"Other_Lowercase", "Diacritic"},
    7517: {"Other_Lowercase", "Diacritic"},
    7518: {"Other_Lowercase", "Diacritic"},
    7519: {"Other_Lowercase", "Diacritic"},
    7520: {"Other_Lowercase", "Diacritic"},
    7521: {"Other_Lowercase", "Diacritic"},
    7522: {"Other_Lowercase", "Diacritic", "Soft_Dotted"},
    7523: {"Other_Lowercase", "Diacritic"},
    7524: {"Other_Lowercase", "Diacritic"},
    7525: {"Other_Lowercase", "Diacritic"},
    7526: {"Other_Lowercase", "Diacritic"},
    7527: {"Other_Lowercase", "Diacritic"},
    7528: {"Other_Lowercase", "Diacritic"},
    7529: {"Other_Lowercase", "Diacritic"},
    7530: {"Other_Lowercase", "Diacritic"},
    7544: {"Other_Lowercase"},
    7574: {"Soft_Dotted"},
    7579: {"Other_Lowercase"},
    7580: {"Other_Lowercase"},
    7581: {"Other_Lowercase"},
    7582: {"Other_Lowercase"},
    7583: {"Other_Lowercase"},
    7584: {"Other_Lowercase"},
    7585: {"Other_Lowercase"},
    7586: {"Other_Lowercase"},
    7587: {"Other_Lowercase"},
    7588: {"Other_Lowercase", "Soft_Dotted"},
    7589: {"Other_Lowercase"},
    7590: {"Other_Lowercase"},
    7591: {"Other_Lowercase"},
    7592: {"Other_Lowercase", "Soft_Dotted"},
    7593: {"Other_Lowercase"},
    7594: {"Other_Lowercase"},
    7595: {"Other_Lowercase"},
    7596: {"Other_Lowercase"},
    7597: {"Other_Lowercase"},
    7598: {"Other_Lowercase"},
    7599: {"Other_Lowercase"},
    7600: {"Other_Lowercase"},
    7601: {"Other_Lowercase"},
    7602: {"Other_Lowercase"},
    7603: {"Other_Lowercase"},
    7604: {"Other_Lowercase"},
    7605: {"Other_Lowercase"},
    7606: {"Other_Lowercase"},
    7607: {"Other_Lowercase"},
    7608: {"Other_Lowercase"},
    7609: {"Other_Lowercase"},
    7610: {"Other_Lowercase"},
    7611: {"Other_Lowercase"},
    7612: {"Other_Lowercase"},
    7613: {"Other_Lowercase"},
    7614: {"Other_Lowercase"},
    7615: {"Other_Lowercase"},
    7620: {"Diacritic"},
    7621: {"Diacritic"},
    7622: {"Diacritic"},
    7623: {"Diacritic"},
    7624: {"Diacritic"},
    7625: {"Diacritic"},
    7626: {"Diacritic"},
    7627: {"Diacritic"},
    7628: {"Diacritic"},
    7629: {"Diacritic"},
    7630: {"Diacritic"},
    7631: {"Diacritic"},
    7655: {"Other_Alphabetic"},
    7656: {"Other_Alphabetic"},
    7657: {"Other_Alphabetic"},
    7658: {"Other_Alphabetic"},
    7659: {"Other_Alphabetic"},
    7660: {"Other_Alphabetic"},
    7661: {"Other_Alphabetic"},
    7662: {"Other_Alphabetic"},
    7663: {"Other_Alphabetic"},
    7664: {"Other_Alphabetic"},
    7665: {"Other_Alphabetic"},
    7666: {"Other_Alphabetic"},
    7667: {"Other_Alphabetic"},
    7668: {"Other_Alphabetic"},
    7669: {"Diacritic"},
    7670: {"Diacritic"},
    7671: {"Diacritic"},
    7672: {"Diacritic"},
    7673: {"Diacritic"},
    7677: {"Diacritic"},
    7678: {"Diacritic"},
    7679: {"Diacritic"},
    7725: {"Soft_Dotted"},
    7883: {"Soft_Dotted"},
    8125: {"Diacritic"},
    8127: {"Diacritic"},
    8128: {"Diacritic"},
    8129: {"Diacritic"},
    8141: {"Diacritic"},
    8142: {"Diacritic"},
    8143: {"Diacritic"},
    8157: {"Diacritic"},
    8158: {"Diacritic"},
    8159: {"Diacritic"},
    8173: {"Diacritic"},
    8174: {"Diacritic"},
    8175: {"Diacritic"},
    8189: {"Diacritic"},
    8190: {"Diacritic"},
    8192: {"White_Space"},
    8193: {"White_Space"},
    8194: {"White_Space"},
    8195: {"White_Space"},
    8196: {"White_Space"},
    8197: {"White_Space"},
    8198: {"White_Space"},
    8199: {"White_Space"},
    8200: {"White_Space"},
    8201: {"White_Space"},
    8202: {"White_Space"},
    8204: {"Other_Grapheme_Extend", "Join_Control"},
    8205: {"Join_Control"},
    8206: {"Pattern_White_Space", "Bidi_Control"},
    8207: {"Pattern_White_Space", "Bidi_Control"},
    8208: {"Pattern_Syntax", "Dash", "Hyphen"},
    8209: {"Pattern_Syntax", "Dash", "Hyphen"},
    8210: {"Pattern_Syntax", "Dash"},
    8211: {"Pattern_Syntax", "Dash"},
    8212: {"Pattern_Syntax", "Dash"},
    8213: {"Pattern_Syntax", "Dash"},
    8214: {"Pattern_Syntax", "Other_Math"},
    8215: {"Pattern_Syntax"},
    8216: {"Pattern_Syntax", "Quotation_Mark"},
    8217: {"Pattern_Syntax", "Quotation_Mark"},
    8218: {"Pattern_Syntax", "Quotation_Mark"},
    8219: {"Pattern_Syntax", "Quotation_Mark"},
    8220: {"Pattern_Syntax", "Quotation_Mark"},
    8221: {"Pattern_Syntax", "Quotation_Mark"},
    8222: {"Pattern_Syntax", "Quotation_Mark"},
    8223: {"Pattern_Syntax", "Quotation_Mark"},
    8224: {"Pattern_Syntax"},
    8225: {"Pattern_Syntax"},
    8226: {"Pattern_Syntax"},
    8227: {"Pattern_Syntax"},
    8228: {"Pattern_Syntax"},
    8229: {"Pattern_Syntax"},
    8230: {"Pattern_Syntax"},
    8231: {"Pattern_Syntax"},
    8232: {"White_Space", "Pattern_White_Space"},
    8233: {"White_Space", "Pattern_White_Space"},
    8234: {"Bidi_Control"},
    8235: {"Bidi_Control"},
    8236: {"Bidi_Control"},
    8237: {"Bidi_Control"},
    8238: {"Bidi_Control"},
    8239: {"White_Space"},
    8240: {"Pattern_Syntax"},
    8241: {"Pattern_Syntax"},
    8242: {"Pattern_Syntax", "Other_Math"},
    8243: {"Pattern_Syntax", "Other_Math"},
    8244: {"Pattern_Syntax", "Other_Math"},
    8245: {"Pattern_Syntax"},
    8246: {"Pattern_Syntax"},
    8247: {"Pattern_Syntax"},
    8248: {"Pattern_Syntax"},
    8249: {"Pattern_Syntax", "Quotation_Mark"},
    8250: {"Pattern_Syntax", "Quotation_Mark"},
    8251: {"Pattern_Syntax"},
    8252: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    8253: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    8254: {"Pattern_Syntax"},
    8256: {"Other_Math"},
    8257: {"Pattern_Syntax"},
    8258: {"Pattern_Syntax"},
    8259: {"Pattern_Syntax"},
    8260: {"Pattern_Syntax"},
    8261: {"Pattern_Syntax"},
    8262: {"Pattern_Syntax"},
    8263: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    8264: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    8265: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    8266: {"Pattern_Syntax"},
    8267: {"Pattern_Syntax"},
    8268: {"Pattern_Syntax"},
    8269: {"Pattern_Syntax"},
    8270: {"Pattern_Syntax"},
    8271: {"Pattern_Syntax"},
    8272: {"Pattern_Syntax"},
    8273: {"Pattern_Syntax"},
    8274: {"Pattern_Syntax"},
    8275: {"Pattern_Syntax", "Dash"},
    8277: {"Pattern_Syntax"},
    8278: {"Pattern_Syntax"},
    8279: {"Pattern_Syntax"},
    8280: {"Pattern_Syntax"},
    8281: {"Pattern_Syntax"},
    8282: {"Pattern_Syntax"},
    8283: {"Pattern_Syntax"},
    8284: {"Pattern_Syntax"},
    8285: {"Pattern_Syntax"},
    8286: {"Pattern_Syntax"},
    8287: {"White_Space"},
    8289: {"Other_Math"},
    8290: {"Other_Math"},
    8291: {"Other_Math"},
    8292: {"Other_Math"},
    8293: {"Other_Default_Ignorable_Code_Point"},
    8294: {"Bidi_Control"},
    8295: {"Bidi_Control"},
    8296: {"Bidi_Control"},
    8297: {"Bidi_Control"},
    8298: {"Deprecated"},
    8299: {"Deprecated"},
    8300: {"Deprecated"},
    8301: {"Deprecated"},
    8302: {"Deprecated"},
    8303: {"Deprecated"},
    8305: {"Other_Lowercase", "Soft_Dotted"},
    8315: {"Dash"},
    8317: {"Other_Math"},
    8318: {"Other_Math"},
    8319: {"Other_Lowercase"},
    8331: {"Dash"},
    8333: {"Other_Math"},
    8334: {"Other_Math"},
    8336: {"Other_Lowercase"},
    8337: {"Other_Lowercase"},
    8338: {"Other_Lowercase"},
    8339: {"Other_Lowercase"},
    8340: {"Other_Lowercase"},
    8341: {"Other_Lowercase"},
    8342: {"Other_Lowercase"},
    8343: {"Other_Lowercase"},
    8344: {"Other_Lowercase"},
    8345: {"Other_Lowercase"},
    8346: {"Other_Lowercase"},
    8347: {"Other_Lowercase"},
    8348: {"Other_Lowercase"},
    8400: {"Other_Math"},
    8401: {"Other_Math"},
    8402: {"Other_Math"},
    8403: {"Other_Math"},
    8404: {"Other_Math"},
    8405: {"Other_Math"},
    8406: {"Other_Math"},
    8407: {"Other_Math"},
    8408: {"Other_Math"},
    8409: {"Other_Math"},
    8410: {"Other_Math"},
    8411: {"Other_Math"},
    8412: {"Other_Math"},
    8417: {"Other_Math"},
    8421: {"Other_Math"},
    8422: {"Other_Math"},
    8427: {"Other_Math"},
    8428: {"Other_Math"},
    8429: {"Other_Math"},
    8430: {"Other_Math"},
    8431: {"Other_Math"},
    8450: {"Other_Math"},
    8455: {"Other_Math"},
    8458: {"Other_Math"},
    8459: {"Other_Math"},
    8460: {"Other_Math"},
    8461: {"Other_Math"},
    8462: {"Other_Math"},
    8463: {"Other_Math"},
    8464: {"Other_Math"},
    8465: {"Other_Math"},
    8466: {"Other_Math"},
    8467: {"Other_Math"},
    8469: {"Other_Math"},
    8472: {"Other_ID_Start"},
    8473: {"Other_Math"},
    8474: {"Other_Math"},
    8475: {"Other_Math"},
    8476: {"Other_Math"},
    8477: {"Other_Math"},
    8484: {"Other_Math"},
    8488: {"Other_Math"},
    8489: {"Other_Math"},
    8492: {"Other_Math"},
    8493: {"Other_Math"},
    8494: {"Other_ID_Start"},
    8495: {"Other_Math"},
    8496: {"Other_Math"},
    8497: {"Other_Math"},
    8499: {"Other_Math"},
    8500: {"Other_Math"},
    8501: {"Other_Math"},
    8502: {"Other_Math"},
    8503: {"Other_Math"},
    8504: {"Other_Math"},
    8508: {"Other_Math"},
    8509: {"Other_Math"},
    8510: {"Other_Math"},
    8511: {"Other_Math"},
    8517: {"Other_Math"},
    8518: {"Other_Math"},
    8519: {"Other_Math"},
    8520: {"Soft_Dotted", "Other_Math"},
    8521: {"Soft_Dotted", "Other_Math"},
    8544: {"Other_Uppercase"},
    8545: {"Other_Uppercase"},
    8546: {"Other_Uppercase"},
    8547: {"Other_Uppercase"},
    8548: {"Other_Uppercase"},
    8549: {"Other_Uppercase"},
    8550: {"Other_Uppercase"},
    8551: {"Other_Uppercase"},
    8552: {"Other_Uppercase"},
    8553: {"Other_Uppercase"},
    8554: {"Other_Uppercase"},
    8555: {"Other_Uppercase"},
    8556: {"Other_Uppercase"},
    8557: {"Other_Uppercase"},
    8558: {"Other_Uppercase"},
    8559: {"Other_Uppercase"},
    8560: {"Other_Lowercase"},
    8561: {"Other_Lowercase"},
    8562: {"Other_Lowercase"},
    8563: {"Other_Lowercase"},
    8564: {"Other_Lowercase"},
    8565: {"Other_Lowercase"},
    8566: {"Other_Lowercase"},
    8567: {"Other_Lowercase"},
    8568: {"Other_Lowercase"},
    8569: {"Other_Lowercase"},
    8570: {"Other_Lowercase"},
    8571: {"Other_Lowercase"},
    8572: {"Other_Lowercase"},
    8573: {"Other_Lowercase"},
    8574: {"Other_Lowercase"},
    8575: {"Other_Lowercase"},
    8592: {"Pattern_Syntax"},
    8593: {"Pattern_Syntax"},
    8594: {"Pattern_Syntax"},
    8595: {"Pattern_Syntax"},
    8596: {"Pattern_Syntax"},
    8597: {"Pattern_Syntax", "Other_Math"},
    8598: {"Pattern_Syntax", "Other_Math"},
    8599: {"Pattern_Syntax", "Other_Math"},
    8600: {"Pattern_Syntax", "Other_Math"},
    8601: {"Pattern_Syntax", "Other_Math"},
    8602: {"Pattern_Syntax"},
    8603: {"Pattern_Syntax"},
    8604: {"Pattern_Syntax", "Other_Math"},
    8605: {"Pattern_Syntax", "Other_Math"},
    8606: {"Pattern_Syntax", "Other_Math"},
    8607: {"Pattern_Syntax", "Other_Math"},
    8608: {"Pattern_Syntax"},
    8609: {"Pattern_Syntax", "Other_Math"},
    8610: {"Pattern_Syntax", "Other_Math"},
    8611: {"Pattern_Syntax"},
    8612: {"Pattern_Syntax", "Other_Math"},
    8613: {"Pattern_Syntax", "Other_Math"},
    8614: {"Pattern_Syntax"},
    8615: {"Pattern_Syntax", "Other_Math"},
    8616: {"Pattern_Syntax"},
    8617: {"Pattern_Syntax", "Other_Math"},
    8618: {"Pattern_Syntax", "Other_Math"},
    8619: {"Pattern_Syntax", "Other_Math"},
    8620: {"Pattern_Syntax", "Other_Math"},
    8621: {"Pattern_Syntax", "Other_Math"},
    8622: {"Pattern_Syntax"},
    8623: {"Pattern_Syntax"},
    8624: {"Pattern_Syntax", "Other_Math"},
    8625: {"Pattern_Syntax", "Other_Math"},
    8626: {"Pattern_Syntax"},
    8627: {"Pattern_Syntax"},
    8628: {"Pattern_Syntax"},
    8629: {"Pattern_Syntax"},
    8630: {"Pattern_Syntax", "Other_Math"},
    8631: {"Pattern_Syntax", "Other_Math"},
    8632: {"Pattern_Syntax"},
    8633: {"Pattern_Syntax"},
    8634: {"Pattern_Syntax"},
    8635: {"Pattern_Syntax"},
    8636: {"Pattern_Syntax", "Other_Math"},
    8637: {"Pattern_Syntax", "Other_Math"},
    8638: {"Pattern_Syntax", "Other_Math"},
    8639: {"Pattern_Syntax", "Other_Math"},
    8640: {"Pattern_Syntax", "Other_Math"},
    8641: {"Pattern_Syntax", "Other_Math"},
    8642: {"Pattern_Syntax", "Other_Math"},
    8643: {"Pattern_Syntax", "Other_Math"},
    8644: {"Pattern_Syntax", "Other_Math"},
    8645: {"Pattern_Syntax", "Other_Math"},
    8646: {"Pattern_Syntax", "Other_Math"},
    8647: {"Pattern_Syntax", "Other_Math"},
    8648: {"Pattern_Syntax", "Other_Math"},
    8649: {"Pattern_Syntax", "Other_Math"},
    8650: {"Pattern_Syntax", "Other_Math"},
    8651: {"Pattern_Syntax", "Other_Math"},
    8652: {"Pattern_Syntax", "Other_Math"},
    8653: {"Pattern_Syntax", "Other_Math"},
    8654: {"Pattern_Syntax"},
    8655: {"Pattern_Syntax"},
    8656: {"Pattern_Syntax", "Other_Math"},
    8657: {"Pattern_Syntax", "Other_Math"},
    8658: {"Pattern_Syntax"},
    8659: {"Pattern_Syntax", "Other_Math"},
    8660: {"Pattern_Syntax"},
    8661: {"Pattern_Syntax", "Other_Math"},
    8662: {"Pattern_Syntax", "Other_Math"},
    8663: {"Pattern_Syntax", "Other_Math"},
    8664: {"Pattern_Syntax", "Other_Math"},
    8665: {"Pattern_Syntax", "Other_Math"},
    8666: {"Pattern_Syntax", "Other_Math"},
    8667: {"Pattern_Syntax", "Other_Math"},
    8668: {"Pattern_Syntax"},
    8669: {"Pattern_Syntax", "Other_Math"},
    8670: {"Pattern_Syntax"},
    8671: {"Pattern_Syntax"},
    8672: {"Pattern_Syntax"},
    8673: {"Pattern_Syntax"},
    8674: {"Pattern_Syntax"},
    8675: {"Pattern_Syntax"},
    8676: {"Pattern_Syntax", "Other_Math"},
    8677: {"Pattern_Syntax", "Other_Math"},
    8678: {"Pattern_Syntax"},
    8679: {"Pattern_Syntax"},
    8680: {"Pattern_Syntax"},
    8681: {"Pattern_Syntax"},
    8682: {"Pattern_Syntax"},
    8683: {"Pattern_Syntax"},
    8684: {"Pattern_Syntax"},
    8685: {"Pattern_Syntax"},
    8686: {"Pattern_Syntax"},
    8687: {"Pattern_Syntax"},
    8688: {"Pattern_Syntax"},
    8689: {"Pattern_Syntax"},
    8690: {"Pattern_Syntax"},
    8691: {"Pattern_Syntax"},
    8692: {"Pattern_Syntax"},
    8693: {"Pattern_Syntax"},
    8694: {"Pattern_Syntax"},
    8695: {"Pattern_Syntax"},
    8696: {"Pattern_Syntax"},
    8697: {"Pattern_Syntax"},
    8698: {"Pattern_Syntax"},
    8699: {"Pattern_Syntax"},
    8700: {"Pattern_Syntax"},
    8701: {"Pattern_Syntax"},
    8702: {"Pattern_Syntax"},
    8703: {"Pattern_Syntax"},
    8704: {"Pattern_Syntax"},
    8705: {"Pattern_Syntax"},
    8706: {"Pattern_Syntax"},
    8707: {"Pattern_Syntax"},
    8708: {"Pattern_Syntax"},
    8709: {"Pattern_Syntax"},
    8710: {"Pattern_Syntax"},
    8711: {"Pattern_Syntax"},
    8712: {"Pattern_Syntax"},
    8713: {"Pattern_Syntax"},
    8714: {"Pattern_Syntax"},
    8715: {"Pattern_Syntax"},
    8716: {"Pattern_Syntax"},
    8717: {"Pattern_Syntax"},
    8718: {"Pattern_Syntax"},
    8719: {"Pattern_Syntax"},
    8720: {"Pattern_Syntax"},
    8721: {"Pattern_Syntax"},
    8722: {"Pattern_Syntax", "Dash"},
    8723: {"Pattern_Syntax"},
    8724: {"Pattern_Syntax"},
    8725: {"Pattern_Syntax"},
    8726: {"Pattern_Syntax"},
    8727: {"Pattern_Syntax"},
    8728: {"Pattern_Syntax"},
    8729: {"Pattern_Syntax"},
    8730: {"Pattern_Syntax"},
    8731: {"Pattern_Syntax"},
    8732: {"Pattern_Syntax"},
    8733: {"Pattern_Syntax"},
    8734: {"Pattern_Syntax"},
    8735: {"Pattern_Syntax"},
    8736: {"Pattern_Syntax"},
    8737: {"Pattern_Syntax"},
    8738: {"Pattern_Syntax"},
    8739: {"Pattern_Syntax"},
    8740: {"Pattern_Syntax"},
    8741: {"Pattern_Syntax"},
    8742: {"Pattern_Syntax"},
    8743: {"Pattern_Syntax"},
    8744: {"Pattern_Syntax"},
    8745: {"Pattern_Syntax"},
    8746: {"Pattern_Syntax"},
    8747: {"Pattern_Syntax"},
    8748: {"Pattern_Syntax"},
    8749: {"Pattern_Syntax"},
    8750: {"Pattern_Syntax"},
    8751: {"Pattern_Syntax"},
    8752: {"Pattern_Syntax"},
    8753: {"Pattern_Syntax"},
    8754: {"Pattern_Syntax"},
    8755: {"Pattern_Syntax"},
    8756: {"Pattern_Syntax"},
    8757: {"Pattern_Syntax"},
    8758: {"Pattern_Syntax"},
    8759: {"Pattern_Syntax"},
    8760: {"Pattern_Syntax"},
    8761: {"Pattern_Syntax"},
    8762: {"Pattern_Syntax"},
    8763: {"Pattern_Syntax"},
    8764: {"Pattern_Syntax"},
    8765: {"Pattern_Syntax"},
    8766: {"Pattern_Syntax"},
    8767: {"Pattern_Syntax"},
    8768: {"Pattern_Syntax"},
    8769: {"Pattern_Syntax"},
    8770: {"Pattern_Syntax"},
    8771: {"Pattern_Syntax"},
    8772: {"Pattern_Syntax"},
    8773: {"Pattern_Syntax"},
    8774: {"Pattern_Syntax"},
    8775: {"Pattern_Syntax"},
    8776: {"Pattern_Syntax"},
    8777: {"Pattern_Syntax"},
    8778: {"Pattern_Syntax"},
    8779: {"Pattern_Syntax"},
    8780: {"Pattern_Syntax"},
    8781: {"Pattern_Syntax"},
    8782: {"Pattern_Syntax"},
    8783: {"Pattern_Syntax"},
    8784: {"Pattern_Syntax"},
    8785: {"Pattern_Syntax"},
    8786: {"Pattern_Syntax"},
    8787: {"Pattern_Syntax"},
    8788: {"Pattern_Syntax"},
    8789: {"Pattern_Syntax"},
    8790: {"Pattern_Syntax"},
    8791: {"Pattern_Syntax"},
    8792: {"Pattern_Syntax"},
    8793: {"Pattern_Syntax"},
    8794: {"Pattern_Syntax"},
    8795: {"Pattern_Syntax"},
    8796: {"Pattern_Syntax"},
    8797: {"Pattern_Syntax"},
    8798: {"Pattern_Syntax"},
    8799: {"Pattern_Syntax"},
    8800: {"Pattern_Syntax"},
    8801: {"Pattern_Syntax"},
    8802: {"Pattern_Syntax"},
    8803: {"Pattern_Syntax"},
    8804: {"Pattern_Syntax"},
    8805: {"Pattern_Syntax"},
    8806: {"Pattern_Syntax"},
    8807: {"Pattern_Syntax"},
    8808: {"Pattern_Syntax"},
    8809: {"Pattern_Syntax"},
    8810: {"Pattern_Syntax"},
    8811: {"Pattern_Syntax"},
    8812: {"Pattern_Syntax"},
    8813: {"Pattern_Syntax"},
    8814: {"Pattern_Syntax"},
    8815: {"Pattern_Syntax"},
    8816: {"Pattern_Syntax"},
    8817: {"Pattern_Syntax"},
    8818: {"Pattern_Syntax"},
    8819: {"Pattern_Syntax"},
    8820: {"Pattern_Syntax"},
    8821: {"Pattern_Syntax"},
    8822: {"Pattern_Syntax"},
    8823: {"Pattern_Syntax"},
    8824: {"Pattern_Syntax"},
    8825: {"Pattern_Syntax"},
    8826: {"Pattern_Syntax"},
    8827: {"Pattern_Syntax"},
    8828: {"Pattern_Syntax"},
    8829: {"Pattern_Syntax"},
    8830: {"Pattern_Syntax"},
    8831: {"Pattern_Syntax"},
    8832: {"Pattern_Syntax"},
    8833: {"Pattern_Syntax"},
    8834: {"Pattern_Syntax"},
    8835: {"Pattern_Syntax"},
    8836: {"Pattern_Syntax"},
    8837: {"Pattern_Syntax"},
    8838: {"Pattern_Syntax"},
    8839: {"Pattern_Syntax"},
    8840: {"Pattern_Syntax"},
    8841: {"Pattern_Syntax"},
    8842: {"Pattern_Syntax"},
    8843: {"Pattern_Syntax"},
    8844: {"Pattern_Syntax"},
    8845: {"Pattern_Syntax"},
    8846: {"Pattern_Syntax"},
    8847: {"Pattern_Syntax"},
    8848: {"Pattern_Syntax"},
    8849: {"Pattern_Syntax"},
    8850: {"Pattern_Syntax"},
    8851: {"Pattern_Syntax"},
    8852: {"Pattern_Syntax"},
    8853: {"Pattern_Syntax"},
    8854: {"Pattern_Syntax"},
    8855: {"Pattern_Syntax"},
    8856: {"Pattern_Syntax"},
    8857: {"Pattern_Syntax"},
    8858: {"Pattern_Syntax"},
    8859: {"Pattern_Syntax"},
    8860: {"Pattern_Syntax"},
    8861: {"Pattern_Syntax"},
    8862: {"Pattern_Syntax"},
    8863: {"Pattern_Syntax"},
    8864: {"Pattern_Syntax"},
    8865: {"Pattern_Syntax"},
    8866: {"Pattern_Syntax"},
    8867: {"Pattern_Syntax"},
    8868: {"Pattern_Syntax"},
    8869: {"Pattern_Syntax"},
    8870: {"Pattern_Syntax"},
    8871: {"Pattern_Syntax"},
    8872: {"Pattern_Syntax"},
    8873: {"Pattern_Syntax"},
    8874: {"Pattern_Syntax"},
    8875: {"Pattern_Syntax"},
    8876: {"Pattern_Syntax"},
    8877: {"Pattern_Syntax"},
    8878: {"Pattern_Syntax"},
    8879: {"Pattern_Syntax"},
    8880: {"Pattern_Syntax"},
    8881: {"Pattern_Syntax"},
    8882: {"Pattern_Syntax"},
    8883: {"Pattern_Syntax"},
    8884: {"Pattern_Syntax"},
    8885: {"Pattern_Syntax"},
    8886: {"Pattern_Syntax"},
    8887: {"Pattern_Syntax"},
    8888: {"Pattern_Syntax"},
    8889: {"Pattern_Syntax"},
    8890: {"Pattern_Syntax"},
    8891: {"Pattern_Syntax"},
    8892: {"Pattern_Syntax"},
    8893: {"Pattern_Syntax"},
    8894: {"Pattern_Syntax"},
    8895: {"Pattern_Syntax"},
    8896: {"Pattern_Syntax"},
    8897: {"Pattern_Syntax"},
    8898: {"Pattern_Syntax"},
    8899: {"Pattern_Syntax"},
    8900: {"Pattern_Syntax"},
    8901: {"Pattern_Syntax"},
    8902: {"Pattern_Syntax"},
    8903: {"Pattern_Syntax"},
    8904: {"Pattern_Syntax"},
    8905: {"Pattern_Syntax"},
    8906: {"Pattern_Syntax"},
    8907: {"Pattern_Syntax"},
    8908: {"Pattern_Syntax"},
    8909: {"Pattern_Syntax"},
    8910: {"Pattern_Syntax"},
    8911: {"Pattern_Syntax"},
    8912: {"Pattern_Syntax"},
    8913: {"Pattern_Syntax"},
    8914: {"Pattern_Syntax"},
    8915: {"Pattern_Syntax"},
    8916: {"Pattern_Syntax"},
    8917: {"Pattern_Syntax"},
    8918: {"Pattern_Syntax"},
    8919: {"Pattern_Syntax"},
    8920: {"Pattern_Syntax"},
    8921: {"Pattern_Syntax"},
    8922: {"Pattern_Syntax"},
    8923: {"Pattern_Syntax"},
    8924: {"Pattern_Syntax"},
    8925: {"Pattern_Syntax"},
    8926: {"Pattern_Syntax"},
    8927: {"Pattern_Syntax"},
    8928: {"Pattern_Syntax"},
    8929: {"Pattern_Syntax"},
    8930: {"Pattern_Syntax"},
    8931: {"Pattern_Syntax"},
    8932: {"Pattern_Syntax"},
    8933: {"Pattern_Syntax"},
    8934: {"Pattern_Syntax"},
    8935: {"Pattern_Syntax"},
    8936: {"Pattern_Syntax"},
    8937: {"Pattern_Syntax"},
    8938: {"Pattern_Syntax"},
    8939: {"Pattern_Syntax"},
    8940: {"Pattern_Syntax"},
    8941: {"Pattern_Syntax"},
    8942: {"Pattern_Syntax"},
    8943: {"Pattern_Syntax"},
    8944: {"Pattern_Syntax"},
    8945: {"Pattern_Syntax"},
    8946: {"Pattern_Syntax"},
    8947: {"Pattern_Syntax"},
    8948: {"Pattern_Syntax"},
    8949: {"Pattern_Syntax"},
    8950: {"Pattern_Syntax"},
    8951: {"Pattern_Syntax"},
    8952: {"Pattern_Syntax"},
    8953: {"Pattern_Syntax"},
    8954: {"Pattern_Syntax"},
    8955: {"Pattern_Syntax"},
    8956: {"Pattern_Syntax"},
    8957: {"Pattern_Syntax"},
    8958: {"Pattern_Syntax"},
    8959: {"Pattern_Syntax"},
    8960: {"Pattern_Syntax"},
    8961: {"Pattern_Syntax"},
    8962: {"Pattern_Syntax"},
    8963: {"Pattern_Syntax"},
    8964: {"Pattern_Syntax"},
    8965: {"Pattern_Syntax"},
    8966: {"Pattern_Syntax"},
    8967: {"Pattern_Syntax"},
    8968: {"Pattern_Syntax", "Other_Math"},
    8969: {"Pattern_Syntax", "Other_Math"},
    8970: {"Pattern_Syntax", "Other_Math"},
    8971: {"Pattern_Syntax", "Other_Math"},
    8972: {"Pattern_Syntax"},
    8973: {"Pattern_Syntax"},
    8974: {"Pattern_Syntax"},
    8975: {"Pattern_Syntax"},
    8976: {"Pattern_Syntax"},
    8977: {"Pattern_Syntax"},
    8978: {"Pattern_Syntax"},
    8979: {"Pattern_Syntax"},
    8980: {"Pattern_Syntax"},
    8981: {"Pattern_Syntax"},
    8982: {"Pattern_Syntax"},
    8983: {"Pattern_Syntax"},
    8984: {"Pattern_Syntax"},
    8985: {"Pattern_Syntax"},
    8986: {"Pattern_Syntax"},
    8987: {"Pattern_Syntax"},
    8988: {"Pattern_Syntax"},
    8989: {"Pattern_Syntax"},
    8990: {"Pattern_Syntax"},
    8991: {"Pattern_Syntax"},
    8992: {"Pattern_Syntax"},
    8993: {"Pattern_Syntax"},
    8994: {"Pattern_Syntax"},
    8995: {"Pattern_Syntax"},
    8996: {"Pattern_Syntax"},
    8997: {"Pattern_Syntax"},
    8998: {"Pattern_Syntax"},
    8999: {"Pattern_Syntax"},
    9000: {"Pattern_Syntax"},
    9001: {"Pattern_Syntax", "Deprecated"},
    9002: {"Pattern_Syntax", "Deprecated"},
    9003: {"Pattern_Syntax"},
    9004: {"Pattern_Syntax"},
    9005: {"Pattern_Syntax"},
    9006: {"Pattern_Syntax"},
    9007: {"Pattern_Syntax"},
    9008: {"Pattern_Syntax"},
    9009: {"Pattern_Syntax"},
    9010: {"Pattern_Syntax"},
    9011: {"Pattern_Syntax"},
    9012: {"Pattern_Syntax"},
    9013: {"Pattern_Syntax"},
    9014: {"Pattern_Syntax"},
    9015: {"Pattern_Syntax"},
    9016: {"Pattern_Syntax"},
    9017: {"Pattern_Syntax"},
    9018: {"Pattern_Syntax"},
    9019: {"Pattern_Syntax"},
    9020: {"Pattern_Syntax"},
    9021: {"Pattern_Syntax"},
    9022: {"Pattern_Syntax"},
    9023: {"Pattern_Syntax"},
    9024: {"Pattern_Syntax"},
    9025: {"Pattern_Syntax"},
    9026: {"Pattern_Syntax"},
    9027: {"Pattern_Syntax"},
    9028: {"Pattern_Syntax"},
    9029: {"Pattern_Syntax"},
    9030: {"Pattern_Syntax"},
    9031: {"Pattern_Syntax"},
    9032: {"Pattern_Syntax"},
    9033: {"Pattern_Syntax"},
    9034: {"Pattern_Syntax"},
    9035: {"Pattern_Syntax"},
    9036: {"Pattern_Syntax"},
    9037: {"Pattern_Syntax"},
    9038: {"Pattern_Syntax"},
    9039: {"Pattern_Syntax"},
    9040: {"Pattern_Syntax"},
    9041: {"Pattern_Syntax"},
    9042: {"Pattern_Syntax"},
    9043: {"Pattern_Syntax"},
    9044: {"Pattern_Syntax"},
    9045: {"Pattern_Syntax"},
    9046: {"Pattern_Syntax"},
    9047: {"Pattern_Syntax"},
    9048: {"Pattern_Syntax"},
    9049: {"Pattern_Syntax"},
    9050: {"Pattern_Syntax"},
    9051: {"Pattern_Syntax"},
    9052: {"Pattern_Syntax"},
    9053: {"Pattern_Syntax"},
    9054: {"Pattern_Syntax"},
    9055: {"Pattern_Syntax"},
    9056: {"Pattern_Syntax"},
    9057: {"Pattern_Syntax"},
    9058: {"Pattern_Syntax"},
    9059: {"Pattern_Syntax"},
    9060: {"Pattern_Syntax"},
    9061: {"Pattern_Syntax"},
    9062: {"Pattern_Syntax"},
    9063: {"Pattern_Syntax"},
    9064: {"Pattern_Syntax"},
    9065: {"Pattern_Syntax"},
    9066: {"Pattern_Syntax"},
    9067: {"Pattern_Syntax"},
    9068: {"Pattern_Syntax"},
    9069: {"Pattern_Syntax"},
    9070: {"Pattern_Syntax"},
    9071: {"Pattern_Syntax"},
    9072: {"Pattern_Syntax"},
    9073: {"Pattern_Syntax"},
    9074: {"Pattern_Syntax"},
    9075: {"Pattern_Syntax"},
    9076: {"Pattern_Syntax"},
    9077: {"Pattern_Syntax"},
    9078: {"Pattern_Syntax"},
    9079: {"Pattern_Syntax"},
    9080: {"Pattern_Syntax"},
    9081: {"Pattern_Syntax"},
    9082: {"Pattern_Syntax"},
    9083: {"Pattern_Syntax"},
    9084: {"Pattern_Syntax"},
    9085: {"Pattern_Syntax"},
    9086: {"Pattern_Syntax"},
    9087: {"Pattern_Syntax"},
    9088: {"Pattern_Syntax"},
    9089: {"Pattern_Syntax"},
    9090: {"Pattern_Syntax"},
    9091: {"Pattern_Syntax"},
    9092: {"Pattern_Syntax"},
    9093: {"Pattern_Syntax"},
    9094: {"Pattern_Syntax"},
    9095: {"Pattern_Syntax"},
    9096: {"Pattern_Syntax"},
    9097: {"Pattern_Syntax"},
    9098: {"Pattern_Syntax"},
    9099: {"Pattern_Syntax"},
    9100: {"Pattern_Syntax"},
    9101: {"Pattern_Syntax"},
    9102: {"Pattern_Syntax"},
    9103: {"Pattern_Syntax"},
    9104: {"Pattern_Syntax"},
    9105: {"Pattern_Syntax"},
    9106: {"Pattern_Syntax"},
    9107: {"Pattern_Syntax"},
    9108: {"Pattern_Syntax"},
    9109: {"Pattern_Syntax"},
    9110: {"Pattern_Syntax"},
    9111: {"Pattern_Syntax"},
    9112: {"Pattern_Syntax"},
    9113: {"Pattern_Syntax"},
    9114: {"Pattern_Syntax"},
    9115: {"Pattern_Syntax"},
    9116: {"Pattern_Syntax"},
    9117: {"Pattern_Syntax"},
    9118: {"Pattern_Syntax"},
    9119: {"Pattern_Syntax"},
    9120: {"Pattern_Syntax"},
    9121: {"Pattern_Syntax"},
    9122: {"Pattern_Syntax"},
    9123: {"Pattern_Syntax"},
    9124: {"Pattern_Syntax"},
    9125: {"Pattern_Syntax"},
    9126: {"Pattern_Syntax"},
    9127: {"Pattern_Syntax"},
    9128: {"Pattern_Syntax"},
    9129: {"Pattern_Syntax"},
    9130: {"Pattern_Syntax"},
    9131: {"Pattern_Syntax"},
    9132: {"Pattern_Syntax"},
    9133: {"Pattern_Syntax"},
    9134: {"Pattern_Syntax"},
    9135: {"Pattern_Syntax"},
    9136: {"Pattern_Syntax"},
    9137: {"Pattern_Syntax"},
    9138: {"Pattern_Syntax"},
    9139: {"Pattern_Syntax"},
    9140: {"Pattern_Syntax", "Other_Math"},
    9141: {"Pattern_Syntax", "Other_Math"},
    9142: {"Pattern_Syntax"},
    9143: {"Pattern_Syntax", "Other_Math"},
    9144: {"Pattern_Syntax"},
    9145: {"Pattern_Syntax"},
    9146: {"Pattern_Syntax"},
    9147: {"Pattern_Syntax"},
    9148: {"Pattern_Syntax"},
    9149: {"Pattern_Syntax"},
    9150: {"Pattern_Syntax"},
    9151: {"Pattern_Syntax"},
    9152: {"Pattern_Syntax"},
    9153: {"Pattern_Syntax"},
    9154: {"Pattern_Syntax"},
    9155: {"Pattern_Syntax"},
    9156: {"Pattern_Syntax"},
    9157: {"Pattern_Syntax"},
    9158: {"Pattern_Syntax"},
    9159: {"Pattern_Syntax"},
    9160: {"Pattern_Syntax"},
    9161: {"Pattern_Syntax"},
    9162: {"Pattern_Syntax"},
    9163: {"Pattern_Syntax"},
    9164: {"Pattern_Syntax"},
    9165: {"Pattern_Syntax"},
    9166: {"Pattern_Syntax"},
    9167: {"Pattern_Syntax"},
    9168: {"Pattern_Syntax", "Other_Math"},
    9169: {"Pattern_Syntax"},
    9170: {"Pattern_Syntax"},
    9171: {"Pattern_Syntax"},
    9172: {"Pattern_Syntax"},
    9173: {"Pattern_Syntax"},
    9174: {"Pattern_Syntax"},
    9175: {"Pattern_Syntax"},
    9176: {"Pattern_Syntax"},
    9177: {"Pattern_Syntax"},
    9178: {"Pattern_Syntax"},
    9179: {"Pattern_Syntax"},
    9180: {"Pattern_Syntax"},
    9181: {"Pattern_Syntax"},
    9182: {"Pattern_Syntax"},
    9183: {"Pattern_Syntax"},
    9184: {"Pattern_Syntax"},
    9185: {"Pattern_Syntax"},
    9186: {"Pattern_Syntax", "Other_Math"},
    9187: {"Pattern_Syntax"},
    9188: {"Pattern_Syntax"},
    9189: {"Pattern_Syntax"},
    9190: {"Pattern_Syntax"},
    9191: {"Pattern_Syntax"},
    9192: {"Pattern_Syntax"},
    9193: {"Pattern_Syntax"},
    9194: {"Pattern_Syntax"},
    9195: {"Pattern_Syntax"},
    9196: {"Pattern_Syntax"},
    9197: {"Pattern_Syntax"},
    9198: {"Pattern_Syntax"},
    9199: {"Pattern_Syntax"},
    9200: {"Pattern_Syntax"},
    9201: {"Pattern_Syntax"},
    9202: {"Pattern_Syntax"},
    9203: {"Pattern_Syntax"},
    9204: {"Pattern_Syntax"},
    9205: {"Pattern_Syntax"},
    9206: {"Pattern_Syntax"},
    9207: {"Pattern_Syntax"},
    9208: {"Pattern_Syntax"},
    9209: {"Pattern_Syntax"},
    9210: {"Pattern_Syntax"},
    9211: {"Pattern_Syntax"},
    9212: {"Pattern_Syntax"},
    9213: {"Pattern_Syntax"},
    9214: {"Pattern_Syntax"},
    9215: {"Pattern_Syntax"},
    9216: {"Pattern_Syntax"},
    9217: {"Pattern_Syntax"},
    9218: {"Pattern_Syntax"},
    9219: {"Pattern_Syntax"},
    9220: {"Pattern_Syntax"},
    9221: {"Pattern_Syntax"},
    9222: {"Pattern_Syntax"},
    9223: {"Pattern_Syntax"},
    9224: {"Pattern_Syntax"},
    9225: {"Pattern_Syntax"},
    9226: {"Pattern_Syntax"},
    9227: {"Pattern_Syntax"},
    9228: {"Pattern_Syntax"},
    9229: {"Pattern_Syntax"},
    9230: {"Pattern_Syntax"},
    9231: {"Pattern_Syntax"},
    9232: {"Pattern_Syntax"},
    9233: {"Pattern_Syntax"},
    9234: {"Pattern_Syntax"},
    9235: {"Pattern_Syntax"},
    9236: {"Pattern_Syntax"},
    9237: {"Pattern_Syntax"},
    9238: {"Pattern_Syntax"},
    9239: {"Pattern_Syntax"},
    9240: {"Pattern_Syntax"},
    9241: {"Pattern_Syntax"},
    9242: {"Pattern_Syntax"},
    9243: {"Pattern_Syntax"},
    9244: {"Pattern_Syntax"},
    9245: {"Pattern_Syntax"},
    9246: {"Pattern_Syntax"},
    9247: {"Pattern_Syntax"},
    9248: {"Pattern_Syntax"},
    9249: {"Pattern_Syntax"},
    9250: {"Pattern_Syntax"},
    9251: {"Pattern_Syntax"},
    9252: {"Pattern_Syntax"},
    9253: {"Pattern_Syntax"},
    9254: {"Pattern_Syntax"},
    9255: {"Pattern_Syntax"},
    9256: {"Pattern_Syntax"},
    9257: {"Pattern_Syntax"},
    9258: {"Pattern_Syntax"},
    9259: {"Pattern_Syntax"},
    9260: {"Pattern_Syntax"},
    9261: {"Pattern_Syntax"},
    9262: {"Pattern_Syntax"},
    9263: {"Pattern_Syntax"},
    9264: {"Pattern_Syntax"},
    9265: {"Pattern_Syntax"},
    9266: {"Pattern_Syntax"},
    9267: {"Pattern_Syntax"},
    9268: {"Pattern_Syntax"},
    9269: {"Pattern_Syntax"},
    9270: {"Pattern_Syntax"},
    9271: {"Pattern_Syntax"},
    9272: {"Pattern_Syntax"},
    9273: {"Pattern_Syntax"},
    9274: {"Pattern_Syntax"},
    9275: {"Pattern_Syntax"},
    9276: {"Pattern_Syntax"},
    9277: {"Pattern_Syntax"},
    9278: {"Pattern_Syntax"},
    9279: {"Pattern_Syntax"},
    9280: {"Pattern_Syntax"},
    9281: {"Pattern_Syntax"},
    9282: {"Pattern_Syntax"},
    9283: {"Pattern_Syntax"},
    9284: {"Pattern_Syntax"},
    9285: {"Pattern_Syntax"},
    9286: {"Pattern_Syntax"},
    9287: {"Pattern_Syntax"},
    9288: {"Pattern_Syntax"},
    9289: {"Pattern_Syntax"},
    9290: {"Pattern_Syntax"},
    9291: {"Pattern_Syntax"},
    9292: {"Pattern_Syntax"},
    9293: {"Pattern_Syntax"},
    9294: {"Pattern_Syntax"},
    9295: {"Pattern_Syntax"},
    9296: {"Pattern_Syntax"},
    9297: {"Pattern_Syntax"},
    9298: {"Pattern_Syntax"},
    9299: {"Pattern_Syntax"},
    9300: {"Pattern_Syntax"},
    9301: {"Pattern_Syntax"},
    9302: {"Pattern_Syntax"},
    9303: {"Pattern_Syntax"},
    9304: {"Pattern_Syntax"},
    9305: {"Pattern_Syntax"},
    9306: {"Pattern_Syntax"},
    9307: {"Pattern_Syntax"},
    9308: {"Pattern_Syntax"},
    9309: {"Pattern_Syntax"},
    9310: {"Pattern_Syntax"},
    9311: {"Pattern_Syntax"},
    9398: {"Other_Alphabetic", "Other_Uppercase"},
    9399: {"Other_Alphabetic", "Other_Uppercase"},
    9400: {"Other_Alphabetic", "Other_Uppercase"},
    9401: {"Other_Alphabetic", "Other_Uppercase"},
    9402: {"Other_Alphabetic", "Other_Uppercase"},
    9403: {"Other_Alphabetic", "Other_Uppercase"},
    9404: {"Other_Alphabetic", "Other_Uppercase"},
    9405: {"Other_Alphabetic", "Other_Uppercase"},
    9406: {"Other_Alphabetic", "Other_Uppercase"},
    9407: {"Other_Alphabetic", "Other_Uppercase"},
    9408: {"Other_Alphabetic", "Other_Uppercase"},
    9409: {"Other_Alphabetic", "Other_Uppercase"},
    9410: {"Other_Alphabetic", "Other_Uppercase"},
    9411: {"Other_Alphabetic", "Other_Uppercase"},
    9412: {"Other_Alphabetic", "Other_Uppercase"},
    9413: {"Other_Alphabetic", "Other_Uppercase"},
    9414: {"Other_Alphabetic", "Other_Uppercase"},
    9415: {"Other_Alphabetic", "Other_Uppercase"},
    9416: {"Other_Alphabetic", "Other_Uppercase"},
    9417: {"Other_Alphabetic", "Other_Uppercase"},
    9418: {"Other_Alphabetic", "Other_Uppercase"},
    9419: {"Other_Alphabetic", "Other_Uppercase"},
    9420: {"Other_Alphabetic", "Other_Uppercase"},
    9421: {"Other_Alphabetic", "Other_Uppercase"},
    9422: {"Other_Alphabetic", "Other_Uppercase"},
    9423: {"Other_Alphabetic", "Other_Uppercase"},
    9424: {"Other_Lowercase", "Other_Alphabetic"},
    9425: {"Other_Lowercase", "Other_Alphabetic"},
    9426: {"Other_Lowercase", "Other_Alphabetic"},
    9427: {"Other_Lowercase", "Other_Alphabetic"},
    9428: {"Other_Lowercase", "Other_Alphabetic"},
    9429: {"Other_Lowercase", "Other_Alphabetic"},
    9430: {"Other_Lowercase", "Other_Alphabetic"},
    9431: {"Other_Lowercase", "Other_Alphabetic"},
    9432: {"Other_Lowercase", "Other_Alphabetic"},
    9433: {"Other_Lowercase", "Other_Alphabetic"},
    9434: {"Other_Lowercase", "Other_Alphabetic"},
    9435: {"Other_Lowercase", "Other_Alphabetic"},
    9436: {"Other_Lowercase", "Other_Alphabetic"},
    9437: {"Other_Lowercase", "Other_Alphabetic"},
    9438: {"Other_Lowercase", "Other_Alphabetic"},
    9439: {"Other_Lowercase", "Other_Alphabetic"},
    9440: {"Other_Lowercase", "Other_Alphabetic"},
    9441: {"Other_Lowercase", "Other_Alphabetic"},
    9442: {"Other_Lowercase", "Other_Alphabetic"},
    9443: {"Other_Lowercase", "Other_Alphabetic"},
    9444: {"Other_Lowercase", "Other_Alphabetic"},
    9445: {"Other_Lowercase", "Other_Alphabetic"},
    9446: {"Other_Lowercase", "Other_Alphabetic"},
    9447: {"Other_Lowercase", "Other_Alphabetic"},
    9448: {"Other_Lowercase", "Other_Alphabetic"},
    9449: {"Other_Lowercase", "Other_Alphabetic"},
    9472: {"Pattern_Syntax"},
    9473: {"Pattern_Syntax"},
    9474: {"Pattern_Syntax"},
    9475: {"Pattern_Syntax"},
    9476: {"Pattern_Syntax"},
    9477: {"Pattern_Syntax"},
    9478: {"Pattern_Syntax"},
    9479: {"Pattern_Syntax"},
    9480: {"Pattern_Syntax"},
    9481: {"Pattern_Syntax"},
    9482: {"Pattern_Syntax"},
    9483: {"Pattern_Syntax"},
    9484: {"Pattern_Syntax"},
    9485: {"Pattern_Syntax"},
    9486: {"Pattern_Syntax"},
    9487: {"Pattern_Syntax"},
    9488: {"Pattern_Syntax"},
    9489: {"Pattern_Syntax"},
    9490: {"Pattern_Syntax"},
    9491: {"Pattern_Syntax"},
    9492: {"Pattern_Syntax"},
    9493: {"Pattern_Syntax"},
    9494: {"Pattern_Syntax"},
    9495: {"Pattern_Syntax"},
    9496: {"Pattern_Syntax"},
    9497: {"Pattern_Syntax"},
    9498: {"Pattern_Syntax"},
    9499: {"Pattern_Syntax"},
    9500: {"Pattern_Syntax"},
    9501: {"Pattern_Syntax"},
    9502: {"Pattern_Syntax"},
    9503: {"Pattern_Syntax"},
    9504: {"Pattern_Syntax"},
    9505: {"Pattern_Syntax"},
    9506: {"Pattern_Syntax"},
    9507: {"Pattern_Syntax"},
    9508: {"Pattern_Syntax"},
    9509: {"Pattern_Syntax"},
    9510: {"Pattern_Syntax"},
    9511: {"Pattern_Syntax"},
    9512: {"Pattern_Syntax"},
    9513: {"Pattern_Syntax"},
    9514: {"Pattern_Syntax"},
    9515: {"Pattern_Syntax"},
    9516: {"Pattern_Syntax"},
    9517: {"Pattern_Syntax"},
    9518: {"Pattern_Syntax"},
    9519: {"Pattern_Syntax"},
    9520: {"Pattern_Syntax"},
    9521: {"Pattern_Syntax"},
    9522: {"Pattern_Syntax"},
    9523: {"Pattern_Syntax"},
    9524: {"Pattern_Syntax"},
    9525: {"Pattern_Syntax"},
    9526: {"Pattern_Syntax"},
    9527: {"Pattern_Syntax"},
    9528: {"Pattern_Syntax"},
    9529: {"Pattern_Syntax"},
    9530: {"Pattern_Syntax"},
    9531: {"Pattern_Syntax"},
    9532: {"Pattern_Syntax"},
    9533: {"Pattern_Syntax"},
    9534: {"Pattern_Syntax"},
    9535: {"Pattern_Syntax"},
    9536: {"Pattern_Syntax"},
    9537: {"Pattern_Syntax"},
    9538: {"Pattern_Syntax"},
    9539: {"Pattern_Syntax"},
    9540: {"Pattern_Syntax"},
    9541: {"Pattern_Syntax"},
    9542: {"Pattern_Syntax"},
    9543: {"Pattern_Syntax"},
    9544: {"Pattern_Syntax"},
    9545: {"Pattern_Syntax"},
    9546: {"Pattern_Syntax"},
    9547: {"Pattern_Syntax"},
    9548: {"Pattern_Syntax"},
    9549: {"Pattern_Syntax"},
    9550: {"Pattern_Syntax"},
    9551: {"Pattern_Syntax"},
    9552: {"Pattern_Syntax"},
    9553: {"Pattern_Syntax"},
    9554: {"Pattern_Syntax"},
    9555: {"Pattern_Syntax"},
    9556: {"Pattern_Syntax"},
    9557: {"Pattern_Syntax"},
    9558: {"Pattern_Syntax"},
    9559: {"Pattern_Syntax"},
    9560: {"Pattern_Syntax"},
    9561: {"Pattern_Syntax"},
    9562: {"Pattern_Syntax"},
    9563: {"Pattern_Syntax"},
    9564: {"Pattern_Syntax"},
    9565: {"Pattern_Syntax"},
    9566: {"Pattern_Syntax"},
    9567: {"Pattern_Syntax"},
    9568: {"Pattern_Syntax"},
    9569: {"Pattern_Syntax"},
    9570: {"Pattern_Syntax"},
    9571: {"Pattern_Syntax"},
    9572: {"Pattern_Syntax"},
    9573: {"Pattern_Syntax"},
    9574: {"Pattern_Syntax"},
    9575: {"Pattern_Syntax"},
    9576: {"Pattern_Syntax"},
    9577: {"Pattern_Syntax"},
    9578: {"Pattern_Syntax"},
    9579: {"Pattern_Syntax"},
    9580: {"Pattern_Syntax"},
    9581: {"Pattern_Syntax"},
    9582: {"Pattern_Syntax"},
    9583: {"Pattern_Syntax"},
    9584: {"Pattern_Syntax"},
    9585: {"Pattern_Syntax"},
    9586: {"Pattern_Syntax"},
    9587: {"Pattern_Syntax"},
    9588: {"Pattern_Syntax"},
    9589: {"Pattern_Syntax"},
    9590: {"Pattern_Syntax"},
    9591: {"Pattern_Syntax"},
    9592: {"Pattern_Syntax"},
    9593: {"Pattern_Syntax"},
    9594: {"Pattern_Syntax"},
    9595: {"Pattern_Syntax"},
    9596: {"Pattern_Syntax"},
    9597: {"Pattern_Syntax"},
    9598: {"Pattern_Syntax"},
    9599: {"Pattern_Syntax"},
    9600: {"Pattern_Syntax"},
    9601: {"Pattern_Syntax"},
    9602: {"Pattern_Syntax"},
    9603: {"Pattern_Syntax"},
    9604: {"Pattern_Syntax"},
    9605: {"Pattern_Syntax"},
    9606: {"Pattern_Syntax"},
    9607: {"Pattern_Syntax"},
    9608: {"Pattern_Syntax"},
    9609: {"Pattern_Syntax"},
    9610: {"Pattern_Syntax"},
    9611: {"Pattern_Syntax"},
    9612: {"Pattern_Syntax"},
    9613: {"Pattern_Syntax"},
    9614: {"Pattern_Syntax"},
    9615: {"Pattern_Syntax"},
    9616: {"Pattern_Syntax"},
    9617: {"Pattern_Syntax"},
    9618: {"Pattern_Syntax"},
    9619: {"Pattern_Syntax"},
    9620: {"Pattern_Syntax"},
    9621: {"Pattern_Syntax"},
    9622: {"Pattern_Syntax"},
    9623: {"Pattern_Syntax"},
    9624: {"Pattern_Syntax"},
    9625: {"Pattern_Syntax"},
    9626: {"Pattern_Syntax"},
    9627: {"Pattern_Syntax"},
    9628: {"Pattern_Syntax"},
    9629: {"Pattern_Syntax"},
    9630: {"Pattern_Syntax"},
    9631: {"Pattern_Syntax"},
    9632: {"Pattern_Syntax", "Other_Math"},
    9633: {"Pattern_Syntax", "Other_Math"},
    9634: {"Pattern_Syntax"},
    9635: {"Pattern_Syntax"},
    9636: {"Pattern_Syntax"},
    9637: {"Pattern_Syntax"},
    9638: {"Pattern_Syntax"},
    9639: {"Pattern_Syntax"},
    9640: {"Pattern_Syntax"},
    9641: {"Pattern_Syntax"},
    9642: {"Pattern_Syntax"},
    9643: {"Pattern_Syntax"},
    9644: {"Pattern_Syntax"},
    9645: {"Pattern_Syntax"},
    9646: {"Pattern_Syntax", "Other_Math"},
    9647: {"Pattern_Syntax", "Other_Math"},
    9648: {"Pattern_Syntax", "Other_Math"},
    9649: {"Pattern_Syntax", "Other_Math"},
    9650: {"Pattern_Syntax", "Other_Math"},
    9651: {"Pattern_Syntax", "Other_Math"},
    9652: {"Pattern_Syntax", "Other_Math"},
    9653: {"Pattern_Syntax", "Other_Math"},
    9654: {"Pattern_Syntax", "Other_Math"},
    9655: {"Pattern_Syntax"},
    9656: {"Pattern_Syntax"},
    9657: {"Pattern_Syntax"},
    9658: {"Pattern_Syntax"},
    9659: {"Pattern_Syntax"},
    9660: {"Pattern_Syntax", "Other_Math"},
    9661: {"Pattern_Syntax", "Other_Math"},
    9662: {"Pattern_Syntax", "Other_Math"},
    9663: {"Pattern_Syntax", "Other_Math"},
    9664: {"Pattern_Syntax", "Other_Math"},
    9665: {"Pattern_Syntax"},
    9666: {"Pattern_Syntax"},
    9667: {"Pattern_Syntax"},
    9668: {"Pattern_Syntax"},
    9669: {"Pattern_Syntax"},
    9670: {"Pattern_Syntax", "Other_Math"},
    9671: {"Pattern_Syntax", "Other_Math"},
    9672: {"Pattern_Syntax"},
    9673: {"Pattern_Syntax"},
    9674: {"Pattern_Syntax", "Other_Math"},
    9675: {"Pattern_Syntax", "Other_Math"},
    9676: {"Pattern_Syntax"},
    9677: {"Pattern_Syntax"},
    9678: {"Pattern_Syntax"},
    9679: {"Pattern_Syntax", "Other_Math"},
    9680: {"Pattern_Syntax", "Other_Math"},
    9681: {"Pattern_Syntax", "Other_Math"},
    9682: {"Pattern_Syntax", "Other_Math"},
    9683: {"Pattern_Syntax", "Other_Math"},
    9684: {"Pattern_Syntax"},
    9685: {"Pattern_Syntax"},
    9686: {"Pattern_Syntax"},
    9687: {"Pattern_Syntax"},
    9688: {"Pattern_Syntax"},
    9689: {"Pattern_Syntax"},
    9690: {"Pattern_Syntax"},
    9691: {"Pattern_Syntax"},
    9692: {"Pattern_Syntax"},
    9693: {"Pattern_Syntax"},
    9694: {"Pattern_Syntax"},
    9695: {"Pattern_Syntax"},
    9696: {"Pattern_Syntax"},
    9697: {"Pattern_Syntax"},
    9698: {"Pattern_Syntax", "Other_Math"},
    9699: {"Pattern_Syntax"},
    9700: {"Pattern_Syntax", "Other_Math"},
    9701: {"Pattern_Syntax"},
    9702: {"Pattern_Syntax"},
    9703: {"Pattern_Syntax", "Other_Math"},
    9704: {"Pattern_Syntax", "Other_Math"},
    9705: {"Pattern_Syntax", "Other_Math"},
    9706: {"Pattern_Syntax", "Other_Math"},
    9707: {"Pattern_Syntax", "Other_Math"},
    9708: {"Pattern_Syntax", "Other_Math"},
    9709: {"Pattern_Syntax"},
    9710: {"Pattern_Syntax"},
    9711: {"Pattern_Syntax"},
    9712: {"Pattern_Syntax"},
    9713: {"Pattern_Syntax"},
    9714: {"Pattern_Syntax"},
    9715: {"Pattern_Syntax"},
    9716: {"Pattern_Syntax"},
    9717: {"Pattern_Syntax"},
    9718: {"Pattern_Syntax"},
    9719: {"Pattern_Syntax"},
    9720: {"Pattern_Syntax"},
    9721: {"Pattern_Syntax"},
    9722: {"Pattern_Syntax"},
    9723: {"Pattern_Syntax"},
    9724: {"Pattern_Syntax"},
    9725: {"Pattern_Syntax"},
    9726: {"Pattern_Syntax"},
    9727: {"Pattern_Syntax"},
    9728: {"Pattern_Syntax"},
    9729: {"Pattern_Syntax"},
    9730: {"Pattern_Syntax"},
    9731: {"Pattern_Syntax"},
    9732: {"Pattern_Syntax"},
    9733: {"Pattern_Syntax", "Other_Math"},
    9734: {"Pattern_Syntax", "Other_Math"},
    9735: {"Pattern_Syntax"},
    9736: {"Pattern_Syntax"},
    9737: {"Pattern_Syntax"},
    9738: {"Pattern_Syntax"},
    9739: {"Pattern_Syntax"},
    9740: {"Pattern_Syntax"},
    9741: {"Pattern_Syntax"},
    9742: {"Pattern_Syntax"},
    9743: {"Pattern_Syntax"},
    9744: {"Pattern_Syntax"},
    9745: {"Pattern_Syntax"},
    9746: {"Pattern_Syntax"},
    9747: {"Pattern_Syntax"},
    9748: {"Pattern_Syntax"},
    9749: {"Pattern_Syntax"},
    9750: {"Pattern_Syntax"},
    9751: {"Pattern_Syntax"},
    9752: {"Pattern_Syntax"},
    9753: {"Pattern_Syntax"},
    9754: {"Pattern_Syntax"},
    9755: {"Pattern_Syntax"},
    9756: {"Pattern_Syntax"},
    9757: {"Pattern_Syntax"},
    9758: {"Pattern_Syntax"},
    9759: {"Pattern_Syntax"},
    9760: {"Pattern_Syntax"},
    9761: {"Pattern_Syntax"},
    9762: {"Pattern_Syntax"},
    9763: {"Pattern_Syntax"},
    9764: {"Pattern_Syntax"},
    9765: {"Pattern_Syntax"},
    9766: {"Pattern_Syntax"},
    9767: {"Pattern_Syntax"},
    9768: {"Pattern_Syntax"},
    9769: {"Pattern_Syntax"},
    9770: {"Pattern_Syntax"},
    9771: {"Pattern_Syntax"},
    9772: {"Pattern_Syntax"},
    9773: {"Pattern_Syntax"},
    9774: {"Pattern_Syntax"},
    9775: {"Pattern_Syntax"},
    9776: {"Pattern_Syntax"},
    9777: {"Pattern_Syntax"},
    9778: {"Pattern_Syntax"},
    9779: {"Pattern_Syntax"},
    9780: {"Pattern_Syntax"},
    9781: {"Pattern_Syntax"},
    9782: {"Pattern_Syntax"},
    9783: {"Pattern_Syntax"},
    9784: {"Pattern_Syntax"},
    9785: {"Pattern_Syntax"},
    9786: {"Pattern_Syntax"},
    9787: {"Pattern_Syntax"},
    9788: {"Pattern_Syntax"},
    9789: {"Pattern_Syntax"},
    9790: {"Pattern_Syntax"},
    9791: {"Pattern_Syntax"},
    9792: {"Pattern_Syntax", "Other_Math"},
    9793: {"Pattern_Syntax"},
    9794: {"Pattern_Syntax", "Other_Math"},
    9795: {"Pattern_Syntax"},
    9796: {"Pattern_Syntax"},
    9797: {"Pattern_Syntax"},
    9798: {"Pattern_Syntax"},
    9799: {"Pattern_Syntax"},
    9800: {"Pattern_Syntax"},
    9801: {"Pattern_Syntax"},
    9802: {"Pattern_Syntax"},
    9803: {"Pattern_Syntax"},
    9804: {"Pattern_Syntax"},
    9805: {"Pattern_Syntax"},
    9806: {"Pattern_Syntax"},
    9807: {"Pattern_Syntax"},
    9808: {"Pattern_Syntax"},
    9809: {"Pattern_Syntax"},
    9810: {"Pattern_Syntax"},
    9811: {"Pattern_Syntax"},
    9812: {"Pattern_Syntax"},
    9813: {"Pattern_Syntax"},
    9814: {"Pattern_Syntax"},
    9815: {"Pattern_Syntax"},
    9816: {"Pattern_Syntax"},
    9817: {"Pattern_Syntax"},
    9818: {"Pattern_Syntax"},
    9819: {"Pattern_Syntax"},
    9820: {"Pattern_Syntax"},
    9821: {"Pattern_Syntax"},
    9822: {"Pattern_Syntax"},
    9823: {"Pattern_Syntax"},
    9824: {"Pattern_Syntax", "Other_Math"},
    9825: {"Pattern_Syntax", "Other_Math"},
    9826: {"Pattern_Syntax", "Other_Math"},
    9827: {"Pattern_Syntax", "Other_Math"},
    9828: {"Pattern_Syntax"},
    9829: {"Pattern_Syntax"},
    9830: {"Pattern_Syntax"},
    9831: {"Pattern_Syntax"},
    9832: {"Pattern_Syntax"},
    9833: {"Pattern_Syntax"},
    9834: {"Pattern_Syntax"},
    9835: {"Pattern_Syntax"},
    9836: {"Pattern_Syntax"},
    9837: {"Pattern_Syntax", "Other_Math"},
    9838: {"Pattern_Syntax", "Other_Math"},
    9839: {"Pattern_Syntax"},
    9840: {"Pattern_Syntax"},
    9841: {"Pattern_Syntax"},
    9842: {"Pattern_Syntax"},
    9843: {"Pattern_Syntax"},
    9844: {"Pattern_Syntax"},
    9845: {"Pattern_Syntax"},
    9846: {"Pattern_Syntax"},
    9847: {"Pattern_Syntax"},
    9848: {"Pattern_Syntax"},
    9849: {"Pattern_Syntax"},
    9850: {"Pattern_Syntax"},
    9851: {"Pattern_Syntax"},
    9852: {"Pattern_Syntax"},
    9853: {"Pattern_Syntax"},
    9854: {"Pattern_Syntax"},
    9855: {"Pattern_Syntax"},
    9856: {"Pattern_Syntax"},
    9857: {"Pattern_Syntax"},
    9858: {"Pattern_Syntax"},
    9859: {"Pattern_Syntax"},
    9860: {"Pattern_Syntax"},
    9861: {"Pattern_Syntax"},
    9862: {"Pattern_Syntax"},
    9863: {"Pattern_Syntax"},
    9864: {"Pattern_Syntax"},
    9865: {"Pattern_Syntax"},
    9866: {"Pattern_Syntax"},
    9867: {"Pattern_Syntax"},
    9868: {"Pattern_Syntax"},
    9869: {"Pattern_Syntax"},
    9870: {"Pattern_Syntax"},
    9871: {"Pattern_Syntax"},
    9872: {"Pattern_Syntax"},
    9873: {"Pattern_Syntax"},
    9874: {"Pattern_Syntax"},
    9875: {"Pattern_Syntax"},
    9876: {"Pattern_Syntax"},
    9877: {"Pattern_Syntax"},
    9878: {"Pattern_Syntax"},
    9879: {"Pattern_Syntax"},
    9880: {"Pattern_Syntax"},
    9881: {"Pattern_Syntax"},
    9882: {"Pattern_Syntax"},
    9883: {"Pattern_Syntax"},
    9884: {"Pattern_Syntax"},
    9885: {"Pattern_Syntax"},
    9886: {"Pattern_Syntax"},
    9887: {"Pattern_Syntax"},
    9888: {"Pattern_Syntax"},
    9889: {"Pattern_Syntax"},
    9890: {"Pattern_Syntax"},
    9891: {"Pattern_Syntax"},
    9892: {"Pattern_Syntax"},
    9893: {"Pattern_Syntax"},
    9894: {"Pattern_Syntax"},
    9895: {"Pattern_Syntax"},
    9896: {"Pattern_Syntax"},
    9897: {"Pattern_Syntax"},
    9898: {"Pattern_Syntax"},
    9899: {"Pattern_Syntax"},
    9900: {"Pattern_Syntax"},
    9901: {"Pattern_Syntax"},
    9902: {"Pattern_Syntax"},
    9903: {"Pattern_Syntax"},
    9904: {"Pattern_Syntax"},
    9905: {"Pattern_Syntax"},
    9906: {"Pattern_Syntax"},
    9907: {"Pattern_Syntax"},
    9908: {"Pattern_Syntax"},
    9909: {"Pattern_Syntax"},
    9910: {"Pattern_Syntax"},
    9911: {"Pattern_Syntax"},
    9912: {"Pattern_Syntax"},
    9913: {"Pattern_Syntax"},
    9914: {"Pattern_Syntax"},
    9915: {"Pattern_Syntax"},
    9916: {"Pattern_Syntax"},
    9917: {"Pattern_Syntax"},
    9918: {"Pattern_Syntax"},
    9919: {"Pattern_Syntax"},
    9920: {"Pattern_Syntax"},
    9921: {"Pattern_Syntax"},
    9922: {"Pattern_Syntax"},
    9923: {"Pattern_Syntax"},
    9924: {"Pattern_Syntax"},
    9925: {"Pattern_Syntax"},
    9926: {"Pattern_Syntax"},
    9927: {"Pattern_Syntax"},
    9928: {"Pattern_Syntax"},
    9929: {"Pattern_Syntax"},
    9930: {"Pattern_Syntax"},
    9931: {"Pattern_Syntax"},
    9932: {"Pattern_Syntax"},
    9933: {"Pattern_Syntax"},
    9934: {"Pattern_Syntax"},
    9935: {"Pattern_Syntax"},
    9936: {"Pattern_Syntax"},
    9937: {"Pattern_Syntax"},
    9938: {"Pattern_Syntax"},
    9939: {"Pattern_Syntax"},
    9940: {"Pattern_Syntax"},
    9941: {"Pattern_Syntax"},
    9942: {"Pattern_Syntax"},
    9943: {"Pattern_Syntax"},
    9944: {"Pattern_Syntax"},
    9945: {"Pattern_Syntax"},
    9946: {"Pattern_Syntax"},
    9947: {"Pattern_Syntax"},
    9948: {"Pattern_Syntax"},
    9949: {"Pattern_Syntax"},
    9950: {"Pattern_Syntax"},
    9951: {"Pattern_Syntax"},
    9952: {"Pattern_Syntax"},
    9953: {"Pattern_Syntax"},
    9954: {"Pattern_Syntax"},
    9955: {"Pattern_Syntax"},
    9956: {"Pattern_Syntax"},
    9957: {"Pattern_Syntax"},
    9958: {"Pattern_Syntax"},
    9959: {"Pattern_Syntax"},
    9960: {"Pattern_Syntax"},
    9961: {"Pattern_Syntax"},
    9962: {"Pattern_Syntax"},
    9963: {"Pattern_Syntax"},
    9964: {"Pattern_Syntax"},
    9965: {"Pattern_Syntax"},
    9966: {"Pattern_Syntax"},
    9967: {"Pattern_Syntax"},
    9968: {"Pattern_Syntax"},
    9969: {"Pattern_Syntax"},
    9970: {"Pattern_Syntax"},
    9971: {"Pattern_Syntax"},
    9972: {"Pattern_Syntax"},
    9973: {"Pattern_Syntax"},
    9974: {"Pattern_Syntax"},
    9975: {"Pattern_Syntax"},
    9976: {"Pattern_Syntax"},
    9977: {"Pattern_Syntax"},
    9978: {"Pattern_Syntax"},
    9979: {"Pattern_Syntax"},
    9980: {"Pattern_Syntax"},
    9981: {"Pattern_Syntax"},
    9982: {"Pattern_Syntax"},
    9983: {"Pattern_Syntax"},
    9984: {"Pattern_Syntax"},
    9985: {"Pattern_Syntax"},
    9986: {"Pattern_Syntax"},
    9987: {"Pattern_Syntax"},
    9988: {"Pattern_Syntax"},
    9989: {"Pattern_Syntax"},
    9990: {"Pattern_Syntax"},
    9991: {"Pattern_Syntax"},
    9992: {"Pattern_Syntax"},
    9993: {"Pattern_Syntax"},
    9994: {"Pattern_Syntax"},
    9995: {"Pattern_Syntax"},
    9996: {"Pattern_Syntax"},
    9997: {"Pattern_Syntax"},
    9998: {"Pattern_Syntax"},
    9999: {"Pattern_Syntax"},
    10000: {"Pattern_Syntax"},
    10001: {"Pattern_Syntax"},
    10002: {"Pattern_Syntax"},
    10003: {"Pattern_Syntax"},
    10004: {"Pattern_Syntax"},
    10005: {"Pattern_Syntax"},
    10006: {"Pattern_Syntax"},
    10007: {"Pattern_Syntax"},
    10008: {"Pattern_Syntax"},
    10009: {"Pattern_Syntax"},
    10010: {"Pattern_Syntax"},
    10011: {"Pattern_Syntax"},
    10012: {"Pattern_Syntax"},
    10013: {"Pattern_Syntax"},
    10014: {"Pattern_Syntax"},
    10015: {"Pattern_Syntax"},
    10016: {"Pattern_Syntax"},
    10017: {"Pattern_Syntax"},
    10018: {"Pattern_Syntax"},
    10019: {"Pattern_Syntax"},
    10020: {"Pattern_Syntax"},
    10021: {"Pattern_Syntax"},
    10022: {"Pattern_Syntax"},
    10023: {"Pattern_Syntax"},
    10024: {"Pattern_Syntax"},
    10025: {"Pattern_Syntax"},
    10026: {"Pattern_Syntax"},
    10027: {"Pattern_Syntax"},
    10028: {"Pattern_Syntax"},
    10029: {"Pattern_Syntax"},
    10030: {"Pattern_Syntax"},
    10031: {"Pattern_Syntax"},
    10032: {"Pattern_Syntax"},
    10033: {"Pattern_Syntax"},
    10034: {"Pattern_Syntax"},
    10035: {"Pattern_Syntax"},
    10036: {"Pattern_Syntax"},
    10037: {"Pattern_Syntax"},
    10038: {"Pattern_Syntax"},
    10039: {"Pattern_Syntax"},
    10040: {"Pattern_Syntax"},
    10041: {"Pattern_Syntax"},
    10042: {"Pattern_Syntax"},
    10043: {"Pattern_Syntax"},
    10044: {"Pattern_Syntax"},
    10045: {"Pattern_Syntax"},
    10046: {"Pattern_Syntax"},
    10047: {"Pattern_Syntax"},
    10048: {"Pattern_Syntax"},
    10049: {"Pattern_Syntax"},
    10050: {"Pattern_Syntax"},
    10051: {"Pattern_Syntax"},
    10052: {"Pattern_Syntax"},
    10053: {"Pattern_Syntax"},
    10054: {"Pattern_Syntax"},
    10055: {"Pattern_Syntax"},
    10056: {"Pattern_Syntax"},
    10057: {"Pattern_Syntax"},
    10058: {"Pattern_Syntax"},
    10059: {"Pattern_Syntax"},
    10060: {"Pattern_Syntax"},
    10061: {"Pattern_Syntax"},
    10062: {"Pattern_Syntax"},
    10063: {"Pattern_Syntax"},
    10064: {"Pattern_Syntax"},
    10065: {"Pattern_Syntax"},
    10066: {"Pattern_Syntax"},
    10067: {"Pattern_Syntax"},
    10068: {"Pattern_Syntax"},
    10069: {"Pattern_Syntax"},
    10070: {"Pattern_Syntax"},
    10071: {"Pattern_Syntax"},
    10072: {"Pattern_Syntax"},
    10073: {"Pattern_Syntax"},
    10074: {"Pattern_Syntax"},
    10075: {"Pattern_Syntax"},
    10076: {"Pattern_Syntax"},
    10077: {"Pattern_Syntax"},
    10078: {"Pattern_Syntax"},
    10079: {"Pattern_Syntax"},
    10080: {"Pattern_Syntax"},
    10081: {"Pattern_Syntax"},
    10082: {"Pattern_Syntax"},
    10083: {"Pattern_Syntax"},
    10084: {"Pattern_Syntax"},
    10085: {"Pattern_Syntax"},
    10086: {"Pattern_Syntax"},
    10087: {"Pattern_Syntax"},
    10088: {"Pattern_Syntax"},
    10089: {"Pattern_Syntax"},
    10090: {"Pattern_Syntax"},
    10091: {"Pattern_Syntax"},
    10092: {"Pattern_Syntax"},
    10093: {"Pattern_Syntax"},
    10094: {"Pattern_Syntax"},
    10095: {"Pattern_Syntax"},
    10096: {"Pattern_Syntax"},
    10097: {"Pattern_Syntax"},
    10098: {"Pattern_Syntax"},
    10099: {"Pattern_Syntax"},
    10100: {"Pattern_Syntax"},
    10101: {"Pattern_Syntax"},
    10132: {"Pattern_Syntax"},
    10133: {"Pattern_Syntax"},
    10134: {"Pattern_Syntax"},
    10135: {"Pattern_Syntax"},
    10136: {"Pattern_Syntax"},
    10137: {"Pattern_Syntax"},
    10138: {"Pattern_Syntax"},
    10139: {"Pattern_Syntax"},
    10140: {"Pattern_Syntax"},
    10141: {"Pattern_Syntax"},
    10142: {"Pattern_Syntax"},
    10143: {"Pattern_Syntax"},
    10144: {"Pattern_Syntax"},
    10145: {"Pattern_Syntax"},
    10146: {"Pattern_Syntax"},
    10147: {"Pattern_Syntax"},
    10148: {"Pattern_Syntax"},
    10149: {"Pattern_Syntax"},
    10150: {"Pattern_Syntax"},
    10151: {"Pattern_Syntax"},
    10152: {"Pattern_Syntax"},
    10153: {"Pattern_Syntax"},
    10154: {"Pattern_Syntax"},
    10155: {"Pattern_Syntax"},
    10156: {"Pattern_Syntax"},
    10157: {"Pattern_Syntax"},
    10158: {"Pattern_Syntax"},
    10159: {"Pattern_Syntax"},
    10160: {"Pattern_Syntax"},
    10161: {"Pattern_Syntax"},
    10162: {"Pattern_Syntax"},
    10163: {"Pattern_Syntax"},
    10164: {"Pattern_Syntax"},
    10165: {"Pattern_Syntax"},
    10166: {"Pattern_Syntax"},
    10167: {"Pattern_Syntax"},
    10168: {"Pattern_Syntax"},
    10169: {"Pattern_Syntax"},
    10170: {"Pattern_Syntax"},
    10171: {"Pattern_Syntax"},
    10172: {"Pattern_Syntax"},
    10173: {"Pattern_Syntax"},
    10174: {"Pattern_Syntax"},
    10175: {"Pattern_Syntax"},
    10176: {"Pattern_Syntax"},
    10177: {"Pattern_Syntax"},
    10178: {"Pattern_Syntax"},
    10179: {"Pattern_Syntax"},
    10180: {"Pattern_Syntax"},
    10181: {"Pattern_Syntax", "Other_Math"},
    10182: {"Pattern_Syntax", "Other_Math"},
    10183: {"Pattern_Syntax"},
    10184: {"Pattern_Syntax"},
    10185: {"Pattern_Syntax"},
    10186: {"Pattern_Syntax"},
    10187: {"Pattern_Syntax"},
    10188: {"Pattern_Syntax"},
    10189: {"Pattern_Syntax"},
    10190: {"Pattern_Syntax"},
    10191: {"Pattern_Syntax"},
    10192: {"Pattern_Syntax"},
    10193: {"Pattern_Syntax"},
    10194: {"Pattern_Syntax"},
    10195: {"Pattern_Syntax"},
    10196: {"Pattern_Syntax"},
    10197: {"Pattern_Syntax"},
    10198: {"Pattern_Syntax"},
    10199: {"Pattern_Syntax"},
    10200: {"Pattern_Syntax"},
    10201: {"Pattern_Syntax"},
    10202: {"Pattern_Syntax"},
    10203: {"Pattern_Syntax"},
    10204: {"Pattern_Syntax"},
    10205: {"Pattern_Syntax"},
    10206: {"Pattern_Syntax"},
    10207: {"Pattern_Syntax"},
    10208: {"Pattern_Syntax"},
    10209: {"Pattern_Syntax"},
    10210: {"Pattern_Syntax"},
    10211: {"Pattern_Syntax"},
    10212: {"Pattern_Syntax"},
    10213: {"Pattern_Syntax"},
    10214: {"Pattern_Syntax", "Other_Math"},
    10215: {"Pattern_Syntax", "Other_Math"},
    10216: {"Pattern_Syntax", "Other_Math"},
    10217: {"Pattern_Syntax", "Other_Math"},
    10218: {"Pattern_Syntax", "Other_Math"},
    10219: {"Pattern_Syntax", "Other_Math"},
    10220: {"Pattern_Syntax", "Other_Math"},
    10221: {"Pattern_Syntax", "Other_Math"},
    10222: {"Pattern_Syntax", "Other_Math"},
    10223: {"Pattern_Syntax", "Other_Math"},
    10224: {"Pattern_Syntax"},
    10225: {"Pattern_Syntax"},
    10226: {"Pattern_Syntax"},
    10227: {"Pattern_Syntax"},
    10228: {"Pattern_Syntax"},
    10229: {"Pattern_Syntax"},
    10230: {"Pattern_Syntax"},
    10231: {"Pattern_Syntax"},
    10232: {"Pattern_Syntax"},
    10233: {"Pattern_Syntax"},
    10234: {"Pattern_Syntax"},
    10235: {"Pattern_Syntax"},
    10236: {"Pattern_Syntax"},
    10237: {"Pattern_Syntax"},
    10238: {"Pattern_Syntax"},
    10239: {"Pattern_Syntax"},
    10240: {"Pattern_Syntax"},
    10241: {"Pattern_Syntax"},
    10242: {"Pattern_Syntax"},
    10243: {"Pattern_Syntax"},
    10244: {"Pattern_Syntax"},
    10245: {"Pattern_Syntax"},
    10246: {"Pattern_Syntax"},
    10247: {"Pattern_Syntax"},
    10248: {"Pattern_Syntax"},
    10249: {"Pattern_Syntax"},
    10250: {"Pattern_Syntax"},
    10251: {"Pattern_Syntax"},
    10252: {"Pattern_Syntax"},
    10253: {"Pattern_Syntax"},
    10254: {"Pattern_Syntax"},
    10255: {"Pattern_Syntax"},
    10256: {"Pattern_Syntax"},
    10257: {"Pattern_Syntax"},
    10258: {"Pattern_Syntax"},
    10259: {"Pattern_Syntax"},
    10260: {"Pattern_Syntax"},
    10261: {"Pattern_Syntax"},
    10262: {"Pattern_Syntax"},
    10263: {"Pattern_Syntax"},
    10264: {"Pattern_Syntax"},
    10265: {"Pattern_Syntax"},
    10266: {"Pattern_Syntax"},
    10267: {"Pattern_Syntax"},
    10268: {"Pattern_Syntax"},
    10269: {"Pattern_Syntax"},
    10270: {"Pattern_Syntax"},
    10271: {"Pattern_Syntax"},
    10272: {"Pattern_Syntax"},
    10273: {"Pattern_Syntax"},
    10274: {"Pattern_Syntax"},
    10275: {"Pattern_Syntax"},
    10276: {"Pattern_Syntax"},
    10277: {"Pattern_Syntax"},
    10278: {"Pattern_Syntax"},
    10279: {"Pattern_Syntax"},
    10280: {"Pattern_Syntax"},
    10281: {"Pattern_Syntax"},
    10282: {"Pattern_Syntax"},
    10283: {"Pattern_Syntax"},
    10284: {"Pattern_Syntax"},
    10285: {"Pattern_Syntax"},
    10286: {"Pattern_Syntax"},
    10287: {"Pattern_Syntax"},
    10288: {"Pattern_Syntax"},
    10289: {"Pattern_Syntax"},
    10290: {"Pattern_Syntax"},
    10291: {"Pattern_Syntax"},
    10292: {"Pattern_Syntax"},
    10293: {"Pattern_Syntax"},
    10294: {"Pattern_Syntax"},
    10295: {"Pattern_Syntax"},
    10296: {"Pattern_Syntax"},
    10297: {"Pattern_Syntax"},
    10298: {"Pattern_Syntax"},
    10299: {"Pattern_Syntax"},
    10300: {"Pattern_Syntax"},
    10301: {"Pattern_Syntax"},
    10302: {"Pattern_Syntax"},
    10303: {"Pattern_Syntax"},
    10304: {"Pattern_Syntax"},
    10305: {"Pattern_Syntax"},
    10306: {"Pattern_Syntax"},
    10307: {"Pattern_Syntax"},
    10308: {"Pattern_Syntax"},
    10309: {"Pattern_Syntax"},
    10310: {"Pattern_Syntax"},
    10311: {"Pattern_Syntax"},
    10312: {"Pattern_Syntax"},
    10313: {"Pattern_Syntax"},
    10314: {"Pattern_Syntax"},
    10315: {"Pattern_Syntax"},
    10316: {"Pattern_Syntax"},
    10317: {"Pattern_Syntax"},
    10318: {"Pattern_Syntax"},
    10319: {"Pattern_Syntax"},
    10320: {"Pattern_Syntax"},
    10321: {"Pattern_Syntax"},
    10322: {"Pattern_Syntax"},
    10323: {"Pattern_Syntax"},
    10324: {"Pattern_Syntax"},
    10325: {"Pattern_Syntax"},
    10326: {"Pattern_Syntax"},
    10327: {"Pattern_Syntax"},
    10328: {"Pattern_Syntax"},
    10329: {"Pattern_Syntax"},
    10330: {"Pattern_Syntax"},
    10331: {"Pattern_Syntax"},
    10332: {"Pattern_Syntax"},
    10333: {"Pattern_Syntax"},
    10334: {"Pattern_Syntax"},
    10335: {"Pattern_Syntax"},
    10336: {"Pattern_Syntax"},
    10337: {"Pattern_Syntax"},
    10338: {"Pattern_Syntax"},
    10339: {"Pattern_Syntax"},
    10340: {"Pattern_Syntax"},
    10341: {"Pattern_Syntax"},
    10342: {"Pattern_Syntax"},
    10343: {"Pattern_Syntax"},
    10344: {"Pattern_Syntax"},
    10345: {"Pattern_Syntax"},
    10346: {"Pattern_Syntax"},
    10347: {"Pattern_Syntax"},
    10348: {"Pattern_Syntax"},
    10349: {"Pattern_Syntax"},
    10350: {"Pattern_Syntax"},
    10351: {"Pattern_Syntax"},
    10352: {"Pattern_Syntax"},
    10353: {"Pattern_Syntax"},
    10354: {"Pattern_Syntax"},
    10355: {"Pattern_Syntax"},
    10356: {"Pattern_Syntax"},
    10357: {"Pattern_Syntax"},
    10358: {"Pattern_Syntax"},
    10359: {"Pattern_Syntax"},
    10360: {"Pattern_Syntax"},
    10361: {"Pattern_Syntax"},
    10362: {"Pattern_Syntax"},
    10363: {"Pattern_Syntax"},
    10364: {"Pattern_Syntax"},
    10365: {"Pattern_Syntax"},
    10366: {"Pattern_Syntax"},
    10367: {"Pattern_Syntax"},
    10368: {"Pattern_Syntax"},
    10369: {"Pattern_Syntax"},
    10370: {"Pattern_Syntax"},
    10371: {"Pattern_Syntax"},
    10372: {"Pattern_Syntax"},
    10373: {"Pattern_Syntax"},
    10374: {"Pattern_Syntax"},
    10375: {"Pattern_Syntax"},
    10376: {"Pattern_Syntax"},
    10377: {"Pattern_Syntax"},
    10378: {"Pattern_Syntax"},
    10379: {"Pattern_Syntax"},
    10380: {"Pattern_Syntax"},
    10381: {"Pattern_Syntax"},
    10382: {"Pattern_Syntax"},
    10383: {"Pattern_Syntax"},
    10384: {"Pattern_Syntax"},
    10385: {"Pattern_Syntax"},
    10386: {"Pattern_Syntax"},
    10387: {"Pattern_Syntax"},
    10388: {"Pattern_Syntax"},
    10389: {"Pattern_Syntax"},
    10390: {"Pattern_Syntax"},
    10391: {"Pattern_Syntax"},
    10392: {"Pattern_Syntax"},
    10393: {"Pattern_Syntax"},
    10394: {"Pattern_Syntax"},
    10395: {"Pattern_Syntax"},
    10396: {"Pattern_Syntax"},
    10397: {"Pattern_Syntax"},
    10398: {"Pattern_Syntax"},
    10399: {"Pattern_Syntax"},
    10400: {"Pattern_Syntax"},
    10401: {"Pattern_Syntax"},
    10402: {"Pattern_Syntax"},
    10403: {"Pattern_Syntax"},
    10404: {"Pattern_Syntax"},
    10405: {"Pattern_Syntax"},
    10406: {"Pattern_Syntax"},
    10407: {"Pattern_Syntax"},
    10408: {"Pattern_Syntax"},
    10409: {"Pattern_Syntax"},
    10410: {"Pattern_Syntax"},
    10411: {"Pattern_Syntax"},
    10412: {"Pattern_Syntax"},
    10413: {"Pattern_Syntax"},
    10414: {"Pattern_Syntax"},
    10415: {"Pattern_Syntax"},
    10416: {"Pattern_Syntax"},
    10417: {"Pattern_Syntax"},
    10418: {"Pattern_Syntax"},
    10419: {"Pattern_Syntax"},
    10420: {"Pattern_Syntax"},
    10421: {"Pattern_Syntax"},
    10422: {"Pattern_Syntax"},
    10423: {"Pattern_Syntax"},
    10424: {"Pattern_Syntax"},
    10425: {"Pattern_Syntax"},
    10426: {"Pattern_Syntax"},
    10427: {"Pattern_Syntax"},
    10428: {"Pattern_Syntax"},
    10429: {"Pattern_Syntax"},
    10430: {"Pattern_Syntax"},
    10431: {"Pattern_Syntax"},
    10432: {"Pattern_Syntax"},
    10433: {"Pattern_Syntax"},
    10434: {"Pattern_Syntax"},
    10435: {"Pattern_Syntax"},
    10436: {"Pattern_Syntax"},
    10437: {"Pattern_Syntax"},
    10438: {"Pattern_Syntax"},
    10439: {"Pattern_Syntax"},
    10440: {"Pattern_Syntax"},
    10441: {"Pattern_Syntax"},
    10442: {"Pattern_Syntax"},
    10443: {"Pattern_Syntax"},
    10444: {"Pattern_Syntax"},
    10445: {"Pattern_Syntax"},
    10446: {"Pattern_Syntax"},
    10447: {"Pattern_Syntax"},
    10448: {"Pattern_Syntax"},
    10449: {"Pattern_Syntax"},
    10450: {"Pattern_Syntax"},
    10451: {"Pattern_Syntax"},
    10452: {"Pattern_Syntax"},
    10453: {"Pattern_Syntax"},
    10454: {"Pattern_Syntax"},
    10455: {"Pattern_Syntax"},
    10456: {"Pattern_Syntax"},
    10457: {"Pattern_Syntax"},
    10458: {"Pattern_Syntax"},
    10459: {"Pattern_Syntax"},
    10460: {"Pattern_Syntax"},
    10461: {"Pattern_Syntax"},
    10462: {"Pattern_Syntax"},
    10463: {"Pattern_Syntax"},
    10464: {"Pattern_Syntax"},
    10465: {"Pattern_Syntax"},
    10466: {"Pattern_Syntax"},
    10467: {"Pattern_Syntax"},
    10468: {"Pattern_Syntax"},
    10469: {"Pattern_Syntax"},
    10470: {"Pattern_Syntax"},
    10471: {"Pattern_Syntax"},
    10472: {"Pattern_Syntax"},
    10473: {"Pattern_Syntax"},
    10474: {"Pattern_Syntax"},
    10475: {"Pattern_Syntax"},
    10476: {"Pattern_Syntax"},
    10477: {"Pattern_Syntax"},
    10478: {"Pattern_Syntax"},
    10479: {"Pattern_Syntax"},
    10480: {"Pattern_Syntax"},
    10481: {"Pattern_Syntax"},
    10482: {"Pattern_Syntax"},
    10483: {"Pattern_Syntax"},
    10484: {"Pattern_Syntax"},
    10485: {"Pattern_Syntax"},
    10486: {"Pattern_Syntax"},
    10487: {"Pattern_Syntax"},
    10488: {"Pattern_Syntax"},
    10489: {"Pattern_Syntax"},
    10490: {"Pattern_Syntax"},
    10491: {"Pattern_Syntax"},
    10492: {"Pattern_Syntax"},
    10493: {"Pattern_Syntax"},
    10494: {"Pattern_Syntax"},
    10495: {"Pattern_Syntax"},
    10496: {"Pattern_Syntax"},
    10497: {"Pattern_Syntax"},
    10498: {"Pattern_Syntax"},
    10499: {"Pattern_Syntax"},
    10500: {"Pattern_Syntax"},
    10501: {"Pattern_Syntax"},
    10502: {"Pattern_Syntax"},
    10503: {"Pattern_Syntax"},
    10504: {"Pattern_Syntax"},
    10505: {"Pattern_Syntax"},
    10506: {"Pattern_Syntax"},
    10507: {"Pattern_Syntax"},
    10508: {"Pattern_Syntax"},
    10509: {"Pattern_Syntax"},
    10510: {"Pattern_Syntax"},
    10511: {"Pattern_Syntax"},
    10512: {"Pattern_Syntax"},
    10513: {"Pattern_Syntax"},
    10514: {"Pattern_Syntax"},
    10515: {"Pattern_Syntax"},
    10516: {"Pattern_Syntax"},
    10517: {"Pattern_Syntax"},
    10518: {"Pattern_Syntax"},
    10519: {"Pattern_Syntax"},
    10520: {"Pattern_Syntax"},
    10521: {"Pattern_Syntax"},
    10522: {"Pattern_Syntax"},
    10523: {"Pattern_Syntax"},
    10524: {"Pattern_Syntax"},
    10525: {"Pattern_Syntax"},
    10526: {"Pattern_Syntax"},
    10527: {"Pattern_Syntax"},
    10528: {"Pattern_Syntax"},
    10529: {"Pattern_Syntax"},
    10530: {"Pattern_Syntax"},
    10531: {"Pattern_Syntax"},
    10532: {"Pattern_Syntax"},
    10533: {"Pattern_Syntax"},
    10534: {"Pattern_Syntax"},
    10535: {"Pattern_Syntax"},
    10536: {"Pattern_Syntax"},
    10537: {"Pattern_Syntax"},
    10538: {"Pattern_Syntax"},
    10539: {"Pattern_Syntax"},
    10540: {"Pattern_Syntax"},
    10541: {"Pattern_Syntax"},
    10542: {"Pattern_Syntax"},
    10543: {"Pattern_Syntax"},
    10544: {"Pattern_Syntax"},
    10545: {"Pattern_Syntax"},
    10546: {"Pattern_Syntax"},
    10547: {"Pattern_Syntax"},
    10548: {"Pattern_Syntax"},
    10549: {"Pattern_Syntax"},
    10550: {"Pattern_Syntax"},
    10551: {"Pattern_Syntax"},
    10552: {"Pattern_Syntax"},
    10553: {"Pattern_Syntax"},
    10554: {"Pattern_Syntax"},
    10555: {"Pattern_Syntax"},
    10556: {"Pattern_Syntax"},
    10557: {"Pattern_Syntax"},
    10558: {"Pattern_Syntax"},
    10559: {"Pattern_Syntax"},
    10560: {"Pattern_Syntax"},
    10561: {"Pattern_Syntax"},
    10562: {"Pattern_Syntax"},
    10563: {"Pattern_Syntax"},
    10564: {"Pattern_Syntax"},
    10565: {"Pattern_Syntax"},
    10566: {"Pattern_Syntax"},
    10567: {"Pattern_Syntax"},
    10568: {"Pattern_Syntax"},
    10569: {"Pattern_Syntax"},
    10570: {"Pattern_Syntax"},
    10571: {"Pattern_Syntax"},
    10572: {"Pattern_Syntax"},
    10573: {"Pattern_Syntax"},
    10574: {"Pattern_Syntax"},
    10575: {"Pattern_Syntax"},
    10576: {"Pattern_Syntax"},
    10577: {"Pattern_Syntax"},
    10578: {"Pattern_Syntax"},
    10579: {"Pattern_Syntax"},
    10580: {"Pattern_Syntax"},
    10581: {"Pattern_Syntax"},
    10582: {"Pattern_Syntax"},
    10583: {"Pattern_Syntax"},
    10584: {"Pattern_Syntax"},
    10585: {"Pattern_Syntax"},
    10586: {"Pattern_Syntax"},
    10587: {"Pattern_Syntax"},
    10588: {"Pattern_Syntax"},
    10589: {"Pattern_Syntax"},
    10590: {"Pattern_Syntax"},
    10591: {"Pattern_Syntax"},
    10592: {"Pattern_Syntax"},
    10593: {"Pattern_Syntax"},
    10594: {"Pattern_Syntax"},
    10595: {"Pattern_Syntax"},
    10596: {"Pattern_Syntax"},
    10597: {"Pattern_Syntax"},
    10598: {"Pattern_Syntax"},
    10599: {"Pattern_Syntax"},
    10600: {"Pattern_Syntax"},
    10601: {"Pattern_Syntax"},
    10602: {"Pattern_Syntax"},
    10603: {"Pattern_Syntax"},
    10604: {"Pattern_Syntax"},
    10605: {"Pattern_Syntax"},
    10606: {"Pattern_Syntax"},
    10607: {"Pattern_Syntax"},
    10608: {"Pattern_Syntax"},
    10609: {"Pattern_Syntax"},
    10610: {"Pattern_Syntax"},
    10611: {"Pattern_Syntax"},
    10612: {"Pattern_Syntax"},
    10613: {"Pattern_Syntax"},
    10614: {"Pattern_Syntax"},
    10615: {"Pattern_Syntax"},
    10616: {"Pattern_Syntax"},
    10617: {"Pattern_Syntax"},
    10618: {"Pattern_Syntax"},
    10619: {"Pattern_Syntax"},
    10620: {"Pattern_Syntax"},
    10621: {"Pattern_Syntax"},
    10622: {"Pattern_Syntax"},
    10623: {"Pattern_Syntax"},
    10624: {"Pattern_Syntax"},
    10625: {"Pattern_Syntax"},
    10626: {"Pattern_Syntax"},
    10627: {"Pattern_Syntax", "Other_Math"},
    10628: {"Pattern_Syntax", "Other_Math"},
    10629: {"Pattern_Syntax", "Other_Math"},
    10630: {"Pattern_Syntax", "Other_Math"},
    10631: {"Pattern_Syntax", "Other_Math"},
    10632: {"Pattern_Syntax", "Other_Math"},
    10633: {"Pattern_Syntax", "Other_Math"},
    10634: {"Pattern_Syntax", "Other_Math"},
    10635: {"Pattern_Syntax", "Other_Math"},
    10636: {"Pattern_Syntax", "Other_Math"},
    10637: {"Pattern_Syntax", "Other_Math"},
    10638: {"Pattern_Syntax", "Other_Math"},
    10639: {"Pattern_Syntax", "Other_Math"},
    10640: {"Pattern_Syntax", "Other_Math"},
    10641: {"Pattern_Syntax", "Other_Math"},
    10642: {"Pattern_Syntax", "Other_Math"},
    10643: {"Pattern_Syntax", "Other_Math"},
    10644: {"Pattern_Syntax", "Other_Math"},
    10645: {"Pattern_Syntax", "Other_Math"},
    10646: {"Pattern_Syntax", "Other_Math"},
    10647: {"Pattern_Syntax", "Other_Math"},
    10648: {"Pattern_Syntax", "Other_Math"},
    10649: {"Pattern_Syntax"},
    10650: {"Pattern_Syntax"},
    10651: {"Pattern_Syntax"},
    10652: {"Pattern_Syntax"},
    10653: {"Pattern_Syntax"},
    10654: {"Pattern_Syntax"},
    10655: {"Pattern_Syntax"},
    10656: {"Pattern_Syntax"},
    10657: {"Pattern_Syntax"},
    10658: {"Pattern_Syntax"},
    10659: {"Pattern_Syntax"},
    10660: {"Pattern_Syntax"},
    10661: {"Pattern_Syntax"},
    10662: {"Pattern_Syntax"},
    10663: {"Pattern_Syntax"},
    10664: {"Pattern_Syntax"},
    10665: {"Pattern_Syntax"},
    10666: {"Pattern_Syntax"},
    10667: {"Pattern_Syntax"},
    10668: {"Pattern_Syntax"},
    10669: {"Pattern_Syntax"},
    10670: {"Pattern_Syntax"},
    10671: {"Pattern_Syntax"},
    10672: {"Pattern_Syntax"},
    10673: {"Pattern_Syntax"},
    10674: {"Pattern_Syntax"},
    10675: {"Pattern_Syntax"},
    10676: {"Pattern_Syntax"},
    10677: {"Pattern_Syntax"},
    10678: {"Pattern_Syntax"},
    10679: {"Pattern_Syntax"},
    10680: {"Pattern_Syntax"},
    10681: {"Pattern_Syntax"},
    10682: {"Pattern_Syntax"},
    10683: {"Pattern_Syntax"},
    10684: {"Pattern_Syntax"},
    10685: {"Pattern_Syntax"},
    10686: {"Pattern_Syntax"},
    10687: {"Pattern_Syntax"},
    10688: {"Pattern_Syntax"},
    10689: {"Pattern_Syntax"},
    10690: {"Pattern_Syntax"},
    10691: {"Pattern_Syntax"},
    10692: {"Pattern_Syntax"},
    10693: {"Pattern_Syntax"},
    10694: {"Pattern_Syntax"},
    10695: {"Pattern_Syntax"},
    10696: {"Pattern_Syntax"},
    10697: {"Pattern_Syntax"},
    10698: {"Pattern_Syntax"},
    10699: {"Pattern_Syntax"},
    10700: {"Pattern_Syntax"},
    10701: {"Pattern_Syntax"},
    10702: {"Pattern_Syntax"},
    10703: {"Pattern_Syntax"},
    10704: {"Pattern_Syntax"},
    10705: {"Pattern_Syntax"},
    10706: {"Pattern_Syntax"},
    10707: {"Pattern_Syntax"},
    10708: {"Pattern_Syntax"},
    10709: {"Pattern_Syntax"},
    10710: {"Pattern_Syntax"},
    10711: {"Pattern_Syntax"},
    10712: {"Pattern_Syntax", "Other_Math"},
    10713: {"Pattern_Syntax", "Other_Math"},
    10714: {"Pattern_Syntax", "Other_Math"},
    10715: {"Pattern_Syntax", "Other_Math"},
    10716: {"Pattern_Syntax"},
    10717: {"Pattern_Syntax"},
    10718: {"Pattern_Syntax"},
    10719: {"Pattern_Syntax"},
    10720: {"Pattern_Syntax"},
    10721: {"Pattern_Syntax"},
    10722: {"Pattern_Syntax"},
    10723: {"Pattern_Syntax"},
    10724: {"Pattern_Syntax"},
    10725: {"Pattern_Syntax"},
    10726: {"Pattern_Syntax"},
    10727: {"Pattern_Syntax"},
    10728: {"Pattern_Syntax"},
    10729: {"Pattern_Syntax"},
    10730: {"Pattern_Syntax"},
    10731: {"Pattern_Syntax"},
    10732: {"Pattern_Syntax"},
    10733: {"Pattern_Syntax"},
    10734: {"Pattern_Syntax"},
    10735: {"Pattern_Syntax"},
    10736: {"Pattern_Syntax"},
    10737: {"Pattern_Syntax"},
    10738: {"Pattern_Syntax"},
    10739: {"Pattern_Syntax"},
    10740: {"Pattern_Syntax"},
    10741: {"Pattern_Syntax"},
    10742: {"Pattern_Syntax"},
    10743: {"Pattern_Syntax"},
    10744: {"Pattern_Syntax"},
    10745: {"Pattern_Syntax"},
    10746: {"Pattern_Syntax"},
    10747: {"Pattern_Syntax"},
    10748: {"Pattern_Syntax", "Other_Math"},
    10749: {"Pattern_Syntax", "Other_Math"},
    10750: {"Pattern_Syntax"},
    10751: {"Pattern_Syntax"},
    10752: {"Pattern_Syntax"},
    10753: {"Pattern_Syntax"},
    10754: {"Pattern_Syntax"},
    10755: {"Pattern_Syntax"},
    10756: {"Pattern_Syntax"},
    10757: {"Pattern_Syntax"},
    10758: {"Pattern_Syntax"},
    10759: {"Pattern_Syntax"},
    10760: {"Pattern_Syntax"},
    10761: {"Pattern_Syntax"},
    10762: {"Pattern_Syntax"},
    10763: {"Pattern_Syntax"},
    10764: {"Pattern_Syntax"},
    10765: {"Pattern_Syntax"},
    10766: {"Pattern_Syntax"},
    10767: {"Pattern_Syntax"},
    10768: {"Pattern_Syntax"},
    10769: {"Pattern_Syntax"},
    10770: {"Pattern_Syntax"},
    10771: {"Pattern_Syntax"},
    10772: {"Pattern_Syntax"},
    10773: {"Pattern_Syntax"},
    10774: {"Pattern_Syntax"},
    10775: {"Pattern_Syntax"},
    10776: {"Pattern_Syntax"},
    10777: {"Pattern_Syntax"},
    10778: {"Pattern_Syntax"},
    10779: {"Pattern_Syntax"},
    10780: {"Pattern_Syntax"},
    10781: {"Pattern_Syntax"},
    10782: {"Pattern_Syntax"},
    10783: {"Pattern_Syntax"},
    10784: {"Pattern_Syntax"},
    10785: {"Pattern_Syntax"},
    10786: {"Pattern_Syntax"},
    10787: {"Pattern_Syntax"},
    10788: {"Pattern_Syntax"},
    10789: {"Pattern_Syntax"},
    10790: {"Pattern_Syntax"},
    10791: {"Pattern_Syntax"},
    10792: {"Pattern_Syntax"},
    10793: {"Pattern_Syntax"},
    10794: {"Pattern_Syntax"},
    10795: {"Pattern_Syntax"},
    10796: {"Pattern_Syntax"},
    10797: {"Pattern_Syntax"},
    10798: {"Pattern_Syntax"},
    10799: {"Pattern_Syntax"},
    10800: {"Pattern_Syntax"},
    10801: {"Pattern_Syntax"},
    10802: {"Pattern_Syntax"},
    10803: {"Pattern_Syntax"},
    10804: {"Pattern_Syntax"},
    10805: {"Pattern_Syntax"},
    10806: {"Pattern_Syntax"},
    10807: {"Pattern_Syntax"},
    10808: {"Pattern_Syntax"},
    10809: {"Pattern_Syntax"},
    10810: {"Pattern_Syntax"},
    10811: {"Pattern_Syntax"},
    10812: {"Pattern_Syntax"},
    10813: {"Pattern_Syntax"},
    10814: {"Pattern_Syntax"},
    10815: {"Pattern_Syntax"},
    10816: {"Pattern_Syntax"},
    10817: {"Pattern_Syntax"},
    10818: {"Pattern_Syntax"},
    10819: {"Pattern_Syntax"},
    10820: {"Pattern_Syntax"},
    10821: {"Pattern_Syntax"},
    10822: {"Pattern_Syntax"},
    10823: {"Pattern_Syntax"},
    10824: {"Pattern_Syntax"},
    10825: {"Pattern_Syntax"},
    10826: {"Pattern_Syntax"},
    10827: {"Pattern_Syntax"},
    10828: {"Pattern_Syntax"},
    10829: {"Pattern_Syntax"},
    10830: {"Pattern_Syntax"},
    10831: {"Pattern_Syntax"},
    10832: {"Pattern_Syntax"},
    10833: {"Pattern_Syntax"},
    10834: {"Pattern_Syntax"},
    10835: {"Pattern_Syntax"},
    10836: {"Pattern_Syntax"},
    10837: {"Pattern_Syntax"},
    10838: {"Pattern_Syntax"},
    10839: {"Pattern_Syntax"},
    10840: {"Pattern_Syntax"},
    10841: {"Pattern_Syntax"},
    10842: {"Pattern_Syntax"},
    10843: {"Pattern_Syntax"},
    10844: {"Pattern_Syntax"},
    10845: {"Pattern_Syntax"},
    10846: {"Pattern_Syntax"},
    10847: {"Pattern_Syntax"},
    10848: {"Pattern_Syntax"},
    10849: {"Pattern_Syntax"},
    10850: {"Pattern_Syntax"},
    10851: {"Pattern_Syntax"},
    10852: {"Pattern_Syntax"},
    10853: {"Pattern_Syntax"},
    10854: {"Pattern_Syntax"},
    10855: {"Pattern_Syntax"},
    10856: {"Pattern_Syntax"},
    10857: {"Pattern_Syntax"},
    10858: {"Pattern_Syntax"},
    10859: {"Pattern_Syntax"},
    10860: {"Pattern_Syntax"},
    10861: {"Pattern_Syntax"},
    10862: {"Pattern_Syntax"},
    10863: {"Pattern_Syntax"},
    10864: {"Pattern_Syntax"},
    10865: {"Pattern_Syntax"},
    10866: {"Pattern_Syntax"},
    10867: {"Pattern_Syntax"},
    10868: {"Pattern_Syntax"},
    10869: {"Pattern_Syntax"},
    10870: {"Pattern_Syntax"},
    10871: {"Pattern_Syntax"},
    10872: {"Pattern_Syntax"},
    10873: {"Pattern_Syntax"},
    10874: {"Pattern_Syntax"},
    10875: {"Pattern_Syntax"},
    10876: {"Pattern_Syntax"},
    10877: {"Pattern_Syntax"},
    10878: {"Pattern_Syntax"},
    10879: {"Pattern_Syntax"},
    10880: {"Pattern_Syntax"},
    10881: {"Pattern_Syntax"},
    10882: {"Pattern_Syntax"},
    10883: {"Pattern_Syntax"},
    10884: {"Pattern_Syntax"},
    10885: {"Pattern_Syntax"},
    10886: {"Pattern_Syntax"},
    10887: {"Pattern_Syntax"},
    10888: {"Pattern_Syntax"},
    10889: {"Pattern_Syntax"},
    10890: {"Pattern_Syntax"},
    10891: {"Pattern_Syntax"},
    10892: {"Pattern_Syntax"},
    10893: {"Pattern_Syntax"},
    10894: {"Pattern_Syntax"},
    10895: {"Pattern_Syntax"},
    10896: {"Pattern_Syntax"},
    10897: {"Pattern_Syntax"},
    10898: {"Pattern_Syntax"},
    10899: {"Pattern_Syntax"},
    10900: {"Pattern_Syntax"},
    10901: {"Pattern_Syntax"},
    10902: {"Pattern_Syntax"},
    10903: {"Pattern_Syntax"},
    10904: {"Pattern_Syntax"},
    10905: {"Pattern_Syntax"},
    10906: {"Pattern_Syntax"},
    10907: {"Pattern_Syntax"},
    10908: {"Pattern_Syntax"},
    10909: {"Pattern_Syntax"},
    10910: {"Pattern_Syntax"},
    10911: {"Pattern_Syntax"},
    10912: {"Pattern_Syntax"},
    10913: {"Pattern_Syntax"},
    10914: {"Pattern_Syntax"},
    10915: {"Pattern_Syntax"},
    10916: {"Pattern_Syntax"},
    10917: {"Pattern_Syntax"},
    10918: {"Pattern_Syntax"},
    10919: {"Pattern_Syntax"},
    10920: {"Pattern_Syntax"},
    10921: {"Pattern_Syntax"},
    10922: {"Pattern_Syntax"},
    10923: {"Pattern_Syntax"},
    10924: {"Pattern_Syntax"},
    10925: {"Pattern_Syntax"},
    10926: {"Pattern_Syntax"},
    10927: {"Pattern_Syntax"},
    10928: {"Pattern_Syntax"},
    10929: {"Pattern_Syntax"},
    10930: {"Pattern_Syntax"},
    10931: {"Pattern_Syntax"},
    10932: {"Pattern_Syntax"},
    10933: {"Pattern_Syntax"},
    10934: {"Pattern_Syntax"},
    10935: {"Pattern_Syntax"},
    10936: {"Pattern_Syntax"},
    10937: {"Pattern_Syntax"},
    10938: {"Pattern_Syntax"},
    10939: {"Pattern_Syntax"},
    10940: {"Pattern_Syntax"},
    10941: {"Pattern_Syntax"},
    10942: {"Pattern_Syntax"},
    10943: {"Pattern_Syntax"},
    10944: {"Pattern_Syntax"},
    10945: {"Pattern_Syntax"},
    10946: {"Pattern_Syntax"},
    10947: {"Pattern_Syntax"},
    10948: {"Pattern_Syntax"},
    10949: {"Pattern_Syntax"},
    10950: {"Pattern_Syntax"},
    10951: {"Pattern_Syntax"},
    10952: {"Pattern_Syntax"},
    10953: {"Pattern_Syntax"},
    10954: {"Pattern_Syntax"},
    10955: {"Pattern_Syntax"},
    10956: {"Pattern_Syntax"},
    10957: {"Pattern_Syntax"},
    10958: {"Pattern_Syntax"},
    10959: {"Pattern_Syntax"},
    10960: {"Pattern_Syntax"},
    10961: {"Pattern_Syntax"},
    10962: {"Pattern_Syntax"},
    10963: {"Pattern_Syntax"},
    10964: {"Pattern_Syntax"},
    10965: {"Pattern_Syntax"},
    10966: {"Pattern_Syntax"},
    10967: {"Pattern_Syntax"},
    10968: {"Pattern_Syntax"},
    10969: {"Pattern_Syntax"},
    10970: {"Pattern_Syntax"},
    10971: {"Pattern_Syntax"},
    10972: {"Pattern_Syntax"},
    10973: {"Pattern_Syntax"},
    10974: {"Pattern_Syntax"},
    10975: {"Pattern_Syntax"},
    10976: {"Pattern_Syntax"},
    10977: {"Pattern_Syntax"},
    10978: {"Pattern_Syntax"},
    10979: {"Pattern_Syntax"},
    10980: {"Pattern_Syntax"},
    10981: {"Pattern_Syntax"},
    10982: {"Pattern_Syntax"},
    10983: {"Pattern_Syntax"},
    10984: {"Pattern_Syntax"},
    10985: {"Pattern_Syntax"},
    10986: {"Pattern_Syntax"},
    10987: {"Pattern_Syntax"},
    10988: {"Pattern_Syntax"},
    10989: {"Pattern_Syntax"},
    10990: {"Pattern_Syntax"},
    10991: {"Pattern_Syntax"},
    10992: {"Pattern_Syntax"},
    10993: {"Pattern_Syntax"},
    10994: {"Pattern_Syntax"},
    10995: {"Pattern_Syntax"},
    10996: {"Pattern_Syntax"},
    10997: {"Pattern_Syntax"},
    10998: {"Pattern_Syntax"},
    10999: {"Pattern_Syntax"},
    11000: {"Pattern_Syntax"},
    11001: {"Pattern_Syntax"},
    11002: {"Pattern_Syntax"},
    11003: {"Pattern_Syntax"},
    11004: {"Pattern_Syntax"},
    11005: {"Pattern_Syntax"},
    11006: {"Pattern_Syntax"},
    11007: {"Pattern_Syntax"},
    11008: {"Pattern_Syntax"},
    11009: {"Pattern_Syntax"},
    11010: {"Pattern_Syntax"},
    11011: {"Pattern_Syntax"},
    11012: {"Pattern_Syntax"},
    11013: {"Pattern_Syntax"},
    11014: {"Pattern_Syntax"},
    11015: {"Pattern_Syntax"},
    11016: {"Pattern_Syntax"},
    11017: {"Pattern_Syntax"},
    11018: {"Pattern_Syntax"},
    11019: {"Pattern_Syntax"},
    11020: {"Pattern_Syntax"},
    11021: {"Pattern_Syntax"},
    11022: {"Pattern_Syntax"},
    11023: {"Pattern_Syntax"},
    11024: {"Pattern_Syntax"},
    11025: {"Pattern_Syntax"},
    11026: {"Pattern_Syntax"},
    11027: {"Pattern_Syntax"},
    11028: {"Pattern_Syntax"},
    11029: {"Pattern_Syntax"},
    11030: {"Pattern_Syntax"},
    11031: {"Pattern_Syntax"},
    11032: {"Pattern_Syntax"},
    11033: {"Pattern_Syntax"},
    11034: {"Pattern_Syntax"},
    11035: {"Pattern_Syntax"},
    11036: {"Pattern_Syntax"},
    11037: {"Pattern_Syntax"},
    11038: {"Pattern_Syntax"},
    11039: {"Pattern_Syntax"},
    11040: {"Pattern_Syntax"},
    11041: {"Pattern_Syntax"},
    11042: {"Pattern_Syntax"},
    11043: {"Pattern_Syntax"},
    11044: {"Pattern_Syntax"},
    11045: {"Pattern_Syntax"},
    11046: {"Pattern_Syntax"},
    11047: {"Pattern_Syntax"},
    11048: {"Pattern_Syntax"},
    11049: {"Pattern_Syntax"},
    11050: {"Pattern_Syntax"},
    11051: {"Pattern_Syntax"},
    11052: {"Pattern_Syntax"},
    11053: {"Pattern_Syntax"},
    11054: {"Pattern_Syntax"},
    11055: {"Pattern_Syntax"},
    11056: {"Pattern_Syntax"},
    11057: {"Pattern_Syntax"},
    11058: {"Pattern_Syntax"},
    11059: {"Pattern_Syntax"},
    11060: {"Pattern_Syntax"},
    11061: {"Pattern_Syntax"},
    11062: {"Pattern_Syntax"},
    11063: {"Pattern_Syntax"},
    11064: {"Pattern_Syntax"},
    11065: {"Pattern_Syntax"},
    11066: {"Pattern_Syntax"},
    11067: {"Pattern_Syntax"},
    11068: {"Pattern_Syntax"},
    11069: {"Pattern_Syntax"},
    11070: {"Pattern_Syntax"},
    11071: {"Pattern_Syntax"},
    11072: {"Pattern_Syntax"},
    11073: {"Pattern_Syntax"},
    11074: {"Pattern_Syntax"},
    11075: {"Pattern_Syntax"},
    11076: {"Pattern_Syntax"},
    11077: {"Pattern_Syntax"},
    11078: {"Pattern_Syntax"},
    11079: {"Pattern_Syntax"},
    11080: {"Pattern_Syntax"},
    11081: {"Pattern_Syntax"},
    11082: {"Pattern_Syntax"},
    11083: {"Pattern_Syntax"},
    11084: {"Pattern_Syntax"},
    11085: {"Pattern_Syntax"},
    11086: {"Pattern_Syntax"},
    11087: {"Pattern_Syntax"},
    11088: {"Pattern_Syntax"},
    11089: {"Pattern_Syntax"},
    11090: {"Pattern_Syntax"},
    11091: {"Pattern_Syntax"},
    11092: {"Pattern_Syntax"},
    11093: {"Pattern_Syntax"},
    11094: {"Pattern_Syntax"},
    11095: {"Pattern_Syntax"},
    11096: {"Pattern_Syntax"},
    11097: {"Pattern_Syntax"},
    11098: {"Pattern_Syntax"},
    11099: {"Pattern_Syntax"},
    11100: {"Pattern_Syntax"},
    11101: {"Pattern_Syntax"},
    11102: {"Pattern_Syntax"},
    11103: {"Pattern_Syntax"},
    11104: {"Pattern_Syntax"},
    11105: {"Pattern_Syntax"},
    11106: {"Pattern_Syntax"},
    11107: {"Pattern_Syntax"},
    11108: {"Pattern_Syntax"},
    11109: {"Pattern_Syntax"},
    11110: {"Pattern_Syntax"},
    11111: {"Pattern_Syntax"},
    11112: {"Pattern_Syntax"},
    11113: {"Pattern_Syntax"},
    11114: {"Pattern_Syntax"},
    11115: {"Pattern_Syntax"},
    11116: {"Pattern_Syntax"},
    11117: {"Pattern_Syntax"},
    11118: {"Pattern_Syntax"},
    11119: {"Pattern_Syntax"},
    11120: {"Pattern_Syntax"},
    11121: {"Pattern_Syntax"},
    11122: {"Pattern_Syntax"},
    11123: {"Pattern_Syntax"},
    11124: {"Pattern_Syntax"},
    11125: {"Pattern_Syntax"},
    11126: {"Pattern_Syntax"},
    11127: {"Pattern_Syntax"},
    11128: {"Pattern_Syntax"},
    11129: {"Pattern_Syntax"},
    11130: {"Pattern_Syntax"},
    11131: {"Pattern_Syntax"},
    11132: {"Pattern_Syntax"},
    11133: {"Pattern_Syntax"},
    11134: {"Pattern_Syntax"},
    11135: {"Pattern_Syntax"},
    11136: {"Pattern_Syntax"},
    11137: {"Pattern_Syntax"},
    11138: {"Pattern_Syntax"},
    11139: {"Pattern_Syntax"},
    11140: {"Pattern_Syntax"},
    11141: {"Pattern_Syntax"},
    11142: {"Pattern_Syntax"},
    11143: {"Pattern_Syntax"},
    11144: {"Pattern_Syntax"},
    11145: {"Pattern_Syntax"},
    11146: {"Pattern_Syntax"},
    11147: {"Pattern_Syntax"},
    11148: {"Pattern_Syntax"},
    11149: {"Pattern_Syntax"},
    11150: {"Pattern_Syntax"},
    11151: {"Pattern_Syntax"},
    11152: {"Pattern_Syntax"},
    11153: {"Pattern_Syntax"},
    11154: {"Pattern_Syntax"},
    11155: {"Pattern_Syntax"},
    11156: {"Pattern_Syntax"},
    11157: {"Pattern_Syntax"},
    11158: {"Pattern_Syntax"},
    11159: {"Pattern_Syntax"},
    11160: {"Pattern_Syntax"},
    11161: {"Pattern_Syntax"},
    11162: {"Pattern_Syntax"},
    11163: {"Pattern_Syntax"},
    11164: {"Pattern_Syntax"},
    11165: {"Pattern_Syntax"},
    11166: {"Pattern_Syntax"},
    11167: {"Pattern_Syntax"},
    11168: {"Pattern_Syntax"},
    11169: {"Pattern_Syntax"},
    11170: {"Pattern_Syntax"},
    11171: {"Pattern_Syntax"},
    11172: {"Pattern_Syntax"},
    11173: {"Pattern_Syntax"},
    11174: {"Pattern_Syntax"},
    11175: {"Pattern_Syntax"},
    11176: {"Pattern_Syntax"},
    11177: {"Pattern_Syntax"},
    11178: {"Pattern_Syntax"},
    11179: {"Pattern_Syntax"},
    11180: {"Pattern_Syntax"},
    11181: {"Pattern_Syntax"},
    11182: {"Pattern_Syntax"},
    11183: {"Pattern_Syntax"},
    11184: {"Pattern_Syntax"},
    11185: {"Pattern_Syntax"},
    11186: {"Pattern_Syntax"},
    11187: {"Pattern_Syntax"},
    11188: {"Pattern_Syntax"},
    11189: {"Pattern_Syntax"},
    11190: {"Pattern_Syntax"},
    11191: {"Pattern_Syntax"},
    11192: {"Pattern_Syntax"},
    11193: {"Pattern_Syntax"},
    11194: {"Pattern_Syntax"},
    11195: {"Pattern_Syntax"},
    11196: {"Pattern_Syntax"},
    11197: {"Pattern_Syntax"},
    11198: {"Pattern_Syntax"},
    11199: {"Pattern_Syntax"},
    11200: {"Pattern_Syntax"},
    11201: {"Pattern_Syntax"},
    11202: {"Pattern_Syntax"},
    11203: {"Pattern_Syntax"},
    11204: {"Pattern_Syntax"},
    11205: {"Pattern_Syntax"},
    11206: {"Pattern_Syntax"},
    11207: {"Pattern_Syntax"},
    11208: {"Pattern_Syntax"},
    11209: {"Pattern_Syntax"},
    11210: {"Pattern_Syntax"},
    11211: {"Pattern_Syntax"},
    11212: {"Pattern_Syntax"},
    11213: {"Pattern_Syntax"},
    11214: {"Pattern_Syntax"},
    11215: {"Pattern_Syntax"},
    11216: {"Pattern_Syntax"},
    11217: {"Pattern_Syntax"},
    11218: {"Pattern_Syntax"},
    11219: {"Pattern_Syntax"},
    11220: {"Pattern_Syntax"},
    11221: {"Pattern_Syntax"},
    11222: {"Pattern_Syntax"},
    11223: {"Pattern_Syntax"},
    11224: {"Pattern_Syntax"},
    11225: {"Pattern_Syntax"},
    11226: {"Pattern_Syntax"},
    11227: {"Pattern_Syntax"},
    11228: {"Pattern_Syntax"},
    11229: {"Pattern_Syntax"},
    11230: {"Pattern_Syntax"},
    11231: {"Pattern_Syntax"},
    11232: {"Pattern_Syntax"},
    11233: {"Pattern_Syntax"},
    11234: {"Pattern_Syntax"},
    11235: {"Pattern_Syntax"},
    11236: {"Pattern_Syntax"},
    11237: {"Pattern_Syntax"},
    11238: {"Pattern_Syntax"},
    11239: {"Pattern_Syntax"},
    11240: {"Pattern_Syntax"},
    11241: {"Pattern_Syntax"},
    11242: {"Pattern_Syntax"},
    11243: {"Pattern_Syntax"},
    11244: {"Pattern_Syntax"},
    11245: {"Pattern_Syntax"},
    11246: {"Pattern_Syntax"},
    11247: {"Pattern_Syntax"},
    11248: {"Pattern_Syntax"},
    11249: {"Pattern_Syntax"},
    11250: {"Pattern_Syntax"},
    11251: {"Pattern_Syntax"},
    11252: {"Pattern_Syntax"},
    11253: {"Pattern_Syntax"},
    11254: {"Pattern_Syntax"},
    11255: {"Pattern_Syntax"},
    11256: {"Pattern_Syntax"},
    11257: {"Pattern_Syntax"},
    11258: {"Pattern_Syntax"},
    11259: {"Pattern_Syntax"},
    11260: {"Pattern_Syntax"},
    11261: {"Pattern_Syntax"},
    11262: {"Pattern_Syntax"},
    11263: {"Pattern_Syntax"},
    11388: {"Other_Lowercase", "Soft_Dotted"},
    11389: {"Other_Lowercase"},
    11503: {"Diacritic"},
    11504: {"Diacritic"},
    11505: {"Diacritic"},
    11744: {"Other_Alphabetic"},
    11745: {"Other_Alphabetic"},
    11746: {"Other_Alphabetic"},
    11747: {"Other_Alphabetic"},
    11748: {"Other_Alphabetic"},
    11749: {"Other_Alphabetic"},
    11750: {"Other_Alphabetic"},
    11751: {"Other_Alphabetic"},
    11752: {"Other_Alphabetic"},
    11753: {"Other_Alphabetic"},
    11754: {"Other_Alphabetic"},
    11755: {"Other_Alphabetic"},
    11756: {"Other_Alphabetic"},
    11757: {"Other_Alphabetic"},
    11758: {"Other_Alphabetic"},
    11759: {"Other_Alphabetic"},
    11760: {"Other_Alphabetic"},
    11761: {"Other_Alphabetic"},
    11762: {"Other_Alphabetic"},
    11763: {"Other_Alphabetic"},
    11764: {"Other_Alphabetic"},
    11765: {"Other_Alphabetic"},
    11766: {"Other_Alphabetic"},
    11767: {"Other_Alphabetic"},
    11768: {"Other_Alphabetic"},
    11769: {"Other_Alphabetic"},
    11770: {"Other_Alphabetic"},
    11771: {"Other_Alphabetic"},
    11772: {"Other_Alphabetic"},
    11773: {"Other_Alphabetic"},
    11774: {"Other_Alphabetic"},
    11775: {"Other_Alphabetic"},
    11776: {"Pattern_Syntax"},
    11777: {"Pattern_Syntax"},
    11778: {"Pattern_Syntax"},
    11779: {"Pattern_Syntax"},
    11780: {"Pattern_Syntax"},
    11781: {"Pattern_Syntax"},
    11782: {"Pattern_Syntax"},
    11783: {"Pattern_Syntax"},
    11784: {"Pattern_Syntax"},
    11785: {"Pattern_Syntax"},
    11786: {"Pattern_Syntax"},
    11787: {"Pattern_Syntax"},
    11788: {"Pattern_Syntax"},
    11789: {"Pattern_Syntax"},
    11790: {"Pattern_Syntax"},
    11791: {"Pattern_Syntax"},
    11792: {"Pattern_Syntax"},
    11793: {"Pattern_Syntax"},
    11794: {"Pattern_Syntax"},
    11795: {"Pattern_Syntax"},
    11796: {"Pattern_Syntax"},
    11797: {"Pattern_Syntax"},
    11798: {"Pattern_Syntax"},
    11799: {"Pattern_Syntax", "Dash", "Hyphen"},
    11800: {"Pattern_Syntax"},
    11801: {"Pattern_Syntax"},
    11802: {"Pattern_Syntax", "Dash"},
    11803: {"Pattern_Syntax"},
    11804: {"Pattern_Syntax"},
    11805: {"Pattern_Syntax"},
    11806: {"Pattern_Syntax"},
    11807: {"Pattern_Syntax"},
    11808: {"Pattern_Syntax"},
    11809: {"Pattern_Syntax"},
    11810: {"Pattern_Syntax"},
    11811: {"Pattern_Syntax"},
    11812: {"Pattern_Syntax"},
    11813: {"Pattern_Syntax"},
    11814: {"Pattern_Syntax"},
    11815: {"Pattern_Syntax"},
    11816: {"Pattern_Syntax"},
    11817: {"Pattern_Syntax"},
    11818: {"Pattern_Syntax"},
    11819: {"Pattern_Syntax"},
    11820: {"Pattern_Syntax"},
    11821: {"Pattern_Syntax"},
    11822: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    11823: {"Diacritic", "Pattern_Syntax"},
    11824: {"Pattern_Syntax"},
    11825: {"Pattern_Syntax"},
    11826: {"Pattern_Syntax"},
    11827: {"Pattern_Syntax"},
    11828: {"Pattern_Syntax"},
    11829: {"Pattern_Syntax"},
    11830: {"Pattern_Syntax"},
    11831: {"Pattern_Syntax"},
    11832: {"Pattern_Syntax"},
    11833: {"Pattern_Syntax"},
    11834: {"Pattern_Syntax", "Dash"},
    11835: {"Pattern_Syntax", "Dash"},
    11836: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    11837: {"Pattern_Syntax"},
    11838: {"Pattern_Syntax"},
    11839: {"Pattern_Syntax"},
    11840: {"Pattern_Syntax", "Dash"},
    11841: {"Pattern_Syntax", "Terminal_Punctuation"},
    11842: {"Pattern_Syntax", "Quotation_Mark"},
    11843: {"Pattern_Syntax"},
    11844: {"Pattern_Syntax"},
    11845: {"Pattern_Syntax"},
    11846: {"Pattern_Syntax"},
    11847: {"Pattern_Syntax"},
    11848: {"Pattern_Syntax"},
    11849: {"Pattern_Syntax"},
    11850: {"Pattern_Syntax"},
    11851: {"Pattern_Syntax"},
    11852: {"Pattern_Syntax", "Terminal_Punctuation"},
    11853: {"Pattern_Syntax"},
    11854: {"Pattern_Syntax", "Terminal_Punctuation"},
    11855: {"Pattern_Syntax", "Terminal_Punctuation"},
    11856: {"Pattern_Syntax"},
    11857: {"Pattern_Syntax"},
    11858: {"Pattern_Syntax"},
    11859: {"Pattern_Syntax"},
    11860: {"Pattern_Syntax"},
    11861: {"Pattern_Syntax"},
    11862: {"Pattern_Syntax"},
    11863: {"Pattern_Syntax"},
    11864: {"Pattern_Syntax"},
    11865: {"Pattern_Syntax"},
    11866: {"Pattern_Syntax"},
    11867: {"Pattern_Syntax"},
    11868: {"Pattern_Syntax"},
    11869: {"Pattern_Syntax"},
    11870: {"Pattern_Syntax"},
    11871: {"Pattern_Syntax"},
    11872: {"Pattern_Syntax"},
    11873: {"Pattern_Syntax"},
    11874: {"Pattern_Syntax"},
    11875: {"Pattern_Syntax"},
    11876: {"Pattern_Syntax"},
    11877: {"Pattern_Syntax"},
    11878: {"Pattern_Syntax"},
    11879: {"Pattern_Syntax"},
    11880: {"Pattern_Syntax"},
    11881: {"Pattern_Syntax"},
    11882: {"Pattern_Syntax"},
    11883: {"Pattern_Syntax"},
    11884: {"Pattern_Syntax"},
    11885: {"Pattern_Syntax"},
    11886: {"Pattern_Syntax"},
    11887: {"Pattern_Syntax"},
    11888: {"Pattern_Syntax"},
    11889: {"Pattern_Syntax"},
    11890: {"Pattern_Syntax"},
    11891: {"Pattern_Syntax"},
    11892: {"Pattern_Syntax"},
    11893: {"Pattern_Syntax"},
    11894: {"Pattern_Syntax"},
    11895: {"Pattern_Syntax"},
    11896: {"Pattern_Syntax"},
    11897: {"Pattern_Syntax"},
    11898: {"Pattern_Syntax"},
    11899: {"Pattern_Syntax"},
    11900: {"Pattern_Syntax"},
    11901: {"Pattern_Syntax"},
    11902: {"Pattern_Syntax"},
    11903: {"Pattern_Syntax"},
    11904: {"Radical"},
    11905: {"Radical"},
    11906: {"Radical"},
    11907: {"Radical"},
    11908: {"Radical"},
    11909: {"Radical"},
    11910: {"Radical"},
    11911: {"Radical"},
    11912: {"Radical"},
    11913: {"Radical"},
    11914: {"Radical"},
    11915: {"Radical"},
    11916: {"Radical"},
    11917: {"Radical"},
    11918: {"Radical"},
    11919: {"Radical"},
    11920: {"Radical"},
    11921: {"Radical"},
    11922: {"Radical"},
    11923: {"Radical"},
    11924: {"Radical"},
    11925: {"Radical"},
    11926: {"Radical"},
    11927: {"Radical"},
    11928: {"Radical"},
    11929: {"Radical"},
    11931: {"Radical"},
    11932: {"Radical"},
    11933: {"Radical"},
    11934: {"Radical"},
    11935: {"Radical"},
    11936: {"Radical"},
    11937: {"Radical"},
    11938: {"Radical"},
    11939: {"Radical"},
    11940: {"Radical"},
    11941: {"Radical"},
    11942: {"Radical"},
    11943: {"Radical"},
    11944: {"Radical"},
    11945: {"Radical"},
    11946: {"Radical"},
    11947: {"Radical"},
    11948: {"Radical"},
    11949: {"Radical"},
    11950: {"Radical"},
    11951: {"Radical"},
    11952: {"Radical"},
    11953: {"Radical"},
    11954: {"Radical"},
    11955: {"Radical"},
    11956: {"Radical"},
    11957: {"Radical"},
    11958: {"Radical"},
    11959: {"Radical"},
    11960: {"Radical"},
    11961: {"Radical"},
    11962: {"Radical"},
    11963: {"Radical"},
    11964: {"Radical"},
    11965: {"Radical"},
    11966: {"Radical"},
    11967: {"Radical"},
    11968: {"Radical"},
    11969: {"Radical"},
    11970: {"Radical"},
    11971: {"Radical"},
    11972: {"Radical"},
    11973: {"Radical"},
    11974: {"Radical"},
    11975: {"Radical"},
    11976: {"Radical"},
    11977: {"Radical"},
    11978: {"Radical"},
    11979: {"Radical"},
    11980: {"Radical"},
    11981: {"Radical"},
    11982: {"Radical"},
    11983: {"Radical"},
    11984: {"Radical"},
    11985: {"Radical"},
    11986: {"Radical"},
    11987: {"Radical"},
    11988: {"Radical"},
    11989: {"Radical"},
    11990: {"Radical"},
    11991: {"Radical"},
    11992: {"Radical"},
    11993: {"Radical"},
    11994: {"Radical"},
    11995: {"Radical"},
    11996: {"Radical"},
    11997: {"Radical"},
    11998: {"Radical"},
    11999: {"Radical"},
    12000: {"Radical"},
    12001: {"Radical"},
    12002: {"Radical"},
    12003: {"Radical"},
    12004: {"Radical"},
    12005: {"Radical"},
    12006: {"Radical"},
    12007: {"Radical"},
    12008: {"Radical"},
    12009: {"Radical"},
    12010: {"Radical"},
    12011: {"Radical"},
    12012: {"Radical"},
    12013: {"Radical"},
    12014: {"Radical"},
    12015: {"Radical"},
    12016: {"Radical"},
    12017: {"Radical"},
    12018: {"Radical"},
    12019: {"Radical"},
    12032: {"Radical"},
    12033: {"Radical"},
    12034: {"Radical"},
    12035: {"Radical"},
    12036: {"Radical"},
    12037: {"Radical"},
    12038: {"Radical"},
    12039: {"Radical"},
    12040: {"Radical"},
    12041: {"Radical"},
    12042: {"Radical"},
    12043: {"Radical"},
    12044: {"Radical"},
    12045: {"Radical"},
    12046: {"Radical"},
    12047: {"Radical"},
    12048: {"Radical"},
    12049: {"Radical"},
    12050: {"Radical"},
    12051: {"Radical"},
    12052: {"Radical"},
    12053: {"Radical"},
    12054: {"Radical"},
    12055: {"Radical"},
    12056: {"Radical"},
    12057: {"Radical"},
    12058: {"Radical"},
    12059: {"Radical"},
    12060: {"Radical"},
    12061: {"Radical"},
    12062: {"Radical"},
    12063: {"Radical"},
    12064: {"Radical"},
    12065: {"Radical"},
    12066: {"Radical"},
    12067: {"Radical"},
    12068: {"Radical"},
    12069: {"Radical"},
    12070: {"Radical"},
    12071: {"Radical"},
    12072: {"Radical"},
    12073: {"Radical"},
    12074: {"Radical"},
    12075: {"Radical"},
    12076: {"Radical"},
    12077: {"Radical"},
    12078: {"Radical"},
    12079: {"Radical"},
    12080: {"Radical"},
    12081: {"Radical"},
    12082: {"Radical"},
    12083: {"Radical"},
    12084: {"Radical"},
    12085: {"Radical"},
    12086: {"Radical"},
    12087: {"Radical"},
    12088: {"Radical"},
    12089: {"Radical"},
    12090: {"Radical"},
    12091: {"Radical"},
    12092: {"Radical"},
    12093: {"Radical"},
    12094: {"Radical"},
    12095: {"Radical"},
    12096: {"Radical"},
    12097: {"Radical"},
    12098: {"Radical"},
    12099: {"Radical"},
    12100: {"Radical"},
    12101: {"Radical"},
    12102: {"Radical"},
    12103: {"Radical"},
    12104: {"Radical"},
    12105: {"Radical"},
    12106: {"Radical"},
    12107: {"Radical"},
    12108: {"Radical"},
    12109: {"Radical"},
    12110: {"Radical"},
    12111: {"Radical"},
    12112: {"Radical"},
    12113: {"Radical"},
    12114: {"Radical"},
    12115: {"Radical"},
    12116: {"Radical"},
    12117: {"Radical"},
    12118: {"Radical"},
    12119: {"Radical"},
    12120: {"Radical"},
    12121: {"Radical"},
    12122: {"Radical"},
    12123: {"Radical"},
    12124: {"Radical"},
    12125: {"Radical"},
    12126: {"Radical"},
    12127: {"Radical"},
    12128: {"Radical"},
    12129: {"Radical"},
    12130: {"Radical"},
    12131: {"Radical"},
    12132: {"Radical"},
    12133: {"Radical"},
    12134: {"Radical"},
    12135: {"Radical"},
    12136: {"Radical"},
    12137: {"Radical"},
    12138: {"Radical"},
    12139: {"Radical"},
    12140: {"Radical"},
    12141: {"Radical"},
    12142: {"Radical"},
    12143: {"Radical"},
    12144: {"Radical"},
    12145: {"Radical"},
    12146: {"Radical"},
    12147: {"Radical"},
    12148: {"Radical"},
    12149: {"Radical"},
    12150: {"Radical"},
    12151: {"Radical"},
    12152: {"Radical"},
    12153: {"Radical"},
    12154: {"Radical"},
    12155: {"Radical"},
    12156: {"Radical"},
    12157: {"Radical"},
    12158: {"Radical"},
    12159: {"Radical"},
    12160: {"Radical"},
    12161: {"Radical"},
    12162: {"Radical"},
    12163: {"Radical"},
    12164: {"Radical"},
    12165: {"Radical"},
    12166: {"Radical"},
    12167: {"Radical"},
    12168: {"Radical"},
    12169: {"Radical"},
    12170: {"Radical"},
    12171: {"Radical"},
    12172: {"Radical"},
    12173: {"Radical"},
    12174: {"Radical"},
    12175: {"Radical"},
    12176: {"Radical"},
    12177: {"Radical"},
    12178: {"Radical"},
    12179: {"Radical"},
    12180: {"Radical"},
    12181: {"Radical"},
    12182: {"Radical"},
    12183: {"Radical"},
    12184: {"Radical"},
    12185: {"Radical"},
    12186: {"Radical"},
    12187: {"Radical"},
    12188: {"Radical"},
    12189: {"Radical"},
    12190: {"Radical"},
    12191: {"Radical"},
    12192: {"Radical"},
    12193: {"Radical"},
    12194: {"Radical"},
    12195: {"Radical"},
    12196: {"Radical"},
    12197: {"Radical"},
    12198: {"Radical"},
    12199: {"Radical"},
    12200: {"Radical"},
    12201: {"Radical"},
    12202: {"Radical"},
    12203: {"Radical"},
    12204: {"Radical"},
    12205: {"Radical"},
    12206: {"Radical"},
    12207: {"Radical"},
    12208: {"Radical"},
    12209: {"Radical"},
    12210: {"Radical"},
    12211: {"Radical"},
    12212: {"Radical"},
    12213: {"Radical"},
    12214: {"Radical"},
    12215: {"Radical"},
    12216: {"Radical"},
    12217: {"Radical"},
    12218: {"Radical"},
    12219: {"Radical"},
    12220: {"Radical"},
    12221: {"Radical"},
    12222: {"Radical"},
    12223: {"Radical"},
    12224: {"Radical"},
    12225: {"Radical"},
    12226: {"Radical"},
    12227: {"Radical"},
    12228: {"Radical"},
    12229: {"Radical"},
    12230: {"Radical"},
    12231: {"Radical"},
    12232: {"Radical"},
    12233: {"Radical"},
    12234: {"Radical"},
    12235: {"Radical"},
    12236: {"Radical"},
    12237: {"Radical"},
    12238: {"Radical"},
    12239: {"Radical"},
    12240: {"Radical"},
    12241: {"Radical"},
    12242: {"Radical"},
    12243: {"Radical"},
    12244: {"Radical"},
    12245: {"Radical"},
    12272: {"IDS_Binary_Operator"},
    12273: {"IDS_Binary_Operator"},
    12274: {"IDS_Trinary_Operator"},
    12275: {"IDS_Trinary_Operator"},
    12276: {"IDS_Binary_Operator"},
    12277: {"IDS_Binary_Operator"},
    12278: {"IDS_Binary_Operator"},
    12279: {"IDS_Binary_Operator"},
    12280: {"IDS_Binary_Operator"},
    12281: {"IDS_Binary_Operator"},
    12282: {"IDS_Binary_Operator"},
    12283: {"IDS_Binary_Operator"},
    12288: {"White_Space"},
    12289: {"Pattern_Syntax", "Terminal_Punctuation"},
    12290: {"Pattern_Syntax", "Terminal_Punctuation", "Sentence_Terminal"},
    12291: {"Pattern_Syntax"},
    12293: {"Extender"},
    12294: {"Ideographic"},
    12295: {"Ideographic"},
    12296: {"Pattern_Syntax"},
    12297: {"Pattern_Syntax"},
    12298: {"Pattern_Syntax"},
    12299: {"Pattern_Syntax"},
    12300: {"Pattern_Syntax", "Quotation_Mark"},
    12301: {"Pattern_Syntax", "Quotation_Mark"},
    12302: {"Pattern_Syntax", "Quotation_Mark"},
    12303: {"Pattern_Syntax", "Quotation_Mark"},
    12304: {"Pattern_Syntax"},
    12305: {"Pattern_Syntax"},
    12306: {"Pattern_Syntax"},
    12307: {"Pattern_Syntax"},
    12308: {"Pattern_Syntax"},
    12309: {"Pattern_Syntax"},
    12310: {"Pattern_Syntax"},
    12311: {"Pattern_Syntax"},
    12312: {"Pattern_Syntax"},
    12313: {"Pattern_Syntax"},
    12314: {"Pattern_Syntax"},
    12315: {"Pattern_Syntax"},
    12316: {"Pattern_Syntax", "Dash"},
    12317: {"Pattern_Syntax", "Quotation_Mark"},
    12318: {"Pattern_Syntax", "Quotation_Mark"},
    12319: {"Pattern_Syntax", "Quotation_Mark"},
    12320: {"Pattern_Syntax"},
    12321: {"Ideographic"},
    12322: {"Ideographic"},
    12323: {"Ideographic"},
    12324: {"Ideographic"},
    12325: {"Ideographic"},
    12326: {"Ideographic"},
    12327: {"Ideographic"},
    12328: {"Ideographic"},
    12329: {"Ideographic"},
    12330: {"Diacritic"},
    12331: {"Diacritic"},
    12332: {"Diacritic"},
    12333: {"Diacritic"},
    12334: {"Diacritic", "Other_Grapheme_Extend"},
    12335: {"Diacritic", "Other_Grapheme_Extend"},
    12336: {"Pattern_Syntax", "Dash"},
    12337: {"Extender"},
    12338: {"Extender"},
    12339: {"Extender"},
    12340: {"Extender"},
    12341: {"Extender"},
    12344: {"Ideographic"},
    12345: {"Ideographic"},
    12346: {"Ideographic"},
    12441: {"Diacritic"},
    12442: {"Diacritic"},
    12443: {"Diacritic", "Other_ID_Start"},
    12444: {"Diacritic", "Other_ID_Start"},
    12445: {"Extender"},
    12446: {"Extender"},
    12448: {"Dash"},
    12539: {"Hyphen"},
    12540: {"Diacritic", "Extender"},
    12541: {"Extender"},
    12542: {"Extender"},
    12644: {"Other_Default_Ignorable_Code_Point"},
    13312: {"Unified_Ideograph", "Ideographic"},
    13313: {"Unified_Ideograph", "Ideographic"},
    13314: {"Unified_Ideograph", "Ideographic"},
    13315: {"Unified_Ideograph", "Ideographic"},
    13316: {"Unified_Ideograph", "Ideographic"},
    13317: {"Unified_Ideograph", "Ideographic"},
    13318: {"Unified_Ideograph", "Ideographic"},
    13319: {"Unified_Ideograph", "Ideographic"},
    13320: {"Unified_Ideograph", "Ideographic"},
    13321: {"Unified_Ideograph", "Ideographic"},
    13322: {"Unified_Ideograph", "Ideographic"},
    13323: {"Unified_Ideograph", "Ideographic"},
    13324: {"Unified_Ideograph", "Ideographic"},
    13325: {"Unified_Ideograph", "Ideographic"},
    13326: {"Unified_Ideograph", "Ideographic"},
    13327: {"Unified_Ideograph", "Ideographic"},
    13328: {"Unified_Ideograph", "Ideographic"},
    13329: {"Unified_Ideograph", "Ideographic"},
    13330: {"Unified_Ideograph", "Ideographic"},
    13331: {"Unified_Ideograph", "Ideographic"},
    13332: {"Unified_Ideograph", "Ideographic"},
    13333: {"Unified_Ideograph", "Ideographic"},
    13334: {"Unified_Ideograph", "Ideographic"},
    13335: {"Unified_Ideograph", "Ideographic"},
    13336: {"Unified_Ideograph", "Ideographic"},
    13337: {"Unified_Ideograph", "Ideographic"},
    13338: {"Unified_Ideograph", "Ideographic"},
    13339: {"Unified_Ideograph", "Ideographic"},
    13340: {"Unified_Ideograph", "Ideographic"},
    13341: {"Unified_Ideograph", "Ideographic"},
    13342: {"Unified_Ideograph", "Ideographic"},
    13343: {"Unified_Ideograph", "Ideographic"},
    13344: {"Unified_Ideograph", "Ideographic"},
    13345: {"Unified_Ideograph", "Ideographic"},
    13346: {"Unified_Ideograph", "Ideographic"},
    13347: {"Unified_Ideograph", "Ideographic"},
    13348: {"Unified_Ideograph", "Ideographic"},
    13349: {"Unified_Ideograph", "Ideographic"},
    13350: {"Unified_Ideograph", "Ideographic"},
    13351: {"Unified_Ideograph", "Ideographic"},
    13352: {"Unified_Ideograph", "Ideographic"},
    13353: {"Unified_Ideograph", "Ideographic"},
    13354: {"Unified_Ideograph", "Ideographic"},
    13355: {"Unified_Ideograph", "Ideographic"},
    13356: {"Unified_Ideograph", "Ideographic"},
    13357: {"Unified_Ideograph", "Ideographic"},
    13358: {"Unified_Ideograph", "Ideographic"},
    13359: {"Unified_Ideograph", "Ideographic"},
    13360: {"Unified_Ideograph", "Ideographic"},
    13361: {"Unified_Ideograph", "Ideographic"},
    13362: {"Unified_Ideograph", "Ideographic"},
    13363: {"Unified_Ideograph", "Ideographic"},
    13364: {"Unified_Ideograph", "Ideographic"},
    13365: {"Unified_Ideograph", "Ideographic"},
    13366: {"Unified_Ideograph", "Ideographic"},
    13367: {"Unified_Ideograph", "Ideographic"},
    13368: {"Unified_Ideograph", "Ideographic"},
    13369: {"Unified_Ideograph", "Ideographic"},
    13370: {"Unified_Ideograph", "Ideographic"},
    13371: {"Unified_Ideograph", "Ideographic"},
    13372: {"Unified_Ideograph", "Ideographic"},
    13373: {"Unified_Ideograph", "Ideographic"},
    13374: {"Unified_Ideograph", "Ideographic"},
    13375: {"Unified_Ideograph", "Ideographic"},
    13376: {"Unified_Ideograph", "Ideographic"},
    13377: {"Unified_Ideograph", "Ideographic"},
    13378: {"Unified_Ideograph", "Ideographic"},
    13379: {"Unified_Ideograph", "Ideographic"},
    13380: {"Unified_Ideograph", "Ideographic"},
    13381: {"Unified_Ideograph", "Ideographic"},
    13382: {"Unified_Ideograph", "Ideographic"},
    13383: {"Unified_Ideograph", "Ideographic"},
    13384: {"Unified_Ideograph", "Ideographic"},
    13385: {"Unified_Ideograph", "Ideographic"},
    13386: {"Unified_Ideograph", "Ideographic"},
    13387: {"Unified_Ideograph", "Ideographic"},
    13388: {"Unified_Ideograph", "Ideographic"},
    13389: {"Unified_Ideograph", "Ideographic"},
    13390: {"Unified_Ideograph", "Ideographic"},
    13391: {"Unified_Ideograph", "Ideographic"},
    13392: {"Unified_Ideograph", "Ideographic"},
    13393: {"Unified_Ideograph", "Ideographic"},
    13394: {"Unified_Ideograph", "Ideographic"},
    13395: {"Unified_Ideograph", "Ideographic"},
    13396: {"Unified_Ideograph", "Ideographic"},
    13397: {"Unified_Ideograph", "Ideographic"},
    13398: {"Unified_Ideograph", "Ideographic"},
    13399: {"Unified_Ideograph", "Ideographic"},
    13400: {"Unified_Ideograph", "Ideographic"},
    13401: {"Unified_Ideograph", "Ideographic"},
    13402: {"Unified_Ideograph", "Ideographic"},
    13403: {"Unified_Ideograph", "Ideographic"},
    13404: {"Unified_Ideograph", "Ideographic"},
    13405: {"Unified_Ideograph", "Ideographic"},
    13406: {"Unified_Ideograph", "Ideographic"},
    13407: {"Unified_Ideograph", "Ideographic"},
    13408: {"Unified_Ideograph", "Ideographic"},
    13409: {"Unified_Ideograph", "Ideographic"},
    13410: {"Unified_Ideograph", "Ideographic"},
    13411: {"Unified_Ideograph", "Ideographic"},
    13412: {"Unified_Ideograph", "Ideographic"},
    13413: {"Unified_Ideograph", "Ideographic"},
    13414: {"Unified_Ideograph", "Ideographic"},
    13415: {"Unified_Ideograph", "Ideographic"},
    13416: {"Unified_Ideograph", "Ideographic"},
    13417: {"Unified_Ideograph", "Ideographic"},
    13418: {"Unified_Ideograph", "Ideographic"},
    13419: {"Unified_Ideograph", "Ideographic"},
    13420: {"Unified_Ideograph", "Ideographic"},
    13421: {"Unified_Ideograph", "Ideographic"},
    13422: {"Unified_Ideograph", "Ideographic"},
    13423: {"Unified_Ideograph", "Ideographic"},
    13424: {"Unified_Ideograph", "Ideographic"},
    13425: {"Unified_Ideograph", "Ideographic"},
    13426: {"Unified_Ideograph", "Ideographic"},
    13427: {"Unified_Ideograph", "Ideographic"},
    13428: {"Unified_Ideograph", "Ideographic"},
    13429: {"Unified_Ideograph", "Ideographic"},
    13430: {"Unified_Ideograph", "Ideographic"},
    13431: {"Unified_Ideograph", "Ideographic"},
    13432: {"Unified_Ideograph", "Ideographic"},
    13433: {"Unified_Ideograph", "Ideographic"},
    13434: {"Unified_Ideograph", "Ideographic"},
    13435: {"Unified_Ideograph", "Ideographic"},
    13436: {"Unified_Ideograph", "Ideographic"},
    13437: {"Unified_Ideograph", "Ideographic"},
    13438: {"Unified_Ideograph", "Ideographic"},
    13439: {"Unified_Ideograph", "Ideographic"},
    13440: {"Unified_Ideograph", "Ideographic"},
    13441: {"Unified_Ideograph", "Ideographic"},
    13442: {"Unified_Ideograph", "Ideographic"},
    13443: {"Unified_Ideograph", "Ideographic"},
    13444: {"Unified_Ideograph", "Ideographic"},
    13445: {"Unified_Ideograph", "Ideographic"},
    13446: {"Unified_Ideograph", "Ideographic"},
    13447: {"Unified_Ideograph", "Ideographic"},
    13448: {"Unified_Ideograph", "Ideographic"},
    13449: {"Unified_Ideograph", "Ideographic"},
    13450: {"Unified_Ideograph", "Ideographic"},
    13451: {"Unified_Ideograph", "Ideographic"},
    13452: {"Unified_Ideograph", "Ideographic"},
    13453: {"Unified_Ideograph", "Ideographic"},
    13454: {"Unified_Ideograph", "Ideographic"},
    13455: {"Unified_Ideograph", "Ideographic"},
    13456: {"Unified_Ideograph", "Ideographic"},
    13457: {"Unified_Ideograph", "Ideographic"},
    13458: {"Unified_Ideograph", "Ideographic"},
    13459: {"Unified_Ideograph", "Ideographic"},
    13460: {"Unified_Ideograph", "Ideographic"},
    13461: {"Unified_Ideograph", "Ideographic"},
    13462: {"Unified_Ideograph", "Ideographic"},
    13463: {"Unified_Ideograph", "Ideographic"},
    13464: {"Unified_Ideograph", "Ideographic"},
    13465: {"Unified_Ideograph", "Ideographic"},
    13466: {"Unified_Ideograph", "Ideographic"},
    13467: {"Unified_Ideograph", "Ideographic"},
    13468: {"Unified_Ideograph", "Ideographic"},
    13469: {"Unified_Ideograph", "Ideographic"},
    13470: {"Unified_Ideograph", "Ideographic"},
    13471: {"Unified_Ideograph", "Ideographic"},
    13472: {"Unified_Ideograph", "Ideographic"},
    13473: {"Unified_Ideograph", "Ideographic"},
    13474: {"Unified_Ideograph", "Ideographic"},
    13475: {"Unified_Ideograph", "Ideographic"},
    13476: {"Unified_Ideograph", "Ideographic"},
    13477: {"Unified_Ideograph", "Ideographic"},
    13478: {"Unified_Ideograph", "Ideographic"},
    13479: {"Unified_Ideograph", "Ideographic"},
    13480: {"Unified_Ideograph", "Ideographic"},
    13481: {"Unified_Ideograph", "Ideographic"},
    13482: {"Unified_Ideograph", "Ideographic"},
    13483: {"Unified_Ideograph", "Ideographic"},
    13484: {"Unified_Ideograph", "Ideographic"},
    13485: {"Unified_Ideograph", "Ideographic"},
    13486: {"Unified_Ideograph", "Ideographic"},
    13487: {"Unified_Ideograph", "Ideographic"},
    13488: {"Unified_Ideograph", "Ideographic"},
    13489: {"Unified_Ideograph", "Ideographic"},
    13490: {"Unified_Ideograph", "Ideographic"},
    13491: {"Unified_Ideograph", "Ideographic"},
    13492: {"Unified_Ideograph", "Ideographic"},
    13493: {"Unified_Ideograph", "Ideographic"},
    13494: {"Unified_Ideograph", "Ideographic"},
    13495: {"Unified_Ideograph", "Ideographic"},
    13496: {"Unified_Ideograph", "Ideographic"},
    13497: {"Unified_Ideograph", "Ideographic"},
    13498: {"Unified_Ideograph", "Ideographic"},
    13499: {"Unified_Ideograph", "Ideographic"},
    13500: {"Unified_Ideograph", "Ideographic"},
    13501: {"Unified_Ideograph", "Ideographic"},
    13502: {"Unified_Ideograph", "Ideographic"},
    13503: {"Unified_Ideograph", "Ideographic"},
    13504: {"Unified_Ideograph", "Ideographic"},
    13505: {"Unified_Ideograph", "Ideographic"},
    13506: {"Unified_Ideograph", "Ideographic"},
    13507: {"Unified_Ideograph", "Ideographic"},
    13508: {"Unified_Ideograph", "Ideographic"},
    13509: {"Unified_Ideograph", "Ideographic"},
    13510: {"Unified_Ideograph", "Ideographic"},
    13511: {"Unified_Ideograph", "Ideographic"},
    13512: {"Unified_Ideograph", "Ideographic"},
    13513: {"Unified_Ideograph", "Ideographic"},
    13514: {"Unified_Ideograph", "Ideographic"},
    13515: {"Unified_Ideograph", "Ideographic"},
    13516: {"Unified_Ideograph", "Ideographic"},
    13517: {"Unified_Ideograph", "Ideographic"},
    13518: {"Unified_Ideograph", "Ideographic"},
    13519: {"Unified_Ideograph", "Ideographic"},
    13520: {"Unified_Ideograph", "Ideographic"},
    13521: {"Unified_Ideograph", "Ideographic"},
    13522: {"Unified_Ideograph", "Ideographic"},
    13523: {"Unified_Ideograph", "Ideographic"},
    13524: {"Unified_Ideograph", "Ideographic"},
    13525: {"Unified_Ideograph", "Ideographic"},
    13526: {"Unified_Ideograph", "Ideographic"},
    13527: {"Unified_Ideograph", "Ideographic"},
    13528: {"Unified_Ideograph", "Ideographic"},
    13529: {"Unified_Ideograph", "Ideographic"},
    13530: {"Unified_Ideograph", "Ideographic"},
    13531: {"Unified_Ideograph", "Ideographic"},
    13532: {"Unified_Ideograph", "Ideographic"},
    13533: {"Unified_Ideograph", "Ideographic"},
    13534: {"Unified_Ideograph", "Ideographic"},
    13535: {"Unified_Ideograph", "Ideographic"},
    13536: {"Unified_Ideograph", "Ideographic"},
    13537: {"Unified_Ideograph", "Ideographic"},
    13538: {"Unified_Ideograph", "Ideographic"},
    13539: {"Unified_Ideograph", "Ideographic"},
    13540: {"Unified_Ideograph", "Ideographic"},
    13541: {"Unified_Ideograph", "Ideographic"},
    13542: {"Unified_Ideograph", "Ideographic"},
    13543: {"Unified_Ideograph", "Ideographic"},
    13544: {"Unified_Ideograph", "Ideographic"},
    13545: {"Unified_Ideograph", "Ideographic"},
    13546: {"Unified_Ideograph", "Ideographic"},
    13547: {"Unified_Ideograph", "Ideographic"},
    13548: {"Unified_Ideograph", "Ideographic"},
    13549: {"Unified_Ideograph", "Ideographic"},
    13550: {"Unified_Ideograph", "Ideographic"},
    13551: {"Unified_Ideograph", "Ideographic"},
    13552: {"Unified_Ideograph", "Ideographic"},
    13553: {"Unified_Ideograph", "Ideographic"},
    13554: {"Unified_Ideograph", "Ideographic"},
    13555: {"Unified_Ideograph", "Ideographic"},
    13556: {"Unified_Ideograph", "Ideographic"},
    13557: {"Unified_Ideograph", "Ideographic"},
    13558: {"Unified_Ideograph", "Ideographic"},
    13559: {"Unified_Ideograph", "Ideographic"},
    13560: {"Unified_Ideograph", "Ideographic"},
    13561: {"Unified_Ideograph", "Ideographic"},
    13562: {"Unified_Ideograph", "Ideographic"},
    13563: {"Unified_Ideograph", "Ideographic"},
    13564: {"Unified_Ideograph", "Ideographic"},
    13565: {"Unified_Ideograph", "Ideographic"},
    13566: {"Unified_Ideograph", "Ideographic"},
    13567: {"Unified_Ideograph", "Ideographic"},
    13568: {"Unified_Ideograph", "Ideographic"},
    13569: {"Unified_Ideograph", "Ideographic"},
    13570: {"Unified_Ideograph", "Ideographic"},
    13571: {"Unified_Ideograph", "Ideographic"},
    13572: {"Unified_Ideograph", "Ideographic"},
    13573: {"Unified_Ideograph", "Ideographic"},
    13574: {"Unified_Ideograph", "Ideographic"},
    13575: {"Unified_Ideograph", "Ideographic"},
    13576: {"Unified_Ideograph", "Ideographic"},
    13577: {"Unified_Ideograph", "Ideographic"},
    13578: {"Unified_Ideograph", "Ideographic"},
    13579: {"Unified_Ideograph", "Ideographic"},
    13580: {"Unified_Ideograph", "Ideographic"},
    13581: {"Unified_Ideograph", "Ideographic"},
    13582: {"Unified_Ideograph", "Ideographic"},
    13583: {"Unified_Ideograph", "Ideographic"},
    13584: {"Unified_Ideograph", "Ideographic"},
    13585: {"Unified_Ideograph", "Ideographic"},
    13586: {"Unified_Ideograph", "Ideographic"},
    13587: {"Unified_Ideograph", "Ideographic"},
    13588: {"Unified_Ideograph", "Ideographic"},
    13589: {"Unified_Ideograph", "Ideographic"},
    13590: {"Unified_Ideograph", "Ideographic"},
    13591: {"Unified_Ideograph", "Ideographic"},
    13592: {"Unified_Ideograph", "Ideographic"},
    13593: {"Unified_Ideograph", "Ideographic"},
    13594: {"Unified_Ideograph", "Ideographic"},
    13595: {"Unified_Ideograph", "Ideographic"},
    13596: {"Unified_Ideograph", "Ideographic"},
    13597: {"Unified_Ideograph", "Ideographic"},
    13598: {"Unified_Ideograph", "Ideographic"},
    13599: {"Unified_Ideograph", "Ideographic"},
    13600: {"Unified_Ideograph", "Ideographic"},
    13601: {"Unified_Ideograph", "Ideographic"},
    13602: {"Unified_Ideograph", "Ideographic"},
    13603: {"Unified_Ideograph", "Ideographic"},
    13604: {"Unified_Ideograph", "Ideographic"},
    13605: {"Unified_Ideograph", "Ideographic"},
    13606: {"Unified_Ideograph", "Ideographic"},
    13607: {"Unified_Ideograph", "Ideographic"},
    13608: {"Unified_Ideograph", "Ideographic"},
    13609: {"Unified_Ideograph", "Ideographic"},
    13610: {"Unified_Ideograph", "Ideographic"},
    13611: {"Unified_Ideograph", "Ideographic"},
    13612: {"Unified_Ideograph", "Ideographic"},
    13613: {"Unified_Ideograph", "Ideographic"},
    13614: {"Unified_Ideograph", "Ideographic"},
    13615: {"Unified_Ideograph", "Ideographic"},
    13616: {"Unified_Ideograph", "Ideographic"},
    13617: {"Unified_Ideograph", "Ideographic"},
    13618: {"Unified_Ideograph", "Ideographic"},
    13619: {"Unified_Ideograph", "Ideographic"},
    13620: {"Unified_Ideograph", "Ideographic"},
    13621: {"Unified_Ideograph", "Ideographic"},
    13622: {"Unified_Ideograph", "Ideographic"},
    13623: {"Unified_Ideograph", "Ideographic"},
    13624: {"Unified_Ideograph", "Ideographic"},
    13625: {"Unified_Ideograph", "Ideographic"},
    13626: {"Unified_Ideograph", "Ideographic"},
    13627: {"Unified_Ideograph", "Ideographic"},
    13628: {"Unified_Ideograph", "Ideographic"},
    13629: {"Unified_Ideograph", "Ideographic"},
    13630: {"Unified_Ideograph", "Ideographic"},
    13631: {"Unified_Ideograph", "Ideographic"},
    13632: {"Unified_Ideograph", "Ideographic"},
    13633: {"Unified_Ideograph", "Ideographic"},
    13634: {"Unified_Ideograph", "Ideographic"},
    13635: {"Unified_Ideograph", "Ideographic"},
    13636: {"Unified_Ideograph", "Ideographic"},
    13637: {"Unified_Ideograph", "Ideographic"},
    13638: {"Unified_Ideograph", "Ideographic"},
    13639: {"Unified_Ideograph", "Ideographic"},
    13640: {"Unified_Ideograph", "Ideographic"},
    13641: {"Unified_Ideograph", "Ideographic"},
    13642: {"Unified_Ideograph", "Ideographic"},
    13643: {"Unified_Ideograph", "Ideographic"},
    13644: {"Unified_Ideograph", "Ideographic"},
    13645: {"Unified_Ideograph", "Ideographic"},
    13646: {"Unified_Ideograph", "Ideographic"},
    13647: {"Unified_Ideograph", "Ideographic"},
    13648: {"Unified_Ideograph", "Ideographic"},
    13649: {"Unified_Ideograph", "Ideographic"},
    13650: {"Unified_Ideograph", "Ideographic"},
    13651: {"Unified_Ideograph", "Ideographic"},
    13652: {"Unified_Ideograph", "Ideographic"},
    13653: {"Unified_Ideograph", "Ideographic"},
    13654: {"Unified_Ideograph", "Ideographic"},
    13655: {"Unified_Ideograph", "Ideographic"},
    13656: {"Unified_Ideograph", "Ideographic"},
    13657: {"Unified_Ideograph", "Ideographic"},
    13658: {"Unified_Ideograph", "Ideographic"},
    13659: {"Unified_Ideograph", "Ideographic"},
    13660: {"Unified_Ideograph", "Ideographic"},
    13661: {"Unified_Ideograph", "Ideographic"},
    13662: {"Unified_Ideograph", "Ideographic"},
    13663: {"Unified_Ideograph", "Ideographic"},
    13664: {"Unified_Ideograph", "Ideographic"},
    13665: {"Unified_Ideograph", "Ideographic"},
    13666: {"Unified_Ideograph", "Ideographic"},
    13667: {"Unified_Ideograph", "Ideographic"},
    13668: {"Unified_Ideograph", "Ideographic"},
    13669: {"Unified_Ideograph", "Ideographic"},
    13670: {"Unified_Ideograph", "Ideographic"},
    13671: {"Unified_Ideograph", "Ideographic"},
    13672: {"Unified_Ideograph", "Ideographic"},
    13673: {"Unified_Ideograph", "Ideographic"},
    13674: {"Unified_Ideograph", "Ideographic"},
    13675: {"Unified_Ideograph", "Ideographic"},
    13676: {"Unified_Ideograph", "Ideographic"},
    13677: {"Unified_Ideograph", "Ideographic"},
    13678: {"Unified_Ideograph", "Ideographic"},
    13679: {"Unified_Ideograph", "Ideographic"},
    13680: {"Unified_Ideograph", "Ideographic"},
    13681: {"Unified_Ideograph", "Ideographic"},
    13682: {"Unified_Ideograph", "Ideographic"},
    13683: {"Unified_Ideograph", "Ideographic"},
    13684: {"Unified_Ideograph", "Ideographic"},
    13685: {"Unified_Ideograph", "Ideographic"},
    13686: {"Unified_Ideograph", "Ideographic"},
    13687: {"Unified_Ideograph", "Ideographic"},
    13688: {"Unified_Ideograph", "Ideographic"},
    13689: {"Unified_Ideograph", "Ideographic"},
    13690: {"Unified_Ideograph", "Ideographic"},
    13691: {"Unified_Ideograph", "Ideographic"},
    13692: {"Unified_Ideograph", "Ideographic"},
    13693: {"Unified_Ideograph", "Ideographic"},
    13694: {"Unified_Ideograph", "Ideographic"},
    13695: {"Unified_Ideograph", "Ideographic"},
    13696: {"Unified_Ideograph", "Ideographic"},
    13697: {"Unified_Ideograph", "Ideographic"},
    13698: {"Unified_Ideograph", "Ideographic"},
    13699: {"Unified_Ideograph", "Ideographic"},
    13700: {"Unified_Ideograph", "Ideographic"},
    13701: {"Unified_Ideograph", "Ideographic"},
    13702: {"Unified_Ideograph", "Ideographic"},
    13703: {"Unified_Ideograph", "Ideographic"},
    13704: {"Unified_Ideograph", "Ideographic"},
    13705: {"Unified_Ideograph", "Ideographic"},
    13706: {"Unified_Ideograph", "Ideographic"},
    13707: {"Unified_Ideograph", "Ideographic"},
    13708: {"Unified_Ideograph", "Ideographic"},
    13709: {"Unified_Ideograph", "Ideographic"},
    13710: {"Unified_Ideograph", "Ideographic"},
    13711: {"Unified_Ideograph", "Ideographic"},
    13712: {"Unified_Ideograph", "Ideographic"},
    13713: {"Unified_Ideograph", "Ideographic"},
    13714: {"Unified_Ideograph", "Ideographic"},
    13715: {"Unified_Ideograph", "Ideographic"},
    13716: {"Unified_Ideograph", "Ideographic"},
    13717: {"Unified_Ideograph", "Ideographic"},
    13718: {"Unified_Ideograph", "Ideographic"},
    13719: {"Unified_Ideograph", "Ideographic"},
    13720: {"Unified_Ideograph", "Ideographic"},
    13721: {"Unified_Ideograph", "Ideographic"},
    13722: {"Unified_Ideograph", "Ideographic"},
    13723: {"Unified_Ideograph", "Ideographic"},
    13724: {"Unified_Ideograph", "Ideographic"},
    13725: {"Unified_Ideograph", "Ideographic"},
    13726: {"Unified_Ideograph", "Ideographic"},
    13727: {"Unified_Ideograph", "Ideographic"},
    13728: {"Unified_Ideograph", "Ideographic"},
    13729: {"Unified_Ideograph", "Ideographic"},
    13730: {"Unified_Ideograph", "Ideographic"},
    13731: {"Unified_Ideograph", "Ideographic"},
    13732: {"Unified_Ideograph", "Ideographic"},
    13733: {"Unified_Ideograph", "Ideographic"},
    13734: {"Unified_Ideograph", "Ideographic"},
    13735: {"Unified_Ideograph", "Ideographic"},
    13736: {"Unified_Ideograph", "Ideographic"},
    13737: {"Unified_Ideograph", "Ideographic"},
    13738: {"Unified_Ideograph", "Ideographic"},
    13739: {"Unified_Ideograph", "Ideographic"},
    13740: {"Unified_Ideograph", "Ideographic"},
    13741: {"Unified_Ideograph", "Ideographic"},
    13742: {"Unified_Ideograph", "Ideographic"},
    13743: {"Unified_Ideograph", "Ideographic"},
    13744: {"Unified_Ideograph", "Ideographic"},
    13745: {"Unified_Ideograph", "Ideographic"},
    13746: {"Unified_Ideograph", "Ideographic"},
    13747: {"Unified_Ideograph", "Ideographic"},
    13748: {"Unified_Ideograph", "Ideographic"},
    13749: {"Unified_Ideograph", "Ideographic"},
    13750: {"Unified_Ideograph", "Ideographic"},
    13751: {"Unified_Ideograph", "Ideographic"},
    13752: {"Unified_Ideograph", "Ideographic"},
    13753: {"Unified_Ideograph", "Ideographic"},
    13754: {"Unified_Ideograph", "Ideographic"},
    13755: {"Unified_Ideograph", "Ideographic"},
    13756: {"Unified_Ideograph", "Ideographic"},
    13757: {"Unified_Ideograph", "Ideographic"},
    13758: {"Unified_Ideograph", "Ideographic"},
    13759: {"Unified_Ideograph", "Ideographic"},
    13760: {"Unified_Ideograph", "Ideographic"},
    13761: {"Unified_Ideograph", "Ideographic"},
    13762: {"Unified_Ideograph", "Ideographic"},
    13763: {"Unified_Ideograph", "Ideographic"},
    13764: {"Unified_Ideograph", "Ideographic"},
    13765: {"Unified_Ideograph", "Ideographic"},
    13766: {"Unified_Ideograph", "Ideographic"},
    13767: {"Unified_Ideograph", "Ideographic"},
    13768: {"Unified_Ideograph", "Ideographic"},
    13769: {"Unified_Ideograph", "Ideographic"},
    13770: {"Unified_Ideograph", "Ideographic"},
    13771: {"Unified_Ideograph", "Ideographic"},
    13772: {"Unified_Ideograph", "Ideographic"},
    13773: {"Unified_Ideograph", "Ideographic"},
    13774: {"Unified_Ideograph", "Ideographic"},
    13775: {"Unified_Ideograph", "Ideographic"},
    13776: {"Unified_Ideograph", "Ideographic"},
    13777: {"Unified_Ideograph", "Ideographic"},
    13778: {"Unified_Ideograph", "Ideographic"},
    13779: {"Unified_Ideograph", "Ideographic"},
    13780: {"Unified_Ideograph", "Ideographic"},
    13781: {"Unified_Ideograph", "Ideographic"},
    13782: {"Unified_Ideograph", "Ideographic"},
    13783: {"Unified_Ideograph", "Ideographic"},
    13784: {"Unified_Ideograph", "Ideographic"},
    13785: {"Unified_Ideograph", "Ideographic"},
    13786: {"Unified_Ideograph", "Ideographic"},
    13787: {"Unified_Ideograph", "Ideographic"},
    13788: {"Unified_Ideograph", "Ideographic"},
    13789: {"Unified_Ideograph", "Ideographic"},
    13790: {"Unified_Ideograph", "Ideographic"},
    13791: {"Unified_Ideograph", "Ideographic"},
    13792: {"Unified_Ideograph", "Ideographic"},
    13793: {"Unified_Ideograph", "Ideographic"},
    13794: {"Unified_Ideograph", "Ideographic"},
    13795: {"Unified_Ideograph", "Ideographic"},
    13796: {"Unified_Ideograph", "Ideographic"},
    13797: {"Unified_Ideograph", "Ideographic"},
    13798: {"Unified_Ideograph", "Ideographic"},
    13799: {"Unified_Ideograph", "Ideographic"},
    13800: {"Unified_Ideograph", "Ideographic"},
    13801: {"Unified_Ideograph", "Ideographic"},
    13802: {"Unified_Ideograph", "Ideographic"},
    13803: {"Unified_Ideograph", "Ideographic"},
    13804: {"Unified_Ideograph", "Ideographic"},
    13805: {"Unified_Ideograph", "Ideographic"},
    13806: {"Unified_Ideograph", "Ideographic"},
    13807: {"Unified_Ideograph", "Ideographic"},
    13808: {"Unified_Ideograph", "Ideographic"},
    13809: {"Unified_Ideograph", "Ideographic"},
    13810: {"Unified_Ideograph", "Ideographic"},
    13811: {"Unified_Ideograph", "Ideographic"},
    13812: {"Unified_Ideograph", "Ideographic"},
    13813: {"Unified_Ideograph", "Ideographic"},
    13814: {"Unified_Ideograph", "Ideographic"},
    13815: {"Unified_Ideograph", "Ideographic"},
    13816: {"Unified_Ideograph", "Ideographic"},
    13817: {"Unified_Ideograph", "Ideographic"},
    13818: {"Unified_Ideograph", "Ideographic"},
    13819: {"Unified_Ideograph", "Ideographic"},
    13820: {"Unified_Ideograph", "Ideographic"},
    13821: {"Unified_Ideograph", "Ideographic"},
    13822: {"Unified_Ideograph", "Ideographic"},
    13823: {"Unified_Ideograph", "Ideographic"},
    13824: {"Unified_Ideograph", "Ideographic"},
    13825: {"Unified_Ideograph", "Ideographic"},
    13826: {"Unified_Ideograph", "Ideographic"},
    13827: {"Unified_Ideograph", "Ideographic"},
    13828: {"Unified_Ideograph", "Ideographic"},
    13829: {"Unified_Ideograph", "Ideographic"},
    13830: {"Unified_Ideograph", "Ideographic"},
    13831: {"Unified_Ideograph", "Ideographic"},
    13832: {"Unified_Ideograph", "Ideographic"},
    13833: {"Unified_Ideograph", "Ideographic"},
    13834: {"Unified_Ideograph", "Ideographic"},
    13835: {"Unified_Ideograph", "Ideographic"},
    13836: {"Unified_Ideograph", "Ideographic"},
    13837: {"Unified_Ideograph", "Ideographic"},
    13838: {"Unified_Ideograph", "Ideographic"},
    13839: {"Unified_Ideograph", "Ideographic"},
    13840: {"Unified_Ideograph", "Ideographic"},
    13841: {"Unified_Ideograph", "Ideographic"},
    13842: {"Unified_Ideograph", "Ideographic"},
    13843: {"Unified_Ideograph", "Ideographic"},
    13844: {"Unified_Ideograph", "Ideographic"},
    13845: {"Unified_Ideograph", "Ideographic"},
    13846: {"Unified_Ideograph", "Ideographic"},
    13847: {"Unified_Ideograph", "Ideographic"},
    13848: {"Unified_Ideograph", "Ideographic"},
    13849: {"Unified_Ideograph", "Ideographic"},
    13850: {"Unified_Ideograph", "Ideographic"},
    13851: {"Unified_Ideograph", "Ideographic"},
    13852: {"Unified_Ideograph", "Ideographic"},
    13853: {"Unified_Ideograph", "Ideographic"},
    13854: {"Unified_Ideograph", "Ideographic"},
    13855: {"Unified_Ideograph", "Ideographic"},
    13856: {"Unified_Ideograph", "Ideographic"},
    13857: {"Unified_Ideograph", "Ideographic"},
    13858: {"Unified_Ideograph", "Ideographic"},
    13859: {"Unified_Ideograph", "Ideographic"},
    13860: {"Unified_Ideograph", "Ideographic"},
    13861: {"Unified_Ideograph", "Ideographic"},
    13862: {"Unified_Ideograph", "Ideographic"},
    13863: {"Unified_Ideograph", "Ideographic"},
    13864: {"Unified_Ideograph", "Ideographic"},
    13865: {"Unified_Ideograph", "Ideographic"},
    13866: {"Unified_Ideograph", "Ideographic"},
    13867: {"Unified_Ideograph", "Ideographic"},
    13868: {"Unified_Ideograph", "Ideographic"},
    13869: {"Unified_Ideograph", "Ideographic"},
    13870: {"Unified_Ideograph", "Ideographic"},
    13871: {"Unified_Ideograph", "Ideographic"},
    13872: {"Unified_Ideograph", "Ideographic"},
    13873: {"Unified_Ideograph", "Ideographic"},
    13874: {"Unified_Ideograph", "Ideographic"},
    13875: {"Unified_Ideograph", "Ideographic"},
    13876: {"Unified_Ideograph", "Ideographic"},
    13877: {"Unified_Ideograph", "Ideographic"},
    13878: {"Unified_Ideograph", "Ideographic"},
    13879: {"Unified_Ideograph", "Ideographic"},
    13880: {"Unified_Ideograph", "Ideographic"},
    13881: {"Unified_Ideograph", "Ideographic"},
    13882: {"Unified_Ideograph", "Ideographic"},
    13883: {"Unified_Ideograph", "Ideographic"},
    13884: {"Unified_Ideograph", "Ideographic"},
    13885: {"Unified_Ideograph", "Ideographic"},
    13886: {"Unified_Ideograph", "Ideographic"},
    13887: {"Unified_Ideograph", "Ideographic"},
    13888: {"Unified_Ideograph", "Ideographic"},
    13889: {"Unified_Ideograph", "Ideographic"},
    13890: {"Unified_Ideograph", "Ideographic"},
    13891: {"Unified_Ideograph", "Ideographic"},
    13892: {"Unified_Ideograph", "Ideographic"},
    13893: {"Unified_Ideograph", "Ideographic"},
    13894: {"Unified_Ideograph", "Ideographic"},
    13895: {"Unified_Ideograph", "Ideographic"},
    13896: {"Unified_Ideograph", "Ideographic"},
    13897: {"Unified_Ideograph", "Ideographic"},
    13898: {"Unified_Ideograph", "Ideographic"},
    13899: {"Unified_Ideograph", "Ideographic"},
    13900: {"Unified_Ideograph", "Ideographic"},
    13901: {"Unified_Ideograph", "Ideographic"},
    13902: {"Unified_Ideograph", "Ideographic"},
    13903: {"Unified_Ideograph", "Ideographic"},
    13904: {"Unified_Ideograph", "Ideographic"},
    13905: {"Unified_Ideograph", "Ideographic"},
    13906: {"Unified_Ideograph", "Ideographic"},
    13907: {"Unified_Ideograph", "Ideographic"},
    13908: {"Unified_Ideograph", "Ideographic"},
    13909: {"Unified_Ideograph", "Ideographic"},
    13910: {"Unified_Ideograph", "Ideographic"},
    13911: {"Unified_Ideograph", "Ideographic"},
    13912: {"Unified_Ideograph", "Ideographic"},
    13913: {"Unified_Ideograph", "Ideographic"},
    13914: {"Unified_Ideograph", "Ideographic"},
    13915: {"Unified_Ideograph", "Ideographic"},
    13916: {"Unified_Ideograph", "Ideographic"},
    13917: {"Unified_Ideograph", "Ideographic"},
    13918: {"Unified_Ideograph", "Ideographic"},
    13919: {"Unified_Ideograph", "Ideographic"},
    13920: {"Unified_Ideograph", "Ideographic"},
    13921: {"Unified_Ideograph", "Ideographic"},
    13922: {"Unified_Ideograph", "Ideographic"},
    13923: {"Unified_Ideograph", "Ideographic"},
    13924: {"Unified_Ideograph", "Ideographic"},
    13925: {"Unified_Ideograph", "Ideographic"},
    13926: {"Unified_Ideograph", "Ideographic"},
    13927: {"Unified_Ideograph", "Ideographic"},
    13928: {"Unified_Ideograph", "Ideographic"},
    13929: {"Unified_Ideograph", "Ideographic"},
    13930: {"Unified_Ideograph", "Ideographic"},
    13931: {"Unified_Ideograph", "Ideographic"},
    13932: {"Unified_Ideograph", "Ideographic"},
    13933: {"Unified_Ideograph", "Ideographic"},
    13934: {"Unified_Ideograph", "Ideographic"},
    13935: {"Unified_Ideograph", "Ideographic"},
    13936: {"Unified_Ideograph", "Ideographic"},
    13937: {"Unified_Ideograph", "Ideographic"},
    13938: {"Unified_Ideograph", "Ideographic"},
    13939: {"Unified_Ideograph", "Ideographic"},
    13940: {"Unified_Ideograph", "Ideographic"},
    13941: {"Unified_Ideograph", "Ideographic"},
    13942: {"Unified_Ideograph", "Ideographic"},
    13943: {"Unified_Ideograph", "Ideographic"},
    13944: {"Unified_Ideograph", "Ideographic"},
    13945: {"Unified_Ideograph", "Ideographic"},
    13946: {"Unified_Ideograph", "Ideographic"},
    13947: {"Unified_Ideograph", "Ideographic"},
    13948: {"Unified_Ideograph", "Ideographic"},
    13949: {"Unified_Ideograph", "Ideographic"},
    13950: {"Unified_Ideograph", "Ideographic"},
    13951: {"Unified_Ideograph", "Ideographic"},
    13952: {"Unified_Ideograph", "Ideographic"},
    13953: {"Unified_Ideograph", "Ideographic"},
    13954: {"Unified_Ideograph", "Ideographic"},
    13955: {"Unified_Ideograph", "Ideographic"},
    13956: {"Unified_Ideograph", "Ideographic"},
    13957: {"Unified_Ideograph", "Ideographic"},
    13958: {"Unified_Ideograph", "Ideographic"},
    13959: {"Unified_Ideograph", "Ideographic"},
    13960: {"Unified_Ideograph", "Ideographic"},
    13961: {"Unified_Ideograph", "Ideographic"},
    13962: {"Unified_Ideograph", "Ideographic"},
    13963: {"Unified_Ideograph", "Ideographic"},
    13964: {"Unified_Ideograph", "Ideographic"},
    13965: {"Unified_Ideograph", "Ideographic"},
    13966: {"Unified_Ideograph", "Ideographic"},
    13967: {"Unified_Ideograph", "Ideographic"},
    13968: {"Unified_Ideograph", "Ideographic"},
    13969: {"Unified_Ideograph", "Ideographic"},
    13970: {"Unified_Ideograph", "Ideographic"},
    13971: {"Unified_Ideograph", "Ideographic"},
    13972: {"Unified_Ideograph", "Ideographic"},
    13973: {"Unified_Ideograph", "Ideographic"},
    13974: {"Unified_Ideograph", "Ideographic"},
    13975: {"Unified_Ideograph", "Ideographic"},
    13976: {"Unified_Ideograph", "Ideographic"},
    13977: {"Unified_Ideograph", "Ideographic"},
    13978: {"Unified_Ideograph", "Ideographic"},
    13979: {"Unified_Ideograph", "Ideographic"},
    13980: {"Unified_Ideograph", "Ideographic"},
    13981: {"Unified_Ideograph", "Ideographic"},
    13982: {"Unified_Ideograph", "Ideographic"},
    13983: {"Unified_Ideograph", "Ideographic"},
    13984: {"Unified_Ideograph", "Ideographic"},
    13985: {"Unified_Ideograph", "Ideographic"},
    13986: {"Unified_Ideograph", "Ideographic"},
    13987: {"Unified_Ideograph", "Ideographic"},
    13988: {"Unified_Ideograph", "Ideographic"},
    13989: {"Unified_Ideograph", "Ideographic"},
    13990: {"Unified_Ideograph", "Ideographic"},
    13991: {"Unified_Ideograph", "Ideographic"},
    13992: {"Unified_Ideograph", "Ideographic"},
    13993: {"Unified_Ideograph", "Ideographic"},
    13994: {"Unified_Ideograph", "Ideographic"},
    13995: {"Unified_Ideograph", "Ideographic"},
    13996: {"Unified_Ideograph", "Ideographic"},
    13997: {"Unified_Ideograph", "Ideographic"},
    13998: {"Unified_Ideograph", "Ideographic"},
    13999: {"Unified_Ideograph", "Ideographic"},
    14000: {"Unified_Ideograph", "Ideographic"},
    14001: {"Unified_Ideograph", "Ideographic"},
    14002: {"Unified_Ideograph", "Ideographic"},
    14003: {"Unified_Ideograph", "Ideographic"},
    14004: {"Unified_Ideograph", "Ideographic"},
    14005: {"Unified_Ideograph", "Ideographic"},
    14006: {"Unified_Ideograph", "Ideographic"},
    14007: {"Unified_Ideograph", "Ideographic"},
    14008: {"Unified_Ideograph", "Ideographic"},
    14009: {"Unified_Ideograph", "Ideographic"},
    14010: {"Unified_Ideograph", "Ideographic"},
    14011: {"Unified_Ideograph", "Ideographic"},
    14012: {"Unified_Ideograph", "Ideographic"},
    14013: {"Unified_Ideograph", "Ideographic"},
    14014: {"Unified_Ideograph", "Ideographic"},
    14015: {"Unified_Ideograph", "Ideographic"},
    14016: {"Unified_Ideograph", "Ideographic"},
    14017: {"Unified_Ideograph", "Ideographic"},
    14018: {"Unified_Ideograph", "Ideographic"},
    14019: {"Unified_Ideograph", "Ideographic"},
    14020: {"Unified_Ideograph", "Ideographic"},
    14021: {"Unified_Ideograph", "Ideographic"},
    14022: {"Unified_Ideograph", "Ideographic"},
    14023: {"Unified_Ideograph", "Ideographic"},
    14024: {"Unified_Ideograph", "Ideographic"},
    14025: {"Unified_Ideograph", "Ideographic"},
    14026: {"Unified_Ideograph", "Ideographic"},
    14027: {"Unified_Ideograph", "Ideographic"},
    14028: {"Unified_Ideograph", "Ideographic"},
    14029: {"Unified_Ideograph", "Ideographic"},
    14030: {"Unified_Ideograph", "Ideographic"},
    14031: {"Unified_Ideograph", "Ideographic"},
    14032: {"Unified_Ideograph", "Ideographic"},
    14033: {"Unified_Ideograph", "Ideographic"},
    14034: {"Unified_Ideograph", "Ideographic"},
    14035: {"Unified_Ideograph", "Ideographic"},
    14036: {"Unified_Ideograph", "Ideographic"},
    14037: {"Unified_Ideograph", "Ideographic"},
    14038: {"Unified_Ideograph", "Ideographic"},
    14039: {"Unified_Ideograph", "Ideographic"},
    14040: {"Unified_Ideograph", "Ideographic"},
    14041: {"Unified_Ideograph", "Ideographic"},
    14042: {"Unified_Ideograph", "Ideographic"},
    14043: {"Unified_Ideograph", "Ideographic"},
    14044: {"Unified_Ideograph", "Ideographic"},
    14045: {"Unified_Ideograph", "Ideographic"},
    14046: {"Unified_Ideograph", "Ideographic"},
    14047: {"Unified_Ideograph", "Ideographic"},
    14048: {"Unified_Ideograph", "Ideographic"},
    14049: {"Unified_Ideograph", "Ideographic"},
    14050: {"Unified_Ideograph", "Ideographic"},
    14051: {"Unified_Ideograph", "Ideographic"},
    14052: {"Unified_Ideograph", "Ideographic"},
    14053: {"Unified_Ideograph", "Ideographic"},
    14054: {"Unified_Ideograph", "Ideographic"},
    14055: {"Unified_Ideograph", "Ideographic"},
    14056: {"Unified_Ideograph", "Ideographic"},
    14057: {"Unified_Ideograph", "Ideographic"},
    14058: {"Unified_Ideograph", "Ideographic"},
    14059: {"Unified_Ideograph", "Ideographic"},
    14060: {"Unified_Ideograph", "Ideographic"},
    14061: {"Unified_Ideograph", "Ideographic"},
    14062: {"Unified_Ideograph", "Ideographic"},
    14063: {"Unified_Ideograph", "Ideographic"},
    14064: {"Unified_Ideograph", "Ideographic"},
    14065: {"Unified_Ideograph", "Ideographic"},
    14066: {"Unified_Ideograph", "Ideographic"},
    14067: {"Unified_Ideograph", "Ideographic"},
    14068: {"Unified_Ideograph", "Ideographic"},
    14069: {"Unified_Ideograph", "Ideographic"},
    14070: {"Unified_Ideograph", "Ideographic"},
    14071: {"Unified_Ideograph", "Ideographic"},
    14072: {"Unified_Ideograph", "Ideographic"},
    14073: {"Unified_Ideograph", "Ideographic"},
    14074: {"Unified_Ideograph", "Ideographic"},
    14075: {"Unified_Ideograph", "Ideographic"},
    14076: {"Unified_Ideograph", "Ideographic"},
    14077: {"Unified_Ideograph", "Ideographic"},
    14078: {"Unified_Ideograph", "Ideographic"},
    14079: {"Unified_Ideograph", "Ideographic"},
    14080: {"Unified_Ideograph", "Ideographic"},
    14081: {"Unified_Ideograph", "Ideographic"},
    14082: {"Unified_Ideograph", "Ideographic"},
    14083: {"Unified_Ideograph", "Ideographic"},
    14084: {"Unified_Ideograph", "Ideographic"},
    14085: {"Unified_Ideograph", "Ideographic"},
    14086: {"Unified_Ideograph", "Ideographic"},
    14087: {"Unified_Ideograph", "Ideographic"},
    14088: {"Unified_Ideograph", "Ideographic"},
    14089: {"Unified_Ideograph", "Ideographic"},
    14090: {"Unified_Ideograph", "Ideographic"},
    14091: {"Unified_Ideograph", "Ideographic"},
    14092: {"Unified_Ideograph", "Ideographic"},
    14093: {"Unified_Ideograph", "Ideographic"},
    14094: {"Unified_Ideograph", "Ideographic"},
    14095: {"Unified_Ideograph", "Ideographic"},
    14096: {"Unified_Ideograph", "Ideographic"},
    14097: {"Unified_Ideograph", "Ideographic"},
    14098: {"Unified_Ideograph", "Ideographic"},
    14099: {"Unified_Ideograph", "Ideographic"},
    14100: {"Unified_Ideograph", "Ideographic"},
    14101: {"Unified_Ideograph", "Ideographic"},
    14102: {"Unified_Ideograph", "Ideographic"},
    14103: {"Unified_Ideograph", "Ideographic"},
    14104: {"Unified_Ideograph", "Ideographic"},
    14105: {"Unified_Ideograph", "Ideographic"},
    14106: {"Unified_Ideograph", "Ideographic"},
    14107: {"Unified_Ideograph", "Ideographic"},
    14108: {"Unified_Ideograph", "Ideographic"},
    14109: {"Unified_Ideograph", "Ideographic"},
    14110: {"Unified_Ideograph", "Ideographic"},
    14111: {"Unified_Ideograph", "Ideographic"},
    14112: {"Unified_Ideograph", "Ideographic"},
    14113: {"Unified_Ideograph", "Ideographic"},
    14114: {"Unified_Ideograph", "Ideographic"},
    14115: {"Unified_Ideograph", "Ideographic"},
    14116: {"Unified_Ideograph", "Ideographic"},
    14117: {"Unified_Ideograph", "Ideographic"},
    14118: {"Unified_Ideograph", "Ideographic"},
    14119: {"Unified_Ideograph", "Ideographic"},
    14120: {"Unified_Ideograph", "Ideographic"},
    14121: {"Unified_Ideograph", "Ideographic"},
    14122: {"Unified_Ideograph", "Ideographic"},
    14123: {"Unified_Ideograph", "Ideographic"},
    14124: {"Unified_Ideograph", "Ideographic"},
    14125: {"Unified_Ideograph", "Ideographic"},
    14126: {"Unified_Ideograph", "Ideographic"},
    14127: {"Unified_Ideograph", "Ideographic"},
    14128: {"Unified_Ideograph", "Ideographic"},
    14129: {"Unified_Ideograph", "Ideographic"},
    14130: {"Unified_Ideograph", "Ideographic"},
    14131: {"Unified_Ideograph", "Ideographic"},
    14132: {"Unified_Ideograph", "Ideographic"},
    14133: {"Unified_Ideograph", "Ideographic"},
    14134: {"Unified_Ideograph", "Ideographic"},
    14135: {"Unified_Ideograph", "Ideographic"},
    14136: {"Unified_Ideograph", "Ideographic"},
    14137: {"Unified_Ideograph", "Ideographic"},
    14138: {"Unified_Ideograph", "Ideographic"},
    14139: {"Unified_Ideograph", "Ideographic"},
    14140: {"Unified_Ideograph", "Ideographic"},
    14141: {"Unified_Ideograph", "Ideographic"},
    14142: {"Unified_Ideograph", "Ideographic"},
    14143: {"Unified_Ideograph", "Ideographic"},
    14144: {"Unified_Ideograph", "Ideographic"},
    14145: {"Unified_Ideograph", "Ideographic"},
    14146: {"Unified_Ideograph", "Ideographic"},
    14147: {"Unified_Ideograph", "Ideographic"},
    14148: {"Unified_Ideograph", "Ideographic"},
    14149: {"Unified_Ideograph", "Ideographic"},
    14150: {"Unified_Ideograph", "Ideographic"},
    14151: {"Unified_Ideograph", "Ideographic"},
    14152: {"Unified_Ideograph", "Ideographic"},
    14153: {"Unified_Ideograph", "Ideographic"},
    14154: {"Unified_Ideograph", "Ideographic"},
    14155: {"Unified_Ideograph", "Ideographic"},
    14156: {"Unified_Ideograph", "Ideographic"},
    14157: {"Unified_Ideograph", "Ideographic"},
    14158: {"Unified_Ideograph", "Ideographic"},
    14159: {"Unified_Ideograph", "Ideographic"},
    14160: {"Unified_Ideograph", "Ideographic"},
    14161: {"Unified_Ideograph", "Ideographic"},
    14162: {"Unified_Ideograph", "Ideographic"},
    14163: {"Unified_Ideograph", "Ideographic"},
    14164: {"Unified_Ideograph", "Ideographic"},
    14165: {"Unified_Ideograph", "Ideographic"},
    14166: {"Unified_Ideograph", "Ideographic"},
    14167: {"Unified_Ideograph", "Ideographic"},
    14168: {"Unified_Ideograph", "Ideographic"},
    14169: {"Unified_Ideograph", "Ideographic"},
    14170: {"Unified_Ideograph", "Ideographic"},
    14171: {"Unified_Ideograph", "Ideographic"},
    14172: {"Unified_Ideograph", "Ideographic"},
    14173: {"Unified_Ideograph", "Ideographic"},
    14174: {"Unified_Ideograph", "Ideographic"},
    14175: {"Unified_Ideograph", "Ideographic"},
    14176: {"Unified_Ideograph", "Ideographic"},
    14177: {"Unified_Ideograph", "Ideographic"},
    14178: {"Unified_Ideograph", "Ideographic"},
    14179: {"Unified_Ideograph", "Ideographic"},
    14180: {"Unified_Ideograph", "Ideographic"},
    14181: {"Unified_Ideograph", "Ideographic"},
    14182: {"Unified_Ideograph", "Ideographic"},
    14183: {"Unified_Ideograph", "Ideographic"},
    14184: {"Unified_Ideograph", "Ideographic"},
    14185: {"Unified_Ideograph", "Ideographic"},
    14186: {"Unified_Ideograph", "Ideographic"},
    14187: {"Unified_Ideograph", "Ideographic"},
    14188: {"Unified_Ideograph", "Ideographic"},
    14189: {"Unified_Ideograph", "Ideographic"},
    14190: {"Unified_Ideograph", "Ideographic"},
    14191: {"Unified_Ideograph", "Ideographic"},
    14192: {"Unified_Ideograph", "Ideographic"},
    14193: {"Unified_Ideograph", "Ideographic"},
    14194: {"Unified_Ideograph", "Ideographic"},
    14195: {"Unified_Ideograph", "Ideographic"},
    14196: {"Unified_Ideograph", "Ideographic"},
    14197: {"Unified_Ideograph", "Ideographic"},
    14198: {"Unified_Ideograph", "Ideographic"},
    14199: {"Unified_Ideograph", "Ideographic"},
    14200: {"Unified_Ideograph", "Ideographic"},
    14201: {"Unified_Ideograph", "Ideographic"},
    14202: {"Unified_Ideograph", "Ideographic"},
    14203: {"Unified_Ideograph", "Ideographic"},
    14204: {"Unified_Ideograph", "Ideographic"},
    14205: {"Unified_Ideograph", "Ideographic"},
    14206: {"Unified_Ideograph", "Ideographic"},
    14207: {"Unified_Ideograph", "Ideographic"},
    14208: {"Unified_Ideograph", "Ideographic"},
    14209: {"Unified_Ideograph", "Ideographic"},
    14210: {"Unified_Ideograph", "Ideographic"},
    14211: {"Unified_Ideograph", "Ideographic"},
    14212: {"Unified_Ideograph", "Ideographic"},
    14213: {"Unified_Ideograph", "Ideographic"},
    14214: {"Unified_Ideograph", "Ideographic"},
    14215: {"Unified_Ideograph", "Ideographic"},
    14216: {"Unified_Ideograph", "Ideographic"},
    14217: {"Unified_Ideograph", "Ideographic"},
    14218: {"Unified_Ideograph", "Ideographic"},
    14219: {"Unified_Ideograph", "Ideographic"},
    14220: {"Unified_Ideograph", "Ideographic"},
    14221: {"Unified_Ideograph", "Ideographic"},
    14222: {"Unified_Ideograph", "Ideographic"},
    14223: {"Unified_Ideograph", "Ideographic"},
    14224: {"Unified_Ideograph", "Ideographic"},
    14225: {"Unified_Ideograph", "Ideographic"},
    14226: {"Unified_Ideograph", "Ideographic"},
    14227: {"Unified_Ideograph", "Ideographic"},
    14228: {"Unified_Ideograph", "Ideographic"},
    14229: {"Unified_Ideograph", "Ideographic"},
    14230: {"Unified_Ideograph", "Ideographic"},
    14231: {"Unified_Ideograph", "Ideographic"},
    14232: {"Unified_Ideograph", "Ideographic"},
    14233: {"Unified_Ideograph", "Ideographic"},
    14234: {"Unified_Ideograph", "Ideographic"},
    14235: {"Unified_Ideograph", "Ideographic"},
    14236: {"Unified_Ideograph", "Ideographic"},
    14237: {"Unified_Ideograph", "Ideographic"},
    14238: {"Unified_Ideograph", "Ideographic"},
    14239: {"Unified_Ideograph", "Ideographic"},
    14240: {"Unified_Ideograph", "Ideographic"},
    14241: {"Unified_Ideograph", "Ideographic"},
    14242: {"Unified_Ideograph", "Ideographic"},
    14243: {"Unified_Ideograph", "Ideographic"},
    14244: {"Unified_Ideograph", "Ideographic"},
    14245: {"Unified_Ideograph", "Ideographic"},
    14246: {"Unified_Ideograph", "Ideographic"},
    14247: {"Unified_Ideograph", "Ideographic"},
    14248: {"Unified_Ideograph", "Ideographic"},
    14249: {"Unified_Ideograph", "Ideographic"},
    14250: {"Unified_Ideograph", "Ideographic"},
    14251: {"Unified_Ideograph", "Ideographic"},
    14252: {"Unified_Ideograph", "Ideographic"},
    14253: {"Unified_Ideograph", "Ideographic"},
    14254: {"Unified_Ideograph", "Ideographic"},
    14255: {"Unified_Ideograph", "Ideographic"},
    14256: {"Unified_Ideograph", "Ideographic"},
    14257: {"Unified_Ideograph", "Ideographic"},
    14258: {"Unified_Ideograph", "Ideographic"},
    14259: {"Unified_Ideograph", "Ideographic"},
    14260: {"Unified_Ideograph", "Ideographic"},
    14261: {"Unified_Ideograph", "Ideographic"},
    14262: {"Unified_Ideograph", "Ideographic"},
    14263: {"Unified_Ideograph", "Ideographic"},
    14264: {"Unified_Ideograph", "Ideographic"},
    14265: {"Unified_Ideograph", "Ideographic"},
    14266: {"Unified_Ideograph", "Ideographic"},
    14267: {"Unified_Ideograph", "Ideographic"},
    14268: {"Unified_Ideograph", "Ideographic"},
    14269: {"Unified_Ideograph", "Ideographic"},
    14270: {"Unified_Ideograph", "Ideographic"},
    14271: {"Unified_Ideograph", "Ideographic"},
    14272: {"Unified_Ideograph", "Ideographic"},
    14273: {"Unified_Ideograph", "Ideographic"},
    14274: {"Unified_Ideograph", "Ideographic"},
    14275: {"Unified_Ideograph", "Ideographic"},
    14276: {"Unified_Ideograph", "Ideographic"},
    14277: {"Unified_Ideograph", "Ideographic"},
    14278: {"Unified_Ideograph", "Ideographic"},
    14279: {"Unified_Ideograph", "Ideographic"},
    14280: {"Unified_Ideograph", "Ideographic"},
    14281: {"Unified_Ideograph", "Ideographic"},
    14282: {"Unified_Ideograph", "Ideographic"},
    14283: {"Unified_Ideograph", "Ideographic"},
    14284: {"Unified_Ideograph", "Ideographic"},
    14285: {"Unified_Ideograph", "Ideographic"},
    14286: {"Unified_Ideograph", "Ideographic"},
    14287: {"Unified_Ideograph", "Ideographic"},
    14288: {"Unified_Ideograph", "Ideographic"},
    14289: {"Unified_Ideograph", "Ideographic"},
    14290: {"Unified_Ideograph", "Ideographic"},
    14291: {"Unified_Ideograph", "Ideographic"},
    14292: {"Unified_Ideograph", "Ideographic"},
    14293: {"Unified_Ideograph", "Ideographic"},
    14294: {"Unified_Ideograph", "Ideographic"},
    14295: {"Unified_Ideograph", "Ideographic"},
    14296: {"Unified_Ideograph", "Ideographic"},
    14297: {"Unified_Ideograph", "Ideographic"},
    14298: {"Unified_Ideograph", "Ideographic"},
    14299: {"Unified_Ideograph", "Ideographic"},
    14300: {"Unified_Ideograph", "Ideographic"},
    14301: {"Unified_Ideograph", "Ideographic"},
    14302: {"Unified_Ideograph", "Ideographic"},
    14303: {"Unified_Ideograph", "Ideographic"},
    14304: {"Unified_Ideograph", "Ideographic"},
    14305: {"Unified_Ideograph", "Ideographic"},
    14306: {"Unified_Ideograph", "Ideographic"},
    14307: {"Unified_Ideograph", "Ideographic"},
    14308: {"Unified_Ideograph", "Ideographic"},
    14309: {"Unified_Ideograph", "Ideographic"},
    14310: {"Unified_Ideograph", "Ideographic"},
    14311: {"Unified_Ideograph", "Ideographic"},
    14312: {"Unified_Ideograph", "Ideographic"},
    14313: {"Unified_Ideograph", "Ideographic"},
    14314: {"Unified_Ideograph", "Ideographic"},
    14315: {"Unified_Ideograph", "Ideographic"},
    14316: {"Unified_Ideograph", "Ideographic"},
    14317: {"Unified_Ideograph", "Ideographic"},
    14318: {"Unified_Ideograph", "Ideographic"},
    14319: {"Unified_Ideograph", "Ideographic"},
    14320: {"Unified_Ideograph", "Ideographic"},
    14321: {"Unified_Ideograph", "Ideographic"},
    14322: {"Unified_Ideograph", "Ideographic"},
    14323: {"Unified_Ideograph", "Ideographic"},
    14324: {"Unified_Ideograph", "Ideographic"},
    14325: {"Unified_Ideograph", "Ideographic"},
    14326: {"Unified_Ideograph", "Ideographic"},
    14327: {"Unified_Ideograph", "Ideographic"},
    14328: {"Unified_Ideograph", "Ideographic"},
    14329: {"Unified_Ideograph", "Ideographic"},
    14330: {"Unified_Ideograph", "Ideographic"},
    14331: {"Unified_Ideograph", "Ideographic"},
    14332: {"Unified_Ideograph", "Ideographic"},
    14333: {"Unified_Ideograph", "Ideographic"},
    14334: {"Unified_Ideograph", "Ideographic"},
    14335: {"Unified_Ideograph", "Ideographic"},
    14336: {"Unified_Ideograph", "Ideographic"},
    14337: {"Unified_Ideograph", "Ideographic"},
    14338: {"Unified_Ideograph", "Ideographic"},
    14339: {"Unified_Ideograph", "Ideographic"},
    14340: {"Unified_Ideograph", "Ideographic"},
    14341: {"Unified_Ideograph", "Ideographic"},
    14342: {"Unified_Ideograph", "Ideographic"},
    14343: {"Unified_Ideograph", "Ideographic"},
    14344: {"Unified_Ideograph", "Ideographic"},
    14345: {"Unified_Ideograph", "Ideographic"},
    14346: {"Unified_Ideograph", "Ideographic"},
    14347: {"Unified_Ideograph", "Ideographic"},
    14348: {"Unified_Ideograph", "Ideographic"},
    14349: {"Unified_Ideograph", "Ideographic"},
    14350: {"Unified_Ideograph", "Ideographic"},
    14351: {"Unified_Ideograph", "Ideographic"},
    14352: {"Unified_Ideograph", "Ideographic"},
    14353: {"Unified_Ideograph", "Ideographic"},
    14354: {"Unified_Ideograph", "Ideographic"},
    14355: {"Unified_Ideograph", "Ideographic"},
    14356: {"Unified_Ideograph", "Ideographic"},
    14357: {"Unified_Ideograph", "Ideographic"},
    14358: {"Unified_Ideograph", "Ideographic"},
    14359: {"Unified_Ideograph", "Ideographic"},
    14360: {"Unified_Ideograph", "Ideographic"},
    14361: {"Unified_Ideograph", "Ideographic"},
    14362: {"Unified_Ideograph", "Ideographic"},
    14363: {"Unified_Ideograph", "Ideographic"},
    14364: {"Unified_Ideograph", "Ideographic"},
    14365: {"Unified_Ideograph", "Ideographic"},
    14366: {"Unified_Ideograph", "Ideographic"},
    14367: {"Unified_Ideograph", "Ideographic"},
    14368: {"Unified_Ideograph", "Ideographic"},
    14369: {"Unified_Ideograph", "Ideographic"},
    14370: {"Unified_Ideograph", "Ideographic"},
    14371: {"Unified_Ideograph", "Ideographic"},
    14372: {"Unified_Ideograph", "Ideographic"},
    14373: {"Unified_Ideograph", "Ideographic"},
    14374: {"Unified_Ideograph", "Ideographic"},
    14375: {"Unified_Ideograph", "Ideographic"},
    14376: {"Unified_Ideograph", "Ideographic"},
    14377: {"Unified_Ideograph", "Ideographic"},
    14378: {"Unified_Ideograph", "Ideographic"},
    14379: {"Unified_Ideograph", "Ideographic"},
    14380: {"Unified_Ideograph", "Ideographic"},
    14381: {"Unified_Ideograph", "Ideographic"},
    14382: {"Unified_Ideograph", "Ideographic"},
    14383: {"Unified_Ideograph", "Ideographic"},
    14384: {"Unified_Ideograph", "Ideographic"},
    14385: {"Unified_Ideograph", "Ideographic"},
    14386: {"Unified_Ideograph", "Ideographic"},
    14387: {"Unified_Ideograph", "Ideographic"},
    14388: {"Unified_Ideograph", "Ideographic"},
    14389: {"Unified_Ideograph", "Ideographic"},
    14390: {"Unified_Ideograph", "Ideographic"},
    14391: {"Unified_Ideograph", "Ideographic"},
    14392: {"Unified_Ideograph", "Ideographic"},
    14393: {"Unified_Ideograph", "Ideographic"},
    14394: {"Unified_Ideograph", "Ideographic"},
    14395: {"Unified_Ideograph", "Ideographic"},
    14396: {"Unified_Ideograph", "Ideographic"},
    14397: {"Unified_Ideograph", "Ideographic"},
    14398: {"Unified_Ideograph", "Ideographic"},
    14399: {"Unified_Ideograph", "Ideographic"},
    14400: {"Unified_Ideograph", "Ideographic"},
    14401: {"Unified_Ideograph", "Ideographic"},
    14402: {"Unified_Ideograph", "Ideographic"},
    14403: {"Unified_Ideograph", "Ideographic"},
    14404: {"Unified_Ideograph", "Ideographic"},
    14405: {"Unified_Ideograph", "Ideographic"},
    14406: {"Unified_Ideograph", "Ideographic"},
    14407: {"Unified_Ideograph", "Ideographic"},
    14408: {"Unified_Ideograph", "Ideographic"},
    14409: {"Unified_Ideograph", "Ideographic"},
    14410: {"Unified_Ideograph", "Ideographic"},
    14411: {"Unified_Ideograph", "Ideographic"},
    14412: {"Unified_Ideograph", "Ideographic"},
    14413: {"Unified_Ideograph", "Ideographic"},
    14414: {"Unified_Ideograph", "Ideographic"},
    14415: {"Unified_Ideograph", "Ideographic"},
    14416: {"Unified_Ideograph", "Ideographic"},
    14417: {"Unified_Ideograph", "Ideographic"},
    14418: {"Unified_Ideograph", "Ideographic"},
    14419: {"Unified_Ideograph", "Ideographic"},
    14420: {"Unified_Ideograph", "Ideographic"},
    14421: {"Unified_Ideograph", "Ideographic"},
    14422: {"Unified_Ideograph", "Ideographic"},
    14423: {"Unified_Ideograph", "Ideographic"},
    14424: {"Unified_Ideograph", "Ideographic"},
    14425: {"Unified_Ideograph", "Ideographic"},
    14426: {"Unified_Ideograph", "Ideographic"},
    14427: {"Unified_Ideograph", "Ideographic"},
    14428: {"Unified_Ideograph", "Ideographic"},
    14429: {"Unified_Ideograph", "Ideographic"},
    14430: {"Unified_Ideograph", "Ideographic"},
    14431: {"Unified_Ideograph", "Ideographic"},
    14432: {"Unified_Ideograph", "Ideographic"},
    14433: {"Unified_Ideograph", "Ideographic"},
    14434: {"Unified_Ideograph", "Ideographic"},
    14435: {"Unified_Ideograph", "Ideographic"},
    14436: {"Unified_Ideograph", "Ideographic"},
    14437: {"Unified_Ideograph", "Ideographic"},
    14438: {"Unified_Ideograph", "Ideographic"},
    14439: {"Unified_Ideograph", "Ideographic"},
    14440: {"Unified_Ideograph", "Ideographic"},
    14441: {"Unified_Ideograph", "Ideographic"},
    14442: {"Unified_Ideograph", "Ideographic"},
    14443: {"Unified_Ideograph", "Ideographic"},
    14444: {"Unified_Ideograph", "Ideographic"},
    14445: {"Unified_Ideograph", "Ideographic"},
    14446: {"Unified_Ideograph", "Ideographic"},
    14447: {"Unified_Ideograph", "Ideographic"},
    14448: {"Unified_Ideograph", "Ideographic"},
    14449: {"Unified_Ideograph", "Ideographic"},
    14450: {"Unified_Ideograph", "Ideographic"},
    14451: {"Unified_Ideograph", "Ideographic"},
    14452: {"Unified_Ideograph", "Ideographic"},
    14453: {"Unified_Ideograph", "Ideographic"},
    14454: {"Unified_Ideograph", "Ideographic"},
    14455: {"Unified_Ideograph", "Ideographic"},
    14456: {"Unified_Ideograph", "Ideographic"},
    14457: {"Unified_Ideograph", "Ideographic"},
    14458: {"Unified_Ideograph", "Ideographic"},
    14459: {"Unified_Ideograph", "Ideographic"},
    14460: {"Unified_Ideograph", "Ideographic"},
    14461: {"Unified_Ideograph", "Ideographic"},
    14462: {"Unified_Ideograph", "Ideographic"},
    14463: {"Unified_Ideograph", "Ideographic"},
    14464: {"Unified_Ideograph", "Ideographic"},
    14465: {"Unified_Ideograph", "Ideographic"},
    14466: {"Unified_Ideograph", "Ideographic"},
    14467: {"Unified_Ideograph", "Ideographic"},
    14468: {"Unified_Ideograph", "Ideographic"},
    14469: {"Unified_Ideograph", "Ideographic"},
    14470: {"Unified_Ideograph", "Ideographic"},
    14471: {"Unified_Ideograph", "Ideographic"},
    14472: {"Unified_Ideograph", "Ideographic"},
    14473: {"Unified_Ideograph", "Ideographic"},
    14474: {"Unified_Ideograph", "Ideographic"},
    14475: {"Unified_Ideograph", "Ideographic"},
    14476: {"Unified_Ideograph", "Ideographic"},
    14477: {"Unified_Ideograph", "Ideographic"},
    14478: {"Unified_Ideograph", "Ideographic"},
    14479: {"Unified_Ideograph", "Ideographic"},
    14480: {"Unified_Ideograph", "Ideographic"},
    14481: {"Unified_Ideograph", "Ideographic"},
    14482: {"Unified_Ideograph", "Ideographic"},
    14483: {"Unified_Ideograph", "Ideographic"},
    14484: {"Unified_Ideograph", "Ideographic"},
    14485: {"Unified_Ideograph", "Ideographic"},
    14486: {"Unified_Ideograph", "Ideographic"},
    14487: {"Unified_Ideograph", "Ideographic"},
    14488: {"Unified_Ideograph", "Ideographic"},
    14489: {"Unified_Ideograph", "Ideographic"},
    14490: {"Unified_Ideograph", "Ideographic"},
    14491: {"Unified_Ideograph", "Ideographic"},
    14492: {"Unified_Ideograph", "Ideographic"},
    14493: {"Unified_Ideograph", "Ideographic"},
    14494: {"Unified_Ideograph", "Ideographic"},
    14495: {"Unified_Ideograph", "Ideographic"},
    14496: {"Unified_Ideograph", "Ideographic"},
    14497: {"Unified_Ideograph", "Ideographic"},
    14498: {"Unified_Ideograph", "Ideographic"},
    14499: {"Unified_Ideograph", "Ideographic"},
    14500: {"Unified_Ideograph", "Ideographic"},
    14501: {"Unified_Ideograph", "Ideographic"},
    14502: {"Unified_Ideograph", "Ideographic"},
    14503: {"Unified_Ideograph", "Ideographic"},
    14504: {"Unified_Ideograph", "Ideographic"},
    14505: {"Unified_Ideograph", "Ideographic"},
    14506: {"Unified_Ideograph", "Ideographic"},
    14507: {"Unified_Ideograph", "Ideographic"},
    14508: {"Unified_Ideograph", "Ideographic"},
    14509: {"Unified_Ideograph", "Ideographic"},
    14510: {"Unified_Ideograph", "Ideographic"},
    14511: {"Unified_Ideograph", "Ideographic"},
    14512: {"Unified_Ideograph", "Ideographic"},
    14513: {"Unified_Ideograph", "Ideographic"},
    14514: {"Unified_Ideograph", "Ideographic"},
    14515: {"Unified_Ideograph", "Ideographic"},
    14516: {"Unified_Ideograph", "Ideographic"},
    14517: {"Unified_Ideograph", "Ideographic"},
    14518: {"Unified_Ideograph", "Ideographic"},
    14519: {"Unified_Ideograph", "Ideographic"},
    14520: {"Unified_Ideograph", "Ideographic"},
    14521: {"Unified_Ideograph", "Ideographic"},
    14522: {"Unified_Ideograph", "Ideographic"},
    14523: {"Unified_Ideograph", "Ideographic"},
    14524: {"Unified_Ideograph", "Ideographic"},
    14525: {"Unified_Ideograph", "Ideographic"},
    14526: {"Unified_Ideograph", "Ideographic"},
    14527: {"Unified_Ideograph", "Ideographic"},
    14528: {"Unified_Ideograph", "Ideographic"},
    14529: {"Unified_Ideograph", "Ideographic"},
    14530: {"Unified_Ideograph", "Ideographic"},
    14531: {"Unified_Ideograph", "Ideographic"},
    14532: {"Unified_Ideograph", "Ideographic"},
    14533: {"Unified_Ideograph", "Ideographic"},
    14534: {"Unified_Ideograph", "Ideographic"},
    14535: {"Unified_Ideograph", "Ideographic"},
    14536: {"Unified_Ideograph", "Ideographic"},
    14537: {"Unified_Ideograph", "Ideographic"},
    14538: {"Unified_Ideograph", "Ideographic"},
    14539: {"Unified_Ideograph", "Ideographic"},
    14540: {"Unified_Ideograph", "Ideographic"},
    14541: {"Unified_Ideograph", "Ideographic"},
    14542: {"Unified_Ideograph", "Ideographic"},
    14543: {"Unified_Ideograph", "Ideographic"},
    14544: {"Unified_Ideograph", "Ideographic"},
    14545: {"Unified_Ideograph", "Ideographic"},
    14546: {"Unified_Ideograph", "Ideographic"},
    14547: {"Unified_Ideograph", "Ideographic"},
    14548: {"Unified_Ideograph", "Ideographic"},
    14549: {"Unified_Ideograph", "Ideographic"},
    14550: {"Unified_Ideograph", "Ideographic"},
    14551: {"Unified_Ideograph", "Ideographic"},
    14552: {"Unified_Ideograph", "Ideographic"},
    14553: {"Unified_Ideograph", "Ideographic"},
    14554: {"Unified_Ideograph", "Ideographic"},
    14555: {"Unified_Ideograph", "Ideographic"},
    14556: {"Unified_Ideograph", "Ideographic"},
    14557: {"Unified_Ideograph", "Ideographic"},
    14558: {"Unified_Ideograph", "Ideographic"},
    14559: {"Unified_Ideograph", "Ideographic"},
    14560: {"Unified_Ideograph", "Ideographic"},
    14561: {"Unified_Ideograph", "Ideographic"},
    14562: {"Unified_Ideograph", "Ideographic"},
    14563: {"Unified_Ideograph", "Ideographic"},
    14564: {"Unified_Ideograph", "Ideographic"},
    14565: {"Unified_Ideograph", "Ideographic"},
    14566: {"Unified_Ideograph", "Ideographic"},
    14567: {"Unified_Ideograph", "Ideographic"},
    14568: {"Unified_Ideograph", "Ideographic"},
    14569: {"Unified_Ideograph", "Ideographic"},
    14570: {"Unified_Ideograph", "Ideographic"},
    14571: {"Unified_Ideograph", "Ideographic"},
    14572: {"Unified_Ideograph", "Ideographic"},
    14573: {"Unified_Ideograph", "Ideographic"},
    14574: {"Unified_Ideograph", "Ideographic"},
    14575: {"Unified_Ideograph", "Ideographic"},
    14576: {"Unified_Ideograph", "Ideographic"},
    14577: {"Unified_Ideograph", "Ideographic"},
    14578: {"Unified_Ideograph", "Ideographic"},
    14579: {"Unified_Ideograph", "Ideographic"},
    14580: {"Unified_Ideograph", "Ideographic"},
    14581: {"Unified_Ideograph", "Ideographic"},
    14582: {"Unified_Ideograph", "Ideographic"},
    14583: {"Unified_Ideograph", "Ideographic"},
    14584: {"Unified_Ideograph", "Ideographic"},
    14585: {"Unified_Ideograph", "Ideographic"},
    14586: {"Unified_Ideograph", "Ideographic"},
    14587: {"Unified_Ideograph", "Ideographic"},
    14588: {"Unified_Ideograph", "Ideographic"},
    14589: {"Unified_Ideograph", "Ideographic"},
    14590: {"Unified_Ideograph", "Ideographic"},
    14591: {"Unified_Ideograph", "Ideographic"},
    14592: {"Unified_Ideograph", "Ideographic"},
    14593: {"Unified_Ideograph", "Ideographic"},
    14594: {"Unified_Ideograph", "Ideographic"},
    14595: {"Unified_Ideograph", "Ideographic"},
    14596: {"Unified_Ideograph", "Ideographic"},
    14597: {"Unified_Ideograph", "Ideographic"},
    14598: {"Unified_Ideograph", "Ideographic"},
    14599: {"Unified_Ideograph", "Ideographic"},
    14600: {"Unified_Ideograph", "Ideographic"},
    14601: {"Unified_Ideograph", "Ideographic"},
    14602: {"Unified_Ideograph", "Ideographic"},
    14603: {"Unified_Ideograph", "Ideographic"},
    14604: {"Unified_Ideograph", "Ideographic"},
    14605: {"Unified_Ideograph", "Ideographic"},
    14606: {"Unified_Ideograph", "Ideographic"},
    14607: {"Unified_Ideograph", "Ideographic"},
    14608: {"Unified_Ideograph", "Ideographic"},
    14609: {"Unified_Ideograph", "Ideographic"},
    14610: {"Unified_Ideograph", "Ideographic"},
    14611: {"Unified_Ideograph", "Ideographic"},
    14612: {"Unified_Ideograph", "Ideographic"},
    14613: {"Unified_Ideograph", "Ideographic"},
    14614: {"Unified_Ideograph", "Ideographic"},
    14615: {"Unified_Ideograph", "Ideographic"},
    14616: {"Unified_Ideograph", "Ideographic"},
    14617: {"Unified_Ideograph", "Ideographic"},
    14618: {"Unified_Ideograph", "Ideographic"},
    14619: {"Unified_Ideograph", "Ideographic"},
    14620: {"Unified_Ideograph", "Ideographic"},
    14621: {"Unified_Ideograph", "Ideographic"},
    14622: {"Unified_Ideograph", "Ideographic"},
    14623: {"Unified_Ideograph", "Ideographic"},
    14624: {"Unified_Ideograph", "Ideographic"},
    14625: {"Unified_Ideograph", "Ideographic"},
    14626: {"Unified_Ideograph", "Ideographic"},
    14627: {"Unified_Ideograph", "Ideographic"},
    14628: {"Unified_Ideograph", "Ideographic"},
    14629: {"Unified_Ideograph", "Ideographic"},
    14630: {"Unified_Ideograph", "Ideographic"},
    14631: {"Unified_Ideograph", "Ideographic"},
    14632: {"Unified_Ideograph", "Ideographic"},
    14633: {"Unified_Ideograph", "Ideographic"},
    14634: {"Unified_Ideograph", "Ideographic"},
    14635: {"Unified_Ideograph", "Ideographic"},
    14636: {"Unified_Ideograph", "Ideographic"},
    14637: {"Unified_Ideograph", "Ideographic"},
    14638: {"Unified_Ideograph", "Ideographic"},
    14639: {"Unified_Ideograph", "Ideographic"},
    14640: {"Unified_Ideograph", "Ideographic"},
    14641: {"Unified_Ideograph", "Ideographic"},
    14642: {"Unified_Ideograph", "Ideographic"},
    14643: {"Unified_Ideograph", "Ideographic"},
    14644: {"Unified_Ideograph", "Ideographic"},
    14645: {"Unified_Ideograph", "Ideographic"},
    14646: {"Unified_Ideograph", "Ideographic"},
    14647: {"Unified_Ideograph", "Ideographic"},
    14648: {"Unified_Ideograph", "Ideographic"},
    14649: {"Unified_Ideograph", "Ideographic"},
    14650: {"Unified_Ideograph", "Ideographic"},
    14651: {"Unified_Ideograph", "Ideographic"},
    14652: {"Unified_Ideograph", "Ideographic"},
    14653: {"Unified_Ideograph", "Ideographic"},
    14654: {"Unified_Ideograph", "Ideographic"},
    14655: {"Unified_Ideograph", "Ideographic"},
    14656: {"Unified_Ideograph", "Ideographic"},
    14657: {"Unified_Ideograph", "Ideographic"},
    14658: {"Unified_Ideograph", "Ideographic"},
    14659: {"Unified_Ideograph", "Ideographic"},
    14660: {"Unified_Ideograph", "Ideographic"},
    14661: {"Unified_Ideograph", "Ideographic"},
    14662: {"Unified_Ideograph", "Ideographic"},
    14663: {"Unified_Ideograph", "Ideographic"},
    14664: {"Unified_Ideograph", "Ideographic"},
    14665: {"Unified_Ideograph", "Ideographic"},
    14666: {"Unified_Ideograph", "Ideographic"},
    14667: {"Unified_Ideograph", "Ideographic"},
    14668: {"Unified_Ideograph", "Ideographic"},
    14669: {"Unified_Ideograph", "Ideographic"},
    14670: {"Unified_Ideograph", "Ideographic"},
    14671: {"Unified_Ideograph", "Ideographic"},
    14672: {"Unified_Ideograph", "Ideographic"},
    14673: {"Unified_Ideograph", "Ideographic"},
    14674: {"Unified_Ideograph", "Ideographic"},
    14675: {"Unified_Ideograph", "Ideographic"},
    14676: {"Unified_Ideograph", "Ideographic"},
    14677: {"Unified_Ideograph", "Ideographic"},
    14678: {"Unified_Ideograph", "Ideographic"},
    14679: {"Unified_Ideograph", "Ideographic"},
    14680: {"Unified_Ideograph", "Ideographic"},
    14681: {"Unified_Ideograph", "Ideographic"},
    14682: {"Unified_Ideograph", "Ideographic"},
    14683: {"Unified_Ideograph", "Ideographic"},
    14684: {"Unified_Ideograph", "Ideographic"},
    14685: {"Unified_Ideograph", "Ideographic"},
    14686: {"Unified_Ideograph", "Ideographic"},
    14687: {"Unified_Ideograph", "Ideographic"},
    14688: {"Unified_Ideograph", "Ideographic"},
    14689: {"Unified_Ideograph", "Ideographic"},
    14690: {"Unified_Ideograph", "Ideographic"},
    14691: {"Unified_Ideograph", "Ideographic"},
    14692: {"Unified_Ideograph", "Ideographic"},
    14693: {"Unified_Ideograph", "Ideographic"},
    14694: {"Unified_Ideograph", "Ideographic"},
    14695: {"Unified_Ideograph", "Ideographic"},
    14696: {"Unified_Ideograph", "Ideographic"},
    14697: {"Unified_Ideograph", "Ideographic"},
    14698: {"Unified_Ideograph", "Ideographic"},
    14699: {"Unified_Ideograph", "Ideographic"},
    14700: {"Unified_Ideograph", "Ideographic"},
    14701: {"Unified_Ideograph", "Ideographic"},
    14702: {"Unified_Ideograph", "Ideographic"},
    14703: {"Unified_Ideograph", "Ideographic"},
    14704: {"Unified_Ideograph", "Ideographic"},
    14705: {"Unified_Ideograph", "Ideographic"},
    14706: {"Unified_Ideograph", "Ideographic"},
    14707: {"Unified_Ideograph", "Ideographic"},
    14708: {"Unified_Ideograph", "Ideographic"},
    14709: {"Unified_Ideograph", "Ideographic"},
    14710: {"Unified_Ideograph", "Ideographic"},
    14711: {"Unified_Ideograph", "Ideographic"},
    14712: {"Unified_Ideograph", "Ideographic"},
    14713: {"Unified_Ideograph", "Ideographic"},
    14714: {"Unified_Ideograph", "Ideographic"},
    14715: {"Unified_Ideograph", "Ideographic"},
    14716: {"Unified_Ideograph", "Ideographic"},
    14717: {"Unified_Ideograph", "Ideographic"},
    14718: {"Unified_Ideograph", "Ideographic"},
    14719: {"Unified_Ideograph", "Ideographic"},
    14720: {"Unified_Ideograph", "Ideographic"},
    14721: {"Unified_Ideograph", "Ideographic"},
    14722: {"Unified_Ideograph", "Ideographic"},
    14723: {"Unified_Ideograph", "Ideographic"},
    14724: {"Unified_Ideograph", "Ideographic"},
    14725: {"Unified_Ideograph", "Ideographic"},
    14726: {"Unified_Ideograph", "Ideographic"},
    14727: {"Unified_Ideograph", "Ideographic"},
    14728: {"Unified_Ideograph", "Ideographic"},
    14729: {"Unified_Ideograph", "Ideographic"},
    14730: {"Unified_Ideograph", "Ideographic"},
    14731: {"Unified_Ideograph", "Ideographic"},
    14732: {"Unified_Ideograph", "Ideographic"},
    14733: {"Unified_Ideograph", "Ideographic"},
    14734: {"Unified_Ideograph", "Ideographic"},
    14735: {"Unified_Ideograph", "Ideographic"},
    14736: {"Unified_Ideograph", "Ideographic"},
    14737: {"Unified_Ideograph", "Ideographic"},
    14738: {"Unified_Ideograph", "Ideographic"},
    14739: {"Unified_Ideograph", "Ideographic"},
    14740: {"Unified_Ideograph", "Ideographic"},
    14741: {"Unified_Ideograph", "Ideographic"},
    14742: {"Unified_Ideograph", "Ideographic"},
    14743: {"Unified_Ideograph", "Ideographic"},
    14744: {"Unified_Ideograph", "Ideographic"},
    14745: {"Unified_Ideograph", "Ideographic"},
    14746: {"Unified_Ideograph", "Ideographic"},
    14747: {"Unified_Ideograph", "Ideographic"},
    14748: {"Unified_Ideograph", "Ideographic"},
    14749: {"Unified_Ideograph", "Ideographic"},
    14750: {"Unified_Ideograph", "Ideographic"},
    14751: {"Unified_Ideograph", "Ideographic"},
    14752: {"Unified_Ideograph", "Ideographic"},
    14753: {"Unified_Ideograph", "Ideographic"},
    14754: {"Unified_Ideograph", "Ideographic"},
    14755: {"Unified_Ideograph", "Ideographic"},
    14756: {"Unified_Ideograph", "Ideographic"},
    14757: {"Unified_Ideograph", "Ideographic"},
    14758: {"Unified_Ideograph", "Ideographic"},
    14759: {"Unified_Ideograph", "Ideographic"},
    14760: {"Unified_Ideograph", "Ideographic"},
    14761: {"Unified_Ideograph", "Ideographic"},
    14762: {"Unified_Ideograph", "Ideographic"},
    14763: {"Unified_Ideograph", "Ideographic"},
    14764: {"Unified_Ideograph", "Ideographic"},
    14765: {"Unified_Ideograph", "Ideographic"},
    14766: {"Unified_Ideograph", "Ideographic"},
    14767: {"Unified_Ideograph", "Ideographic"},
    14768: {"Unified_Ideograph", "Ideographic"},
    14769: {"Unified_Ideograph", "Ideographic"},
    14770: {"Unified_Ideograph", "Ideographic"},
    14771: {"Unified_Ideograph", "Ideographic"},
    14772: {"Unified_Ideograph", "Ideographic"},
    14773: {"Unified_Ideograph", "Ideographic"},
    14774: {"Unified_Ideograph", "Ideographic"},
    14775: {"Unified_Ideograph", "Ideographic"},
    14776: {"Unified_Ideograph", "Ideographic"},
    14777: {"Unified_Ideograph", "Ideographic"},
    14778: {"Unified_Ideograph", "Ideographic"},
    14779: {"Unified_Ideograph", "Ideographic"},
    14780: {"Unified_Ideograph", "Ideographic"},
    14781: {"Unified_Ideograph", "Ideographic"},
    14782: {"Unified_Ideograph", "Ideographic"},
    14783: {"Unified_Ideograph", "Ideographic"},
    14784: {"Unified_Ideograph", "Ideographic"},
    14785: {"Unified_Ideograph", "Ideographic"},
    14786: {"Unified_Ideograph", "Ideographic"},
    14787: {"Unified_Ideograph", "Ideographic"},
    14788: {"Unified_Ideograph", "Ideographic"},
    14789: {"Unified_Ideograph", "Ideographic"},
    14790: {"Unified_Ideograph", "Ideographic"},
    14791: {"Unified_Ideograph", "Ideographic"},
    14792: {"Unified_Ideograph", "Ideographic"},
    14793: {"Unified_Ideograph", "Ideographic"},
    14794: {"Unified_Ideograph", "Ideographic"},
    14795: {"Unified_Ideograph", "Ideographic"},
    14796: {"Unified_Ideograph", "Ideographic"},
    14797: {"Unified_Ideograph", "Ideographic"},
    14798: {"Unified_Ideograph", "Ideographic"},
    14799: {"Unified_Ideograph", "Ideographic"},
    14800: {"Unified_Ideograph", "Ideographic"},
    14801: {"Unified_Ideograph", "Ideographic"},
    14802: {"Unified_Ideograph", "Ideographic"},
    14803: {"Unified_Ideograph", "Ideographic"},
    14804: {"Unified_Ideograph", "Ideographic"},
    14805: {"Unified_Ideograph", "Ideographic"},
    14806: {"Unified_Ideograph", "Ideographic"},
    14807: {"Unified_Ideograph", "Ideographic"},
    14808: {"Unified_Ideograph", "Ideographic"},
    14809: {"Unified_Ideograph", "Ideographic"},
    14810: {"Unified_Ideograph", "Ideographic"},
    14811: {"Unified_Ideograph", "Ideographic"},
    14812: {"Unified_Ideograph", "Ideographic"},
    14813: {"Unified_Ideograph", "Ideographic"},
    14814: {"Unified_Ideograph", "Ideographic"},
    14815: {"Unified_Ideograph", "Ideographic"},
    14816: {"Unified_Ideograph", "Ideographic"},
    14817: {"Unified_Ideograph", "Ideographic"},
    14818: {"Unified_Ideograph", "Ideographic"},
    14819: {"Unified_Ideograph", "Ideographic"},
    14820: {"Unified_Ideograph", "Ideographic"},
    14821: {"Unified_Ideograph", "Ideographic"},
    14822: {"Unified_Ideograph", "Ideographic"},
    14823: {"Unified_Ideograph", "Ideographic"},
    14824: {"Unified_Ideograph", "Ideographic"},
    14825: {"Unified_Ideograph", "Ideographic"},
    14826: {"Unified_Ideograph", "Ideographic"},
    14827: {"Unified_Ideograph", "Ideographic"},
    14828: {"Unified_Ideograph", "Ideographic"},
    14829: {"Unified_Ideograph", "Ideographic"},
    14830: {"Unified_Ideograph", "Ideographic"},
    14831: {"Unified_Ideograph", "Ideographic"},
    14832: {"Unified_Ideograph", "Ideographic"},
    14833: {"Unified_Ideograph", "Ideographic"},
    14834: {"Unified_Ideograph", "Ideographic"},
    14835: {"Unified_Ideograph", "Ideographic"},
    14836: {"Unified_Ideograph", "Ideographic"},
    14837: {"Unified_Ideograph", "Ideographic"},
    14838: {"Unified_Ideograph", "Ideographic"},
    14839: {"Unified_Ideograph", "Ideographic"},
    14840: {"Unified_Ideograph", "Ideographic"},
    14841: {"Unified_Ideograph", "Ideographic"},
    14842: {"Unified_Ideograph", "Ideographic"},
    14843: {"Unified_Ideograph", "Ideographic"},
    14844: {"Unified_Ideograph", "Ideographic"},
    14845: {"Unified_Ideograph", "Ideographic"},
    14846: {"Unified_Ideograph", "Ideographic"},
    14847: {"Unified_Ideograph", "Ideographic"},
    14848: {"Unified_Ideograph", "Ideographic"},
    14849: {"Unified_Ideograph", "Ideographic"},
    14850: {"Unified_Ideograph", "Ideographic"},
    14851: {"Unified_Ideograph", "Ideographic"},
    14852: {"Unified_Ideograph", "Ideographic"},
    14853: {"Unified_Ideograph", "Ideographic"},
    14854: {"Unified_Ideograph", "Ideographic"},
    14855: {"Unified_Ideograph", "Ideographic"},
    14856: {"Unified_Ideograph", "Ideographic"},
    14857: {"Unified_Ideograph", "Ideographic"},
    14858: {"Unified_Ideograph", "Ideographic"},
    14859: {"Unified_Ideograph", "Ideographic"},
    14860: {"Unified_Ideograph", "Ideographic"},
    14861: {"Unified_Ideograph", "Ideographic"},
    14862: {"Unified_Ideograph", "Ideographic"},
    14863: {"Unified_Ideograph", "Ideographic"},
    14864: {"Unified_Ideograph", "Ideographic"},
    14865: {"Unified_Ideograph", "Ideographic"},
    14866: {"Unified_Ideograph", "Ideographic"},
    14867: {"Unified_Ideograph", "Ideographic"},
    14868: {"Unified_Ideograph", "Ideographic"},
    14869: {"Unified_Ideograph", "Ideographic"},
    14870: {"Unified_Ideograph", "Ideographic"},
    14871: {"Unified_Ideograph", "Ideographic"},
    14872: {"Unified_Ideograph", "Ideographic"},
    14873: {"Unified_Ideograph", "Ideographic"},
    14874: {"Unified_Ideograph", "Ideographic"},
    14875: {"Unified_Ideograph", "Ideographic"},
    14876: {"Unified_Ideograph", "Ideographic"},
    14877: {"Unified_Ideograph", "Ideographic"},
    14878: {"Unified_Ideograph", "Ideographic"},
    14879: {"Unified_Ideograph", "Ideographic"},
    14880: {"Unified_Ideograph", "Ideographic"},
    14881: {"Unified_Ideograph", "Ideographic"},
    14882: {"Unified_Ideograph", "Ideographic"},
    14883: {"Unified_Ideograph", "Ideographic"},
    14884: {"Unified_Ideograph", "Ideographic"},
    14885: {"Unified_Ideograph", "Ideographic"},
    14886: {"Unified_Ideograph", "Ideographic"},
    14887: {"Unified_Ideograph", "Ideographic"},
    14888: {"Unified_Ideograph", "Ideographic"},
    14889: {"Unified_Ideograph", "Ideographic"},
    14890: {"Unified_Ideograph", "Ideographic"},
    14891: {"Unified_Ideograph", "Ideographic"},
    14892: {"Unified_Ideograph", "Ideographic"},
    14893: {"Unified_Ideograph", "Ideographic"},
    14894: {"Unified_Ideograph", "Ideographic"},
    14895: {"Unified_Ideograph", "Ideographic"},
    14896: {"Unified_Ideograph", "Ideographic"},
    14897: {"Unified_Ideograph", "Ideographic"},
    14898: {"Unified_Ideograph", "Ideographic"},
    14899: {"Unified_Ideograph", "Ideographic"},
    14900: {"Unified_Ideograph", "Ideographic"},
    14901: {"Unified_Ideograph", "Ideographic"},
    14902: {"Unified_Ideograph", "Ideographic"},
    14903: {"Unified_Ideograph", "Ideographic"},
    14904: {"Unified_Ideograph", "Ideographic"},
    14905: {"Unified_Ideograph", "Ideographic"},
    14906: {"Unified_Ideograph", "Ideographic"},
    14907: {"Unified_Ideograph", "Ideographic"},
    14908: {"Unified_Ideograph", "Ideographic"},
    14909: {"Unified_Ideograph", "Ideographic"},
    14910: {"Unified_Ideograph", "Ideographic"},
    14911: {"Unified_Ideograph", "Ideographic"},
    14912: {"Unified_Ideograph", "Ideographic"},
    14913: {"Unified_Ideograph", "Ideographic"},
    14914: {"Unified_Ideograph", "Ideographic"},
    14915: {"Unified_Ideograph", "Ideographic"},
    14916: {"Unified_Ideograph", "Ideographic"},
    14917: {"Unified_Ideograph", "Ideographic"},
    14918: {"Unified_Ideograph", "Ideographic"},
    14919: {"Unified_Ideograph", "Ideographic"},
    14920: {"Unified_Ideograph", "Ideographic"},
    14921: {"Unified_Ideograph", "Ideographic"},
    14922: {"Unified_Ideograph", "Ideographic"},
    14923: {"Unified_Ideograph", "Ideographic"},
    14924: {"Unified_Ideograph", "Ideographic"},
    14925: {"Unified_Ideograph", "Ideographic"},
    14926: {"Unified_Ideograph", "Ideographic"},
    14927: {"Unified_Ideograph", "Ideographic"},
    14928: {"Unified_Ideograph", "Ideographic"},
    14929: {"Unified_Ideograph", "Ideographic"},
    14930: {"Unified_Ideograph", "Ideographic"},
    14931: {"Unified_Ideograph", "Ideographic"},
    14932: {"Unified_Ideograph", "Ideographic"},
    14933: {"Unified_Ideograph", "Ideographic"},
    14934: {"Unified_Ideograph", "Ideographic"},
    14935: {"Unified_Ideograph", "Ideographic"},
    14936: {"Unified_Ideograph", "Ideographic"},
    14937: {"Unified_Ideograph", "Ideographic"},
    14938: {"Unified_Ideograph", "Ideographic"},
    14939: {"Unified_Ideograph", "Ideographic"},
    14940: {"Unified_Ideograph", "Ideographic"},
    14941: {"Unified_Ideograph", "Ideographic"},
    14942: {"Unified_Ideograph", "Ideographic"},
    14943: {"Unified_Ideograph", "Ideographic"},
    14944: {"Unified_Ideograph", "Ideographic"},
    14945: {"Unified_Ideograph", "Ideographic"},
    14946: {"Unified_Ideograph", "Ideographic"},
    14947: {"Unified_Ideograph", "Ideographic"},
    14948: {"Unified_Ideograph", "Ideographic"},
    14949: {"Unified_Ideograph", "Ideographic"},
    14950: {"Unified_Ideograph", "Ideographic"},
    14951: {"Unified_Ideograph", "Ideographic"},
    14952: {"Unified_Ideograph", "Ideographic"},
    14953: {"Unified_Ideograph", "Ideographic"},
    14954: {"Unified_Ideograph", "Ideographic"},
    14955: {"Unified_Ideograph", "Ideographic"},
    14956: {"Unified_Ideograph", "Ideographic"},
    14957: {"Unified_Ideograph", "Ideographic"},
    14958: {"Unified_Ideograph", "Ideographic"},
    14959: {"Unified_Ideograph", "Ideographic"},
    14960: {"Unified_Ideograph", "Ideographic"},
    14961: {"Unified_Ideograph", "Ideographic"},
    14962: {"Unified_Ideograph", "Ideographic"},
    14963: {"Unified_Ideograph", "Ideographic"},
    14964: {"Unified_Ideograph", "Ideographic"},
    14965: {"Unified_Ideograph", "Ideographic"},
    14966: {"Unified_Ideograph", "Ideographic"},
    14967: {"Unified_Ideograph", "Ideographic"},
    14968: {"Unified_Ideograph", "Ideographic"},
    14969: {"Unified_Ideograph", "Ideographic"},
    14970: {"Unified_Ideograph", "Ideographic"},
    14971: {"Unified_Ideograph", "Ideographic"},
    14972: {"Unified_Ideograph", "Ideographic"},
    14973: {"Unified_Ideograph", "Ideographic"},
    14974: {"Unified_Ideograph", "Ideographic"},
    14975: {"Unified_Ideograph", "Ideographic"},
    14976: {"Unified_Ideograph", "Ideographic"},
    14977: {"Unified_Ideograph", "Ideographic"},
    14978: {"Unified_Ideograph", "Ideographic"},
    14979: {"Unified_Ideograph", "Ideographic"},
    14980: {"Unified_Ideograph", "Ideographic"},
    14981: {"Unified_Ideograph", "Ideographic"},
    14982: {"Unified_Ideograph", "Ideographic"},
    14983: {"Unified_Ideograph", "Ideographic"},
    14984: {"Unified_Ideograph", "Ideographic"},
    14985: {"Unified_Ideograph", "Ideographic"},
    14986: {"Unified_Ideograph", "Ideographic"},
    14987: {"Unified_Ideograph", "Ideographic"},
    14988: {"Unified_Ideograph", "Ideographic"},
    14989: {"Unified_Ideograph", "Ideographic"},
    14990: {"Unified_Ideograph", "Ideographic"},
    14991: {"Unified_Ideograph", "Ideographic"},
    14992: {"Unified_Ideograph", "Ideographic"},
    14993: {"Unified_Ideograph", "Ideographic"},
    14994: {"Unified_Ideograph", "Ideographic"},
    14995: {"Unified_Ideograph", "Ideographic"},
    14996: {"Unified_Ideograph", "Ideographic"},
    14997: {"Unified_Ideograph", "Ideographic"},
    14998: {"Unified_Ideograph", "Ideographic"},
    14999: {"Unified_Ideograph", "Ideographic"},
    15000: {"Unified_Ideograph", "Ideographic"},
    15001: {"Unified_Ideograph", "Ideographic"},
    15002: {"Unified_Ideograph", "Ideographic"},
    15003: {"Unified_Ideograph", "Ideographic"},
    15004: {"Unified_Ideograph", "Ideographic"},
    15005: {"Unified_Ideograph", "Ideographic"},
    15006: {"Unified_Ideograph", "Ideographic"},
    15007: {"Unified_Ideograph", "Ideographic"},
    15008: {"Unified_Ideograph", "Ideographic"},
    15009: {"Unified_Ideograph", "Ideographic"},
    15010: {"Unified_Ideograph", "Ideographic"},
    15011: {"Unified_Ideograph", "Ideographic"},
    15012: {"Unified_Ideograph", "Ideographic"},
    15013: {"Unified_Ideograph", "Ideographic"},
    15014: {"Unified_Ideograph", "Ideographic"},
    15015: {"Unified_Ideograph", "Ideographic"},
    15016: {"Unified_Ideograph", "Ideographic"},
    15017: {"Unified_Ideograph", "Ideographic"},
    15018: {"Unified_Ideograph", "Ideographic"},
    15019: {"Unified_Ideograph", "Ideographic"},
    15020: {"Unified_Ideograph", "Ideographic"},
    15021: {"Unified_Ideograph", "Ideographic"},
    15022: {"Unified_Ideograph", "Ideographic"},
    15023: {"Unified_Ideograph", "Ideographic"},
    15024: {"Unified_Ideograph", "Ideographic"},
    15025: {"Unified_Ideograph", "Ideographic"},
    15026: {"Unified_Ideograph", "Ideographic"},
    15027: {"Unified_Ideograph", "Ideographic"},
    15028: {"Unified_Ideograph", "Ideographic"},
    15029: {"Unified_Ideograph", "Ideographic"},
    15030: {"Unified_Ideograph", "Ideographic"},
    15031: {"Unified_Ideograph", "Ideographic"},
    15032: {"Unified_Ideograph", "Ideographic"},
    15033: {"Unified_Ideograph", "Ideographic"},
    15034: {"Unified_Ideograph", "Ideographic"},
    15035: {"Unified_Ideograph", "Ideographic"},
    15036: {"Unified_Ideograph", "Ideographic"},
    15037: {"Unified_Ideograph", "Ideographic"},
    15038: {"Unified_Ideograph", "Ideographic"},
    15039: {"Unified_Ideograph", "Ideographic"},
    15040: {"Unified_Ideograph", "Ideographic"},
    15041: {"Unified_Ideograph", "Ideographic"},
    15042: {"Unified_Ideograph", "Ideographic"},
    15043: {"Unified_Ideograph", "Ideographic"},
    15044: {"Unified_Ideograph", "Ideographic"},
    15045: {"Unified_Ideograph", "Ideographic"},
    15046: {"Unified_Ideograph", "Ideographic"},
    15047: {"Unified_Ideograph", "Ideographic"},
    15048: {"Unified_Ideograph", "Ideographic"},
    15049: {"Unified_Ideograph", "Ideographic"},
    15050: {"Unified_Ideograph", "Ideographic"},
    15051: {"Unified_Ideograph", "Ideographic"},
    15052: {"Unified_Ideograph", "Ideographic"},
    15053: {"Unified_Ideograph", "Ideographic"},
    15054: {"Unified_Ideograph", "Ideographic"},
    15055: {"Unified_Ideograph", "Ideographic"},
    15056: {"Unified_Ideograph", "Ideographic"},
    15057: {"Unified_Ideograph", "Ideographic"},
    15058: {"Unified_Ideograph", "Ideographic"},
    15059: {"Unified_Ideograph", "Ideographic"},
    15060: {"Unified_Ideograph", "Ideographic"},
    15061: {"Unified_Ideograph", "Ideographic"},
    15062: {"Unified_Ideograph", "Ideographic"},
    15063: {"Unified_Ideograph", "Ideographic"},
    15064: {"Unified_Ideograph", "Ideographic"},
    15065: {"Unified_Ideograph", "Ideographic"},
    15066: {"Unified_Ideograph", "Ideographic"},
    15067: {"Unified_Ideograph", "Ideographic"},
    15068: {"Unified_Ideograph", "Ideographic"},
    15069: {"Unified_Ideograph", "Ideographic"},
    15070: {"Unified_Ideograph", "Ideographic"},
    15071: {"Unified_Ideograph", "Ideographic"},
    15072: {"Unified_Ideograph", "Ideographic"},
    15073: {"Unified_Ideograph", "Ideographic"},
    15074: {"Unified_Ideograph", "Ideographic"},
    15075: {"Unified_Ideograph", "Ideographic"},
    15076: {"Unified_Ideograph", "Ideographic"},
    15077: {"Unified_Ideograph", "Ideographic"},
    15078: {"Unified_Ideograph", "Ideographic"},
    15079: {"Unified_Ideograph", "Ideographic"},
    15080: {"Unified_Ideograph", "Ideographic"},
    15081: {"Unified_Ideograph", "Ideographic"},
    15082: {"Unified_Ideograph", "Ideographic"},
    15083: {"Unified_Ideograph", "Ideographic"},
    15084: {"Unified_Ideograph", "Ideographic"},
    15085: {"Unified_Ideograph", "Ideographic"},
    15086: {"Unified_Ideograph", "Ideographic"},
    15087: {"Unified_Ideograph", "Ideographic"},
    15088: {"Unified_Ideograph", "Ideographic"},
    15089: {"Unified_Ideograph", "Ideographic"},
    15090: {"Unified_Ideograph", "Ideographic"},
    15091: {"Unified_Ideograph", "Ideographic"},
    15092: {"Unified_Ideograph", "Ideographic"},
    15093: {"Unified_Ideograph", "Ideographic"},
    15094: {"Unified_Ideograph", "Ideographic"},
    15095: {"Unified_Ideograph", "Ideographic"},
    15096: {"Unified_Ideograph", "Ideographic"},
    15097: {"Unified_Ideograph", "Ideographic"},
    15098: {"Unified_Ideograph", "Ideographic"},
    15099: {"Unified_Ideograph", "Ideographic"},
    15100: {"Unified_Ideograph", "Ideographic"},
    15101: {"Unified_Ideograph", "Ideographic"},
    15102: {"Unified_Ideograph", "Ideographic"},
    15103: {"Unified_Ideograph", "Ideographic"},
    15104: {"Unified_Ideograph", "Ideographic"},
    15105: {"Unified_Ideograph", "Ideographic"},
    15106: {"Unified_Ideograph", "Ideographic"},
    15107: {"Unified_Ideograph", "Ideographic"},
    15108: {"Unified_Ideograph", "Ideographic"},
    15109: {"Unified_Ideograph", "Ideographic"},
    15110: {"Unified_Ideograph", "Ideographic"},
    15111: {"Unified_Ideograph", "Ideographic"},
    15112: {"Unified_Ideograph", "Ideographic"},
    15113: {"Unified_Ideograph", "Ideographic"},
    15114: {"Unified_Ideograph", "Ideographic"},
    15115: {"Unified_Ideograph", "Ideographic"},
    15116: {"Unified_Ideograph", "Ideographic"},
    15117: {"Unified_Ideograph", "Ideographic"},
    15118: {"Unified_Ideograph", "Ideographic"},
    15119: {"Unified_Ideograph", "Ideographic"},
    15120: {"Unified_Ideograph", "Ideographic"},
    15121: {"Unified_Ideograph", "Ideographic"},
    15122: {"Unified_Ideograph", "Ideographic"},
    15123: {"Unified_Ideograph", "Ideographic"},
    15124: {"Unified_Ideograph", "Ideographic"},
    15125: {"Unified_Ideograph", "Ideographic"},
    15126: {"Unified_Ideograph", "Ideographic"},
    15127: {"Unified_Ideograph", "Ideographic"},
    15128: {"Unified_Ideograph", "Ideographic"},
    15129: {"Unified_Ideograph", "Ideographic"},
    15130: {"Unified_Ideograph", "Ideographic"},
    15131: {"Unified_Ideograph", "Ideographic"},
    15132: {"Unified_Ideograph", "Ideographic"},
    15133: {"Unified_Ideograph", "Ideographic"},
    15134: {"Unified_Ideograph", "Ideographic"},
    15135: {"Unified_Ideograph", "Ideographic"},
    15136: {"Unified_Ideograph", "Ideographic"},
    15137: {"Unified_Ideograph", "Ideographic"},
    15138: {"Unified_Ideograph", "Ideographic"},
    15139: {"Unified_Ideograph", "Ideographic"},
    15140: {"Unified_Ideograph", "Ideographic"},
    15141: {"Unified_Ideograph", "Ideographic"},
    15142: {"Unified_Ideograph", "Ideographic"},
    15143: {"Unified_Ideograph", "Ideographic"},
    15144: {"Unified_Ideograph", "Ideographic"},
    15145: {"Unified_Ideograph", "Ideographic"},
    15146: {"Unified_Ideograph", "Ideographic"},
    15147: {"Unified_Ideograph", "Ideographic"},
    15148: {"Unified_Ideograph", "Ideographic"},
    15149: {"Unified_Ideograph", "Ideographic"},
    15150: {"Unified_Ideograph", "Ideographic"},
    15151: {"Unified_Ideograph", "Ideographic"},
    15152: {"Unified_Ideograph", "Ideographic"},
    15153: {"Unified_Ideograph", "Ideographic"},
    15154: {"Unified_Ideograph", "Ideographic"},
    15155: {"Unified_Ideograph", "Ideographic"},
    15156: {"Unified_Ideograph", "Ideographic"},
    15157: {"Unified_Ideograph", "Ideographic"},
    15158: {"Unified_Ideograph", "Ideographic"},
    15159: {"Unified_Ideograph", "Ideographic"},
    15160: {"Unified_Ideograph", "Ideographic"},
    15161: {"Unified_Ideograph", "Ideographic"},
    15162: {"Unified_Ideograph", "Ideographic"},
    15163: {"Unified_Ideograph", "Ideographic"},
    15164: {"Unified_Ideograph", "Ideographic"},
    15165: {"Unified_Ideograph", "Ideographic"},
    15166: {"Unified_Ideograph", "Ideographic"},
    15167: {"Unified_Ideograph", "Ideographic"},
    15168: {"Unified_Ideograph", "Ideographic"},
    15169: {"Unified_Ideograph", "Ideographic"},
    15170: {"Unified_Ideograph", "Ideographic"},
    15171: {"Unified_Ideograph", "Ideographic"},
    15172: {"Unified_Ideograph", "Ideographic"},
    15173: {"Unified_Ideograph", "Ideographic"},
    15174: {"Unified_Ideograph", "Ideographic"},
    15175: {"Unified_Ideograph", "Ideographic"},
    15176: {"Unified_Ideograph", "Ideographic"},
    15177: {"Unified_Ideograph", "Ideographic"},
    15178: {"Unified_Ideograph", "Ideographic"},
    15179: {"Unified_Ideograph", "Ideographic"},
    15180: {"Unified_Ideograph", "Ideographic"},
    15181: {"Unified_Ideograph", "Ideographic"},
    15182: {"Unified_Ideograph", "Ideographic"},
    15183: {"Unified_Ideograph", "Ideographic"},
    15184: {"Unified_Ideograph", "Ideographic"},
    15185: {"Unified_Ideograph", "Ideographic"},
    15186: {"Unified_Ideograph", "Ideographic"},
    15187: {"Unified_Ideograph", "Ideographic"},
    15188: {"Unified_Ideograph", "Ideographic"},
    15189: {"Unified_Ideograph", "Ideographic"},
    15190: {"Unified_Ideograph", "Ideographic"},
    15191: {"Unified_Ideograph", "Ideographic"},
    15192: {"Unified_Ideograph", "Ideographic"},
    15193: {"Unified_Ideograph", "Ideographic"},
    15194: {"Unified_Ideograph", "Ideographic"},
    15195: {"Unified_Ideograph", "Ideographic"},
    15196: {"Unified_Ideograph", "Ideographic"},
    15197: {"Unified_Ideograph", "Ideographic"},
    15198: {"Unified_Ideograph", "Ideographic"},
    15199: {"Unified_Ideograph", "Ideographic"},
    15200: {"Unified_Ideograph", "Ideographic"},
    15201: {"Unified_Ideograph", "Ideographic"},
    15202: {"Unified_Ideograph", "Ideographic"},
    15203: {"Unified_Ideograph", "Ideographic"},
    15204: {"Unified_Ideograph", "Ideographic"},
    15205: {"Unified_Ideograph", "Ideographic"},
    15206: {"Unified_Ideograph", "Ideographic"},
    15207: {"Unified_Ideograph", "Ideographic"},
    15208: {"Unified_Ideograph", "Ideographic"},
    15209: {"Unified_Ideograph", "Ideographic"},
    15210: {"Unified_Ideograph", "Ideographic"},
    15211: {"Unified_Ideograph", "Ideographic"},
    15212: {"Unified_Ideograph", "Ideographic"},
    15213: {"Unified_Ideograph", "Ideographic"},
    15214: {"Unified_Ideograph", "Ideographic"},
    15215: {"Unified_Ideograph", "Ideographic"},
    15216: {"Unified_Ideograph", "Ideographic"},
    15217: {"Unified_Ideograph", "Ideographic"},
    15218: {"Unified_Ideograph", "Ideographic"},
    15219: {"Unified_Ideograph", "Ideographic"},
    15220: {"Unified_Ideograph", "Ideographic"},
    15221: {"Unified_Ideograph", "Ideographic"},
    15222: {"Unified_Ideograph", "Ideographic"},
    15223: {"Unified_Ideograph", "Ideographic"},
    15224: {"Unified_Ideograph", "Ideographic"},
    15225: {"Unified_Ideograph", "Ideographic"},
    15226: {"Unified_Ideograph", "Ideographic"},
    15227: {"Unified_Ideograph", "Ideographic"},
    15228: {"Unified_Ideograph", "Ideographic"},
    15229: {"Unified_Ideograph", "Ideographic"},
    15230: {"Unified_Ideograph", "Ideographic"},
    15231: {"Unified_Ideograph", "Ideographic"},
    15232: {"Unified_Ideograph", "Ideographic"},
    15233: {"Unified_Ideograph", "Ideographic"},
    15234: {"Unified_Ideograph", "Ideographic"},
    15235: {"Unified_Ideograph", "Ideographic"},
    15236: {"Unified_Ideograph", "Ideographic"},
    15237: {"Unified_Ideograph", "Ideographic"},
    15238: {"Unified_Ideograph", "Ideographic"},
    15239: {"Unified_Ideograph", "Ideographic"},
    15240: {"Unified_Ideograph", "Ideographic"},
    15241: {"Unified_Ideograph", "Ideographic"},
    15242: {"Unified_Ideograph", "Ideographic"},
    15243: {"Unified_Ideograph", "Ideographic"},
    15244: {"Unified_Ideograph", "Ideographic"},
    15245: {"Unified_Ideograph", "Ideographic"},
    15246: {"Unified_Ideograph", "Ideographic"},
    15247: {"Unified_Ideograph", "Ideographic"},
    15248: {"Unified_Ideograph", "Ideographic"},
    15249: {"Unified_Ideograph", "Ideographic"},
    15250: {"Unified_Ideograph", "Ideographic"},
    15251: {"Unified_Ideograph", "Ideographic"},
    15252: {"Unified_Ideograph", "Ideographic"},
    15253: {"Unified_Ideograph", "Ideographic"},
    15254: {"Unified_Ideograph", "Ideographic"},
    15255: {"Unified_Ideograph", "Ideographic"},
    15256: {"Unified_Ideograph", "Ideographic"},
    15257: {"Unified_Ideograph", "Ideographic"},
    15258: {"Unified_Ideograph", "Ideographic"},
    15259: {"Unified_Ideograph", "Ideographic"},
    15260: {"Unified_Ideograph", "Ideographic"},
    15261: {"Unified_Ideograph", "Ideographic"},
    15262: {"Unified_Ideograph", "Ideographic"},
    15263: {"Unified_Ideograph", "Ideographic"},
    15264: {"Unified_Ideograph", "Ideographic"},
    15265: {"Unified_Ideograph", "Ideographic"},
    15266: {"Unified_Ideograph", "Ideographic"},
    15267: {"Unified_Ideograph", "Ideographic"},
    15268: {"Unified_Ideograph", "Ideographic"},
    15269: {"Unified_Ideograph", "Ideographic"},
    15270: {"Unified_Ideograph", "Ideographic"},
    15271: {"Unified_Ideograph", "Ideographic"},
    15272: {"Unified_Ideograph", "Ideographic"},
    15273: {"Unified_Ideograph", "Ideographic"},
    15274: {"Unified_Ideograph", "Ideographic"},
    15275: {"Unified_Ideograph", "Ideographic"},
    15276: {"Unified_Ideograph", "Ideographic"},
    15277: {"Unified_Ideograph", "Ideographic"},
    15278: {"Unified_Ideograph", "Ideographic"},
    15279: {"Unified_Ideograph", "Ideographic"},
    15280: {"Unified_Ideograph", "Ideographic"},
    15281: {"Unified_Ideograph", "Ideographic"},
    15282: {"Unified_Ideograph", "Ideographic"},
    15283: {"Unified_Ideograph", "Ideographic"},
    15284: {"Unified_Ideograph", "Ideographic"},
    15285: {"Unified_Ideograph", "Ideographic"},
    15286: {"Unified_Ideograph", "Ideographic"},
    15287: {"Unified_Ideograph", "Ideographic"},
    15288: {"Unified_Ideograph", "Ideographic"},
    15289: {"Unified_Ideograph", "Ideographic"},
    15290: {"Unified_Ideograph", "Ideographic"},
    15291: {"Unified_Ideograph", "Ideographic"},
    15292: {"Unified_Ideograph", "Ideographic"},
    15293: {"Unified_Ideograph", "Ideographic"},
    15294: {"Unified_Ideograph", "Ideographic"},
    15295: {"Unified_Ideograph", "Ideographic"},
    15296: {"Unified_Ideograph", "Ideographic"},
    15297: {"Unified_Ideograph", "Ideographic"},
    15298: {"Unified_Ideograph", "Ideographic"},
    15299: {"Unified_Ideograph", "Ideographic"},
    15300: {"Unified_Ideograph", "Ideographic"},
    15301: {"Unified_Ideograph", "Ideographic"},
    15302: {"Unified_Ideograph", "Ideographic"},
    15303: {"Unified_Ideograph", "Ideographic"},
    15304: {"Unified_Ideograph", "Ideographic"},
    15305: {"Unified_Ideograph", "Ideographic"},
    15306: {"Unified_Ideograph", "Ideographic"},
    15307: {"Unified_Ideograph", "Ideographic"},
    15308: {"Unified_Ideograph", "Ideographic"},
    15309: {"Unified_Ideograph", "Ideographic"},
    15310: {"Unified_Ideograph", "Ideographic"},
    15311: {"Unified_Ideograph", "Ideographic"},
    15312: {"Unified_Ideograph", "Ideographic"},
    15313: {"Unified_Ideograph", "Ideographic"},
    15314: {"Unified_Ideograph", "Ideographic"},
    15315: {"Unified_Ideograph", "Ideographic"},
    15316: {"Unified_Ideograph", "Ideographic"},
    15317: {"Unified_Ideograph", "Ideographic"},
    15318: {"Unified_Ideograph", "Ideographic"},
    15319: {"Unified_Ideograph", "Ideographic"},
    15320: {"Unified_Ideograph", "Ideographic"},
    15321: {"Unified_Ideograph", "Ideographic"},
    15322: {"Unified_Ideograph", "Ideographic"},
    15323: {"Unified_Ideograph", "Ideographic"},
    15324: {"Unified_Ideograph", "Ideographic"},
    15325: {"Unified_Ideograph", "Ideographic"},
    15326: {"Unified_Ideograph", "Ideographic"},
    15327: {"Unified_Ideograph", "Ideographic"},
    15328: {"Unified_Ideograph", "Ideographic"},
    15329: {"Unified_Ideograph", "Ideographic"},
    15330: {"Unified_Ideograph", "Ideographic"},
    15331: {"Unified_Ideograph", "Ideographic"},
    15332: {"Unified_Ideograph", "Ideographic"},
    15333: {"Unified_Ideograph", "Ideographic"},
    15334: {"Unified_Ideograph", "Ideographic"},
    15335: {"Unified_Ideograph", "Ideographic"},
    15336: {"Unified_Ideograph", "Ideographic"},
    15337: {"Unified_Ideograph", "Ideographic"},
    15338: {"Unified_Ideograph", "Ideographic"},
    15339: {"Unified_Ideograph", "Ideographic"},
    15340: {"Unified_Ideograph", "Ideographic"},
    15341: {"Unified_Ideograph", "Ideographic"},
    15342: {"Unified_Ideograph", "Ideographic"},
    15343: {"Unified_Ideograph", "Ideographic"},
    15344: {"Unified_Ideograph", "Ideographic"},
    15345: {"Unified_Ideograph", "Ideographic"},
    15346: {"Unified_Ideograph", "Ideographic"},
    15347: {"Unified_Ideograph", "Ideographic"},
    15348: {"Unified_Ideograph", "Ideographic"},
    15349: {"Unified_Ideograph", "Ideographic"},
    15350: {"Unified_Ideograph", "Ideographic"},
    15351: {"Unified_Ideograph", "Ideographic"},
    15352: {"Unified_Ideograph", "Ideographic"},
    15353: {"Unified_Ideograph", "Ideographic"},
    15354: {"Unified_Ideograph", "Ideographic"},
    15355: {"Unified_Ideograph", "Ideographic"},
    15356: {"Unified_Ideograph", "Ideographic"},
    15357: {"Unified_Ideograph", "Ideographic"},
    15358: {"Unified_Ideograph", "Ideographic"},
    15359: {"Unified_Ideograph", "Ideographic"},
    15360: {"Unified_Ideograph", "Ideographic"},
    15361: {"Unified_Ideograph", "Ideographic"},
    15362: {"Unified_Ideograph", "Ideographic"},
    15363: {"Unified_Ideograph", "Ideographic"},
    15364: {"Unified_Ideograph", "Ideographic"},
    15365: {"Unified_Ideograph", "Ideographic"},
    15366: {"Unified_Ideograph", "Ideographic"},
    15367: {"Unified_Ideograph", "Ideographic"},
    15368: {"Unified_Ideograph", "Ideographic"},
    15369: {"Unified_Ideograph", "Ideographic"},
    15370: {"Unified_Ideograph", "Ideographic"},
    15371: {"Unified_Ideograph", "Ideographic"},
    15372: {"Unified_Ideograph", "Ideographic"},
    15373: {"Unified_Ideograph", "Ideographic"},
    15374: {"Unified_Ideograph", "Ideographic"},
    15375: {"Unified_Ideograph", "Ideographic"},
    15376: {"Unified_Ideograph", "Ideographic"},
    15377: {"Unified_Ideograph", "Ideographic"},
    15378: {"Unified_Ideograph", "Ideographic"},
    15379: {"Unified_Ideograph", "Ideographic"},
    15380: {"Unified_Ideograph", "Ideographic"},
    15381: {"Unified_Ideograph", "Ideographic"},
    15382: {"Unified_Ideograph", "Ideographic"},
    15383: {"Unified_Ideograph", "Ideographic"},
    15384: {"Unified_Ideograph", "Ideographic"},
    15385: {"Unified_Ideograph", "Ideographic"},
    15386: {"Unified_Ideograph", "Ideographic"},
    15387: {"Unified_Ideograph", "Ideographic"},
    15388: {"Unified_Ideograph", "Ideographic"},
    15389: {"Unified_Ideograph", "Ideographic"},
    15390: {"Unified_Ideograph", "Ideographic"},
    15391: {"Unified_Ideograph", "Ideographic"},
    15392: {"Unified_Ideograph", "Ideographic"},
    15393: {"Unified_Ideograph", "Ideographic"},
    15394: {"Unified_Ideograph", "Ideographic"},
    15395: {"Unified_Ideograph", "Ideographic"},
    15396: {"Unified_Ideograph", "Ideographic"},
    15397: {"Unified_Ideograph", "Ideographic"},
    15398: {"Unified_Ideograph", "Ideographic"},
    15399: {"Unified_Ideograph", "Ideographic"},
    15400: {"Unified_Ideograph", "Ideographic"},
    15401: {"Unified_Ideograph", "Ideographic"},
    15402: {"Unified_Ideograph", "Ideographic"},
    15403: {"Unified_Ideograph", "Ideographic"},
    15404: {"Unified_Ideograph", "Ideographic"},
    15405: {"Unified_Ideograph", "Ideographic"},
    15406: {"Unified_Ideograph", "Ideographic"},
    15407: {"Unified_Ideograph", "Ideographic"},
    15408: {"Unified_Ideograph", "Ideographic"},
    15409: {"Unified_Ideograph", "Ideographic"},
    15410: {"Unified_Ideograph", "Ideographic"},
    15411: {"Unified_Ideograph", "Ideographic"},
    15412: {"Unified_Ideograph", "Ideographic"},
    15413: {"Unified_Ideograph", "Ideographic"},
    15414: {"Unified_Ideograph", "Ideographic"},
    15415: {"Unified_Ideograph", "Ideographic"},
    15416: {"Unified_Ideograph", "Ideographic"},
    15417: {"Unified_Ideograph", "Ideographic"},
    15418: {"Unified_Ideograph", "Ideographic"},
    15419: {"Unified_Ideograph", "Ideographic"},
    15420: {"Unified_Ideograph", "Ideographic"},
    15421: {"Unified_Ideograph", "Ideographic"},
    15422: {"Unified_Ideograph", "Ideographic"},
    15423: {"Unified_Ideograph", "Ideographic"},
    15424: {"Unified_Ideograph", "Ideographic"},
    15425: {"Unified_Ideograph", "Ideographic"},
    15426: {"Unified_Ideograph", "Ideographic"},
    15427: {"Unified_Ideograph", "Ideographic"},
    15428: {"Unified_Ideograph", "Ideographic"},
    15429: {"Unified_Ideograph", "Ideographic"},
    15430: {"Unified_Ideograph", "Ideographic"},
    15431: {"Unified_Ideograph", "Ideographic"},
    15432: {"Unified_Ideograph", "Ideographic"},
    15433: {"Unified_Ideograph", "Ideographic"},
    15434: {"Unified_Ideograph", "Ideographic"},
    15435: {"Unified_Ideograph", "Ideographic"},
    15436: {"Unified_Ideograph", "Ideographic"},
    15437: {"Unified_Ideograph", "Ideographic"},
    15438: {"Unified_Ideograph", "Ideographic"},
    15439: {"Unified_Ideograph", "Ideographic"},
    15440: {"Unified_Ideograph", "Ideographic"},
    15441: {"Unified_Ideograph", "Ideographic"},
    15442: {"Unified_Ideograph", "Ideographic"},
    15443: {"Unified_Ideograph", "Ideographic"},
    15444: {"Unified_Ideograph", "Ideographic"},
    15445: {"Unified_Ideograph", "Ideographic"},
    15446: {"Unified_Ideograph", "Ideographic"},
    15447: {"Unified_Ideograph", "Ideographic"},
    15448: {"Unified_Ideograph", "Ideographic"},
    15449: {"Unified_Ideograph", "Ideographic"},
    15450: {"Unified_Ideograph", "Ideographic"},
    15451: {"Unified_Ideograph", "Ideographic"},
    15452: {"Unified_Ideograph", "Ideographic"},
    15453: {"Unified_Ideograph", "Ideographic"},
    15454: {"Unified_Ideograph", "Ideographic"},
    15455: {"Unified_Ideograph", "Ideographic"},
    15456: {"Unified_Ideograph", "Ideographic"},
    15457: {"Unified_Ideograph", "Ideographic"},
    15458: {"Unified_Ideograph", "Ideographic"},
    15459: {"Unified_Ideograph", "Ideographic"},
    15460: {"Unified_Ideograph", "Ideographic"},
    15461: {"Unified_Ideograph", "Ideographic"},
    15462: {"Unified_Ideograph", "Ideographic"},
    15463: {"Unified_Ideograph", "Ideographic"},
    15464: {"Unified_Ideograph", "Ideographic"},
    15465: {"Unified_Ideograph", "Ideographic"},
    15466: {"Unified_Ideograph", "Ideographic"},
    15467: {"Unified_Ideograph", "Ideographic"},
    15468: {"Unified_Ideograph", "Ideographic"},
    15469: {"Unified_Ideograph", "Ideographic"},
    15470: {"Unified_Ideograph", "Ideographic"},
    15471: {"Unified_Ideograph", "Ideographic"},
    15472: {"Unified_Ideograph", "Ideographic"},
    15473: {"Unified_Ideograph", "Ideographic"},
    15474: {"Unified_Ideograph", "Ideographic"},
    15475: {"Unified_Ideograph", "Ideographic"},
    15476: {"Unified_Ideograph", "Ideographic"},
    15477: {"Unified_Ideograph", "Ideographic"},
    15478: {"Unified_Ideograph", "Ideographic"},
    15479: {"Unified_Ideograph", "Ideographic"},
    15480: {"Unified_Ideograph", "Ideographic"},
    15481: {"Unified_Ideograph", "Ideographic"},
    15482: {"Unified_Ideograph", "Ideographic"},
    15483: {"Unified_Ideograph", "Ideographic"},
    15484: {"Unified_Ideograph", "Ideographic"},
    15485: {"Unified_Ideograph", "Ideographic"},
    15486: {"Unified_Ideograph", "Ideographic"},
    15487: {"Unified_Ideograph", "Ideographic"},
    15488: {"Unified_Ideograph", "Ideographic"},
    15489: {"Unified_Ideograph", "Ideographic"},
    15490: {"Unified_Ideograph", "Ideographic"},
    15491: {"Unified_Ideograph", "Ideographic"},
    15492: {"Unified_Ideograph", "Ideographic"},
    15493: {"Unified_Ideograph", "Ideographic"},
    15494: {"Unified_Ideograph", "Ideographic"},
    15495: {"Unified_Ideograph", "Ideographic"},
    15496: {"Unified_Ideograph", "Ideographic"},
    15497: {"Unified_Ideograph", "Ideographic"},
    15498: {"Unified_Ideograph", "Ideographic"},
    15499: {"Unified_Ideograph", "Ideographic"},
    15500: {"Unified_Ideograph", "Ideographic"},
    15501: {"Unified_Ideograph", "Ideographic"},
    15502: {"Unified_Ideograph", "Ideographic"},
    15503: {"Unified_Ideograph", "Ideographic"},
    15504: {"Unified_Ideograph", "Ideographic"},
    15505: {"Unified_Ideograph", "Ideographic"},
    15506: {"Unified_Ideograph", "Ideographic"},
    15507: {"Unified_Ideograph", "Ideographic"},
    15508: {"Unified_Ideograph", "Ideographic"},
    15509: {"Unified_Ideograph", "Ideographic"},
    15510: {"Unified_Ideograph", "Ideographic"},
    15511: {"Unified_Ideograph", "Ideographic"},
    15512: {"Unified_Ideograph", "Ideographic"},
    15513: {"Unified_Ideograph", "Ideographic"},
    15514: {"Unified_Ideograph", "Ideographic"},
    15515: {"Unified_Ideograph", "Ideographic"},
    15516: {"Unified_Ideograph", "Ideographic"},
    15517: {"Unified_Ideograph", "Ideographic"},
    15518: {"Unified_Ideograph", "Ideographic"},
    15519: {"Unified_Ideograph", "Ideographic"},
    15520: {"Unified_Ideograph", "Ideographic"},
    15521: {"Unified_Ideograph", "Ideographic"},
    15522: {"Unified_Ideograph", "Ideographic"},
    15523: {"Unified_Ideograph", "Ideographic"},
    15524: {"Unified_Ideograph", "Ideographic"},
    15525: {"Unified_Ideograph", "Ideographic"},
    15526: {"Unified_Ideograph", "Ideographic"},
    15527: {"Unified_Ideograph", "Ideographic"},
    15528: {"Unified_Ideograph", "Ideographic"},
    15529: {"Unified_Ideograph", "Ideographic"},
    15530: {"Unified_Ideograph", "Ideographic"},
    15531: {"Unified_Ideograph", "Ideographic"},
    15532: {"Unified_Ideograph", "Ideographic"},
    15533: {"Unified_Ideograph", "Ideographic"},
    15534: {"Unified_Ideograph", "Ideographic"},
    15535: {"Unified_Ideograph", "Ideographic"},
    15536: {"Unified_Ideograph", "Ideographic"},
    15537: {"Unified_Ideograph", "Ideographic"},
    15538: {"Unified_Ideograph", "Ideographic"},
    15539: {"Unified_Ideograph", "Ideographic"},
    15540: {"Unified_Ideograph", "Ideographic"},
    15541: {"Unified_Ideograph", "Ideographic"},
    15542: {"Unified_Ideograph", "Ideographic"},
    15543: {"Unified_Ideograph", "Ideographic"},
    15544: {"Unified_Ideograph", "Ideographic"},
    15545: {"Unified_Ideograph", "Ideographic"},
    15546: {"Unified_Ideograph", "Ideographic"},
    15547: {"Unified_Ideograph", "Ideographic"},
    15548: {"Unified_Ideograph", "Ideographic"},
    15549: {"Unified_Ideograph", "Ideographic"},
    15550: {"Unified_Ideograph", "Ideographic"},
    15551: {"Unified_Ideograph", "Ideographic"},
    15552: {"Unified_Ideograph", "Ideographic"},
    15553: {"Unified_Ideograph", "Ideographic"},
    15554: {"Unified_Ideograph", "Ideographic"},
    15555: {"Unified_Ideograph", "Ideographic"},
    15556: {"Unified_Ideograph", "Ideographic"},
    15557: {"Unified_Ideograph", "Ideographic"},
    15558: {"Unified_Ideograph", "Ideographic"},
    15559: {"Unified_Ideograph", "Ideographic"},
    15560: {"Unified_Ideograph", "Ideographic"},
    15561: {"Unified_Ideograph", "Ideographic"},
    15562: {"Unified_Ideograph", "Ideographic"},
    15563: {"Unified_Ideograph", "Ideographic"},
    15564: {"Unified_Ideograph", "Ideographic"},
    15565: {"Unified_Ideograph", "Ideographic"},
    15566: {"Unified_Ideograph", "Ideographic"},
    15567: {"Unified_Ideograph", "Ideographic"},
    15568: {"Unified_Ideograph", "Ideographic"},
    15569: {"Unified_Ideograph", "Ideographic"},
    15570: {"Unified_Ideograph", "Ideographic"},
    15571: {"Unified_Ideograph", "Ideographic"},
    15572: {"Unified_Ideograph", "Ideographic"},
    15573: {"Unified_Ideograph", "Ideographic"},
    15574: {"Unified_Ideograph", "Ideographic"},
    15575: {"Unified_Ideograph", "Ideographic"},
    15576: {"Unified_Ideograph", "Ideographic"},
    15577: {"Unified_Ideograph", "Ideographic"},
    15578: {"Unified_Ideograph", "Ideographic"},
    15579: {"Unified_Ideograph", "Ideographic"},
    15580: {"Unified_Ideograph", "Ideographic"},
    15581: {"Unified_Ideograph", "Ideographic"},
    15582: {"Unified_Ideograph", "Ideographic"},
    15583: {"Unified_Ideograph", "Ideographic"},
    15584: {"Unified_Ideograph", "Ideographic"},
    15585: {"Unified_Ideograph", "Ideographic"},
    15586: {"Unified_Ideograph", "Ideographic"},
    15587: {"Unified_Ideograph", "Ideographic"},
    15588: {"Unified_Ideograph", "Ideographic"},
    15589: {"Unified_Ideograph", "Ideographic"},
    15590: {"Unified_Ideograph", "Ideographic"},
    15591: {"Unified_Ideograph", "Ideographic"},
    15592: {"Unified_Ideograph", "Ideographic"},
    15593: {"Unified_Ideograph", "Ideographic"},
    15594: {"Unified_Ideograph", "Ideographic"},
    15595: {"Unified_Ideograph", "Ideographic"},
    15596: {"Unified_Ideograph", "Ideographic"},
    15597: {"Unified_Ideograph", "Ideographic"},
    15598: {"Unified_Ideograph", "Ideographic"},
    15599: {"Unified_Ideograph", "Ideographic"},
    15600: {"Unified_Ideograph", "Ideographic"},
    15601: {"Unified_Ideograph", "Ideographic"},
    15602: {"Unified_Ideograph", "Ideographic"},
    15603: {"Unified_Ideograph", "Ideographic"},
    15604: {"Unified_Ideograph", "Ideographic"},
    15605: {"Unified_Ideograph", "Ideographic"},
    15606: {"Unified_Ideograph", "Ideographic"},
    15607: {"Unified_Ideograph", "Ideographic"},
    15608: {"Unified_Ideograph", "Ideographic"},
    15609: {"Unified_Ideograph", "Ideographic"},
    15610: {"Unified_Ideograph", "Ideographic"},
    15611: {"Unified_Ideograph", "Ideographic"},
    15612: {"Unified_Ideograph", "Ideographic"},
    15613: {"Unified_Ideograph", "Ideographic"},
    15614: {"Unified_Ideograph", "Ideographic"},
    15615: {"Unified_Ideograph", "Ideographic"},
    15616: {"Unified_Ideograph", "Ideographic"},
    15617: {"Unified_Ideograph", "Ideographic"},
    15618: {"Unified_Ideograph", "Ideographic"},
    15619: {"Unified_Ideograph", "Ideographic"},
    15620: {"Unified_Ideograph", "Ideographic"},
    15621: {"Unified_Ideograph", "Ideographic"},
    15622: {"Unified_Ideograph", "Ideographic"},
    15623: {"Unified_Ideograph", "Ideographic"},
    15624: {"Unified_Ideograph", "Ideographic"},
    15625: {"Unified_Ideograph", "Ideographic"},
    15626: {"Unified_Ideograph", "Ideographic"},
    15627: {"Unified_Ideograph", "Ideographic"},
    15628: {"Unified_Ideograph", "Ideographic"},
    15629: {"Unified_Ideograph", "Ideographic"},
    15630: {"Unified_Ideograph", "Ideographic"},
    15631: {"Unified_Ideograph", "Ideographic"},
    15632: {"Unified_Ideograph", "Ideographic"},
    15633: {"Unified_Ideograph", "Ideographic"},
    15634: {"Unified_Ideograph", "Ideographic"},
    15635: {"Unified_Ideograph", "Ideographic"},
    15636: {"Unified_Ideograph", "Ideographic"},
    15637: {"Unified_Ideograph", "Ideographic"},
    15638: {"Unified_Ideograph", "Ideographic"},
    15639: {"Unified_Ideograph", "Ideographic"},
    15640: {"Unified_Ideograph", "Ideographic"},
    15641: {"Unified_Ideograph", "Ideographic"},
    15642: {"Unified_Ideograph", "Ideographic"},
    15643: {"Unified_Ideograph", "Ideographic"},
    15644: {"Unified_Ideograph", "Ideographic"},
    15645: {"Unified_Ideograph", "Ideographic"},
    15646: {"Unified_Ideograph", "Ideographic"},
    15647: {"Unified_Ideograph", "Ideographic"},
    15648: {"Unified_Ideograph", "Ideographic"},
    15649: {"Unified_Ideograph", "Ideographic"},
    15650: {"Unified_Ideograph", "Ideographic"},
    15651: {"Unified_Ideograph", "Ideographic"},
    15652: {"Unified_Ideograph", "Ideographic"},
    15653: {"Unified_Ideograph", "Ideographic"},
    15654: {"Unified_Ideograph", "Ideographic"},
    15655: {"Unified_Ideograph", "Ideographic"},
    15656: {"Unified_Ideograph", "Ideographic"},
    15657: {"Unified_Ideograph", "Ideographic"},
    15658: {"Unified_Ideograph", "Ideographic"},
    15659: {"Unified_Ideograph", "Ideographic"},
    15660: {"Unified_Ideograph", "Ideographic"},
    15661: {"Unified_Ideograph", "Ideographic"},
    15662: {"Unified_Ideograph", "Ideographic"},
    15663: {"Unified_Ideograph", "Ideographic"},
    15664: {"Unified_Ideograph", "Ideographic"},
    15665: {"Unified_Ideograph", "Ideographic"},
    15666: {"Unified_Ideograph", "Ideographic"},
    15667: {"Unified_Ideograph", "Ideographic"},
    15668: {"Unified_Ideograph", "Ideographic"},
    15669: {"Unified_Ideograph", "Ideographic"},
    15670: {"Unified_Ideograph", "Ideographic"},
    15671: {"Unified_Ideograph", "Ideographic"},
    15672: {"Unified_Ideograph", "Ideographic"},
    15673: {"Unified_Ideograph", "Ideographic"},
    15674: {"Unified_Ideograph", "Ideographic"},
    15675: {"Unified_Ideograph", "Ideographic"},
    15676: {"Unified_Ideograph", "Ideographic"},
    15677: {"Unified_Ideograph", "Ideographic"},
    15678: {"Unified_Ideograph", "Ideographic"},
    15679: {"Unified_Ideograph", "Ideographic"},
    15680: {"Unified_Ideograph", "Ideographic"},
    15681: {"Unified_Ideograph", "Ideographic"},
    15682: {"Unified_Ideograph", "Ideographic"},
    15683: {"Unified_Ideograph", "Ideographic"},
    15684: {"Unified_Ideograph", "Ideographic"},
    15685: {"Unified_Ideograph", "Ideographic"},
    15686: {"Unified_Ideograph", "Ideographic"},
    15687: {"Unified_Ideograph", "Ideographic"},
    15688: {"Unified_Ideograph", "Ideographic"},
    15689: {"Unified_Ideograph", "Ideographic"},
    15690: {"Unified_Ideograph", "Ideographic"},
    15691: {"Unified_Ideograph", "Ideographic"},
    15692: {"Unified_Ideograph", "Ideographic"},
    15693: {"Unified_Ideograph", "Ideographic"},
    15694: {"Unified_Ideograph", "Ideographic"},
    15695: {"Unified_Ideograph", "Ideographic"},
    15696: {"Unified_Ideograph", "Ideographic"},
    15697: {"Unified_Ideograph", "Ideographic"},
    15698: {"Unified_Ideograph", "Ideographic"},
    15699: {"Unified_Ideograph", "Ideographic"},
    15700: {"Unified_Ideograph", "Ideographic"},
    15701: {"Unified_Ideograph", "Ideographic"},
    15702: {"Unified_Ideograph", "Ideographic"},
    15703: {"Unified_Ideograph", "Ideographic"},
    15704: {"Unified_Ideograph", "Ideographic"},
    15705: {"Unified_Ideograph", "Ideographic"},
    15706: {"Unified_Ideograph", "Ideographic"},
    15707: {"Unified_Ideograph", "Ideographic"},
    15708: {"Unified_Ideograph", "Ideographic"},
    15709: {"Unified_Ideograph", "Ideographic"},
    15710: {"Unified_Ideograph", "Ideographic"},
    15711: {"Unified_Ideograph", "Ideographic"},
    15712: {"Unified_Ideograph", "Ideographic"},
    15713: {"Unified_Ideograph", "Ideographic"},
    15714: {"Unified_Ideograph", "Ideographic"},
    15715: {"Unified_Ideograph", "Ideographic"},
    15716: {"Unified_Ideograph", "Ideographic"},
    15717: {"Unified_Ideograph", "Ideographic"},
    15718: {"Unified_Ideograph", "Ideographic"},
    15719: {"Unified_Ideograph", "Ideographic"},
    15720: {"Unified_Ideograph", "Ideographic"},
    15721: {"Unified_Ideograph", "Ideographic"},
    15722: {"Unified_Ideograph", "Ideographic"},
    15723: {"Unified_Ideograph", "Ideographic"},
    15724: {"Unified_Ideograph", "Ideographic"},
    15725: {"Unified_Ideograph", "Ideographic"},
    15726: {"Unified_Ideograph", "Ideographic"},
    15727: {"Unified_Ideograph", "Ideographic"},
    15728: {"Unified_Ideograph", "Ideographic"},
    15729: {"Unified_Ideograph", "Ideographic"},
    15730: {"Unified_Ideograph", "Ideographic"},
    15731: {"Unified_Ideograph", "Ideographic"},
    15732: {"Unified_Ideograph", "Ideographic"},
    15733: {"Unified_Ideograph", "Ideographic"},
    15734: {"Unified_Ideograph", "Ideographic"},
    15735: {"Unified_Ideograph", "Ideographic"},
    15736: {"Unified_Ideograph", "Ideographic"},
    15737: {"Unified_Ideograph", "Ideographic"},
    15738: {"Unified_Ideograph", "Ideographic"},
    15739: {"Unified_Ideograph", "Ideographic"},
    15740: {"Unified_Ideograph", "Ideographic"},
    15741: {"Unified_Ideograph", "Ideographic"},
    15742: {"Unified_Ideograph", "Ideographic"},
    15743: {"Unified_Ideograph", "Ideographic"},
    15744: {"Unified_Ideograph", "Ideographic"},
    15745: {"Unified_Ideograph", "Ideographic"},
    15746: {"Unified_Ideograph", "Ideographic"},
    15747: {"Unified_Ideograph", "Ideographic"},
    15748: {"Unified_Ideograph", "Ideographic"},
    15749: {"Unified_Ideograph", "Ideographic"},
    15750: {"Unified_Ideograph", "Ideographic"},
    15751: {"Unified_Ideograph", "Ideographic"},
    15752: {"Unified_Ideograph", "Ideographic"},
    15753: {"Unified_Ideograph", "Ideographic"},
    15754: {"Unified_Ideograph", "Ideographic"},
    15755: {"Unified_Ideograph", "Ideographic"},
    15756: {"Unified_Ideograph", "Ideographic"},
    15757: {"Unified_Ideograph", "Ideographic"},
    15758: {"Unified_Ideograph", "Ideographic"},
    15759: {"Unified_Ideograph", "Ideographic"},
    15760: {"Unified_Ideograph", "Ideographic"},
    15761: {"Unified_Ideograph", "Ideographic"},
    15762: {"Unified_Ideograph", "Ideographic"},
    15763: {"Unified_Ideograph", "Ideographic"},
    15764: {"Unified_Ideograph", "Ideographic"},
    15765: {"Unified_Ideograph", "Ideographic"},
    15766: {"Unified_Ideograph", "Ideographic"},
    15767: {"Unified_Ideograph", "Ideographic"},
    15768: {"Unified_Ideograph", "Ideographic"},
    15769: {"Unified_Ideograph", "Ideographic"},
    15770: {"Unified_Ideograph", "Ideographic"},
    15771: {"Unified_Ideograph", "Ideographic"},
    15772: {"Unified_Ideograph", "Ideographic"},
    15773: {"Unified_Ideograph", "Ideographic"},
    15774: {"Unified_Ideograph", "Ideographic"},
    15775: {"Unified_Ideograph", "Ideographic"},
    15776: {"Unified_Ideograph", "Ideographic"},
    15777: {"Unified_Ideograph", "Ideographic"},
    15778: {"Unified_Ideograph", "Ideographic"},
    15779: {"Unified_Ideograph", "Ideographic"},
    15780: {"Unified_Ideograph", "Ideographic"},
    15781: {"Unified_Ideograph", "Ideographic"},
    15782: {"Unified_Ideograph", "Ideographic"},
    15783: {"Unified_Ideograph", "Ideographic"},
    15784: {"Unified_Ideograph", "Ideographic"},
    15785: {"Unified_Ideograph", "Ideographic"},
    15786: {"Unified_Ideograph", "Ideographic"},
    15787: {"Unified_Ideograph", "Ideographic"},
    15788: {"Unified_Ideograph", "Ideographic"},
    15789: {"Unified_Ideograph", "Ideographic"},
    15790: {"Unified_Ideograph", "Ideographic"},
    15791: {"Unified_Ideograph", "Ideographic"},
    15792: {"Unified_Ideograph", "Ideographic"},
    15793: {"Unified_Ideograph", "Ideographic"},
    15794: {"Unified_Ideograph", "Ideographic"},
    15795: {"Unified_Ideograph", "Ideographic"},
    15796: {"Unified_Ideograph", "Ideographic"},
    15797: {"Unified_Ideograph", "Ideographic"},
    15798: {"Unified_Ideograph", "Ideographic"},
    15799: {"Unified_Ideograph", "Ideographic"},
    15800: {"Unified_Ideograph", "Ideographic"},
    15801: {"Unified_Ideograph", "Ideographic"},
    15802: {"Unified_Ideograph", "Ideographic"},
    15803: {"Unified_Ideograph", "Ideographic"},
    15804: {"Unified_Ideograph", "Ideographic"},
    15805: {"Unified_Ideograph", "Ideographic"},
    15806: {"Unified_Ideograph", "Ideographic"},
    15807: {"Unified_Ideograph", "Ideographic"},
    15808: {"Unified_Ideograph", "Ideographic"},
    15809: {"Unified_Ideograph", "Ideographic"},
    15810: {"Unified_Ideograph", "Ideographic"},
    15811: {"Unified_Ideograph", "Ideographic"},
    15812: {"Unified_Ideograph", "Ideographic"},
    15813: {"Unified_Ideograph", "Ideographic"},
    15814: {"Unified_Ideograph", "Ideographic"},
    15815: {"Unified_Ideograph", "Ideographic"},
    15816: {"Unified_Ideograph", "Ideographic"},
    15817: {"Unified_Ideograph", "Ideographic"},
    15818: {"Unified_Ideograph", "Ideographic"},
    15819: {"Unified_Ideograph", "Ideographic"},
    15820: {"Unified_Ideograph", "Ideographic"},
    15821: {"Unified_Ideograph", "Ideographic"},
    15822: {"Unified_Ideograph", "Ideographic"},
    15823: {"Unified_Ideograph", "Ideographic"},
    15824: {"Unified_Ideograph", "Ideographic"},
    15825: {"Unified_Ideograph", "Ideographic"},
    15826: {"Unified_Ideograph", "Ideographic"},
    15827: {"Unified_Ideograph", "Ideographic"},
    15828: {"Unified_Ideograph", "Ideographic"},
    15829: {"Unified_Ideograph", "Ideographic"},
    15830: {"Unified_Ideograph", "Ideographic"},
    15831: {"Unified_Ideograph", "Ideographic"},
    15832: {"Unified_Ideograph", "Ideographic"},
    15833: {"Unified_Ideograph", "Ideographic"},
    15834: {"Unified_Ideograph", "Ideographic"},
    15835: {"Unified_Ideograph", "Ideographic"},
    15836: {"Unified_Ideograph", "Ideographic"},
    15837: {"Unified_Ideograph", "Ideographic"},
    15838: {"Unified_Ideograph", "Ideographic"},
    15839: {"Unified_Ideograph", "Ideographic"},
    15840: {"Unified_Ideograph", "Ideographic"},
    15841: {"Unified_Ideograph", "Ideographic"},
    15842: {"Unified_Ideograph", "Ideographic"},
    15843: {"Unified_Ideograph", "Ideographic"},
    15844: {"Unified_Ideograph", "Ideographic"},
    15845: {"Unified_Ideograph", "Ideographic"},
    15846: {"Unified_Ideograph", "Ideographic"},
    15847: {"Unified_Ideograph", "Ideographic"},
    15848: {"Unified_Ideograph", "Ideographic"},
    15849: {"Unified_Ideograph", "Ideographic"},
    15850: {"Unified_Ideograph", "Ideographic"},
    15851: {"Unified_Ideograph", "Ideographic"},
    15852: {"Unified_Ideograph", "Ideographic"},
    15853: {"Unified_Ideograph", "Ideographic"},
    15854: {"Unified_Ideograph", "Ideographic"},
    15855: {"Unified_Ideograph", "Ideographic"},
    15856: {"Unified_Ideograph", "Ideographic"},
    15857: {"Unified_Ideograph", "Ideographic"},
    15858: {"Unified_Ideograph", "Ideographic"},
    15859: {"Unified_Ideograph", "Ideographic"},
    15860: {"Unified_Ideograph", "Ideographic"},
    15861: {"Unified_Ideograph", "Ideographic"},
    15862: {"Unified_Ideograph", "Ideographic"},
    15863: {"Unified_Ideograph", "Ideographic"},
    15864: {"Unified_Ideograph", "Ideographic"},
    15865: {"Unified_Ideograph", "Ideographic"},
    15866: {"Unified_Ideograph", "Ideographic"},
    15867: {"Unified_Ideograph", "Ideographic"},
    15868: {"Unified_Ideograph", "Ideographic"},
    15869: {"Unified_Ideograph", "Ideographic"},
    15870: {"Unified_Ideograph", "Ideographic"},
    15871: {"Unified_Ideograph", "Ideographic"},
    15872: {"Unified_Ideograph", "Ideographic"},
    15873: {"Unified_Ideograph", "Ideographic"},
    15874: {"Unified_Ideograph", "Ideographic"},
    15875: {"Unified_Ideograph", "Ideographic"},
    15876: {"Unified_Ideograph", "Ideographic"},
    15877: {"Unified_Ideograph", "Ideographic"},
    15878: {"Unified_Ideograph", "Ideographic"},
    15879: {"Unified_Ideograph", "Ideographic"},
    15880: {"Unified_Ideograph", "Ideographic"},
    15881: {"Unified_Ideograph", "Ideographic"},
    15882: {"Unified_Ideograph", "Ideographic"},
    15883: {"Unified_Ideograph", "Ideographic"},
    15884: {"Unified_Ideograph", "Ideographic"},
    15885: {"Unified_Ideograph", "Ideographic"},
    15886: {"Unified_Ideograph", "Ideographic"},
    15887: {"Unified_Ideograph", "Ideographic"},
    15888: {"Unified_Ideograph", "Ideographic"},
    15889: {"Unified_Ideograph", "Ideographic"},
    15890: {"Unified_Ideograph", "Ideographic"},
    15891: {"Unified_Ideograph", "Ideographic"},
    15892: {"Unified_Ideograph", "Ideographic"},
    15893: {"Unified_Ideograph", "Ideographic"},
    15894: {"Unified_Ideograph", "Ideographic"},
    15895: {"Unified_Ideograph", "Ideographic"},
    15896: {"Unified_Ideograph", "Ideographic"},
    15897: {"Unified_Ideograph", "Ideographic"},
    15898: {"Unified_Ideograph", "Ideographic"},
    15899: {"Unified_Ideograph", "Ideographic"},
    15900: {"Unified_Ideograph", "Ideographic"},
    15901: {"Unified_Ideograph", "Ideographic"},
    15902: {"Unified_Ideograph", "Ideographic"},
    15903: {"Unified_Ideograph", "Ideographic"},
    15904: {"Unified_Ideograph", "Ideographic"},
    15905: {"Unified_Ideograph", "Ideographic"},
    15906: {"Unified_Ideograph", "Ideographic"},
    15907: {"Unified_Ideograph", "Ideographic"},
    15908: {"Unified_Ideograph", "Ideographic"},
    15909: {"Unified_Ideograph", "Ideographic"},
    15910: {"Unified_Ideograph", "Ideographic"},
    15911: {"Unified_Ideograph", "Ideographic"},
    15912: {"Unified_Ideograph", "Ideographic"},
    15913: {"Unified_Ideograph", "Ideographic"},
    15914: {"Unified_Ideograph", "Ideographic"},
    15915: {"Unified_Ideograph", "Ideographic"},
    15916: {"Unified_Ideograph", "Ideographic"},
    15917: {"Unified_Ideograph", "Ideographic"},
    15918: {"Unified_Ideograph", "Ideographic"},
    15919: {"Unified_Ideograph", "Ideographic"},
    15920: {"Unified_Ideograph", "Ideographic"},
    15921: {"Unified_Ideograph", "Ideographic"},
    15922: {"Unified_Ideograph", "Ideographic"},
    15923: {"Unified_Ideograph", "Ideographic"},
    15924: {"Unified_Ideograph", "Ideographic"},
    15925: {"Unified_Ideograph", "Ideographic"},
    15926: {"Unified_Ideograph", "Ideographic"},
    15927: {"Unified_Ideograph", "Ideographic"},
    15928: {"Unified_Ideograph", "Ideographic"},
    15929: {"Unified_Ideograph", "Ideographic"},
    15930: {"Unified_Ideograph", "Ideographic"},
    15931: {"Unified_Ideograph", "Ideographic"},
    15932: {"Unified_Ideograph", "Ideographic"},
    15933: {"Unified_Ideograph", "Ideographic"},
    15934: {"Unified_Ideograph", "Ideographic"},
    15935: {"Unified_Ideograph", "Ideographic"},
    15936: {"Unified_Ideograph", "Ideographic"},
    15937: {"Unified_Ideograph", "Ideographic"},
    15938: {"Unified_Ideograph", "Ideographic"},
    15939: {"Unified_Ideograph", "Ideographic"},
    15940: {"Unified_Ideograph", "Ideographic"},
    15941: {"Unified_Ideograph", "Ideographic"},
    15942: {"Unified_Ideograph", "Ideographic"},
    15943: {"Unified_Ideograph", "Ideographic"},
    15944: {"Unified_Ideograph", "Ideographic"},
    15945: {"Unified_Ideograph", "Ideographic"},
    15946: {"Unified_Ideograph", "Ideographic"},
    15947: {"Unified_Ideograph", "Ideographic"},
    15948: {"Unified_Ideograph", "Ideographic"},
    15949: {"Unified_Ideograph", "Ideographic"},
    15950: {"Unified_Ideograph", "Ideographic"},
    15951: {"Unified_Ideograph", "Ideographic"},
    15952: {"Unified_Ideograph", "Ideographic"},
    15953: {"Unified_Ideograph", "Ideographic"},
    15954: {"Unified_Ideograph", "Ideographic"},
    15955: {"Unified_Ideograph", "Ideographic"},
    15956: {"Unified_Ideograph", "Ideographic"},
    15957: {"Unified_Ideograph", "Ideographic"},
    15958: {"Unified_Ideograph", "Ideographic"},
    15959: {"Unified_Ideograph", "Ideographic"},
    15960: {"Unified_Ideograph", "Ideographic"},
    15961: {"Unified_Ideograph", "Ideographic"},
    15962: {"Unified_Ideograph", "Ideographic"},
    15963: {"Unified_Ideograph", "Ideographic"},
    15964: {"Unified_Ideograph", "Ideographic"},
    15965: {"Unified_Ideograph", "Ideographic"},
    15966: {"Unified_Ideograph", "Ideographic"},
    15967: {"Unified_Ideograph", "Ideographic"},
    15968: {"Unified_Ideograph", "Ideographic"},
    15969: {"Unified_Ideograph", "Ideographic"},
    15970: {"Unified_Ideograph", "Ideographic"},
    15971: {"Unified_Ideograph", "Ideographic"},
    15972: {"Unified_Ideograph", "Ideographic"},
    15973: {"Unified_Ideograph", "Ideographic"},
    15974: {"Unified_Ideograph", "Ideographic"},
    15975: {"Unified_Ideograph", "Ideographic"},
    15976: {"Unified_Ideograph", "Ideographic"},
    15977: {"Unified_Ideograph", "Ideographic"},
    15978: {"Unified_Ideograph", "Ideographic"},
    15979: {"Unified_Ideograph", "Ideographic"},
    15980: {"Unified_Ideograph", "Ideographic"},
    15981: {"Unified_Ideograph", "Ideographic"},
    15982: {"Unified_Ideograph", "Ideographic"},
    15983: {"Unified_Ideograph", "Ideographic"},
    15984: {"Unified_Ideograph", "Ideographic"},
    15985: {"Unified_Ideograph", "Ideographic"},
    15986: {"Unified_Ideograph", "Ideographic"},
    15987: {"Unified_Ideograph", "Ideographic"},
    15988: {"Unified_Ideograph", "Ideographic"},
    15989: {"Unified_Ideograph", "Ideographic"},
    15990: {"Unified_Ideograph", "Ideographic"},
    15991: {"Unified_Ideograph", "Ideographic"},
    15992: {"Unified_Ideograph", "Ideographic"},
    15993: {"Unified_Ideograph", "Ideographic"},
    15994: {"Unified_Ideograph", "Ideographic"},
    15995: {"Unified_Ideograph", "Ideographic"},
    15996: {"Unified_Ideograph", "Ideographic"},
    15997: {"Unified_Ideograph", "Ideographic"},
    15998: {"Unified_Ideograph", "Ideographic"},
    15999: {"Unified_Ideograph", "Ideographic"},
    16000: {"Unified_Ideograph", "Ideographic"},
    16001: {"Unified_Ideograph", "Ideographic"},
    16002: {"Unified_Ideograph", "Ideographic"},
    16003: {"Unified_Ideograph", "Ideographic"},
    16004: {"Unified_Ideograph", "Ideographic"},
    16005: {"Unified_Ideograph", "Ideographic"},
    16006: {"Unified_Ideograph", "Ideographic"},
    16007: {"Unified_Ideograph", "Ideographic"},
    16008: {"Unified_Ideograph", "Ideographic"},
    16009: {"Unified_Ideograph", "Ideographic"},
    16010: {"Unified_Ideograph", "Ideographic"},
    16011: {"Unified_Ideograph", "Ideographic"},
    16012: {"Unified_Ideograph", "Ideographic"},
    16013: {"Unified_Ideograph", "Ideographic"},
    16014: {"Unified_Ideograph", "Ideographic"},
    16015: {"Unified_Ideograph", "Ideographic"},
    16016: {"Unified_Ideograph", "Ideographic"},
    16017: {"Unified_Ideograph", "Ideographic"},
    16018: {"Unified_Ideograph", "Ideographic"},
    16019: {"Unified_Ideograph", "Ideographic"},
    16020: {"Unified_Ideograph", "Ideographic"},
    16021: {"Unified_Ideograph", "Ideographic"},
    16022: {"Unified_Ideograph", "Ideographic"},
    16023: {"Unified_Ideograph", "Ideographic"},
    16024: {"Unified_Ideograph", "Ideographic"},
    16025: {"Unified_Ideograph", "Ideographic"},
    16026: {"Unified_Ideograph", "Ideographic"},
    16027: {"Unified_Ideograph", "Ideographic"},
    16028: {"Unified_Ideograph", "Ideographic"},
    16029: {"Unified_Ideograph", "Ideographic"},
    16030: {"Unified_Ideograph", "Ideographic"},
    16031: {"Unified_Ideograph", "Ideographic"},
    16032: {"Unified_Ideograph", "Ideographic"},
    16033: {"Unified_Ideograph", "Ideographic"},
    16034: {"Unified_Ideograph", "Ideographic"},
    16035: {"Unified_Ideograph", "Ideographic"},
    16036: {"Unified_Ideograph", "Ideographic"},
    16037: {"Unified_Ideograph", "Ideographic"},
    16038: {"Unified_Ideograph", "Ideographic"},
    16039: {"Unified_Ideograph", "Ideographic"},
    16040: {"Unified_Ideograph", "Ideographic"},
    16041: {"Unified_Ideograph", "Ideographic"},
    16042: {"Unified_Ideograph", "Ideographic"},
    16043: {"Unified_Ideograph", "Ideographic"},
    16044: {"Unified_Ideograph", "Ideographic"},
    16045: {"Unified_Ideograph", "Ideographic"},
    16046: {"Unified_Ideograph", "Ideographic"},
    16047: {"Unified_Ideograph", "Ideographic"},
    16048: {"Unified_Ideograph", "Ideographic"},
    16049: {"Unified_Ideograph", "Ideographic"},
    16050: {"Unified_Ideograph", "Ideographic"},
    16051: {"Unified_Ideograph", "Ideographic"},
    16052: {"Unified_Ideograph", "Ideographic"},
    16053: {"Unified_Ideograph", "Ideographic"},
    16054: {"Unified_Ideograph", "Ideographic"},
    16055: {"Unified_Ideograph", "Ideographic"},
    16056: {"Unified_Ideograph", "Ideographic"},
    16057: {"Unified_Ideograph", "Ideographic"},
    16058: {"Unified_Ideograph", "Ideographic"},
    16059: {"Unified_Ideograph", "Ideographic"},
    16060: {"Unified_Ideograph", "Ideographic"},
    16061: {"Unified_Ideograph", "Ideographic"},
    16062: {"Unified_Ideograph", "Ideographic"},
    16063: {"Unified_Ideograph", "Ideographic"},
    16064: {"Unified_Ideograph", "Ideographic"},
    16065: {"Unified_Ideograph", "Ideographic"},
    16066: {"Unified_Ideograph", "Ideographic"},
    16067: {"Unified_Ideograph", "Ideographic"},
    16068: {"Unified_Ideograph", "Ideographic"},
    16069: {"Unified_Ideograph", "Ideographic"},
    16070: {"Unified_Ideograph", "Ideographic"},
    16071: {"Unified_Ideograph", "Ideographic"},
    16072: {"Unified_Ideograph", "Ideographic"},
    16073: {"Unified_Ideograph", "Ideographic"},
    16074: {"Unified_Ideograph", "Ideographic"},
    16075: {"Unified_Ideograph", "Ideographic"},
    16076: {"Unified_Ideograph", "Ideographic"},
    16077: {"Unified_Ideograph", "Ideographic"},
    16078: {"Unified_Ideograph", "Ideographic"},
    16079: {"Unified_Ideograph", "Ideographic"},
    16080: {"Unified_Ideograph", "Ideographic"},
    16081: {"Unified_Ideograph", "Ideographic"},
    16082: {"Unified_Ideograph", "Ideographic"},
    16083: {"Unified_Ideograph", "Ideographic"},
    16084: {"Unified_Ideograph", "Ideographic"},
    16085: {"Unified_Ideograph", "Ideographic"},
    16086: {"Unified_Ideograph", "Ideographic"},
    16087: {"Unified_Ideograph", "Ideographic"},
    16088: {"Unified_Ideograph", "Ideographic"},
    16089: {"Unified_Ideograph", "Ideographic"},
    16090: {"Unified_Ideograph", "Ideographic"},
    16091: {"Unified_Ideograph", "Ideographic"},
    16092: {"Unified_Ideograph", "Ideographic"},
    16093: {"Unified_Ideograph", "Ideographic"},
    16094: {"Unified_Ideograph", "Ideographic"},
    16095: {"Unified_Ideograph", "Ideographic"},
    16096: {"Unified_Ideograph", "Ideographic"},
    16097: {"Unified_Ideograph", "Ideographic"},
    16098: {"Unified_Ideograph", "Ideographic"},
    16099: {"Unified_Ideograph", "Ideographic"},
    16100: {"Unified_Ideograph", "Ideographic"},
    16101: {"Unified_Ideograph", "Ideographic"},
    16102: {"Unified_Ideograph", "Ideographic"},
    16103: {"Unified_Ideograph", "Ideographic"},
    16104: {"Unified_Ideograph", "Ideographic"},
    16105: {"Unified_Ideograph", "Ideographic"},
    16106: {"Unified_Ideograph", "Ideographic"},
    16107: {"Unified_Ideograph", "Ideographic"},
    16108: {"Unified_Ideograph", "Ideographic"},
    16109: {"Unified_Ideograph", "Ideographic"},
    16110: {"Unified_Ideograph", "Ideographic"},
    16111: {"Unified_Ideograph", "Ideographic"},
    16112: {"Unified_Ideograph", "Ideographic"},
    16113: {"Unified_Ideograph", "Ideographic"},
    16114: {"Unified_Ideograph", "Ideographic"},
    16115: {"Unified_Ideograph", "Ideographic"},
    16116: {"Unified_Ideograph", "Ideographic"},
    16117: {"Unified_Ideograph", "Ideographic"},
    16118: {"Unified_Ideograph", "Ideographic"},
    16119: {"Unified_Ideograph", "Ideographic"},
    16120: {"Unified_Ideograph", "Ideographic"},
    16121: {"Unified_Ideograph", "Ideographic"},
    16122: {"Unified_Ideograph", "Ideographic"},
    16123: {"Unified_Ideograph", "Ideographic"},
    16124: {"Unified_Ideograph", "Ideographic"},
    16125: {"Unified_Ideograph", "Ideographic"},
    16126: {"Unified_Ideograph", "Ideographic"},
    16127: {"Unified_Ideograph", "Ideographic"},
    16128: {"Unified_Ideograph", "Ideographic"},
    16129: {"Unified_Ideograph", "Ideographic"},
    16130: {"Unified_Ideograph", "Ideographic"},
    16131: {"Unified_Ideograph", "Ideographic"},
    16132: {"Unified_Ideograph", "Ideographic"},
    16133: {"Unified_Ideograph", "Ideographic"},
    16134: {"Unified_Ideograph", "Ideographic"},
    16135: {"Unified_Ideograph", "Ideographic"},
    16136: {"Unified_Ideograph", "Ideographic"},
    16137: {"Unified_Ideograph", "Ideographic"},
    16138: {"Unified_Ideograph", "Ideographic"},
    16139: {"Unified_Ideograph", "Ideographic"},
    16140: {"Unified_Ideograph", "Ideographic"},
    16141: {"Unified_Ideograph", "Ideographic"},
    16142: {"Unified_Ideograph", "Ideographic"},
    16143: {"Unified_Ideograph", "Ideographic"},
    16144: {"Unified_Ideograph", "Ideographic"},
    16145: {"Unified_Ideograph", "Ideographic"},
    16146: {"Unified_Ideograph", "Ideographic"},
    16147: {"Unified_Ideograph", "Ideographic"},
    16148: {"Unified_Ideograph", "Ideographic"},
    16149: {"Unified_Ideograph", "Ideographic"},
    16150: {"Unified_Ideograph", "Ideographic"},
    16151: {"Unified_Ideograph", "Ideographic"},
    16152: {"Unified_Ideograph", "Ideographic"},
    16153: {"Unified_Ideograph", "Ideographic"},
    16154: {"Unified_Ideograph", "Ideographic"},
    16155: {"Unified_Ideograph", "Ideographic"},
    16156: {"Unified_Ideograph", "Ideographic"},
    16157: {"Unified_Ideograph", "Ideographic"},
    16158: {"Unified_Ideograph", "Ideographic"},
    16159: {"Unified_Ideograph", "Ideographic"},
    16160: {"Unified_Ideograph", "Ideographic"},
    16161: {"Unified_Ideograph", "Ideographic"},
    16162: {"Unified_Ideograph", "Ideographic"},
    16163: {"Unified_Ideograph", "Ideographic"},
    16164: {"Unified_Ideograph", "Ideographic"},
    16165: {"Unified_Ideograph", "Ideographic"},
    16166: {"Unified_Ideograph", "Ideographic"},
    16167: {"Unified_Ideograph", "Ideographic"},
    16168: {"Unified_Ideograph", "Ideographic"},
    16169: {"Unified_Ideograph", "Ideographic"},
    16170: {"Unified_Ideograph", "Ideographic"},
    16171: {"Unified_Ideograph", "Ideographic"},
    16172: {"Unified_Ideograph", "Ideographic"},
    16173: {"Unified_Ideograph", "Ideographic"},
    16174: {"Unified_Ideograph", "Ideographic"},
    16175: {"Unified_Ideograph", "Ideographic"},
    16176: {"Unified_Ideograph", "Ideographic"},
    16177: {"Unified_Ideograph", "Ideographic"},
    16178: {"Unified_Ideograph", "Ideographic"},
    16179: {"Unified_Ideograph", "Ideographic"},
    16180: {"Unified_Ideograph", "Ideographic"},
    16181: {"Unified_Ideograph", "Ideographic"},
    16182: {"Unified_Ideograph", "Ideographic"},
    16183: {"Unified_Ideograph", "Ideographic"},
    16184: {"Unified_Ideograph", "Ideographic"},
    16185: {"Unified_Ideograph", "Ideographic"},
    16186: {"Unified_Ideograph", "Ideographic"},
    16187: {"Unified_Ideograph", "Ideographic"},
    16188: {"Unified_Ideograph", "Ideographic"},
    16189: {"Unified_Ideograph", "Ideographic"},
    16190: {"Unified_Ideograph", "Ideographic"},
    16191: {"Unified_Ideograph", "Ideographic"},
    16192: {"Unified_Ideograph", "Ideographic"},
    16193: {"Unified_Ideograph", "Ideographic"},
    16194: {"Unified_Ideograph", "Ideographic"},
    16195: {"Unified_Ideograph", "Ideographic"},
    16196: {"Unified_Ideograph", "Ideographic"},
    16197: {"Unified_Ideograph", "Ideographic"},
    16198: {"Unified_Ideograph", "Ideographic"},
    16199: {"Unified_Ideograph", "Ideographic"},
    16200: {"Unified_Ideograph", "Ideographic"},
    16201: {"Unified_Ideograph", "Ideographic"},
    16202: {"Unified_Ideograph", "Ideographic"},
    16203: {"Unified_Ideograph", "Ideographic"},
    16204: {"Unified_Ideograph", "Ideographic"},
    16205: {"Unified_Ideograph", "Ideographic"},
    16206: {"Unified_Ideograph", "Ideographic"},
    16207: {"Unified_Ideograph", "Ideographic"},
    16208: {"Unified_Ideograph", "Ideographic"},
    16209: {"Unified_Ideograph", "Ideographic"},
    16210: {"Unified_Ideograph", "Ideographic"},
    16211: {"Unified_Ideograph", "Ideographic"},
    16212: {"Unified_Ideograph", "Ideographic"},
    16213: {"Unified_Ideograph", "Ideographic"},
    16214: {"Unified_Ideograph", "Ideographic"},
    16215: {"Unified_Ideograph", "Ideographic"},
    16216: {"Unified_Ideograph", "Ideographic"},
    16217: {"Unified_Ideograph", "Ideographic"},
    16218: {"Unified_Ideograph", "Ideographic"},
    16219: {"Unified_Ideograph", "Ideographic"},
    16220: {"Unified_Ideograph", "Ideographic"},
    16221: {"Unified_Ideograph", "Ideographic"},
    16222: {"Unified_Ideograph", "Ideographic"},
    16223: {"Unified_Ideograph", "Ideographic"},
    16224: {"Unified_Ideograph", "Ideographic"},
    16225: {"Unified_Ideograph", "Ideographic"},
    16226: {"Unified_Ideograph", "Ideographic"},
    16227: {"Unified_Ideograph", "Ideographic"},
    16228: {"Unified_Ideograph", "Ideographic"},
    16229: {"Unified_Ideograph", "Ideographic"},
    16230: {"Unified_Ideograph", "Ideographic"},
    16231: {"Unified_Ideograph", "Ideographic"},
    16232: {"Unified_Ideograph", "Ideographic"},
    16233: {"Unified_Ideograph", "Ideographic"},
    16234: {"Unified_Ideograph", "Ideographic"},
    16235: {"Unified_Ideograph", "Ideographic"},
    16236: {"Unified_Ideograph", "Ideographic"},
    16237: {"Unified_Ideograph", "Ideographic"},
    16238: {"Unified_Ideograph", "Ideographic"},
    16239: {"Unified_Ideograph", "Ideographic"},
    16240: {"Unified_Ideograph", "Ideographic"},
    16241: {"Unified_Ideograph", "Ideographic"},
    16242: {"Unified_Ideograph", "Ideographic"},
    16243: {"Unified_Ideograph", "Ideographic"},
    16244: {"Unified_Ideograph", "Ideographic"},
    16245: {"Unified_Ideograph", "Ideographic"},
    16246: {"Unified_Ideograph", "Ideographic"},
    16247: {"Unified_Ideograph", "Ideographic"},
    16248: {"Unified_Ideograph", "Ideographic"},
    16249: {"Unified_Ideograph", "Ideographic"},
    16250: {"Unified_Ideograph", "Ideographic"},
    16251: {"Unified_Ideograph", "Ideographic"},
    16252: {"Unified_Ideograph", "Ideographic"},
    16253: {"Unified_Ideograph", "Ideographic"},
    16254: {"Unified_Ideograph", "Ideographic"},
    16255: {"Unified_Ideograph", "Ideographic"},
    16256: {"Unified_Ideograph", "Ideographic"},
    16257: {"Unified_Ideograph", "Ideographic"},
    16258: {"Unified_Ideograph", "Ideographic"},
    16259: {"Unified_Ideograph", "Ideographic"},
    16260: {"Unified_Ideograph", "Ideographic"},
    16261: {"Unified_Ideograph", "Ideographic"},
    16262: {"Unified_Ideograph", "Ideographic"},
    16263: {"Unified_Ideograph", "Ideographic"},
    16264: {"Unified_Ideograph", "Ideographic"},
    16265: {"Unified_Ideograph", "Ideographic"},
    16266: {"Unified_Ideograph", "Ideographic"},
    16267: {"Unified_Ideograph", "Ideographic"},
    16268: {"Unified_Ideograph", "Ideographic"},
    16269: {"Unified_Ideograph", "Ideographic"},
    16270: {"Unified_Ideograph", "Ideographic"},
    16271: {"Unified_Ideograph", "Ideographic"},
    16272: {"Unified_Ideograph", "Ideographic"},
    16273: {"Unified_Ideograph", "Ideographic"},
    16274: {"Unified_Ideograph", "Ideographic"},
    16275: {"Unified_Ideograph", "Ideographic"},
    16276: {"Unified_Ideograph", "Ideographic"},
    16277: {"Unified_Ideograph", "Ideographic"},
    16278: {"Unified_Ideograph", "Ideographic"},
    16279: {"Unified_Ideograph", "Ideographic"},
    16280: {"Unified_Ideograph", "Ideographic"},
    16281: {"Unified_Ideograph", "Ideographic"},
    16282: {"Unified_Ideograph", "Ideographic"},
    16283: {"Unified_Ideograph", "Ideographic"},
    16284: {"Unified_Ideograph", "Ideographic"},
    16285: {"Unified_Ideograph", "Ideographic"},
    16286: {"Unified_Ideograph", "Ideographic"},
    16287: {"Unified_Ideograph", "Ideographic"},
    16288: {"Unified_Ideograph", "Ideographic"},
    16289: {"Unified_Ideograph", "Ideographic"},
    16290: {"Unified_Ideograph", "Ideographic"},
    16291: {"Unified_Ideograph", "Ideographic"},
    16292: {"Unified_Ideograph", "Ideographic"},
    16293: {"Unified_Ideograph", "Ideographic"},
    16294: {"Unified_Ideograph", "Ideographic"},
    16295: {"Unified_Ideograph", "Ideographic"},
    16296: {"Unified_Ideograph", "Ideographic"},
    16297: {"Unified_Ideograph", "Ideographic"},
    16298: {"Unified_Ideograph", "Ideographic"},
    16299: {"Unified_Ideograph", "Ideographic"},
    16300: {"Unified_Ideograph", "Ideographic"},
    16301: {"Unified_Ideograph", "Ideographic"},
    16302: {"Unified_Ideograph", "Ideographic"},
    16303: {"Unified_Ideograph", "Ideographic"},
    16304: {"Unified_Ideograph", "Ideographic"},
    16305: {"Unified_Ideograph", "Ideographic"},
    16306: {"Unified_Ideograph", "Ideographic"},
    16307: {"Unified_Ideograph", "Ideographic"},
    16308: {"Unified_Ideograph", "Ideographic"},
    16309: {"Unified_Ideograph", "Ideographic"},
    16310: {"Unified_Ideograph", "Ideographic"},
    16311: {"Unified_Ideograph", "Ideographic"},
    16312: {"Unified_Ideograph", "Ideographic"},
    16313: {"Unified_Ideograph", "Ideographic"},
    16314: {"Unified_Ideograph", "Ideographic"},
    16315: {"Unified_Ideograph", "Ideographic"},
    16316: {"Unified_Ideograph", "Ideographic"},
    16317: {"Unified_Ideograph", "Ideographic"},
    16318: {"Unified_Ideograph", "Ideographic"},
    16319: {"Unified_Ideograph", "Ideographic"},
    16320: {"Unified_Ideograph", "Ideographic"},
    16321: {"Unified_Ideograph", "Ideographic"},
    16322: {"Unified_Ideograph", "Ideographic"},
    16323: {"Unified_Ideograph", "Ideographic"},
    16324: {"Unified_Ideograph", "Ideographic"},
    16325: {"Unified_Ideograph", "Ideographic"},
    16326: {"Unified_Ideograph", "Ideographic"},
    16327: {"Unified_Ideograph", "Ideographic"},
    16328: {"Unified_Ideograph", "Ideographic"},
    16329: {"Unified_Ideograph", "Ideographic"},
    16330: {"Unified_Ideograph", "Ideographic"},
    16331: {"Unified_Ideograph", "Ideographic"},
    16332: {"Unified_Ideograph", "Ideographic"},
    16333: {"Unified_Ideograph", "Ideographic"},
    16334: {"Unified_Ideograph", "Ideographic"},
    16335: {"Unified_Ideograph", "Ideographic"},
    16336: {"Unified_Ideograph", "Ideographic"},
    16337: {"Unified_Ideograph", "Ideographic"},
    16338: {"Unified_Ideograph", "Ideographic"},
    16339: {"Unified_Ideograph", "Ideographic"},
    16340: {"Unified_Ideograph", "Ideographic"},
    16341: {"Unified_Ideograph", "Ideographic"},
    16342: {"Unified_Ideograph", "Ideographic"},
    16343: {"Unified_Ideograph", "Ideographic"},
    16344: {"Unified_Ideograph", "Ideographic"},
    16345: {"Unified_Ideograph", "Ideographic"},
    16346: {"Unified_Ideograph", "Ideographic"},
    16347: {"Unified_Ideograph", "Ideographic"},
    16348: {"Unified_Ideograph", "Ideographic"},
    16349: {"Unified_Ideograph", "Ideographic"},
    16350: {"Unified_Ideograph", "Ideographic"},
    16351: {"Unified_Ideograph", "Ideographic"},
    16352: {"Unified_Ideograph", "Ideographic"},
    16353: {"Unified_Ideograph", "Ideographic"},
    16354: {"Unified_Ideograph", "Ideographic"},
    16355: {"Unified_Ideograph", "Ideographic"},
    16356: {"Unified_Ideograph", "Ideographic"},
    16357: {"Unified_Ideograph", "Ideographic"},
    16358: {"Unified_Ideograph", "Ideographic"},
    16359: {"Unified_Ideograph", "Ideographic"},
    16360: {"Unified_Ideograph", "Ideographic"},
    16361: {"Unified_Ideograph", "Ideographic"},
    16362: {"Unified_Ideograph", "Ideographic"},
    16363: {"Unified_Ideograph", "Ideographic"},
    16364: {"Unified_Ideograph", "Ideographic"},
    16365: {"Unified_Ideograph", "Ideographic"},
    16366: {"Unified_Ideograph", "Ideographic"},
    16367: {"Unified_Ideograph", "Ideographic"},
    16368: {"Unified_Ideograph", "Ideographic"},
    16369: {"Unified_Ideograph", "Ideographic"},
    16370: {"Unified_Ideograph", "Ideographic"},
    16371: {"Unified_Ideograph", "Ideographic"},
    16372: {"Unified_Ideograph", "Ideographic"},
    16373: {"Unified_Ideograph", "Ideographic"},
    16374: {"Unified_Ideograph", "Ideographic"},
    16375: {"Unified_Ideograph", "Ideographic"},
    16376: {"Unified_Ideograph", "Ideographic"},
    16377: {"Unified_Ideograph", "Ideographic"},
    16378: {"Unified_Ideograph", "Ideographic"},
    16379: {"Unified_Ideograph", "Ideographic"},
    16380: {"Unified_Ideograph", "Ideographic"},
    16381: {"Unified_Ideograph", "Ideographic"},
    16382: {"Unified_Ideograph", "Ideographic"},
    16383: {"Unified_Ideograph", "Ideographic"},
    16384: {"Unified_Ideograph", "Ideographic"},
    16385: {"Unified_Ideograph", "Ideographic"},
    16386: {"Unified_Ideograph", "Ideographic"},
    16387: {"Unified_Ideograph", "Ideographic"},
    16388: {"Unified_Ideograph", "Ideographic"},
    16389: {"Unified_Ideograph", "Ideographic"},
    16390: {"Unified_Ideograph", "Ideographic"},
    16391: {"Unified_Ideograph", "Ideographic"},
    16392: {"Unified_Ideograph", "Ideographic"},
    16393: {"Unified_Ideograph", "Ideographic"},
    16394: {"Unified_Ideograph", "Ideographic"},
    16395: {"Unified_Ideograph", "Ideographic"},
    16396: {"Unified_Ideograph", "Ideographic"},
    16397: {"Unified_Ideograph", "Ideographic"},
    16398: {"Unified_Ideograph", "Ideographic"},
    16399: {"Unified_Ideograph", "Ideographic"},
    16400: {"Unified_Ideograph", "Ideographic"},
    16401: {"Unified_Ideograph", "Ideographic"},
    16402: {"Unified_Ideograph", "Ideographic"},
    16403: {"Unified_Ideograph", "Ideographic"},
    16404: {"Unified_Ideograph", "Ideographic"},
    16405: {"Unified_Ideograph", "Ideographic"},
    16406: {"Unified_Ideograph", "Ideographic"},
    16407: {"Unified_Ideograph", "Ideographic"},
    16408: {"Unified_Ideograph", "Ideographic"},
    16409: {"Unified_Ideograph", "Ideographic"},
    16410: {"Unified_Ideograph", "Ideographic"},
    16411: {"Unified_Ideograph", "Ideographic"},
    16412: {"Unified_Ideograph", "Ideographic"},
    16413: {"Unified_Ideograph", "Ideographic"},
    16414: {"Unified_Ideograph", "Ideographic"},
    16415: {"Unified_Ideograph", "Ideographic"},
    16416: {"Unified_Ideograph", "Ideographic"},
    16417: {"Unified_Ideograph", "Ideographic"},
    16418: {"Unified_Ideograph", "Ideographic"},
    16419: {"Unified_Ideograph", "Ideographic"},
    16420: {"Unified_Ideograph", "Ideographic"},
    16421: {"Unified_Ideograph", "Ideographic"},
    16422: {"Unified_Ideograph", "Ideographic"},
    16423: {"Unified_Ideograph", "Ideographic"},
    16424: {"Unified_Ideograph", "Ideographic"},
    16425: {"Unified_Ideograph", "Ideographic"},
    16426: {"Unified_Ideograph", "Ideographic"},
    16427: {"Unified_Ideograph", "Ideographic"},
    16428: {"Unified_Ideograph", "Ideographic"},
    16429: {"Unified_Ideograph", "Ideographic"},
    16430: {"Unified_Ideograph", "Ideographic"},
    16431: {"Unified_Ideograph", "Ideographic"},
    16432: {"Unified_Ideograph", "Ideographic"},
    16433: {"Unified_Ideograph", "Ideographic"},
    16434: {"Unified_Ideograph", "Ideographic"},
    16435: {"Unified_Ideograph", "Ideographic"},
    16436: {"Unified_Ideograph", "Ideographic"},
    16437: {"Unified_Ideograph", "Ideographic"},
    16438: {"Unified_Ideograph", "Ideographic"},
    16439: {"Unified_Ideograph", "Ideographic"},
    16440: {"Unified_Ideograph", "Ideographic"},
    16441: {"Unified_Ideograph", "Ideographic"},
    16442: {"Unified_Ideograph", "Ideographic"},
    16443: {"Unified_Ideograph", "Ideographic"},
    16444: {"Unified_Ideograph", "Ideographic"},
    16445: {"Unified_Ideograph", "Ideographic"},
    16446: {"Unified_Ideograph", "Ideographic"},
    16447: {"Unified_Ideograph", "Ideographic"},
    16448: {"Unified_Ideograph", "Ideographic"},
    16449: {"Unified_Ideograph", "Ideographic"},
    16450: {"Unified_Ideograph", "Ideographic"},
    16451: {"Unified_Ideograph", "Ideographic"},
    16452: {"Unified_Ideograph", "Ideographic"},
    16453: {"Unified_Ideograph", "Ideographic"},
    16454: {"Unified_Ideograph", "Ideographic"},
    16455: {"Unified_Ideograph", "Ideographic"},
    16456: {"Unified_Ideograph", "Ideographic"},
    16457: {"Unified_Ideograph", "Ideographic"},
    16458: {"Unified_Ideograph", "Ideographic"},
    16459: {"Unified_Ideograph", "Ideographic"},
    16460: {"Unified_Ideograph", "Ideographic"},
    16461: {"Unified_Ideograph", "Ideographic"},
    16462: {"Unified_Ideograph", "Ideographic"},
    16463: {"Unified_Ideograph", "Ideographic"},
    16464: {"Unified_Ideograph", "Ideographic"},
    16465: {"Unified_Ideograph", "Ideographic"},
    16466: {"Unified_Ideograph", "Ideographic"},
    16467: {"Unified_Ideograph", "Ideographic"},
    16468: {"Unified_Ideograph", "Ideographic"},
    16469: {"Unified_Ideograph", "Ideographic"},
    16470: {"Unified_Ideograph", "Ideographic"},
    16471: {"Unified_Ideograph", "Ideographic"},
    16472: {"Unified_Ideograph", "Ideographic"},
    16473: {"Unified_Ideograph", "Ideographic"},
    16474: {"Unified_Ideograph", "Ideographic"},
    16475: {"Unified_Ideograph", "Ideographic"},
    16476: {"Unified_Ideograph", "Ideographic"},
    16477: {"Unified_Ideograph", "Ideographic"},
    16478: {"Unified_Ideograph", "Ideographic"},
    16479: {"Unified_Ideograph", "Ideographic"},
    16480: {"Unified_Ideograph", "Ideographic"},
    16481: {"Unified_Ideograph", "Ideographic"},
    16482: {"Unified_Ideograph", "Ideographic"},
    16483: {"Unified_Ideograph", "Ideographic"},
    16484: {"Unified_Ideograph", "Ideographic"},
    16485: {"Unified_Ideograph", "Ideographic"},
    16486: {"Unified_Ideograph", "Ideographic"},
    16487: {"Unified_Ideograph", "Ideographic"},
    16488: {"Unified_Ideograph", "Ideographic"},
    16489: {"Unified_Ideograph", "Ideographic"},
    16490: {"Unified_Ideograph", "Ideographic"},
    16491: {"Unified_Ideograph", "Ideographic"},
    16492: {"Unified_Ideograph", "Ideographic"},
    16493: {"Unified_Ideograph", "Ideographic"},
    16494: {"Unified_Ideograph", "Ideographic"},
    16495: {"Unified_Ideograph", "Ideographic"},
    16496: {"Unified_Ideograph", "Ideographic"},
    16497: {"Unified_Ideograph", "Ideographic"},
    16498: {"Unified_Ideograph", "Ideographic"},
    16499: {"Unified_Ideograph", "Ideographic"},
    16500: {"Unified_Ideograph", "Ideographic"},
    16501: {"Unified_Ideograph", "Ideographic"},
    16502: {"Unified_Ideograph", "Ideographic"},
    16503: {"Unified_Ideograph", "Ideographic"},
    16504: {"Unified_Ideograph", "Ideographic"},
    16505: {"Unified_Ideograph", "Ideographic"},
    16506: {"Unified_Ideograph", "Ideographic"},
    16507: {"Unified_Ideograph", "Ideographic"},
    16508: {"Unified_Ideograph", "Ideographic"},
    16509: {"Unified_Ideograph", "Ideographic"},
    16510: {"Unified_Ideograph", "Ideographic"},
    16511: {"Unified_Ideograph", "Ideographic"},
    16512: {"Unified_Ideograph", "Ideographic"},
    16513: {"Unified_Ideograph", "Ideographic"},
    16514: {"Unified_Ideograph", "Ideographic"},
    16515: {"Unified_Ideograph", "Ideographic"},
    16516: {"Unified_Ideograph", "Ideographic"},
    16517: {"Unified_Ideograph", "Ideographic"},
    16518: {"Unified_Ideograph", "Ideographic"},
    16519: {"Unified_Ideograph", "Ideographic"},
    16520: {"Unified_Ideograph", "Ideographic"},
    16521: {"Unified_Ideograph", "Ideographic"},
    16522: {"Unified_Ideograph", "Ideographic"},
    16523: {"Unified_Ideograph", "Ideographic"},
    16524: {"Unified_Ideograph", "Ideographic"},
    16525: {"Unified_Ideograph", "Ideographic"},
    16526: {"Unified_Ideograph", "Ideographic"},
    16527: {"Unified_Ideograph", "Ideographic"},
    16528: {"Unified_Ideograph", "Ideographic"},
    16529: {"Unified_Ideograph", "Ideographic"},
    16530: {"Unified_Ideograph", "Ideographic"},
    16531: {"Unified_Ideograph", "Ideographic"},
    16532: {"Unified_Ideograph", "Ideographic"},
    16533: {"Unified_Ideograph", "Ideographic"},
    16534: {"Unified_Ideograph", "Ideographic"},
    16535: {"Unified_Ideograph", "Ideographic"},
    16536: {"Unified_Ideograph", "Ideographic"},
    16537: {"Unified_Ideograph", "Ideographic"},
    16538: {"Unified_Ideograph", "Ideographic"},
    16539: {"Unified_Ideograph", "Ideographic"},
    16540: {"Unified_Ideograph", "Ideographic"},
    16541: {"Unified_Ideograph", "Ideographic"},
    16542: {"Unified_Ideograph", "Ideographic"},
    16543: {"Unified_Ideograph", "Ideographic"},
    16544: {"Unified_Ideograph", "Ideographic"},
    16545: {"Unified_Ideograph", "Ideographic"},
    16546: {"Unified_Ideograph", "Ideographic"},
    16547: {"Unified_Ideograph", "Ideographic"},
    16548: {"Unified_Ideograph", "Ideographic"},
    16549: {"Unified_Ideograph", "Ideographic"},
    16550: {"Unified_Ideograph", "Ideographic"},
    16551: {"Unified_Ideograph", "Ideographic"},
    16552: {"Unified_Ideograph", "Ideographic"},
    16553: {"Unified_Ideograph", "Ideographic"},
    16554: {"Unified_Ideograph", "Ideographic"},
    16555: {"Unified_Ideograph", "Ideographic"},
    16556: {"Unified_Ideograph", "Ideographic"},
    16557: {"Unified_Ideograph", "Ideographic"},
    16558: {"Unified_Ideograph", "Ideographic"},
    16559: {"Unified_Ideograph", "Ideographic"},
    16560: {"Unified_Ideograph", "Ideographic"},
    16561: {"Unified_Ideograph", "Ideographic"},
    16562: {"Unified_Ideograph", "Ideographic"},
    16563: {"Unified_Ideograph", "Ideographic"},
    16564: {"Unified_Ideograph", "Ideographic"},
    16565: {"Unified_Ideograph", "Ideographic"},
    16566: {"Unified_Ideograph", "Ideographic"},
    16567: {"Unified_Ideograph", "Ideographic"},
    16568: {"Unified_Ideograph", "Ideographic"},
    16569: {"Unified_Ideograph", "Ideographic"},
    16570: {"Unified_Ideograph", "Ideographic"},
    16571: {"Unified_Ideograph", "Ideographic"},
    16572: {"Unified_Ideograph", "Ideographic"},
    16573: {"Unified_Ideograph", "Ideographic"},
    16574: {"Unified_Ideograph", "Ideographic"},
    16575: {"Unified_Ideograph", "Ideographic"},
    16576: {"Unified_Ideograph", "Ideographic"},
    16577: {"Unified_Ideograph", "Ideographic"},
    16578: {"Unified_Ideograph", "Ideographic"},
    16579: {"Unified_Ideograph", "Ideographic"},
    16580: {"Unified_Ideograph", "Ideographic"},
    16581: {"Unified_Ideograph", "Ideographic"},
    16582: {"Unified_Ideograph", "Ideographic"},
    16583: {"Unified_Ideograph", "Ideographic"},
    16584: {"Unified_Ideograph", "Ideographic"},
    16585: {"Unified_Ideograph", "Ideographic"},
    16586: {"Unified_Ideograph", "Ideographic"},
    16587: {"Unified_Ideograph", "Ideographic"},
    16588: {"Unified_Ideograph", "Ideographic"},
    16589: {"Unified_Ideograph", "Ideographic"},
    16590: {"Unified_Ideograph", "Ideographic"},
    16591: {"Unified_Ideograph", "Ideographic"},
    16592: {"Unified_Ideograph", "Ideographic"},
    16593: {"Unified_Ideograph", "Ideographic"},
    16594: {"Unified_Ideograph", "Ideographic"},
    16595: {"Unified_Ideograph", "Ideographic"},
    16596: {"Unified_Ideograph", "Ideographic"},
    16597: {"Unified_Ideograph", "Ideographic"},
    16598: {"Unified_Ideograph", "Ideographic"},
    16599: {"Unified_Ideograph", "Ideographic"},
    16600: {"Unified_Ideograph", "Ideographic"},
    16601: {"Unified_Ideograph", "Ideographic"},
    16602: {"Unified_Ideograph", "Ideographic"},
    16603: {"Unified_Ideograph", "Ideographic"},
    16604: {"Unified_Ideograph", "Ideographic"},
    16605: {"Unified_Ideograph", "Ideographic"},
    16606: {"Unified_Ideograph", "Ideographic"},
    16607: {"Unified_Ideograph", "Ideographic"},
    16608: {"Unified_Ideograph", "Ideographic"},
    16609: {"Unified_Ideograph", "Ideographic"},
    16610: {"Unified_Ideograph", "Ideographic"},
    16611: {"Unified_Ideograph", "Ideographic"},
    16612: {"Unified_Ideograph", "Ideographic"},
    16613: {"Unified_Ideograph", "Ideographic"},
    16614: {"Unified_Ideograph", "Ideographic"},
    16615: {"Unified_Ideograph", "Ideographic"},
    16616: {"Unified_Ideograph", "Ideographic"},
    16617: {"Unified_Ideograph", "Ideographic"},
    16618: {"Unified_Ideograph", "Ideographic"},
    16619: {"Unified_Ideograph", "Ideographic"},
    16620: {"Unified_Ideograph", "Ideographic"},
    16621: {"Unified_Ideograph", "Ideographic"},
    16622: {"Unified_Ideograph", "Ideographic"},
    16623: {"Unified_Ideograph", "Ideographic"},
    16624: {"Unified_Ideograph", "Ideographic"},
    16625: {"Unified_Ideograph", "Ideographic"},
    16626: {"Unified_Ideograph", "Ideographic"},
    16627: {"Unified_Ideograph", "Ideographic"},
    16628: {"Unified_Ideograph", "Ideographic"},
    16629: {"Unified_Ideograph", "Ideographic"},
    16630: {"Unified_Ideograph", "Ideographic"},
    16631: {"Unified_Ideograph", "Ideographic"},
    16632: {"Unified_Ideograph", "Ideographic"},
    16633: {"Unified_Ideograph", "Ideographic"},
    16634: {"Unified_Ideograph", "Ideographic"},
    16635: {"Unified_Ideograph", "Ideographic"},
    16636: {"Unified_Ideograph", "Ideographic"},
    16637: {"Unified_Ideograph", "Ideographic"},
    16638: {"Unified_Ideograph", "Ideographic"},
    16639: {"Unified_Ideograph", "Ideographic"},
    16640: {"Unified_Ideograph", "Ideographic"},
    16641: {"Unified_Ideograph", "Ideographic"},
    16642: {"Unified_Ideograph", "Ideographic"},
    16643: {"Unified_Ideograph", "Ideographic"},
    16644: {"Unified_Ideograph", "Ideographic"},
    16645: {"Unified_Ideograph", "Ideographic"},
    16646: {"Unified_Ideograph", "Ideographic"},
    16647: {"Unified_Ideograph", "Ideographic"},
    16648: {"Unified_Ideograph", "Ideographic"},
    16649: {"Unified_Ideograph", "Ideographic"},
    16650: {"Unified_Ideograph", "Ideographic"},
    16651: {"Unified_Ideograph", "Ideographic"},
    16652: {"Unified_Ideograph", "Ideographic"},
    16653: {"Unified_Ideograph", "Ideographic"},
    16654: {"Unified_Ideograph", "Ideographic"},
    16655: {"Unified_Ideograph", "Ideographic"},
    16656: {"Unified_Ideograph", "Ideographic"},
    16657: {"Unified_Ideograph", "Ideographic"},
    16658: {"Unified_Ideograph", "Ideographic"},
    16659: {"Unified_Ideograph", "Ideographic"},
    16660: {"Unified_Ideograph", "Ideographic"},
    16661: {"Unified_Ideograph", "Ideographic"},
    16662: {"Unified_Ideograph", "Ideographic"},
    16663: {"Unified_Ideograph", "Ideographic"},
    16664: {"Unified_Ideograph", "Ideographic"},
    16665: {"Unified_Ideograph", "Ideographic"},
    16666: {"Unified_Ideograph", "Ideographic"},
    16667: {"Unified_Ideograph", "Ideographic"},
    16668: {"Unified_Ideograph", "Ideographic"},
    16669: {"Unified_Ideograph", "Ideographic"},
    16670: {"Unified_Ideograph", "Ideographic"},
    16671: {"Unified_Ideograph", "Ideographic"},
    16672: {"Unified_Ideograph", "Ideographic"},
    16673: {"Unified_Ideograph", "Ideographic"},
    16674: {"Unified_Ideograph", "Ideographic"},
    16675: {"Unified_Ideograph", "Ideographic"},
    16676: {"Unified_Ideograph", "Ideographic"},
    16677: {"Unified_Ideograph", "Ideographic"},
    16678: {"Unified_Ideograph", "Ideographic"},
    16679: {"Unified_Ideograph", "Ideographic"},
    16680: {"Unified_Ideograph", "Ideographic"},
    16681: {"Unified_Ideograph", "Ideographic"},
    16682: {"Unified_Ideograph", "Ideographic"},
    16683: {"Unified_Ideograph", "Ideographic"},
    16684: {"Unified_Ideograph", "Ideographic"},
    16685: {"Unified_Ideograph", "Ideographic"},
    16686: {"Unified_Ideograph", "Ideographic"},
    16687: {"Unified_Ideograph", "Ideographic"},
    16688: {"Unified_Ideograph", "Ideographic"},
    16689: {"Unified_Ideograph", "Ideographic"},
    16690: {"Unified_Ideograph", "Ideographic"},
    16691: {"Unified_Ideograph", "Ideographic"},
    16692: {"Unified_Ideograph", "Ideographic"},
    16693: {"Unified_Ideograph", "Ideographic"},
    16694: {"Unified_Ideograph", "Ideographic"},
    16695: {"Unified_Ideograph", "Ideographic"},
    16696: {"Unified_Ideograph", "Ideographic"},
    16697: {"Unified_Ideograph", "Ideographic"},
    16698: {"Unified_Ideograph", "Ideographic"},
    16699: {"Unified_Ideograph", "Ideographic"},
    16700: {"Unified_Ideograph", "Ideographic"},
    16701: {"Unified_Ideograph", "Ideographic"},
    16702: {"Unified_Ideograph", "Ideographic"},
    16703: {"Unified_Ideograph", "Ideographic"},
    16704: {"Unified_Ideograph", "Ideographic"},
    16705: {"Unified_Ideograph", "Ideographic"},
    16706: {"Unified_Ideograph", "Ideographic"},
    16707: {"Unified_Ideograph", "Ideographic"},
    16708: {"Unified_Ideograph", "Ideographic"},
    16709: {"Unified_Ideograph", "Ideographic"},
    16710: {"Unified_Ideograph", "Ideographic"},
    16711: {"Unified_Ideograph", "Ideographic"},
    16712: {"Unified_Ideograph", "Ideographic"},
    16713: {"Unified_Ideograph", "Ideographic"},
    16714: {"Unified_Ideograph", "Ideographic"},
    16715: {"Unified_Ideograph", "Ideographic"},
    16716: {"Unified_Ideograph", "Ideographic"},
    16717: {"Unified_Ideograph", "Ideographic"},
    16718: {"Unified_Ideograph", "Ideographic"},
    16719: {"Unified_Ideograph", "Ideographic"},
    16720: {"Unified_Ideograph", "Ideographic"},
    16721: {"Unified_Ideograph", "Ideographic"},
    16722: {"Unified_Ideograph", "Ideographic"},
    16723: {"Unified_Ideograph", "Ideographic"},
    16724: {"Unified_Ideograph", "Ideographic"},
    16725: {"Unified_Ideograph", "Ideographic"},
    16726: {"Unified_Ideograph", "Ideographic"},
    16727: {"Unified_Ideograph", "Ideographic"},
    16728: {"Unified_Ideograph", "Ideographic"},
    16729: {"Unified_Ideograph", "Ideographic"},
    16730: {"Unified_Ideograph", "Ideographic"},
    16731: {"Unified_Ideograph", "Ideographic"},
    16732: {"Unified_Ideograph", "Ideographic"},
    16733: {"Unified_Ideograph", "Ideographic"},
    16734: {"Unified_Ideograph", "Ideographic"},
    16735: {"Unified_Ideograph", "Ideographic"},
    16736: {"Unified_Ideograph", "Ideographic"},
    16737: {"Unified_Ideograph", "Ideographic"},
    16738: {"Unified_Ideograph", "Ideographic"},
    16739: {"Unified_Ideograph", "Ideographic"},
    16740: {"Unified_Ideograph", "Ideographic"},
    16741: {"Unified_Ideograph", "Ideographic"},
    16742: {"Unified_Ideograph", "Ideographic"},
    16743: {"Unified_Ideograph", "Ideographic"},
    16744: {"Unified_Ideograph", "Ideographic"},
    16745: {"Unified_Ideograph", "Ideographic"},
    16746: {"Unified_Ideograph", "Ideographic"},
    16747: {"Unified_Ideograph", "Ideographic"},
    16748: {"Unified_Ideograph", "Ideographic"},
    16749: {"Unified_Ideograph", "Ideographic"},
    16750: {"Unified_Ideograph", "Ideographic"},
    16751: {"Unified_Ideograph", "Ideographic"},
    16752: {"Unified_Ideograph", "Ideographic"},
    16753: {"Unified_Ideograph", "Ideographic"},
    16754: {"Unified_Ideograph", "Ideographic"},
    16755: {"Unified_Ideograph", "Ideographic"},
    16756: {"Unified_Ideograph", "Ideographic"},
    16757: {"Unified_Ideograph", "Ideographic"},
    16758: {"Unified_Ideograph", "Ideographic"},
    16759: {"Unified_Ideograph", "Ideographic"},
    16760: {"Unified_Ideograph", "Ideographic"},
    16761: {"Unified_Ideograph", "Ideographic"},
    16762: {"Unified_Ideograph", "Ideographic"},
    16763: {"Unified_Ideograph", "Ideographic"},
    16764: {"Unified_Ideograph", "Ideographic"},
    16765: {"Unified_Ideograph", "Ideographic"},
    16766: {"Unified_Ideograph", "Ideographic"},
    16767: {"Unified_Ideograph", "Ideographic"},
    16768: {"Unified_Ideograph", "Ideographic"},
    16769: {"Unified_Ideograph", "Ideographic"},
    16770: {"Unified_Ideograph", "Ideographic"},
    16771: {"Unified_Ideograph", "Ideographic"},
    16772: {"Unified_Ideograph", "Ideographic"},
    16773: {"Unified_Ideograph", "Ideographic"},
    16774: {"Unified_Ideograph", "Ideographic"},
    16775: {"Unified_Ideograph", "Ideographic"},
    16776: {"Unified_Ideograph", "Ideographic"},
    16777: {"Unified_Ideograph", "Ideographic"},
    16778: {"Unified_Ideograph", "Ideographic"},
    16779: {"Unified_Ideograph", "Ideographic"},
    16780: {"Unified_Ideograph", "Ideographic"},
    16781: {"Unified_Ideograph", "Ideographic"},
    16782: {"Unified_Ideograph", "Ideographic"},
    16783: {"Unified_Ideograph", "Ideographic"},
    16784: {"Unified_Ideograph", "Ideographic"},
    16785: {"Unified_Ideograph", "Ideographic"},
    16786: {"Unified_Ideograph", "Ideographic"},
    16787: {"Unified_Ideograph", "Ideographic"},
    16788: {"Unified_Ideograph", "Ideographic"},
    16789: {"Unified_Ideograph", "Ideographic"},
    16790: {"Unified_Ideograph", "Ideographic"},
    16791: {"Unified_Ideograph", "Ideographic"},
    16792: {"Unified_Ideograph", "Ideographic"},
    16793: {"Unified_Ideograph", "Ideographic"},
    16794: {"Unified_Ideograph", "Ideographic"},
    16795: {"Unified_Ideograph", "Ideographic"},
    16796: {"Unified_Ideograph", "Ideographic"},
    16797: {"Unified_Ideograph", "Ideographic"},
    16798: {"Unified_Ideograph", "Ideographic"},
    16799: {"Unified_Ideograph", "Ideographic"},
    16800: {"Unified_Ideograph", "Ideographic"},
    16801: {"Unified_Ideograph", "Ideographic"},
    16802: {"Unified_Ideograph", "Ideographic"},
    16803: {"Unified_Ideograph", "Ideographic"},
    16804: {"Unified_Ideograph", "Ideographic"},
    16805: {"Unified_Ideograph", "Ideographic"},
    16806: {"Unified_Ideograph", "Ideographic"},
    16807: {"Unified_Ideograph", "Ideographic"},
    16808: {"Unified_Ideograph", "Ideographic"},
    16809: {"Unified_Ideograph", "Ideographic"},
    16810: {"Unified_Ideograph", "Ideographic"},
    16811: {"Unified_Ideograph", "Ideographic"},
    16812: {"Unified_Ideograph", "Ideographic"},
    16813: {"Unified_Ideograph", "Ideographic"},
    16814: {"Unified_Ideograph", "Ideographic"},
    16815: {"Unified_Ideograph", "Ideographic"},
    16816: {"Unified_Ideograph", "Ideographic"},
    16817: {"Unified_Ideograph", "Ideographic"},
    16818: {"Unified_Ideograph", "Ideographic"},
    16819: {"Unified_Ideograph", "Ideographic"},
    16820: {"Unified_Ideograph", "Ideographic"},
    16821: {"Unified_Ideograph", "Ideographic"},
    16822: {"Unified_Ideograph", "Ideographic"},
    16823: {"Unified_Ideograph", "Ideographic"},
    16824: {"Unified_Ideograph", "Ideographic"},
    16825: {"Unified_Ideograph", "Ideographic"},
    16826: {"Unified_Ideograph", "Ideographic"},
    16827: {"Unified_Ideograph", "Ideographic"},
    16828: {"Unified_Ideograph", "Ideographic"},
    16829: {"Unified_Ideograph", "Ideographic"},
    16830: {"Unified_Ideograph", "Ideographic"},
    16831: {"Unified_Ideograph", "Ideographic"},
    16832: {"Unified_Ideograph", "Ideographic"},
    16833: {"Unified_Ideograph", "Ideographic"},
    16834: {"Unified_Ideograph", "Ideographic"},
    16835: {"Unified_Ideograph", "Ideographic"},
    16836: {"Unified_Ideograph", "Ideographic"},
    16837: {"Unified_Ideograph", "Ideographic"},
    16838: {"Unified_Ideograph", "Ideographic"},
    16839: {"Unified_Ideograph", "Ideographic"},
    16840: {"Unified_Ideograph", "Ideographic"},
    16841: {"Unified_Ideograph", "Ideographic"},
    16842: {"Unified_Ideograph", "Ideographic"},
    16843: {"Unified_Ideograph", "Ideographic"},
    16844: {"Unified_Ideograph", "Ideographic"},
    16845: {"Unified_Ideograph", "Ideographic"},
    16846: {"Unified_Ideograph", "Ideographic"},
    16847: {"Unified_Ideograph", "Ideographic"},
    16848: {"Unified_Ideograph", "Ideographic"},
    16849: {"Unified_Ideograph", "Ideographic"},
    16850: {"Unified_Ideograph", "Ideographic"},
    16851: {"Unified_Ideograph", "Ideographic"},
    16852: {"Unified_Ideograph", "Ideographic"},
    16853: {"Unified_Ideograph", "Ideographic"},
    16854: {"Unified_Ideograph", "Ideographic"},
    16855: {"Unified_Ideograph", "Ideographic"},
    16856: {"Unified_Ideograph", "Ideographic"},
    16857: {"Unified_Ideograph", "Ideographic"},
    16858: {"Unified_Ideograph", "Ideographic"},
    16859: {"Unified_Ideograph", "Ideographic"},
    16860: {"Unified_Ideograph", "Ideographic"},
    16861: {"Unified_Ideograph", "Ideographic"},
    16862: {"Unified_Ideograph", "Ideographic"},
    16863: {"Unified_Ideograph", "Ideographic"},
    16864: {"Unified_Ideograph", "Ideographic"},
    16865: {"Unified_Ideograph", "Ideographic"},
    16866: {"Unified_Ideograph", "Ideographic"},
    16867: {"Unified_Ideograph", "Ideographic"},
    16868: {"Unified_Ideograph", "Ideographic"},
    16869: {"Unified_Ideograph", "Ideographic"},
    16870: {"Unified_Ideograph", "Ideographic"},
    16871: {"Unified_Ideograph", "Ideographic"},
    16872: {"Unified_Ideograph", "Ideographic"},
    16873: {"Unified_Ideograph", "Ideographic"},
    16874: {"Unified_Ideograph", "Ideographic"},
    16875: {"Unified_Ideograph", "Ideographic"},
    16876: {"Unified_Ideograph", "Ideographic"},
    16877: {"Unified_Ideograph", "Ideographic"},
    16878: {"Unified_Ideograph", "Ideographic"},
    16879: {"Unified_Ideograph", "Ideographic"},
    16880: {"Unified_Ideograph", "Ideographic"},
    16881: {"Unified_Ideograph", "Ideographic"},
    16882: {"Unified_Ideograph", "Ideographic"},
    16883: {"Unified_Ideograph", "Ideographic"},
    16884: {"Unified_Ideograph", "Ideographic"},
    16885: {"Unified_Ideograph", "Ideographic"},
    16886: {"Unified_Ideograph", "Ideographic"},
    16887: {"Unified_Ideograph", "Ideographic"},
    16888: {"Unified_Ideograph", "Ideographic"},
    16889: {"Unified_Ideograph", "Ideographic"},
    16890: {"Unified_Ideograph", "Ideographic"},
    16891: {"Unified_Ideograph", "Ideographic"},
    16892: {"Unified_Ideograph", "Ideographic"},
    16893: {"Unified_Ideograph", "Ideographic"},
    16894: {"Unified_Ideograph", "Ideographic"},
    16895: {"Unified_Ideograph", "Ideographic"},
    16896: {"Unified_Ideograph", "Ideographic"},
    16897: {"Unified_Ideograph", "Ideographic"},
    16898: {"Unified_Ideograph", "Ideographic"},
    16899: {"Unified_Ideograph", "Ideographic"},
    16900: {"Unified_Ideograph", "Ideographic"},
    16901: {"Unified_Ideograph", "Ideographic"},
    16902: {"Unified_Ideograph", "Ideographic"},
    16903: {"Unified_Ideograph", "Ideographic"},
    16904: {"Unified_Ideograph", "Ideographic"},
    16905: {"Unified_Ideograph", "Ideographic"},
    16906: {"Unified_Ideograph", "Ideographic"},
    16907: {"Unified_Ideograph", "Ideographic"},
    16908: {"Unified_Ideograph", "Ideographic"},
    16909: {"Unified_Ideograph", "Ideographic"},
    16910: {"Unified_Ideograph", "Ideographic"},
    16911: {"Unified_Ideograph", "Ideographic"},
    16912: {"Unified_Ideograph", "Ideographic"},
    16913: {"Unified_Ideograph", "Ideographic"},
    16914: {"Unified_Ideograph", "Ideographic"},
    16915: {"Unified_Ideograph", "Ideographic"},
    16916: {"Unified_Ideograph", "Ideographic"},
    16917: {"Unified_Ideograph", "Ideographic"},
    16918: {"Unified_Ideograph", "Ideographic"},
    16919: {"Unified_Ideograph", "Ideographic"},
    16920: {"Unified_Ideograph", "Ideographic"},
    16921: {"Unified_Ideograph", "Ideographic"},
    16922: {"Unified_Ideograph", "Ideographic"},
    16923: {"Unified_Ideograph", "Ideographic"},
    16924: {"Unified_Ideograph", "Ideographic"},
    16925: {"Unified_Ideograph", "Ideographic"},
    16926: {"Unified_Ideograph", "Ideographic"},
    16927: {"Unified_Ideograph", "Ideographic"},
    16928: {"Unified_Ideograph", "Ideographic"},
    16929: {"Unified_Ideograph", "Ideographic"},
    16930: {"Unified_Ideograph", "Ideographic"},
    16931: {"Unified_Ideograph", "Ideographic"},
    16932: {"Unified_Ideograph", "Ideographic"},
    16933: {"Unified_Ideograph", "Ideographic"},
    16934: {"Unified_Ideograph", "Ideographic"},
    16935: {"Unified_Ideograph", "Ideographic"},
    16936: {"Unified_Ideograph", "Ideographic"},
    16937: {"Unified_Ideograph", "Ideographic"},
    16938: {"Unified_Ideograph", "Ideographic"},
    16939: {"Unified_Ideograph", "Ideographic"},
    16940: {"Unified_Ideograph", "Ideographic"},
    16941: {"Unified_Ideograph", "Ideographic"},
    16942: {"Unified_Ideograph", "Ideographic"},
    16943: {"Unified_Ideograph", "Ideographic"},
    16944: {"Unified_Ideograph", "Ideographic"},
    16945: {"Unified_Ideograph", "Ideographic"},
    16946: {"Unified_Ideograph", "Ideographic"},
    16947: {"Unified_Ideograph", "Ideographic"},
    16948: {"Unified_Ideograph", "Ideographic"},
    16949: {"Unified_Ideograph", "Ideographic"},
    16950: {"Unified_Ideograph", "Ideographic"},
    16951: {"Unified_Ideograph", "Ideographic"},
    16952: {"Unified_Ideograph", "Ideographic"},
    16953: {"Unified_Ideograph", "Ideographic"},
    16954: {"Unified_Ideograph", "Ideographic"},
    16955: {"Unified_Ideograph", "Ideographic"},
    16956: {"Unified_Ideograph", "Ideographic"},
    16957: {"Unified_Ideograph", "Ideographic"},
    16958: {"Unified_Ideograph", "Ideographic"},
    16959: {"Unified_Ideograph", "Ideographic"},
    16960: {"Unified_Ideograph", "Ideographic"},
    16961: {"Unified_Ideograph", "Ideographic"},
    16962: {"Unified_Ideograph", "Ideographic"},
    16963: {"Unified_Ideograph", "Ideographic"},
    16964: {"Unified_Ideograph", "Ideographic"},
    16965: {"Unified_Ideograph", "Ideographic"},
    16966: {"Unified_Ideograph", "Ideographic"},
    16967: {"Unified_Ideograph", "Ideographic"},
    16968: {"Unified_Ideograph", "Ideographic"},
    16969: {"Unified_Ideograph", "Ideographic"},
    16970: {"Unified_Ideograph", "Ideographic"},
    16971: {"Unified_Ideograph", "Ideographic"},
    16972: {"Unified_Ideograph", "Ideographic"},
    16973: {"Unified_Ideograph", "Ideographic"},
    16974: {"Unified_Ideograph", "Ideographic"},
    16975: {"Unified_Ideograph", "Ideographic"},
    16976: {"Unified_Ideograph", "Ideographic"},
    16977: {"Unified_Ideograph", "Ideographic"},
    16978: {"Unified_Ideograph", "Ideographic"},
    16979: {"Unified_Ideograph", "Ideographic"},
    16980: {"Unified_Ideograph", "Ideographic"},
    16981: {"Unified_Ideograph", "Ideographic"},
    16982: {"Unified_Ideograph", "Ideographic"},
    16983: {"Unified_Ideograph", "Ideographic"},
    16984: {"Unified_Ideograph", "Ideographic"},
    16985: {"Unified_Ideograph", "Ideographic"},
    16986: {"Unified_Ideograph", "Ideographic"},
    16987: {"Unified_Ideograph", "Ideographic"},
    16988: {"Unified_Ideograph", "Ideographic"},
    16989: {"Unified_Ideograph", "Ideographic"},
    16990: {"Unified_Ideograph", "Ideographic"},
    16991: {"Unified_Ideograph", "Ideographic"},
    16992: {"Unified_Ideograph", "Ideographic"},
    16993: {"Unified_Ideograph", "Ideographic"},
    16994: {"Unified_Ideograph", "Ideographic"},
    16995: {"Unified_Ideograph", "Ideographic"},
    16996: {"Unified_Ideograph", "Ideographic"},
    16997: {"Unified_Ideograph", "Ideographic"},
    16998: {"Unified_Ideograph", "Ideographic"},
    16999: {"Unified_Ideograph", "Ideographic"},
    17000: {"Unified_Ideograph", "Ideographic"},
    17001: {"Unified_Ideograph", "Ideographic"},
    17002: {"Unified_Ideograph", "Ideographic"},
    17003: {"Unified_Ideograph", "Ideographic"},
    17004: {"Unified_Ideograph", "Ideographic"},
    17005: {"Unified_Ideograph", "Ideographic"},
    17006: {"Unified_Ideograph", "Ideographic"},
    17007: {"Unified_Ideograph", "Ideographic"},
    17008: {"Unified_Ideograph", "Ideographic"},
    17009: {"Unified_Ideograph", "Ideographic"},
    17010: {"Unified_Ideograph", "Ideographic"},
    17011: {"Unified_Ideograph", "Ideographic"},
    17012: {"Unified_Ideograph", "Ideographic"},
    17013: {"Unified_Ideograph", "Ideographic"},
    17014: {"Unified_Ideograph", "Ideographic"},
    17015: {"Unified_Ideograph", "Ideographic"},
    17016: {"Unified_Ideograph", "Ideographic"},
    17017: {"Unified_Ideograph", "Ideographic"},
    17018: {"Unified_Ideograph", "Ideographic"},
    17019: {"Unified_Ideograph", "Ideographic"},
    17020: {"Unified_Ideograph", "Ideographic"},
    17021: {"Unified_Ideograph", "Ideographic"},
    17022: {"Unified_Ideograph", "Ideographic"},
    17023: {"Unified_Ideograph", "Ideographic"},
    17024: {"Unified_Ideograph", "Ideographic"},
    17025: {"Unified_Ideograph", "Ideographic"},
    17026: {"Unified_Ideograph", "Ideographic"},
    17027: {"Unified_Ideograph", "Ideographic"},
    17028: {"Unified_Ideograph", "Ideographic"},
    17029: {"Unified_Ideograph", "Ideographic"},
    17030: {"Unified_Ideograph", "Ideographic"},
    17031: {"Unified_Ideograph", "Ideographic"},
    17032: {"Unified_Ideograph", "Ideographic"},
    17033: {"Unified_Ideograph", "Ideographic"},
    17034: {"Unified_Ideograph", "Ideographic"},
    17035: {"Unified_Ideograph", "Ideographic"},
    17036: {"Unified_Ideograph", "Ideographic"},
    17037: {"Unified_Ideograph", "Ideographic"},
    17038: {"Unified_Ideograph", "Ideographic"},
    17039: {"Unified_Ideograph", "Ideographic"},
    17040: {"Unified_Ideograph", "Ideographic"},
    17041: {"Unified_Ideograph", "Ideographic"},
    17042: {"Unified_Ideograph", "Ideographic"},
    17043: {"Unified_Ideograph", "Ideographic"},
    17044: {"Unified_Ideograph", "Ideographic"},
    17045: {"Unified_Ideograph", "Ideographic"},
    17046: {"Unified_Ideograph", "Ideographic"},
    17047: {"Unified_Ideograph", "Ideographic"},
    17048: {"Unified_Ideograph", "Ideographic"},
    17049: {"Unified_Ideograph", "Ideographic"},
    17050: {"Unified_Ideograph", "Ideographic"},
    17051: {"Unified_Ideograph", "Ideographic"},
    17052: {"Unified_Ideograph", "Ideographic"},
    17053: {"Unified_Ideograph", "Ideographic"},
    17054: {"Unified_Ideograph", "Ideographic"},
    17055: {"Unified_Ideograph", "Ideographic"},
    17056: {"Unified_Ideograph", "Ideographic"},
    17057: {"Unified_Ideograph", "Ideographic"},
    17058: {"Unified_Ideograph", "Ideographic"},
    17059: {"Unified_Ideograph", "Ideographic"},
    17060: {"Unified_Ideograph", "Ideographic"},
    17061: {"Unified_Ideograph", "Ideographic"},
    17062: {"Unified_Ideograph", "Ideographic"},
    17063: {"Unified_Ideograph", "Ideographic"},
    17064: {"Unified_Ideograph", "Ideographic"},
    17065: {"Unified_Ideograph", "Ideographic"},
    17066: {"Unified_Ideograph", "Ideographic"},
    17067: {"Unified_Ideograph", "Ideographic"},
    17068: {"Unified_Ideograph", "Ideographic"},
    17069: {"Unified_Ideograph", "Ideographic"},
    17070: {"Unified_Ideograph", "Ideographic"},
    17071: {"Unified_Ideograph", "Ideographic"},
    17072: {"Unified_Ideograph", "Ideographic"},
    17073: {"Unified_Ideograph", "Ideographic"},
    17074: {"Unified_Ideograph", "Ideographic"},
    17075: {"Unified_Ideograph", "Ideographic"},
    17076: {"Unified_Ideograph", "Ideographic"},
    17077: {"Unified_Ideograph", "Ideographic"},
    17078: {"Unified_Ideograph", "Ideographic"},
    17079: {"Unified_Ideograph", "Ideographic"},
    17080: {"Unified_Ideograph", "Ideographic"},
    17081: {"Unified_Ideograph", "Ideographic"},
    17082: {"Unified_Ideograph", "Ideographic"},
    17083: {"Unified_Ideograph", "Ideographic"},
    17084: {"Unified_Ideograph", "Ideographic"},
    17085: {"Unified_Ideograph", "Ideographic"},
    17086: {"Unified_Ideograph", "Ideographic"},
    17087: {"Unified_Ideograph", "Ideographic"},
    17088: {"Unified_Ideograph", "Ideographic"},
    17089: {"Unified_Ideograph", "Ideographic"},
    17090: {"Unified_Ideograph", "Ideographic"},
    17091: {"Unified_Ideograph", "Ideographic"},
    17092: {"Unified_Ideograph", "Ideographic"},
    17093: {"Unified_Ideograph", "Ideographic"},
    17094: {"Unified_Ideograph", "Ideographic"},
    17095: {"Unified_Ideograph", "Ideographic"},
    17096: {"Unified_Ideograph", "Ideographic"},
    17097: {"Unified_Ideograph", "Ideographic"},
    17098: {"Unified_Ideograph", "Ideographic"},
    17099: {"Unified_Ideograph", "Ideographic"},
    17100: {"Unified_Ideograph", "Ideographic"},
    17101: {"Unified_Ideograph", "Ideographic"},
    17102: {"Unified_Ideograph", "Ideographic"},
    17103: {"Unified_Ideograph", "Ideographic"},
    17104: {"Unified_Ideograph", "Ideographic"},
    17105: {"Unified_Ideograph", "Ideographic"},
    17106: {"Unified_Ideograph", "Ideographic"},
    17107: {"Unified_Ideograph", "Ideographic"},
    17108: {"Unified_Ideograph", "Ideographic"},
    17109: {"Unified_Ideograph", "Ideographic"},
    17110: {"Unified_Ideograph", "Ideographic"},
    17111: {"Unified_Ideograph", "Ideographic"},
    17112: {"Unified_Ideograph", "Ideographic"},
    17113: {"Unified_Ideograph", "Ideographic"},
    17114: {"Unified_Ideograph", "Ideographic"},
    17115: {"Unified_Ideograph", "Ideographic"},
    17116: {"Unified_Ideograph", "Ideographic"},
    17117: {"Unified_Ideograph", "Ideographic"},
    17118: {"Unified_Ideograph", "Ideographic"},
    17119: {"Unified_Ideograph", "Ideographic"},
    17120: {"Unified_Ideograph", "Ideographic"},
    17121: {"Unified_Ideograph", "Ideographic"},
    17122: {"Unified_Ideograph", "Ideographic"},
    17123: {"Unified_Ideograph", "Ideographic"},
    17124: {"Unified_Ideograph", "Ideographic"},
    17125: {"Unified_Ideograph", "Ideographic"},
    17126: {"Unified_Ideograph", "Ideographic"},
    17127: {"Unified_Ideograph", "Ideographic"},
    17128: {"Unified_Ideograph", "Ideographic"},
    17129: {"Unified_Ideograph", "Ideographic"},
    17130: {"Unified_Ideograph", "Ideographic"},
    17131: {"Unified_Ideograph", "Ideographic"},
    17132: {"Unified_Ideograph", "Ideographic"},
    17133: {"Unified_Ideograph", "Ideographic"},
    17134: {"Unified_Ideograph", "Ideographic"},
    17135: {"Unified_Ideograph", "Ideographic"},
    17136: {"Unified_Ideograph", "Ideographic"},
    17137: {"Unified_Ideograph", "Ideographic"},
    17138: {"Unified_Ideograph", "Ideographic"},
    17139: {"Unified_Ideograph", "Ideographic"},
    17140: {"Unified_Ideograph", "Ideographic"},
    17141: {"Unified_Ideograph", "Ideographic"},
    17142: {"Unified_Ideograph", "Ideographic"},
    17143: {"Unified_Ideograph", "Ideographic"},
    17144: {"Unified_Ideograph", "Ideographic"},
    17145: {"Unified_Ideograph", "Ideographic"},
    17146: {"Unified_Ideograph", "Ideographic"},
    17147: {"Unified_Ideograph", "Ideographic"},
    17148: {"Unified_Ideograph", "Ideographic"},
    17149: {"Unified_Ideograph", "Ideographic"},
    17150: {"Unified_Ideograph", "Ideographic"},
    17151: {"Unified_Ideograph", "Ideographic"},
    17152: {"Unified_Ideograph", "Ideographic"},
    17153: {"Unified_Ideograph", "Ideographic"},
    17154: {"Unified_Ideograph", "Ideographic"},
    17155: {"Unified_Ideograph", "Ideographic"},
    17156: {"Unified_Ideograph", "Ideographic"},
    17157: {"Unified_Ideograph", "Ideographic"},
    17158: {"Unified_Ideograph", "Ideographic"},
    17159: {"Unified_Ideograph", "Ideographic"},
    17160: {"Unified_Ideograph", "Ideographic"},
    17161: {"Unified_Ideograph", "Ideographic"},
    17162: {"Unified_Ideograph", "Ideographic"},
    17163: {"Unified_Ideograph", "Ideographic"},
    17164: {"Unified_Ideograph", "Ideographic"},
    17165: {"Unified_Ideograph", "Ideographic"},
    17166: {"Unified_Ideograph", "Ideographic"},
    17167: {"Unified_Ideograph", "Ideographic"},
    17168: {"Unified_Ideograph", "Ideographic"},
    17169: {"Unified_Ideograph", "Ideographic"},
    17170: {"Unified_Ideograph", "Ideographic"},
    17171: {"Unified_Ideograph", "Ideographic"},
    17172: {"Unified_Ideograph", "Ideographic"},
    17173: {"Unified_Ideograph", "Ideographic"},
    17174: {"Unified_Ideograph", "Ideographic"},
    17175: {"Unified_Ideograph", "Ideographic"},
    17176: {"Unified_Ideograph", "Ideographic"},
    17177: {"Unified_Ideograph", "Ideographic"},
    17178: {"Unified_Ideograph", "Ideographic"},
    17179: {"Unified_Ideograph", "Ideographic"},
    17180: {"Unified_Ideograph", "Ideographic"},
    17181: {"Unified_Ideograph", "Ideographic"},
    17182: {"Unified_Ideograph", "Ideographic"},
    17183: {"Unified_Ideograph", "Ideographic"},
    17184: {"Unified_Ideograph", "Ideographic"},
    17185: {"Unified_Ideograph", "Ideographic"},
    17186: {"Unified_Ideograph", "Ideographic"},
    17187: {"Unified_Ideograph", "Ideographic"},
    17188: {"Unified_Ideograph", "Ideographic"},
    17189: {"Unified_Ideograph", "Ideographic"},
    17190: {"Unified_Ideograph", "Ideographic"},
    17191: {"Unified_Ideograph", "Ideographic"},
    17192: {"Unified_Ideograph", "Ideographic"},
    17193: {"Unified_Ideograph", "Ideographic"},
    17194: {"Unified_Ideograph", "Ideographic"},
    17195: {"Unified_Ideograph", "Ideographic"},
    17196: {"Unified_Ideograph", "Ideographic"},
    17197: {"Unified_Ideograph", "Ideographic"},
    17198: {"Unified_Ideograph", "Ideographic"},
    17199: {"Unified_Ideograph", "Ideographic"},
    17200: {"Unified_Ideograph", "Ideographic"},
    17201: {"Unified_Ideograph", "Ideographic"},
    17202: {"Unified_Ideograph", "Ideographic"},
    17203: {"Unified_Ideograph", "Ideographic"},
    17204: {"Unified_Ideograph", "Ideographic"},
    17205: {"Unified_Ideograph", "Ideographic"},
    17206: {"Unified_Ideograph", "Ideographic"},
    17207: {"Unified_Ideograph", "Ideographic"},
    17208: {"Unified_Ideograph", "Ideographic"},
    17209: {"Unified_Ideograph", "Ideographic"},
    17210: {"Unified_Ideograph", "Ideographic"},
    17211: {"Unified_Ideograph", "Ideographic"},
    17212: {"Unified_Ideograph", "Ideographic"},
    17213: {"Unified_Ideograph", "Ideographic"},
    17214: {"Unified_Ideograph", "Ideographic"},
    17215: {"Unified_Ideograph", "Ideographic"},
    17216: {"Unified_Ideograph", "Ideographic"},
    17217: {"Unified_Ideograph", "Ideographic"},
    17218: {"Unified_Ideograph", "Ideographic"},
    17219: {"Unified_Ideograph", "Ideographic"},
    17220: {"Unified_Ideograph", "Ideographic"},
    17221: {"Unified_Ideograph", "Ideographic"},
    17222: {"Unified_Ideograph", "Ideographic"},
    17223: {"Unified_Ideograph", "Ideographic"},
    17224: {"Unified_Ideograph", "Ideographic"},
    17225: {"Unified_Ideograph", "Ideographic"},
    17226: {"Unified_Ideograph", "Ideographic"},
    17227: {"Unified_Ideograph", "Ideographic"},
    17228: {"Unified_Ideograph", "Ideographic"},
    17229: {"Unified_Ideograph", "Ideographic"},
    17230: {"Unified_Ideograph", "Ideographic"},
    17231: {"Unified_Ideograph", "Ideographic"},
    17232: {"Unified_Ideograph", "Ideographic"},
    17233: {"Unified_Ideograph", "Ideographic"},
    17234: {"Unified_Ideograph", "Ideographic"},
    17235: {"Unified_Ideograph", "Ideographic"},
    17236: {"Unified_Ideograph", "Ideographic"},
    17237: {"Unified_Ideograph", "Ideographic"},
    17238: {"Unified_Ideograph", "Ideographic"},
    17239: {"Unified_Ideograph", "Ideographic"},
    17240: {"Unified_Ideograph", "Ideographic"},
    17241: {"Unified_Ideograph", "Ideographic"},
    17242: {"Unified_Ideograph", "Ideographic"},
    17243: {"Unified_Ideograph", "Ideographic"},
    17244: {"Unified_Ideograph", "Ideographic"},
    17245: {"Unified_Ideograph", "Ideographic"},
    17246: {"Unified_Ideograph", "Ideographic"},
    17247: {"Unified_Ideograph", "Ideographic"},
    17248: {"Unified_Ideograph", "Ideographic"},
    17249: {"Unified_Ideograph", "Ideographic"},
    17250: {"Unified_Ideograph", "Ideographic"},
    17251: {"Unified_Ideograph", "Ideographic"},
    17252: {"Unified_Ideograph", "Ideographic"},
    17253: {"Unified_Ideograph", "Ideographic"},
    17254: {"Unified_Ideograph", "Ideographic"},
    17255: {"Unified_Ideograph", "Ideographic"},
    17256: {"Unified_Ideograph", "Ideographic"},
    17257: {"Unified_Ideograph", "Ideographic"},
    17258: {"Unified_Ideograph", "Ideographic"},
    17259: {"Unified_Ideograph", "Ideographic"},
    17260: {"Unified_Ideograph", "Ideographic"},
    17261: {"Unified_Ideograph", "Ideographic"},
    17262: {"Unified_Ideograph", "Ideographic"},
    17263: {"Unified_Ideograph", "Ideographic"},
    17264: {"Unified_Ideograph", "Ideographic"},
    17265: {"Unified_Ideograph", "Ideographic"},
    17266: {"Unified_Ideograph", "Ideographic"},
    17267: {"Unified_Ideograph", "Ideographic"},
    17268: {"Unified_Ideograph", "Ideographic"},
    17269: {"Unified_Ideograph", "Ideographic"},
    17270: {"Unified_Ideograph", "Ideographic"},
    17271: {"Unified_Ideograph", "Ideographic"},
    17272: {"Unified_Ideograph", "Ideographic"},
    17273: {"Unified_Ideograph", "Ideographic"},
    17274: {"Unified_Ideograph", "Ideographic"},
    17275: {"Unified_Ideograph", "Ideographic"},
    17276: {"Unified_Ideograph", "Ideographic"},
    17277: {"Unified_Ideograph", "Ideographic"},
    17278: {"Unified_Ideograph", "Ideographic"},
    17279: {"Unified_Ideograph", "Ideographic"},
    17280: {"Unified_Ideograph", "Ideographic"},
    17281: {"Unified_Ideograph", "Ideographic"},
    17282: {"Unified_Ideograph", "Ideographic"},
    17283: {"Unified_Ideograph", "Ideographic"},
    17284: {"Unified_Ideograph", "Ideographic"},
    17285: {"Unified_Ideograph", "Ideographic"},
    17286: {"Unified_Ideograph", "Ideographic"},
    17287: {"Unified_Ideograph", "Ideographic"},
    17288: {"Unified_Ideograph", "Ideographic"},
    17289: {"Unified_Ideograph", "Ideographic"},
    17290: {"Unified_Ideograph", "Ideographic"},
    17291: {"Unified_Ideograph", "Ideographic"},
    17292: {"Unified_Ideograph", "Ideographic"},
    17293: {"Unified_Ideograph", "Ideographic"},
    17294: {"Unified_Ideograph", "Ideographic"},
    17295: {"Unified_Ideograph", "Ideographic"},
    17296: {"Unified_Ideograph", "Ideographic"},
    17297: {"Unified_Ideograph", "Ideographic"},
    17298: {"Unified_Ideograph", "Ideographic"},
    17299: {"Unified_Ideograph", "Ideographic"},
    17300: {"Unified_Ideograph", "Ideographic"},
    17301: {"Unified_Ideograph", "Ideographic"},
    17302: {"Unified_Ideograph", "Ideographic"},
    17303: {"Unified_Ideograph", "Ideographic"},
    17304: {"Unified_Ideograph", "Ideographic"},
    17305: {"Unified_Ideograph", "Ideographic"},
    17306: {"Unified_Ideograph", "Ideographic"},
    17307: {"Unified_Ideograph", "Ideographic"},
    17308: {"Unified_Ideograph", "Ideographic"},
    17309: {"Unified_Ideograph", "Ideographic"},
    17310: {"Unified_Ideograph", "Ideographic"},
    17311: {"Unified_Ideograph", "Ideographic"},
    17312: {"Unified_Ideograph", "Ideographic"},
    17313: {"Unified_Ideograph", "Ideographic"},
    17314: {"Unified_Ideograph", "Ideographic"},
    17315: {"Unified_Ideograph", "Ideographic"},
    17316: {"Unified_Ideograph", "Ideographic"},
    17317: {"Unified_Ideograph", "Ideographic"},
    17318: {"Unified_Ideograph", "Ideographic"},
    17319: {"Unified_Ideograph", "Ideographic"},
    17320: {"Unified_Ideograph", "Ideographic"},
    17321: {"Unified_Ideograph", "Ideographic"},
    17322: {"Unified_Ideograph", "Ideographic"},
    17323: {"Unified_Ideograph", "Ideographic"},
    17324: {"Unified_Ideograph", "Ideographic"},
    17325: {"Unified_Ideograph", "Ideographic"},
    17326: {"Unified_Ideograph", "Ideographic"},
    17327: {"Unified_Ideograph", "Ideographic"},
    17328: {"Unified_Ideograph", "Ideographic"},
    17329: {"Unified_Ideograph", "Ideographic"},
    17330: {"Unified_Ideograph", "Ideographic"},
    17331: {"Unified_Ideograph", "Ideographic"},
    17332: {"Unified_Ideograph", "Ideographic"},
    17333: {"Unified_Ideograph", "Ideographic"},
    17334: {"Unified_Ideograph", "Ideographic"},
    17335: {"Unified_Ideograph", "Ideographic"},
    17336: {"Unified_Ideograph", "Ideographic"},
    17337: {"Unified_Ideograph", "Ideographic"},
    17338: {"Unified_Ideograph", "Ideographic"},
    17339: {"Unified_Ideograph", "Ideographic"},
    17340: {"Unified_Ideograph", "Ideographic"},
    17341: {"Unified_Ideograph", "Ideographic"},
    17342: {"Unified_Ideograph", "Ideographic"},
    17343: {"Unified_Ideograph", "Ideographic"},
    17344: {"Unified_Ideograph", "Ideographic"},
    17345: {"Unified_Ideograph", "Ideographic"},
    17346: {"Unified_Ideograph", "Ideographic"},
    17347: {"Unified_Ideograph", "Ideographic"},
    17348: {"Unified_Ideograph", "Ideographic"},
    17349: {"Unified_Ideograph", "Ideographic"},
    17350: {"Unified_Ideograph", "Ideographic"},
    17351: {"Unified_Ideograph", "Ideographic"},
    17352: {"Unified_Ideograph", "Ideographic"},
    17353: {"Unified_Ideograph", "Ideographic"},
    17354: {"Unified_Ideograph", "Ideographic"},
    17355: {"Unified_Ideograph", "Ideographic"},
    17356: {"Unified_Ideograph", "Ideographic"},
    17357: {"Unified_Ideograph", "Ideographic"},
    17358: {"Unified_Ideograph", "Ideographic"},
    17359: {"Unified_Ideograph", "Ideographic"},
    17360: {"Unified_Ideograph", "Ideographic"},
    17361: {"Unified_Ideograph", "Ideographic"},
    17362: {"Unified_Ideograph", "Ideographic"},
    17363: {"Unified_Ideograph", "Ideographic"},
    17364: {"Unified_Ideograph", "Ideographic"},
    17365: {"Unified_Ideograph", "Ideographic"},
    17366: {"Unified_Ideograph", "Ideographic"},
    17367: {"Unified_Ideograph", "Ideographic"},
    17368: {"Unified_Ideograph", "Ideographic"},
    17369: {"Unified_Ideograph", "Ideographic"},
    17370: {"Unified_Ideograph", "Ideographic"},
    17371: {"Unified_Ideograph", "Ideographic"},
    17372: {"Unified_Ideograph", "Ideographic"},
    17373: {"Unified_Ideograph", "Ideographic"},
    17374: {"Unified_Ideograph", "Ideographic"},
    17375: {"Unified_Ideograph", "Ideographic"},
    17376: {"Unified_Ideograph", "Ideographic"},
    17377: {"Unified_Ideograph", "Ideographic"},
    17378: {"Unified_Ideograph", "Ideographic"},
    17379: {"Unified_Ideograph", "Ideographic"},
    17380: {"Unified_Ideograph", "Ideographic"},
    17381: {"Unified_Ideograph", "Ideographic"},
    17382: {"Unified_Ideograph", "Ideographic"},
    17383: {"Unified_Ideograph", "Ideographic"},
    17384: {"Unified_Ideograph", "Ideographic"},
    17385: {"Unified_Ideograph", "Ideographic"},
    17386: {"Unified_Ideograph", "Ideographic"},
    17387: {"Unified_Ideograph", "Ideographic"},
    17388: {"Unified_Ideograph", "Ideographic"},
    17389: {"Unified_Ideograph", "Ideographic"},
    17390: {"Unified_Ideograph", "Ideographic"},
    17391: {"Unified_Ideograph", "Ideographic"},
    17392: {"Unified_Ideograph", "Ideographic"},
    17393: {"Unified_Ideograph", "Ideographic"},
    17394: {"Unified_Ideograph", "Ideographic"},
    17395: {"Unified_Ideograph", "Ideographic"},
    17396: {"Unified_Ideograph", "Ideographic"},
    17397: {"Unified_Ideograph", "Ideographic"},
    17398: {"Unified_Ideograph", "Ideographic"},
    17399: {"Unified_Ideograph", "Ideographic"},
    17400: {"Unified_Ideograph", "Ideographic"},
    17401: {"Unified_Ideograph", "Ideographic"},
    17402: {"Unified_Ideograph", "Ideographic"},
    17403: {"Unified_Ideograph", "Ideographic"},
    17404: {"Unified_Ideograph", "Ideographic"},
    17405: {"Unified_Ideograph", "Ideographic"},
    17406: {"Unified_Ideograph", "Ideographic"},
    17407: {"Unified_Ideograph", "Ideographic"},
    17408: {"Unified_Ideograph", "Ideographic"},
    17409: {"Unified_Ideograph", "Ideographic"},
    17410: {"Unified_Ideograph", "Ideographic"},
    17411: {"Unified_Ideograph", "Ideographic"},
    17412: {"Unified_Ideograph", "Ideographic"},
    17413: {"Unified_Ideograph", "Ideographic"},
    17414: {"Unified_Ideograph", "Ideographic"},
    17415: {"Unified_Ideograph", "Ideographic"},
    17416: {"Unified_Ideograph", "Ideographic"},
    17417: {"Unified_Ideograph", "Ideographic"},
    17418: {"Unified_Ideograph", "Ideographic"},
    17419: {"Unified_Ideograph", "Ideographic"},
    17420: {"Unified_Ideograph", "Ideographic"},
    17421: {"Unified_Ideograph", "Ideographic"},
    17422: {"Unified_Ideograph", "Ideographic"},
    17423: {"Unified_Ideograph", "Ideographic"},
    17424: {"Unified_Ideograph", "Ideographic"},
    17425: {"Unified_Ideograph", "Ideographic"},
    17426: {"Unified_Ideograph", "Ideographic"},
    17427: {"Unified_Ideograph", "Ideographic"},
    17428: {"Unified_Ideograph", "Ideographic"},
    17429: {"Unified_Ideograph", "Ideographic"},
    17430: {"Unified_Ideograph", "Ideographic"},
    17431: {"Unified_Ideograph", "Ideographic"},
    17432: {"Unified_Ideograph", "Ideographic"},
    17433: {"Unified_Ideograph", "Ideographic"},
    17434: {"Unified_Ideograph", "Ideographic"},
    17435: {"Unified_Ideograph", "Ideographic"},
    17436: {"Unified_Ideograph", "Ideographic"},
    17437: {"Unified_Ideograph", "Ideographic"},
    17438: {"Unified_Ideograph", "Ideographic"},
    17439: {"Unified_Ideograph", "Ideographic"},
    17440: {"Unified_Ideograph", "Ideographic"},
    17441: {"Unified_Ideograph", "Ideographic"},
    17442: {"Unified_Ideograph", "Ideographic"},
    17443: {"Unified_Ideograph", "Ideographic"},
    17444: {"Unified_Ideograph", "Ideographic"},
    17445: {"Unified_Ideograph", "Ideographic"},
    17446: {"Unified_Ideograph", "Ideographic"},
    17447: {"Unified_Ideograph", "Ideographic"},
    17448: {"Unified_Ideograph", "Ideographic"},
    17449: {"Unified_Ideograph", "Ideographic"},
    17450: {"Unified_Ideograph", "Ideographic"},
    17451: {"Unified_Ideograph", "Ideographic"},
    17452: {"Unified_Ideograph", "Ideographic"},
    17453: {"Unified_Ideograph", "Ideographic"},
    17454: {"Unified_Ideograph", "Ideographic"},
    17455: {"Unified_Ideograph", "Ideographic"},
    17456: {"Unified_Ideograph", "Ideographic"},
    17457: {"Unified_Ideograph", "Ideographic"},
    17458: {"Unified_Ideograph", "Ideographic"},
    17459: {"Unified_Ideograph", "Ideographic"},
    17460: {"Unified_Ideograph", "Ideographic"},
    17461: {"Unified_Ideograph", "Ideographic"},
    17462: {"Unified_Ideograph", "Ideographic"},
    17463: {"Unified_Ideograph", "Ideographic"},
    17464: {"Unified_Ideograph", "Ideographic"},
    17465: {"Unified_Ideograph", "Ideographic"},
    17466: {"Unified_Ideograph", "Ideographic"},
    17467: {"Unified_Ideograph", "Ideographic"},
    17468: {"Unified_Ideograph", "Ideographic"},
    17469: {"Unified_Ideograph", "Ideographic"},
    17470: {"Unified_Ideograph", "Ideographic"},
    17471: {"Unified_Ideograph", "Ideographic"},
    17472: {"Unified_Ideograph", "Ideographic"},
    17473: {"Unified_Ideograph", "Ideographic"},
    17474: {"Unified_Ideograph", "Ideographic"},
    17475: {"Unified_Ideograph", "Ideographic"},
    17476: {"Unified_Ideograph", "Ideographic"},
    17477: {"Unified_Ideograph", "Ideographic"},
    17478: {"Unified_Ideograph", "Ideographic"},
    17479: {"Unified_Ideograph", "Ideographic"},
    17480: {"Unified_Ideograph", "Ideographic"},
    17481: {"Unified_Ideograph", "Ideographic"},
    17482: {"Unified_Ideograph", "Ideographic"},
    17483: {"Unified_Ideograph", "Ideographic"},
    17484: {"Unified_Ideograph", "Ideographic"},
    17485: {"Unified_Ideograph", "Ideographic"},
    17486: {"Unified_Ideograph", "Ideographic"},
    17487: {"Unified_Ideograph", "Ideographic"},
    17488: {"Unified_Ideograph", "Ideographic"},
    17489: {"Unified_Ideograph", "Ideographic"},
    17490: {"Unified_Ideograph", "Ideographic"},
    17491: {"Unified_Ideograph", "Ideographic"},
    17492: {"Unified_Ideograph", "Ideographic"},
    17493: {"Unified_Ideograph", "Ideographic"},
    17494: {"Unified_Ideograph", "Ideographic"},
    17495: {"Unified_Ideograph", "Ideographic"},
    17496: {"Unified_Ideograph", "Ideographic"},
    17497: {"Unified_Ideograph", "Ideographic"},
    17498: {"Unified_Ideograph", "Ideographic"},
    17499: {"Unified_Ideograph", "Ideographic"},
    17500: {"Unified_Ideograph", "Ideographic"},
    17501: {"Unified_Ideograph", "Ideographic"},
    17502: {"Unified_Ideograph", "Ideographic"},
    17503: {"Unified_Ideograph", "Ideographic"},
    17504: {"Unified_Ideograph", "Ideographic"},
    17505: {"Unified_Ideograph", "Ideographic"},
    17506: {"Unified_Ideograph", "Ideographic"},
    17507: {"Unified_Ideograph", "Ideographic"},
    17508: {"Unified_Ideograph", "Ideographic"},
    17509: {"Unified_Ideograph", "Ideographic"},
    17510: {"Unified_Ideograph", "Ideographic"},
    17511: {"Unified_Ideograph", "Ideographic"},
    17512: {"Unified_Ideograph", "Ideographic"},
    17513: {"Unified_Ideograph", "Ideographic"},
    17514: {"Unified_Ideograph", "Ideographic"},
    17515: {"Unified_Ideograph", "Ideographic"},
    17516: {"Unified_Ideograph", "Ideographic"},
    17517: {"Unified_Ideograph", "Ideographic"},
    17518: {"Unified_Ideograph", "Ideographic"},
    17519: {"Unified_Ideograph", "Ideographic"},
    17520: {"Unified_Ideograph", "Ideographic"},
    17521: {"Unified_Ideograph", "Ideographic"},
    17522: {"Unified_Ideograph", "Ideographic"},
    17523: {"Unified_Ideograph", "Ideographic"},
    17524: {"Unified_Ideograph", "Ideographic"},
    17525: {"Unified_Ideograph", "Ideographic"},
    17526: {"Unified_Ideograph", "Ideographic"},
    17527: {"Unified_Ideograph", "Ideographic"},
    17528: {"Unified_Ideograph", "Ideographic"},
    17529: {"Unified_Ideograph", "Ideographic"},
    17530: {"Unified_Ideograph", "Ideographic"},
    17531: {"Unified_Ideograph", "Ideographic"},
    17532: {"Unified_Ideograph", "Ideographic"},
    17533: {"Unified_Ideograph", "Ideographic"},
    17534: {"Unified_Ideograph", "Ideographic"},
    17535: {"Unified_Ideograph", "Ideographic"},
    17536: {"Unified_Ideograph", "Ideographic"},
    17537: {"Unified_Ideograph", "Ideographic"},
    17538: {"Unified_Ideograph", "Ideographic"},
    17539: {"Unified_Ideograph", "Ideographic"},
    17540: {"Unified_Ideograph", "Ideographic"},
    17541: {"Unified_Ideograph", "Ideographic"},
    17542: {"Unified_Ideograph", "Ideographic"},
    17543: {"Unified_Ideograph", "Ideographic"},
    17544: {"Unified_Ideograph", "Ideographic"},
    17545: {"Unified_Ideograph", "Ideographic"},
    17546: {"Unified_Ideograph", "Ideographic"},
    17547: {"Unified_Ideograph", "Ideographic"},
    17548: {"Unified_Ideograph", "Ideographic"},
    17549: {"Unified_Ideograph", "Ideographic"},
    17550: {"Unified_Ideograph", "Ideographic"},
    17551: {"Unified_Ideograph", "Ideographic"},
    17552: {"Unified_Ideograph", "Ideographic"},
    17553: {"Unified_Ideograph", "Ideographic"},
    17554: {"Unified_Ideograph", "Ideographic"},
    17555: {"Unified_Ideograph", "Ideographic"},
    17556: {"Unified_Ideograph", "Ideographic"},
    17557: {"Unified_Ideograph", "Ideographic"},
    17558: {"Unified_Ideograph", "Ideographic"},
    17559: {"Unified_Ideograph", "Ideographic"},
    17560: {"Unified_Ideograph", "Ideographic"},
    17561: {"Unified_Ideograph", "Ideographic"},
    17562: {"Unified_Ideograph", "Ideographic"},
    17563: {"Unified_Ideograph", "Ideographic"},
    17564: {"Unified_Ideograph", "Ideographic"},
    17565: {"Unified_Ideograph", "Ideographic"},
    17566: {"Unified_Ideograph", "Ideographic"},
    17567: {"Unified_Ideograph", "Ideographic"},
    17568: {"Unified_Ideograph", "Ideographic"},
    17569: {"Unified_Ideograph", "Ideographic"},
    17570: {"Unified_Ideograph", "Ideographic"},
    17571: {"Unified_Ideograph", "Ideographic"},
    17572: {"Unified_Ideograph", "Ideographic"},
    17573: {"Unified_Ideograph", "Ideographic"},
    17574: {"Unified_Ideograph", "Ideographic"},
    17575: {"Unified_Ideograph", "Ideographic"},
    17576: {"Unified_Ideograph", "Ideographic"},
    17577: {"Unified_Ideograph", "Ideographic"},
    17578: {"Unified_Ideograph", "Ideographic"},
    17579: {"Unified_Ideograph", "Ideographic"},
    17580: {"Unified_Ideograph", "Ideographic"},
    17581: {"Unified_Ideograph", "Ideographic"},
    17582: {"Unified_Ideograph", "Ideographic"},
    17583: {"Unified_Ideograph", "Ideographic"},
    17584: {"Unified_Ideograph", "Ideographic"},
    17585: {"Unified_Ideograph", "Ideographic"},
    17586: {"Unified_Ideograph", "Ideographic"},
    17587: {"Unified_Ideograph", "Ideographic"},
    17588: {"Unified_Ideograph", "Ideographic"},
    17589: {"Unified_Ideograph", "Ideographic"},
    17590: {"Unified_Ideograph", "Ideographic"},
    17591: {"Unified_Ideograph", "Ideographic"},
    17592: {"Unified_Ideograph", "Ideographic"},
    17593: {"Unified_Ideograph", "Ideographic"},
    17594: {"Unified_Ideograph", "Ideographic"},
    17595: {"Unified_Ideograph", "Ideographic"},
    17596: {"Unified_Ideograph", "Ideographic"},
    17597: {"Unified_Ideograph", "Ideographic"},
    17598: {"Unified_Ideograph", "Ideographic"},
    17599: {"Unified_Ideograph", "Ideographic"},
    17600: {"Unified_Ideograph", "Ideographic"},
    17601: {"Unified_Ideograph", "Ideographic"},
    17602: {"Unified_Ideograph", "Ideographic"},
    17603: {"Unified_Ideograph", "Ideographic"},
    17604: {"Unified_Ideograph", "Ideographic"},
    17605: {"Unified_Ideograph", "Ideographic"},
    17606: {"Unified_Ideograph", "Ideographic"},
    17607: {"Unified_Ideograph", "Ideographic"},
    17608: {"Unified_Ideograph", "Ideographic"},
    17609: {"Unified_Ideograph", "Ideographic"},
    17610: {"Unified_Ideograph", "Ideographic"},
    17611: {"Unified_Ideograph", "Ideographic"},
    17612: {"Unified_Ideograph", "Ideographic"},
    17613: {"Unified_Ideograph", "Ideographic"},
    17614: {"Unified_Ideograph", "Ideographic"},
    17615: {"Unified_Ideograph", "Ideographic"},
    17616: {"Unified_Ideograph", "Ideographic"},
    17617: {"Unified_Ideograph", "Ideographic"},
    17618: {"Unified_Ideograph", "Ideographic"},
    17619: {"Unified_Ideograph", "Ideographic"},
    17620: {"Unified_Ideograph", "Ideographic"},
    17621: {"Unified_Ideograph", "Ideographic"},
    17622: {"Unified_Ideograph", "Ideographic"},
    17623: {"Unified_Ideograph", "Ideographic"},
    17624: {"Unified_Ideograph", "Ideographic"},
    17625: {"Unified_Ideograph", "Ideographic"},
    17626: {"Unified_Ideograph", "Ideographic"},
    17627: {"Unified_Ideograph", "Ideographic"},
    17628: {"Unified_Ideograph", "Ideographic"},
    17629: {"Unified_Ideograph", "Ideographic"},
    17630: {"Unified_Ideograph", "Ideographic"},
    17631: {"Unified_Ideograph", "Ideographic"},
    17632: {"Unified_Ideograph", "Ideographic"},
    17633: {"Unified_Ideograph", "Ideographic"},
    17634: {"Unified_Ideograph", "Ideographic"},
    17635: {"Unified_Ideograph", "Ideographic"},
    17636: {"Unified_Ideograph", "Ideographic"},
    17637: {"Unified_Ideograph", "Ideographic"},
    17638: {"Unified_Ideograph", "Ideographic"},
    17639: {"Unified_Ideograph", "Ideographic"},
    17640: {"Unified_Ideograph", "Ideographic"},
    17641: {"Unified_Ideograph", "Ideographic"},
    17642: {"Unified_Ideograph", "Ideographic"},
    17643: {"Unified_Ideograph", "Ideographic"},
    17644: {"Unified_Ideograph", "Ideographic"},
    17645: {"Unified_Ideograph", "Ideographic"},
    17646: {"Unified_Ideograph", "Ideographic"},
    17647: {"Unified_Ideograph", "Ideographic"},
    17648: {"Unified_Ideograph", "Ideographic"},
    17649: {"Unified_Ideograph", "Ideographic"},
    17650: {"Unified_Ideograph", "Ideographic"},
    17651: {"Unified_Ideograph", "Ideographic"},
    17652: {"Unified_Ideograph", "Ideographic"},
    17653: {"Unified_Ideograph", "Ideographic"},
    17654: {"Unified_Ideograph", "Ideographic"},
    17655: {"Unified_Ideograph", "Ideographic"},
    17656: {"Unified_Ideograph", "Ideographic"},
    17657: {"Unified_Ideograph", "Ideographic"},
    17658: {"Unified_Ideograph", "Ideographic"},
    17659: {"Unified_Ideograph", "Ideographic"},
    17660: {"Unified_Ideograph", "Ideographic"},
    17661: {"Unified_Ideograph", "Ideographic"},
    17662: {"Unified_Ideograph", "Ideographic"},
    17663: {"Unified_Ideograph", "Ideographic"},
    17664: {"Unified_Ideograph", "Ideographic"},
    17665: {"Unified_Ideograph", "Ideographic"},
    17666: {"Unified_Ideograph", "Ideographic"},
    17667: {"Unified_Ideograph", "Ideographic"},
    17668: {"Unified_Ideograph", "Ideographic"},
    17669: {"Unified_Ideograph", "Ideographic"},
    17670: {"Unified_Ideograph", "Ideographic"},
    17671: {"Unified_Ideograph", "Ideographic"},
    17672: {"Unified_Ideograph", "Ideographic"},
    17673: {"Unified_Ideograph", "Ideographic"},
    17674: {"Unified_Ideograph", "Ideographic"},
    17675: {"Unified_Ideograph", "Ideographic"},
    17676: {"Unified_Ideograph", "Ideographic"},
    17677: {"Unified_Ideograph", "Ideographic"},
    17678: {"Unified_Ideograph", "Ideographic"},
    17679: {"Unified_Ideograph", "Ideographic"},
    17680: {"Unified_Ideograph", "Ideographic"},
    17681: {"Unified_Ideograph", "Ideographic"},
    17682: {"Unified_Ideograph", "Ideographic"},
    17683: {"Unified_Ideograph", "Ideographic"},
    17684: {"Unified_Ideograph", "Ideographic"},
    17685: {"Unified_Ideograph", "Ideographic"},
    17686: {"Unified_Ideograph", "Ideographic"},
    17687: {"Unified_Ideograph", "Ideographic"},
    17688: {"Unified_Ideograph", "Ideographic"},
    17689: {"Unified_Ideograph", "Ideographic"},
    17690: {"Unified_Ideograph", "Ideographic"},
    17691: {"Unified_Ideograph", "Ideographic"},
    17692: {"Unified_Ideograph", "Ideographic"},
    17693: {"Unified_Ideograph", "Ideographic"},
    17694: {"Unified_Ideograph", "Ideographic"},
    17695: {"Unified_Ideograph", "Ideographic"},
    17696: {"Unified_Ideograph", "Ideographic"},
    17697: {"Unified_Ideograph", "Ideographic"},
    17698: {"Unified_Ideograph", "Ideographic"},
    17699: {"Unified_Ideograph", "Ideographic"},
    17700: {"Unified_Ideograph", "Ideographic"},
    17701: {"Unified_Ideograph", "Ideographic"},
    17702: {"Unified_Ideograph", "Ideographic"},
    17703: {"Unified_Ideograph", "Ideographic"},
    17704: {"Unified_Ideograph", "Ideographic"},
    17705: {"Unified_Ideograph", "Ideographic"},
    17706: {"Unified_Ideograph", "Ideographic"},
    17707: {"Unified_Ideograph", "Ideographic"},
    17708: {"Unified_Ideograph", "Ideographic"},
    17709: {"Unified_Ideograph", "Ideographic"},
    17710: {"Unified_Ideograph", "Ideographic"},
    17711: {"Unified_Ideograph", "Ideographic"},
    17712: {"Unified_Ideograph", "Ideographic"},
    17713: {"Unified_Ideograph", "Ideographic"},
    17714: {"Unified_Ideograph", "Ideographic"},
    17715: {"Unified_Ideograph", "Ideographic"},
    17716: {"Unified_Ideograph", "Ideographic"},
    17717: {"Unified_Ideograph", "Ideographic"},
    17718: {"Unified_Ideograph", "Ideographic"},
    17719: {"Unified_Ideograph", "Ideographic"},
    17720: {"Unified_Ideograph", "Ideographic"},
    17721: {"Unified_Ideograph", "Ideographic"},
    17722: {"Unified_Ideograph", "Ideographic"},
    17723: {"Unified_Ideograph", "Ideographic"},
    17724: {"Unified_Ideograph", "Ideographic"},
    17725: {"Unified_Ideograph", "Ideographic"},
    17726: {"Unified_Ideograph", "Ideographic"},
    17727: {"Unified_Ideograph", "Ideographic"},
    17728: {"Unified_Ideograph", "Ideographic"},
    17729: {"Unified_Ideograph", "Ideographic"},
    17730: {"Unified_Ideograph", "Ideographic"},
    17731: {"Unified_Ideograph", "Ideographic"},
    17732: {"Unified_Ideograph", "Ideographic"},
    17733: {"Unified_Ideograph", "Ideographic"},
    17734: {"Unified_Ideograph", "Ideographic"},
    17735: {"Unified_Ideograph", "Ideographic"},
    17736: {"Unified_Ideograph", "Ideographic"},
    17737: {"Unified_Ideograph", "Ideographic"},
    17738: {"Unified_Ideograph", "Ideographic"},
    17739: {"Unified_Ideograph", "Ideographic"},
    17740: {"Unified_Ideograph", "Ideographic"},
    17741: {"Unified_Ideograph", "Ideographic"},
    17742: {"Unified_Ideograph", "Ideographic"},
    17743: {"Unified_Ideograph", "Ideographic"},
    17744: {"Unified_Ideograph", "Ideographic"},
    17745: {"Unified_Ideograph", "Ideographic"},
    17746: {"Unified_Ideograph", "Ideographic"},
    17747: {"Unified_Ideograph", "Ideographic"},
    17748: {"Unified_Ideograph", "Ideographic"},
    17749: {"Unified_Ideograph", "Ideographic"},
    17750: {"Unified_Ideograph", "Ideographic"},
    17751: {"Unified_Ideograph", "Ideographic"},
    17752: {"Unified_Ideograph", "Ideographic"},
    17753: {"Unified_Ideograph", "Ideographic"},
    17754: {"Unified_Ideograph", "Ideographic"},
    17755: {"Unified_Ideograph", "Ideographic"},
    17756: {"Unified_Ideograph", "Ideographic"},
    17757: {"Unified_Ideograph", "Ideographic"},
    17758: {"Unified_Ideograph", "Ideographic"},
    17759: {"Unified_Ideograph", "Ideographic"},
    17760: {"Unified_Ideograph", "Ideographic"},
    17761: {"Unified_Ideograph", "Ideographic"},
    17762: {"Unified_Ideograph", "Ideographic"},
    17763: {"Unified_Ideograph", "Ideographic"},
    17764: {"Unified_Ideograph", "Ideographic"},
    17765: {"Unified_Ideograph", "Ideographic"},
    17766: {"Unified_Ideograph", "Ideographic"},
    17767: {"Unified_Ideograph", "Ideographic"},
    17768: {"Unified_Ideograph", "Ideographic"},
    17769: {"Unified_Ideograph", "Ideographic"},
    17770: {"Unified_Ideograph", "Ideographic"},
    17771: {"Unified_Ideograph", "Ideographic"},
    17772: {"Unified_Ideograph", "Ideographic"},
    17773: {"Unified_Ideograph", "Ideographic"},
    17774: {"Unified_Ideograph", "Ideographic"},
    17775: {"Unified_Ideograph", "Ideographic"},
    17776: {"Unified_Ideograph", "Ideographic"},
    17777: {"Unified_Ideograph", "Ideographic"},
    17778: {"Unified_Ideograph", "Ideographic"},
    17779: {"Unified_Ideograph", "Ideographic"},
    17780: {"Unified_Ideograph", "Ideographic"},
    17781: {"Unified_Ideograph", "Ideographic"},
    17782: {"Unified_Ideograph", "Ideographic"},
    17783: {"Unified_Ideograph", "Ideographic"},
    17784: {"Unified_Ideograph", "Ideographic"},
    17785: {"Unified_Ideograph", "Ideographic"},
    17786: {"Unified_Ideograph", "Ideographic"},
    17787: {"Unified_Ideograph", "Ideographic"},
    17788: {"Unified_Ideograph", "Ideographic"},
    17789: {"Unified_Ideograph", "Ideographic"},
    17790: {"Unified_Ideograph", "Ideographic"},
    17791: {"Unified_Ideograph", "Ideographic"},
    17792: {"Unified_Ideograph", "Ideographic"},
    17793: {"Unified_Ideograph", "Ideographic"},
    17794: {"Unified_Ideograph", "Ideographic"},
    17795: {"Unified_Ideograph", "Ideographic"},
    17796: {"Unified_Ideograph", "Ideographic"},
    17797: {"Unified_Ideograph", "Ideographic"},
    17798: {"Unified_Ideograph", "Ideographic"},
    17799: {"Unified_Ideograph", "Ideographic"},
    17800: {"Unified_Ideograph", "Ideographic"},
    17801: {"Unified_Ideograph", "Ideographic"},
    17802: {"Unified_Ideograph", "Ideographic"},
    17803: {"Unified_Ideograph", "Ideographic"},
    17804: {"Unified_Ideograph", "Ideographic"},
    17805: {"Unified_Ideograph", "Ideographic"},
    17806: {"Unified_Ideograph", "Ideographic"},
    17807: {"Unified_Ideograph", "Ideographic"},
    17808: {"Unified_Ideograph", "Ideographic"},
    17809: {"Unified_Ideograph", "Ideographic"},
    17810: {"Unified_Ideograph", "Ideographic"},
    17811: {"Unified_Ideograph", "Ideographic"},
    17812: {"Unified_Ideograph", "Ideographic"},
    17813: {"Unified_Ideograph", "Ideographic"},
    17814: {"Unified_Ideograph", "Ideographic"},
    17815: {"Unified_Ideograph", "Ideographic"},
    17816: {"Unified_Ideograph", "Ideographic"},
    17817: {"Unified_Ideograph", "Ideographic"},
    17818: {"Unified_Ideograph", "Ideographic"},
    17819: {"Unified_Ideograph", "Ideographic"},
    17820: {"Unified_Ideograph", "Ideographic"},
    17821: {"Unified_Ideograph", "Ideographic"},
    17822: {"Unified_Ideograph", "Ideographic"},
    17823: {"Unified_Ideograph", "Ideographic"},
    17824: {"Unified_Ideograph", "Ideographic"},
    17825: {"Unified_Ideograph", "Ideographic"},
    17826: {"Unified_Ideograph", "Ideographic"},
    17827: {"Unified_Ideograph", "Ideographic"},
    17828: {"Unified_Ideograph", "Ideographic"},
    17829: {"Unified_Ideograph", "Ideographic"},
    17830: {"Unified_Ideograph", "Ideographic"},
    17831: {"Unified_Ideograph", "Ideographic"},
    17832: {"Unified_Ideograph", "Ideographic"},
    17833: {"Unified_Ideograph", "Ideographic"},
    17834: {"Unified_Ideograph", "Ideographic"},
    17835: {"Unified_Ideograph", "Ideographic"},
    17836: {"Unified_Ideograph", "Ideographic"},
    17837: {"Unified_Ideograph", "Ideographic"},
    17838: {"Unified_Ideograph", "Ideographic"},
    17839: {"Unified_Ideograph", "Ideographic"},
    17840: {"Unified_Ideograph", "Ideographic"},
    17841: {"Unified_Ideograph", "Ideographic"},
    17842: {"Unified_Ideograph", "Ideographic"},
    17843: {"Unified_Ideograph", "Ideographic"},
    17844: {"Unified_Ideograph", "Ideographic"},
    17845: {"Unified_Ideograph", "Ideographic"},
    17846: {"Unified_Ideograph", "Ideographic"},
    17847: {"Unified_Ideograph", "Ideographic"},
    17848: {"Unified_Ideograph", "Ideographic"},
    17849: {"Unified_Ideograph", "Ideographic"},
    17850: {"Unified_Ideograph", "Ideographic"},
    17851: {"Unified_Ideograph", "Ideographic"},
    17852: {"Unified_Ideograph", "Ideographic"},
    17853: {"Unified_Ideograph", "Ideographic"},
    17854: {"Unified_Ideograph", "Ideographic"},
    17855: {"Unified_Ideograph", "Ideographic"},
    17856: {"Unified_Ideograph", "Ideographic"},
    17857: {"Unified_Ideograph", "Ideographic"},
    17858: {"Unified_Ideograph", "Ideographic"},
    17859: {"Unified_Ideograph", "Ideographic"},
    17860: {"Unified_Ideograph", "Ideographic"},
    17861: {"Unified_Ideograph", "Ideographic"},
    17862: {"Unified_Ideograph", "Ideographic"},
    17863: {"Unified_Ideograph", "Ideographic"},
    17864: {"Unified_Ideograph", "Ideographic"},
    17865: {"Unified_Ideograph", "Ideographic"},
    17866: {"Unified_Ideograph", "Ideographic"},
    17867: {"Unified_Ideograph", "Ideographic"},
    17868: {"Unified_Ideograph", "Ideographic"},
    17869: {"Unified_Ideograph", "Ideographic"},
    17870: {"Unified_Ideograph", "Ideographic"},
    17871: {"Unified_Ideograph", "Ideographic"},
    17872: {"Unified_Ideograph", "Ideographic"},
    17873: {"Unified_Ideograph", "Ideographic"},
    17874: {"Unified_Ideograph", "Ideographic"},
    17875: {"Unified_Ideograph", "Ideographic"},
    17876: {"Unified_Ideograph", "Ideographic"},
    17877: {"Unified_Ideograph", "Ideographic"},
    17878: {"Unified_Ideograph", "Ideographic"},
    17879: {"Unified_Ideograph", "Ideographic"},
    17880: {"Unified_Ideograph", "Ideographic"},
    17881: {"Unified_Ideograph", "Ideographic"},
    17882: {"Unified_Ideograph", "Ideographic"},
    17883: {"Unified_Ideograph", "Ideographic"},
    17884: {"Unified_Ideograph", "Ideographic"},
    17885: {"Unified_Ideograph", "Ideographic"},
    17886: {"Unified_Ideograph", "Ideographic"},
    17887: {"Unified_Ideograph", "Ideographic"},
    17888: {"Unified_Ideograph", "Ideographic"},
    17889: {"Unified_Ideograph", "Ideographic"},
    17890: {"Unified_Ideograph", "Ideographic"},
    17891: {"Unified_Ideograph", "Ideographic"},
    17892: {"Unified_Ideograph", "Ideographic"},
    17893: {"Unified_Ideograph", "Ideographic"},
    17894: {"Unified_Ideograph", "Ideographic"},
    17895: {"Unified_Ideograph", "Ideographic"},
    17896: {"Unified_Ideograph", "Ideographic"},
    17897: {"Unified_Ideograph", "Ideographic"},
    17898: {"Unified_Ideograph", "Ideographic"},
    17899: {"Unified_Ideograph", "Ideographic"},
    17900: {"Unified_Ideograph", "Ideographic"},
    17901: {"Unified_Ideograph", "Ideographic"},
    17902: {"Unified_Ideograph", "Ideographic"},
    17903: {"Unified_Ideograph", "Ideographic"},
    17904: {"Unified_Ideograph", "Ideographic"},
    17905: {"Unified_Ideograph", "Ideographic"},
    17906: {"Unified_Ideograph", "Ideographic"},
    17907: {"Unified_Ideograph", "Ideographic"},
    17908: {"Unified_Ideograph", "Ideographic"},
    17909: {"Unified_Ideograph", "Ideographic"},
    17910: {"Unified_Ideograph", "Ideographic"},
    17911: {"Unified_Ideograph", "Ideographic"},
    17912: {"Unified_Ideograph", "Ideographic"},
    17913: {"Unified_Ideograph", "Ideographic"},
    17914: {"Unified_Ideograph", "Ideographic"},
    17915: {"Unified_Ideograph", "Ideographic"},
    17916: {"Unified_Ideograph", "Ideographic"},
    17917: {"Unified_Ideograph", "Ideographic"},
    17918: {"Unified_Ideograph", "Ideographic"},
    17919: {"Unified_Ideograph", "Ideographic"},
    17920: {"Unified_Ideograph", "Ideographic"},
    17921: {"Unified_Ideograph", "Ideographic"},
    17922: {"Unified_Ideograph", "Ideographic"},
    17923: {"Unified_Ideograph", "Ideographic"},
    17924: {"Unified_Ideograph", "Ideographic"},
    17925: {"Unified_Ideograph", "Ideographic"},
    17926: {"Unified_Ideograph", "Ideographic"},
    17927: {"Unified_Ideograph", "Ideographic"},
    17928: {"Unified_Ideograph", "Ideographic"},
    17929: {"Unified_Ideograph", "Ideographic"},
    17930: {"Unified_Ideograph", "Ideographic"},
    17931: {"Unified_Ideograph", "Ideographic"},
    17932: {"Unified_Ideograph", "Ideographic"},
    17933: {"Unified_Ideograph", "Ideographic"},
    17934: {"Unified_Ideograph", "Ideographic"},
    17935: {"Unified_Ideograph", "Ideographic"},
    17936: {"Unified_Ideograph", "Ideographic"},
    17937: {"Unified_Ideograph", "Ideographic"},
    17938: {"Unified_Ideograph", "Ideographic"},
    17939: {"Unified_Ideograph", "Ideographic"},
    17940: {"Unified_Ideograph", "Ideographic"},
    17941: {"Unified_Ideograph", "Ideographic"},
    17942: {"Unified_Ideograph", "Ideographic"},
    17943: {"Unified_Ideograph", "Ideographic"},
    17944: {"Unified_Ideograph", "Ideographic"},
    17945: {"Unified_Ideograph", "Ideographic"},
    17946: {"Unified_Ideograph", "Ideographic"},
    17947: {"Unified_Ideograph", "Ideographic"},
    17948: {"Unified_Ideograph", "Ideographic"},
    17949: {"Unified_Ideograph", "Ideographic"},
    17950: {"Unified_Ideograph", "Ideographic"},
    17951: {"Unified_Ideograph", "Ideographic"},
    17952: {"Unified_Ideograph", "Ideographic"},
    17953: {"Unified_Ideograph", "Ideographic"},
    17954: {"Unified_Ideograph", "Ideographic"},
    17955: {"Unified_Ideograph", "Ideographic"},
    17956: {"Unified_Ideograph", "Ideographic"},
    17957: {"Unified_Ideograph", "Ideographic"},
    17958: {"Unified_Ideograph", "Ideographic"},
    17959: {"Unified_Ideograph", "Ideographic"},
    17960: {"Unified_Ideograph", "Ideographic"},
    17961: {"Unified_Ideograph", "Ideographic"},
    17962: {"Unified_Ideograph", "Ideographic"},
    17963: {"Unified_Ideograph", "Ideographic"},
    17964: {"Unified_Ideograph", "Ideographic"},
    17965: {"Unified_Ideograph", "Ideographic"},
    17966: {"Unified_Ideograph", "Ideographic"},
    17967: {"Unified_Ideograph", "Ideographic"},
    17968: {"Unified_Ideograph", "Ideographic"},
    17969: {"Unified_Ideograph", "Ideographic"},
    17970: {"Unified_Ideograph", "Ideographic"},
    17971: {"Unified_Ideograph", "Ideographic"},
    17972: {"Unified_Ideograph", "Ideographic"},
    17973: {"Unified_Ideograph", "Ideographic"},
    17974: {"Unified_Ideograph", "Ideographic"},
    17975: {"Unified_Ideograph", "Ideographic"},
    17976: {"Unified_Ideograph", "Ideographic"},
    17977: {"Unified_Ideograph", "Ideographic"},
    17978: {"Unified_Ideograph", "Ideographic"},
    17979: {"Unified_Ideograph", "Ideographic"},
    17980: {"Unified_Ideograph", "Ideographic"},
    17981: {"Unified_Ideograph", "Ideographic"},
    17982: {"Unified_Ideograph", "Ideographic"},
    17983: {"Unified_Ideograph", "Ideographic"},
    17984: {"Unified_Ideograph", "Ideographic"},
    17985: {"Unified_Ideograph", "Ideographic"},
    17986: {"Unified_Ideograph", "Ideographic"},
    17987: {"Unified_Ideograph", "Ideographic"},
    17988: {"Unified_Ideograph", "Ideographic"},
    17989: {"Unified_Ideograph", "Ideographic"},
    17990: {"Unified_Ideograph", "Ideographic"},
    17991: {"Unified_Ideograph", "Ideographic"},
    17992: {"Unified_Ideograph", "Ideographic"},
    17993: {"Unified_Ideograph", "Ideographic"},
    17994: {"Unified_Ideograph", "Ideographic"},
    17995: {"Unified_Ideograph", "Ideographic"},
    17996: {"Unified_Ideograph", "Ideographic"},
    17997: {"Unified_Ideograph", "Ideographic"},
    17998: {"Unified_Ideograph", "Ideographic"},
    17999: {"Unified_Ideograph", "Ideographic"},
    18000: {"Unified_Ideograph", "Ideographic"},
    18001: {"Unified_Ideograph", "Ideographic"},
    18002: {"Unified_Ideograph", "Ideographic"},
    18003: {"Unified_Ideograph", "Ideographic"},
    18004: {"Unified_Ideograph", "Ideographic"},
    18005: {"Unified_Ideograph", "Ideographic"},
    18006: {"Unified_Ideograph", "Ideographic"},
    18007: {"Unified_Ideograph", "Ideographic"},
    18008: {"Unified_Ideograph", "Ideographic"},
    18009: {"Unified_Ideograph", "Ideographic"},
    18010: {"Unified_Ideograph", "Ideographic"},
    18011: {"Unified_Ideograph", "Ideographic"},
    18012: {"Unified_Ideograph", "Ideographic"},
    18013: {"Unified_Ideograph", "Ideographic"},
    18014: {"Unified_Ideograph", "Ideographic"},
    18015: {"Unified_Ideograph", "Ideographic"},
    18016: {"Unified_Ideograph", "Ideographic"},
    18017: {"Unified_Ideograph", "Ideographic"},
    18018: {"Unified_Ideograph", "Ideographic"},
    18019: {"Unified_Ideograph", "Ideographic"},
    18020: {"Unified_Ideograph", "Ideographic"},
    18021: {"Unified_Ideograph", "Ideographic"},
    18022: {"Unified_Ideograph", "Ideographic"},
    18023: {"Unified_Ideograph", "Ideographic"},
    18024: {"Unified_Ideograph", "Ideographic"},
    18025: {"Unified_Ideograph", "Ideographic"},
    18026: {"Unified_Ideograph", "Ideographic"},
    18027: {"Unified_Ideograph", "Ideographic"},
    18028: {"Unified_Ideograph", "Ideographic"},
    18029: {"Unified_Ideograph", "Ideographic"},
    18030: {"Unified_Ideograph", "Ideographic"},
    18031: {"Unified_Ideograph", "Ideographic"},
    18032: {"Unified_Ideograph", "Ideographic"},
    18033: {"Unified_Ideograph", "Ideographic"},
    18034: {"Unified_Ideograph", "Ideographic"},
    18035: {"Unified_Ideograph", "Ideographic"},
    18036: {"Unified_Ideograph", "Ideographic"},
    18037: {"Unified_Ideograph", "Ideographic"},
    18038: {"Unified_Ideograph", "Ideographic"},
    18039: {"Unified_Ideograph", "Ideographic"},
    18040: {"Unified_Ideograph", "Ideographic"},
    18041: {"Unified_Ideograph", "Ideographic"},
    18042: {"Unified_Ideograph", "Ideographic"},
    18043: {"Unified_Ideograph", "Ideographic"},
    18044: {"Unified_Ideograph", "Ideographic"},
    18045: {"Unified_Ideograph", "Ideographic"},
    18046: {"Unified_Ideograph", "Ideographic"},
    18047: {"Unified_Ideograph", "Ideographic"},
    18048: {"Unified_Ideograph", "Ideographic"},
    18049: {"Unified_Ideograph", "Ideographic"},
    18050: {"Unified_Ideograph", "Ideographic"},
    18051: {"Unified_Ideograph", "Ideographic"},
    18052: {"Unified_Ideograph", "Ideographic"},
    18053: {"Unified_Ideograph", "Ideographic"},
    18054: {"Unified_Ideograph", "Ideographic"},
    18055: {"Unified_Ideograph", "Ideographic"},
    18056: {"Unified_Ideograph", "Ideographic"},
    18057: {"Unified_Ideograph", "Ideographic"},
    18058: {"Unified_Ideograph", "Ideographic"},
    18059: {"Unified_Ideograph", "Ideographic"},
    18060: {"Unified_Ideograph", "Ideographic"},
    18061: {"Unified_Ideograph", "Ideographic"},
    18062: {"Unified_Ideograph", "Ideographic"},
    18063: {"Unified_Ideograph", "Ideographic"},
    18064: {"Unified_Ideograph", "Ideographic"},
    18065: {"Unified_Ideograph", "Ideographic"},
    18066: {"Unified_Ideograph", "Ideographic"},
    18067: {"Unified_Ideograph", "Ideographic"},
    18068: {"Unified_Ideograph", "Ideographic"},
    18069: {"Unified_Ideograph", "Ideographic"},
    18070: {"Unified_Ideograph", "Ideographic"},
    18071: {"Unified_Ideograph", "Ideographic"},
    18072: {"Unified_Ideograph", "Ideographic"},
    18073: {"Unified_Ideograph", "Ideographic"},
    18074: {"Unified_Ideograph", "Ideographic"},
    18075: {"Unified_Ideograph", "Ideographic"},
    18076: {"Unified_Ideograph", "Ideographic"},
    18077: {"Unified_Ideograph", "Ideographic"},
    18078: {"Unified_Ideograph", "Ideographic"},
    18079: {"Unified_Ideograph", "Ideographic"},
    18080: {"Unified_Ideograph", "Ideographic"},
    18081: {"Unified_Ideograph", "Ideographic"},
    18082: {"Unified_Ideograph", "Ideographic"},
    18083: {"Unified_Ideograph", "Ideographic"},
    18084: {"Unified_Ideograph", "Ideographic"},
    18085: {"Unified_Ideograph", "Ideographic"},
    18086: {"Unified_Ideograph", "Ideographic"},
    18087: {"Unified_Ideograph", "Ideographic"},
    18088: {"Unified_Ideograph", "Ideographic"},
    18089: {"Unified_Ideograph", "Ideographic"},
    18090: {"Unified_Ideograph", "Ideographic"},
    18091: {"Unified_Ideograph", "Ideographic"},
    18092: {"Unified_Ideograph", "Ideographic"},
    18093: {"Unified_Ideograph", "Ideographic"},
    18094: {"Unified_Ideograph", "Ideographic"},
    18095: {"Unified_Ideograph", "Ideographic"},
    18096: {"Unified_Ideograph", "Ideographic"},
    18097: {"Unified_Ideograph", "Ideographic"},
    18098: {"Unified_Ideograph", "Ideographic"},
    18099: {"Unified_Ideograph", "Ideographic"},
    18100: {"Unified_Ideograph", "Ideographic"},
    18101: {"Unified_Ideograph", "Ideographic"},
    18102: {"Unified_Ideograph", "Ideographic"},
    18103: {"Unified_Ideograph", "Ideographic"},
    18104: {"Unified_Ideograph", "Ideographic"},
    18105: {"Unified_Ideograph", "Ideographic"},
    18106: {"Unified_Ideograph", "Ideographic"},
    18107: {"Unified_Ideograph", "Ideographic"},
    18108: {"Unified_Ideograph", "Ideographic"},
    18109: {"Unified_Ideograph", "Ideographic"},
    18110: {"Unified_Ideograph", "Ideographic"},
    18111: {"Unified_Ideograph", "Ideographic"},
    18112: {"Unified_Ideograph", "Ideographic"},
    18113: {"Unified_Ideograph", "Ideographic"},
    18114: {"Unified_Ideograph", "Ideographic"},
    18115: {"Unified_Ideograph", "Ideographic"},
    18116: {"Unified_Ideograph", "Ideographic"},
    18117: {"Unified_Ideograph", "Ideographic"},
    18118: {"Unified_Ideograph", "Ideographic"},
    18119: {"Unified_Ideograph", "Ideographic"},
    18120: {"Unified_Ideograph", "Ideographic"},
    18121: {"Unified_Ideograph", "Ideographic"},
    18122: {"Unified_Ideograph", "Ideographic"},
    18123: {"Unified_Ideograph", "Ideographic"},
    18124: {"Unified_Ideograph", "Ideographic"},
    18125: {"Unified_Ideograph", "Ideographic"},
    18126: {"Unified_Ideograph", "Ideographic"},
    18127: {"Unified_Ideograph", "Ideographic"},
    18128: {"Unified_Ideograph", "Ideographic"},
    18129: {"Unified_Ideograph", "Ideographic"},
    18130: {"Unified_Ideograph", "Ideographic"},
    18131: {"Unified_Ideograph", "Ideographic"},
    18132: {"Unified_Ideograph", "Ideographic"},
    18133: {"Unified_Ideograph", "Ideographic"},
    18134: {"Unified_Ideograph", "Ideographic"},
    18135: {"Unified_Ideograph", "Ideographic"},
    18136: {"Unified_Ideograph", "Ideographic"},
    18137: {"Unified_Ideograph", "Ideographic"},
    18138: {"Unified_Ideograph", "Ideographic"},
    18139: {"Unified_Ideograph", "Ideographic"},
    18140: {"Unified_Ideograph", "Ideographic"},
    18141: {"Unified_Ideograph", "Ideographic"},
    18142: {"Unified_Ideograph", "Ideographic"},
    18143: {"Unified_Ideograph", "Ideographic"},
    18144: {"Unified_Ideograph", "Ideographic"},
    18145: {"Unified_Ideograph", "Ideographic"},
    18146: {"Unified_Ideograph", "Ideographic"},
    18147: {"Unified_Ideograph", "Ideographic"},
    18148: {"Unified_Ideograph", "Ideographic"},
    18149: {"Unified_Ideograph", "Ideographic"},
    18150: {"Unified_Ideograph", "Ideographic"},
    18151: {"Unified_Ideograph", "Ideographic"},
    18152: {"Unified_Ideograph", "Ideographic"},
    18153: {"Unified_Ideograph", "Ideographic"},
    18154: {"Unified_Ideograph", "Ideographic"},
    18155: {"Unified_Ideograph", "Ideographic"},
    18156: {"Unified_Ideograph", "Ideographic"},
    18157: {"Unified_Ideograph", "Ideographic"},
    18158: {"Unified_Ideograph", "Ideographic"},
    18159: {"Unified_Ideograph", "Ideographic"},
    18160: {"Unified_Ideograph", "Ideographic"},
    18161: {"Unified_Ideograph", "Ideographic"},
    18162: {"Unified_Ideograph", "Ideographic"},
    18163: {"Unified_Ideograph", "Ideographic"},
    18164: {"Unified_Ideograph", "Ideographic"},
    18165: {"Unified_Ideograph", "Ideographic"},
    18166: {"Unified_Ideograph", "Ideographic"},
    18167: {"Unified_Ideograph", "Ideographic"},
    18168: {"Unified_Ideograph", "Ideographic"},
    18169: {"Unified_Ideograph", "Ideographic"},
    18170: {"Unified_Ideograph", "Ideographic"},
    18171: {"Unified_Ideograph", "Ideographic"},
    18172: {"Unified_Ideograph", "Ideographic"},
    18173: {"Unified_Ideograph", "Ideographic"},
    18174: {"Unified_Ideograph", "Ideographic"},
    18175: {"Unified_Ideograph", "Ideographic"},
    18176: {"Unified_Ideograph", "Ideographic"},
    18177: {"Unified_Ideograph", "Ideographic"},
    18178: {"Unified_Ideograph", "Ideographic"},
    18179: {"Unified_Ideograph", "Ideographic"},
    18180: {"Unified_Ideograph", "Ideographic"},
    18181: {"Unified_Ideograph", "Ideographic"},
    18182: {"Unified_Ideograph", "Ideographic"},
    18183: {"Unified_Ideograph", "Ideographic"},
    18184: {"Unified_Ideograph", "Ideographic"},
    18185: {"Unified_Ideograph", "Ideographic"},
    18186: {"Unified_Ideograph", "Ideographic"},
    18187: {"Unified_Ideograph", "Ideographic"},
    18188: {"Unified_Ideograph", "Ideographic"},
    18189: {"Unified_Ideograph", "Ideographic"},
    18190: {"Unified_Ideograph", "Ideographic"},
    18191: {"Unified_Ideograph", "Ideographic"},
    18192: {"Unified_Ideograph", "Ideographic"},
    18193: {"Unified_Ideograph", "Ideographic"},
    18194: {"Unified_Ideograph", "Ideographic"},
    18195: {"Unified_Ideograph", "Ideographic"},
    18196: {"Unified_Ideograph", "Ideographic"},
    18197: {"Unified_Ideograph", "Ideographic"},
    18198: {"Unified_Ideograph", "Ideographic"},
    18199: {"Unified_Ideograph", "Ideographic"},
    18200: {"Unified_Ideograph", "Ideographic"},
    18201: {"Unified_Ideograph", "Ideographic"},
    18202: {"Unified_Ideograph", "Ideographic"},
    18203: {"Unified_Ideograph", "Ideographic"},
    18204: {"Unified_Ideograph", "Ideographic"},
    18205: {"Unified_Ideograph", "Ideographic"},
    18206: {"Unified_Ideograph", "Ideographic"},
    18207: {"Unified_Ideograph", "Ideographic"},
    18208: {"Unified_Ideograph", "Ideographic"},
    18209: {"Unified_Ideograph", "Ideographic"},
    18210: {"Unified_Ideograph", "Ideographic"},
    18211: {"Unified_Ideograph", "Ideographic"},
    18212: {"Unified_Ideograph", "Ideographic"},
    18213: {"Unified_Ideograph", "Ideographic"},
    18214: {"Unified_Ideograph", "Ideographic"},
    18215: {"Unified_Ideograph", "Ideographic"},
    18216: {"Unified_Ideograph", "Ideographic"},
    18217: {"Unified_Ideograph", "Ideographic"},
    18218: {"Unified_Ideograph", "Ideographic"},
    18219: {"Unified_Ideograph", "Ideographic"},
    18220: {"Unified_Ideograph", "Ideographic"},
    18221: {"Unified_Ideograph", "Ideographic"},
    18222: {"Unified_Ideograph", "Ideographic"},
    18223: {"Unified_Ideograph", "Ideographic"},
    18224: {"Unified_Ideograph", "Ideographic"},
    18225: {"Unified_Ideograph", "Ideographic"},
    18226: {"Unified_Ideograph", "Ideographic"},
    18227: {"Unified_Ideograph", "Ideographic"},
    18228: {"Unified_Ideograph", "Ideographic"},
    18229: {"Unified_Ideograph", "Ideographic"},
    18230: {"Unified_Ideograph", "Ideographic"},
    18231: {"Unified_Ideograph", "Ideographic"},
    18232: {"Unified_Ideograph", "Ideographic"},
    18233: {"Unified_Ideograph", "Ideographic"},
    18234: {"Unified_Ideograph", "Ideographic"},
    18235: {"Unified_Ideograph", "Ideographic"},
    18236: {"Unified_Ideograph", "Ideographic"},
    18237: {"Unified_Ideograph", "Ideographic"},
    18238: {"Unified_Ideograph", "Ideographic"},
    18239: {"Unified_Ideograph", "Ideographic"},
    18240: {"Unified_Ideograph", "Ideographic"},
    18241: {"Unified_Ideograph", "Ideographic"},
    18242: {"Unified_Ideograph", "Ideographic"},
    18243: {"Unified_Ideograph", "Ideographic"},
    18244: {"Unified_Ideograph", "Ideographic"},
    18245: {"Unified_Ideograph", "Ideographic"},
    18246: {"Unified_Ideograph", "Ideographic"},
    18247: {"Unified_Ideograph", "Ideographic"},
    18248: {"Unified_Ideograph", "Ideographic"},
    18249: {"Unified_Ideograph", "Ideographic"},
    18250: {"Unified_Ideograph", "Ideographic"},
    18251: {"Unified_Ideograph", "Ideographic"},
    18252: {"Unified_Ideograph", "Ideographic"},
    18253: {"Unified_Ideograph", "Ideographic"},
    18254: {"Unified_Ideograph", "Ideographic"},
    18255: {"Unified_Ideograph", "Ideographic"},
    18256: {"Unified_Ideograph", "Ideographic"},
    18257: {"Unified_Ideograph", "Ideographic"},
    18258: {"Unified_Ideograph", "Ideographic"},
    18259: {"Unified_Ideograph", "Ideographic"},
    18260: {"Unified_Ideograph", "Ideographic"},
    18261: {"Unified_Ideograph", "Ideographic"},
    18262: {"Unified_Ideograph", "Ideographic"},
    18263: {"Unified_Ideograph", "Ideographic"},
    18264: {"Unified_Ideograph", "Ideographic"},
    18265: {"Unified_Ideograph", "Ideographic"},
    18266: {"Unified_Ideograph", "Ideographic"},
    18267: {"Unified_Ideograph", "Ideographic"},
    18268: {"Unified_Ideograph", "Ideographic"},
    18269: {"Unified_Ideograph", "Ideographic"},
    18270: {"Unified_Ideograph", "Ideographic"},
    18271: {"Unified_Ideograph", "Ideographic"},
    18272: {"Unified_Ideograph", "Ideographic"},
    18273: {"Unified_Ideograph", "Ideographic"},
    18274: {"Unified_Ideograph", "Ideographic"},
    18275: {"Unified_Ideograph", "Ideographic"},
    18276: {"Unified_Ideograph", "Ideographic"},
    18277: {"Unified_Ideograph", "Ideographic"},
    18278: {"Unified_Ideograph", "Ideographic"},
    18279: {"Unified_Ideograph", "Ideographic"},
    18280: {"Unified_Ideograph", "Ideographic"},
    18281: {"Unified_Ideograph", "Ideographic"},
    18282: {"Unified_Ideograph", "Ideographic"},
    18283: {"Unified_Ideograph", "Ideographic"},
    18284: {"Unified_Ideograph", "Ideographic"},
    18285: {"Unified_Ideograph", "Ideographic"},
    18286: {"Unified_Ideograph", "Ideographic"},
    18287: {"Unified_Ideograph", "Ideographic"},
    18288: {"Unified_Ideograph", "Ideographic"},
    18289: {"Unified_Ideograph", "Ideographic"},
    18290: {"Unified_Ideograph", "Ideographic"},
    18291: {"Unified_Ideograph", "Ideographic"},
    18292: {"Unified_Ideograph", "Ideographic"},
    18293: {"Unified_Ideograph", "Ideographic"},
    18294: {"Unified_Ideograph", "Ideographic"},
    18295: {"Unified_Ideograph", "Ideographic"},
    18296: {"Unified_Ideograph", "Ideographic"},
    18297: {"Unified_Ideograph", "Ideographic"},
    18298: {"Unified_Ideograph", "Ideographic"},
    18299: {"Unified_Ideograph", "Ideographic"},
    18300: {"Unified_Ideograph", "Ideographic"},
    18301: {"Unified_Ideograph", "Ideographic"},
    18302: {"Unified_Ideograph", "Ideographic"},
    18303: {"Unified_Ideograph", "Ideographic"},
    18304: {"Unified_Ideograph", "Ideographic"},
    18305: {"Unified_Ideograph", "Ideographic"},
    18306: {"Unified_Ideograph", "Ideographic"},
    18307: {"Unified_Ideograph", "Ideographic"},
    18308: {"Unified_Ideograph", "Ideographic"},
    18309: {"Unified_Ideograph", "Ideographic"},
    18310: {"Unified_Ideograph", "Ideographic"},
    18311: {"Unified_Ideograph", "Ideographic"},
    18312: {"Unified_Ideograph", "Ideographic"},
    18313: {"Unified_Ideograph", "Ideographic"},
    18314: {"Unified_Ideograph", "Ideographic"},
    18315: {"Unified_Ideograph", "Ideographic"},
    18316: {"Unified_Ideograph", "Ideographic"},
    18317: {"Unified_Ideograph", "Ideographic"},
    18318: {"Unified_Ideograph", "Ideographic"},
    18319: {"Unified_Ideograph", "Ideographic"},
    18320: {"Unified_Ideograph", "Ideographic"},
    18321: {"Unified_Ideograph", "Ideographic"},
    18322: {"Unified_Ideograph", "Ideographic"},
    18323: {"Unified_Ideograph", "Ideographic"},
    18324: {"Unified_Ideograph", "Ideographic"},
    18325: {"Unified_Ideograph", "Ideographic"},
    18326: {"Unified_Ideograph", "Ideographic"},
    18327: {"Unified_Ideograph", "Ideographic"},
    18328: {"Unified_Ideograph", "Ideographic"},
    18329: {"Unified_Ideograph", "Ideographic"},
    18330: {"Unified_Ideograph", "Ideographic"},
    18331: {"Unified_Ideograph", "Ideographic"},
    18332: {"Unified_Ideograph", "Ideographic"},
    18333: {"Unified_Ideograph", "Ideographic"},
    18334: {"Unified_Ideograph", "Ideographic"},
    18335: {"Unified_Ideograph", "Ideographic"},
    18336: {"Unified_Ideograph", "Ideographic"},
    18337: {"Unified_Ideograph", "Ideographic"},
    18338: {"Unified_Ideograph", "Ideographic"},
    18339: {"Unified_Ideograph", "Ideographic"},
    18340: {"Unified_Ideograph", "Ideographic"},
    18341: {"Unified_Ideograph", "Ideographic"},
    18342: {"Unified_Ideograph", "Ideographic"},
    18343: {"Unified_Ideograph", "Ideographic"},
    18344: {"Unified_Ideograph", "Ideographic"},
    18345: {"Unified_Ideograph", "Ideographic"},
    18346: {"Unified_Ideograph", "Ideographic"},
    18347: {"Unified_Ideograph", "Ideographic"},
    18348: {"Unified_Ideograph", "Ideographic"},
    18349: {"Unified_Ideograph", "Ideographic"},
    18350: {"Unified_Ideograph", "Ideographic"},
    18351: {"Unified_Ideograph", "Ideographic"},
    18352: {"Unified_Ideograph", "Ideographic"},
    18353: {"Unified_Ideograph", "Ideographic"},
    18354: {"Unified_Ideograph", "Ideographic"},
    18355: {"Unified_Ideograph", "Ideographic"},
    18356: {"Unified_Ideograph", "Ideographic"},
    18357: {"Unified_Ideograph", "Ideographic"},
    18358: {"Unified_Ideograph", "Ideographic"},
    18359: {"Unified_Ideograph", "Ideographic"},
    18360: {"Unified_Ideograph", "Ideographic"},
    18361: {"Unified_Ideograph", "Ideographic"},
    18362: {"Unified_Ideograph", "Ideographic"},
    18363: {"Unified_Ideograph", "Ideographic"},
    18364: {"Unified_Ideograph", "Ideographic"},
    18365: {"Unified_Ideograph", "Ideographic"},
    18366: {"Unified_Ideograph", "Ideographic"},
    18367: {"Unified_Ideograph", "Ideographic"},
    18368: {"Unified_Ideograph", "Ideographic"},
    18369: {"Unified_Ideograph", "Ideographic"},
    18370: {"Unified_Ideograph", "Ideographic"},
    18371: {"Unified_Ideograph", "Ideographic"},
    18372: {"Unified_Ideograph", "Ideographic"},
    18373: {"Unified_Ideograph", "Ideographic"},
    18374: {"Unified_Ideograph", "Ideographic"},
    18375: {"Unified_Ideograph", "Ideographic"},
    18376: {"Unified_Ideograph", "Ideographic"},
    18377: {"Unified_Ideograph", "Ideographic"},
    18378: {"Unified_Ideograph", "Ideographic"},
    18379: {"Unified_Ideograph", "Ideographic"},
    18380: {"Unified_Ideograph", "Ideographic"},
    18381: {"Unified_Ideograph", "Ideographic"},
    18382: {"Unified_Ideograph", "Ideographic"},
    18383: {"Unified_Ideograph", "Ideographic"},
    18384: {"Unified_Ideograph", "Ideographic"},
    18385: {"Unified_Ideograph", "Ideographic"},
    18386: {"Unified_Ideograph", "Ideographic"},
    18387: {"Unified_Ideograph", "Ideographic"},
    18388: {"Unified_Ideograph", "Ideographic"},
    18389: {"Unified_Ideograph", "Ideographic"},
    18390: {"Unified_Ideograph", "Ideographic"},
    18391: {"Unified_Ideograph", "Ideographic"},
    18392: {"Unified_Ideograph", "Ideographic"},
    18393: {"Unified_Ideograph", "Ideographic"},
    18394: {"Unified_Ideograph", "Ideographic"},
    18395: {"Unified_Ideograph", "Ideographic"},
    18396: {"Unified_Ideograph", "Ideographic"},
    18397: {"Unified_Ideograph", "Ideographic"},
    18398: {"Unified_Ideograph", "Ideographic"},
    18399: {"Unified_Ideograph", "Ideographic"},
    18400: {"Unified_Ideograph", "Ideographic"},
    18401: {"Unified_Ideograph", "Ideographic"},
    18402: {"Unified_Ideograph", "Ideographic"},
    18403: {"Unified_Ideograph", "Ideographic"},
    18404: {"Unified_Ideograph", "Ideographic"},
    18405: {"Unified_Ideograph", "Ideographic"},
    18406: {"Unified_Ideograph", "Ideographic"},
    18407: {"Unified_Ideograph", "Ideographic"},
    18408: {"Unified_Ideograph", "Ideographic"},
    18409: {"Unified_Ideograph", "Ideographic"},
    18410: {"Unified_Ideograph", "Ideographic"},
    18411: {"Unified_Ideograph", "Ideographic"},
    18412: {"Unified_Ideograph", "Ideographic"},
    18413: {"Unified_Ideograph", "Ideographic"},
    18414: {"Unified_Ideograph", "Ideographic"},
    18415: {"Unified_Ideograph", "Ideographic"},
    18416: {"Unified_Ideograph", "Ideographic"},
    18417: {"Unified_Ideograph", "Ideographic"},
    18418: {"Unified_Ideograph", "Ideographic"},
    18419: {"Unified_Ideograph", "Ideographic"},
    18420: {"Unified_Ideograph", "Ideographic"},
    18421: {"Unified_Ideograph", "Ideographic"},
    18422: {"Unified_Ideograph", "Ideographic"},
    18423: {"Unified_Ideograph", "Ideographic"},
    18424: {"Unified_Ideograph", "Ideographic"},
    18425: {"Unified_Ideograph", "Ideographic"},
    18426: {"Unified_Ideograph", "Ideographic"},
    18427: {"Unified_Ideograph", "Ideographic"},
    18428: {"Unified_Ideograph", "Ideographic"},
    18429: {"Unified_Ideograph", "Ideographic"},
    18430: {"Unified_Ideograph", "Ideographic"},
    18431: {"Unified_Ideograph", "Ideographic"},
    18432: {"Unified_Ideograph", "Ideographic"},
    18433: {"Unified_Ideograph", "Ideographic"},
    18434: {"Unified_Ideograph", "Ideographic"},
    18435: {"Unified_Ideograph", "Ideographic"},
    18436: {"Unified_Ideograph", "Ideographic"},
    18437: {"Unified_Ideograph", "Ideographic"},
    18438: {"Unified_Ideograph", "Ideographic"},
    18439: {"Unified_Ideograph", "Ideographic"},
    18440: {"Unified_Ideograph", "Ideographic"},
    18441: {"Unified_Ideograph", "Ideographic"},
    18442: {"Unified_Ideograph", "Ideographic"},
    18443: {"Unified_Ideograph", "Ideographic"},
    18444: {"Unified_Ideograph", "Ideographic"},
    18445: {"Unified_Ideograph", "Ideographic"},
    18446: {"Unified_Ideograph", "Ideographic"},
    18447: {"Unified_Ideograph", "Ideographic"},
    18448: {"Unified_Ideograph", "Ideographic"},
    18449: {"Unified_Ideograph", "Ideographic"},
    18450: {"Unified_Ideograph", "Ideographic"},
    18451: {"Unified_Ideograph", "Ideographic"},
    18452: {"Unified_Ideograph", "Ideographic"},
    18453: {"Unified_Ideograph", "Ideographic"},
    18454: {"Unified_Ideograph", "Ideographic"},
    18455: {"Unified_Ideograph", "Ideographic"},
    18456: {"Unified_Ideograph", "Ideographic"},
    18457: {"Unified_Ideograph", "Ideographic"},
    18458: {"Unified_Ideograph", "Ideographic"},
    18459: {"Unified_Ideograph", "Ideographic"},
    18460: {"Unified_Ideograph", "Ideographic"},
    18461: {"Unified_Ideograph", "Ideographic"},
    18462: {"Unified_Ideograph", "Ideographic"},
    18463: {"Unified_Ideograph", "Ideographic"},
    18464: {"Unified_Ideograph", "Ideographic"},
    18465: {"Unified_Ideograph", "Ideographic"},
    18466: {"Unified_Ideograph", "Ideographic"},
    18467: {"Unified_Ideograph", "Ideographic"},
    18468: {"Unified_Ideograph", "Ideographic"},
    18469: {"Unified_Ideograph", "Ideographic"},
    18470: {"Unified_Ideograph", "Ideographic"},
    18471: {"Unified_Ideograph", "Ideographic"},
    18472: {"Unified_Ideograph", "Ideographic"},
    18473: {"Unified_Ideograph", "Ideographic"},
    18474: {"Unified_Ideograph", "Ideographic"},
    18475: {"Unified_Ideograph", "Ideographic"},
    18476: {"Unified_Ideograph", "Ideographic"},
    18477: {"Unified_Ideograph", "Ideographic"},
    18478: {"Unified_Ideograph", "Ideographic"},
    18479: {"Unified_Ideograph", "Ideographic"},
    18480: {"Unified_Ideograph", "Ideographic"},
    18481: {"Unified_Ideograph", "Ideographic"},
    18482: {"Unified_Ideograph", "Ideographic"},
    18483: {"Unified_Ideograph", "Ideographic"},
    18484: {"Unified_Ideograph", "Ideographic"},
    18485: {"Unified_Ideograph", "Ideographic"},
    18486: {"Unified_Ideograph", "Ideographic"},
    18487: {"Unified_Ideograph", "Ideographic"},
    18488: {"Unified_Ideograph", "Ideographic"},
    18489: {"Unified_Ideograph", "Ideographic"},
    18490: {"Unified_Ideograph", "Ideographic"},
    18491: {"Unified_Ideograph", "Ideographic"},
    18492: {"Unified_Ideograph", "Ideographic"},
    18493: {"Unified_Ideograph", "Ideographic"},
    18494: {"Unified_Ideograph", "Ideographic"},
    18495: {"Unified_Ideograph", "Ideographic"},
    18496: {"Unified_Ideograph", "Ideographic"},
    18497: {"Unified_Ideograph", "Ideographic"},
    18498: {"Unified_Ideograph", "Ideographic"},
    18499: {"Unified_Ideograph", "Ideographic"},
    18500: {"Unified_Ideograph", "Ideographic"},
    18501: {"Unified_Ideograph", "Ideographic"},
    18502: {"Unified_Ideograph", "Ideographic"},
    18503: {"Unified_Ideograph", "Ideographic"},
    18504: {"Unified_Ideograph", "Ideographic"},
    18505: {"Unified_Ideograph", "Ideographic"},
    18506: {"Unified_Ideograph", "Ideographic"},
    18507: {"Unified_Ideograph", "Ideographic"},
    18508: {"Unified_Ideograph", "Ideographic"},
    18509: {"Unified_Ideograph", "Ideographic"},
    18510: {"Unified_Ideograph", "Ideographic"},
    18511: {"Unified_Ideograph", "Ideographic"},
    18512: {"Unified_Ideograph", "Ideographic"},
    18513: {"Unified_Ideograph", "Ideographic"},
    18514: {"Unified_Ideograph", "Ideographic"},
    18515: {"Unified_Ideograph", "Ideographic"},
    18516: {"Unified_Ideograph", "Ideographic"},
    18517: {"Unified_Ideograph", "Ideographic"},
    18518: {"Unified_Ideograph", "Ideographic"},
    18519: {"Unified_Ideograph", "Ideographic"},
    18520: {"Unified_Ideograph", "Ideographic"},
    18521: {"Unified_Ideograph", "Ideographic"},
    18522: {"Unified_Ideograph", "Ideographic"},
    18523: {"Unified_Ideograph", "Ideographic"},
    18524: {"Unified_Ideograph", "Ideographic"},
    18525: {"Unified_Ideograph", "Ideographic"},
    18526: {"Unified_Ideograph", "Ideographic"},
    18527: {"Unified_Ideograph", "Ideographic"},
    18528: {"Unified_Ideograph", "Ideographic"},
    18529: {"Unified_Ideograph", "Ideographic"},
    18530: {"Unified_Ideograph", "Ideographic"},
    18531: {"Unified_Ideograph", "Ideographic"},
    18532: {"Unified_Ideograph", "Ideographic"},
    18533: {"Unified_Ideograph", "Ideographic"},
    18534: {"Unified_Ideograph", "Ideographic"},
    18535: {"Unified_Ideograph", "Ideographic"},
    18536: {"Unified_Ideograph", "Ideographic"},
    18537: {"Unified_Ideograph", "Ideographic"},
    18538: {"Unified_Ideograph", "Ideographic"},
    18539: {"Unified_Ideograph", "Ideographic"},
    18540: {"Unified_Ideograph", "Ideographic"},
    18541: {"Unified_Ideograph", "Ideographic"},
    18542: {"Unified_Ideograph", "Ideographic"},
    18543: {"Unified_Ideograph", "Ideographic"},
    18544: {"Unified_Ideograph", "Ideographic"},
    18545: {"Unified_Ideograph", "Ideographic"},
    18546: {"Unified_Ideograph", "Ideographic"},
    18547: {"Unified_Ideograph", "Ideographic"},
    18548: {"Unified_Ideograph", "Ideographic"},
    18549: {"Unified_Ideograph", "Ideographic"},
    18550: {"Unified_Ideograph", "Ideographic"},
    18551: {"Unified_Ideograph", "Ideographic"},
    18552: {"Unified_Ideograph", "Ideographic"},
    18553: {"Unified_Ideograph", "Ideographic"},
    18554: {"Unified_Ideograph", "Ideographic"},
    18555: {"Unified_Ideograph", "Ideographic"},
    18556: {"Unified_Ideograph", "Ideographic"},
    18557: {"Unified_Ideograph", "Ideographic"},
    18558: {"Unified_Ideograph", "Ideographic"},
    18559: {"Unified_Ideograph", "Ideographic"},
    18560: {"Unified_Ideograph", "Ideographic"},
    18561: {"Unified_Ideograph", "Ideographic"},
    18562: {"Unified_Ideograph", "Ideographic"},
    18563: {"Unified_Ideograph", "Ideographic"},
    18564: {"Unified_Ideograph", "Ideographic"},
    18565: {"Unified_Ideograph", "Ideographic"},
    18566: {"Unified_Ideograph", "Ideographic"},
    18567: {"Unified_Ideograph", "Ideographic"},
    18568: {"Unified_Ideograph", "Ideographic"},
    18569: {"Unified_Ideograph", "Ideographic"},
    18570: {"Unified_Ideograph", "Ideographic"},
    18571: {"Unified_Ideograph", "Ideographic"},
    18572: {"Unified_Ideograph", "Ideographic"},
    18573: {"Unified_Ideograph", "Ideographic"},
    18574: {"Unified_Ideograph", "Ideographic"},
    18575: {"Unified_Ideograph", "Ideographic"},
    18576: {"Unified_Ideograph", "Ideographic"},
    18577: {"Unified_Ideograph", "Ideographic"},
    18578: {"Unified_Ideograph", "Ideographic"},
    18579: {"Unified_Ideograph", "Ideographic"},
    18580: {"Unified_Ideograph", "Ideographic"},
    18581: {"Unified_Ideograph", "Ideographic"},
    18582: {"Unified_Ideograph", "Ideographic"},
    18583: {"Unified_Ideograph", "Ideographic"},
    18584: {"Unified_Ideograph", "Ideographic"},
    18585: {"Unified_Ideograph", "Ideographic"},
    18586: {"Unified_Ideograph", "Ideographic"},
    18587: {"Unified_Ideograph", "Ideographic"},
    18588: {"Unified_Ideograph", "Ideographic"},
    18589: {"Unified_Ideograph", "Ideographic"},
    18590: {"Unified_Ideograph", "Ideographic"},
    18591: {"Unified_Ideograph", "Ideographic"},
    18592: {"Unified_Ideograph", "Ideographic"},
    18593: {"Unified_Ideograph", "Ideographic"},
    18594: {"Unified_Ideograph", "Ideographic"},
    18595: {"Unified_Ideograph", "Ideographic"},
    18596: {"Unified_Ideograph", "Ideographic"},
    18597: {"Unified_Ideograph", "Ideographic"},
    18598: {"Unified_Ideograph", "Ideographic"},
    18599: {"Unified_Ideograph", "Ideographic"},
    18600: {"Unified_Ideograph", "Ideographic"},
    18601: {"Unified_Ideograph", "Ideographic"},
    18602: {"Unified_Ideograph", "Ideographic"},
    18603: {"Unified_Ideograph", "Ideographic"},
    18604: {"Unified_Ideograph", "Ideographic"},
    18605: {"Unified_Ideograph", "Ideographic"},
    18606: {"Unified_Ideograph", "Ideographic"},
    18607: {"Unified_Ideograph", "Ideographic"},
    18608: {"Unified_Ideograph", "Ideographic"},
    18609: {"Unified_Ideograph", "Ideographic"},
    18610: {"Unified_Ideograph", "Ideographic"},
    18611: {"Unified_Ideograph", "Ideographic"},
    18612: {"Unified_Ideograph", "Ideographic"},
    18613: {"Unified_Ideograph", "Ideographic"},
    18614: {"Unified_Ideograph", "Ideographic"},
    18615: {"Unified_Ideograph", "Ideographic"},
    18616: {"Unified_Ideograph", "Ideographic"},
    18617: {"Unified_Ideograph", "Ideographic"},
    18618: {"Unified_Ideograph", "Ideographic"},
    18619: {"Unified_Ideograph", "Ideographic"},
    18620: {"Unified_Ideograph", "Ideographic"},
    18621: {"Unified_Ideograph", "Ideographic"},
    18622: {"Unified_Ideograph", "Ideographic"},
    18623: {"Unified_Ideograph", "Ideographic"},
    18624: {"Unified_Ideograph", "Ideographic"},
    18625: {"Unified_Ideograph", "Ideographic"},
    18626: {"Unified_Ideograph", "Ideographic"},
    18627: {"Unified_Ideograph", "Ideographic"},
    18628: {"Unified_Ideograph", "Ideographic"},
    18629: {"Unified_Ideograph", "Ideographic"},
    18630: {"Unified_Ideograph", "Ideographic"},
    18631: {"Unified_Ideograph", "Ideographic"},
    18632: {"Unified_Ideograph", "Ideographic"},
    18633: {"Unified_Ideograph", "Ideographic"},
    18634: {"Unified_Ideograph", "Ideographic"},
    18635: {"Unified_Ideograph", "Ideographic"},
    18636: {"Unified_Ideograph", "Ideographic"},
    18637: {"Unified_Ideograph", "Ideographic"},
    18638: {"Unified_Ideograph", "Ideographic"},
    18639: {"Unified_Ideograph", "Ideographic"},
    18640: {"Unified_Ideograph", "Ideographic"},
    18641: {"Unified_Ideograph", "Ideographic"},
    18642: {"Unified_Ideograph", "Ideographic"},
    18643: {"Unified_Ideograph", "Ideographic"},
    18644: {"Unified_Ideograph", "Ideographic"},
    18645: {"Unified_Ideograph", "Ideographic"},
    18646: {"Unified_Ideograph", "Ideographic"},
    18647: {"Unified_Ideograph", "Ideographic"},
    18648: {"Unified_Ideograph", "Ideographic"},
    18649: {"Unified_Ideograph", "Ideographic"},
    18650: {"Unified_Ideograph", "Ideographic"},
    18651: {"Unified_Ideograph", "Ideographic"},
    18652: {"Unified_Ideograph", "Ideographic"},
    18653: {"Unified_Ideograph", "Ideographic"},
    18654: {"Unified_Ideograph", "Ideographic"},
    18655: {"Unified_Ideograph", "Ideographic"},
    18656: {"Unified_Ideograph", "Ideographic"},
    18657: {"Unified_Ideograph", "Ideographic"},
    18658: {"Unified_Ideograph", "Ideographic"},
    18659: {"Unified_Ideograph", "Ideographic"},
    18660: {"Unified_Ideograph", "Ideographic"},
    18661: {"Unified_Ideograph", "Ideographic"},
    18662: {"Unified_Ideograph", "Ideographic"},
    18663: {"Unified_Ideograph", "Ideographic"},
    18664: {"Unified_Ideograph", "Ideographic"},
    18665: {"Unified_Ideograph", "Ideographic"},
    18666: {"Unified_Ideograph", "Ideographic"},
    18667: {"Unified_Ideograph", "Ideographic"},
    18668: {"Unified_Ideograph", "Ideographic"},
    18669: {"Unified_Ideograph", "Ideographic"},
    18670: {"Unified_Ideograph", "Ideographic"},
    18671: {"Unified_Ideograph", "Ideographic"},
    18672: {"Unified_Ideograph", "Ideographic"},
    18673: {"Unified_Ideograph", "Ideographic"},
    18674: {"Unified_Ideograph", "Ideographic"},
    18675: {"Unified_Ideograph", "Ideographic"},
    18676: {"Unified_Ideograph", "Ideographic"},
    18677: {"Unified_Ideograph", "Ideographic"},
    18678: {"Unified_Ideograph", "Ideographic"},
    18679: {"Unified_Ideograph", "Ideographic"},
    18680: {"Unified_Ideograph", "Ideographic"},
    18681: {"Unified_Ideograph", "Ideographic"},
    18682: {"Unified_Ideograph", "Ideographic"},
    18683: {"Unified_Ideograph", "Ideographic"},
    18684: {"Unified_Ideograph", "Ideographic"},
    18685: {"Unified_Ideograph", "Ideographic"},
    18686: {"Unified_Ideograph", "Ideographic"},
    18687: {"Unified_Ideograph", "Ideographic"},
    18688: {"Unified_Ideograph", "Ideographic"},
    18689: {"Unified_Ideograph", "Ideographic"},
    18690: {"Unified_Ideograph", "Ideographic"},
    18691: {"Unified_Ideograph", "Ideographic"},
    18692: {"Unified_Ideograph", "Ideographic"},
    18693: {"Unified_Ideograph", "Ideographic"},
    18694: {"Unified_Ideograph", "Ideographic"},
    18695: {"Unified_Ideograph", "Ideographic"},
    18696: {"Unified_Ideograph", "Ideographic"},
    18697: {"Unified_Ideograph", "Ideographic"},
    18698: {"Unified_Ideograph", "Ideographic"},
    18699: {"Unified_Ideograph", "Ideographic"},
    18700: {"Unified_Ideograph", "Ideographic"},
    18701: {"Unified_Ideograph", "Ideographic"},
    18702: {"Unified_Ideograph", "Ideographic"},
    18703: {"Unified_Ideograph", "Ideographic"},
    18704: {"Unified_Ideograph", "Ideographic"},
    18705: {"Unified_Ideograph", "Ideographic"},
    18706: {"Unified_Ideograph", "Ideographic"},
    18707: {"Unified_Ideograph", "Ideographic"},
    18708: {"Unified_Ideograph", "Ideographic"},
    18709: {"Unified_Ideograph", "Ideographic"},
    18710: {"Unified_Ideograph", "Ideographic"},
    18711: {"Unified_Ideograph", "Ideographic"},
    18712: {"Unified_Ideograph", "Ideographic"},
    18713: {"Unified_Ideograph", "Ideographic"},
    18714: {"Unified_Ideograph", "Ideographic"},
    18715: {"Unified_Ideograph", "Ideographic"},
    18716: {"Unified_Ideograph", "Ideographic"},
    18717: {"Unified_Ideograph", "Ideographic"},
    18718: {"Unified_Ideograph", "Ideographic"},
    18719: {"Unified_Ideograph", "Ideographic"},
    18720: {"Unified_Ideograph", "Ideographic"},
    18721: {"Unified_Ideograph", "Ideographic"},
    18722: {"Unified_Ideograph", "Ideographic"},
    18723: {"Unified_Ideograph", "Ideographic"},
    18724: {"Unified_Ideograph", "Ideographic"},
    18725: {"Unified_Ideograph", "Ideographic"},
    18726: {"Unified_Ideograph", "Ideographic"},
    18727: {"Unified_Ideograph", "Ideographic"},
    18728: {"Unified_Ideograph", "Ideographic"},
    18729: {"Unified_Ideograph", "Ideographic"},
    18730: {"Unified_Ideograph", "Ideographic"},
    18731: {"Unified_Ideograph", "Ideographic"},
    18732: {"Unified_Ideograph", "Ideographic"},
    18733: {"Unified_Ideograph", "Ideographic"},
    18734: {"Unified_Ideograph", "Ideographic"},
    18735: {"Unified_Ideograph", "Ideographic"},
    18736: {"Unified_Ideograph", "Ideographic"},
    18737: {"Unified_Ideograph", "Ideographic"},
    18738: {"Unified_Ideograph", "Ideographic"},
    18739: {"Unified_Ideograph", "Ideographic"},
    18740: {"Unified_Ideograph", "Ideographic"},
    18741: {"Unified_Ideograph", "Ideographic"},
    18742: {"Unified_Ideograph", "Ideographic"},
    18743: {"Unified_Ideograph", "Ideographic"},
    18744: {"Unified_Ideograph", "Ideographic"},
    18745: {"Unified_Ideograph", "Ideographic"},
    18746: {"Unified_Ideograph", "Ideographic"},
    18747: {"Unified_Ideograph", "Ideographic"},
    18748: {"Unified_Ideograph", "Ideographic"},
    18749: {"Unified_Ideograph", "Ideographic"},
    18750: {"Unified_Ideograph", "Ideographic"},
    18751: {"Unified_Ideograph", "Ideographic"},
    18752: {"Unified_Ideograph", "Ideographic"},
    18753: {"Unified_Ideograph", "Ideographic"},
    18754: {"Unified_Ideograph", "Ideographic"},
    18755: {"Unified_Ideograph", "Ideographic"},
    18756: {"Unified_Ideograph", "Ideographic"},
    18757: {"Unified_Ideograph", "Ideographic"},
    18758: {"Unified_Ideograph", "Ideographic"},
    18759: {"Unified_Ideograph", "Ideographic"},
    18760: {"Unified_Ideograph", "Ideographic"},
    18761: {"Unified_Ideograph", "Ideographic"},
    18762: {"Unified_Ideograph", "Ideographic"},
    18763: {"Unified_Ideograph", "Ideographic"},
    18764: {"Unified_Ideograph", "Ideographic"},
    18765: {"Unified_Ideograph", "Ideographic"},
    18766: {"Unified_Ideograph", "Ideographic"},
    18767: {"Unified_Ideograph", "Ideographic"},
    18768: {"Unified_Ideograph", "Ideographic"},
    18769: {"Unified_Ideograph", "Ideographic"},
    18770: {"Unified_Ideograph", "Ideographic"},
    18771: {"Unified_Ideograph", "Ideographic"},
    18772: {"Unified_Ideograph", "Ideographic"},
    18773: {"Unified_Ideograph", "Ideographic"},
    18774: {"Unified_Ideograph", "Ideographic"},
    18775: {"Unified_Ideograph", "Ideographic"},
    18776: {"Unified_Ideograph", "Ideographic"},
    18777: {"Unified_Ideograph", "Ideographic"},
    18778: {"Unified_Ideograph", "Ideographic"},
    18779: {"Unified_Ideograph", "Ideographic"},
    18780: {"Unified_Ideograph", "Ideographic"},
    18781: {"Unified_Ideograph", "Ideographic"},
    18782: {"Unified_Ideograph", "Ideographic"},
    18783: {"Unified_Ideograph", "Ideographic"},
    18784: {"Unified_Ideograph", "Ideographic"},
    18785: {"Unified_Ideograph", "Ideographic"},
    18786: {"Unified_Ideograph", "Ideographic"},
    18787: {"Unified_Ideograph", "Ideographic"},
    18788: {"Unified_Ideograph", "Ideographic"},
    18789: {"Unified_Ideograph", "Ideographic"},
    18790: {"Unified_Ideograph", "Ideographic"},
    18791: {"Unified_Ideograph", "Ideographic"},
    18792: {"Unified_Ideograph", "Ideographic"},
    18793: {"Unified_Ideograph", "Ideographic"},
    18794: {"Unified_Ideograph", "Ideographic"},
    18795: {"Unified_Ideograph", "Ideographic"},
    18796: {"Unified_Ideograph", "Ideographic"},
    18797: {"Unified_Ideograph", "Ideographic"},
    18798: {"Unified_Ideograph", "Ideographic"},
    18799: {"Unified_Ideograph", "Ideographic"},
    18800: {"Unified_Ideograph", "Ideographic"},
    18801: {"Unified_Ideograph", "Ideographic"},
    18802: {"Unified_Ideograph", "Ideographic"},
    18803: {"Unified_Ideograph", "Ideographic"},
    18804: {"Unified_Ideograph", "Ideographic"},
    18805: {"Unified_Ideograph", "Ideographic"},
    18806: {"Unified_Ideograph", "Ideographic"},
    18807: {"Unified_Ideograph", "Ideographic"},
    18808: {"Unified_Ideograph", "Ideographic"},
    18809: {"Unified_Ideograph", "Ideographic"},
    18810: {"Unified_Ideograph", "Ideographic"},
    18811: {"Unified_Ideograph", "Ideographic"},
    18812: {"Unified_Ideograph", "Ideographic"},
    18813: {"Unified_Ideograph", "Ideographic"},
    18814: {"Unified_Ideograph", "Ideographic"},
    18815: {"Unified_Ideograph", "Ideographic"},
    18816: {"Unified_Ideograph", "Ideographic"},
    18817: {"Unified_Ideograph", "Ideographic"},
    18818: {"Unified_Ideograph", "Ideographic"},
    18819: {"Unified_Ideograph", "Ideographic"},
    18820: {"Unified_Ideograph", "Ideographic"},
    18821: {"Unified_Ideograph", "Ideographic"},
    18822: {"Unified_Ideograph", "Ideographic"},
    18823: {"Unified_Ideograph", "Ideographic"},
    18824: {"Unified_Ideograph", "Ideographic"},
    18825: {"Unified_Ideograph", "Ideographic"},
    18826: {"Unified_Ideograph", "Ideographic"},
    18827: {"Unified_Ideograph", "Ideographic"},
    18828: {"Unified_Ideograph", "Ideographic"},
    18829: {"Unified_Ideograph", "Ideographic"},
    18830: {"Unified_Ideograph", "Ideographic"},
    18831: {"Unified_Ideograph", "Ideographic"},
    18832: {"Unified_Ideograph", "Ideographic"},
    18833: {"Unified_Ideograph", "Ideographic"},
    18834: {"Unified_Ideograph", "Ideographic"},
    18835: {"Unified_Ideograph", "Ideographic"},
    18836: {"Unified_Ideograph", "Ideographic"},
    18837: {"Unified_Ideograph", "Ideographic"},
    18838: {"Unified_Ideograph", "Ideographic"},
    18839: {"Unified_Ideograph", "Ideographic"},
    18840: {"Unified_Ideograph", "Ideographic"},
    18841: {"Unified_Ideograph", "Ideographic"},
    18842: {"Unified_Ideograph", "Ideographic"},
    18843: {"Unified_Ideograph", "Ideographic"},
    18844: {"Unified_Ideograph", "Ideographic"},
    18845: {"Unified_Ideograph", "Ideographic"},
    18846: {"Unified_Ideograph", "Ideographic"},
    18847: {"Unified_Ideograph", "Ideographic"},
    18848: {"Unified_Ideograph", "Ideographic"},
    18849: {"Unified_Ideograph", "Ideographic"},
    18850: {"Unified_Ideograph", "Ideographic"},
    18851: {"Unified_Ideograph", "Ideographic"},
    18852: {"Unified_Ideograph", "Ideographic"},
    18853: {"Unified_Ideograph", "Ideographic"},
    18854: {"Unified_Ideograph", "Ideographic"},
    18855: {"Unified_Ideograph", "Ideographic"},
    18856: {"Unified_Ideograph", "Ideographic"},
    18857: {"Unified_Ideograph", "Ideographic"},
    18858: {"Unified_Ideograph", "Ideographic"},
    18859: {"Unified_Ideograph", "Ideographic"},
    18860: {"Unified_Ideograph", "Ideographic"},
    18861: {"Unified_Ideograph", "Ideographic"},
    18862: {"Unified_Ideograph", "Ideographic"},
    18863: {"Unified_Ideograph", "Ideographic"},
    18864: {"Unified_Ideograph", "Ideographic"},
    18865: {"Unified_Ideograph", "Ideographic"},
    18866: {"Unified_Ideograph", "Ideographic"},
    18867: {"Unified_Ideograph", "Ideographic"},
    18868: {"Unified_Ideograph", "Ideographic"},
    18869: {"Unified_Ideograph", "Ideographic"},
    18870: {"Unified_Ideograph", "Ideographic"},
    18871: {"Unified_Ideograph", "Ideographic"},
    18872: {"Unified_Ideograph", "Ideographic"},
    18873: {"Unified_Ideograph", "Ideographic"},
    18874: {"Unified_Ideograph", "Ideographic"},
    18875: {"Unified_Ideograph", "Ideographic"},
    18876: {"Unified_Ideograph", "Ideographic"},
    18877: {"Unified_Ideograph", "Ideographic"},
    18878: {"Unified_Ideograph", "Ideographic"},
    18879: {"Unified_Ideograph", "Ideographic"},
    18880: {"Unified_Ideograph", "Ideographic"},
    18881: {"Unified_Ideograph", "Ideographic"},
    18882: {"Unified_Ideograph", "Ideographic"},
    18883: {"Unified_Ideograph", "Ideographic"},
    18884: {"Unified_Ideograph", "Ideographic"},
    18885: {"Unified_Ideograph", "Ideographic"},
    18886: {"Unified_Ideograph", "Ideographic"},
    18887: {"Unified_Ideograph", "Ideographic"},
    18888: {"Unified_Ideograph", "Ideographic"},
    18889: {"Unified_Ideograph", "Ideographic"},
    18890: {"Unified_Ideograph", "Ideographic"},
    18891: {"Unified_Ideograph", "Ideographic"},
    18892: {"Unified_Ideograph", "Ideographic"},
    18893: {"Unified_Ideograph", "Ideographic"},
    18894: {"Unified_Ideograph", "Ideographic"},
    18895: {"Unified_Ideograph", "Ideographic"},
    18896: {"Unified_Ideograph", "Ideographic"},
    18897: {"Unified_Ideograph", "Ideographic"},
    18898: {"Unified_Ideograph", "Ideographic"},
    18899: {"Unified_Ideograph", "Ideographic"},
    18900: {"Unified_Ideograph", "Ideographic"},
    18901: {"Unified_Ideograph", "Ideographic"},
    18902: {"Unified_Ideograph", "Ideographic"},
    18903: {"Unified_Ideograph", "Ideographic"},
    18904: {"Unified_Ideograph", "Ideographic"},
    18905: {"Unified_Ideograph", "Ideographic"},
    18906: {"Unified_Ideograph", "Ideographic"},
    18907: {"Unified_Ideograph", "Ideographic"},
    18908: {"Unified_Ideograph", "Ideographic"},
    18909: {"Unified_Ideograph", "Ideographic"},
    18910: {"Unified_Ideograph", "Ideographic"},
    18911: {"Unified_Ideograph", "Ideographic"},
    18912: {"Unified_Ideograph", "Ideographic"},
    18913: {"Unified_Ideograph", "Ideographic"},
    18914: {"Unified_Ideograph", "Ideographic"},
    18915: {"Unified_Ideograph", "Ideographic"},
    18916: {"Unified_Ideograph", "Ideographic"},
    18917: {"Unified_Ideograph", "Ideographic"},
    18918: {"Unified_Ideograph", "Ideographic"},
    18919: {"Unified_Ideograph", "Ideographic"},
    18920: {"Unified_Ideograph", "Ideographic"},
    18921: {"Unified_Ideograph", "Ideographic"},
    18922: {"Unified_Ideograph", "Ideographic"},
    18923: {"Unified_Ideograph", "Ideographic"},
    18924: {"Unified_Ideograph", "Ideographic"},
    18925: {"Unified_Ideograph", "Ideographic"},
    18926: {"Unified_Ideograph", "Ideographic"},
    18927: {"Unified_Ideograph", "Ideographic"},
    18928: {"Unified_Ideograph", "Ideographic"},
    18929: {"Unified_Ideograph", "Ideographic"},
    18930: {"Unified_Ideograph", "Ideographic"},
    18931: {"Unified_Ideograph", "Ideographic"},
    18932: {"Unified_Ideograph", "Ideographic"},
    18933: {"Unified_Ideograph", "Ideographic"},
    18934: {"Unified_Ideograph", "Ideographic"},
    18935: {"Unified_Ideograph", "Ideographic"},
    18936: {"Unified_Ideograph", "Ideographic"},
    18937: {"Unified_Ideograph", "Ideographic"},
    18938: {"Unified_Ideograph", "Ideographic"},
    18939: {"Unified_Ideograph", "Ideographic"},
    18940: {"Unified_Ideograph", "Ideographic"},
    18941: {"Unified_Ideograph", "Ideographic"},
    18942: {"Unified_Ideograph", "Ideographic"},
    18943: {"Unified_Ideograph", "Ideographic"},
    18944: {"Unified_Ideograph", "Ideographic"},
    18945: {"Unified_Ideograph", "Ideographic"},
    18946: {"Unified_Ideograph", "Ideographic"},
    18947: {"Unified_Ideograph", "Ideographic"},
    18948: {"Unified_Ideograph", "Ideographic"},
    18949: {"Unified_Ideograph", "Ideographic"},
    18950: {"Unified_Ideograph", "Ideographic"},
    18951: {"Unified_Ideograph", "Ideographic"},
    18952: {"Unified_Ideograph", "Ideographic"},
    18953: {"Unified_Ideograph", "Ideographic"},
    18954: {"Unified_Ideograph", "Ideographic"},
    18955: {"Unified_Ideograph", "Ideographic"},
    18956: {"Unified_Ideograph", "Ideographic"},
    18957: {"Unified_Ideograph", "Ideographic"},
    18958: {"Unified_Ideograph", "Ideographic"},
    18959: {"Unified_Ideograph", "Ideographic"},
    18960: {"Unified_Ideograph", "Ideographic"},
    18961: {"Unified_Ideograph", "Ideographic"},
    18962: {"Unified_Ideograph", "Ideographic"},
    18963: {"Unified_Ideograph", "Ideographic"},
    18964: {"Unified_Ideograph", "Ideographic"},
    18965: {"Unified_Ideograph", "Ideographic"},
    18966: {"Unified_Ideograph", "Ideographic"},
    18967: {"Unified_Ideograph", "Ideographic"},
    18968: {"Unified_Ideograph", "Ideographic"},
    18969: {"Unified_Ideograph", "Ideographic"},
    18970: {"Unified_Ideograph", "Ideographic"},
    18971: {"Unified_Ideograph", "Ideographic"},
    18972: {"Unified_Ideograph", "Ideographic"},
    18973: {"Unified_Ideograph", "Ideographic"},
    18974: {"Unified_Ideograph", "Ideographic"},
    18975: {"Unified_Ideograph", "Ideographic"},
    18976: {"Unified_Ideograph", "Ideographic"},
    18977: {"Unified_Ideograph", "Ideographic"},
    18978: {"Unified_Ideograph", "Ideographic"},
    18979: {"Unified_Ideograph", "Ideographic"},
    18980: {"Unified_Ideograph", "Ideographic"},
    18981: {"Unified_Ideograph", "Ideographic"},
    18982: {"Unified_Ideograph", "Ideographic"},
    18983: {"Unified_Ideograph", "Ideographic"},
    18984: {"Unified_Ideograph", "Ideographic"},
    18985: {"Unified_Ideograph", "Ideographic"},
    18986: {"Unified_Ideograph", "Ideographic"},
    18987: {"Unified_Ideograph", "Ideographic"},
    18988: {"Unified_Ideograph", "Ideographic"},
    18989: {"Unified_Ideograph", "Ideographic"},
    18990: {"Unified_Ideograph", "Ideographic"},
    18991: {"Unified_Ideograph", "Ideographic"},
    18992: {"Unified_Ideograph", "Ideographic"},
    18993: {"Unified_Ideograph", "Ideographic"},
    18994: {"Unified_Ideograph", "Ideographic"},
    18995: {"Unified_Ideograph", "Ideographic"},
    18996: {"Unified_Ideograph", "Ideographic"},
    18997: {"Unified_Ideograph", "Ideographic"},
    18998: {"Unified_Ideograph", "Ideographic"},
    18999: {"Unified_Ideograph", "Ideographic"},
    19000: {"Unified_Ideograph", "Ideographic"},
    19001: {"Unified_Ideograph", "Ideographic"},
    19002: {"Unified_Ideograph", "Ideographic"},
    19003: {"Unified_Ideograph", "Ideographic"},
    19004: {"Unified_Ideograph", "Ideographic"},
    19005: {"Unified_Ideograph", "Ideographic"},
    19006: {"Unified_Ideograph", "Ideographic"},
    19007: {"Unified_Ideograph", "Ideographic"},
    19008: {"Unified_Ideograph", "Ideographic"},
    19009: {"Unified_Ideograph", "Ideographic"},
    19010: {"Unified_Ideograph", "Ideographic"},
    19011: {"Unified_Ideograph", "Ideographic"},
    19012: {"Unified_Ideograph", "Ideographic"},
    19013: {"Unified_Ideograph", "Ideographic"},
    19014: {"Unified_Ideograph", "Ideographic"},
    19015: {"Unified_Ideograph", "Ideographic"},
    19016: {"Unified_Ideograph", "Ideographic"},
    19017: {"Unified_Ideograph", "Ideographic"},
    19018: {"Unified_Ideograph", "Ideographic"},
    19019: {"Unified_Ideograph", "Ideographic"},
    19020: {"Unified_Ideograph", "Ideographic"},
    19021: {"Unified_Ideograph", "Ideographic"},
    19022: {"Unified_Ideograph", "Ideographic"},
    19023: {"Unified_Ideograph", "Ideographic"},
    19024: {"Unified_Ideograph", "Ideographic"},
    19025: {"Unified_Ideograph", "Ideographic"},
    19026: {"Unified_Ideograph", "Ideographic"},
    19027: {"Unified_Ideograph", "Ideographic"},
    19028: {"Unified_Ideograph", "Ideographic"},
    19029: {"Unified_Ideograph", "Ideographic"},
    19030: {"Unified_Ideograph", "Ideographic"},
    19031: {"Unified_Ideograph", "Ideographic"},
    19032: {"Unified_Ideograph", "Ideographic"},
    19033: {"Unified_Ideograph", "Ideographic"},
    19034: {"Unified_Ideograph", "Ideographic"},
    19035: {"Unified_Ideograph", "Ideographic"},
    19036: {"Unified_Ideograph", "Ideographic"},
    19037: {"Unified_Ideograph", "Ideographic"},
    19038: {"Unified_Ideograph", "Ideographic"},
    19039: {"Unified_Ideograph", "Ideographic"},
    19040: {"Unified_Ideograph", "Ideographic"},
    19041: {"Unified_Ideograph", "Ideographic"},
    19042: {"Unified_Ideograph", "Ideographic"},
    19043: {"Unified_Ideograph", "Ideographic"},
    19044: {"Unified_Ideograph", "Ideographic"},
    19045: {"Unified_Ideograph", "Ideographic"},
    19046: {"Unified_Ideograph", "Ideographic"},
    19047: {"Unified_Ideograph", "Ideographic"},
    19048: {"Unified_Ideograph", "Ideographic"},
    19049: {"Unified_Ideograph", "Ideographic"},
    19050: {"Unified_Ideograph", "Ideographic"},
    19051: {"Unified_Ideograph", "Ideographic"},
    19052: {"Unified_Ideograph", "Ideographic"},
    19053: {"Unified_Ideograph", "Ideographic"},
    19054: {"Unified_Ideograph", "Ideographic"},
    19055: {"Unified_Ideograph", "Ideographic"},
    19056: {"Unified_Ideograph", "Ideographic"},
    19057: {"Unified_Ideograph", "Ideographic"},
    19058: {"Unified_Ideograph", "Ideographic"},
    19059: {"Unified_Ideograph", "Ideographic"},
    19060: {"Unified_Ideograph", "Ideographic"},
    19061: {"Unified_Ideograph", "Ideographic"},
    19062: {"Unified_Ideograph", "Ideographic"},
    19063: {"Unified_Ideograph", "Ideographic"},
    19064: {"Unified_Ideograph", "Ideographic"},
    19065: {"Unified_Ideograph", "Ideographic"},
    19066: {"Unified_Ideograph", "Ideographic"},
    19067: {"Unified_Ideograph", "Ideographic"},
    19068: {"Unified_Ideograph", "Ideographic"},
    19069: {"Unified_Ideograph", "Ideographic"},
    19070: {"Unified_Ideograph", "Ideographic"},
    19071: {"Unified_Ideograph", "Ideographic"},
    19072: {"Unified_Ideograph", "Ideographic"},
    19073: {"Unified_Ideograph", "Ideographic"},
    19074: {"Unified_Ideograph", "Ideographic"},
    19075: {"Unified_Ideograph", "Ideographic"},
    19076: {"Unified_Ideograph", "Ideographic"},
    19077: {"Unified_Ideograph", "Ideographic"},
    19078: {"Unified_Ideograph", "Ideographic"},
    19079: {"Unified_Ideograph", "Ideographic"},
    19080: {"Unified_Ideograph", "Ideographic"},
    19081: {"Unified_Ideograph", "Ideographic"},
    19082: {"Unified_Ideograph", "Ideographic"},
    19083: {"Unified_Ideograph", "Ideographic"},
    19084: {"Unified_Ideograph", "Ideographic"},
    19085: {"Unified_Ideograph", "Ideographic"},
    19086: {"Unified_Ideograph", "Ideographic"},
    19087: {"Unified_Ideograph", "Ideographic"},
    19088: {"Unified_Ideograph", "Ideographic"},
    19089: {"Unified_Ideograph", "Ideographic"},
    19090: {"Unified_Ideograph", "Ideographic"},
    19091: {"Unified_Ideograph", "Ideographic"},
    19092: {"Unified_Ideograph", "Ideographic"},
    19093: {"Unified_Ideograph", "Ideographic"},
    19094: {"Unified_Ideograph", "Ideographic"},
    19095: {"Unified_Ideograph", "Ideographic"},
    19096: {"Unified_Ideograph", "Ideographic"},
    19097: {"Unified_Ideograph", "Ideographic"},
    19098: {"Unified_Ideograph", "Ideographic"},
    19099: {"Unified_Ideograph", "Ideographic"},
    19100: {"Unified_Ideograph", "Ideographic"},
    19101: {"Unified_Ideograph", "Ideographic"},
    19102: {"Unified_Ideograph", "Ideographic"},
    19103: {"Unified_Ideograph", "Ideographic"},
    19104: {"Unified_Ideograph", "Ideographic"},
    19105: {"Unified_Ideograph", "Ideographic"},
    19106: {"Unified_Ideograph", "Ideographic"},
    19107: {"Unified_Ideograph", "Ideographic"},
    19108: {"Unified_Ideograph", "Ideographic"},
    19109: {"Unified_Ideograph", "Ideographic"},
    19110: {"Unified_Ideograph", "Ideographic"},
    19111: {"Unified_Ideograph", "Ideographic"},
    19112: {"Unified_Ideograph", "Ideographic"},
    19113: {"Unified_Ideograph", "Ideographic"},
    19114: {"Unified_Ideograph", "Ideographic"},
    19115: {"Unified_Ideograph", "Ideographic"},
    19116: {"Unified_Ideograph", "Ideographic"},
    19117: {"Unified_Ideograph", "Ideographic"},
    19118: {"Unified_Ideograph", "Ideographic"},
    19119: {"Unified_Ideograph", "Ideographic"},
    19120: {"Unified_Ideograph", "Ideographic"},
    19121: {"Unified_Ideograph", "Ideographic"},
    19122: {"Unified_Ideograph", "Ideographic"},
    19123: {"Unified_Ideograph", "Ideographic"},
    19124: {"Unified_Ideograph", "Ideographic"},
    19125: {"Unified_Ideograph", "Ideographic"},
    19126: {"Unified_Ideograph", "Ideographic"},
    19127: {"Unified_Ideograph", "Ideographic"},
    19128: {"Unified_Ideograph", "Ideographic"},
    19129: {"Unified_Ideograph", "Ideographic"},
    19130: {"Unified_Ideograph", "Ideographic"},
    19131: {"Unified_Ideograph", "Ideographic"},
    19132: {"Unified_Ideograph", "Ideographic"},
    19133: {"Unified_Ideograph", "Ideographic"},
    19134: {"Unified_Ideograph", "Ideographic"},
    19135: {"Unified_Ideograph", "Ideographic"},
    19136: {"Unified_Ideograph", "Ideographic"},
    19137: {"Unified_Ideograph", "Ideographic"},
    19138: {"Unified_Ideograph", "Ideographic"},
    19139: {"Unified_Ideograph", "Ideographic"},
    19140: {"Unified_Ideograph", "Ideographic"},
    19141: {"Unified_Ideograph", "Ideographic"},
    19142: {"Unified_Ideograph", "Ideographic"},
    19143: {"Unified_Ideograph", "Ideographic"},
    19144: {"Unified_Ideograph", "Ideographic"},
    19145: {"Unified_Ideograph", "Ideographic"},
    19146: {"Unified_Ideograph", "Ideographic"},
    19147: {"Unified_Ideograph", "Ideographic"},
    19148: {"Unified_Ideograph", "Ideographic"},
    19149: {"Unified_Ideograph", "Ideographic"},
    19150: {"Unified_Ideograph", "Ideographic"},
    19151: {"Unified_Ideograph", "Ideographic"},
    19152: {"Unified_Ideograph", "Ideographic"},
    19153: {"Unified_Ideograph", "Ideographic"},
    19154: {"Unified_Ideograph", "Ideographic"},
    19155: {"Unified_Ideograph", "Ideographic"},
    19156: {"Unified_Ideograph", "Ideographic"},
    19157: {"Unified_Ideograph", "Ideographic"},
    19158: {"Unified_Ideograph", "Ideographic"},
    19159: {"Unified_Ideograph", "Ideographic"},
    19160: {"Unified_Ideograph", "Ideographic"},
    19161: {"Unified_Ideograph", "Ideographic"},
    19162: {"Unified_Ideograph", "Ideographic"},
    19163: {"Unified_Ideograph", "Ideographic"},
    19164: {"Unified_Ideograph", "Ideographic"},
    19165: {"Unified_Ideograph", "Ideographic"},
    19166: {"Unified_Ideograph", "Ideographic"},
    19167: {"Unified_Ideograph", "Ideographic"},
    19168: {"Unified_Ideograph", "Ideographic"},
    19169: {"Unified_Ideograph", "Ideographic"},
    19170: {"Unified_Ideograph", "Ideographic"},
    19171: {"Unified_Ideograph", "Ideographic"},
    19172: {"Unified_Ideograph", "Ideographic"},
    19173: {"Unified_Ideograph", "Ideographic"},
    19174: {"Unified_Ideograph", "Ideographic"},
    19175: {"Unified_Ideograph", "Ideographic"},
    19176: {"Unified_Ideograph", "Ideographic"},
    19177: {"Unified_Ideograph", "Ideographic"},
    19178: {"Unified_Ideograph", "Ideographic"},
    19179: {"Unified_Ideograph", "Ideographic"},
    19180: {"Unified_Ideograph", "Ideographic"},
    19181: {"Unified_Ideograph", "Ideographic"},
    19182: {"Unified_Ideograph", "Ideographic"},
    19183: {"Unified_Ideograph", "Ideographic"},
    19184: {"Unified_Ideograph", "Ideographic"},
    19185: {"Unified_Ideograph", "Ideographic"},
    19186: {"Unified_Ideograph", "Ideographic"},
    19187: {"Unified_Ideograph", "Ideographic"},
    19188: {"Unified_Ideograph", "Ideographic"},
    19189: {"Unified_Ideograph", "Ideographic"},
    19190: {"Unified_Ideograph", "Ideographic"},
    19191: {"Unified_Ideograph", "Ideographic"},
    19192: {"Unified_Ideograph", "Ideographic"},
    19193: {"Unified_Ideograph", "Ideographic"},
    19194: {"Unified_Ideograph", "Ideographic"},
    19195: {"Unified_Ideograph", "Ideographic"},
    19196: {"Unified_Ideograph", "Ideographic"},
    19197: {"Unified_Ideograph", "Ideographic"},
    19198: {"Unified_Ideograph", "Ideographic"},
    19199: {"Unified_Ideograph", "Ideographic"},
    19200: {"Unified_Ideograph", "Ideographic"},
    19201: {"Unified_Ideograph", "Ideographic"},
    19202: {"Unified_Ideograph", "Ideographic"},
    19203: {"Unified_Ideograph", "Ideographic"},
    19204: {"Unified_Ideograph", "Ideographic"},
    19205: {"Unified_Ideograph", "Ideographic"},
    19206: {"Unified_Ideograph", "Ideographic"},
    19207: {"Unified_Ideograph", "Ideographic"},
    19208: {"Unified_Ideograph", "Ideographic"},
    19209: {"Unified_Ideograph", "Ideographic"},
    19210: {"Unified_Ideograph", "Ideographic"},
    19211: {"Unified_Ideograph", "Ideographic"},
    19212: {"Unified_Ideograph", "Ideographic"},
    19213: {"Unified_Ideograph", "Ideographic"},
    19214: {"Unified_Ideograph", "Ideographic"},
    19215: {"Unified_Ideograph", "Ideographic"},
    19216: {"Unified_Ideograph", "Ideographic"},
    19217: {"Unified_Ideograph", "Ideographic"},
    19218: {"Unified_Ideograph", "Ideographic"},
    19219: {"Unified_Ideograph", "Ideographic"},
    19220: {"Unified_Ideograph", "Ideographic"},
    19221: {"Unified_Ideograph", "Ideographic"},
    19222: {"Unified_Ideograph", "Ideographic"},
    19223: {"Unified_Ideograph", "Ideographic"},
    19224: {"Unified_Ideograph", "Ideographic"},
    19225: {"Unified_Ideograph", "Ideographic"},
    19226: {"Unified_Ideograph", "Ideographic"},
    19227: {"Unified_Ideograph", "Ideographic"},
    19228: {"Unified_Ideograph", "Ideographic"},
    19229: {"Unified_Ideograph", "Ideographic"},
    19230: {"Unified_Ideograph", "Ideographic"},
    19231: {"Unified_Ideograph", "Ideographic"},
    19232: {"Unified_Ideograph", "Ideographic"},
    19233: {"Unified_Ideograph", "Ideographic"},
    19234: {"Unified_Ideograph", "Ideographic"},
    19235: {"Unified_Ideograph", "Ideographic"},
    19236: {"Unified_Ideograph", "Ideographic"},
    19237: {"Unified_Ideograph", "Ideographic"},
    19238: {"Unified_Ideograph", "Ideographic"},
    19239: {"Unified_Ideograph", "Ideographic"},
    19240: {"Unified_Ideograph", "Ideographic"},
    19241: {"Unified_Ideograph", "Ideographic"},
    19242: {"Unified_Ideograph", "Ideographic"},
    19243: {"Unified_Ideograph", "Ideographic"},
    19244: {"Unified_Ideograph", "Ideographic"},
    19245: {"Unified_Ideograph", "Ideographic"},
    19246: {"Unified_Ideograph", "Ideographic"},
    19247: {"Unified_Ideograph", "Ideographic"},
    19248: {"Unified_Ideograph", "Ideographic"},
    19249: {"Unified_Ideograph", "Ideographic"},
    19250: {"Unified_Ideograph", "Ideographic"},
    19251: {"Unified_Ideograph", "Ideographic"},
    19252: {"Unified_Ideograph", "Ideographic"},
    19253: {"Unified_Ideograph", "Ideographic"},
    19254: {"Unified_Ideograph", "Ideographic"},
    19255: {"Unified_Ideograph", "Ideographic"},
    19256: {"Unified_Ideograph", "Ideographic"},
    19257: {"Unified_Ideograph", "Ideographic"},
    19258: {"Unified_Ideograph", "Ideographic"},
    19259: {"Unified_Ideograph", "Ideographic"},
    19260: {"Unified_Ideograph", "Ideographic"},
    19261: {"Unified_Ideograph", "Ideographic"},
    19262: {"Unified_Ideograph", "Ideographic"},
    19263: {"Unified_Ideograph", "Ideographic"},
    19264: {"Unified_Ideograph", "Ideographic"},
    19265: {"Unified_Ideograph", "Ideographic"},
    19266: {"Unified_Ideograph", "Ideographic"},
    19267: {"Unified_Ideograph", "Ideographic"},
    19268: {"Unified_Ideograph", "Ideographic"},
    19269: {"Unified_Ideograph", "Ideographic"},
    19270: {"Unified_Ideograph", "Ideographic"},
    19271: {"Unified_Ideograph", "Ideographic"},
    19272: {"Unified_Ideograph", "Ideographic"},
    19273: {"Unified_Ideograph", "Ideographic"},
    19274: {"Unified_Ideograph", "Ideographic"},
    19275: {"Unified_Ideograph", "Ideographic"},
    19276: {"Unified_Ideograph", "Ideographic"},
    19277: {"Unified_Ideograph", "Ideographic"},
    19278: {"Unified_Ideograph", "Ideographic"},
    19279: {"Unified_Ideograph", "Ideographic"},
    19280: {"Unified_Ideograph", "Ideographic"},
    19281: {"Unified_Ideograph", "Ideographic"},
    19282: {"Unified_Ideograph", "Ideographic"},
    19283: {"Unified_Ideograph", "Ideographic"},
    19284: {"Unified_Ideograph", "Ideographic"},
    19285: {"Unified_Ideograph", "Ideographic"},
    19286: {"Unified_Ideograph", "Ideographic"},
    19287: {"Unified_Ideograph", "Ideographic"},
    19288: {"Unified_Ideograph", "Ideographic"},
    19289: {"Unified_Ideograph", "Ideographic"},
    19290: {"Unified_Ideograph", "Ideographic"},
    19291: {"Unified_Ideograph", "Ideographic"},
    19292: {"Unified_Ideograph", "Ideographic"},
    19293: {"Unified_Ideograph", "Ideographic"},
    19294: {"Unified_Ideograph", "Ideographic"},
    19295: {"Unified_Ideograph", "Ideographic"},
    19296: {"Unified_Ideograph", "Ideographic"},
    19297: {"Unified_Ideograph", "Ideographic"},
    19298: {"Unified_Ideograph", "Ideographic"},
    19299: {"Unified_Ideograph", "Ideographic"},
    19300: {"Unified_Ideograph", "Ideographic"},
    19301: {"Unified_Ideograph", "Ideographic"},
    19302: {"Unified_Ideograph", "Ideographic"},
    19303: {"Unified_Ideograph", "Ideographic"},
    19304: {"Unified_Ideograph", "Ideographic"},
    19305: {"Unified_Ideograph", "Ideographic"},
    19306: {"Unified_Ideograph", "Ideographic"},
    19307: {"Unified_Ideograph", "Ideographic"},
    19308: {"Unified_Ideograph", "Ideographic"},
    19309: {"Unified_Ideograph", "Ideographic"},
    19310: {"Unified_Ideograph", "Ideographic"},
    19311: {"Unified_Ideograph", "Ideographic"},
    19312: {"Unified_Ideograph", "Ideographic"},
    19313: {"Unified_Ideograph", "Ideographic"},
    19314: {"Unified_Ideograph", "Ideographic"},
    19315: {"Unified_Ideograph", "Ideographic"},
    19316: {"Unified_Ideograph", "Ideographic"},
    19317: {"Unified_Ideograph", "Ideographic"},
    19318: {"Unified_Ideograph", "Ideographic"},
    19319: {"Unified_Ideograph", "Ideographic"},
    19320: {"Unified_Ideograph", "Ideographic"},
    19321: {"Unified_Ideograph", "Ideographic"},
    19322: {"Unified_Ideograph", "Ideographic"},
    19323: {"Unified_Ideograph", "Ideographic"},
    19324: {"Unified_Ideograph", "Ideographic"},
    19325: {"Unified_Ideograph", "Ideographic"},
    19326: {"Unified_Ideograph", "Ideographic"},
    19327: {"Unified_Ideograph", "Ideographic"},
    19328: {"Unified_Ideograph", "Ideographic"},
    19329: {"Unified_Ideograph", "Ideographic"},
    19330: {"Unified_Ideograph", "Ideographic"},
    19331: {"Unified_Ideograph", "Ideographic"},
    19332: {"Unified_Ideograph", "Ideographic"},
    19333: {"Unified_Ideograph", "Ideographic"},
    19334: {"Unified_Ideograph", "Ideographic"},
    19335: {"Unified_Ideograph", "Ideographic"},
    19336: {"Unified_Ideograph", "Ideographic"},
    19337: {"Unified_Ideograph", "Ideographic"},
    19338: {"Unified_Ideograph", "Ideographic"},
    19339: {"Unified_Ideograph", "Ideographic"},
    19340: {"Unified_Ideograph", "Ideographic"},
    19341: {"Unified_Ideograph", "Ideographic"},
    19342: {"Unified_Ideograph", "Ideographic"},
    19343: {"Unified_Ideograph", "Ideographic"},
    19344: {"Unified_Ideograph", "Ideographic"},
    19345: {"Unified_Ideograph", "Ideographic"},
    19346: {"Unified_Ideograph", "Ideographic"},
    19347: {"Unified_Ideograph", "Ideographic"},
    19348: {"Unified_Ideograph", "Ideographic"},
    19349: {"Unified_Ideograph", "Ideographic"},
    19350: {"Unified_Ideograph", "Ideographic"},
    19351: {"Unified_Ideograph", "Ideographic"},
    19352: {"Unified_Ideograph", "Ideographic"},
    19353: {"Unified_Ideograph", "Ideographic"},
    19354: {"Unified_Ideograph", "Ideographic"},
    19355: {"Unified_Ideograph", "Ideographic"},
    19356: {"Unified_Ideograph", "Ideographic"},
    19357: {"Unified_Ideograph", "Ideographic"},
    19358: {"Unified_Ideograph", "Ideographic"},
    19359: {"Unified_Ideograph", "Ideographic"},
    19360: {"Unified_Ideograph", "Ideographic"},
    19361: {"Unified_Ideograph", "Ideographic"},
    19362: {"Unified_Ideograph", "Ideographic"},
    19363: {"Unified_Ideograph", "Ideographic"},
    19364: {"Unified_Ideograph", "Ideographic"},
    19365: {"Unified_Ideograph", "Ideographic"},
    19366: {"Unified_Ideograph", "Ideographic"},
    19367: {"Unified_Ideograph", "Ideographic"},
    19368: {"Unified_Ideograph", "Ideographic"},
    19369: {"Unified_Ideograph", "Ideographic"},
    19370: {"Unified_Ideograph", "Ideographic"},
    19371: {"Unified_Ideograph", "Ideographic"},
    19372: {"Unified_Ideograph", "Ideographic"},
    19373: {"Unified_Ideograph", "Ideographic"},
    19374: {"Unified_Ideograph", "Ideographic"},
    19375: {"Unified_Ideograph", "Ideographic"},
    19376: {"Unified_Ideograph", "Ideographic"},
    19377: {"Unified_Ideograph", "Ideographic"},
    19378: {"Unified_Ideograph", "Ideographic"},
    19379: {"Unified_Ideograph", "Ideographic"},
    19380: {"Unified_Ideograph", "Ideographic"},
    19381: {"Unified_Ideograph", "Ideographic"},
    19382: {"Unified_Ideograph", "Ideographic"},
    19383: {"Unified_Ideograph", "Ideographic"},
    19384: {"Unified_Ideograph", "Ideographic"},
    19385: {"Unified_Ideograph", "Ideographic"},
    19386: {"Unified_Ideograph", "Ideographic"},
    19387: {"Unified_Ideograph", "Ideographic"},
    19388: {"Unified_Ideograph", "Ideographic"},
    19389: {"Unified_Ideograph", "Ideographic"},
    19390: {"Unified_Ideograph", "Ideographic"},
    19391: {"Unified_Ideograph", "Ideographic"},
    19392: {"Unified_Ideograph", "Ideographic"},
    19393: {"Unified_Ideograph", "Ideographic"},
    19394: {"Unified_Ideograph", "Ideographic"},
    19395: {"Unified_Ideograph", "Ideographic"},
    19396: {"Unified_Ideograph", "Ideographic"},
    19397: {"Unified_Ideograph", "Ideographic"},
    19398: {"Unified_Ideograph", "Ideographic"},
    19399: {"Unified_Ideograph", "Ideographic"},
    19400: {"Unified_Ideograph", "Ideographic"},
    19401: {"Unified_Ideograph", "Ideographic"},
    19402: {"Unified_Ideograph", "Ideographic"},
    19403: {"Unified_Ideograph", "Ideographic"},
    19404: {"Unified_Ideograph", "Ideographic"},
    19405: {"Unified_Ideograph", "Ideographic"},
    19406: {"Unified_Ideograph", "Ideographic"},
    19407: {"Unified_Ideograph", "Ideographic"},
    19408: {"Unified_Ideograph", "Ideographic"},
    19409: {"Unified_Ideograph", "Ideographic"},
    19410: {"Unified_Ideograph", "Ideographic"},
    19411: {"Unified_Ideograph", "Ideographic"},
    19412: {"Unified_Ideograph", "Ideographic"},
    19413: {"Unified_Ideograph", "Ideographic"},
    19414: {"Unified_Ideograph", "Ideographic"},
    19415: {"Unified_Ideograph", "Ideographic"},
    19416: {"Unified_Ideograph", "Ideographic"},
    19417: {"Unified_Ideograph", "Ideographic"},
    19418: {"Unified_Ideograph", "Ideographic"},
    19419: {"Unified_Ideograph", "Ideographic"},
    19420: {"Unified_Ideograph", "Ideographic"},
    19421: {"Unified_Ideograph", "Ideographic"},
    19422: {"Unified_Ideograph", "Ideographic"},
    19423: {"Unified_Ideograph", "Ideographic"},
    19424: {"Unified_Ideograph", "Ideographic"},
    19425: {"Unified_Ideograph", "Ideographic"},
    19426: {"Unified_Ideograph", "Ideographic"},
    19427: {"Unified_Ideograph", "Ideographic"},
    19428: {"Unified_Ideograph", "Ideographic"},
    19429: {"Unified_Ideograph", "Ideographic"},
    19430: {"Unified_Ideograph", "Ideographic"},
    19431: {"Unified_Ideograph", "Ideographic"},
    19432: {"Unified_Ideograph", "Ideographic"},
    19433: {"Unified_Ideograph", "Ideographic"},
    19434: {"Unified_Ideograph", "Ideographic"},
    19435: {"Unified_Ideograph", "Ideographic"},
    19436: {"Unified_Ideograph", "Ideographic"},
    19437: {"Unified_Ideograph", "Ideographic"},
    19438: {"Unified_Ideograph", "Ideographic"},
    19439: {"Unified_Ideograph", "Ideographic"},
    19440: {"Unified_Ideograph", "Ideographic"},
    19441: {"Unified_Ideograph", "Ideographic"},
    19442: {"Unified_Ideograph", "Ideographic"},
    19443: {"Unified_Ideograph", "Ideographic"},
    19444: {"Unified_Ideograph", "Ideographic"},
    19445: {"Unified_Ideograph", "Ideographic"},
    19446: {"Unified_Ideograph", "Ideographic"},
    19447: {"Unified_Ideograph", "Ideographic"},
    19448: {"Unified_Ideograph", "Ideographic"},
    19449: {"Unified_Ideograph", "Ideographic"},
    19450: {"Unified_Ideograph", "Ideographic"},
    19451: {"Unified_Ideograph", "Ideographic"},
    19452: {"Unified_Ideograph", "Ideographic"},
    19453: {"Unified_Ideograph", "Ideographic"},
    19454: {"Unified_Ideograph", "Ideographic"},
    19455: {"Unified_Ideograph", "Ideographic"},
    19456: {"Unified_Ideograph", "Ideographic"},
    19457: {"Unified_Ideograph", "Ideographic"},
    19458: {"Unified_Ideograph", "Ideographic"},
    19459: {"Unified_Ideograph", "Ideographic"},
    19460: {"Unified_Ideograph", "Ideographic"},
    19461: {"Unified_Ideograph", "Ideographic"},
    19462: {"Unified_Ideograph", "Ideographic"},
    19463: {"Unified_Ideograph", "Ideographic"},
    19464: {"Unified_Ideograph", "Ideographic"},
    19465: {"Unified_Ideograph", "Ideographic"},
    19466: {"Unified_Ideograph", "Ideographic"},
    19467: {"Unified_Ideograph", "Ideographic"},
    19468: {"Unified_Ideograph", "Ideographic"},
    19469: {"Unified_Ideograph", "Ideographic"},
    19470: {"Unified_Ideograph", "Ideographic"},
    19471: {"Unified_Ideograph", "Ideographic"},
    19472: {"Unified_Ideograph", "Ideographic"},
    19473: {"Unified_Ideograph", "Ideographic"},
    19474: {"Unified_Ideograph", "Ideographic"},
    19475: {"Unified_Ideograph", "Ideographic"},
    19476: {"Unified_Ideograph", "Ideographic"},
    19477: {"Unified_Ideograph", "Ideographic"},
    19478: {"Unified_Ideograph", "Ideographic"},
    19479: {"Unified_Ideograph", "Ideographic"},
    19480: {"Unified_Ideograph", "Ideographic"},
    19481: {"Unified_Ideograph", "Ideographic"},
    19482: {"Unified_Ideograph", "Ideographic"},
    19483: {"Unified_Ideograph", "Ideographic"},
    19484: {"Unified_Ideograph", "Ideographic"},
    19485: {"Unified_Ideograph", "Ideographic"},
    19486: {"Unified_Ideograph", "Ideographic"},
    19487: {"Unified_Ideograph", "Ideographic"},
    19488: {"Unified_Ideograph", "Ideographic"},
    19489: {"Unified_Ideograph", "Ideographic"},
    19490: {"Unified_Ideograph", "Ideographic"},
    19491: {"Unified_Ideograph", "Ideographic"},
    19492: {"Unified_Ideograph", "Ideographic"},
    19493: {"Unified_Ideograph", "Ideographic"},
    19494: {"Unified_Ideograph", "Ideographic"},
    19495: {"Unified_Ideograph", "Ideographic"},
    19496: {"Unified_Ideograph", "Ideographic"},
    19497: {"Unified_Ideograph", "Ideographic"},
    19498: {"Unified_Ideograph", "Ideographic"},
    19499: {"Unified_Ideograph", "Ideographic"},
    19500: {"Unified_Ideograph", "Ideographic"},
    19501: {"Unified_Ideograph", "Ideographic"},
    19502: {"Unified_Ideograph", "Ideographic"},
    19503: {"Unified_Ideograph", "Ideographic"},
    19504: {"Unified_Ideograph", "Ideographic"},
    19505: {"Unified_Ideograph", "Ideographic"},
    19506: {"Unified_Ideograph", "Ideographic"},
    19507: {"Unified_Ideograph", "Ideographic"},
    19508: {"Unified_Ideograph", "Ideographic"},
    19509: {"Unified_Ideograph", "Ideographic"},
    19510: {"Unified_Ideograph", "Ideographic"},
    19511: {"Unified_Ideograph", "Ideographic"},
    19512: {"Unified_Ideograph", "Ideographic"},
    19513: {"Unified_Ideograph", "Ideographic"},
    19514: {"Unified_Ideograph", "Ideographic"},
    19515: {"Unified_Ideograph", "Ideographic"},
    19516: {"Unified_Ideograph", "Ideographic"},
    19517: {"Unified_Ideograph", "Ideographic"},
    19518: {"Unified_Ideograph", "Ideographic"},
    19519: {"Unified_Ideograph", "Ideographic"},
    19520: {"Unified_Ideograph", "Ideographic"},
    19521: {"Unified_Ideograph", "Ideographic"},
    19522: {"Unified_Ideograph", "Ideographic"},
    19523: {"Unified_Ideograph", "Ideographic"},
    19524: {"Unified_Ideograph", "Ideographic"},
    19525: {"Unified_Ideograph", "Ideographic"},
    19526: {"Unified_Ideograph", "Ideographic"},
    19527: {"Unified_Ideograph", "Ideographic"},
    19528: {"Unified_Ideograph", "Ideographic"},
    19529: {"Unified_Ideograph", "Ideographic"},
    19530: {"Unified_Ideograph", "Ideographic"},
    19531: {"Unified_Ideograph", "Ideographic"},
    19532: {"Unified_Ideograph", "Ideographic"},
    19533: {"Unified_Ideograph", "Ideographic"},
    19534: {"Unified_Ideograph", "Ideographic"},
    19535: {"Unified_Ideograph", "Ideographic"},
    19536: {"Unified_Ideograph", "Ideographic"},
    19537: {"Unified_Ideograph", "Ideographic"},
    19538: {"Unified_Ideograph", "Ideographic"},
    19539: {"Unified_Ideograph", "Ideographic"},
    19540: {"Unified_Ideograph", "Ideographic"},
    19541: {"Unified_Ideograph", "Ideographic"},
    19542: {"Unified_Ideograph", "Ideographic"},
    19543: {"Unified_Ideograph", "Ideographic"},
    19544: {"Unified_Ideograph", "Ideographic"},
    19545: {"Unified_Ideograph", "Ideographic"},
    19546: {"Unified_Ideograph", "Ideographic"},
    19547: {"Unified_Ideograph", "Ideographic"},
    19548: {"Unified_Ideograph", "Ideographic"},
    19549: {"Unified_Ideograph", "Ideographic"},
    19550: {"Unified_Ideograph", "Ideographic"},
    19551: {"Unified_Ideograph", "Ideographic"},
    19552: {"Unified_Ideograph", "Ideographic"},
    19553: {"Unified_Ideograph", "Ideographic"},
    19554: {"Unified_Ideograph", "Ideographic"},
    19555: {"Unified_Ideograph", "Ideographic"},
    19556: {"Unified_Ideograph", "Ideographic"},
    19557: {"Unified_Ideograph", "Ideographic"},
    19558: {"Unified_Ideograph", "Ideographic"},
    19559: {"Unified_Ideograph", "Ideographic"},
    19560: {"Unified_Ideograph", "Ideographic"},
    19561: {"Unified_Ideograph", "Ideographic"},
    19562: {"Unified_Ideograph", "Ideographic"},
    19563: {"Unified_Ideograph", "Ideographic"},
    19564: {"Unified_Ideograph", "Ideographic"},
    19565: {"Unified_Ideograph", "Ideographic"},
    19566: {"Unified_Ideograph", "Ideographic"},
    19567: {"Unified_Ideograph", "Ideographic"},
    19568: {"Unified_Ideograph", "Ideographic"},
    19569: {"Unified_Ideograph", "Ideographic"},
    19570: {"Unified_Ideograph", "Ideographic"},
    19571: {"Unified_Ideograph", "Ideographic"},
    19572: {"Unified_Ideograph", "Ideographic"},
    19573: {"Unified_Ideograph", "Ideographic"},
    19574: {"Unified_Ideograph", "Ideographic"},
    19575: {"Unified_Ideograph", "Ideographic"},
    19576: {"Unified_Ideograph", "Ideographic"},
    19577: {"Unified_Ideograph", "Ideographic"},
    19578: {"Unified_Ideograph", "Ideographic"},
    19579: {"Unified_Ideograph", "Ideographic"},
    19580: {"Unified_Ideograph", "Ideographic"},
    19581: {"Unified_Ideograph", "Ideographic"},
    19582: {"Unified_Ideograph", "Ideographic"},
    19583: {"Unified_Ideograph", "Ideographic"},
    19584: {"Unified_Ideograph", "Ideographic"},
    19585: {"Unified_Ideograph", "Ideographic"},
    19586: {"Unified_Ideograph", "Ideographic"},
    19587: {"Unified_Ideograph", "Ideographic"},
    19588: {"Unified_Ideograph", "Ideographic"},
    19589: {"Unified_Ideograph", "Ideographic"},
    19590: {"Unified_Ideograph", "Ideographic"},
    19591: {"Unified_Ideograph", "Ideographic"},
    19592: {"Unified_Ideograph", "Ideographic"},
    19593: {"Unified_Ideograph", "Ideographic"},
    19594: {"Unified_Ideograph", "Ideographic"},
    19595: {"Unified_Ideograph", "Ideographic"},
    19596: {"Unified_Ideograph", "Ideographic"},
    19597: {"Unified_Ideograph", "Ideographic"},
    19598: {"Unified_Ideograph", "Ideographic"},
    19599: {"Unified_Ideograph", "Ideographic"},
    19600: {"Unified_Ideograph", "Ideographic"},
    19601: {"Unified_Ideograph", "Ideographic"},
    19602: {"Unified_Ideograph", "Ideographic"},
    19603: {"Unified_Ideograph", "Ideographic"},
    19604: {"Unified_Ideograph", "Ideographic"},
    19605: {"Unified_Ideograph", "Ideographic"},
    19606: {"Unified_Ideograph", "Ideographic"},
    19607: {"Unified_Ideograph", "Ideographic"},
    19608: {"Unified_Ideograph", "Ideographic"},
    19609: {"Unified_Ideograph", "Ideographic"},
    19610: {"Unified_Ideograph", "Ideographic"},
    19611: {"Unified_Ideograph", "Ideographic"},
    19612: {"Unified_Ideograph", "Ideographic"},
    19613: {"Unified_Ideograph", "Ideographic"},
    19614: {"Unified_Ideograph", "Ideographic"},
    19615: {"Unified_Ideograph", "Ideographic"},
    19616: {"Unified_Ideograph", "Ideographic"},
    19617: {"Unified_Ideograph", "Ideographic"},
    19618: {"Unified_Ideograph", "Ideographic"},
    19619: {"Unified_Ideograph", "Ideographic"},
    19620: {"Unified_Ideograph", "Ideographic"},
    19621: {"Unified_Ideograph", "Ideographic"},
    19622: {"Unified_Ideograph", "Ideographic"},
    19623: {"Unified_Ideograph", "Ideographic"},
    19624: {"Unified_Ideograph", "Ideographic"},
    19625: {"Unified_Ideograph", "Ideographic"},
    19626: {"Unified_Ideograph", "Ideographic"},
    19627: {"Unified_Ideograph", "Ideographic"},
    19628: {"Unified_Ideograph", "Ideographic"},
    19629: {"Unified_Ideograph", "Ideographic"},
    19630: {"Unified_Ideograph", "Ideographic"},
    19631: {"Unified_Ideograph", "Ideographic"},
    19632: {"Unified_Ideograph", "Ideographic"},
    19633: {"Unified_Ideograph", "Ideographic"},
    19634: {"Unified_Ideograph", "Ideographic"},
    19635: {"Unified_Ideograph", "Ideographic"},
    19636: {"Unified_Ideograph", "Ideographic"},
    19637: {"Unified_Ideograph", "Ideographic"},
    19638: {"Unified_Ideograph", "Ideographic"},
    19639: {"Unified_Ideograph", "Ideographic"},
    19640: {"Unified_Ideograph", "Ideographic"},
    19641: {"Unified_Ideograph", "Ideographic"},
    19642: {"Unified_Ideograph", "Ideographic"},
    19643: {"Unified_Ideograph", "Ideographic"},
    19644: {"Unified_Ideograph", "Ideographic"},
    19645: {"Unified_Ideograph", "Ideographic"},
    19646: {"Unified_Ideograph", "Ideographic"},
    19647: {"Unified_Ideograph", "Ideographic"},
    19648: {"Unified_Ideograph", "Ideographic"},
    19649: {"Unified_Ideograph", "Ideographic"},
    19650: {"Unified_Ideograph", "Ideographic"},
    19651: {"Unified_Ideograph", "Ideographic"},
    19652: {"Unified_Ideograph", "Ideographic"},
    19653: {"Unified_Ideograph", "Ideographic"},
    19654: {"Unified_Ideograph", "Ideographic"},
    19655: {"Unified_Ideograph", "Ideographic"},
    19656: {"Unified_Ideograph", "Ideographic"},
    19657: {"Unified_Ideograph", "Ideographic"},
    19658: {"Unified_Ideograph", "Ideographic"},
    19659: {"Unified_Ideograph", "Ideographic"},
    19660: {"Unified_Ideograph", "Ideographic"},
    19661: {"Unified_Ideograph", "Ideographic"},
    19662: {"Unified_Ideograph", "Ideographic"},
    19663: {"Unified_Ideograph", "Ideographic"},
    19664: {"Unified_Ideograph", "Ideographic"},
    19665: {"Unified_Ideograph", "Ideographic"},
    19666: {"Unified_Ideograph", "Ideographic"},
    19667: {"Unified_Ideograph", "Ideographic"},
    19668: {"Unified_Ideograph", "Ideographic"},
    19669: {"Unified_Ideograph", "Ideographic"},
    19670: {"Unified_Ideograph", "Ideographic"},
    19671: {"Unified_Ideograph", "Ideographic"},
    19672: {"Unified_Ideograph", "Ideographic"},
    19673: {"Unified_Ideograph", "Ideographic"},
    19674: {"Unified_Ideograph", "Ideographic"},
    19675: {"Unified_Ideograph", "Ideographic"},
    19676: {"Unified_Ideograph", "Ideographic"},
    19677: {"Unified_Ideograph", "Ideographic"},
    19678: {"Unified_Ideograph", "Ideographic"},
    19679: {"Unified_Ideograph", "Ideographic"},
    19680: {"Unified_Ideograph", "Ideographic"},
    19681: {"Unified_Ideograph", "Ideographic"},
    19682: {"Unified_Ideograph", "Ideographic"},
    19683: {"Unified_Ideograph", "Ideographic"},
    19684: {"Unified_Ideograph", "Ideographic"},
    19685: {"Unified_Ideograph", "Ideographic"},
    19686: {"Unified_Ideograph", "Ideographic"},
    19687: {"Unified_Ideograph", "Ideographic"},
    19688: {"Unified_Ideograph", "Ideographic"},
    19689: {"Unified_Ideograph", "Ideographic"},
    19690: {"Unified_Ideograph", "Ideographic"},
    19691: {"Unified_Ideograph", "Ideographic"},
    19692: {"Unified_Ideograph", "Ideographic"},
    19693: {"Unified_Ideograph", "Ideographic"},
    19694: {"Unified_Ideograph", "Ideographic"},
    19695: {"Unified_Ideograph", "Ideographic"},
    19696: {"Unified_Ideograph", "Ideographic"},
    19697: {"Unified_Ideograph", "Ideographic"},
    19698: {"Unified_Ideograph", "Ideographic"},
    19699: {"Unified_Ideograph", "Ideographic"},
    19700: {"Unified_Ideograph", "Ideographic"},
    19701: {"Unified_Ideograph", "Ideographic"},
    19702: {"Unified_Ideograph", "Ideographic"},
    19703: {"Unified_Ideograph", "Ideographic"},
    19704: {"Unified_Ideograph", "Ideographic"},
    19705: {"Unified_Ideograph", "Ideographic"},
    19706: {"Unified_Ideograph", "Ideographic"},
    19707: {"Unified_Ideograph", "Ideographic"},
    19708: {"Unified_Ideograph", "Ideographic"},
    19709: {"Unified_Ideograph", "Ideographic"},
    19710: {"Unified_Ideograph", "Ideographic"},
    19711: {"Unified_Ideograph", "Ideographic"},
    19712: {"Unified_Ideograph", "Ideographic"},
    19713: {"Unified_Ideograph", "Ideographic"},
    19714: {"Unified_Ideograph", "Ideographic"},
    19715: {"Unified_Ideograph", "Ideographic"},
    19716: {"Unified_Ideograph", "Ideographic"},
    19717: {"Unified_Ideograph", "Ideographic"},
    19718: {"Unified_Ideograph", "Ideographic"},
    19719: {"Unified_Ideograph", "Ideographic"},
    19720: {"Unified_Ideograph", "Ideographic"},
    19721: {"Unified_Ideograph", "Ideographic"},
    19722: {"Unified_Ideograph", "Ideographic"},
    19723: {"Unified_Ideograph", "Ideographic"},
    19724: {"Unified_Ideograph", "Ideographic"},
    19725: {"Unified_Ideograph", "Ideographic"},
    19726: {"Unified_Ideograph", "Ideographic"},
    19727: {"Unified_Ideograph", "Ideographic"},
    19728: {"Unified_Ideograph", "Ideographic"},
    19729: {"Unified_Ideograph", "Ideographic"},
    19730: {"Unified_Ideograph", "Ideographic"},
    19731: {"Unified_Ideograph", "Ideographic"},
    19732: {"Unified_Ideograph", "Ideographic"},
    19733: {"Unified_Ideograph", "Ideographic"},
    19734: {"Unified_Ideograph", "Ideographic"},
    19735: {"Unified_Ideograph", "Ideographic"},
    19736: {"Unified_Ideograph", "Ideographic"},
    19737: {"Unified_Ideograph", "Ideographic"},
    19738: {"Unified_Ideograph", "Ideographic"},
    19739: {"Unified_Ideograph", "Ideographic"},
    19740: {"Unified_Ideograph", "Ideographic"},
    19741: {"Unified_Ideograph", "Ideographic"},
    19742: {"Unified_Ideograph", "Ideographic"},
    19743: {"Unified_Ideograph", "Ideographic"},
    19744: {"Unified_Ideograph", "Ideographic"},
    19745: {"Unified_Ideograph", "Ideographic"},
    19746: {"Unified_Ideograph", "Ideographic"},
    19747: {"Unified_Ideograph", "Ideographic"},
    19748: {"Unified_Ideograph", "Ideographic"},
    19749: {"Unified_Ideograph", "Ideographic"},
    19750: {"Unified_Ideograph", "Ideographic"},
    19751: {"Unified_Ideograph", "Ideographic"},
    19752: {"Unified_Ideograph", "Ideographic"},
    19753: {"Unified_Ideograph", "Ideographic"},
    19754: {"Unified_Ideograph", "Ideographic"},
    19755: {"Unified_Ideograph", "Ideographic"},
    19756: {"Unified_Ideograph", "Ideographic"},
    19757: {"Unified_Ideograph", "Ideographic"},
    19758: {"Unified_Ideograph", "Ideographic"},
    19759: {"Unified_Ideograph", "Ideographic"},
    19760: {"Unified_Ideograph", "Ideographic"},
    19761: {"Unified_Ideograph", "Ideographic"},
    19762: {"Unified_Ideograph", "Ideographic"},
    19763: {"Unified_Ideograph", "Ideographic"},
    19764: {"Unified_Ideograph", "Ideographic"},
    19765: {"Unified_Ideograph", "Ideographic"},
    19766: {"Unified_Ideograph", "Ideographic"},
    19767: {"Unified_Ideograph", "Ideographic"},
    19768: {"Unified_Ideograph", "Ideographic"},
    19769: {"Unified_Ideograph", "Ideographic"},
    19770: {"Unified_Ideograph", "Ideographic"},
    19771: {"Unified_Ideograph", "Ideographic"},
    19772: {"Unified_Ideograph", "Ideographic"},
    19773: {"Unified_Ideograph", "Ideographic"},
    19774: {"Unified_Ideograph", "Ideographic"},
    19775: {"Unified_Ideograph", "Ideographic"},
    19776: {"Unified_Ideograph", "Ideographic"},
    19777: {"Unified_Ideograph", "Ideographic"},
    19778: {"Unified_Ideograph", "Ideographic"},
    19779: {"Unified_Ideograph", "Ideographic"},
    19780: {"Unified_Ideograph", "Ideographic"},
    19781: {"Unified_Ideograph", "Ideographic"},
    19782: {"Unified_Ideograph", "Ideographic"},
    19783: {"Unified_Ideograph", "Ideographic"},
    19784: {"Unified_Ideograph", "Ideographic"},
    19785: {"Unified_Ideograph", "Ideographic"},
    19786: {"Unified_Ideograph", "Ideographic"},
    19787: {"Unified_Ideograph", "Ideographic"},
    19788: {"Unified_Ideograph", "Ideographic"},
    19789: {"Unified_Ideograph", "Ideographic"},
    19790: {"Unified_Ideograph", "Ideographic"},
    19791: {"Unified_Ideograph", "Ideographic"},
    19792: {"Unified_Ideograph", "Ideographic"},
    19793: {"Unified_Ideograph", "Ideographic"},
    19794: {"Unified_Ideograph", "Ideographic"},
    19795: {"Unified_Ideograph", "Ideographic"},
    19796: {"Unified_Ideograph", "Ideographic"},
    19797: {"Unified_Ideograph", "Ideographic"},
    19798: {"Unified_Ideograph", "Ideographic"},
    19799: {"Unified_Ideograph", "Ideographic"},
    19800: {"Unified_Ideograph", "Ideographic"},
    19801: {"Unified_Ideograph", "Ideographic"},
    19802: {"Unified_Ideograph", "Ideographic"},
    19803: {"Unified_Ideograph", "Ideographic"},
    19804: {"Unified_Ideograph", "Ideographic"},
    19805: {"Unified_Ideograph", "Ideographic"},
    19806: {"Unified_Ideograph", "Ideographic"},
    19807: {"Unified_Ideograph", "Ideographic"},
    19808: {"Unified_Ideograph", "Ideographic"},
    19809: {"Unified_Ideograph", "Ideographic"},
    19810: {"Unified_Ideograph", "Ideographic"},
    19811: {"Unified_Ideograph", "Ideographic"},
    19812: {"Unified_Ideograph", "Ideographic"},
    19813: {"Unified_Ideograph", "Ideographic"},
    19814: {"Unified_Ideograph", "Ideographic"},
    19815: {"Unified_Ideograph", "Ideographic"},
    19816: {"Unified_Ideograph", "Ideographic"},
    19817: {"Unified_Ideograph", "Ideographic"},
    19818: {"Unified_Ideograph", "Ideographic"},
    19819: {"Unified_Ideograph", "Ideographic"},
    19820: {"Unified_Ideograph", "Ideographic"},
    19821: {"Unified_Ideograph", "Ideographic"},
    19822: {"Unified_Ideograph", "Ideographic"},
    19823: {"Unified_Ideograph", "Ideographic"},
    19824: {"Unified_Ideograph", "Ideographic"},
    19825: {"Unified_Ideograph", "Ideographic"},
    19826: {"Unified_Ideograph", "Ideographic"},
    19827: {"Unified_Ideograph", "Ideographic"},
    19828: {"Unified_Ideograph", "Ideographic"},
    19829: {"Unified_Ideograph", "Ideographic"},
    19830: {"Unified_Ideograph", "Ideographic"},
    19831: {"Unified_Ideograph", "Ideographic"},
    19832: {"Unified_Ideograph", "Ideographic"},
    19833: {"Unified_Ideograph", "Ideographic"},
    19834: {"Unified_Ideograph", "Ideographic"},
    19835: {"Unified_Ideograph", "Ideographic"},
    19836: {"Unified_Ideograph", "Ideographic"},
    19837: {"Unified_Ideograph", "Ideographic"},
    19838: {"Unified_Ideograph", "Ideographic"},
    19839: {"Unified_Ideograph", "Ideographic"},
    19840: {"Unified_Ideograph", "Ideographic"},
    19841: {"Unified_Ideograph", "Ideographic"},
    19842: {"Unified_Ideograph", "Ideographic"},
    19843: {"Unified_Ideograph", "Ideographic"},
    19844: {"Unified_Ideograph", "Ideographic"},
    19845: {"Unified_Ideograph", "Ideographic"},
    19846: {"Unified_Ideograph", "Ideographic"},
    19847: {"Unified_Ideograph", "Ideographic"},
    19848: {"Unified_Ideograph", "Ideographic"},
    19849: {"Unified_Ideograph", "Ideographic"},
    19850: {"Unified_Ideograph", "Ideographic"},
    19851: {"Unified_Ideograph", "Ideographic"},
    19852: {"Unified_Ideograph", "Ideographic"},
    19853: {"Unified_Ideograph", "Ideographic"},
    19854: {"Unified_Ideograph", "Ideographic"},
    19855: {"Unified_Ideograph", "Ideographic"},
    19856: {"Unified_Ideograph", "Ideographic"},
    19857: {"Unified_Ideograph", "Ideographic"},
    19858: {"Unified_Ideograph", "Ideographic"},
    19859: {"Unified_Ideograph", "Ideographic"},
    19860: {"Unified_Ideograph", "Ideographic"},
    19861: {"Unified_Ideograph", "Ideographic"},
    19862: {"Unified_Ideograph", "Ideographic"},
    19863: {"Unified_Ideograph", "Ideographic"},
    19864: {"Unified_Ideograph", "Ideographic"},
    19865: {"Unified_Ideograph", "Ideographic"},
    19866: {"Unified_Ideograph", "Ideographic"},
    19867: {"Unified_Ideograph", "Ideographic"},
    19868: {"Unified_Ideograph", "Ideographic"},
    19869: {"Unified_Ideograph", "Ideographic"},
    19870: {"Unified_Ideograph", "Ideographic"},
    19871: {"Unified_Ideograph", "Ideographic"},
    19872: {"Unified_Ideograph", "Ideographic"},
    19873: {"Unified_Ideograph", "Ideographic"},
    19874: {"Unified_Ideograph", "Ideographic"},
    19875: {"Unified_Ideograph", "Ideographic"},
    19876: {"Unified_Ideograph", "Ideographic"},
    19877: {"Unified_Ideograph", "Ideographic"},
    19878: {"Unified_Ideograph", "Ideographic"},
    19879: {"Unified_Ideograph", "Ideographic"},
    19880: {"Unified_Ideograph", "Ideographic"},
    19881: {"Unified_Ideograph", "Ideographic"},
    19882: {"Unified_Ideograph", "Ideographic"},
    19883: {"Unified_Ideograph", "Ideographic"},
    19884: {"Unified_Ideograph", "Ideographic"},
    19885: {"Unified_Ideograph", "Ideographic"},
    19886: {"Unified_Ideograph", "Ideographic"},
    19887: {"Unified_Ideograph", "Ideographic"},
    19888: {"Unified_Ideograph", "Ideographic"},
    19889: {"Unified_Ideograph", "Ideographic"},
    19890: {"Unified_Ideograph", "Ideographic"},
    19891: {"Unified_Ideograph", "Ideographic"},
    19892: {"Unified_Ideograph", "Ideographic"},
    19893: {"Unified_Ideograph", "Ideographic"},
    19894: {"Unified_Ideograph", "Ideographic"},
    19895: {"Unified_Ideograph", "Ideographic"},
    19896: {"Unified_Ideograph", "Ideographic"},
    19897: {"Unified_Ideograph", "Ideographic"},
    19898: {"Unified_Ideograph", "Ideographic"},
    19899: {"Unified_Ideograph", "Ideographic"},
    19900: {"Unified_Ideograph", "Ideographic"},
    19901: {"Unified_Ideograph", "Ideographic"},
    19902: {"Unified_Ideograph", "Ideographic"},
    19903: {"Unified_Ideograph", "Ideographic"},
    19968: {"Unified_Ideograph", "Ideographic"},
    19969: {"Unified_Ideograph", "Ideographic"},
    19970: {"Unified_Ideograph", "Ideographic"},
    19971: {"Unified_Ideograph", "Ideographic"},
    19972: {"Unified_Ideograph", "Ideographic"},
    19973: {"Unified_Ideograph", "Ideographic"},
    19974: {"Unified_Ideograph", "Ideographic"},
    19975: {"Unified_Ideograph", "Ideographic"},
    19976: {"Unified_Ideograph", "Ideographic"},
    19977: {"Unified_Ideograph", "Ideographic"},
    19978: {"Unified_Ideograph", "Ideographic"},
    19979: {"Unified_Ideograph", "Ideographic"},
    19980: {"Unified_Ideograph", "Ideographic"},
    19981: {"Unified_Ideograph", "Ideographic"},
    19982: {"Unified_Ideograph", "Ideographic"},
    19983: {"Unified_Ideograph", "Ideographic"},
    19984: {"Unified_Ideograph", "Ideographic"},
    19985: {"Unified_Ideograph", "Ideographic"},
    19986: {"Unified_Ideograph", "Ideographic"},
    19987: {"Unified_Ideograph", "Ideographic"},
    19988: {"Unified_Ideograph", "Ideographic"},
    19989: {"Unified_Ideograph", "Ideographic"},
    19990: {"Unified_Ideograph", "Ideographic"},
    19991: {"Unified_Ideograph", "Ideographic"},
    19992: {"Unified_Ideograph", "Ideographic"},
    19993: {"Unified_Ideograph", "Ideographic"},
    19994: {"Unified_Ideograph", "Ideographic"},
    19995: {"Unified_Ideograph", "Ideographic"},
    19996: {"Unified_Ideograph", "Ideographic"},
    19997: {"Unified_Ideograph", "Ideographic"},
    19998: {"Unified_Ideograph", "Ideographic"},
    19999: {"Unified_Ideograph", "Ideographic"},
    20000: {"Unified_Ideograph", "Ideographic"},
    20001: {"Unified_Ideograph", "Ideographic"},
    20002: {"Unified_Ideograph", "Ideographic"},
    20003: {"Unified_Ideograph", "Ideographic"},
    20004: {"Unified_Ideograph", "Ideographic"},
    20005: {"Unified_Ideograph", "Ideographic"},
    20006: {"Unified_Ideograph", "Ideographic"},
    20007: {"Unified_Ideograph", "Ideographic"},
    20008: {"Unified_Ideograph", "Ideographic"},
    20009: {"Unified_Ideograph", "Ideographic"},
    20010: {"Unified_Ideograph", "Ideographic"},
    20011: {"Unified_Ideograph", "Ideographic"},
    20012: {"Unified_Ideograph", "Ideographic"},
    20013: {"Unified_Ideograph", "Ideographic"},
    20014: {"Unified_Ideograph", "Ideographic"},
    20015: {"Unified_Ideograph", "Ideographic"},
    20016: {"Unified_Ideograph", "Ideographic"},
    20017: {"Unified_Ideograph", "Ideographic"},
    20018: {"Unified_Ideograph", "Ideographic"},
    20019: {"Unified_Ideograph", "Ideographic"},
    20020: {"Unified_Ideograph", "Ideographic"},
    20021: {"Unified_Ideograph", "Ideographic"},
    20022: {"Unified_Ideograph", "Ideographic"},
    20023: {"Unified_Ideograph", "Ideographic"},
    20024: {"Unified_Ideograph", "Ideographic"},
    20025: {"Unified_Ideograph", "Ideographic"},
    20026: {"Unified_Ideograph", "Ideographic"},
    20027: {"Unified_Ideograph", "Ideographic"},
    20028: {"Unified_Ideograph", "Ideographic"},
    20029: {"Unified_Ideograph", "Ideographic"},
    20030: {"Unified_Ideograph", "Ideographic"},
    20031: {"Unified_Ideograph", "Ideographic"},
    20032: {"Unified_Ideograph", "Ideographic"},
    20033: {"Unified_Ideograph", "Ideographic"},
    20034: {"Unified_Ideograph", "Ideographic"},
    20035: {"Unified_Ideograph", "Ideographic"},
    20036: {"Unified_Ideograph", "Ideographic"},
    20037: {"Unified_Ideograph", "Ideographic"},
    20038: {"Unified_Ideograph", "Ideographic"},
    20039: {"Unified_Ideograph", "Ideographic"},
    20040: {"Unified_Ideograph", "Ideographic"},
    20041: {"Unified_Ideograph", "Ideographic"},
    20042: {"Unified_Ideograph", "Ideographic"},
    20043: {"Unified_Ideograph", "Ideographic"},
    20044: {"Unified_Ideograph", "Ideographic"},
    20045: {"Unified_Ideograph", "Ideographic"},
    20046: {"Unified_Ideograph", "Ideographic"},
    20047: {"Unified_Ideograph", "Ideographic"},
    20048: {"Unified_Ideograph", "Ideographic"},
    20049: {"Unified_Ideograph", "Ideographic"},
    20050: {"Unified_Ideograph", "Ideographic"},
    20051: {"Unified_Ideograph", "Ideographic"},
    20052: {"Unified_Ideograph", "Ideographic"},
    20053: {"Unified_Ideograph", "Ideographic"},
    20054: {"Unified_Ideograph", "Ideographic"},
    20055: {"Unified_Ideograph", "Ideographic"},
    20056: {"Unified_Ideograph", "Ideographic"},
    20057: {"Unified_Ideograph", "Ideographic"},
    20058: {"Unified_Ideograph", "Ideographic"},
    20059: {"Unified_Ideograph", "Ideographic"},
    20060: {"Unified_Ideograph", "Ideographic"},
    20061: {"Unified_Ideograph", "Ideographic"},
    20062: {"Unified_Ideograph", "Ideographic"},
    20063: {"Unified_Ideograph", "Ideographic"},
    20064: {"Unified_Ideograph", "Ideographic"},
    20065: {"Unified_Ideograph", "Ideographic"},
    20066: {"Unified_Ideograph", "Ideographic"},
    20067: {"Unified_Ideograph", "Ideographic"},
    20068: {"Unified_Ideograph", "Ideographic"},
    20069: {"Unified_Ideograph", "Ideographic"},
    20070: {"Unified_Ideograph", "Ideographic"},
    20071: {"Unified_Ideograph", "Ideographic"},
    20072: {"Unified_Ideograph", "Ideographic"},
    20073: {"Unified_Ideograph", "Ideographic"},
    20074: {"Unified_Ideograph", "Ideographic"},
    20075: {"Unified_Ideograph", "Ideographic"},
    20076: {"Unified_Ideograph", "Ideographic"},
    20077: {"Unified_Ideograph", "Ideographic"},
    20078: {"Unified_Ideograph", "Ideographic"},
    20079: {"Unified_Ideograph", "Ideographic"},
    20080: {"Unified_Ideograph", "Ideographic"},
    20081: {"Unified_Ideograph", "Ideographic"},
    20082: {"Unified_Ideograph", "Ideographic"},
    20083: {"Unified_Ideograph", "Ideographic"},
    20084: {"Unified_Ideograph", "Ideographic"},
    20085: {"Unified_Ideograph", "Ideographic"},
    20086: {"Unified_Ideograph", "Ideographic"},
    20087: {"Unified_Ideograph", "Ideographic"},
    20088: {"Unified_Ideograph", "Ideographic"},
    20089: {"Unified_Ideograph", "Ideographic"},
    20090: {"Unified_Ideograph", "Ideographic"},
    20091: {"Unified_Ideograph", "Ideographic"},
    20092: {"Unified_Ideograph", "Ideographic"},
    20093: {"Unified_Ideograph", "Ideographic"},
    20094: {"Unified_Ideograph", "Ideographic"},
    20095: {"Unified_Ideograph", "Ideographic"},
    20096: {"Unified_Ideograph", "Ideographic"},
    20097: {"Unified_Ideograph", "Ideographic"},
    20098: {"Unified_Ideograph", "Ideographic"},
    20099: {"Unified_Ideograph", "Ideographic"},
    20100: {"Unified_Ideograph", "Ideographic"},
    20101: {"Unified_Ideograph", "Ideographic"},
    20102: {"Unified_Ideograph", "Ideographic"},
    20103: {"Unified_Ideograph", "Ideographic"},
    20104: {"Unified_Ideograph", "Ideographic"},
    20105: {"Unified_Ideograph", "Ideographic"},
    20106: {"Unified_Ideograph", "Ideographic"},
    20107: {"Unified_Ideograph", "Ideographic"},
    20108: {"Unified_Ideograph", "Ideographic"},
    20109: {"Unified_Ideograph", "Ideographic"},
    20110: {"Unified_Ideograph", "Ideographic"},
    20111: {"Unified_Ideograph", "Ideographic"},
    20112: {"Unified_Ideograph", "Ideographic"},
    20113: {"Unified_Ideograph", "Ideographic"},
    20114: {"Unified_Ideograph", "Ideographic"},
    20115: {"Unified_Ideograph", "Ideographic"},
    20116: {"Unified_Ideograph", "Ideographic"},
    20117: {"Unified_Ideograph", "Ideographic"},
    20118: {"Unified_Ideograph", "Ideographic"},
    20119: {"Unified_Ideograph", "Ideographic"},
    20120: {"Unified_Ideograph", "Ideographic"},
    20121: {"Unified_Ideograph", "Ideographic"},
    20122: {"Unified_Ideograph", "Ideographic"},
    20123: {"Unified_Ideograph", "Ideographic"},
    20124: {"Unified_Ideograph", "Ideographic"},
    20125: {"Unified_Ideograph", "Ideographic"},
    20126: {"Unified_Ideograph", "Ideographic"},
    20127: {"Unified_Ideograph", "Ideographic"},
    20128: {"Unified_Ideograph", "Ideographic"},
    20129: {"Unified_Ideograph", "Ideographic"},
    20130: {"Unified_Ideograph", "Ideographic"},
    20131: {"Unified_Ideograph", "Ideographic"},
    20132: {"Unified_Ideograph", "Ideographic"},
    20133: {"Unified_Ideograph", "Ideographic"},
    20134: {"Unified_Ideograph", "Ideographic"},
    20135: {"Unified_Ideograph", "Ideographic"},
    20136: {"Unified_Ideograph", "Ideographic"},
    20137: {"Unified_Ideograph", "Ideographic"},
    20138: {"Unified_Ideograph", "Ideographic"},
    20139: {"Unified_Ideograph", "Ideographic"},
    20140: {"Unified_Ideograph", "Ideographic"},
    20141: {"Unified_Ideograph", "Ideographic"},
    20142: {"Unified_Ideograph", "Ideographic"},
    20143: {"Unified_Ideograph", "Ideographic"},
    20144: {"Unified_Ideograph", "Ideographic"},
    20145: {"Unified_Ideograph", "Ideographic"},
    20146: {"Unified_Ideograph", "Ideographic"},
    20147: {"Unified_Ideograph", "Ideographic"},
    20148: {"Unified_Ideograph", "Ideographic"},
    20149: {"Unified_Ideograph", "Ideographic"},
    20150: {"Unified_Ideograph", "Ideographic"},
    20151: {"Unified_Ideograph", "Ideographic"},
    20152: {"Unified_Ideograph", "Ideographic"},
    20153: {"Unified_Ideograph", "Ideographic"},
    20154: {"Unified_Ideograph", "Ideographic"},
    20155: {"Unified_Ideograph", "Ideographic"},
    20156: {"Unified_Ideograph", "Ideographic"},
    20157: {"Unified_Ideograph", "Ideographic"},
    20158: {"Unified_Ideograph", "Ideographic"},
    20159: {"Unified_Ideograph", "Ideographic"},
    20160: {"Unified_Ideograph", "Ideographic"},
    20161: {"Unified_Ideograph", "Ideographic"},
    20162: {"Unified_Ideograph", "Ideographic"},
    20163: {"Unified_Ideograph", "Ideographic"},
    20164: {"Unified_Ideograph", "Ideographic"},
    20165: {"Unified_Ideograph", "Ideographic"},
    20166: {"Unified_Ideograph", "Ideographic"},
    20167: {"Unified_Ideograph", "Ideographic"},
    20168: {"Unified_Ideograph", "Ideographic"},
    20169: {"Unified_Ideograph", "Ideographic"},
    20170: {"Unified_Ideograph", "Ideographic"},
    20171: {"Unified_Ideograph", "Ideographic"},
    20172: {"Unified_Ideograph", "Ideographic"},
    20173: {"Unified_Ideograph", "Ideographic"},
    20174: {"Unified_Ideograph", "Ideographic"},
    20175: {"Unified_Ideograph", "Ideographic"},
    20176: {"Unified_Ideograph", "Ideographic"},
    20177: {"Unified_Ideograph", "Ideographic"},
    20178: {"Unified_Ideograph", "Ideographic"},
    20179: {"Unified_Ideograph", "Ideographic"},
    20180: {"Unified_Ideograph", "Ideographic"},
    20181: {"Unified_Ideograph", "Ideographic"},
    20182: {"Unified_Ideograph", "Ideographic"},
    20183: {"Unified_Ideograph", "Ideographic"},
    20184: {"Unified_Ideograph", "Ideographic"},
    20185: {"Unified_Ideograph", "Ideographic"},
    20186: {"Unified_Ideograph", "Ideographic"},
    20187: {"Unified_Ideograph", "Ideographic"},
    20188: {"Unified_Ideograph", "Ideographic"},
    20189: {"Unified_Ideograph", "Ideographic"},
    20190: {"Unified_Ideograph", "Ideographic"},
    20191: {"Unified_Ideograph", "Ideographic"},
    20192: {"Unified_Ideograph", "Ideographic"},
    20193: {"Unified_Ideograph", "Ideographic"},
    20194: {"Unified_Ideograph", "Ideographic"},
    20195: {"Unified_Ideograph", "Ideographic"},
    20196: {"Unified_Ideograph", "Ideographic"},
    20197: {"Unified_Ideograph", "Ideographic"},
    20198: {"Unified_Ideograph", "Ideographic"},
    20199: {"Unified_Ideograph", "Ideographic"},
    20200: {"Unified_Ideograph", "Ideographic"},
    20201: {"Unified_Ideograph", "Ideographic"},
    20202: {"Unified_Ideograph", "Ideographic"},
    20203: {"Unified_Ideograph", "Ideographic"},
    20204: {"Unified_Ideograph", "Ideographic"},
    20205: {"Unified_Ideograph", "Ideographic"},
    20206: {"Unified_Ideograph", "Ideographic"},
    20207: {"Unified_Ideograph", "Ideographic"},
    20208: {"Unified_Ideograph", "Ideographic"},
    20209: {"Unified_Ideograph", "Ideographic"},
    20210: {"Unified_Ideograph", "Ideographic"},
    20211: {"Unified_Ideograph", "Ideographic"},
    20212: {"Unified_Ideograph", "Ideographic"},
    20213: {"Unified_Ideograph", "Ideographic"},
    20214: {"Unified_Ideograph", "Ideographic"},
    20215: {"Unified_Ideograph", "Ideographic"},
    20216: {"Unified_Ideograph", "Ideographic"},
    20217: {"Unified_Ideograph", "Ideographic"},
    20218: {"Unified_Ideograph", "Ideographic"},
    20219: {"Unified_Ideograph", "Ideographic"},
    20220: {"Unified_Ideograph", "Ideographic"},
    20221: {"Unified_Ideograph", "Ideographic"},
    20222: {"Unified_Ideograph", "Ideographic"},
    20223: {"Unified_Ideograph", "Ideographic"},
    20224: {"Unified_Ideograph", "Ideographic"},
    20225: {"Unified_Ideograph", "Ideographic"},
    20226: {"Unified_Ideograph", "Ideographic"},
    20227: {"Unified_Ideograph", "Ideographic"},
    20228: {"Unified_Ideograph", "Ideographic"},
    20229: {"Unified_Ideograph", "Ideographic"},
    20230: {"Unified_Ideograph", "Ideographic"},
    20231: {"Unified_Ideograph", "Ideographic"},
    20232: {"Unified_Ideograph", "Ideographic"},
    20233: {"Unified_Ideograph", "Ideographic"},
    20234: {"Unified_Ideograph", "Ideographic"},
    20235: {"Unified_Ideograph", "Ideographic"},
    20236: {"Unified_Ideograph", "Ideographic"},
    20237: {"Unified_Ideograph", "Ideographic"},
    20238: {"Unified_Ideograph", "Ideographic"},
    20239: {"Unified_Ideograph", "Ideographic"},
    20240: {"Unified_Ideograph", "Ideographic"},
    20241: {"Unified_Ideograph", "Ideographic"},
    20242: {"Unified_Ideograph", "Ideographic"},
    20243: {"Unified_Ideograph", "Ideographic"},
    20244: {"Unified_Ideograph", "Ideographic"},
    20245: {"Unified_Ideograph", "Ideographic"},
    20246: {"Unified_Ideograph", "Ideographic"},
    20247: {"Unified_Ideograph", "Ideographic"},
    20248: {"Unified_Ideograph", "Ideographic"},
    20249: {"Unified_Ideograph", "Ideographic"},
    20250: {"Unified_Ideograph", "Ideographic"},
    20251: {"Unified_Ideograph", "Ideographic"},
    20252: {"Unified_Ideograph", "Ideographic"},
    20253: {"Unified_Ideograph", "Ideographic"},
    20254: {"Unified_Ideograph", "Ideographic"},
    20255: {"Unified_Ideograph", "Ideographic"},
    20256: {"Unified_Ideograph", "Ideographic"},
    20257: {"Unified_Ideograph", "Ideographic"},
    20258: {"Unified_Ideograph", "Ideographic"},
    20259: {"Unified_Ideograph", "Ideographic"},
    20260: {"Unified_Ideograph", "Ideographic"},
    20261: {"Unified_Ideograph", "Ideographic"},
    20262: {"Unified_Ideograph", "Ideographic"},
    20263: {"Unified_Ideograph", "Ideographic"},
    20264: {"Unified_Ideograph", "Ideographic"},
    20265: {"Unified_Ideograph", "Ideographic"},
    20266: {"Unified_Ideograph", "Ideographic"},
    20267: {"Unified_Ideograph", "Ideographic"},
    20268: {"Unified_Ideograph", "Ideographic"},
    20269: {"Unified_Ideograph", "Ideographic"},
    20270: {"Unified_Ideograph", "Ideographic"},
    20271: {"Unified_Ideograph", "Ideographic"},
    20272: {"Unified_Ideograph", "Ideographic"},
    20273: {"Unified_Ideograph", "Ideographic"},
    20274: {"Unified_Ideograph", "Ideographic"},
    20275: {"Unified_Ideograph", "Ideographic"},
    20276: {"Unified_Ideograph", "Ideographic"},
    20277: {"Unified_Ideograph", "Ideographic"},
    20278: {"Unified_Ideograph", "Ideographic"},
    20279: {"Unified_Ideograph", "Ideographic"},
    20280: {"Unified_Ideograph", "Ideographic"},
    20281: {"Unified_Ideograph", "Ideographic"},
    20282: {"Unified_Ideograph", "Ideographic"},
    20283: {"Unified_Ideograph", "Ideographic"},
    20284: {"Unified_Ideograph", "Ideographic"},
    20285: {"Unified_Ideograph", "Ideographic"},
    20286: {"Unified_Ideograph", "Ideographic"},
    20287: {"Unified_Ideograph", "Ideographic"},
    20288: {"Unified_Ideograph", "Ideographic"},
    20289: {"Unified_Ideograph", "Ideographic"},
    20290: {"Unified_Ideograph", "Ideographic"},
    20291: {"Unified_Ideograph", "Ideographic"},
    20292: {"Unified_Ideograph", "Ideographic"},
    20293: {"Unified_Ideograph", "Ideographic"},
    20294: {"Unified_Ideograph", "Ideographic"},
    20295: {"Unified_Ideograph", "Ideographic"},
    20296: {"Unified_Ideograph", "Ideographic"},
    20297: {"Unified_Ideograph", "Ideographic"},
    20298: {"Unified_Ideograph", "Ideographic"},
    20299: {"Unified_Ideograph", "Ideographic"},
    20300: {"Unified_Ideograph", "Ideographic"},
    20301: {"Unified_Ideograph", "Ideographic"},
    20302: {"Unified_Ideograph", "Ideographic"},
    20303: {"Unified_Ideograph", "Ideographic"},
    20304: {"Unified_Ideograph", "Ideographic"},
    20305: {"Unified_Ideograph", "Ideographic"},
    20306: {"Unified_Ideograph", "Ideographic"},
    20307: {"Unified_Ideograph", "Ideographic"},
    20308: {"Unified_Ideograph", "Ideographic"},
    20309: {"Unified_Ideograph", "Ideographic"},
    20310: {"Unified_Ideograph", "Ideographic"},
    20311: {"Unified_Ideograph", "Ideographic"},
    20312: {"Unified_Ideograph", "Ideographic"},
    20313: {"Unified_Ideograph", "Ideographic"},
    20314: {"Unified_Ideograph", "Ideographic"},
    20315: {"Unified_Ideograph", "Ideographic"},
    20316: {"Unified_Ideograph", "Ideographic"},
    20317: {"Unified_Ideograph", "Ideographic"},
    20318: {"Unified_Ideograph", "Ideographic"},
    20319: {"Unified_Ideograph", "Ideographic"},
    20320: {"Unified_Ideograph", "Ideographic"},
    20321: {"Unified_Ideograph", "Ideographic"},
    20322: {"Unified_Ideograph", "Ideographic"},
    20323: {"Unified_Ideograph", "Ideographic"},
    20324: {"Unified_Ideograph", "Ideographic"},
    20325: {"Unified_Ideograph", "Ideographic"},
    20326: {"Unified_Ideograph", "Ideographic"},
    20327: {"Unified_Ideograph", "Ideographic"},
    20328: {"Unified_Ideograph", "Ideographic"},
    20329: {"Unified_Ideograph", "Ideographic"},
    20330: {"Unified_Ideograph", "Ideographic"},
    20331: {"Unified_Ideograph", "Ideographic"},
    20332: {"Unified_Ideograph", "Ideographic"},
    20333: {"Unified_Ideograph", "Ideographic"},
    20334: {"Unified_Ideograph", "Ideographic"},
    20335: {"Unified_Ideograph", "Ideographic"},
    20336: {"Unified_Ideograph", "Ideographic"},
    20337: {"Unified_Ideograph", "Ideographic"},
    20338: {"Unified_Ideograph", "Ideographic"},
    20339: {"Unified_Ideograph", "Ideographic"},
    20340: {"Unified_Ideograph", "Ideographic"},
    20341: {"Unified_Ideograph", "Ideographic"},
    20342: {"Unified_Ideograph", "Ideographic"},
    20343: {"Unified_Ideograph", "Ideographic"},
    20344: {"Unified_Ideograph", "Ideographic"},
    20345: {"Unified_Ideograph", "Ideographic"},
    20346: {"Unified_Ideograph", "Ideographic"},
    20347: {"Unified_Ideograph", "Ideographic"},
    20348: {"Unified_Ideograph", "Ideographic"},
    20349: {"Unified_Ideograph", "Ideographic"},
    20350: {"Unified_Ideograph", "Ideographic"},
    20351: {"Unified_Ideograph", "Ideographic"},
    20352: {"Unified_Ideograph", "Ideographic"},
    20353: {"Unified_Ideograph", "Ideographic"},
    20354: {"Unified_Ideograph", "Ideographic"},
    20355: {"Unified_Ideograph", "Ideographic"},
    20356: {"Unified_Ideograph", "Ideographic"},
    20357: {"Unified_Ideograph", "Ideographic"},
    20358: {"Unified_Ideograph", "Ideographic"},
    20359: {"Unified_Ideograph", "Ideographic"},
    20360: {"Unified_Ideograph", "Ideographic"},
    20361: {"Unified_Ideograph", "Ideographic"},
    20362: {"Unified_Ideograph", "Ideographic"},
    20363: {"Unified_Ideograph", "Ideographic"},
    20364: {"Unified_Ideograph", "Ideographic"},
    20365: {"Unified_Ideograph", "Ideographic"},
    20366: {"Unified_Ideograph", "Ideographic"},
    20367: {"Unified_Ideograph", "Ideographic"},
    20368: {"Unified_Ideograph", "Ideographic"},
    20369: {"Unified_Ideograph", "Ideographic"},
    20370: {"Unified_Ideograph", "Ideographic"},
    20371: {"Unified_Ideograph", "Ideographic"},
    20372: {"Unified_Ideograph", "Ideographic"},
    20373: {"Unified_Ideograph", "Ideographic"},
    20374: {"Unified_Ideograph", "Ideographic"},
    20375: {"Unified_Ideograph", "Ideographic"},
    20376: {"Unified_Ideograph", "Ideographic"},
    20377: {"Unified_Ideograph", "Ideographic"},
    20378: {"Unified_Ideograph", "Ideographic"},
    20379: {"Unified_Ideograph", "Ideographic"},
    20380: {"Unified_Ideograph", "Ideographic"},
    20381: {"Unified_Ideograph", "Ideographic"},
    20382: {"Unified_Ideograph", "Ideographic"},
    20383: {"Unified_Ideograph", "Ideographic"},
    20384: {"Unified_Ideograph", "Ideographic"},
    20385: {"Unified_Ideograph", "Ideographic"},
    20386: {"Unified_Ideograph", "Ideographic"},
    20387: {"Unified_Ideograph", "Ideographic"},
    20388: {"Unified_Ideograph", "Ideographic"},
    20389: {"Unified_Ideograph", "Ideographic"},
    20390: {"Unified_Ideograph", "Ideographic"},
    20391: {"Unified_Ideograph", "Ideographic"},
    20392: {"Unified_Ideograph", "Ideographic"},
    20393: {"Unified_Ideograph", "Ideographic"},
    20394: {"Unified_Ideograph", "Ideographic"},
    20395: {"Unified_Ideograph", "Ideographic"},
    20396: {"Unified_Ideograph", "Ideographic"},
    20397: {"Unified_Ideograph", "Ideographic"},
    20398: {"Unified_Ideograph", "Ideographic"},
    20399: {"Unified_Ideograph", "Ideographic"},
    20400: {"Unified_Ideograph", "Ideographic"},
    20401: {"Unified_Ideograph", "Ideographic"},
    20402: {"Unified_Ideograph", "Ideographic"},
    20403: {"Unified_Ideograph", "Ideographic"},
    20404: {"Unified_Ideograph", "Ideographic"},
    20405: {"Unified_Ideograph", "Ideographic"},
    20406: {"Unified_Ideograph", "Ideographic"},
    20407: {"Unified_Ideograph", "Ideographic"},
    20408: {"Unified_Ideograph", "Ideographic"},
    20409: {"Unified_Ideograph", "Ideographic"},
    20410: {"Unified_Ideograph", "Ideographic"},
    20411: {"Unified_Ideograph", "Ideographic"},
    20412: {"Unified_Ideograph", "Ideographic"},
    20413: {"Unified_Ideograph", "Ideographic"},
    20414: {"Unified_Ideograph", "Ideographic"},
    20415: {"Unified_Ideograph", "Ideographic"},
    20416: {"Unified_Ideograph", "Ideographic"},
    20417: {"Unified_Ideograph", "Ideographic"},
    20418: {"Unified_Ideograph", "Ideographic"},
    20419: {"Unified_Ideograph", "Ideographic"},
    20420: {"Unified_Ideograph", "Ideographic"},
    20421: {"Unified_Ideograph", "Ideographic"},
    20422: {"Unified_Ideograph", "Ideographic"},
    20423: {"Unified_Ideograph", "Ideographic"},
    20424: {"Unified_Ideograph", "Ideographic"},
    20425: {"Unified_Ideograph", "Ideographic"},
    20426: {"Unified_Ideograph", "Ideographic"},
    20427: {"Unified_Ideograph", "Ideographic"},
    20428: {"Unified_Ideograph", "Ideographic"},
    20429: {"Unified_Ideograph", "Ideographic"},
    20430: {"Unified_Ideograph", "Ideographic"},
    20431: {"Unified_Ideograph", "Ideographic"},
    20432: {"Unified_Ideograph", "Ideographic"},
    20433: {"Unified_Ideograph", "Ideographic"},
    20434: {"Unified_Ideograph", "Ideographic"},
    20435: {"Unified_Ideograph", "Ideographic"},
    20436: {"Unified_Ideograph", "Ideographic"},
    20437: {"Unified_Ideograph", "Ideographic"},
    20438: {"Unified_Ideograph", "Ideographic"},
    20439: {"Unified_Ideograph", "Ideographic"},
    20440: {"Unified_Ideograph", "Ideographic"},
    20441: {"Unified_Ideograph", "Ideographic"},
    20442: {"Unified_Ideograph", "Ideographic"},
    20443: {"Unified_Ideograph", "Ideographic"},
    20444: {"Unified_Ideograph", "Ideographic"},
    20445: {"Unified_Ideograph", "Ideographic"},
    20446: {"Unified_Ideograph", "Ideographic"},
    20447: {"Unified_Ideograph", "Ideographic"},
    20448: {"Unified_Ideograph", "Ideographic"},
    20449: {"Unified_Ideograph", "Ideographic"},
    20450: {"Unified_Ideograph", "Ideographic"},
    20451: {"Unified_Ideograph", "Ideographic"},
    20452: {"Unified_Ideograph", "Ideographic"},
    20453: {"Unified_Ideograph", "Ideographic"},
    20454: {"Unified_Ideograph", "Ideographic"},
    20455: {"Unified_Ideograph", "Ideographic"},
    20456: {"Unified_Ideograph", "Ideographic"},
    20457: {"Unified_Ideograph", "Ideographic"},
    20458: {"Unified_Ideograph", "Ideographic"},
    20459: {"Unified_Ideograph", "Ideographic"},
    20460: {"Unified_Ideograph", "Ideographic"},
    20461: {"Unified_Ideograph", "Ideographic"},
    20462: {"Unified_Ideograph", "Ideographic"},
    20463: {"Unified_Ideograph", "Ideographic"},
    20464: {"Unified_Ideograph", "Ideographic"},
    20465: {"Unified_Ideograph", "Ideographic"},
    20466: {"Unified_Ideograph", "Ideographic"},
    20467: {"Unified_Ideograph", "Ideographic"},
    20468: {"Unified_Ideograph", "Ideographic"},
    20469: {"Unified_Ideograph", "Ideographic"},
    20470: {"Unified_Ideograph", "Ideographic"},
    20471: {"Unified_Ideograph", "Ideographic"},
    20472: {"Unified_Ideograph", "Ideographic"},
    20473: {"Unified_Ideograph", "Ideographic"},
    20474: {"Unified_Ideograph", "Ideographic"},
    20475: {"Unified_Ideograph", "Ideographic"},
    20476: {"Unified_Ideograph", "Ideographic"},
    20477: {"Unified_Ideograph", "Ideographic"},
    20478: {"Unified_Ideograph", "Ideographic"},
    20479: {"Unified_Ideograph", "Ideographic"},
    20480: {"Unified_Ideograph", "Ideographic"},
    20481: {"Unified_Ideograph", "Ideographic"},
    20482: {"Unified_Ideograph", "Ideographic"},
    20483: {"Unified_Ideograph", "Ideographic"},
    20484: {"Unified_Ideograph", "Ideographic"},
    20485: {"Unified_Ideograph", "Ideographic"},
    20486: {"Unified_Ideograph", "Ideographic"},
    20487: {"Unified_Ideograph", "Ideographic"},
    20488: {"Unified_Ideograph", "Ideographic"},
    20489: {"Unified_Ideograph", "Ideographic"},
    20490: {"Unified_Ideograph", "Ideographic"},
    20491: {"Unified_Ideograph", "Ideographic"},
    20492: {"Unified_Ideograph", "Ideographic"},
    20493: {"Unified_Ideograph", "Ideographic"},
    20494: {"Unified_Ideograph", "Ideographic"},
    20495: {"Unified_Ideograph", "Ideographic"},
    20496: {"Unified_Ideograph", "Ideographic"},
    20497: {"Unified_Ideograph", "Ideographic"},
    20498: {"Unified_Ideograph", "Ideographic"},
    20499: {"Unified_Ideograph", "Ideographic"},
    20500: {"Unified_Ideograph", "Ideographic"},
    20501: {"Unified_Ideograph", "Ideographic"},
    20502: {"Unified_Ideograph", "Ideographic"},
    20503: {"Unified_Ideograph", "Ideographic"},
    20504: {"Unified_Ideograph", "Ideographic"},
    20505: {"Unified_Ideograph", "Ideographic"},
    20506: {"Unified_Ideograph", "Ideographic"},
    20507: {"Unified_Ideograph", "Ideographic"},
    20508: {"Unified_Ideograph", "Ideographic"},
    20509: {"Unified_Ideograph", "Ideographic"},
    20510: {"Unified_Ideograph", "Ideographic"},
    20511: {"Unified_Ideograph", "Ideographic"},
    20512: {"Unified_Ideograph", "Ideographic"},
    20513: {"Unified_Ideograph", "Ideographic"},
    20514: {"Unified_Ideograph", "Ideographic"},
    20515: {"Unified_Ideograph", "Ideographic"},
    20516: {"Unified_Ideograph", "Ideographic"},
    20517: {"Unified_Ideograph", "Ideographic"},
    20518: {"Unified_Ideograph", "Ideographic"},
    20519: {"Unified_Ideograph", "Ideographic"},
    20520: {"Unified_Ideograph", "Ideographic"},
    20521: {"Unified_Ideograph", "Ideographic"},
    20522: {"Unified_Ideograph", "Ideographic"},
    20523: {"Unified_Ideograph", "Ideographic"},
    20524: {"Unified_Ideograph", "Ideographic"},
    20525: {"Unified_Ideograph", "Ideographic"},
    20526: {"Unified_Ideograph", "Ideographic"},
    20527: {"Unified_Ideograph", "Ideographic"},
    20528: {"Unified_Ideograph", "Ideographic"},
    20529: {"Unified_Ideograph", "Ideographic"},
    20530: {"Unified_Ideograph", "Ideographic"},
    20531: {"Unified_Ideograph", "Ideographic"},
    20532: {"Unified_Ideograph", "Ideographic"},
    20533: {"Unified_Ideograph", "Ideographic"},
    20534: {"Unified_Ideograph", "Ideographic"},
    20535: {"Unified_Ideograph", "Ideographic"},
    20536: {"Unified_Ideograph", "Ideographic"},
    20537: {"Unified_Ideograph", "Ideographic"},
    20538: {"Unified_Ideograph", "Ideographic"},
    20539: {"Unified_Ideograph", "Ideographic"},
    20540: {"Unified_Ideograph", "Ideographic"},
    20541: {"Unified_Ideograph", "Ideographic"},
    20542: {"Unified_Ideograph", "Ideographic"},
    20543: {"Unified_Ideograph", "Ideographic"},
    20544: {"Unified_Ideograph", "Ideographic"},
    20545: {"Unified_Ideograph", "Ideographic"},
    20546: {"Unified_Ideograph", "Ideographic"},
    20547: {"Unified_Ideograph", "Ideographic"},
    20548: {"Unified_Ideograph", "Ideographic"},
    20549: {"Unified_Ideograph", "Ideographic"},
    20550: {"Unified_Ideograph", "Ideographic"},
    20551: {"Unified_Ideograph", "Ideographic"},
    20552: {"Unified_Ideograph", "Ideographic"},
    20553: {"Unified_Ideograph", "Ideographic"},
    20554: {"Unified_Ideograph", "Ideographic"},
    20555: {"Unified_Ideograph", "Ideographic"},
    20556: {"Unified_Ideograph", "Ideographic"},
    20557: {"Unified_Ideograph", "Ideographic"},
    20558: {"Unified_Ideograph", "Ideographic"},
    20559: {"Unified_Ideograph", "Ideographic"},
    20560: {"Unified_Ideograph", "Ideographic"},
    20561: {"Unified_Ideograph", "Ideographic"},
    20562: {"Unified_Ideograph", "Ideographic"},
    20563: {"Unified_Ideograph", "Ideographic"},
    20564: {"Unified_Ideograph", "Ideographic"},
    20565: {"Unified_Ideograph", "Ideographic"},
    20566: {"Unified_Ideograph", "Ideographic"},
    20567: {"Unified_Ideograph", "Ideographic"},
    20568: {"Unified_Ideograph", "Ideographic"},
    20569: {"Unified_Ideograph", "Ideographic"},
    20570: {"Unified_Ideograph", "Ideographic"},
    20571: {"Unified_Ideograph", "Ideographic"},
    20572: {"Unified_Ideograph", "Ideographic"},
    20573: {"Unified_Ideograph", "Ideographic"},
    20574: {"Unified_Ideograph", "Ideographic"},
    20575: {"Unified_Ideograph", "Ideographic"},
    20576: {"Unified_Ideograph", "Ideographic"},
    20577: {"Unified_Ideograph", "Ideographic"},
    20578: {"Unified_Ideograph", "Ideographic"},
    20579: {"Unified_Ideograph", "Ideographic"},
    20580: {"Unified_Ideograph", "Ideographic"},
    20581: {"Unified_Ideograph", "Ideographic"},
    20582: {"Unified_Ideograph", "Ideographic"},
    20583: {"Unified_Ideograph", "Ideographic"},
    20584: {"Unified_Ideograph", "Ideographic"},
    20585: {"Unified_Ideograph", "Ideographic"},
    20586: {"Unified_Ideograph", "Ideographic"},
    20587: {"Unified_Ideograph", "Ideographic"},
    20588: {"Unified_Ideograph", "Ideographic"},
    20589: {"Unified_Ideograph", "Ideographic"},
    20590: {"Unified_Ideograph", "Ideographic"},
    20591: {"Unified_Ideograph", "Ideographic"},
    20592: {"Unified_Ideograph", "Ideographic"},
    20593: {"Unified_Ideograph", "Ideographic"},
    20594: {"Unified_Ideograph", "Ideographic"},
    20595: {"Unified_Ideograph", "Ideographic"},
    20596: {"Unified_Ideograph", "Ideographic"},
    20597: {"Unified_Ideograph", "Ideographic"},
    20598: {"Unified_Ideograph", "Ideographic"},
    20599: {"Unified_Ideograph", "Ideographic"},
    20600: {"Unified_Ideograph", "Ideographic"},
    20601: {"Unified_Ideograph", "Ideographic"},
    20602: {"Unified_Ideograph", "Ideographic"},
    20603: {"Unified_Ideograph", "Ideographic"},
    20604: {"Unified_Ideograph", "Ideographic"},
    20605: {"Unified_Ideograph", "Ideographic"},
    20606: {"Unified_Ideograph", "Ideographic"},
    20607: {"Unified_Ideograph", "Ideographic"},
    20608: {"Unified_Ideograph", "Ideographic"},
    20609: {"Unified_Ideograph", "Ideographic"},
    20610: {"Unified_Ideograph", "Ideographic"},
    20611: {"Unified_Ideograph", "Ideographic"},
    20612: {"Unified_Ideograph", "Ideographic"},
    20613: {"Unified_Ideograph", "Ideographic"},
    20614: {"Unified_Ideograph", "Ideographic"},
    20615: {"Unified_Ideograph", "Ideographic"},
    20616: {"Unified_Ideograph", "Ideographic"},
    20617: {"Unified_Ideograph", "Ideographic"},
    20618: {"Unified_Ideograph", "Ideographic"},
    20619: {"Unified_Ideograph", "Ideographic"},
    20620: {"Unified_Ideograph", "Ideographic"},
    20621: {"Unified_Ideograph", "Ideographic"},
    20622: {"Unified_Ideograph", "Ideographic"},
    20623: {"Unified_Ideograph", "Ideographic"},
    20624: {"Unified_Ideograph", "Ideographic"},
    20625: {"Unified_Ideograph", "Ideographic"},
    20626: {"Unified_Ideograph", "Ideographic"},
    20627: {"Unified_Ideograph", "Ideographic"},
    20628: {"Unified_Ideograph", "Ideographic"},
    20629: {"Unified_Ideograph", "Ideographic"},
    20630: {"Unified_Ideograph", "Ideographic"},
    20631: {"Unified_Ideograph", "Ideographic"},
    20632: {"Unified_Ideograph", "Ideographic"},
    20633: {"Unified_Ideograph", "Ideographic"},
    20634: {"Unified_Ideograph", "Ideographic"},
    20635: {"Unified_Ideograph", "Ideographic"},
    20636: {"Unified_Ideograph", "Ideographic"},
    20637: {"Unified_Ideograph", "Ideographic"},
    20638: {"Unified_Ideograph", "Ideographic"},
    20639: {"Unified_Ideograph", "Ideographic"},
    20640: {"Unified_Ideograph", "Ideographic"},
    20641: {"Unified_Ideograph", "Ideographic"},
    20642: {"Unified_Ideograph", "Ideographic"},
    20643: {"Unified_Ideograph", "Ideographic"},
    20644: {"Unified_Ideograph", "Ideographic"},
    20645: {"Unified_Ideograph", "Ideographic"},
    20646: {"Unified_Ideograph", "Ideographic"},
    20647: {"Unified_Ideograph", "Ideographic"},
    20648: {"Unified_Ideograph", "Ideographic"},
    20649: {"Unified_Ideograph", "Ideographic"},
    20650: {"Unified_Ideograph", "Ideographic"},
    20651: {"Unified_Ideograph", "Ideographic"},
    20652: {"Unified_Ideograph", "Ideographic"},
    20653: {"Unified_Ideograph", "Ideographic"},
    20654: {"Unified_Ideograph", "Ideographic"},
    20655: {"Unified_Ideograph", "Ideographic"},
    20656: {"Unified_Ideograph", "Ideographic"},
    20657: {"Unified_Ideograph", "Ideographic"},
    20658: {"Unified_Ideograph", "Ideographic"},
    20659: {"Unified_Ideograph", "Ideographic"},
    20660: {"Unified_Ideograph", "Ideographic"},
    20661: {"Unified_Ideograph", "Ideographic"},
    20662: {"Unified_Ideograph", "Ideographic"},
    20663: {"Unified_Ideograph", "Ideographic"},
    20664: {"Unified_Ideograph", "Ideographic"},
    20665: {"Unified_Ideograph", "Ideographic"},
    20666: {"Unified_Ideograph", "Ideographic"},
    20667: {"Unified_Ideograph", "Ideographic"},
    20668: {"Unified_Ideograph", "Ideographic"},
    20669: {"Unified_Ideograph", "Ideographic"},
    20670: {"Unified_Ideograph", "Ideographic"},
    20671: {"Unified_Ideograph", "Ideographic"},
    20672: {"Unified_Ideograph", "Ideographic"},
    20673: {"Unified_Ideograph", "Ideographic"},
    20674: {"Unified_Ideograph", "Ideographic"},
    20675: {"Unified_Ideograph", "Ideographic"},
    20676: {"Unified_Ideograph", "Ideographic"},
    20677: {"Unified_Ideograph", "Ideographic"},
    20678: {"Unified_Ideograph", "Ideographic"},
    20679: {"Unified_Ideograph", "Ideographic"},
    20680: {"Unified_Ideograph", "Ideographic"},
    20681: {"Unified_Ideograph", "Ideographic"},
    20682: {"Unified_Ideograph", "Ideographic"},
    20683: {"Unified_Ideograph", "Ideographic"},
    20684: {"Unified_Ideograph", "Ideographic"},
    20685: {"Unified_Ideograph", "Ideographic"},
    20686: {"Unified_Ideograph", "Ideographic"},
    20687: {"Unified_Ideograph", "Ideographic"},
    20688: {"Unified_Ideograph", "Ideographic"},
    20689: {"Unified_Ideograph", "Ideographic"},
    20690: {"Unified_Ideograph", "Ideographic"},
    20691: {"Unified_Ideograph", "Ideographic"},
    20692: {"Unified_Ideograph", "Ideographic"},
    20693: {"Unified_Ideograph", "Ideographic"},
    20694: {"Unified_Ideograph", "Ideographic"},
    20695: {"Unified_Ideograph", "Ideographic"},
    20696: {"Unified_Ideograph", "Ideographic"},
    20697: {"Unified_Ideograph", "Ideographic"},
    20698: {"Unified_Ideograph", "Ideographic"},
    20699: {"Unified_Ideograph", "Ideographic"},
    20700: {"Unified_Ideograph", "Ideographic"},
    20701: {"Unified_Ideograph", "Ideographic"},
    20702: {"Unified_Ideograph", "Ideographic"},
    20703: {"Unified_Ideograph", "Ideographic"},
    20704: {"Unified_Ideograph", "Ideographic"},
    20705: {"Unified_Ideograph", "Ideographic"},
    20706: {"Unified_Ideograph", "Ideographic"},
    20707: {"Unified_Ideograph", "Ideographic"},
    20708: {"Unified_Ideograph", "Ideographic"},
    20709: {"Unified_Ideograph", "Ideographic"},
    20710: {"Unified_Ideograph", "Ideographic"},
    20711: {"Unified_Ideograph", "Ideographic"},
    20712: {"Unified_Ideograph", "Ideographic"},
    20713: {"Unified_Ideograph", "Ideographic"},
    20714: {"Unified_Ideograph", "Ideographic"},
    20715: {"Unified_Ideograph", "Ideographic"},
    20716: {"Unified_Ideograph", "Ideographic"},
    20717: {"Unified_Ideograph", "Ideographic"},
    20718: {"Unified_Ideograph", "Ideographic"},
    20719: {"Unified_Ideograph", "Ideographic"},
    20720: {"Unified_Ideograph", "Ideographic"},
    20721: {"Unified_Ideograph", "Ideographic"},
    20722: {"Unified_Ideograph", "Ideographic"},
    20723: {"Unified_Ideograph", "Ideographic"},
    20724: {"Unified_Ideograph", "Ideographic"},
    20725: {"Unified_Ideograph", "Ideographic"},
    20726: {"Unified_Ideograph", "Ideographic"},
    20727: {"Unified_Ideograph", "Ideographic"},
    20728: {"Unified_Ideograph", "Ideographic"},
    20729: {"Unified_Ideograph", "Ideographic"},
    20730: {"Unified_Ideograph", "Ideographic"},
    20731: {"Unified_Ideograph", "Ideographic"},
    20732: {"Unified_Ideograph", "Ideographic"},
    20733: {"Unified_Ideograph", "Ideographic"},
    20734: {"Unified_Ideograph", "Ideographic"},
    20735: {"Unified_Ideograph", "Ideographic"},
    20736: {"Unified_Ideograph", "Ideographic"},
    20737: {"Unified_Ideograph", "Ideographic"},
    20738: {"Unified_Ideograph", "Ideographic"},
    20739: {"Unified_Ideograph", "Ideographic"},
    20740: {"Unified_Ideograph", "Ideographic"},
    20741: {"Unified_Ideograph", "Ideographic"},
    20742: {"Unified_Ideograph", "Ideographic"},
    20743: {"Unified_Ideograph", "Ideographic"},
    20744: {"Unified_Ideograph", "Ideographic"},
    20745: {"Unified_Ideograph", "Ideographic"},
    20746: {"Unified_Ideograph", "Ideographic"},
    20747: {"Unified_Ideograph", "Ideographic"},
    20748: {"Unified_Ideograph", "Ideographic"},
    20749: {"Unified_Ideograph", "Ideographic"},
    20750: {"Unified_Ideograph", "Ideographic"},
    20751: {"Unified_Ideograph", "Ideographic"},
    20752: {"Unified_Ideograph", "Ideographic"},
    20753: {"Unified_Ideograph", "Ideographic"},
    20754: {"Unified_Ideograph", "Ideographic"},
    20755: {"Unified_Ideograph", "Ideographic"},
    20756: {"Unified_Ideograph", "Ideographic"},
    20757: {"Unified_Ideograph", "Ideographic"},
    20758: {"Unified_Ideograph", "Ideographic"},
    20759: {"Unified_Ideograph", "Ideographic"},
    20760: {"Unified_Ideograph", "Ideographic"},
    20761: {"Unified_Ideograph", "Ideographic"},
    20762: {"Unified_Ideograph", "Ideographic"},
    20763: {"Unified_Ideograph", "Ideographic"},
    20764: {"Unified_Ideograph", "Ideographic"},
    20765: {"Unified_Ideograph", "Ideographic"},
    20766: {"Unified_Ideograph", "Ideographic"},
    20767: {"Unified_Ideograph", "Ideographic"},
    20768: {"Unified_Ideograph", "Ideographic"},
    20769: {"Unified_Ideograph", "Ideographic"},
    20770: {"Unified_Ideograph", "Ideographic"},
    20771: {"Unified_Ideograph", "Ideographic"},
    20772: {"Unified_Ideograph", "Ideographic"},
    20773: {"Unified_Ideograph", "Ideographic"},
    20774: {"Unified_Ideograph", "Ideographic"},
    20775: {"Unified_Ideograph", "Ideographic"},
    20776: {"Unified_Ideograph", "Ideographic"},
    20777: {"Unified_Ideograph", "Ideographic"},
    20778: {"Unified_Ideograph", "Ideographic"},
    20779: {"Unified_Ideograph", "Ideographic"},
    20780: {"Unified_Ideograph", "Ideographic"},
    20781: {"Unified_Ideograph", "Ideographic"},
    20782: {"Unified_Ideograph", "Ideographic"},
    20783: {"Unified_Ideograph", "Ideographic"},
    20784: {"Unified_Ideograph", "Ideographic"},
    20785: {"Unified_Ideograph", "Ideographic"},
    20786: {"Unified_Ideograph", "Ideographic"},
    20787: {"Unified_Ideograph", "Ideographic"},
    20788: {"Unified_Ideograph", "Ideographic"},
    20789: {"Unified_Ideograph", "Ideographic"},
    20790: {"Unified_Ideograph", "Ideographic"},
    20791: {"Unified_Ideograph", "Ideographic"},
    20792: {"Unified_Ideograph", "Ideographic"},
    20793: {"Unified_Ideograph", "Ideographic"},
    20794: {"Unified_Ideograph", "Ideographic"},
    20795: {"Unified_Ideograph", "Ideographic"},
    20796: {"Unified_Ideograph", "Ideographic"},
    20797: {"Unified_Ideograph", "Ideographic"},
    20798: {"Unified_Ideograph", "Ideographic"},
    20799: {"Unified_Ideograph", "Ideographic"},
    20800: {"Unified_Ideograph", "Ideographic"},
    20801: {"Unified_Ideograph", "Ideographic"},
    20802: {"Unified_Ideograph", "Ideographic"},
    20803: {"Unified_Ideograph", "Ideographic"},
    20804: {"Unified_Ideograph", "Ideographic"},
    20805: {"Unified_Ideograph", "Ideographic"},
    20806: {"Unified_Ideograph", "Ideographic"},
    20807: {"Unified_Ideograph", "Ideographic"},
    20808: {"Unified_Ideograph", "Ideographic"},
    20809: {"Unified_Ideograph", "Ideographic"},
    20810: {"Unified_Ideograph", "Ideographic"},
    20811: {"Unified_Ideograph", "Ideographic"},
    20812: {"Unified_Ideograph", "Ideographic"},
    20813: {"Unified_Ideograph", "Ideographic"},
    20814: {"Unified_Ideograph", "Ideographic"},
    20815: {"Unified_Ideograph", "Ideographic"},
    20816: {"Unified_Ideograph", "Ideographic"},
    20817: {"Unified_Ideograph", "Ideographic"},
    20818: {"Unified_Ideograph", "Ideographic"},
    20819: {"Unified_Ideograph", "Ideographic"},
    20820: {"Unified_Ideograph", "Ideographic"},
    20821: {"Unified_Ideograph", "Ideographic"},
    20822: {"Unified_Ideograph", "Ideographic"},
    20823: {"Unified_Ideograph", "Ideographic"},
    20824: {"Unified_Ideograph", "Ideographic"},
    20825: {"Unified_Ideograph", "Ideographic"},
    20826: {"Unified_Ideograph", "Ideographic"},
    20827: {"Unified_Ideograph", "Ideographic"},
    20828: {"Unified_Ideograph", "Ideographic"},
    20829: {"Unified_Ideograph", "Ideographic"},
    20830: {"Unified_Ideograph", "Ideographic"},
    20831: {"Unified_Ideograph", "Ideographic"},
    20832: {"Unified_Ideograph", "Ideographic"},
    20833: {"Unified_Ideograph", "Ideographic"},
    20834: {"Unified_Ideograph", "Ideographic"},
    20835: {"Unified_Ideograph", "Ideographic"},
    20836: {"Unified_Ideograph", "Ideographic"},
    20837: {"Unified_Ideograph", "Ideographic"},
    20838: {"Unified_Ideograph", "Ideographic"},
    20839: {"Unified_Ideograph", "Ideographic"},
    20840: {"Unified_Ideograph", "Ideographic"},
    20841: {"Unified_Ideograph", "Ideographic"},
    20842: {"Unified_Ideograph", "Ideographic"},
    20843: {"Unified_Ideograph", "Ideographic"},
    20844: {"Unified_Ideograph", "Ideographic"},
    20845: {"Unified_Ideograph", "Ideographic"},
    20846: {"Unified_Ideograph", "Ideographic"},
    20847: {"Unified_Ideograph", "Ideographic"},
    20848: {"Unified_Ideograph", "Ideographic"},
    20849: {"Unified_Ideograph", "Ideographic"},
    20850: {"Unified_Ideograph", "Ideographic"},
    20851: {"Unified_Ideograph", "Ideographic"},
    20852: {"Unified_Ideograph", "Ideographic"},
    20853: {"Unified_Ideograph", "Ideographic"},
    20854: {"Unified_Ideograph", "Ideographic"},
    20855: {"Unified_Ideograph", "Ideographic"},
    20856: {"Unified_Ideograph", "Ideographic"},
    20857: {"Unified_Ideograph", "Ideographic"},
    20858: {"Unified_Ideograph", "Ideographic"},
    20859: {"Unified_Ideograph", "Ideographic"},
    20860: {"Unified_Ideograph", "Ideographic"},
    20861: {"Unified_Ideograph", "Ideographic"},
    20862: {"Unified_Ideograph", "Ideographic"},
    20863: {"Unified_Ideograph", "Ideographic"},
    20864: {"Unified_Ideograph", "Ideographic"},
    20865: {"Unified_Ideograph", "Ideographic"},
    20866: {"Unified_Ideograph", "Ideographic"},
    20867: {"Unified_Ideograph", "Ideographic"},
    20868: {"Unified_Ideograph", "Ideographic"},
    20869: {"Unified_Ideograph", "Ideographic"},
    20870: {"Unified_Ideograph", "Ideographic"},
    20871: {"Unified_Ideograph", "Ideographic"},
    20872: {"Unified_Ideograph", "Ideographic"},
    20873: {"Unified_Ideograph", "Ideographic"},
    20874: {"Unified_Ideograph", "Ideographic"},
    20875: {"Unified_Ideograph", "Ideographic"},
    20876: {"Unified_Ideograph", "Ideographic"},
    20877: {"Unified_Ideograph", "Ideographic"},
    20878: {"Unified_Ideograph", "Ideographic"},
    20879: {"Unified_Ideograph", "Ideographic"},
    20880: {"Unified_Ideograph", "Ideographic"},
    20881: {"Unified_Ideograph", "Ideographic"},
    20882: {"Unified_Ideograph", "Ideographic"},
    20883: {"Unified_Ideograph", "Ideographic"},
    20884: {"Unified_Ideograph", "Ideographic"},
    20885: {"Unified_Ideograph", "Ideographic"},
    20886: {"Unified_Ideograph", "Ideographic"},
    20887: {"Unified_Ideograph", "Ideographic"},
    20888: {"Unified_Ideograph", "Ideographic"},
    20889: {"Unified_Ideograph", "Ideographic"},
    20890: {"Unified_Ideograph", "Ideographic"},
    20891: {"Unified_Ideograph", "Ideographic"},
    20892: {"Unified_Ideograph", "Ideographic"},
    20893: {"Unified_Ideograph", "Ideographic"},
    20894: {"Unified_Ideograph", "Ideographic"},
    20895: {"Unified_Ideograph", "Ideographic"},
    20896: {"Unified_Ideograph", "Ideographic"},
    20897: {"Unified_Ideograph", "Ideographic"},
    20898: {"Unified_Ideograph", "Ideographic"},
    20899: {"Unified_Ideograph", "Ideographic"},
    20900: {"Unified_Ideograph", "Ideographic"},
    20901: {"Unified_Ideograph", "Ideographic"},
    20902: {"Unified_Ideograph", "Ideographic"},
    20903: {"Unified_Ideograph", "Ideographic"},
    20904: {"Unified_Ideograph", "Ideographic"},
    20905: {"Unified_Ideograph", "Ideographic"},
    20906: {"Unified_Ideograph", "Ideographic"},
    20907: {"Unified_Ideograph", "Ideographic"},
    20908: {"Unified_Ideograph", "Ideographic"},
    20909: {"Unified_Ideograph", "Ideographic"},
    20910: {"Unified_Ideograph", "Ideographic"},
    20911: {"Unified_Ideograph", "Ideographic"},
    20912: {"Unified_Ideograph", "Ideographic"},
    20913: {"Unified_Ideograph", "Ideographic"},
    20914: {"Unified_Ideograph", "Ideographic"},
    20915: {"Unified_Ideograph", "Ideographic"},
    20916: {"Unified_Ideograph", "Ideographic"},
    20917: {"Unified_Ideograph", "Ideographic"},
    20918: {"Unified_Ideograph", "Ideographic"},
    20919: {"Unified_Ideograph", "Ideographic"},
    20920: {"Unified_Ideograph", "Ideographic"},
    20921: {"Unified_Ideograph", "Ideographic"},
    20922: {"Unified_Ideograph", "Ideographic"},
    20923: {"Unified_Ideograph", "Ideographic"},
    20924: {"Unified_Ideograph", "Ideographic"},
    20925: {"Unified_Ideograph", "Ideographic"},
    20926: {"Unified_Ideograph", "Ideographic"},
    20927: {"Unified_Ideograph", "Ideographic"},
    20928: {"Unified_Ideograph", "Ideographic"},
    20929: {"Unified_Ideograph", "Ideographic"},
    20930: {"Unified_Ideograph", "Ideographic"},
    20931: {"Unified_Ideograph", "Ideographic"},
    20932: {"Unified_Ideograph", "Ideographic"},
    20933: {"Unified_Ideograph", "Ideographic"},
    20934: {"Unified_Ideograph", "Ideographic"},
    20935: {"Unified_Ideograph", "Ideographic"},
    20936: {"Unified_Ideograph", "Ideographic"},
    20937: {"Unified_Ideograph", "Ideographic"},
    20938: {"Unified_Ideograph", "Ideographic"},
    20939: {"Unified_Ideograph", "Ideographic"},
    20940: {"Unified_Ideograph", "Ideographic"},
    20941: {"Unified_Ideograph", "Ideographic"},
    20942: {"Unified_Ideograph", "Ideographic"},
    20943: {"Unified_Ideograph", "Ideographic"},
    20944: {"Unified_Ideograph", "Ideographic"},
    20945: {"Unified_Ideograph", "Ideographic"},
    20946: {"Unified_Ideograph", "Ideographic"},
    20947: {"Unified_Ideograph", "Ideographic"},
    20948: {"Unified_Ideograph", "Ideographic"},
    20949: {"Unified_Ideograph", "Ideographic"},
    20950: {"Unified_Ideograph", "Ideographic"},
    20951: {"Unified_Ideograph", "Ideographic"},
    20952: {"Unified_Ideograph", "Ideographic"},
    20953: {"Unified_Ideograph", "Ideographic"},
    20954: {"Unified_Ideograph", "Ideographic"},
    20955: {"Unified_Ideograph", "Ideographic"},
    20956: {"Unified_Ideograph", "Ideographic"},
    20957: {"Unified_Ideograph", "Ideographic"},
    20958: {"Unified_Ideograph", "Ideographic"},
    20959: {"Unified_Ideograph", "Ideographic"},
    20960: {"Unified_Ideograph", "Ideographic"},
    20961: {"Unified_Ideograph", "Ideographic"},
    20962: {"Unified_Ideograph", "Ideographic"},
    20963: {"Unified_Ideograph", "Ideographic"},
    20964: {"Unified_Ideograph", "Ideographic"},
    20965: {"Unified_Ideograph", "Ideographic"},
    20966: {"Unified_Ideograph", "Ideographic"},
    20967: {"Unified_Ideograph", "Ideographic"},
    20968: {"Unified_Ideograph", "Ideographic"},
    20969: {"Unified_Ideograph", "Ideographic"},
    20970: {"Unified_Ideograph", "Ideographic"},
    20971: {"Unified_Ideograph", "Ideographic"},
    20972: {"Unified_Ideograph", "Ideographic"},
    20973: {"Unified_Ideograph", "Ideographic"},
    20974: {"Unified_Ideograph", "Ideographic"},
    20975: {"Unified_Ideograph", "Ideographic"},
    20976: {"Unified_Ideograph", "Ideographic"},
    20977: {"Unified_Ideograph", "Ideographic"},
    20978: {"Unified_Ideograph", "Ideographic"},
    20979: {"Unified_Ideograph", "Ideographic"},
    20980: {"Unified_Ideograph", "Ideographic"},
    20981: {"Unified_Ideograph", "Ideographic"},
    20982: {"Unified_Ideograph", "Ideographic"},
    20983: {"Unified_Ideograph", "Ideographic"},
    20984: {"Unified_Ideograph", "Ideographic"},
    20985: {"Unified_Ideograph", "Ideographic"},
    20986: {"Unified_Ideograph", "Ideographic"},
    20987: {"Unified_Ideograph", "Ideographic"},
    20988: {"Unified_Ideograph", "Ideographic"},
    20989: {"Unified_Ideograph", "Ideographic"},
    20990: {"Unified_Ideograph", "Ideographic"},
    20991: {"Unified_Ideograph", "Ideographic"},
    20992: {"Unified_Ideograph", "Ideographic"},
    20993: {"Unified_Ideograph", "Ideographic"},
    20994: {"Unified_Ideograph", "Ideographic"},
    20995: {"Unified_Ideograph", "Ideographic"},
    20996: {"Unified_Ideograph", "Ideographic"},
    20997: {"Unified_Ideograph", "Ideographic"},
    20998: {"Unified_Ideograph", "Ideographic"},
    20999: {"Unified_Ideograph", "Ideographic"},
    21000: {"Unified_Ideograph", "Ideographic"},
    21001: {"Unified_Ideograph", "Ideographic"},
    21002: {"Unified_Ideograph", "Ideographic"},
    21003: {"Unified_Ideograph", "Ideographic"},
    21004: {"Unified_Ideograph", "Ideographic"},
    21005: {"Unified_Ideograph", "Ideographic"},
    21006: {"Unified_Ideograph", "Ideographic"},
    21007: {"Unified_Ideograph", "Ideographic"},
    21008: {"Unified_Ideograph", "Ideographic"},
    21009: {"Unified_Ideograph", "Ideographic"},
    21010: {"Unified_Ideograph", "Ideographic"},
    21011: {"Unified_Ideograph", "Ideographic"},
    21012: {"Unified_Ideograph", "Ideographic"},
    21013: {"Unified_Ideograph", "Ideographic"},
    21014: {"Unified_Ideograph", "Ideographic"},
    21015: {"Unified_Ideograph", "Ideographic"},
    21016: {"Unified_Ideograph", "Ideographic"},
    21017: {"Unified_Ideograph", "Ideographic"},
    21018: {"Unified_Ideograph", "Ideographic"},
    21019: {"Unified_Ideograph", "Ideographic"},
    21020: {"Unified_Ideograph", "Ideographic"},
    21021: {"Unified_Ideograph", "Ideographic"},
    21022: {"Unified_Ideograph", "Ideographic"},
    21023: {"Unified_Ideograph", "Ideographic"},
    21024: {"Unified_Ideograph", "Ideographic"},
    21025: {"Unified_Ideograph", "Ideographic"},
    21026: {"Unified_Ideograph", "Ideographic"},
    21027: {"Unified_Ideograph", "Ideographic"},
    21028: {"Unified_Ideograph", "Ideographic"},
    21029: {"Unified_Ideograph", "Ideographic"},
    21030: {"Unified_Ideograph", "Ideographic"},
    21031: {"Unified_Ideograph", "Ideographic"},
    21032: {"Unified_Ideograph", "Ideographic"},
    21033: {"Unified_Ideograph", "Ideographic"},
    21034: {"Unified_Ideograph", "Ideographic"},
    21035: {"Unified_Ideograph", "Ideographic"},
    21036: {"Unified_Ideograph", "Ideographic"},
    21037: {"Unified_Ideograph", "Ideographic"},
    21038: {"Unified_Ideograph", "Ideographic"},
    21039: {"Unified_Ideograph", "Ideographic"},
    21040: {"Unified_Ideograph", "Ideographic"},
    21041: {"Unified_Ideograph", "Ideographic"},
    21042: {"Unified_Ideograph", "Ideographic"},
    21043: {"Unified_Ideograph", "Ideographic"},
    21044: {"Unified_Ideograph", "Ideographic"},
    21045: {"Unified_Ideograph", "Ideographic"},
    21046: {"Unified_Ideograph", "Ideographic"},
    21047: {"Unified_Ideograph", "Ideographic"},
    21048: {"Unified_Ideograph", "Ideographic"},
    21049: {"Unified_Ideograph", "Ideographic"},
    21050: {"Unified_Ideograph", "Ideographic"},
    21051: {"Unified_Ideograph", "Ideographic"},
    21052: {"Unified_Ideograph", "Ideographic"},
    21053: {"Unified_Ideograph", "Ideographic"},
    21054: {"Unified_Ideograph", "Ideographic"},
    21055: {"Unified_Ideograph", "Ideographic"},
    21056: {"Unified_Ideograph", "Ideographic"},
    21057: {"Unified_Ideograph", "Ideographic"},
    21058: {"Unified_Ideograph", "Ideographic"},
    21059: {"Unified_Ideograph", "Ideographic"},
    21060: {"Unified_Ideograph", "Ideographic"},
    21061: {"Unified_Ideograph", "Ideographic"},
    21062: {"Unified_Ideograph", "Ideographic"},
    21063: {"Unified_Ideograph", "Ideographic"},
    21064: {"Unified_Ideograph", "Ideographic"},
    21065: {"Unified_Ideograph", "Ideographic"},
    21066: {"Unified_Ideograph", "Ideographic"},
    21067: {"Unified_Ideograph", "Ideographic"},
    21068: {"Unified_Ideograph", "Ideographic"},
    21069: {"Unified_Ideograph", "Ideographic"},
    21070: {"Unified_Ideograph", "Ideographic"},
    21071: {"Unified_Ideograph", "Ideographic"},
    21072: {"Unified_Ideograph", "Ideographic"},
    21073: {"Unified_Ideograph", "Ideographic"},
    21074: {"Unified_Ideograph", "Ideographic"},
    21075: {"Unified_Ideograph", "Ideographic"},
    21076: {"Unified_Ideograph", "Ideographic"},
    21077: {"Unified_Ideograph", "Ideographic"},
    21078: {"Unified_Ideograph", "Ideographic"},
    21079: {"Unified_Ideograph", "Ideographic"},
    21080: {"Unified_Ideograph", "Ideographic"},
    21081: {"Unified_Ideograph", "Ideographic"},
    21082: {"Unified_Ideograph", "Ideographic"},
    21083: {"Unified_Ideograph", "Ideographic"},
    21084: {"Unified_Ideograph", "Ideographic"},
    21085: {"Unified_Ideograph", "Ideographic"},
    21086: {"Unified_Ideograph", "Ideographic"},
    21087: {"Unified_Ideograph", "Ideographic"},
    21088: {"Unified_Ideograph", "Ideographic"},
    21089: {"Unified_Ideograph", "Ideographic"},
    21090: {"Unified_Ideograph", "Ideographic"},
    21091: {"Unified_Ideograph", "Ideographic"},
    21092: {"Unified_Ideograph", "Ideographic"},
    21093: {"Unified_Ideograph", "Ideographic"},
    21094: {"Unified_Ideograph", "Ideographic"},
    21095: {"Unified_Ideograph", "Ideographic"},
    21096: {"Unified_Ideograph", "Ideographic"},
    21097: {"Unified_Ideograph", "Ideographic"},
    21098: {"Unified_Ideograph", "Ideographic"},
    21099: {"Unified_Ideograph", "Ideographic"},
    21100: {"Unified_Ideograph", "Ideographic"},
    21101: {"Unified_Ideograph", "Ideographic"},
    21102: {"Unified_Ideograph", "Ideographic"},
    21103: {"Unified_Ideograph", "Ideographic"},
    21104: {"Unified_Ideograph", "Ideographic"},
    21105: {"Unified_Ideograph", "Ideographic"},
    21106: {"Unified_Ideograph", "Ideographic"},
    21107: {"Unified_Ideograph", "Ideographic"},
    21108: {"Unified_Ideograph", "Ideographic"},
    21109: {"Unified_Ideograph", "Ideographic"},
    21110: {"Unified_Ideograph", "Ideographic"},
    21111: {"Unified_Ideograph", "Ideographic"},
    21112: {"Unified_Ideograph", "Ideographic"},
    21113: {"Unified_Ideograph", "Ideographic"},
    21114: {"Unified_Ideograph", "Ideographic"},
    21115: {"Unified_Ideograph", "Ideographic"},
    21116: {"Unified_Ideograph", "Ideographic"},
    21117: {"Unified_Ideograph", "Ideographic"},
    21118: {"Unified_Ideograph", "Ideographic"},
    21119: {"Unified_Ideograph", "Ideographic"},
    21120: {"Unified_Ideograph", "Ideographic"},
    21121: {"Unified_Ideograph", "Ideographic"},
    21122: {"Unified_Ideograph", "Ideographic"},
    21123: {"Unified_Ideograph", "Ideographic"},
    21124: {"Unified_Ideograph", "Ideographic"},
    21125: {"Unified_Ideograph", "Ideographic"},
    21126: {"Unified_Ideograph", "Ideographic"},
    21127: {"Unified_Ideograph", "Ideographic"},
    21128: {"Unified_Ideograph", "Ideographic"},
    21129: {"Unified_Ideograph", "Ideographic"},
    21130: {"Unified_Ideograph", "Ideographic"},
    21131: {"Unified_Ideograph", "Ideographic"},
    21132: {"Unified_Ideograph", "Ideographic"},
    21133: {"Unified_Ideograph", "Ideographic"},
    21134: {"Unified_Ideograph", "Ideographic"},
    21135: {"Unified_Ideograph", "Ideographic"},
    21136: {"Unified_Ideograph", "Ideographic"},
    21137: {"Unified_Ideograph", "Ideographic"},
    21138: {"Unified_Ideograph", "Ideographic"},
    21139: {"Unified_Ideograph", "Ideographic"},
    21140: {"Unified_Ideograph", "Ideographic"},
    21141: {"Unified_Ideograph", "Ideographic"},
    21142: {"Unified_Ideograph", "Ideographic"},
    21143: {"Unified_Ideograph", "Ideographic"},
    21144: {"Unified_Ideograph", "Ideographic"},
    21145: {"Unified_Ideograph", "Ideographic"},
    21146: {"Unified_Ideograph", "Ideographic"},
    21147: {"Unified_Ideograph", "Ideographic"},
    21148: {"Unified_Ideograph", "Ideographic"},
    21149: {"Unified_Ideograph", "Ideographic"},
    21150: {"Unified_Ideograph", "Ideographic"},
    21151: {"Unified_Ideograph", "Ideographic"},
    21152: {"Unified_Ideograph", "Ideographic"},
    21153: {"Unified_Ideograph", "Ideographic"},
    21154: {"Unified_Ideograph", "Ideographic"},
    21155: {"Unified_Ideograph", "Ideographic"},
    21156: {"Unified_Ideograph", "Ideographic"},
    21157: {"Unified_Ideograph", "Ideographic"},
    21158: {"Unified_Ideograph", "Ideographic"},
    21159: {"Unified_Ideograph", "Ideographic"},
    21160: {"Unified_Ideograph", "Ideographic"},
    21161: {"Unified_Ideograph", "Ideographic"},
    21162: {"Unified_Ideograph", "Ideographic"},
    21163: {"Unified_Ideograph", "Ideographic"},
    21164: {"Unified_Ideograph", "Ideographic"},
    21165: {"Unified_Ideograph", "Ideographic"},
    21166: {"Unified_Ideograph", "Ideographic"},
    21167: {"Unified_Ideograph", "Ideographic"},
    21168: {"Unified_Ideograph", "Ideographic"},
    21169: {"Unified_Ideograph", "Ideographic"},
    21170: {"Unified_Ideograph", "Ideographic"},
    21171: {"Unified_Ideograph", "Ideographic"},
    21172: {"Unified_Ideograph", "Ideographic"},
    21173: {"Unified_Ideograph", "Ideographic"},
    21174: {"Unified_Ideograph", "Ideographic"},
    21175: {"Unified_Ideograph", "Ideographic"},
    21176: {"Unified_Ideograph", "Ideographic"},
    21177: {"Unified_Ideograph", "Ideographic"},
    21178: {"Unified_Ideograph", "Ideographic"},
    21179: {"Unified_Ideograph", "Ideographic"},
    21180: {"Unified_Ideograph", "Ideographic"},
    21181: {"Unified_Ideograph", "Ideographic"},
    21182: {"Unified_Ideograph", "Ideographic"},
    21183: {"Unified_Ideograph", "Ideographic"},
    21184: {"Unified_Ideograph", "Ideographic"},
    21185: {"Unified_Ideograph", "Ideographic"},
    21186: {"Unified_Ideograph", "Ideographic"},
    21187: {"Unified_Ideograph", "Ideographic"},
    21188: {"Unified_Ideograph", "Ideographic"},
    21189: {"Unified_Ideograph", "Ideographic"},
    21190: {"Unified_Ideograph", "Ideographic"},
    21191: {"Unified_Ideograph", "Ideographic"},
    21192: {"Unified_Ideograph", "Ideographic"},
    21193: {"Unified_Ideograph", "Ideographic"},
    21194: {"Unified_Ideograph", "Ideographic"},
    21195: {"Unified_Ideograph", "Ideographic"},
    21196: {"Unified_Ideograph", "Ideographic"},
    21197: {"Unified_Ideograph", "Ideographic"},
    21198: {"Unified_Ideograph", "Ideographic"},
    21199: {"Unified_Ideograph", "Ideographic"},
    21200: {"Unified_Ideograph", "Ideographic"},
    21201: {"Unified_Ideograph", "Ideographic"},
    21202: {"Unified_Ideograph", "Ideographic"},
    21203: {"Unified_Ideograph", "Ideographic"},
    21204: {"Unified_Ideograph", "Ideographic"},
    21205: {"Unified_Ideograph", "Ideographic"},
    21206: {"Unified_Ideograph", "Ideographic"},
    21207: {"Unified_Ideograph", "Ideographic"},
    21208: {"Unified_Ideograph", "Ideographic"},
    21209: {"Unified_Ideograph", "Ideographic"},
    21210: {"Unified_Ideograph", "Ideographic"},
    21211: {"Unified_Ideograph", "Ideographic"},
    21212: {"Unified_Ideograph", "Ideographic"},
    21213: {"Unified_Ideograph", "Ideographic"},
    21214: {"Unified_Ideograph", "Ideographic"},
    21215: {"Unified_Ideograph", "Ideographic"},
    21216: {"Unified_Ideograph", "Ideographic"},
    21217: {"Unified_Ideograph", "Ideographic"},
    21218: {"Unified_Ideograph", "Ideographic"},
    21219: {"Unified_Ideograph", "Ideographic"},
    21220: {"Unified_Ideograph", "Ideographic"},
    21221: {"Unified_Ideograph", "Ideographic"},
    21222: {"Unified_Ideograph", "Ideographic"},
    21223: {"Unified_Ideograph", "Ideographic"},
    21224: {"Unified_Ideograph", "Ideographic"},
    21225: {"Unified_Ideograph", "Ideographic"},
    21226: {"Unified_Ideograph", "Ideographic"},
    21227: {"Unified_Ideograph", "Ideographic"},
    21228: {"Unified_Ideograph", "Ideographic"},
    21229: {"Unified_Ideograph", "Ideographic"},
    21230: {"Unified_Ideograph", "Ideographic"},
    21231: {"Unified_Ideograph", "Ideographic"},
    21232: {"Unified_Ideograph", "Ideographic"},
    21233: {"Unified_Ideograph", "Ideographic"},
    21234: {"Unified_Ideograph", "Ideographic"},
    21235: {"Unified_Ideograph", "Ideographic"},
    21236: {"Unified_Ideograph", "Ideographic"},
    21237: {"Unified_Ideograph", "Ideographic"},
    21238: {"Unified_Ideograph", "Ideographic"},
    21239: {"Unified_Ideograph", "Ideographic"},
    21240: {"Unified_Ideograph", "Ideographic"},
    21241: {"Unified_Ideograph", "Ideographic"},
    21242: {"Unified_Ideograph", "Ideographic"},
    21243: {"Unified_Ideograph", "Ideographic"},
    21244: {"Unified_Ideograph", "Ideographic"},
    21245: {"Unified_Ideograph", "Ideographic"},
    21246: {"Unified_Ideograph", "Ideographic"},
    21247: {"Unified_Ideograph", "Ideographic"},
    21248: {"Unified_Ideograph", "Ideographic"},
    21249: {"Unified_Ideograph", "Ideographic"},
    21250: {"Unified_Ideograph", "Ideographic"},
    21251: {"Unified_Ideograph", "Ideographic"},
    21252: {"Unified_Ideograph", "Ideographic"},
    21253: {"Unified_Ideograph", "Ideographic"},
    21254: {"Unified_Ideograph", "Ideographic"},
    21255: {"Unified_Ideograph", "Ideographic"},
    21256: {"Unified_Ideograph", "Ideographic"},
    21257: {"Unified_Ideograph", "Ideographic"},
    21258: {"Unified_Ideograph", "Ideographic"},
    21259: {"Unified_Ideograph", "Ideographic"},
    21260: {"Unified_Ideograph", "Ideographic"},
    21261: {"Unified_Ideograph", "Ideographic"},
    21262: {"Unified_Ideograph", "Ideographic"},
    21263: {"Unified_Ideograph", "Ideographic"},
    21264: {"Unified_Ideograph", "Ideographic"},
    21265: {"Unified_Ideograph", "Ideographic"},
    21266: {"Unified_Ideograph", "Ideographic"},
    21267: {"Unified_Ideograph", "Ideographic"},
    21268: {"Unified_Ideograph", "Ideographic"},
    21269: {"Unified_Ideograph", "Ideographic"},
    21270: {"Unified_Ideograph", "Ideographic"},
    21271: {"Unified_Ideograph", "Ideographic"},
    21272: {"Unified_Ideograph", "Ideographic"},
    21273: {"Unified_Ideograph", "Ideographic"},
    21274: {"Unified_Ideograph", "Ideographic"},
    21275: {"Unified_Ideograph", "Ideographic"},
    21276: {"Unified_Ideograph", "Ideographic"},
    21277: {"Unified_Ideograph", "Ideographic"},
    21278: {"Unified_Ideograph", "Ideographic"},
    21279: {"Unified_Ideograph", "Ideographic"},
    21280: {"Unified_Ideograph", "Ideographic"},
    21281: {"Unified_Ideograph", "Ideographic"},
    21282: {"Unified_Ideograph", "Ideographic"},
    21283: {"Unified_Ideograph", "Ideographic"},
    21284: {"Unified_Ideograph", "Ideographic"},
    21285: {"Unified_Ideograph", "Ideographic"},
    21286: {"Unified_Ideograph", "Ideographic"},
    21287: {"Unified_Ideograph", "Ideographic"},
    21288: {"Unified_Ideograph", "Ideographic"},
    21289: {"Unified_Ideograph", "Ideographic"},
    21290: {"Unified_Ideograph", "Ideographic"},
    21291: {"Unified_Ideograph", "Ideographic"},
    21292: {"Unified_Ideograph", "Ideographic"},
    21293: {"Unified_Ideograph", "Ideographic"},
    21294: {"Unified_Ideograph", "Ideographic"},
    21295: {"Unified_Ideograph", "Ideographic"},
    21296: {"Unified_Ideograph", "Ideographic"},
    21297: {"Unified_Ideograph", "Ideographic"},
    21298: {"Unified_Ideograph", "Ideographic"},
    21299: {"Unified_Ideograph", "Ideographic"},
    21300: {"Unified_Ideograph", "Ideographic"},
    21301: {"Unified_Ideograph", "Ideographic"},
    21302: {"Unified_Ideograph", "Ideographic"},
    21303: {"Unified_Ideograph", "Ideographic"},
    21304: {"Unified_Ideograph", "Ideographic"},
    21305: {"Unified_Ideograph", "Ideographic"},
    21306: {"Unified_Ideograph", "Ideographic"},
    21307: {"Unified_Ideograph", "Ideographic"},
    21308: {"Unified_Ideograph", "Ideographic"},
    21309: {"Unified_Ideograph", "Ideographic"},
    21310: {"Unified_Ideograph", "Ideographic"},
    21311: {"Unified_Ideograph", "Ideographic"},
    21312: {"Unified_Ideograph", "Ideographic"},
    21313: {"Unified_Ideograph", "Ideographic"},
    21314: {"Unified_Ideograph", "Ideographic"},
    21315: {"Unified_Ideograph", "Ideographic"},
    21316: {"Unified_Ideograph", "Ideographic"},
    21317: {"Unified_Ideograph", "Ideographic"},
    21318: {"Unified_Ideograph", "Ideographic"},
    21319: {"Unified_Ideograph", "Ideographic"},
    21320: {"Unified_Ideograph", "Ideographic"},
    21321: {"Unified_Ideograph", "Ideographic"},
    21322: {"Unified_Ideograph", "Ideographic"},
    21323: {"Unified_Ideograph", "Ideographic"},
    21324: {"Unified_Ideograph", "Ideographic"},
    21325: {"Unified_Ideograph", "Ideographic"},
    21326: {"Unified_Ideograph", "Ideographic"},
    21327: {"Unified_Ideograph", "Ideographic"},
    21328: {"Unified_Ideograph", "Ideographic"},
    21329: {"Unified_Ideograph", "Ideographic"},
    21330: {"Unified_Ideograph", "Ideographic"},
    21331: {"Unified_Ideograph", "Ideographic"},
    21332: {"Unified_Ideograph", "Ideographic"},
    21333: {"Unified_Ideograph", "Ideographic"},
    21334: {"Unified_Ideograph", "Ideographic"},
    21335: {"Unified_Ideograph", "Ideographic"},
    21336: {"Unified_Ideograph", "Ideographic"},
    21337: {"Unified_Ideograph", "Ideographic"},
    21338: {"Unified_Ideograph", "Ideographic"},
    21339: {"Unified_Ideograph", "Ideographic"},
    21340: {"Unified_Ideograph", "Ideographic"},
    21341: {"Unified_Ideograph", "Ideographic"},
    21342: {"Unified_Ideograph", "Ideographic"},
    21343: {"Unified_Ideograph", "Ideographic"},
    21344: {"Unified_Ideograph", "Ideographic"},
    21345: {"Unified_Ideograph", "Ideographic"},
    21346: {"Unified_Ideograph", "Ideographic"},
    21347: {"Unified_Ideograph", "Ideographic"},
    21348: {"Unified_Ideograph", "Ideographic"},
    21349: {"Unified_Ideograph", "Ideographic"},
    21350: {"Unified_Ideograph", "Ideographic"},
    21351: {"Unified_Ideograph", "Ideographic"},
    21352: {"Unified_Ideograph", "Ideographic"},
    21353: {"Unified_Ideograph", "Ideographic"},
    21354: {"Unified_Ideograph", "Ideographic"},
    21355: {"Unified_Ideograph", "Ideographic"},
    21356: {"Unified_Ideograph", "Ideographic"},
    21357: {"Unified_Ideograph", "Ideographic"},
    21358: {"Unified_Ideograph", "Ideographic"},
    21359: {"Unified_Ideograph", "Ideographic"},
    21360: {"Unified_Ideograph", "Ideographic"},
    21361: {"Unified_Ideograph", "Ideographic"},
    21362: {"Unified_Ideograph", "Ideographic"},
    21363: {"Unified_Ideograph", "Ideographic"},
    21364: {"Unified_Ideograph", "Ideographic"},
    21365: {"Unified_Ideograph", "Ideographic"},
    21366: {"Unified_Ideograph", "Ideographic"},
    21367: {"Unified_Ideograph", "Ideographic"},
    21368: {"Unified_Ideograph", "Ideographic"},
    21369: {"Unified_Ideograph", "Ideographic"},
    21370: {"Unified_Ideograph", "Ideographic"},
    21371: {"Unified_Ideograph", "Ideographic"},
    21372: {"Unified_Ideograph", "Ideographic"},
    21373: {"Unified_Ideograph", "Ideographic"},
    21374: {"Unified_Ideograph", "Ideographic"},
    21375: {"Unified_Ideograph", "Ideographic"},
    21376: {"Unified_Ideograph", "Ideographic"},
    21377: {"Unified_Ideograph", "Ideographic"},
    21378: {"Unified_Ideograph", "Ideographic"},
    21379: {"Unified_Ideograph", "Ideographic"},
    21380: {"Unified_Ideograph", "Ideographic"},
    21381: {"Unified_Ideograph", "Ideographic"},
    21382: {"Unified_Ideograph", "Ideographic"},
    21383: {"Unified_Ideograph", "Ideographic"},
    21384: {"Unified_Ideograph", "Ideographic"},
    21385: {"Unified_Ideograph", "Ideographic"},
    21386: {"Unified_Ideograph", "Ideographic"},
    21387: {"Unified_Ideograph", "Ideographic"},
    21388: {"Unified_Ideograph", "Ideographic"},
    21389: {"Unified_Ideograph", "Ideographic"},
    21390: {"Unified_Ideograph", "Ideographic"},
    21391: {"Unified_Ideograph", "Ideographic"},
    21392: {"Unified_Ideograph", "Ideographic"},
    21393: {"Unified_Ideograph", "Ideographic"},
    21394: {"Unified_Ideograph", "Ideographic"},
    21395: {"Unified_Ideograph", "Ideographic"},
    21396: {"Unified_Ideograph", "Ideographic"},
    21397: {"Unified_Ideograph", "Ideographic"},
    21398: {"Unified_Ideograph", "Ideographic"},
    21399: {"Unified_Ideograph", "Ideographic"},
    21400: {"Unified_Ideograph", "Ideographic"},
    21401: {"Unified_Ideograph", "Ideographic"},
    21402: {"Unified_Ideograph", "Ideographic"},
    21403: {"Unified_Ideograph", "Ideographic"},
    21404: {"Unified_Ideograph", "Ideographic"},
    21405: {"Unified_Ideograph", "Ideographic"},
    21406: {"Unified_Ideograph", "Ideographic"},
    21407: {"Unified_Ideograph", "Ideographic"},
    21408: {"Unified_Ideograph", "Ideographic"},
    21409: {"Unified_Ideograph", "Ideographic"},
    21410: {"Unified_Ideograph", "Ideographic"},
    21411: {"Unified_Ideograph", "Ideographic"},
    21412: {"Unified_Ideograph", "Ideographic"},
    21413: {"Unified_Ideograph", "Ideographic"},
    21414: {"Unified_Ideograph", "Ideographic"},
    21415: {"Unified_Ideograph", "Ideographic"},
    21416: {"Unified_Ideograph", "Ideographic"},
    21417: {"Unified_Ideograph", "Ideographic"},
    21418: {"Unified_Ideograph", "Ideographic"},
    21419: {"Unified_Ideograph", "Ideographic"},
    21420: {"Unified_Ideograph", "Ideographic"},
    21421: {"Unified_Ideograph", "Ideographic"},
    21422: {"Unified_Ideograph", "Ideographic"},
    21423: {"Unified_Ideograph", "Ideographic"},
    21424: {"Unified_Ideograph", "Ideographic"},
    21425: {"Unified_Ideograph", "Ideographic"},
    21426: {"Unified_Ideograph", "Ideographic"},
    21427: {"Unified_Ideograph", "Ideographic"},
    21428: {"Unified_Ideograph", "Ideographic"},
    21429: {"Unified_Ideograph", "Ideographic"},
    21430: {"Unified_Ideograph", "Ideographic"},
    21431: {"Unified_Ideograph", "Ideographic"},
    21432: {"Unified_Ideograph", "Ideographic"},
    21433: {"Unified_Ideograph", "Ideographic"},
    21434: {"Unified_Ideograph", "Ideographic"},
    21435: {"Unified_Ideograph", "Ideographic"},
    21436: {"Unified_Ideograph", "Ideographic"},
    21437: {"Unified_Ideograph", "Ideographic"},
    21438: {"Unified_Ideograph", "Ideographic"},
    21439: {"Unified_Ideograph", "Ideographic"},
    21440: {"Unified_Ideograph", "Ideographic"},
    21441: {"Unified_Ideograph", "Ideographic"},
    21442: {"Unified_Ideograph", "Ideographic"},
    21443: {"Unified_Ideograph", "Ideographic"},
    21444: {"Unified_Ideograph", "Ideographic"},
    21445: {"Unified_Ideograph", "Ideographic"},
    21446: {"Unified_Ideograph", "Ideographic"},
    21447: {"Unified_Ideograph", "Ideographic"},
    21448: {"Unified_Ideograph", "Ideographic"},
    21449: {"Unified_Ideograph", "Ideographic"},
    21450: {"Unified_Ideograph", "Ideographic"},
    21451: {"Unified_Ideograph", "Ideographic"},
    21452: {"Unified_Ideograph", "Ideographic"},
    21453: {"Unified_Ideograph", "Ideographic"},
    21454: {"Unified_Ideograph", "Ideographic"},
    21455: {"Unified_Ideograph", "Ideographic"},
    21456: {"Unified_Ideograph", "Ideographic"},
    21457: {"Unified_Ideograph", "Ideographic"},
    21458: {"Unified_Ideograph", "Ideographic"},
    21459: {"Unified_Ideograph", "Ideographic"},
    21460: {"Unified_Ideograph", "Ideographic"},
    21461: {"Unified_Ideograph", "Ideographic"},
    21462: {"Unified_Ideograph", "Ideographic"},
    21463: {"Unified_Ideograph", "Ideographic"},
    21464: {"Unified_Ideograph", "Ideographic"},
    21465: {"Unified_Ideograph", "Ideographic"},
    21466: {"Unified_Ideograph", "Ideographic"},
    21467: {"Unified_Ideograph", "Ideographic"},
    21468: {"Unified_Ideograph", "Ideographic"},
    21469: {"Unified_Ideograph", "Ideographic"},
    21470: {"Unified_Ideograph", "Ideographic"},
    21471: {"Unified_Ideograph", "Ideographic"},
    21472: {"Unified_Ideograph", "Ideographic"},
    21473: {"Unified_Ideograph", "Ideographic"},
    21474: {"Unified_Ideograph", "Ideographic"},
    21475: {"Unified_Ideograph", "Ideographic"},
    21476: {"Unified_Ideograph", "Ideographic"},
    21477: {"Unified_Ideograph", "Ideographic"},
    21478: {"Unified_Ideograph", "Ideographic"},
    21479: {"Unified_Ideograph", "Ideographic"},
    21480: {"Unified_Ideograph", "Ideographic"},
    21481: {"Unified_Ideograph", "Ideographic"},
    21482: {"Unified_Ideograph", "Ideographic"},
    21483: {"Unified_Ideograph", "Ideographic"},
    21484: {"Unified_Ideograph", "Ideographic"},
    21485: {"Unified_Ideograph", "Ideographic"},
    21486: {"Unified_Ideograph", "Ideographic"},
    21487: {"Unified_Ideograph", "Ideographic"},
    21488: {"Unified_Ideograph", "Ideographic"},
    21489: {"Unified_Ideograph", "Ideographic"},
    21490: {"Unified_Ideograph", "Ideographic"},
    21491: {"Unified_Ideograph", "Ideographic"},
    21492: {"Unified_Ideograph", "Ideographic"},
    21493: {"Unified_Ideograph", "Ideographic"},
    21494: {"Unified_Ideograph", "Ideographic"},
    21495: {"Unified_Ideograph", "Ideographic"},
    21496: {"Unified_Ideograph", "Ideographic"},
    21497: {"Unified_Ideograph", "Ideographic"},
    21498: {"Unified_Ideograph", "Ideographic"},
    21499: {"Unified_Ideograph", "Ideographic"},
    21500: {"Unified_Ideograph", "Ideographic"},
    21501: {"Unified_Ideograph", "Ideographic"},
    21502: {"Unified_Ideograph", "Ideographic"},
    21503: {"Unified_Ideograph", "Ideographic"},
    21504: {"Unified_Ideograph", "Ideographic"},
    21505: {"Unified_Ideograph", "Ideographic"},
    21506: {"Unified_Ideograph", "Ideographic"},
    21507: {"Unified_Ideograph", "Ideographic"},
    21508: {"Unified_Ideograph", "Ideographic"},
    21509: {"Unified_Ideograph", "Ideographic"},
    21510: {"Unified_Ideograph", "Ideographic"},
    21511: {"Unified_Ideograph", "Ideographic"},
    21512: {"Unified_Ideograph", "Ideographic"},
    21513: {"Unified_Ideograph", "Ideographic"},
    21514: {"Unified_Ideograph", "Ideographic"},
    21515: {"Unified_Ideograph", "Ideographic"},
    21516: {"Unified_Ideograph", "Ideographic"},
    21517: {"Unified_Ideograph", "Ideographic"},
    21518: {"Unified_Ideograph", "Ideographic"},
    21519: {"Unified_Ideograph", "Ideographic"},
    21520: {"Unified_Ideograph", "Ideographic"},
    21521: {"Unified_Ideograph", "Ideographic"},
    21522: {"Unified_Ideograph", "Ideographic"},
    21523: {"Unified_Ideograph", "Ideographic"},
    21524: {"Unified_Ideograph", "Ideographic"},
    21525: {"Unified_Ideograph", "Ideographic"},
    21526: {"Unified_Ideograph", "Ideographic"},
    21527: {"Unified_Ideograph", "Ideographic"},
    21528: {"Unified_Ideograph", "Ideographic"},
    21529: {"Unified_Ideograph", "Ideographic"},
    21530: {"Unified_Ideograph", "Ideographic"},
    21531: {"Unified_Ideograph", "Ideographic"},
    21532: {"Unified_Ideograph", "Ideographic"},
    21533: {"Unified_Ideograph", "Ideographic"},
    21534: {"Unified_Ideograph", "Ideographic"},
    21535: {"Unified_Ideograph", "Ideographic"},
    21536: {"Unified_Ideograph", "Ideographic"},
    21537: {"Unified_Ideograph", "Ideographic"},
    21538: {"Unified_Ideograph", "Ideographic"},
    21539: {"Unified_Ideograph", "Ideographic"},
    21540: {"Unified_Ideograph", "Ideographic"},
    21541: {"Unified_Ideograph", "Ideographic"},
    21542: {"Unified_Ideograph", "Ideographic"},
    21543: {"Unified_Ideograph", "Ideographic"},
    21544: {"Unified_Ideograph", "Ideographic"},
    21545: {"Unified_Ideograph", "Ideographic"},
    21546: {"Unified_Ideograph", "Ideographic"},
    21547: {"Unified_Ideograph", "Ideographic"},
    21548: {"Unified_Ideograph", "Ideographic"},
    21549: {"Unified_Ideograph", "Ideographic"},
    21550: {"Unified_Ideograph", "Ideographic"},
    21551: {"Unified_Ideograph", "Ideographic"},
    21552: {"Unified_Ideograph", "Ideographic"},
    21553: {"Unified_Ideograph", "Ideographic"},
    21554: {"Unified_Ideograph", "Ideographic"},
    21555: {"Unified_Ideograph", "Ideographic"},
    21556: {"Unified_Ideograph", "Ideographic"},
    21557: {"Unified_Ideograph", "Ideographic"},
    21558: {"Unified_Ideograph", "Ideographic"},
    21559: {"Unified_Ideograph", "Ideographic"},
    21560: {"Unified_Ideograph", "Ideographic"},
    21561: {"Unified_Ideograph", "Ideographic"},
    21562: {"Unified_Ideograph", "Ideographic"},
    21563: {"Unified_Ideograph", "Ideographic"},
    21564: {"Unified_Ideograph", "Ideographic"},
    21565: {"Unified_Ideograph", "Ideographic"},
    21566: {"Unified_Ideograph", "Ideographic"},
    21567: {"Unified_Ideograph", "Ideographic"},
    21568: {"Unified_Ideograph", "Ideographic"},
    21569: {"Unified_Ideograph", "Ideographic"},
    21570: {"Unified_Ideograph", "Ideographic"},
    21571: {"Unified_Ideograph", "Ideographic"},
    21572: {"Unified_Ideograph", "Ideographic"},
    21573: {"Unified_Ideograph", "Ideographic"},
    21574: {"Unified_Ideograph", "Ideographic"},
    21575: {"Unified_Ideograph", "Ideographic"},
    21576: {"Unified_Ideograph", "Ideographic"},
    21577: {"Unified_Ideograph", "Ideographic"},
    21578: {"Unified_Ideograph", "Ideographic"},
    21579: {"Unified_Ideograph", "Ideographic"},
    21580: {"Unified_Ideograph", "Ideographic"},
    21581: {"Unified_Ideograph", "Ideographic"},
    21582: {"Unified_Ideograph", "Ideographic"},
    21583: {"Unified_Ideograph", "Ideographic"},
    21584: {"Unified_Ideograph", "Ideographic"},
    21585: {"Unified_Ideograph", "Ideographic"},
    21586: {"Unified_Ideograph", "Ideographic"},
    21587: {"Unified_Ideograph", "Ideographic"},
    21588: {"Unified_Ideograph", "Ideographic"},
    21589: {"Unified_Ideograph", "Ideographic"},
    21590: {"Unified_Ideograph", "Ideographic"},
    21591: {"Unified_Ideograph", "Ideographic"},
    21592: {"Unified_Ideograph", "Ideographic"},
    21593: {"Unified_Ideograph", "Ideographic"},
    21594: {"Unified_Ideograph", "Ideographic"},
    21595: {"Unified_Ideograph", "Ideographic"},
    21596: {"Unified_Ideograph", "Ideographic"},
    21597: {"Unified_Ideograph", "Ideographic"},
    21598: {"Unified_Ideograph", "Ideographic"},
    21599: {"Unified_Ideograph", "Ideographic"},
    21600: {"Unified_Ideograph", "Ideographic"},
    21601: {"Unified_Ideograph", "Ideographic"},
    21602: {"Unified_Ideograph", "Ideographic"},
    21603: {"Unified_Ideograph", "Ideographic"},
    21604: {"Unified_Ideograph", "Ideographic"},
    21605: {"Unified_Ideograph", "Ideographic"},
    21606: {"Unified_Ideograph", "Ideographic"},
    21607: {"Unified_Ideograph", "Ideographic"},
    21608: {"Unified_Ideograph", "Ideographic"},
    21609: {"Unified_Ideograph", "Ideographic"},
    21610: {"Unified_Ideograph", "Ideographic"},
    21611: {"Unified_Ideograph", "Ideographic"},
    21612: {"Unified_Ideograph", "Ideographic"},
    21613: {"Unified_Ideograph", "Ideographic"},
    21614: {"Unified_Ideograph", "Ideographic"},
    21615: {"Unified_Ideograph", "Ideographic"},
    21616: {"Unified_Ideograph", "Ideographic"},
    21617: {"Unified_Ideograph", "Ideographic"},
    21618: {"Unified_Ideograph", "Ideographic"},
    21619: {"Unified_Ideograph", "Ideographic"},
    21620: {"Unified_Ideograph", "Ideographic"},
    21621: {"Unified_Ideograph", "Ideographic"},
    21622: {"Unified_Ideograph", "Ideographic"},
    21623: {"Unified_Ideograph", "Ideographic"},
    21624: {"Unified_Ideograph", "Ideographic"},
    21625: {"Unified_Ideograph", "Ideographic"},
    21626: {"Unified_Ideograph", "Ideographic"},
    21627: {"Unified_Ideograph", "Ideographic"},
    21628: {"Unified_Ideograph", "Ideographic"},
    21629: {"Unified_Ideograph", "Ideographic"},
    21630: {"Unified_Ideograph", "Ideographic"},
    21631: {"Unified_Ideograph", "Ideographic"},
    21632: {"Unified_Ideograph", "Ideographic"},
    21633: {"Unified_Ideograph", "Ideographic"},
    21634: {"Unified_Ideograph", "Ideographic"},
    21635: {"Unified_Ideograph", "Ideographic"},
    21636: {"Unified_Ideograph", "Ideographic"},
    21637: {"Unified_Ideograph", "Ideographic"},
    21638: {"Unified_Ideograph", "Ideographic"},
    21639: {"Unified_Ideograph", "Ideographic"},
    21640: {"Unified_Ideograph", "Ideographic"},
    21641: {"Unified_Ideograph", "Ideographic"},
    21642: {"Unified_Ideograph", "Ideographic"},
    21643: {"Unified_Ideograph", "Ideographic"},
    21644: {"Unified_Ideograph", "Ideographic"},
    21645: {"Unified_Ideograph", "Ideographic"},
    21646: {"Unified_Ideograph", "Ideographic"},
    21647: {"Unified_Ideograph", "Ideographic"},
    21648: {"Unified_Ideograph", "Ideographic"},
    21649: {"Unified_Ideograph", "Ideographic"},
    21650: {"Unified_Ideograph", "Ideographic"},
    21651: {"Unified_Ideograph", "Ideographic"},
    21652: {"Unified_Ideograph", "Ideographic"},
    21653: {"Unified_Ideograph", "Ideographic"},
    21654: {"Unified_Ideograph", "Ideographic"},
    21655: {"Unified_Ideograph", "Ideographic"},
    21656: {"Unified_Ideograph", "Ideographic"},
    21657: {"Unified_Ideograph", "Ideographic"},
    21658: {"Unified_Ideograph", "Ideographic"},
    21659: {"Unified_Ideograph", "Ideographic"},
    21660: {"Unified_Ideograph", "Ideographic"},
    21661: {"Unified_Ideograph", "Ideographic"},
    21662: {"Unified_Ideograph", "Ideographic"},
    21663: {"Unified_Ideograph", "Ideographic"},
    21664: {"Unified_Ideograph", "Ideographic"},
    21665: {"Unified_Ideograph", "Ideographic"},
    21666: {"Unified_Ideograph", "Ideographic"},
    21667: {"Unified_Ideograph", "Ideographic"},
    21668: {"Unified_Ideograph", "Ideographic"},
    21669: {"Unified_Ideograph", "Ideographic"},
    21670: {"Unified_Ideograph", "Ideographic"},
    21671: {"Unified_Ideograph", "Ideographic"},
    21672: {"Unified_Ideograph", "Ideographic"},
    21673: {"Unified_Ideograph", "Ideographic"},
    21674: {"Unified_Ideograph", "Ideographic"},
    21675: {"Unified_Ideograph", "Ideographic"},
    21676: {"Unified_Ideograph", "Ideographic"},
    21677: {"Unified_Ideograph", "Ideographic"},
    21678: {"Unified_Ideograph", "Ideographic"},
    21679: {"Unified_Ideograph", "Ideographic"},
    21680: {"Unified_Ideograph", "Ideographic"},
    21681: {"Unified_Ideograph", "Ideographic"},
    21682: {"Unified_Ideograph", "Ideographic"},
    21683: {"Unified_Ideograph", "Ideographic"},
    21684: {"Unified_Ideograph", "Ideographic"},
    21685: {"Unified_Ideograph", "Ideographic"},
    21686: {"Unified_Ideograph", "Ideographic"},
    21687: {"Unified_Ideograph", "Ideographic"},
    21688: {"Unified_Ideograph", "Ideographic"},
    21689: {"Unified_Ideograph", "Ideographic"},
    21690: {"Unified_Ideograph", "Ideographic"},
    21691: {"Unified_Ideograph", "Ideographic"},
    21692: {"Unified_Ideograph", "Ideographic"},
    21693: {"Unified_Ideograph", "Ideographic"},
    21694: {"Unified_Ideograph", "Ideographic"},
    21695: {"Unified_Ideograph", "Ideographic"},
    21696: {"Unified_Ideograph", "Ideographic"},
    21697: {"Unified_Ideograph", "Ideographic"},
    21698: {"Unified_Ideograph", "Ideographic"},
    21699: {"Unified_Ideograph", "Ideographic"},
    21700: {"Unified_Ideograph", "Ideographic"},
    21701: {"Unified_Ideograph", "Ideographic"},
    21702: {"Unified_Ideograph", "Ideographic"},
    21703: {"Unified_Ideograph", "Ideographic"},
    21704: {"Unified_Ideograph", "Ideographic"},
    21705: {"Unified_Ideograph", "Ideographic"},
    21706: {"Unified_Ideograph", "Ideographic"},
    21707: {"Unified_Ideograph", "Ideographic"},
    21708: {"Unified_Ideograph", "Ideographic"},
    21709: {"Unified_Ideograph", "Ideographic"},
    21710: {"Unified_Ideograph", "Ideographic"},
    21711: {"Unified_Ideograph", "Ideographic"},
    21712: {"Unified_Ideograph", "Ideographic"},
    21713: {"Unified_Ideograph", "Ideographic"},
    21714: {"Unified_Ideograph", "Ideographic"},
    21715: {"Unified_Ideograph", "Ideographic"},
    21716: {"Unified_Ideograph", "Ideographic"},
    21717: {"Unified_Ideograph", "Ideographic"},
    21718: {"Unified_Ideograph", "Ideographic"},
    21719: {"Unified_Ideograph", "Ideographic"},
    21720: {"Unified_Ideograph", "Ideographic"},
    21721: {"Unified_Ideograph", "Ideographic"},
    21722: {"Unified_Ideograph", "Ideographic"},
    21723: {"Unified_Ideograph", "Ideographic"},
    21724: {"Unified_Ideograph", "Ideographic"},
    21725: {"Unified_Ideograph", "Ideographic"},
    21726: {"Unified_Ideograph", "Ideographic"},
    21727: {"Unified_Ideograph", "Ideographic"},
    21728: {"Unified_Ideograph", "Ideographic"},
    21729: {"Unified_Ideograph", "Ideographic"},
    21730: {"Unified_Ideograph", "Ideographic"},
    21731: {"Unified_Ideograph", "Ideographic"},
    21732: {"Unified_Ideograph", "Ideographic"},
    21733: {"Unified_Ideograph", "Ideographic"},
    21734: {"Unified_Ideograph", "Ideographic"},
    21735: {"Unified_Ideograph", "Ideographic"},
    21736: {"Unified_Ideograph", "Ideographic"},
    21737: {"Unified_Ideograph", "Ideographic"},
    21738: {"Unified_Ideograph", "Ideographic"},
    21739: {"Unified_Ideograph", "Ideographic"},
    21740: {"Unified_Ideograph", "Ideographic"},
    21741: {"Unified_Ideograph", "Ideographic"},
    21742: {"Unified_Ideograph", "Ideographic"},
    21743: {"Unified_Ideograph", "Ideographic"},
    21744: {"Unified_Ideograph", "Ideographic"},
    21745: {"Unified_Ideograph", "Ideographic"},
    21746: {"Unified_Ideograph", "Ideographic"},
    21747: {"Unified_Ideograph", "Ideographic"},
    21748: {"Unified_Ideograph", "Ideographic"},
    21749: {"Unified_Ideograph", "Ideographic"},
    21750: {"Unified_Ideograph", "Ideographic"},
    21751: {"Unified_Ideograph", "Ideographic"},
    21752: {"Unified_Ideograph", "Ideographic"},
    21753: {"Unified_Ideograph", "Ideographic"},
    21754: {"Unified_Ideograph", "Ideographic"},
    21755: {"Unified_Ideograph", "Ideographic"},
    21756: {"Unified_Ideograph", "Ideographic"},
    21757: {"Unified_Ideograph", "Ideographic"},
    21758: {"Unified_Ideograph", "Ideographic"},
    21759: {"Unified_Ideograph", "Ideographic"},
    21760: {"Unified_Ideograph", "Ideographic"},
    21761: {"Unified_Ideograph", "Ideographic"},
    21762: {"Unified_Ideograph", "Ideographic"},
    21763: {"Unified_Ideograph", "Ideographic"},
    21764: {"Unified_Ideograph", "Ideographic"},
    21765: {"Unified_Ideograph", "Ideographic"},
    21766: {"Unified_Ideograph", "Ideographic"},
    21767: {"Unified_Ideograph", "Ideographic"},
    21768: {"Unified_Ideograph", "Ideographic"},
    21769: {"Unified_Ideograph", "Ideographic"},
    21770: {"Unified_Ideograph", "Ideographic"},
    21771: {"Unified_Ideograph", "Ideographic"},
    21772: {"Unified_Ideograph", "Ideographic"},
    21773: {"Unified_Ideograph", "Ideographic"},
    21774: {"Unified_Ideograph", "Ideographic"},
    21775: {"Unified_Ideograph", "Ideographic"},
    21776: {"Unified_Ideograph", "Ideographic"},
    21777: {"Unified_Ideograph", "Ideographic"},
    21778: {"Unified_Ideograph", "Ideographic"},
    21779: {"Unified_Ideograph", "Ideographic"},
    21780: {"Unified_Ideograph", "Ideographic"},
    21781: {"Unified_Ideograph", "Ideographic"},
    21782: {"Unified_Ideograph", "Ideographic"},
    21783: {"Unified_Ideograph", "Ideographic"},
    21784: {"Unified_Ideograph", "Ideographic"},
    21785: {"Unified_Ideograph", "Ideographic"},
    21786: {"Unified_Ideograph", "Ideographic"},
    21787: {"Unified_Ideograph", "Ideographic"},
    21788: {"Unified_Ideograph", "Ideographic"},
    21789: {"Unified_Ideograph", "Ideographic"},
    21790: {"Unified_Ideograph", "Ideographic"},
    21791: {"Unified_Ideograph", "Ideographic"},
    21792: {"Unified_Ideograph", "Ideographic"},
    21793: {"Unified_Ideograph", "Ideographic"},
    21794: {"Unified_Ideograph", "Ideographic"},
    21795: {"Unified_Ideograph", "Ideographic"},
    21796: {"Unified_Ideograph", "Ideographic"},
    21797: {"Unified_Ideograph", "Ideographic"},
    21798: {"Unified_Ideograph", "Ideographic"},
    21799: {"Unified_Ideograph", "Ideographic"},
    21800: {"Unified_Ideograph", "Ideographic"},
    21801: {"Unified_Ideograph", "Ideographic"},
    21802: {"Unified_Ideograph", "Ideographic"},
    21803: {"Unified_Ideograph", "Ideographic"},
    21804: {"Unified_Ideograph", "Ideographic"},
    21805: {"Unified_Ideograph", "Ideographic"},
    21806: {"Unified_Ideograph", "Ideographic"},
    21807: {"Unified_Ideograph", "Ideographic"},
    21808: {"Unified_Ideograph", "Ideographic"},
    21809: {"Unified_Ideograph", "Ideographic"},
    21810: {"Unified_Ideograph", "Ideographic"},
    21811: {"Unified_Ideograph", "Ideographic"},
    21812: {"Unified_Ideograph", "Ideographic"},
    21813: {"Unified_Ideograph", "Ideographic"},
    21814: {"Unified_Ideograph", "Ideographic"},
    21815: {"Unified_Ideograph", "Ideographic"},
    21816: {"Unified_Ideograph", "Ideographic"},
    21817: {"Unified_Ideograph", "Ideographic"},
    21818: {"Unified_Ideograph", "Ideographic"},
    21819: {"Unified_Ideograph", "Ideographic"},
    21820: {"Unified_Ideograph", "Ideographic"},
    21821: {"Unified_Ideograph", "Ideographic"},
    21822: {"Unified_Ideograph", "Ideographic"},
    21823: {"Unified_Ideograph", "Ideographic"},
    21824: {"Unified_Ideograph", "Ideographic"},
    21825: {"Unified_Ideograph", "Ideographic"},
    21826: {"Unified_Ideograph", "Ideographic"},
    21827: {"Unified_Ideograph", "Ideographic"},
    21828: {"Unified_Ideograph", "Ideographic"},
    21829: {"Unified_Ideograph", "Ideographic"},
    21830: {"Unified_Ideograph", "Ideographic"},
    21831: {"Unified_Ideograph", "Ideographic"},
    21832: {"Unified_Ideograph", "Ideographic"},
    21833: {"Unified_Ideograph", "Ideographic"},
    21834: {"Unified_Ideograph", "Ideographic"},
    21835: {"Unified_Ideograph", "Ideographic"},
    21836: {"Unified_Ideograph", "Ideographic"},
    21837: {"Unified_Ideograph", "Ideographic"},
    21838: {"Unified_Ideograph", "Ideographic"},
    21839: {"Unified_Ideograph", "Ideographic"},
    21840: {"Unified_Ideograph", "Ideographic"},
    21841: {"Unified_Ideograph", "Ideographic"},
    21842: {"Unified_Ideograph", "Ideographic"},
    21843: {"Unified_Ideograph", "Ideographic"},
    21844: {"Unified_Ideograph", "Ideographic"},
    21845: {"Unified_Ideograph", "Ideographic"},
    21846: {"Unified_Ideograph", "Ideographic"},
    21847: {"Unified_Ideograph", "Ideographic"},
    21848: {"Unified_Ideograph", "Ideographic"},
    21849: {"Unified_Ideograph", "Ideographic"},
    21850: {"Unified_Ideograph", "Ideographic"},
    21851: {"Unified_Ideograph", "Ideographic"},
    21852: {"Unified_Ideograph", "Ideographic"},
    21853: {"Unified_Ideograph", "Ideographic"},
    21854: {"Unified_Ideograph", "Ideographic"},
    21855: {"Unified_Ideograph", "Ideographic"},
    21856: {"Unified_Ideograph", "Ideographic"},
    21857: {"Unified_Ideograph", "Ideographic"},
    21858: {"Unified_Ideograph", "Ideographic"},
    21859: {"Unified_Ideograph", "Ideographic"},
    21860: {"Unified_Ideograph", "Ideographic"},
    21861: {"Unified_Ideograph", "Ideographic"},
    21862: {"Unified_Ideograph", "Ideographic"},
    21863: {"Unified_Ideograph", "Ideographic"},
    21864: {"Unified_Ideograph", "Ideographic"},
    21865: {"Unified_Ideograph", "Ideographic"},
    21866: {"Unified_Ideograph", "Ideographic"},
    21867: {"Unified_Ideograph", "Ideographic"},
    21868: {"Unified_Ideograph", "Ideographic"},
    21869: {"Unified_Ideograph", "Ideographic"},
    21870: {"Unified_Ideograph", "Ideographic"},
    21871: {"Unified_Ideograph", "Ideographic"},
    21872: {"Unified_Ideograph", "Ideographic"},
    21873: {"Unified_Ideograph", "Ideographic"},
    21874: {"Unified_Ideograph", "Ideographic"},
    21875: {"Unified_Ideograph", "Ideographic"},
    21876: {"Unified_Ideograph", "Ideographic"},
    21877: {"Unified_Ideograph", "Ideographic"},
    21878: {"Unified_Ideograph", "Ideographic"},
    21879: {"Unified_Ideograph", "Ideographic"},
    21880: {"Unified_Ideograph", "Ideographic"},
    21881: {"Unified_Ideograph", "Ideographic"},
    21882: {"Unified_Ideograph", "Ideographic"},
    21883: {"Unified_Ideograph", "Ideographic"},
    21884: {"Unified_Ideograph", "Ideographic"},
    21885: {"Unified_Ideograph", "Ideographic"},
    21886: {"Unified_Ideograph", "Ideographic"},
    21887: {"Unified_Ideograph", "Ideographic"},
    21888: {"Unified_Ideograph", "Ideographic"},
    21889: {"Unified_Ideograph", "Ideographic"},
    21890: {"Unified_Ideograph", "Ideographic"},
    21891: {"Unified_Ideograph", "Ideographic"},
    21892: {"Unified_Ideograph", "Ideographic"},
    21893: {"Unified_Ideograph", "Ideographic"},
    21894: {"Unified_Ideograph", "Ideographic"},
    21895: {"Unified_Ideograph", "Ideographic"},
    21896: {"Unified_Ideograph", "Ideographic"},
    21897: {"Unified_Ideograph", "Ideographic"},
    21898: {"Unified_Ideograph", "Ideographic"},
    21899: {"Unified_Ideograph", "Ideographic"},
    21900: {"Unified_Ideograph", "Ideographic"},
    21901: {"Unified_Ideograph", "Ideographic"},
    21902: {"Unified_Ideograph", "Ideographic"},
    21903: {"Unified_Ideograph", "Ideographic"},
    21904: {"Unified_Ideograph", "Ideographic"},
    21905: {"Unified_Ideograph", "Ideographic"},
    21906: {"Unified_Ideograph", "Ideographic"},
    21907: {"Unified_Ideograph", "Ideographic"},
    21908: {"Unified_Ideograph", "Ideographic"},
    21909: {"Unified_Ideograph", "Ideographic"},
    21910: {"Unified_Ideograph", "Ideographic"},
    21911: {"Unified_Ideograph", "Ideographic"},
    21912: {"Unified_Ideograph", "Ideographic"},
    21913: {"Unified_Ideograph", "Ideographic"},
    21914: {"Unified_Ideograph", "Ideographic"},
    21915: {"Unified_Ideograph", "Ideographic"},
    21916: {"Unified_Ideograph", "Ideographic"},
    21917: {"Unified_Ideograph", "Ideographic"},
    21918: {"Unified_Ideograph", "Ideographic"},
    21919: {"Unified_Ideograph", "Ideographic"},
    21920: {"Unified_Ideograph", "Ideographic"},
    21921: {"Unified_Ideograph", "Ideographic"},
    21922: {"Unified_Ideograph", "Ideographic"},
    21923: {"Unified_Ideograph", "Ideographic"},
    21924: {"Unified_Ideograph", "Ideographic"},
    21925: {"Unified_Ideograph", "Ideographic"},
    21926: {"Unified_Ideograph", "Ideographic"},
    21927: {"Unified_Ideograph", "Ideographic"},
    21928: {"Unified_Ideograph", "Ideographic"},
    21929: {"Unified_Ideograph", "Ideographic"},
    21930: {"Unified_Ideograph", "Ideographic"},
    21931: {"Unified_Ideograph", "Ideographic"},
    21932: {"Unified_Ideograph", "Ideographic"},
    21933: {"Unified_Ideograph", "Ideographic"},
    21934: {"Unified_Ideograph", "Ideographic"},
    21935: {"Unified_Ideograph", "Ideographic"},
    21936: {"Unified_Ideograph", "Ideographic"},
    21937: {"Unified_Ideograph", "Ideographic"},
    21938: {"Unified_Ideograph", "Ideographic"},
    21939: {"Unified_Ideograph", "Ideographic"},
    21940: {"Unified_Ideograph", "Ideographic"},
    21941: {"Unified_Ideograph", "Ideographic"},
    21942: {"Unified_Ideograph", "Ideographic"},
    21943: {"Unified_Ideograph", "Ideographic"},
    21944: {"Unified_Ideograph", "Ideographic"},
    21945: {"Unified_Ideograph", "Ideographic"},
    21946: {"Unified_Ideograph", "Ideographic"},
    21947: {"Unified_Ideograph", "Ideographic"},
    21948: {"Unified_Ideograph", "Ideographic"},
    21949: {"Unified_Ideograph", "Ideographic"},
    21950: {"Unified_Ideograph", "Ideographic"},
    21951: {"Unified_Ideograph", "Ideographic"},
    21952: {"Unified_Ideograph", "Ideographic"},
    21953: {"Unified_Ideograph", "Ideographic"},
    21954: {"Unified_Ideograph", "Ideographic"},
    21955: {"Unified_Ideograph", "Ideographic"},
    21956: {"Unified_Ideograph", "Ideographic"},
    21957: {"Unified_Ideograph", "Ideographic"},
    21958: {"Unified_Ideograph", "Ideographic"},
    21959: {"Unified_Ideograph", "Ideographic"},
    21960: {"Unified_Ideograph", "Ideographic"},
    21961: {"Unified_Ideograph", "Ideographic"},
    21962: {"Unified_Ideograph", "Ideographic"},
    21963: {"Unified_Ideograph", "Ideographic"},
    21964: {"Unified_Ideograph", "Ideographic"},
    21965: {"Unified_Ideograph", "Ideographic"},
    21966: {"Unified_Ideograph", "Ideographic"},
    21967: {"Unified_Ideograph", "Ideographic"},
    21968: {"Unified_Ideograph", "Ideographic"},
    21969: {"Unified_Ideograph", "Ideographic"},
    21970: {"Unified_Ideograph", "Ideographic"},
    21971: {"Unified_Ideograph", "Ideographic"},
    21972: {"Unified_Ideograph", "Ideographic"},
    21973: {"Unified_Ideograph", "Ideographic"},
    21974: {"Unified_Ideograph", "Ideographic"},
    21975: {"Unified_Ideograph", "Ideographic"},
    21976: {"Unified_Ideograph", "Ideographic"},
    21977: {"Unified_Ideograph", "Ideographic"},
    21978: {"Unified_Ideograph", "Ideographic"},
    21979: {"Unified_Ideograph", "Ideographic"},
    21980: {"Unified_Ideograph", "Ideographic"},
    21981: {"Unified_Ideograph", "Ideographic"},
    21982: {"Unified_Ideograph", "Ideographic"},
    21983: {"Unified_Ideograph", "Ideographic"},
    21984: {"Unified_Ideograph", "Ideographic"},
    21985: {"Unified_Ideograph", "Ideographic"},
    21986: {"Unified_Ideograph", "Ideographic"},
    21987: {"Unified_Ideograph", "Ideographic"},
    21988: {"Unified_Ideograph", "Ideographic"},
    21989: {"Unified_Ideograph", "Ideographic"},
    21990: {"Unified_Ideograph", "Ideographic"},
    21991: {"Unified_Ideograph", "Ideographic"},
    21992: {"Unified_Ideograph", "Ideographic"},
    21993: {"Unified_Ideograph", "Ideographic"},
    21994: {"Unified_Ideograph", "Ideographic"},
    21995: {"Unified_Ideograph", "Ideographic"},
    21996: {"Unified_Ideograph", "Ideographic"},
    21997: {"Unified_Ideograph", "Ideographic"},
    21998: {"Unified_Ideograph", "Ideographic"},
    21999: {"Unified_Ideograph", "Ideographic"},
    22000: {"Unified_Ideograph", "Ideographic"},
    22001: {"Unified_Ideograph", "Ideographic"},
    22002: {"Unified_Ideograph", "Ideographic"},
    22003: {"Unified_Ideograph", "Ideographic"},
    22004: {"Unified_Ideograph", "Ideographic"},
    22005: {"Unified_Ideograph", "Ideographic"},
    22006: {"Unified_Ideograph", "Ideographic"},
    22007: {"Unified_Ideograph", "Ideographic"},
    22008: {"Unified_Ideograph", "Ideographic"},
    22009: {"Unified_Ideograph", "Ideographic"},
    22010: {"Unified_Ideograph", "Ideographic"},
    22011: {"Unified_Ideograph", "Ideographic"},
    22012: {"Unified_Ideograph", "Ideographic"},
    22013: {"Unified_Ideograph", "Ideographic"},
    22014: {"Unified_Ideograph", "Ideographic"},
    22015: {"Unified_Ideograph", "Ideographic"},
    22016: {"Unified_Ideograph", "Ideographic"},
    22017: {"Unified_Ideograph", "Ideographic"},
    22018: {"Unified_Ideograph", "Ideographic"},
    22019: {"Unified_Ideograph", "Ideographic"},
    22020: {"Unified_Ideograph", "Ideographic"},
    22021: {"Unified_Ideograph", "Ideographic"},
    22022: {"Unified_Ideograph", "Ideographic"},
    22023: {"Unified_Ideograph", "Ideographic"},
    22024: {"Unified_Ideograph", "Ideographic"},
    22025: {"Unified_Ideograph", "Ideographic"},
    22026: {"Unified_Ideograph", "Ideographic"},
    22027: {"Unified_Ideograph", "Ideographic"},
    22028: {"Unified_Ideograph", "Ideographic"},
    22029: {"Unified_Ideograph", "Ideographic"},
    22030: {"Unified_Ideograph", "Ideographic"},
    22031: {"Unified_Ideograph", "Ideographic"},
    22032: {"Unified_Ideograph", "Ideographic"},
    22033: {"Unified_Ideograph", "Ideographic"},
    22034: {"Unified_Ideograph", "Ideographic"},
    22035: {"Unified_Ideograph", "Ideographic"},
    22036: {"Unified_Ideograph", "Ideographic"},
    22037: {"Unified_Ideograph", "Ideographic"},
    22038: {"Unified_Ideograph", "Ideographic"},
    22039: {"Unified_Ideograph", "Ideographic"},
    22040: {"Unified_Ideograph", "Ideographic"},
    22041: {"Unified_Ideograph", "Ideographic"},
    22042: {"Unified_Ideograph", "Ideographic"},
    22043: {"Unified_Ideograph", "Ideographic"},
    22044: {"Unified_Ideograph", "Ideographic"},
    22045: {"Unified_Ideograph", "Ideographic"},
    22046: {"Unified_Ideograph", "Ideographic"},
    22047: {"Unified_Ideograph", "Ideographic"},
    22048: {"Unified_Ideograph", "Ideographic"},
    22049: {"Unified_Ideograph", "Ideographic"},
    22050: {"Unified_Ideograph", "Ideographic"},
    22051: {"Unified_Ideograph", "Ideographic"},
    22052: {"Unified_Ideograph", "Ideographic"},
    22053: {"Unified_Ideograph", "Ideographic"},
    22054: {"Unified_Ideograph", "Ideographic"},
    22055: {"Unified_Ideograph", "Ideographic"},
    22056: {"Unified_Ideograph", "Ideographic"},
    22057: {"Unified_Ideograph", "Ideographic"},
    22058: {"Unified_Ideograph", "Ideographic"},
    22059: {"Unified_Ideograph", "Ideographic"},
    22060: {"Unified_Ideograph", "Ideographic"},
    22061: {"Unified_Ideograph", "Ideographic"},
    22062: {"Unified_Ideograph", "Ideographic"},
    22063: {"Unified_Ideograph", "Ideographic"},
    22064: {"Unified_Ideograph", "Ideographic"},
    22065: {"Unified_Ideograph", "Ideographic"},
    22066: {"Unified_Ideograph", "Ideographic"},
    22067: {"Unified_Ideograph", "Ideographic"},
    22068: {"Unified_Ideograph", "Ideographic"},
    22069: {"Unified_Ideograph", "Ideographic"},
    22070: {"Unified_Ideograph", "Ideographic"},
    22071: {"Unified_Ideograph", "Ideographic"},
    22072: {"Unified_Ideograph", "Ideographic"},
    22073: {"Unified_Ideograph", "Ideographic"},
    22074: {"Unified_Ideograph", "Ideographic"},
    22075: {"Unified_Ideograph", "Ideographic"},
    22076: {"Unified_Ideograph", "Ideographic"},
    22077: {"Unified_Ideograph", "Ideographic"},
    22078: {"Unified_Ideograph", "Ideographic"},
    22079: {"Unified_Ideograph", "Ideographic"},
    22080: {"Unified_Ideograph", "Ideographic"},
    22081: {"Unified_Ideograph", "Ideographic"},
    22082: {"Unified_Ideograph", "Ideographic"},
    22083: {"Unified_Ideograph", "Ideographic"},
    22084: {"Unified_Ideograph", "Ideographic"},
    22085: {"Unified_Ideograph", "Ideographic"},
    22086: {"Unified_Ideograph", "Ideographic"},
    22087: {"Unified_Ideograph", "Ideographic"},
    22088: {"Unified_Ideograph", "Ideographic"},
    22089: {"Unified_Ideograph", "Ideographic"},
    22090: {"Unified_Ideograph", "Ideographic"},
    22091: {"Unified_Ideograph", "Ideographic"},
    22092: {"Unified_Ideograph", "Ideographic"},
    22093: {"Unified_Ideograph", "Ideographic"},
    22094: {"Unified_Ideograph", "Ideographic"},
    22095: {"Unified_Ideograph", "Ideographic"},
    22096: {"Unified_Ideograph", "Ideographic"},
    22097: {"Unified_Ideograph", "Ideographic"},
    22098: {"Unified_Ideograph", "Ideographic"},
    22099: {"Unified_Ideograph", "Ideographic"},
    22100: {"Unified_Ideograph", "Ideographic"},
    22101: {"Unified_Ideograph", "Ideographic"},
    22102: {"Unified_Ideograph", "Ideographic"},
    22103: {"Unified_Ideograph", "Ideographic"},
    22104: {"Unified_Ideograph", "Ideographic"},
    22105: {"Unified_Ideograph", "Ideographic"},
    22106: {"Unified_Ideograph", "Ideographic"},
    22107: {"Unified_Ideograph", "Ideographic"},
    22108: {"Unified_Ideograph", "Ideographic"},
    22109: {"Unified_Ideograph", "Ideographic"},
    22110: {"Unified_Ideograph", "Ideographic"},
    22111: {"Unified_Ideograph", "Ideographic"},
    22112: {"Unified_Ideograph", "Ideographic"},
    22113: {"Unified_Ideograph", "Ideographic"},
    22114: {"Unified_Ideograph", "Ideographic"},
    22115: {"Unified_Ideograph", "Ideographic"},
    22116: {"Unified_Ideograph", "Ideographic"},
    22117: {"Unified_Ideograph", "Ideographic"},
    22118: {"Unified_Ideograph", "Ideographic"},
    22119: {"Unified_Ideograph", "Ideographic"},
    22120: {"Unified_Ideograph", "Ideographic"},
    22121: {"Unified_Ideograph", "Ideographic"},
    22122: {"Unified_Ideograph", "Ideographic"},
    22123: {"Unified_Ideograph", "Ideographic"},
    22124: {"Unified_Ideograph", "Ideographic"},
    22125: {"Unified_Ideograph", "Ideographic"},
    22126: {"Unified_Ideograph", "Ideographic"},
    22127: {"Unified_Ideograph", "Ideographic"},
    22128: {"Unified_Ideograph", "Ideographic"},
    22129: {"Unified_Ideograph", "Ideographic"},
    22130: {"Unified_Ideograph", "Ideographic"},
    22131: {"Unified_Ideograph", "Ideographic"},
    22132: {"Unified_Ideograph", "Ideographic"},
    22133: {"Unified_Ideograph", "Ideographic"},
    22134: {"Unified_Ideograph", "Ideographic"},
    22135: {"Unified_Ideograph", "Ideographic"},
    22136: {"Unified_Ideograph", "Ideographic"},
    22137: {"Unified_Ideograph", "Ideographic"},
    22138: {"Unified_Ideograph", "Ideographic"},
    22139: {"Unified_Ideograph", "Ideographic"},
    22140: {"Unified_Ideograph", "Ideographic"},
    22141: {"Unified_Ideograph", "Ideographic"},
    22142: {"Unified_Ideograph", "Ideographic"},
    22143: {"Unified_Ideograph", "Ideographic"},
    22144: {"Unified_Ideograph", "Ideographic"},
    22145: {"Unified_Ideograph", "Ideographic"},
    22146: {"Unified_Ideograph", "Ideographic"},
    22147: {"Unified_Ideograph", "Ideographic"},
    22148: {"Unified_Ideograph", "Ideographic"},
    22149: {"Unified_Ideograph", "Ideographic"},
    22150: {"Unified_Ideograph", "Ideographic"},
    22151: {"Unified_Ideograph", "Ideographic"},
    22152: {"Unified_Ideograph", "Ideographic"},
    22153: {"Unified_Ideograph", "Ideographic"},
    22154: {"Unified_Ideograph", "Ideographic"},
    22155: {"Unified_Ideograph", "Ideographic"},
    22156: {"Unified_Ideograph", "Ideographic"},
    22157: {"Unified_Ideograph", "Ideographic"},
    22158: {"Unified_Ideograph", "Ideographic"},
    22159: {"Unified_Ideograph", "Ideographic"},
    22160: {"Unified_Ideograph", "Ideographic"},
    22161: {"Unified_Ideograph", "Ideographic"},
    22162: {"Unified_Ideograph", "Ideographic"},
    22163: {"Unified_Ideograph", "Ideographic"},
    22164: {"Unified_Ideograph", "Ideographic"},
    22165: {"Unified_Ideograph", "Ideographic"},
    22166: {"Unified_Ideograph", "Ideographic"},
    22167: {"Unified_Ideograph", "Ideographic"},
    22168: {"Unified_Ideograph", "Ideographic"},
    22169: {"Unified_Ideograph", "Ideographic"},
    22170: {"Unified_Ideograph", "Ideographic"},
    22171: {"Unified_Ideograph", "Ideographic"},
    22172: {"Unified_Ideograph", "Ideographic"},
    22173: {"Unified_Ideograph", "Ideographic"},
    22174: {"Unified_Ideograph", "Ideographic"},
    22175: {"Unified_Ideograph", "Ideographic"},
    22176: {"Unified_Ideograph", "Ideographic"},
    22177: {"Unified_Ideograph", "Ideographic"},
    22178: {"Unified_Ideograph", "Ideographic"},
    22179: {"Unified_Ideograph", "Ideographic"},
    22180: {"Unified_Ideograph", "Ideographic"},
    22181: {"Unified_Ideograph", "Ideographic"},
    22182: {"Unified_Ideograph", "Ideographic"},
    22183: {"Unified_Ideograph", "Ideographic"},
    22184: {"Unified_Ideograph", "Ideographic"},
    22185: {"Unified_Ideograph", "Ideographic"},
    22186: {"Unified_Ideograph", "Ideographic"},
    22187: {"Unified_Ideograph", "Ideographic"},
    22188: {"Unified_Ideograph", "Ideographic"},
    22189: {"Unified_Ideograph", "Ideographic"},
    22190: {"Unified_Ideograph", "Ideographic"},
    22191: {"Unified_Ideograph", "Ideographic"},
    22192: {"Unified_Ideograph", "Ideographic"},
    22193: {"Unified_Ideograph", "Ideographic"},
    22194: {"Unified_Ideograph", "Ideographic"},
    22195: {"Unified_Ideograph", "Ideographic"},
    22196: {"Unified_Ideograph", "Ideographic"},
    22197: {"Unified_Ideograph", "Ideographic"},
    22198: {"Unified_Ideograph", "Ideographic"},
    22199: {"Unified_Ideograph", "Ideographic"},
    22200: {"Unified_Ideograph", "Ideographic"},
    22201: {"Unified_Ideograph", "Ideographic"},
    22202: {"Unified_Ideograph", "Ideographic"},
    22203: {"Unified_Ideograph", "Ideographic"},
    22204: {"Unified_Ideograph", "Ideographic"},
    22205: {"Unified_Ideograph", "Ideographic"},
    22206: {"Unified_Ideograph", "Ideographic"},
    22207: {"Unified_Ideograph", "Ideographic"},
    22208: {"Unified_Ideograph", "Ideographic"},
    22209: {"Unified_Ideograph", "Ideographic"},
    22210: {"Unified_Ideograph", "Ideographic"},
    22211: {"Unified_Ideograph", "Ideographic"},
    22212: {"Unified_Ideograph", "Ideographic"},
    22213: {"Unified_Ideograph", "Ideographic"},
    22214: {"Unified_Ideograph", "Ideographic"},
    22215: {"Unified_Ideograph", "Ideographic"},
    22216: {"Unified_Ideograph", "Ideographic"},
    22217: {"Unified_Ideograph", "Ideographic"},
    22218: {"Unified_Ideograph", "Ideographic"},
    22219: {"Unified_Ideograph", "Ideographic"},
    22220: {"Unified_Ideograph", "Ideographic"},
    22221: {"Unified_Ideograph", "Ideographic"},
    22222: {"Unified_Ideograph", "Ideographic"},
    22223: {"Unified_Ideograph", "Ideographic"},
    22224: {"Unified_Ideograph", "Ideographic"},
    22225: {"Unified_Ideograph", "Ideographic"},
    22226: {"Unified_Ideograph", "Ideographic"},
    22227: {"Unified_Ideograph", "Ideographic"},
    22228: {"Unified_Ideograph", "Ideographic"},
    22229: {"Unified_Ideograph", "Ideographic"},
    22230: {"Unified_Ideograph", "Ideographic"},
    22231: {"Unified_Ideograph", "Ideographic"},
    22232: {"Unified_Ideograph", "Ideographic"},
    22233: {"Unified_Ideograph", "Ideographic"},
    22234: {"Unified_Ideograph", "Ideographic"},
    22235: {"Unified_Ideograph", "Ideographic"},
    22236: {"Unified_Ideograph", "Ideographic"},
    22237: {"Unified_Ideograph", "Ideographic"},
    22238: {"Unified_Ideograph", "Ideographic"},
    22239: {"Unified_Ideograph", "Ideographic"},
    22240: {"Unified_Ideograph", "Ideographic"},
    22241: {"Unified_Ideograph", "Ideographic"},
    22242: {"Unified_Ideograph", "Ideographic"},
    22243: {"Unified_Ideograph", "Ideographic"},
    22244: {"Unified_Ideograph", "Ideographic"},
    22245: {"Unified_Ideograph", "Ideographic"},
    22246: {"Unified_Ideograph", "Ideographic"},
    22247: {"Unified_Ideograph", "Ideographic"},
    22248: {"Unified_Ideograph", "Ideographic"},
    22249: {"Unified_Ideograph", "Ideographic"},
    22250: {"Unified_Ideograph", "Ideographic"},
    22251: {"Unified_Ideograph", "Ideographic"},
    22252: {"Unified_Ideograph", "Ideographic"},
    22253: {"Unified_Ideograph", "Ideographic"},
    22254: {"Unified_Ideograph", "Ideographic"},
    22255: {"Unified_Ideograph", "Ideographic"},
    22256: {"Unified_Ideograph", "Ideographic"},
    22257: {"Unified_Ideograph", "Ideographic"},
    22258: {"Unified_Ideograph", "Ideographic"},
    22259: {"Unified_Ideograph", "Ideographic"},
    22260: {"Unified_Ideograph", "Ideographic"},
    22261: {"Unified_Ideograph", "Ideographic"},
    22262: {"Unified_Ideograph", "Ideographic"},
    22263: {"Unified_Ideograph", "Ideographic"},
    22264: {"Unified_Ideograph", "Ideographic"},
    22265: {"Unified_Ideograph", "Ideographic"},
    22266: {"Unified_Ideograph", "Ideographic"},
    22267: {"Unified_Ideograph", "Ideographic"},
    22268: {"Unified_Ideograph", "Ideographic"},
    22269: {"Unified_Ideograph", "Ideographic"},
    22270: {"Unified_Ideograph", "Ideographic"},
    22271: {"Unified_Ideograph", "Ideographic"},
    22272: {"Unified_Ideograph", "Ideographic"},
    22273: {"Unified_Ideograph", "Ideographic"},
    22274: {"Unified_Ideograph", "Ideographic"},
    22275: {"Unified_Ideograph", "Ideographic"},
    22276: {"Unified_Ideograph", "Ideographic"},
    22277: {"Unified_Ideograph", "Ideographic"},
    22278: {"Unified_Ideograph", "Ideographic"},
    22279: {"Unified_Ideograph", "Ideographic"},
    22280: {"Unified_Ideograph", "Ideographic"},
    22281: {"Unified_Ideograph", "Ideographic"},
    22282: {"Unified_Ideograph", "Ideographic"},
    22283: {"Unified_Ideograph", "Ideographic"},
    22284: {"Unified_Ideograph", "Ideographic"},
    22285: {"Unified_Ideograph", "Ideographic"},
    22286: {"Unified_Ideograph", "Ideographic"},
    22287: {"Unified_Ideograph", "Ideographic"},
    22288: {"Unified_Ideograph", "Ideographic"},
    22289: {"Unified_Ideograph", "Ideographic"},
    22290: {"Unified_Ideograph", "Ideographic"},
    22291: {"Unified_Ideograph", "Ideographic"},
    22292: {"Unified_Ideograph", "Ideographic"},
    22293: {"Unified_Ideograph", "Ideographic"},
    22294: {"Unified_Ideograph", "Ideographic"},
    22295: {"Unified_Ideograph", "Ideographic"},
    22296: {"Unified_Ideograph", "Ideographic"},
    22297: {"Unified_Ideograph", "Ideographic"},
    22298: {"Unified_Ideograph", "Ideographic"},
    22299: {"Unified_Ideograph", "Ideographic"},
    22300: {"Unified_Ideograph", "Ideographic"},
    22301: {"Unified_Ideograph", "Ideographic"},
    22302: {"Unified_Ideograph", "Ideographic"},
    22303: {"Unified_Ideograph", "Ideographic"},
    22304: {"Unified_Ideograph", "Ideographic"},
    22305: {"Unified_Ideograph", "Ideographic"},
    22306: {"Unified_Ideograph", "Ideographic"},
    22307: {"Unified_Ideograph", "Ideographic"},
    22308: {"Unified_Ideograph", "Ideographic"},
    22309: {"Unified_Ideograph", "Ideographic"},
    22310: {"Unified_Ideograph", "Ideographic"},
    22311: {"Unified_Ideograph", "Ideographic"},
    22312: {"Unified_Ideograph", "Ideographic"},
    22313: {"Unified_Ideograph", "Ideographic"},
    22314: {"Unified_Ideograph", "Ideographic"},
    22315: {"Unified_Ideograph", "Ideographic"},
    22316: {"Unified_Ideograph", "Ideographic"},
    22317: {"Unified_Ideograph", "Ideographic"},
    22318: {"Unified_Ideograph", "Ideographic"},
    22319: {"Unified_Ideograph", "Ideographic"},
    22320: {"Unified_Ideograph", "Ideographic"},
    22321: {"Unified_Ideograph", "Ideographic"},
    22322: {"Unified_Ideograph", "Ideographic"},
    22323: {"Unified_Ideograph", "Ideographic"},
    22324: {"Unified_Ideograph", "Ideographic"},
    22325: {"Unified_Ideograph", "Ideographic"},
    22326: {"Unified_Ideograph", "Ideographic"},
    22327: {"Unified_Ideograph", "Ideographic"},
    22328: {"Unified_Ideograph", "Ideographic"},
    22329: {"Unified_Ideograph", "Ideographic"},
    22330: {"Unified_Ideograph", "Ideographic"},
    22331: {"Unified_Ideograph", "Ideographic"},
    22332: {"Unified_Ideograph", "Ideographic"},
    22333: {"Unified_Ideograph", "Ideographic"},
    22334: {"Unified_Ideograph", "Ideographic"},
    22335: {"Unified_Ideograph", "Ideographic"},
    22336: {"Unified_Ideograph", "Ideographic"},
    22337: {"Unified_Ideograph", "Ideographic"},
    22338: {"Unified_Ideograph", "Ideographic"},
    22339: {"Unified_Ideograph", "Ideographic"},
    22340: {"Unified_Ideograph", "Ideographic"},
    22341: {"Unified_Ideograph", "Ideographic"},
    22342: {"Unified_Ideograph", "Ideographic"},
    22343: {"Unified_Ideograph", "Ideographic"},
    22344: {"Unified_Ideograph", "Ideographic"},
    22345: {"Unified_Ideograph", "Ideographic"},
    22346: {"Unified_Ideograph", "Ideographic"},
    22347: {"Unified_Ideograph", "Ideographic"},
    22348: {"Unified_Ideograph", "Ideographic"},
    22349: {"Unified_Ideograph", "Ideographic"},
    22350: {"Unified_Ideograph", "Ideographic"},
    22351: {"Unified_Ideograph", "Ideographic"},
    22352: {"Unified_Ideograph", "Ideographic"},
    22353: {"Unified_Ideograph", "Ideographic"},
    22354: {"Unified_Ideograph", "Ideographic"},
    22355: {"Unified_Ideograph", "Ideographic"},
    22356: {"Unified_Ideograph", "Ideographic"},
    22357: {"Unified_Ideograph", "Ideographic"},
    22358: {"Unified_Ideograph", "Ideographic"},
    22359: {"Unified_Ideograph", "Ideographic"},
    22360: {"Unified_Ideograph", "Ideographic"},
    22361: {"Unified_Ideograph", "Ideographic"},
    22362: {"Unified_Ideograph", "Ideographic"},
    22363: {"Unified_Ideograph", "Ideographic"},
    22364: {"Unified_Ideograph", "Ideographic"},
    22365: {"Unified_Ideograph", "Ideographic"},
    22366: {"Unified_Ideograph", "Ideographic"},
    22367: {"Unified_Ideograph", "Ideographic"},
    22368: {"Unified_Ideograph", "Ideographic"},
    22369: {"Unified_Ideograph", "Ideographic"},
    22370: {"Unified_Ideograph", "Ideographic"},
    22371: {"Unified_Ideograph", "Ideographic"},
    22372: {"Unified_Ideograph", "Ideographic"},
    22373: {"Unified_Ideograph", "Ideographic"},
    22374: {"Unified_Ideograph", "Ideographic"},
    22375: {"Unified_Ideograph", "Ideographic"},
    22376: {"Unified_Ideograph", "Ideographic"},
    22377: {"Unified_Ideograph", "Ideographic"},
    22378: {"Unified_Ideograph", "Ideographic"},
    22379: {"Unified_Ideograph", "Ideographic"},
    22380: {"Unified_Ideograph", "Ideographic"},
    22381: {"Unified_Ideograph", "Ideographic"},
    22382: {"Unified_Ideograph", "Ideographic"},
    22383: {"Unified_Ideograph", "Ideographic"},
    22384: {"Unified_Ideograph", "Ideographic"},
    22385: {"Unified_Ideograph", "Ideographic"},
    22386: {"Unified_Ideograph", "Ideographic"},
    22387: {"Unified_Ideograph", "Ideographic"},
    22388: {"Unified_Ideograph", "Ideographic"},
    22389: {"Unified_Ideograph", "Ideographic"},
    22390: {"Unified_Ideograph", "Ideographic"},
    22391: {"Unified_Ideograph", "Ideographic"},
    22392: {"Unified_Ideograph", "Ideographic"},
    22393: {"Unified_Ideograph", "Ideographic"},
    22394: {"Unified_Ideograph", "Ideographic"},
    22395: {"Unified_Ideograph", "Ideographic"},
    22396: {"Unified_Ideograph", "Ideographic"},
    22397: {"Unified_Ideograph", "Ideographic"},
    22398: {"Unified_Ideograph", "Ideographic"},
    22399: {"Unified_Ideograph", "Ideographic"},
    22400: {"Unified_Ideograph", "Ideographic"},
    22401: {"Unified_Ideograph", "Ideographic"},
    22402: {"Unified_Ideograph", "Ideographic"},
    22403: {"Unified_Ideograph", "Ideographic"},
    22404: {"Unified_Ideograph", "Ideographic"},
    22405: {"Unified_Ideograph", "Ideographic"},
    22406: {"Unified_Ideograph", "Ideographic"},
    22407: {"Unified_Ideograph", "Ideographic"},
    22408: {"Unified_Ideograph", "Ideographic"},
    22409: {"Unified_Ideograph", "Ideographic"},
    22410: {"Unified_Ideograph", "Ideographic"},
    22411: {"Unified_Ideograph", "Ideographic"},
    22412: {"Unified_Ideograph", "Ideographic"},
    22413: {"Unified_Ideograph", "Ideographic"},
    22414: {"Unified_Ideograph", "Ideographic"},
    22415: {"Unified_Ideograph", "Ideographic"},
    22416: {"Unified_Ideograph", "Ideographic"},
    22417: {"Unified_Ideograph", "Ideographic"},
    22418: {"Unified_Ideograph", "Ideographic"},
    22419: {"Unified_Ideograph", "Ideographic"},
    22420: {"Unified_Ideograph", "Ideographic"},
    22421: {"Unified_Ideograph", "Ideographic"},
    22422: {"Unified_Ideograph", "Ideographic"},
    22423: {"Unified_Ideograph", "Ideographic"},
    22424: {"Unified_Ideograph", "Ideographic"},
    22425: {"Unified_Ideograph", "Ideographic"},
    22426: {"Unified_Ideograph", "Ideographic"},
    22427: {"Unified_Ideograph", "Ideographic"},
    22428: {"Unified_Ideograph", "Ideographic"},
    22429: {"Unified_Ideograph", "Ideographic"},
    22430: {"Unified_Ideograph", "Ideographic"},
    22431: {"Unified_Ideograph", "Ideographic"},
    22432: {"Unified_Ideograph", "Ideographic"},
    22433: {"Unified_Ideograph", "Ideographic"},
    22434: {"Unified_Ideograph", "Ideographic"},
    22435: {"Unified_Ideograph", "Ideographic"},
    22436: {"Unified_Ideograph", "Ideographic"},
    22437: {"Unified_Ideograph", "Ideographic"},
    22438: {"Unified_Ideograph", "Ideographic"},
    22439: {"Unified_Ideograph", "Ideographic"},
    22440: {"Unified_Ideograph", "Ideographic"},
    22441: {"Unified_Ideograph", "Ideographic"},
    22442: {"Unified_Ideograph", "Ideographic"},
    22443: {"Unified_Ideograph", "Ideographic"},
    22444: {"Unified_Ideograph", "Ideographic"},
    22445: {"Unified_Ideograph", "Ideographic"},
    22446: {"Unified_Ideograph", "Ideographic"},
    22447: {"Unified_Ideograph", "Ideographic"},
    22448: {"Unified_Ideograph", "Ideographic"},
    22449: {"Unified_Ideograph", "Ideographic"},
    22450: {"Unified_Ideograph", "Ideographic"},
    22451: {"Unified_Ideograph", "Ideographic"},
    22452: {"Unified_Ideograph", "Ideographic"},
    22453: {"Unified_Ideograph", "Ideographic"},
    22454: {"Unified_Ideograph", "Ideographic"},
    22455: {"Unified_Ideograph", "Ideographic"},
    22456: {"Unified_Ideograph", "Ideographic"},
    22457: {"Unified_Ideograph", "Ideographic"},
    22458: {"Unified_Ideograph", "Ideographic"},
    22459: {"Unified_Ideograph", "Ideographic"},
    22460: {"Unified_Ideograph", "Ideographic"},
    22461: {"Unified_Ideograph", "Ideographic"},
    22462: {"Unified_Ideograph", "Ideographic"},
    22463: {"Unified_Ideograph", "Ideographic"},
    22464: {"Unified_Ideograph", "Ideographic"},
    22465: {"Unified_Ideograph", "Ideographic"},
    22466: {"Unified_Ideograph", "Ideographic"},
    22467: {"Unified_Ideograph", "Ideographic"},
    22468: {"Unified_Ideograph", "Ideographic"},
    22469: {"Unified_Ideograph", "Ideographic"},
    22470: {"Unified_Ideograph", "Ideographic"},
    22471: {"Unified_Ideograph", "Ideographic"},
    22472: {"Unified_Ideograph", "Ideographic"},
    22473: {"Unified_Ideograph", "Ideographic"},
    22474: {"Unified_Ideograph", "Ideographic"},
    22475: {"Unified_Ideograph", "Ideographic"},
    22476: {"Unified_Ideograph", "Ideographic"},
    22477: {"Unified_Ideograph", "Ideographic"},
    22478: {"Unified_Ideograph", "Ideographic"},
    22479: {"Unified_Ideograph", "Ideographic"},
    22480: {"Unified_Ideograph", "Ideographic"},
    22481: {"Unified_Ideograph", "Ideographic"},
    22482: {"Unified_Ideograph", "Ideographic"},
    22483: {"Unified_Ideograph", "Ideographic"},
    22484: {"Unified_Ideograph", "Ideographic"},
    22485: {"Unified_Ideograph", "Ideographic"},
    22486: {"Unified_Ideograph", "Ideographic"},
    22487: {"Unified_Ideograph", "Ideographic"},
    22488: {"Unified_Ideograph", "Ideographic"},
    22489: {"Unified_Ideograph", "Ideographic"},
    22490: {"Unified_Ideograph", "Ideographic"},
    22491: {"Unified_Ideograph", "Ideographic"},
    22492: {"Unified_Ideograph", "Ideographic"},
    22493: {"Unified_Ideograph", "Ideographic"},
    22494: {"Unified_Ideograph", "Ideographic"},
    22495: {"Unified_Ideograph", "Ideographic"},
    22496: {"Unified_Ideograph", "Ideographic"},
    22497: {"Unified_Ideograph", "Ideographic"},
    22498: {"Unified_Ideograph", "Ideographic"},
    22499: {"Unified_Ideograph", "Ideographic"},
    22500: {"Unified_Ideograph", "Ideographic"},
    22501: {"Unified_Ideograph", "Ideographic"},
    22502: {"Unified_Ideograph", "Ideographic"},
    22503: {"Unified_Ideograph", "Ideographic"},
    22504: {"Unified_Ideograph", "Ideographic"},
    22505: {"Unified_Ideograph", "Ideographic"},
    22506: {"Unified_Ideograph", "Ideographic"},
    22507: {"Unified_Ideograph", "Ideographic"},
    22508: {"Unified_Ideograph", "Ideographic"},
    22509: {"Unified_Ideograph", "Ideographic"},
    22510: {"Unified_Ideograph", "Ideographic"},
    22511: {"Unified_Ideograph", "Ideographic"},
    22512: {"Unified_Ideograph", "Ideographic"},
    22513: {"Unified_Ideograph", "Ideographic"},
    22514: {"Unified_Ideograph", "Ideographic"},
    22515: {"Unified_Ideograph", "Ideographic"},
    22516: {"Unified_Ideograph", "Ideographic"},
    22517: {"Unified_Ideograph", "Ideographic"},
    22518: {"Unified_Ideograph", "Ideographic"},
    22519: {"Unified_Ideograph", "Ideographic"},
    22520: {"Unified_Ideograph", "Ideographic"},
    22521: {"Unified_Ideograph", "Ideographic"},
    22522: {"Unified_Ideograph", "Ideographic"},
    22523: {"Unified_Ideograph", "Ideographic"},
    22524: {"Unified_Ideograph", "Ideographic"},
    22525: {"Unified_Ideograph", "Ideographic"},
    22526: {"Unified_Ideograph", "Ideographic"},
    22527: {"Unified_Ideograph", "Ideographic"},
    22528: {"Unified_Ideograph", "Ideographic"},
    22529: {"Unified_Ideograph", "Ideographic"},
    22530: {"Unified_Ideograph", "Ideographic"},
    22531: {"Unified_Ideograph", "Ideographic"},
    22532: {"Unified_Ideograph", "Ideographic"},
    22533: {"Unified_Ideograph", "Ideographic"},
    22534: {"Unified_Ideograph", "Ideographic"},
    22535: {"Unified_Ideograph", "Ideographic"},
    22536: {"Unified_Ideograph", "Ideographic"},
    22537: {"Unified_Ideograph", "Ideographic"},
    22538: {"Unified_Ideograph", "Ideographic"},
    22539: {"Unified_Ideograph", "Ideographic"},
    22540: {"Unified_Ideograph", "Ideographic"},
    22541: {"Unified_Ideograph", "Ideographic"},
    22542: {"Unified_Ideograph", "Ideographic"},
    22543: {"Unified_Ideograph", "Ideographic"},
    22544: {"Unified_Ideograph", "Ideographic"},
    22545: {"Unified_Ideograph", "Ideographic"},
    22546: {"Unified_Ideograph", "Ideographic"},
    22547: {"Unified_Ideograph", "Ideographic"},
    22548: {"Unified_Ideograph", "Ideographic"},
    22549: {"Unified_Ideograph", "Ideographic"},
    22550: {"Unified_Ideograph", "Ideographic"},
    22551: {"Unified_Ideograph", "Ideographic"},
    22552: {"Unified_Ideograph", "Ideographic"},
    22553: {"Unified_Ideograph", "Ideographic"},
    22554: {"Unified_Ideograph", "Ideographic"},
    22555: {"Unified_Ideograph", "Ideographic"},
    22556: {"Unified_Ideograph", "Ideographic"},
    22557: {"Unified_Ideograph", "Ideographic"},
    22558: {"Unified_Ideograph", "Ideographic"},
    22559: {"Unified_Ideograph", "Ideographic"},
    22560: {"Unified_Ideograph", "Ideographic"},
    22561: {"Unified_Ideograph", "Ideographic"},
    22562: {"Unified_Ideograph", "Ideographic"},
    22563: {"Unified_Ideograph", "Ideographic"},
    22564: {"Unified_Ideograph", "Ideographic"},
    22565: {"Unified_Ideograph", "Ideographic"},
    22566: {"Unified_Ideograph", "Ideographic"},
    22567: {"Unified_Ideograph", "Ideographic"},
    22568: {"Unified_Ideograph", "Ideographic"},
    22569: {"Unified_Ideograph", "Ideographic"},
    22570: {"Unified_Ideograph", "Ideographic"},
    22571: {"Unified_Ideograph", "Ideographic"},
    22572: {"Unified_Ideograph", "Ideographic"},
    22573: {"Unified_Ideograph", "Ideographic"},
    22574: {"Unified_Ideograph", "Ideographic"},
    22575: {"Unified_Ideograph", "Ideographic"},
    22576: {"Unified_Ideograph", "Ideographic"},
    22577: {"Unified_Ideograph", "Ideographic"},
    22578: {"Unified_Ideograph", "Ideographic"},
    22579: {"Unified_Ideograph", "Ideographic"},
    22580: {"Unified_Ideograph", "Ideographic"},
    22581: {"Unified_Ideograph", "Ideographic"},
    22582: {"Unified_Ideograph", "Ideographic"},
    22583: {"Unified_Ideograph", "Ideographic"},
    22584: {"Unified_Ideograph", "Ideographic"},
    22585: {"Unified_Ideograph", "Ideographic"},
    22586: {"Unified_Ideograph", "Ideographic"},
    22587: {"Unified_Ideograph", "Ideographic"},
    22588: {"Unified_Ideograph", "Ideographic"},
    22589: {"Unified_Ideograph", "Ideographic"},
    22590: {"Unified_Ideograph", "Ideographic"},
    22591: {"Unified_Ideograph", "Ideographic"},
    22592: {"Unified_Ideograph", "Ideographic"},
    22593: {"Unified_Ideograph", "Ideographic"},
    22594: {"Unified_Ideograph", "Ideographic"},
    22595: {"Unified_Ideograph", "Ideographic"},
    22596: {"Unified_Ideograph", "Ideographic"},
    22597: {"Unified_Ideograph", "Ideographic"},
    22598: {"Unified_Ideograph", "Ideographic"},
    22599: {"Unified_Ideograph", "Ideographic"},
    22600: {"Unified_Ideograph", "Ideographic"},
    22601: {"Unified_Ideograph", "Ideographic"},
    22602: {"Unified_Ideograph", "Ideographic"},
    22603: {"Unified_Ideograph", "Ideographic"},
    22604: {"Unified_Ideograph", "Ideographic"},
    22605: {"Unified_Ideograph", "Ideographic"},
    22606: {"Unified_Ideograph", "Ideographic"},
    22607: {"Unified_Ideograph", "Ideographic"},
    22608: {"Unified_Ideograph", "Ideographic"},
    22609: {"Unified_Ideograph", "Ideographic"},
    22610: {"Unified_Ideograph", "Ideographic"},
    22611: {"Unified_Ideograph", "Ideographic"},
    22612: {"Unified_Ideograph", "Ideographic"},
    22613: {"Unified_Ideograph", "Ideographic"},
    22614: {"Unified_Ideograph", "Ideographic"},
    22615: {"Unified_Ideograph", "Ideographic"},
    22616: {"Unified_Ideograph", "Ideographic"},
    22617: {"Unified_Ideograph", "Ideographic"},
    22618: {"Unified_Ideograph", "Ideographic"},
    22619: {"Unified_Ideograph", "Ideographic"},
    22620: {"Unified_Ideograph", "Ideographic"},
    22621: {"Unified_Ideograph", "Ideographic"},
    22622: {"Unified_Ideograph", "Ideographic"},
    22623: {"Unified_Ideograph", "Ideographic"},
    22624: {"Unified_Ideograph", "Ideographic"},
    22625: {"Unified_Ideograph", "Ideographic"},
    22626: {"Unified_Ideograph", "Ideographic"},
    22627: {"Unified_Ideograph", "Ideographic"},
    22628: {"Unified_Ideograph", "Ideographic"},
    22629: {"Unified_Ideograph", "Ideographic"},
    22630: {"Unified_Ideograph", "Ideographic"},
    22631: {"Unified_Ideograph", "Ideographic"},
    22632: {"Unified_Ideograph", "Ideographic"},
    22633: {"Unified_Ideograph", "Ideographic"},
    22634: {"Unified_Ideograph", "Ideographic"},
    22635: {"Unified_Ideograph", "Ideographic"},
    22636: {"Unified_Ideograph", "Ideographic"},
    22637: {"Unified_Ideograph", "Ideographic"},
    22638: {"Unified_Ideograph", "Ideographic"},
    22639: {"Unified_Ideograph", "Ideographic"},
    22640: {"Unified_Ideograph", "Ideographic"},
    22641: {"Unified_Ideograph", "Ideographic"},
    22642: {"Unified_Ideograph", "Ideographic"},
    22643: {"Unified_Ideograph", "Ideographic"},
    22644: {"Unified_Ideograph", "Ideographic"},
    22645: {"Unified_Ideograph", "Ideographic"},
    22646: {"Unified_Ideograph", "Ideographic"},
    22647: {"Unified_Ideograph", "Ideographic"},
    22648: {"Unified_Ideograph", "Ideographic"},
    22649: {"Unified_Ideograph", "Ideographic"},
    22650: {"Unified_Ideograph", "Ideographic"},
    22651: {"Unified_Ideograph", "Ideographic"},
    22652: {"Unified_Ideograph", "Ideographic"},
    22653: {"Unified_Ideograph", "Ideographic"},
    22654: {"Unified_Ideograph", "Ideographic"},
    22655: {"Unified_Ideograph", "Ideographic"},
    22656: {"Unified_Ideograph", "Ideographic"},
    22657: {"Unified_Ideograph", "Ideographic"},
    22658: {"Unified_Ideograph", "Ideographic"},
    22659: {"Unified_Ideograph", "Ideographic"},
    22660: {"Unified_Ideograph", "Ideographic"},
    22661: {"Unified_Ideograph", "Ideographic"},
    22662: {"Unified_Ideograph", "Ideographic"},
    22663: {"Unified_Ideograph", "Ideographic"},
    22664: {"Unified_Ideograph", "Ideographic"},
    22665: {"Unified_Ideograph", "Ideographic"},
    22666: {"Unified_Ideograph", "Ideographic"},
    22667: {"Unified_Ideograph", "Ideographic"},
    22668: {"Unified_Ideograph", "Ideographic"},
    22669: {"Unified_Ideograph", "Ideographic"},
    22670: {"Unified_Ideograph", "Ideographic"},
    22671: {"Unified_Ideograph", "Ideographic"},
    22672: {"Unified_Ideograph", "Ideographic"},
    22673: {"Unified_Ideograph", "Ideographic"},
    22674: {"Unified_Ideograph", "Ideographic"},
    22675: {"Unified_Ideograph", "Ideographic"},
    22676: {"Unified_Ideograph", "Ideographic"},
    22677: {"Unified_Ideograph", "Ideographic"},
    22678: {"Unified_Ideograph", "Ideographic"},
    22679: {"Unified_Ideograph", "Ideographic"},
    22680: {"Unified_Ideograph", "Ideographic"},
    22681: {"Unified_Ideograph", "Ideographic"},
    22682: {"Unified_Ideograph", "Ideographic"},
    22683: {"Unified_Ideograph", "Ideographic"},
    22684: {"Unified_Ideograph", "Ideographic"},
    22685: {"Unified_Ideograph", "Ideographic"},
    22686: {"Unified_Ideograph", "Ideographic"},
    22687: {"Unified_Ideograph", "Ideographic"},
    22688: {"Unified_Ideograph", "Ideographic"},
    22689: {"Unified_Ideograph", "Ideographic"},
    22690: {"Unified_Ideograph", "Ideographic"},
    22691: {"Unified_Ideograph", "Ideographic"},
    22692: {"Unified_Ideograph", "Ideographic"},
    22693: {"Unified_Ideograph", "Ideographic"},
    22694: {"Unified_Ideograph", "Ideographic"},
    22695: {"Unified_Ideograph", "Ideographic"},
    22696: {"Unified_Ideograph", "Ideographic"},
    22697: {"Unified_Ideograph", "Ideographic"},
    22698: {"Unified_Ideograph", "Ideographic"},
    22699: {"Unified_Ideograph", "Ideographic"},
    22700: {"Unified_Ideograph", "Ideographic"},
    22701: {"Unified_Ideograph", "Ideographic"},
    22702: {"Unified_Ideograph", "Ideographic"},
    22703: {"Unified_Ideograph", "Ideographic"},
    22704: {"Unified_Ideograph", "Ideographic"},
    22705: {"Unified_Ideograph", "Ideographic"},
    22706: {"Unified_Ideograph", "Ideographic"},
    22707: {"Unified_Ideograph", "Ideographic"},
    22708: {"Unified_Ideograph", "Ideographic"},
    22709: {"Unified_Ideograph", "Ideographic"},
    22710: {"Unified_Ideograph", "Ideographic"},
    22711: {"Unified_Ideograph", "Ideographic"},
    22712: {"Unified_Ideograph", "Ideographic"},
    22713: {"Unified_Ideograph", "Ideographic"},
    22714: {"Unified_Ideograph", "Ideographic"},
    22715: {"Unified_Ideograph", "Ideographic"},
    22716: {"Unified_Ideograph", "Ideographic"},
    22717: {"Unified_Ideograph", "Ideographic"},
    22718: {"Unified_Ideograph", "Ideographic"},
    22719: {"Unified_Ideograph", "Ideographic"},
    22720: {"Unified_Ideograph", "Ideographic"},
    22721: {"Unified_Ideograph", "Ideographic"},
    22722: {"Unified_Ideograph", "Ideographic"},
    22723: {"Unified_Ideograph", "Ideographic"},
    22724: {"Unified_Ideograph", "Ideographic"},
    22725: {"Unified_Ideograph", "Ideographic"},
    22726: {"Unified_Ideograph", "Ideographic"},
    22727: {"Unified_Ideograph", "Ideographic"},
    22728: {"Unified_Ideograph", "Ideographic"},
    22729: {"Unified_Ideograph", "Ideographic"},
    22730: {"Unified_Ideograph", "Ideographic"},
    22731: {"Unified_Ideograph", "Ideographic"},
    22732: {"Unified_Ideograph", "Ideographic"},
    22733: {"Unified_Ideograph", "Ideographic"},
    22734: {"Unified_Ideograph", "Ideographic"},
    22735: {"Unified_Ideograph", "Ideographic"},
    22736: {"Unified_Ideograph", "Ideographic"},
    22737: {"Unified_Ideograph", "Ideographic"},
    22738: {"Unified_Ideograph", "Ideographic"},
    22739: {"Unified_Ideograph", "Ideographic"},
    22740: {"Unified_Ideograph", "Ideographic"},
    22741: {"Unified_Ideograph", "Ideographic"},
    22742: {"Unified_Ideograph", "Ideographic"},
    22743: {"Unified_Ideograph", "Ideographic"},
    22744: {"Unified_Ideograph", "Ideographic"},
    22745: {"Unified_Ideograph", "Ideographic"},
    22746: {"Unified_Ideograph", "Ideographic"},
    22747: {"Unified_Ideograph", "Ideographic"},
    22748: {"Unified_Ideograph", "Ideographic"},
    22749: {"Unified_Ideograph", "Ideographic"},
    22750: {"Unified_Ideograph", "Ideographic"},
    22751: {"Unified_Ideograph", "Ideographic"},
    22752: {"Unified_Ideograph", "Ideographic"},
    22753: {"Unified_Ideograph", "Ideographic"},
    22754: {"Unified_Ideograph", "Ideographic"},
    22755: {"Unified_Ideograph", "Ideographic"},
    22756: {"Unified_Ideograph", "Ideographic"},
    22757: {"Unified_Ideograph", "Ideographic"},
    22758: {"Unified_Ideograph", "Ideographic"},
    22759: {"Unified_Ideograph", "Ideographic"},
    22760: {"Unified_Ideograph", "Ideographic"},
    22761: {"Unified_Ideograph", "Ideographic"},
    22762: {"Unified_Ideograph", "Ideographic"},
    22763: {"Unified_Ideograph", "Ideographic"},
    22764: {"Unified_Ideograph", "Ideographic"},
    22765: {"Unified_Ideograph", "Ideographic"},
    22766: {"Unified_Ideograph", "Ideographic"},
    22767: {"Unified_Ideograph", "Ideographic"},
    22768: {"Unified_Ideograph", "Ideographic"},
    22769: {"Unified_Ideograph", "Ideographic"},
    22770: {"Unified_Ideograph", "Ideographic"},
    22771: {"Unified_Ideograph", "Ideographic"},
    22772: {"Unified_Ideograph", "Ideographic"},
    22773: {"Unified_Ideograph", "Ideographic"},
    22774: {"Unified_Ideograph", "Ideographic"},
    22775: {"Unified_Ideograph", "Ideographic"},
    22776: {"Unified_Ideograph", "Ideographic"},
    22777: {"Unified_Ideograph", "Ideographic"},
    22778: {"Unified_Ideograph", "Ideographic"},
    22779: {"Unified_Ideograph", "Ideographic"},
    22780: {"Unified_Ideograph", "Ideographic"},
    22781: {"Unified_Ideograph", "Ideographic"},
    22782: {"Unified_Ideograph", "Ideographic"},
    22783: {"Unified_Ideograph", "Ideographic"},
    22784: {"Unified_Ideograph", "Ideographic"},
    22785: {"Unified_Ideograph", "Ideographic"},
    22786: {"Unified_Ideograph", "Ideographic"},
    22787: {"Unified_Ideograph", "Ideographic"},
    22788: {"Unified_Ideograph", "Ideographic"},
    22789: {"Unified_Ideograph", "Ideographic"},
    22790: {"Unified_Ideograph", "Ideographic"},
    22791: {"Unified_Ideograph", "Ideographic"},
    22792: {"Unified_Ideograph", "Ideographic"},
    22793: {"Unified_Ideograph", "Ideographic"},
    22794: {"Unified_Ideograph", "Ideographic"},
    22795: {"Unified_Ideograph", "Ideographic"},
    22796: {"Unified_Ideograph", "Ideographic"},
    22797: {"Unified_Ideograph", "Ideographic"},
    22798: {"Unified_Ideograph", "Ideographic"},
    22799: {"Unified_Ideograph", "Ideographic"},
    22800: {"Unified_Ideograph", "Ideographic"},
    22801: {"Unified_Ideograph", "Ideographic"},
    22802: {"Unified_Ideograph", "Ideographic"},
    22803: {"Unified_Ideograph", "Ideographic"},
    22804: {"Unified_Ideograph", "Ideographic"},
    22805: {"Unified_Ideograph", "Ideographic"},
    22806: {"Unified_Ideograph", "Ideographic"},
    22807: {"Unified_Ideograph", "Ideographic"},
    22808: {"Unified_Ideograph", "Ideographic"},
    22809: {"Unified_Ideograph", "Ideographic"},
    22810: {"Unified_Ideograph", "Ideographic"},
    22811: {"Unified_Ideograph", "Ideographic"},
    22812: {"Unified_Ideograph", "Ideographic"},
    22813: {"Unified_Ideograph", "Ideographic"},
    22814: {"Unified_Ideograph", "Ideographic"},
    22815: {"Unified_Ideograph", "Ideographic"},
    22816: {"Unified_Ideograph", "Ideographic"},
    22817: {"Unified_Ideograph", "Ideographic"},
    22818: {"Unified_Ideograph", "Ideographic"},
    22819: {"Unified_Ideograph", "Ideographic"},
    22820: {"Unified_Ideograph", "Ideographic"},
    22821: {"Unified_Ideograph", "Ideographic"},
    22822: {"Unified_Ideograph", "Ideographic"},
    22823: {"Unified_Ideograph", "Ideographic"},
    22824: {"Unified_Ideograph", "Ideographic"},
    22825: {"Unified_Ideograph", "Ideographic"},
    22826: {"Unified_Ideograph", "Ideographic"},
    22827: {"Unified_Ideograph", "Ideographic"},
    22828: {"Unified_Ideograph", "Ideographic"},
    22829: {"Unified_Ideograph", "Ideographic"},
    22830: {"Unified_Ideograph", "Ideographic"},
    22831: {"Unified_Ideograph", "Ideographic"},
    22832: {"Unified_Ideograph", "Ideographic"},
    22833: {"Unified_Ideograph", "Ideographic"},
    22834: {"Unified_Ideograph", "Ideographic"},
    22835: {"Unified_Ideograph", "Ideographic"},
    22836: {"Unified_Ideograph", "Ideographic"},
    22837: {"Unified_Ideograph", "Ideographic"},
    22838: {"Unified_Ideograph", "Ideographic"},
    22839: {"Unified_Ideograph", "Ideographic"},
    22840: {"Unified_Ideograph", "Ideographic"},
    22841: {"Unified_Ideograph", "Ideographic"},
    22842: {"Unified_Ideograph", "Ideographic"},
    22843: {"Unified_Ideograph", "Ideographic"},
    22844: {"Unified_Ideograph", "Ideographic"},
    22845: {"Unified_Ideograph", "Ideographic"},
    22846: {"Unified_Ideograph", "Ideographic"},
    22847: {"Unified_Ideograph", "Ideographic"},
    22848: {"Unified_Ideograph", "Ideographic"},
    22849: {"Unified_Ideograph", "Ideographic"},
    22850: {"Unified_Ideograph", "Ideographic"},
    22851: {"Unified_Ideograph", "Ideographic"},
    22852: {"Unified_Ideograph", "Ideographic"},
    22853: {"Unified_Ideograph", "Ideographic"},
    22854: {"Unified_Ideograph", "Ideographic"},
    22855: {"Unified_Ideograph", "Ideographic"},
    22856: {"Unified_Ideograph", "Ideographic"},
    22857: {"Unified_Ideograph", "Ideographic"},
    22858: {"Unified_Ideograph", "Ideographic"},
    22859: {"Unified_Ideograph", "Ideographic"},
    22860: {"Unified_Ideograph", "Ideographic"},
    22861: {"Unified_Ideograph", "Ideographic"},
    22862: {"Unified_Ideograph", "Ideographic"},
    22863: {"Unified_Ideograph", "Ideographic"},
    22864: {"Unified_Ideograph", "Ideographic"},
    22865: {"Unified_Ideograph", "Ideographic"},
    22866: {"Unified_Ideograph", "Ideographic"},
    22867: {"Unified_Ideograph", "Ideographic"},
    22868: {"Unified_Ideograph", "Ideographic"},
    22869: {"Unified_Ideograph", "Ideographic"},
    22870: {"Unified_Ideograph", "Ideographic"},
    22871: {"Unified_Ideograph", "Ideographic"},
    22872: {"Unified_Ideograph", "Ideographic"},
    22873: {"Unified_Ideograph", "Ideographic"},
    22874: {"Unified_Ideograph", "Ideographic"},
    22875: {"Unified_Ideograph", "Ideographic"},
    22876: {"Unified_Ideograph", "Ideographic"},
    22877: {"Unified_Ideograph", "Ideographic"},
    22878: {"Unified_Ideograph", "Ideographic"},
    22879: {"Unified_Ideograph", "Ideographic"},
    22880: {"Unified_Ideograph", "Ideographic"},
    22881: {"Unified_Ideograph", "Ideographic"},
    22882: {"Unified_Ideograph", "Ideographic"},
    22883: {"Unified_Ideograph", "Ideographic"},
    22884: {"Unified_Ideograph", "Ideographic"},
    22885: {"Unified_Ideograph", "Ideographic"},
    22886: {"Unified_Ideograph", "Ideographic"},
    22887: {"Unified_Ideograph", "Ideographic"},
    22888: {"Unified_Ideograph", "Ideographic"},
    22889: {"Unified_Ideograph", "Ideographic"},
    22890: {"Unified_Ideograph", "Ideographic"},
    22891: {"Unified_Ideograph", "Ideographic"},
    22892: {"Unified_Ideograph", "Ideographic"},
    22893: {"Unified_Ideograph", "Ideographic"},
    22894: {"Unified_Ideograph", "Ideographic"},
    22895: {"Unified_Ideograph", "Ideographic"},
    22896: {"Unified_Ideograph", "Ideographic"},
    22897: {"Unified_Ideograph", "Ideographic"},
    22898: {"Unified_Ideograph", "Ideographic"},
    22899: {"Unified_Ideograph", "Ideographic"},
    22900: {"Unified_Ideograph", "Ideographic"},
    22901: {"Unified_Ideograph", "Ideographic"},
    22902: {"Unified_Ideograph", "Ideographic"},
    22903: {"Unified_Ideograph", "Ideographic"},
    22904: {"Unified_Ideograph", "Ideographic"},
    22905: {"Unified_Ideograph", "Ideographic"},
    22906: {"Unified_Ideograph", "Ideographic"},
    22907: {"Unified_Ideograph", "Ideographic"},
    22908: {"Unified_Ideograph", "Ideographic"},
    22909: {"Unified_Ideograph", "Ideographic"},
    22910: {"Unified_Ideograph", "Ideographic"},
    22911: {"Unified_Ideograph", "Ideographic"},
    22912: {"Unified_Ideograph", "Ideographic"},
    22913: {"Unified_Ideograph", "Ideographic"},
    22914: {"Unified_Ideograph", "Ideographic"},
    22915: {"Unified_Ideograph", "Ideographic"},
    22916: {"Unified_Ideograph", "Ideographic"},
    22917: {"Unified_Ideograph", "Ideographic"},
    22918: {"Unified_Ideograph", "Ideographic"},
    22919: {"Unified_Ideograph", "Ideographic"},
    22920: {"Unified_Ideograph", "Ideographic"},
    22921: {"Unified_Ideograph", "Ideographic"},
    22922: {"Unified_Ideograph", "Ideographic"},
    22923: {"Unified_Ideograph", "Ideographic"},
    22924: {"Unified_Ideograph", "Ideographic"},
    22925: {"Unified_Ideograph", "Ideographic"},
    22926: {"Unified_Ideograph", "Ideographic"},
    22927: {"Unified_Ideograph", "Ideographic"},
    22928: {"Unified_Ideograph", "Ideographic"},
    22929: {"Unified_Ideograph", "Ideographic"},
    22930: {"Unified_Ideograph", "Ideographic"},
    22931: {"Unified_Ideograph", "Ideographic"},
    22932: {"Unified_Ideograph", "Ideographic"},
    22933: {"Unified_Ideograph", "Ideographic"},
    22934: {"Unified_Ideograph", "Ideographic"},
    22935: {"Unified_Ideograph", "Ideographic"},
    22936: {"Unified_Ideograph", "Ideographic"},
    22937: {"Unified_Ideograph", "Ideographic"},
    22938: {"Unified_Ideograph", "Ideographic"},
    22939: {"Unified_Ideograph", "Ideographic"},
    22940: {"Unified_Ideograph", "Ideographic"},
    22941: {"Unified_Ideograph", "Ideographic"},
    22942: {"Unified_Ideograph", "Ideographic"},
    22943: {"Unified_Ideograph", "Ideographic"},
    22944: {"Unified_Ideograph", "Ideographic"},
    22945: {"Unified_Ideograph", "Ideographic"},
    22946: {"Unified_Ideograph", "Ideographic"},
    22947: {"Unified_Ideograph", "Ideographic"},
    22948: {"Unified_Ideograph", "Ideographic"},
    22949: {"Unified_Ideograph", "Ideographic"},
    22950: {"Unified_Ideograph", "Ideographic"},
    22951: {"Unified_Ideograph", "Ideographic"},
    22952: {"Unified_Ideograph", "Ideographic"},
    22953: {"Unified_Ideograph", "Ideographic"},
    22954: {"Unified_Ideograph", "Ideographic"},
    22955: {"Unified_Ideograph", "Ideographic"},
    22956: {"Unified_Ideograph", "Ideographic"},
    22957: {"Unified_Ideograph", "Ideographic"},
    22958: {"Unified_Ideograph", "Ideographic"},
    22959: {"Unified_Ideograph", "Ideographic"},
    22960: {"Unified_Ideograph", "Ideographic"},
    22961: {"Unified_Ideograph", "Ideographic"},
    22962: {"Unified_Ideograph", "Ideographic"},
    22963: {"Unified_Ideograph", "Ideographic"},
    22964: {"Unified_Ideograph", "Ideographic"},
    22965: {"Unified_Ideograph", "Ideographic"},
    22966: {"Unified_Ideograph", "Ideographic"},
    22967: {"Unified_Ideograph", "Ideographic"},
    22968: {"Unified_Ideograph", "Ideographic"},
    22969: {"Unified_Ideograph", "Ideographic"},
    22970: {"Unified_Ideograph", "Ideographic"},
    22971: {"Unified_Ideograph", "Ideographic"},
    22972: {"Unified_Ideograph", "Ideographic"},
    22973: {"Unified_Ideograph", "Ideographic"},
    22974: {"Unified_Ideograph", "Ideographic"},
    22975: {"Unified_Ideograph", "Ideographic"},
    22976: {"Unified_Ideograph", "Ideographic"},
    22977: {"Unified_Ideograph", "Ideographic"},
    22978: {"Unified_Ideograph", "Ideographic"},
    22979: {"Unified_Ideograph", "Ideographic"},
    22980: {"Unified_Ideograph", "Ideographic"},
    22981: {"Unified_Ideograph", "Ideographic"},
    22982: {"Unified_Ideograph", "Ideographic"},
    22983: {"Unified_Ideograph", "Ideographic"},
    22984: {"Unified_Ideograph", "Ideographic"},
    22985: {"Unified_Ideograph", "Ideographic"},
    22986: {"Unified_Ideograph", "Ideographic"},
    22987: {"Unified_Ideograph", "Ideographic"},
    22988: {"Unified_Ideograph", "Ideographic"},
    22989: {"Unified_Ideograph", "Ideographic"},
    22990: {"Unified_Ideograph", "Ideographic"},
    22991: {"Unified_Ideograph", "Ideographic"},
    22992: {"Unified_Ideograph", "Ideographic"},
    22993: {"Unified_Ideograph", "Ideographic"},
    22994: {"Unified_Ideograph", "Ideographic"},
    22995: {"Unified_Ideograph", "Ideographic"},
    22996: {"Unified_Ideograph", "Ideographic"},
    22997: {"Unified_Ideograph", "Ideographic"},
    22998: {"Unified_Ideograph", "Ideographic"},
    22999: {"Unified_Ideograph", "Ideographic"},
    23000: {"Unified_Ideograph", "Ideographic"},
    23001: {"Unified_Ideograph", "Ideographic"},
    23002: {"Unified_Ideograph", "Ideographic"},
    23003: {"Unified_Ideograph", "Ideographic"},
    23004: {"Unified_Ideograph", "Ideographic"},
    23005: {"Unified_Ideograph", "Ideographic"},
    23006: {"Unified_Ideograph", "Ideographic"},
    23007: {"Unified_Ideograph", "Ideographic"},
    23008: {"Unified_Ideograph", "Ideographic"},
    23009: {"Unified_Ideograph", "Ideographic"},
    23010: {"Unified_Ideograph", "Ideographic"},
    23011: {"Unified_Ideograph", "Ideographic"},
    23012: {"Unified_Ideograph", "Ideographic"},
    23013: {"Unified_Ideograph", "Ideographic"},
    23014: {"Unified_Ideograph", "Ideographic"},
    23015: {"Unified_Ideograph", "Ideographic"},
    23016: {"Unified_Ideograph", "Ideographic"},
    23017: {"Unified_Ideograph", "Ideographic"},
    23018: {"Unified_Ideograph", "Ideographic"},
    23019: {"Unified_Ideograph", "Ideographic"},
    23020: {"Unified_Ideograph", "Ideographic"},
    23021: {"Unified_Ideograph", "Ideographic"},
    23022: {"Unified_Ideograph", "Ideographic"},
    23023: {"Unified_Ideograph", "Ideographic"},
    23024: {"Unified_Ideograph", "Ideographic"},
    23025: {"Unified_Ideograph", "Ideographic"},
    23026: {"Unified_Ideograph", "Ideographic"},
    23027: {"Unified_Ideograph", "Ideographic"},
    23028: {"Unified_Ideograph", "Ideographic"},
    23029: {"Unified_Ideograph", "Ideographic"},
    23030: {"Unified_Ideograph", "Ideographic"},
    23031: {"Unified_Ideograph", "Ideographic"},
    23032: {"Unified_Ideograph", "Ideographic"},
    23033: {"Unified_Ideograph", "Ideographic"},
    23034: {"Unified_Ideograph", "Ideographic"},
    23035: {"Unified_Ideograph", "Ideographic"},
    23036: {"Unified_Ideograph", "Ideographic"},
    23037: {"Unified_Ideograph", "Ideographic"},
    23038: {"Unified_Ideograph", "Ideographic"},
    23039: {"Unified_Ideograph", "Ideographic"},
    23040: {"Unified_Ideograph", "Ideographic"},
    23041: {"Unified_Ideograph", "Ideographic"},
    23042: {"Unified_Ideograph", "Ideographic"},
    23043: {"Unified_Ideograph", "Ideographic"},
    23044: {"Unified_Ideograph", "Ideographic"},
    23045: {"Unified_Ideograph", "Ideographic"},
    23046: {"Unified_Ideograph", "Ideographic"},
    23047: {"Unified_Ideograph", "Ideographic"},
    23048: {"Unified_Ideograph", "Ideographic"},
    23049: {"Unified_Ideograph", "Ideographic"},
    23050: {"Unified_Ideograph", "Ideographic"},
    23051: {"Unified_Ideograph", "Ideographic"},
    23052: {"Unified_Ideograph", "Ideographic"},
    23053: {"Unified_Ideograph", "Ideographic"},
    23054: {"Unified_Ideograph", "Ideographic"},
    23055: {"Unified_Ideograph", "Ideographic"},
    23056: {"Unified_Ideograph", "Ideographic"},
    23057: {"Unified_Ideograph", "Ideographic"},
    23058: {"Unified_Ideograph", "Ideographic"},
    23059: {"Unified_Ideograph", "Ideographic"},
    23060: {"Unified_Ideograph", "Ideographic"},
    23061: {"Unified_Ideograph", "Ideographic"},
    23062: {"Unified_Ideograph", "Ideographic"},
    23063: {"Unified_Ideograph", "Ideographic"},
    23064: {"Unified_Ideograph", "Ideographic"},
    23065: {"Unified_Ideograph", "Ideographic"},
    23066: {"Unified_Ideograph", "Ideographic"},
    23067: {"Unified_Ideograph", "Ideographic"},
    23068: {"Unified_Ideograph", "Ideographic"},
    23069: {"Unified_Ideograph", "Ideographic"},
    23070: {"Unified_Ideograph", "Ideographic"},
    23071: {"Unified_Ideograph", "Ideographic"},
    23072: {"Unified_Ideograph", "Ideographic"},
    23073: {"Unified_Ideograph", "Ideographic"},
    23074: {"Unified_Ideograph", "Ideographic"},
    23075: {"Unified_Ideograph", "Ideographic"},
    23076: {"Unified_Ideograph", "Ideographic"},
    23077: {"Unified_Ideograph", "Ideographic"},
    23078: {"Unified_Ideograph", "Ideographic"},
    23079: {"Unified_Ideograph", "Ideographic"},
    23080: {"Unified_Ideograph", "Ideographic"},
    23081: {"Unified_Ideograph", "Ideographic"},
    23082: {"Unified_Ideograph", "Ideographic"},
    23083: {"Unified_Ideograph", "Ideographic"},
    23084: {"Unified_Ideograph", "Ideographic"},
    23085: {"Unified_Ideograph", "Ideographic"},
    23086: {"Unified_Ideograph", "Ideographic"},
    23087: {"Unified_Ideograph", "Ideographic"},
    23088: {"Unified_Ideograph", "Ideographic"},
    23089: {"Unified_Ideograph", "Ideographic"},
    23090: {"Unified_Ideograph", "Ideographic"},
    23091: {"Unified_Ideograph", "Ideographic"},
    23092: {"Unified_Ideograph", "Ideographic"},
    23093: {"Unified_Ideograph", "Ideographic"},
    23094: {"Unified_Ideograph", "Ideographic"},
    23095: {"Unified_Ideograph", "Ideographic"},
    23096: {"Unified_Ideograph", "Ideographic"},
    23097: {"Unified_Ideograph", "Ideographic"},
    23098: {"Unified_Ideograph", "Ideographic"},
    23099: {"Unified_Ideograph", "Ideographic"},
    23100: {"Unified_Ideograph", "Ideographic"},
    23101: {"Unified_Ideograph", "Ideographic"},
    23102: {"Unified_Ideograph", "Ideographic"},
    23103: {"Unified_Ideograph", "Ideographic"},
    23104: {"Unified_Ideograph", "Ideographic"},
    23105: {"Unified_Ideograph", "Ideographic"},
    23106: {"Unified_Ideograph", "Ideographic"},
    23107: {"Unified_Ideograph", "Ideographic"},
    23108: {"Unified_Ideograph", "Ideographic"},
    23109: {"Unified_Ideograph", "Ideographic"},
    23110: {"Unified_Ideograph", "Ideographic"},
    23111: {"Unified_Ideograph", "Ideographic"},
    23112: {"Unified_Ideograph", "Ideographic"},
    23113: {"Unified_Ideograph", "Ideographic"},
    23114: {"Unified_Ideograph", "Ideographic"},
    23115: {"Unified_Ideograph", "Ideographic"},
    23116: {"Unified_Ideograph", "Ideographic"},
    23117: {"Unified_Ideograph", "Ideographic"},
    23118: {"Unified_Ideograph", "Ideographic"},
    23119: {"Unified_Ideograph", "Ideographic"},
    23120: {"Unified_Ideograph", "Ideographic"},
    23121: {"Unified_Ideograph", "Ideographic"},
    23122: {"Unified_Ideograph", "Ideographic"},
    23123: {"Unified_Ideograph", "Ideographic"},
    23124: {"Unified_Ideograph", "Ideographic"},
    23125: {"Unified_Ideograph", "Ideographic"},
    23126: {"Unified_Ideograph", "Ideographic"},
    23127: {"Unified_Ideograph", "Ideographic"},
    23128: {"Unified_Ideograph", "Ideographic"},
    23129: {"Unified_Ideograph", "Ideographic"},
    23130: {"Unified_Ideograph", "Ideographic"},
    23131: {"Unified_Ideograph", "Ideographic"},
    23132: {"Unified_Ideograph", "Ideographic"},
    23133: {"Unified_Ideograph", "Ideographic"},
    23134: {"Unified_Ideograph", "Ideographic"},
    23135: {"Unified_Ideograph", "Ideographic"},
    23136: {"Unified_Ideograph", "Ideographic"},
    23137: {"Unified_Ideograph", "Ideographic"},
    23138: {"Unified_Ideograph", "Ideographic"},
    23139: {"Unified_Ideograph", "Ideographic"},
    23140: {"Unified_Ideograph", "Ideographic"},
    23141: {"Unified_Ideograph", "Ideographic"},
    23142: {"Unified_Ideograph", "Ideographic"},
    23143: {"Unified_Ideograph", "Ideographic"},
    23144: {"Unified_Ideograph", "Ideographic"},
    23145: {"Unified_Ideograph", "Ideographic"},
    23146: {"Unified_Ideograph", "Ideographic"},
    23147: {"Unified_Ideograph", "Ideographic"},
    23148: {"Unified_Ideograph", "Ideographic"},
    23149: {"Unified_Ideograph", "Ideographic"},
    23150: {"Unified_Ideograph", "Ideographic"},
    23151: {"Unified_Ideograph", "Ideographic"},
    23152: {"Unified_Ideograph", "Ideographic"},
    23153: {"Unified_Ideograph", "Ideographic"},
    23154: {"Unified_Ideograph", "Ideographic"},
    23155: {"Unified_Ideograph", "Ideographic"},
    23156: {"Unified_Ideograph", "Ideographic"},
    23157: {"Unified_Ideograph", "Ideographic"},
    23158: {"Unified_Ideograph", "Ideographic"},
    23159: {"Unified_Ideograph", "Ideographic"},
    23160: {"Unified_Ideograph", "Ideographic"},
    23161: {"Unified_Ideograph", "Ideographic"},
    23162: {"Unified_Ideograph", "Ideographic"},
    23163: {"Unified_Ideograph", "Ideographic"},
    23164: {"Unified_Ideograph", "Ideographic"},
    23165: {"Unified_Ideograph", "Ideographic"},
    23166: {"Unified_Ideograph", "Ideographic"},
    23167: {"Unified_Ideograph", "Ideographic"},
    23168: {"Unified_Ideograph", "Ideographic"},
    23169: {"Unified_Ideograph", "Ideographic"},
    23170: {"Unified_Ideograph", "Ideographic"},
    23171: {"Unified_Ideograph", "Ideographic"},
    23172: {"Unified_Ideograph", "Ideographic"},
    23173: {"Unified_Ideograph", "Ideographic"},
    23174: {"Unified_Ideograph", "Ideographic"},
    23175: {"Unified_Ideograph", "Ideographic"},
    23176: {"Unified_Ideograph", "Ideographic"},
    23177: {"Unified_Ideograph", "Ideographic"},
    23178: {"Unified_Ideograph", "Ideographic"},
    23179: {"Unified_Ideograph", "Ideographic"},
    23180: {"Unified_Ideograph", "Ideographic"},
    23181: {"Unified_Ideograph", "Ideographic"},
    23182: {"Unified_Ideograph", "Ideographic"},
    23183: {"Unified_Ideograph", "Ideographic"},
    23184: {"Unified_Ideograph", "Ideographic"},
    23185: {"Unified_Ideograph", "Ideographic"},
    23186: {"Unified_Ideograph", "Ideographic"},
    23187: {"Unified_Ideograph", "Ideographic"},
    23188: {"Unified_Ideograph", "Ideographic"},
    23189: {"Unified_Ideograph", "Ideographic"},
    23190: {"Unified_Ideograph", "Ideographic"},
    23191: {"Unified_Ideograph", "Ideographic"},
    23192: {"Unified_Ideograph", "Ideographic"},
    23193: {"Unified_Ideograph", "Ideographic"},
    23194: {"Unified_Ideograph", "Ideographic"},
    23195: {"Unified_Ideograph", "Ideographic"},
    23196: {"Unified_Ideograph", "Ideographic"},
    23197: {"Unified_Ideograph", "Ideographic"},
    23198: {"Unified_Ideograph", "Ideographic"},
    23199: {"Unified_Ideograph", "Ideographic"},
    23200: {"Unified_Ideograph", "Ideographic"},
    23201: {"Unified_Ideograph", "Ideographic"},
    23202: {"Unified_Ideograph", "Ideographic"},
    23203: {"Unified_Ideograph", "Ideographic"},
    23204: {"Unified_Ideograph", "Ideographic"},
    23205: {"Unified_Ideograph", "Ideographic"},
    23206: {"Unified_Ideograph", "Ideographic"},
    23207: {"Unified_Ideograph", "Ideographic"},
    23208: {"Unified_Ideograph", "Ideographic"},
    23209: {"Unified_Ideograph", "Ideographic"},
    23210: {"Unified_Ideograph", "Ideographic"},
    23211: {"Unified_Ideograph", "Ideographic"},
    23212: {"Unified_Ideograph", "Ideographic"},
    23213: {"Unified_Ideograph", "Ideographic"},
    23214: {"Unified_Ideograph", "Ideographic"},
    23215: {"Unified_Ideograph", "Ideographic"},
    23216: {"Unified_Ideograph", "Ideographic"},
    23217: {"Unified_Ideograph", "Ideographic"},
    23218: {"Unified_Ideograph", "Ideographic"},
    23219: {"Unified_Ideograph", "Ideographic"},
    23220: {"Unified_Ideograph", "Ideographic"},
    23221: {"Unified_Ideograph", "Ideographic"},
    23222: {"Unified_Ideograph", "Ideographic"},
    23223: {"Unified_Ideograph", "Ideographic"},
    23224: {"Unified_Ideograph", "Ideographic"},
    23225: {"Unified_Ideograph", "Ideographic"},
    23226: {"Unified_Ideograph", "Ideographic"},
    23227: {"Unified_Ideograph", "Ideographic"},
    23228: {"Unified_Ideograph", "Ideographic"},
    23229: {"Unified_Ideograph", "Ideographic"},
    23230: {"Unified_Ideograph", "Ideographic"},
    23231: {"Unified_Ideograph", "Ideographic"},
    23232: {"Unified_Ideograph", "Ideographic"},
    23233: {"Unified_Ideograph", "Ideographic"},
    23234: {"Unified_Ideograph", "Ideographic"},
    23235: {"Unified_Ideograph", "Ideographic"},
    23236: {"Unified_Ideograph", "Ideographic"},
    23237: {"Unified_Ideograph", "Ideographic"},
    23238: {"Unified_Ideograph", "Ideographic"},
    23239: {"Unified_Ideograph", "Ideographic"},
    23240: {"Unified_Ideograph", "Ideographic"},
    23241: {"Unified_Ideograph", "Ideographic"},
    23242: {"Unified_Ideograph", "Ideographic"},
    23243: {"Unified_Ideograph", "Ideographic"},
    23244: {"Unified_Ideograph", "Ideographic"},
    23245: {"Unified_Ideograph", "Ideographic"},
    23246: {"Unified_Ideograph", "Ideographic"},
    23247: {"Unified_Ideograph", "Ideographic"},
    23248: {"Unified_Ideograph", "Ideographic"},
    23249: {"Unified_Ideograph", "Ideographic"},
    23250: {"Unified_Ideograph", "Ideographic"},
    23251: {"Unified_Ideograph", "Ideographic"},
    23252: {"Unified_Ideograph", "Ideographic"},
    23253: {"Unified_Ideograph", "Ideographic"},
    23254: {"Unified_Ideograph", "Ideographic"},
    23255: {"Unified_Ideograph", "Ideographic"},
    23256: {"Unified_Ideograph", "Ideographic"},
    23257: {"Unified_Ideograph", "Ideographic"},
    23258: {"Unified_Ideograph", "Ideographic"},
    23259: {"Unified_Ideograph", "Ideographic"},
    23260: {"Unified_Ideograph", "Ideographic"},
    23261: {"Unified_Ideograph", "Ideographic"},
    23262: {"Unified_Ideograph", "Ideographic"},
    23263: {"Unified_Ideograph", "Ideographic"},
    23264: {"Unified_Ideograph", "Ideographic"},
    23265: {"Unified_Ideograph", "Ideographic"},
    23266: {"Unified_Ideograph", "Ideographic"},
    23267: {"Unified_Ideograph", "Ideographic"},
    23268: {"Unified_Ideograph", "Ideographic"},
    23269: {"Unified_Ideograph", "Ideographic"},
    23270: {"Unified_Ideograph", "Ideographic"},
    23271: {"Unified_Ideograph", "Ideographic"},
    23272: {"Unified_Ideograph", "Ideographic"},
    23273: {"Unified_Ideograph", "Ideographic"},
    23274: {"Unified_Ideograph", "Ideographic"},
    23275: {"Unified_Ideograph", "Ideographic"},
    23276: {"Unified_Ideograph", "Ideographic"},
    23277: {"Unified_Ideograph", "Ideographic"},
    23278: {"Unified_Ideograph", "Ideographic"},
    23279: {"Unified_Ideograph", "Ideographic"},
    23280: {"Unified_Ideograph", "Ideographic"},
    23281: {"Unified_Ideograph", "Ideographic"},
    23282: {"Unified_Ideograph", "Ideographic"},
    23283: {"Unified_Ideograph", "Ideographic"},
    23284: {"Unified_Ideograph", "Ideographic"},
    23285: {"Unified_Ideograph", "Ideographic"},
    23286: {"Unified_Ideograph", "Ideographic"},
    23287: {"Unified_Ideograph", "Ideographic"},
    23288: {"Unified_Ideograph", "Ideographic"},
    23289: {"Unified_Ideograph", "Ideographic"},
    23290: {"Unified_Ideograph", "Ideographic"},
    23291: {"Unified_Ideograph", "Ideographic"},
    23292: {"Unified_Ideograph", "Ideographic"},
    23293: {"Unified_Ideograph", "Ideographic"},
    23294: {"Unified_Ideograph", "Ideographic"},
    23295: {"Unified_Ideograph", "Ideographic"},
    23296: {"Unified_Ideograph", "Ideographic"},
    23297: {"Unified_Ideograph", "Ideographic"},
    23298: {"Unified_Ideograph", "Ideographic"},
    23299: {"Unified_Ideograph", "Ideographic"},
    23300: {"Unified_Ideograph", "Ideographic"},
    23301: {"Unified_Ideograph", "Ideographic"},
    23302: {"Unified_Ideograph", "Ideographic"},
    23303: {"Unified_Ideograph", "Ideographic"},
    23304: {"Unified_Ideograph", "Ideographic"},
    23305: {"Unified_Ideograph", "Ideographic"},
    23306: {"Unified_Ideograph", "Ideographic"},
    23307: {"Unified_Ideograph", "Ideographic"},
    23308: {"Unified_Ideograph", "Ideographic"},
    23309: {"Unified_Ideograph", "Ideographic"},
    23310: {"Unified_Ideograph", "Ideographic"},
    23311: {"Unified_Ideograph", "Ideographic"},
    23312: {"Unified_Ideograph", "Ideographic"},
    23313: {"Unified_Ideograph", "Ideographic"},
    23314: {"Unified_Ideograph", "Ideographic"},
    23315: {"Unified_Ideograph", "Ideographic"},
    23316: {"Unified_Ideograph", "Ideographic"},
    23317: {"Unified_Ideograph", "Ideographic"},
    23318: {"Unified_Ideograph", "Ideographic"},
    23319: {"Unified_Ideograph", "Ideographic"},
    23320: {"Unified_Ideograph", "Ideographic"},
    23321: {"Unified_Ideograph", "Ideographic"},
    23322: {"Unified_Ideograph", "Ideographic"},
    23323: {"Unified_Ideograph", "Ideographic"},
    23324: {"Unified_Ideograph", "Ideographic"},
    23325: {"Unified_Ideograph", "Ideographic"},
    23326: {"Unified_Ideograph", "Ideographic"},
    23327: {"Unified_Ideograph", "Ideographic"},
    23328: {"Unified_Ideograph", "Ideographic"},
    23329: {"Unified_Ideograph", "Ideographic"},
    23330: {"Unified_Ideograph", "Ideographic"},
    23331: {"Unified_Ideograph", "Ideographic"},
    23332: {"Unified_Ideograph", "Ideographic"},
    23333: {"Unified_Ideograph", "Ideographic"},
    23334: {"Unified_Ideograph", "Ideographic"},
    23335: {"Unified_Ideograph", "Ideographic"},
    23336: {"Unified_Ideograph", "Ideographic"},
    23337: {"Unified_Ideograph", "Ideographic"},
    23338: {"Unified_Ideograph", "Ideographic"},
    23339: {"Unified_Ideograph", "Ideographic"},
    23340: {"Unified_Ideograph", "Ideographic"},
    23341: {"Unified_Ideograph", "Ideographic"},
    23342: {"Unified_Ideograph", "Ideographic"},
    23343: {"Unified_Ideograph", "Ideographic"},
    23344: {"Unified_Ideograph", "Ideographic"},
    23345: {"Unified_Ideograph", "Ideographic"},
    23346: {"Unified_Ideograph", "Ideographic"},
    23347: {"Unified_Ideograph", "Ideographic"},
    23348: {"Unified_Ideograph", "Ideographic"},
    23349: {"Unified_Ideograph", "Ideographic"},
    23350: {"Unified_Ideograph", "Ideographic"},
    23351: {"Unified_Ideograph", "Ideographic"},
    23352: {"Unified_Ideograph", "Ideographic"},
    23353: {"Unified_Ideograph", "Ideographic"},
    23354: {"Unified_Ideograph", "Ideographic"},
    23355: {"Unified_Ideograph", "Ideographic"},
    23356: {"Unified_Ideograph", "Ideographic"},
    23357: {"Unified_Ideograph", "Ideographic"},
    23358: {"Unified_Ideograph", "Ideographic"},
    23359: {"Unified_Ideograph", "Ideographic"},
    23360: {"Unified_Ideograph", "Ideographic"},
    23361: {"Unified_Ideograph", "Ideographic"},
    23362: {"Unified_Ideograph", "Ideographic"},
    23363: {"Unified_Ideograph", "Ideographic"},
    23364: {"Unified_Ideograph", "Ideographic"},
    23365: {"Unified_Ideograph", "Ideographic"},
    23366: {"Unified_Ideograph", "Ideographic"},
    23367: {"Unified_Ideograph", "Ideographic"},
    23368: {"Unified_Ideograph", "Ideographic"},
    23369: {"Unified_Ideograph", "Ideographic"},
    23370: {"Unified_Ideograph", "Ideographic"},
    23371: {"Unified_Ideograph", "Ideographic"},
    23372: {"Unified_Ideograph", "Ideographic"},
    23373: {"Unified_Ideograph", "Ideographic"},
    23374: {"Unified_Ideograph", "Ideographic"},
    23375: {"Unified_Ideograph", "Ideographic"},
    23376: {"Unified_Ideograph", "Ideographic"},
    23377: {"Unified_Ideograph", "Ideographic"},
    23378: {"Unified_Ideograph", "Ideographic"},
    23379: {"Unified_Ideograph", "Ideographic"},
    23380: {"Unified_Ideograph", "Ideographic"},
    23381: {"Unified_Ideograph", "Ideographic"},
    23382: {"Unified_Ideograph", "Ideographic"},
    23383: {"Unified_Ideograph", "Ideographic"},
    23384: {"Unified_Ideograph", "Ideographic"},
    23385: {"Unified_Ideograph", "Ideographic"},
    23386: {"Unified_Ideograph", "Ideographic"},
    23387: {"Unified_Ideograph", "Ideographic"},
    23388: {"Unified_Ideograph", "Ideographic"},
    23389: {"Unified_Ideograph", "Ideographic"},
    23390: {"Unified_Ideograph", "Ideographic"},
    23391: {"Unified_Ideograph", "Ideographic"},
    23392: {"Unified_Ideograph", "Ideographic"},
    23393: {"Unified_Ideograph", "Ideographic"},
    23394: {"Unified_Ideograph", "Ideographic"},
    23395: {"Unified_Ideograph", "Ideographic"},
    23396: {"Unified_Ideograph", "Ideographic"},
    23397: {"Unified_Ideograph", "Ideographic"},
    23398: {"Unified_Ideograph", "Ideographic"},
    23399: {"Unified_Ideograph", "Ideographic"},
    23400: {"Unified_Ideograph", "Ideographic"},
    23401: {"Unified_Ideograph", "Ideographic"},
    23402: {"Unified_Ideograph", "Ideographic"},
    23403: {"Unified_Ideograph", "Ideographic"},
    23404: {"Unified_Ideograph", "Ideographic"},
    23405: {"Unified_Ideograph", "Ideographic"},
    23406: {"Unified_Ideograph", "Ideographic"},
    23407: {"Unified_Ideograph", "Ideographic"},
    23408: {"Unified_Ideograph", "Ideographic"},
    23409: {"Unified_Ideograph", "Ideographic"},
    23410: {"Unified_Ideograph", "Ideographic"},
    23411: {"Unified_Ideograph", "Ideographic"},
    23412: {"Unified_Ideograph", "Ideographic"},
    23413: {"Unified_Ideograph", "Ideographic"},
    23414: {"Unified_Ideograph", "Ideographic"},
    23415: {"Unified_Ideograph", "Ideographic"},
    23416: {"Unified_Ideograph", "Ideographic"},
    23417: {"Unified_Ideograph", "Ideographic"},
    23418: {"Unified_Ideograph", "Ideographic"},
    23419: {"Unified_Ideograph", "Ideographic"},
    23420: {"Unified_Ideograph", "Ideographic"},
    23421: {"Unified_Ideograph", "Ideographic"},
    23422: {"Unified_Ideograph", "Ideographic"},
    23423: {"Unified_Ideograph", "Ideographic"},
    23424: {"Unified_Ideograph", "Ideographic"},
    23425: {"Unified_Ideograph", "Ideographic"},
    23426: {"Unified_Ideograph", "Ideographic"},
    23427: {"Unified_Ideograph", "Ideographic"},
    23428: {"Unified_Ideograph", "Ideographic"},
    23429: {"Unified_Ideograph", "Ideographic"},
    23430: {"Unified_Ideograph", "Ideographic"},
    23431: {"Unified_Ideograph", "Ideographic"},
    23432: {"Unified_Ideograph", "Ideographic"},
    23433: {"Unified_Ideograph", "Ideographic"},
    23434: {"Unified_Ideograph", "Ideographic"},
    23435: {"Unified_Ideograph", "Ideographic"},
    23436: {"Unified_Ideograph", "Ideographic"},
    23437: {"Unified_Ideograph", "Ideographic"},
    23438: {"Unified_Ideograph", "Ideographic"},
    23439: {"Unified_Ideograph", "Ideographic"},
    23440: {"Unified_Ideograph", "Ideographic"},
    23441: {"Unified_Ideograph", "Ideographic"},
    23442: {"Unified_Ideograph", "Ideographic"},
    23443: {"Unified_Ideograph", "Ideographic"},
    23444: {"Unified_Ideograph", "Ideographic"},
    23445: {"Unified_Ideograph", "Ideographic"},
    23446: {"Unified_Ideograph", "Ideographic"},
    23447: {"Unified_Ideograph", "Ideographic"},
    23448: {"Unified_Ideograph", "Ideographic"},
    23449: {"Unified_Ideograph", "Ideographic"},
    23450: {"Unified_Ideograph", "Ideographic"},
    23451: {"Unified_Ideograph", "Ideographic"},
    23452: {"Unified_Ideograph", "Ideographic"},
    23453: {"Unified_Ideograph", "Ideographic"},
    23454: {"Unified_Ideograph", "Ideographic"},
    23455: {"Unified_Ideograph", "Ideographic"},
    23456: {"Unified_Ideograph", "Ideographic"},
    23457: {"Unified_Ideograph", "Ideographic"},
    23458: {"Unified_Ideograph", "Ideographic"},
    23459: {"Unified_Ideograph", "Ideographic"},
    23460: {"Unified_Ideograph", "Ideographic"},
    23461: {"Unified_Ideograph", "Ideographic"},
    23462: {"Unified_Ideograph", "Ideographic"},
    23463: {"Unified_Ideograph", "Ideographic"},
    23464: {"Unified_Ideograph", "Ideographic"},
    23465: {"Unified_Ideograph", "Ideographic"},
    23466: {"Unified_Ideograph", "Ideographic"},
    23467: {"Unified_Ideograph", "Ideographic"},
    23468: {"Unified_Ideograph", "Ideographic"},
    23469: {"Unified_Ideograph", "Ideographic"},
    23470: {"Unified_Ideograph", "Ideographic"},
    23471: {"Unified_Ideograph", "Ideographic"},
    23472: {"Unified_Ideograph", "Ideographic"},
    23473: {"Unified_Ideograph", "Ideographic"},
    23474: {"Unified_Ideograph", "Ideographic"},
    23475: {"Unified_Ideograph", "Ideographic"},
    23476: {"Unified_Ideograph", "Ideographic"},
    23477: {"Unified_Ideograph", "Ideographic"},
    23478: {"Unified_Ideograph", "Ideographic"},
    23479: {"Unified_Ideograph", "Ideographic"},
    23480: {"Unified_Ideograph", "Ideographic"},
    23481: {"Unified_Ideograph", "Ideographic"},
    23482: {"Unified_Ideograph", "Ideographic"},
    23483: {"Unified_Ideograph", "Ideographic"},
    23484: {"Unified_Ideograph", "Ideographic"},
    23485: {"Unified_Ideograph", "Ideographic"},
    23486: {"Unified_Ideograph", "Ideographic"},
    23487: {"Unified_Ideograph", "Ideographic"},
    23488: {"Unified_Ideograph", "Ideographic"},
    23489: {"Unified_Ideograph", "Ideographic"},
    23490: {"Unified_Ideograph", "Ideographic"},
    23491: {"Unified_Ideograph", "Ideographic"},
    23492: {"Unified_Ideograph", "Ideographic"},
    23493: {"Unified_Ideograph", "Ideographic"},
    23494: {"Unified_Ideograph", "Ideographic"},
    23495: {"Unified_Ideograph", "Ideographic"},
    23496: {"Unified_Ideograph", "Ideographic"},
    23497: {"Unified_Ideograph", "Ideographic"},
    23498: {"Unified_Ideograph", "Ideographic"},
    23499: {"Unified_Ideograph", "Ideographic"},
    23500: {"Unified_Ideograph", "Ideographic"},
    23501: {"Unified_Ideograph", "Ideographic"},
    23502: {"Unified_Ideograph", "Ideographic"},
    23503: {"Unified_Ideograph", "Ideographic"},
    23504: {"Unified_Ideograph", "Ideographic"},
    23505: {"Unified_Ideograph", "Ideographic"},
    23506: {"Unified_Ideograph", "Ideographic"},
    23507: {"Unified_Ideograph", "Ideographic"},
    23508: {"Unified_Ideograph", "Ideographic"},
    23509: {"Unified_Ideograph", "Ideographic"},
    23510: {"Unified_Ideograph", "Ideographic"},
    23511: {"Unified_Ideograph", "Ideographic"},
    23512: {"Unified_Ideograph", "Ideographic"},
    23513: {"Unified_Ideograph", "Ideographic"},
    23514: {"Unified_Ideograph", "Ideographic"},
    23515: {"Unified_Ideograph", "Ideographic"},
    23516: {"Unified_Ideograph", "Ideographic"},
    23517: {"Unified_Ideograph", "Ideographic"},
    23518: {"Unified_Ideograph", "Ideographic"},
    23519: {"Unified_Ideograph", "Ideographic"},
    23520: {"Unified_Ideograph", "Ideographic"},
    23521: {"Unified_Ideograph", "Ideographic"},
    23522: {"Unified_Ideograph", "Ideographic"},
    23523: {"Unified_Ideograph", "Ideographic"},
    23524: {"Unified_Ideograph", "Ideographic"},
    23525: {"Unified_Ideograph", "Ideographic"},
    23526: {"Unified_Ideograph", "Ideographic"},
    23527: {"Unified_Ideograph", "Ideographic"},
    23528: {"Unified_Ideograph", "Ideographic"},
    23529: {"Unified_Ideograph", "Ideographic"},
    23530: {"Unified_Ideograph", "Ideographic"},
    23531: {"Unified_Ideograph", "Ideographic"},
    23532: {"Unified_Ideograph", "Ideographic"},
    23533: {"Unified_Ideograph", "Ideographic"},
    23534: {"Unified_Ideograph", "Ideographic"},
    23535: {"Unified_Ideograph", "Ideographic"},
    23536: {"Unified_Ideograph", "Ideographic"},
    23537: {"Unified_Ideograph", "Ideographic"},
    23538: {"Unified_Ideograph", "Ideographic"},
    23539: {"Unified_Ideograph", "Ideographic"},
    23540: {"Unified_Ideograph", "Ideographic"},
    23541: {"Unified_Ideograph", "Ideographic"},
    23542: {"Unified_Ideograph", "Ideographic"},
    23543: {"Unified_Ideograph", "Ideographic"},
    23544: {"Unified_Ideograph", "Ideographic"},
    23545: {"Unified_Ideograph", "Ideographic"},
    23546: {"Unified_Ideograph", "Ideographic"},
    23547: {"Unified_Ideograph", "Ideographic"},
    23548: {"Unified_Ideograph", "Ideographic"},
    23549: {"Unified_Ideograph", "Ideographic"},
    23550: {"Unified_Ideograph", "Ideographic"},
    23551: {"Unified_Ideograph", "Ideographic"},
    23552: {"Unified_Ideograph", "Ideographic"},
    23553: {"Unified_Ideograph", "Ideographic"},
    23554: {"Unified_Ideograph", "Ideographic"},
    23555: {"Unified_Ideograph", "Ideographic"},
    23556: {"Unified_Ideograph", "Ideographic"},
    23557: {"Unified_Ideograph", "Ideographic"},
    23558: {"Unified_Ideograph", "Ideographic"},
    23559: {"Unified_Ideograph", "Ideographic"},
    23560: {"Unified_Ideograph", "Ideographic"},
    23561: {"Unified_Ideograph", "Ideographic"},
    23562: {"Unified_Ideograph", "Ideographic"},
    23563: {"Unified_Ideograph", "Ideographic"},
    23564: {"Unified_Ideograph", "Ideographic"},
    23565: {"Unified_Ideograph", "Ideographic"},
    23566: {"Unified_Ideograph", "Ideographic"},
    23567: {"Unified_Ideograph", "Ideographic"},
    23568: {"Unified_Ideograph", "Ideographic"},
    23569: {"Unified_Ideograph", "Ideographic"},
    23570: {"Unified_Ideograph", "Ideographic"},
    23571: {"Unified_Ideograph", "Ideographic"},
    23572: {"Unified_Ideograph", "Ideographic"},
    23573: {"Unified_Ideograph", "Ideographic"},
    23574: {"Unified_Ideograph", "Ideographic"},
    23575: {"Unified_Ideograph", "Ideographic"},
    23576: {"Unified_Ideograph", "Ideographic"},
    23577: {"Unified_Ideograph", "Ideographic"},
    23578: {"Unified_Ideograph", "Ideographic"},
    23579: {"Unified_Ideograph", "Ideographic"},
    23580: {"Unified_Ideograph", "Ideographic"},
    23581: {"Unified_Ideograph", "Ideographic"},
    23582: {"Unified_Ideograph", "Ideographic"},
    23583: {"Unified_Ideograph", "Ideographic"},
    23584: {"Unified_Ideograph", "Ideographic"},
    23585: {"Unified_Ideograph", "Ideographic"},
    23586: {"Unified_Ideograph", "Ideographic"},
    23587: {"Unified_Ideograph", "Ideographic"},
    23588: {"Unified_Ideograph", "Ideographic"},
    23589: {"Unified_Ideograph", "Ideographic"},
    23590: {"Unified_Ideograph", "Ideographic"},
    23591: {"Unified_Ideograph", "Ideographic"},
    23592: {"Unified_Ideograph", "Ideographic"},
    23593: {"Unified_Ideograph", "Ideographic"},
    23594: {"Unified_Ideograph", "Ideographic"},
    23595: {"Unified_Ideograph", "Ideographic"},
    23596: {"Unified_Ideograph", "Ideographic"},
    23597: {"Unified_Ideograph", "Ideographic"},
    23598: {"Unified_Ideograph", "Ideographic"},
    23599: {"Unified_Ideograph", "Ideographic"},
    23600: {"Unified_Ideograph", "Ideographic"},
    23601: {"Unified_Ideograph", "Ideographic"},
    23602: {"Unified_Ideograph", "Ideographic"},
    23603: {"Unified_Ideograph", "Ideographic"},
    23604: {"Unified_Ideograph", "Ideographic"},
    23605: {"Unified_Ideograph", "Ideographic"},
    23606: {"Unified_Ideograph", "Ideographic"},
    23607: {"Unified_Ideograph", "Ideographic"},
    23608: {"Unified_Ideograph", "Ideographic"},
    23609: {"Unified_Ideograph", "Ideographic"},
    23610: {"Unified_Ideograph", "Ideographic"},
    23611: {"Unified_Ideograph", "Ideographic"},
    23612: {"Unified_Ideograph", "Ideographic"},
    23613: {"Unified_Ideograph", "Ideographic"},
    23614: {"Unified_Ideograph", "Ideographic"},
    23615: {"Unified_Ideograph", "Ideographic"},
    23616: {"Unified_Ideograph", "Ideographic"},
    23617: {"Unified_Ideograph", "Ideographic"},
    23618: {"Unified_Ideograph", "Ideographic"},
    23619: {"Unified_Ideograph", "Ideographic"},
    23620: {"Unified_Ideograph", "Ideographic"},
    23621: {"Unified_Ideograph", "Ideographic"},
    23622: {"Unified_Ideograph", "Ideographic"},
    23623: {"Unified_Ideograph", "Ideographic"},
    23624: {"Unified_Ideograph", "Ideographic"},
    23625: {"Unified_Ideograph", "Ideographic"},
    23626: {"Unified_Ideograph", "Ideographic"},
    23627: {"Unified_Ideograph", "Ideographic"},
    23628: {"Unified_Ideograph", "Ideographic"},
    23629: {"Unified_Ideograph", "Ideographic"},
    23630: {"Unified_Ideograph", "Ideographic"},
    23631: {"Unified_Ideograph", "Ideographic"},
    23632: {"Unified_Ideograph", "Ideographic"},
    23633: {"Unified_Ideograph", "Ideographic"},
    23634: {"Unified_Ideograph", "Ideographic"},
    23635: {"Unified_Ideograph", "Ideographic"},
    23636: {"Unified_Ideograph", "Ideographic"},
    23637: {"Unified_Ideograph", "Ideographic"},
    23638: {"Unified_Ideograph", "Ideographic"},
    23639: {"Unified_Ideograph", "Ideographic"},
    23640: {"Unified_Ideograph", "Ideographic"},
    23641: {"Unified_Ideograph", "Ideographic"},
    23642: {"Unified_Ideograph", "Ideographic"},
    23643: {"Unified_Ideograph", "Ideographic"},
    23644: {"Unified_Ideograph", "Ideographic"},
    23645: {"Unified_Ideograph", "Ideographic"},
    23646: {"Unified_Ideograph", "Ideographic"},
    23647: {"Unified_Ideograph", "Ideographic"},
    23648: {"Unified_Ideograph", "Ideographic"},
    23649: {"Unified_Ideograph", "Ideographic"},
    23650: {"Unified_Ideograph", "Ideographic"},
    23651: {"Unified_Ideograph", "Ideographic"},
    23652: {"Unified_Ideograph", "Ideographic"},
    23653: {"Unified_Ideograph", "Ideographic"},
    23654: {"Unified_Ideograph", "Ideographic"},
    23655: {"Unified_Ideograph", "Ideographic"},
    23656: {"Unified_Ideograph", "Ideographic"},
    23657: {"Unified_Ideograph", "Ideographic"},
    23658: {"Unified_Ideograph", "Ideographic"},
    23659: {"Unified_Ideograph", "Ideographic"},
    23660: {"Unified_Ideograph", "Ideographic"},
    23661: {"Unified_Ideograph", "Ideographic"},
    23662: {"Unified_Ideograph", "Ideographic"},
    23663: {"Unified_Ideograph", "Ideographic"},
    23664: {"Unified_Ideograph", "Ideographic"},
    23665: {"Unified_Ideograph", "Ideographic"},
    23666: {"Unified_Ideograph", "Ideographic"},
    23667: {"Unified_Ideograph", "Ideographic"},
    23668: {"Unified_Ideograph", "Ideographic"},
    23669: {"Unified_Ideograph", "Ideographic"},
    23670: {"Unified_Ideograph", "Ideographic"},
    23671: {"Unified_Ideograph", "Ideographic"},
    23672: {"Unified_Ideograph", "Ideographic"},
    23673: {"Unified_Ideograph", "Ideographic"},
    23674: {"Unified_Ideograph", "Ideographic"},
    23675: {"Unified_Ideograph", "Ideographic"},
    23676: {"Unified_Ideograph", "Ideographic"},
    23677: {"Unified_Ideograph", "Ideographic"},
    23678: {"Unified_Ideograph", "Ideographic"},
    23679: {"Unified_Ideograph", "Ideographic"},
    23680: {"Unified_Ideograph", "Ideographic"},
    23681: {"Unified_Ideograph", "Ideographic"},
    23682: {"Unified_Ideograph", "Ideographic"},
    23683: {"Unified_Ideograph", "Ideographic"},
    23684: {"Unified_Ideograph", "Ideographic"},
    23685: {"Unified_Ideograph", "Ideographic"},
    23686: {"Unified_Ideograph", "Ideographic"},
    23687: {"Unified_Ideograph", "Ideographic"},
    23688: {"Unified_Ideograph", "Ideographic"},
    23689: {"Unified_Ideograph", "Ideographic"},
    23690: {"Unified_Ideograph", "Ideographic"},
    23691: {"Unified_Ideograph", "Ideographic"},
    23692: {"Unified_Ideograph", "Ideographic"},
    23693: {"Unified_Ideograph", "Ideographic"},
    23694: {"Unified_Ideograph", "Ideographic"},
    23695: {"Unified_Ideograph", "Ideographic"},
    23696: {"Unified_Ideograph", "Ideographic"},
    23697: {"Unified_Ideograph", "Ideographic"},
    23698: {"Unified_Ideograph", "Ideographic"},
    23699: {"Unified_Ideograph", "Ideographic"},
    23700: {"Unified_Ideograph", "Ideographic"},
    23701: {"Unified_Ideograph", "Ideographic"},
    23702: {"Unified_Ideograph", "Ideographic"},
    23703: {"Unified_Ideograph", "Ideographic"},
    23704: {"Unified_Ideograph", "Ideographic"},
    23705: {"Unified_Ideograph", "Ideographic"},
    23706: {"Unified_Ideograph", "Ideographic"},
    23707: {"Unified_Ideograph", "Ideographic"},
    23708: {"Unified_Ideograph", "Ideographic"},
    23709: {"Unified_Ideograph", "Ideographic"},
    23710: {"Unified_Ideograph", "Ideographic"},
    23711: {"Unified_Ideograph", "Ideographic"},
    23712: {"Unified_Ideograph", "Ideographic"},
    23713: {"Unified_Ideograph", "Ideographic"},
    23714: {"Unified_Ideograph", "Ideographic"},
    23715: {"Unified_Ideograph", "Ideographic"},
    23716: {"Unified_Ideograph", "Ideographic"},
    23717: {"Unified_Ideograph", "Ideographic"},
    23718: {"Unified_Ideograph", "Ideographic"},
    23719: {"Unified_Ideograph", "Ideographic"},
    23720: {"Unified_Ideograph", "Ideographic"},
    23721: {"Unified_Ideograph", "Ideographic"},
    23722: {"Unified_Ideograph", "Ideographic"},
    23723: {"Unified_Ideograph", "Ideographic"},
    23724: {"Unified_Ideograph", "Ideographic"},
    23725: {"Unified_Ideograph", "Ideographic"},
    23726: {"Unified_Ideograph", "Ideographic"},
    23727: {"Unified_Ideograph", "Ideographic"},
    23728: {"Unified_Ideograph", "Ideographic"},
    23729: {"Unified_Ideograph", "Ideographic"},
    23730: {"Unified_Ideograph", "Ideographic"},
    23731: {"Unified_Ideograph", "Ideographic"},
    23732: {"Unified_Ideograph", "Ideographic"},
    23733: {"Unified_Ideograph", "Ideographic"},
    23734: {"Unified_Ideograph", "Ideographic"},
    23735: {"Unified_Ideograph", "Ideographic"},
    23736: {"Unified_Ideograph", "Ideographic"},
    23737: {"Unified_Ideograph", "Ideographic"},
    23738: {"Unified_Ideograph", "Ideographic"},
    23739: {"Unified_Ideograph", "Ideographic"},
    23740: {"Unified_Ideograph", "Ideographic"},
    23741: {"Unified_Ideograph", "Ideographic"},
    23742: {"Unified_Ideograph", "Ideographic"},
    23743: {"Unified_Ideograph", "Ideographic"},
    23744: {"Unified_Ideograph", "Ideographic"},
    23745: {"Unified_Ideograph", "Ideographic"},
    23746: {"Unified_Ideograph", "Ideographic"},
    23747: {"Unified_Ideograph", "Ideographic"},
    23748: {"Unified_Ideograph", "Ideographic"},
    23749: {"Unified_Ideograph", "Ideographic"},
    23750: {"Unified_Ideograph", "Ideographic"},
    23751: {"Unified_Ideograph", "Ideographic"},
    23752: {"Unified_Ideograph", "Ideographic"},
    23753: {"Unified_Ideograph", "Ideographic"},
    23754: {"Unified_Ideograph", "Ideographic"},
    23755: {"Unified_Ideograph", "Ideographic"},
    23756: {"Unified_Ideograph", "Ideographic"},
    23757: {"Unified_Ideograph", "Ideographic"},
    23758: {"Unified_Ideograph", "Ideographic"},
    23759: {"Unified_Ideograph", "Ideographic"},
    23760: {"Unified_Ideograph", "Ideographic"},
    23761: {"Unified_Ideograph", "Ideographic"},
    23762: {"Unified_Ideograph", "Ideographic"},
    23763: {"Unified_Ideograph", "Ideographic"},
    23764: {"Unified_Ideograph", "Ideographic"},
    23765: {"Unified_Ideograph", "Ideographic"},
    23766: {"Unified_Ideograph", "Ideographic"},
    23767: {"Unified_Ideograph", "Ideographic"},
    23768: {"Unified_Ideograph", "Ideographic"},
    23769: {"Unified_Ideograph", "Ideographic"},
    23770: {"Unified_Ideograph", "Ideographic"},
    23771: {"Unified_Ideograph", "Ideographic"},
    23772: {"Unified_Ideograph", "Ideographic"},
    23773: {"Unified_Ideograph", "Ideographic"},
    23774: {"Unified_Ideograph", "Ideographic"},
    23775: {"Unified_Ideograph", "Ideographic"},
    23776: {"Unified_Ideograph", "Ideographic"},
    23777: {"Unified_Ideograph", "Ideographic"},
    23778: {"Unified_Ideograph", "Ideographic"},
    23779: {"Unified_Ideograph", "Ideographic"},
    23780: {"Unified_Ideograph", "Ideographic"},
    23781: {"Unified_Ideograph", "Ideographic"},
    23782: {"Unified_Ideograph", "Ideographic"},
    23783: {"Unified_Ideograph", "Ideographic"},
    23784: {"Unified_Ideograph", "Ideographic"},
    23785: {"Unified_Ideograph", "Ideographic"},
    23786: {"Unified_Ideograph", "Ideographic"},
    23787: {"Unified_Ideograph", "Ideographic"},
    23788: {"Unified_Ideograph", "Ideographic"},
    23789: {"Unified_Ideograph", "Ideographic"},
    23790: {"Unified_Ideograph", "Ideographic"},
    23791: {"Unified_Ideograph", "Ideographic"},
    23792: {"Unified_Ideograph", "Ideographic"},
    23793: {"Unified_Ideograph", "Ideographic"},
    23794: {"Unified_Ideograph", "Ideographic"},
    23795: {"Unified_Ideograph", "Ideographic"},
    23796: {"Unified_Ideograph", "Ideographic"},
    23797: {"Unified_Ideograph", "Ideographic"},
    23798: {"Unified_Ideograph", "Ideographic"},
    23799: {"Unified_Ideograph", "Ideographic"},
    23800: {"Unified_Ideograph", "Ideographic"},
    23801: {"Unified_Ideograph", "Ideographic"},
    23802: {"Unified_Ideograph", "Ideographic"},
    23803: {"Unified_Ideograph", "Ideographic"},
    23804: {"Unified_Ideograph", "Ideographic"},
    23805: {"Unified_Ideograph", "Ideographic"},
    23806: {"Unified_Ideograph", "Ideographic"},
    23807: {"Unified_Ideograph", "Ideographic"},
    23808: {"Unified_Ideograph", "Ideographic"},
    23809: {"Unified_Ideograph", "Ideographic"},
    23810: {"Unified_Ideograph", "Ideographic"},
    23811: {"Unified_Ideograph", "Ideographic"},
    23812: {"Unified_Ideograph", "Ideographic"},
    23813: {"Unified_Ideograph", "Ideographic"},
    23814: {"Unified_Ideograph", "Ideographic"},
    23815: {"Unified_Ideograph", "Ideographic"},
    23816: {"Unified_Ideograph", "Ideographic"},
    23817: {"Unified_Ideograph", "Ideographic"},
    23818: {"Unified_Ideograph", "Ideographic"},
    23819: {"Unified_Ideograph", "Ideographic"},
    23820: {"Unified_Ideograph", "Ideographic"},
    23821: {"Unified_Ideograph", "Ideographic"},
    23822: {"Unified_Ideograph", "Ideographic"},
    23823: {"Unified_Ideograph", "Ideographic"},
    23824: {"Unified_Ideograph", "Ideographic"},
    23825: {"Unified_Ideograph", "Ideographic"},
    23826: {"Unified_Ideograph", "Ideographic"},
    23827: {"Unified_Ideograph", "Ideographic"},
    23828: {"Unified_Ideograph", "Ideographic"},
    23829: {"Unified_Ideograph", "Ideographic"},
    23830: {"Unified_Ideograph", "Ideographic"},
    23831: {"Unified_Ideograph", "Ideographic"},
    23832: {"Unified_Ideograph", "Ideographic"},
    23833: {"Unified_Ideograph", "Ideographic"},
    23834: {"Unified_Ideograph", "Ideographic"},
    23835: {"Unified_Ideograph", "Ideographic"},
    23836: {"Unified_Ideograph", "Ideographic"},
    23837: {"Unified_Ideograph", "Ideographic"},
    23838: {"Unified_Ideograph", "Ideographic"},
    23839: {"Unified_Ideograph", "Ideographic"},
    23840: {"Unified_Ideograph", "Ideographic"},
    23841: {"Unified_Ideograph", "Ideographic"},
    23842: {"Unified_Ideograph", "Ideographic"},
    23843: {"Unified_Ideograph", "Ideographic"},
    23844: {"Unified_Ideograph", "Ideographic"},
    23845: {"Unified_Ideograph", "Ideographic"},
    23846: {"Unified_Ideograph", "Ideographic"},
    23847: {"Unified_Ideograph", "Ideographic"},
    23848: {"Unified_Ideograph", "Ideographic"},
    23849: {"Unified_Ideograph", "Ideographic"},
    23850: {"Unified_Ideograph", "Ideographic"},
    23851: {"Unified_Ideograph", "Ideographic"},
    23852: {"Unified_Ideograph", "Ideographic"},
    23853: {"Unified_Ideograph", "Ideographic"},
    23854: {"Unified_Ideograph", "Ideographic"},
    23855: {"Unified_Ideograph", "Ideographic"},
    23856: {"Unified_Ideograph", "Ideographic"},
    23857: {"Unified_Ideograph", "Ideographic"},
    23858: {"Unified_Ideograph", "Ideographic"},
    23859: {"Unified_Ideograph", "Ideographic"},
    23860: {"Unified_Ideograph", "Ideographic"},
    23861: {"Unified_Ideograph", "Ideographic"},
    23862: {"Unified_Ideograph", "Ideographic"},
    23863: {"Unified_Ideograph", "Ideographic"},
    23864: {"Unified_Ideograph", "Ideographic"},
    23865: {"Unified_Ideograph", "Ideographic"},
    23866: {"Unified_Ideograph", "Ideographic"},
    23867: {"Unified_Ideograph", "Ideographic"},
    23868: {"Unified_Ideograph", "Ideographic"},
    23869: {"Unified_Ideograph", "Ideographic"},
    23870: {"Unified_Ideograph", "Ideographic"},
    23871: {"Unified_Ideograph", "Ideographic"},
    23872: {"Unified_Ideograph", "Ideographic"},
    23873: {"Unified_Ideograph", "Ideographic"},
    23874: {"Unified_Ideograph", "Ideographic"},
    23875: {"Unified_Ideograph", "Ideographic"},
    23876: {"Unified_Ideograph", "Ideographic"},
    23877: {"Unified_Ideograph", "Ideographic"},
    23878: {"Unified_Ideograph", "Ideographic"},
    23879: {"Unified_Ideograph", "Ideographic"},
    23880: {"Unified_Ideograph", "Ideographic"},
    23881: {"Unified_Ideograph", "Ideographic"},
    23882: {"Unified_Ideograph", "Ideographic"},
    23883: {"Unified_Ideograph", "Ideographic"},
    23884: {"Unified_Ideograph", "Ideographic"},
    23885: {"Unified_Ideograph", "Ideographic"},
    23886: {"Unified_Ideograph", "Ideographic"},
    23887: {"Unified_Ideograph", "Ideographic"},
    23888: {"Unified_Ideograph", "Ideographic"},
    23889: {"Unified_Ideograph", "Ideographic"},
    23890: {"Unified_Ideograph", "Ideographic"},
    23891: {"Unified_Ideograph", "Ideographic"},
    23892: {"Unified_Ideograph", "Ideographic"},
    23893: {"Unified_Ideograph", "Ideographic"},
    23894: {"Unified_Ideograph", "Ideographic"},
    23895: {"Unified_Ideograph", "Ideographic"},
    23896: {"Unified_Ideograph", "Ideographic"},
    23897: {"Unified_Ideograph", "Ideographic"},
    23898: {"Unified_Ideograph", "Ideographic"},
    23899: {"Unified_Ideograph", "Ideographic"},
    23900: {"Unified_Ideograph", "Ideographic"},
    23901: {"Unified_Ideograph", "Ideographic"},
    23902: {"Unified_Ideograph", "Ideographic"},
    23903: {"Unified_Ideograph", "Ideographic"},
    23904: {"Unified_Ideograph", "Ideographic"},
    23905: {"Unified_Ideograph", "Ideographic"},
    23906: {"Unified_Ideograph", "Ideographic"},
    23907: {"Unified_Ideograph", "Ideographic"},
    23908: {"Unified_Ideograph", "Ideographic"},
    23909: {"Unified_Ideograph", "Ideographic"},
    23910: {"Unified_Ideograph", "Ideographic"},
    23911: {"Unified_Ideograph", "Ideographic"},
    23912: {"Unified_Ideograph", "Ideographic"},
    23913: {"Unified_Ideograph", "Ideographic"},
    23914: {"Unified_Ideograph", "Ideographic"},
    23915: {"Unified_Ideograph", "Ideographic"},
    23916: {"Unified_Ideograph", "Ideographic"},
    23917: {"Unified_Ideograph", "Ideographic"},
    23918: {"Unified_Ideograph", "Ideographic"},
    23919: {"Unified_Ideograph", "Ideographic"},
    23920: {"Unified_Ideograph", "Ideographic"},
    23921: {"Unified_Ideograph", "Ideographic"},
    23922: {"Unified_Ideograph", "Ideographic"},
    23923: {"Unified_Ideograph", "Ideographic"},
    23924: {"Unified_Ideograph", "Ideographic"},
    23925: {"Unified_Ideograph", "Ideographic"},
    23926: {"Unified_Ideograph", "Ideographic"},
    23927: {"Unified_Ideograph", "Ideographic"},
    23928: {"Unified_Ideograph", "Ideographic"},
    23929: {"Unified_Ideograph", "Ideographic"},
    23930: {"Unified_Ideograph", "Ideographic"},
    23931: {"Unified_Ideograph", "Ideographic"},
    23932: {"Unified_Ideograph", "Ideographic"},
    23933: {"Unified_Ideograph", "Ideographic"},
    23934: {"Unified_Ideograph", "Ideographic"},
    23935: {"Unified_Ideograph", "Ideographic"},
    23936: {"Unified_Ideograph", "Ideographic"},
    23937: {"Unified_Ideograph", "Ideographic"},
    23938: {"Unified_Ideograph", "Ideographic"},
    23939: {"Unified_Ideograph", "Ideographic"},
    23940: {"Unified_Ideograph", "Ideographic"},
    23941: {"Unified_Ideograph", "Ideographic"},
    23942: {"Unified_Ideograph", "Ideographic"},
    23943: {"Unified_Ideograph", "Ideographic"},
    23944: {"Unified_Ideograph", "Ideographic"},
    23945: {"Unified_Ideograph", "Ideographic"},
    23946: {"Unified_Ideograph", "Ideographic"},
    23947: {"Unified_Ideograph", "Ideographic"},
    23948: {"Unified_Ideograph", "Ideographic"},
    23949: {"Unified_Ideograph", "Ideographic"},
    23950: {"Unified_Ideograph", "Ideographic"},
    23951: {"Unified_Ideograph", "Ideographic"},
    23952: {"Unified_Ideograph", "Ideographic"},
    23953: {"Unified_Ideograph", "Ideographic"},
    23954: {"Unified_Ideograph", "Ideographic"},
    23955: {"Unified_Ideograph", "Ideographic"},
    23956: {"Unified_Ideograph", "Ideographic"},
    23957: {"Unified_Ideograph", "Ideographic"},
    23958: {"Unified_Ideograph", "Ideographic"},
    23959: {"Unified_Ideograph", "Ideographic"},
    23960: {"Unified_Ideograph", "Ideographic"},
    23961: {"Unified_Ideograph", "Ideographic"},
    23962: {"Unified_Ideograph", "Ideographic"},
    23963: {"Unified_Ideograph", "Ideographic"},
    23964: {"Unified_Ideograph", "Ideographic"},
    23965: {"Unified_Ideograph", "Ideographic"},
    23966: {"Unified_Ideograph", "Ideographic"},
    23967: {"Unified_Ideograph", "Ideographic"},
    23968: {"Unified_Ideograph", "Ideographic"},
    23969: {"Unified_Ideograph", "Ideographic"},
    23970: {"Unified_Ideograph", "Ideographic"},
    23971: {"Unified_Ideograph", "Ideographic"},
    23972: {"Unified_Ideograph", "Ideographic"},
    23973: {"Unified_Ideograph", "Ideographic"},
    23974: {"Unified_Ideograph", "Ideographic"},
    23975: {"Unified_Ideograph", "Ideographic"},
    23976: {"Unified_Ideograph", "Ideographic"},
    23977: {"Unified_Ideograph", "Ideographic"},
    23978: {"Unified_Ideograph", "Ideographic"},
    23979: {"Unified_Ideograph", "Ideographic"},
    23980: {"Unified_Ideograph", "Ideographic"},
    23981: {"Unified_Ideograph", "Ideographic"},
    23982: {"Unified_Ideograph", "Ideographic"},
    23983: {"Unified_Ideograph", "Ideographic"},
    23984: {"Unified_Ideograph", "Ideographic"},
    23985: {"Unified_Ideograph", "Ideographic"},
    23986: {"Unified_Ideograph", "Ideographic"},
    23987: {"Unified_Ideograph", "Ideographic"},
    23988: {"Unified_Ideograph", "Ideographic"},
    23989: {"Unified_Ideograph", "Ideographic"},
    23990: {"Unified_Ideograph", "Ideographic"},
    23991: {"Unified_Ideograph", "Ideographic"},
    23992: {"Unified_Ideograph", "Ideographic"},
    23993: {"Unified_Ideograph", "Ideographic"},
    23994: {"Unified_Ideograph", "Ideographic"},
    23995: {"Unified_Ideograph", "Ideographic"},
    23996: {"Unified_Ideograph", "Ideographic"},
    23997: {"Unified_Ideograph", "Ideographic"},
    23998: {"Unified_Ideograph", "Ideographic"},
    23999: {"Unified_Ideograph", "Ideographic"},
    24000: {"Unified_Ideograph", "Ideographic"},
    24001: {"Unified_Ideograph", "Ideographic"},
    24002: {"Unified_Ideograph", "Ideographic"},
    24003: {"Unified_Ideograph", "Ideographic"},
    24004: {"Unified_Ideograph", "Ideographic"},
    24005: {"Unified_Ideograph", "Ideographic"},
    24006: {"Unified_Ideograph", "Ideographic"},
    24007: {"Unified_Ideograph", "Ideographic"},
    24008: {"Unified_Ideograph", "Ideographic"},
    24009: {"Unified_Ideograph", "Ideographic"},
    24010: {"Unified_Ideograph", "Ideographic"},
    24011: {"Unified_Ideograph", "Ideographic"},
    24012: {"Unified_Ideograph", "Ideographic"},
    24013: {"Unified_Ideograph", "Ideographic"},
    24014: {"Unified_Ideograph", "Ideographic"},
    24015: {"Unified_Ideograph", "Ideographic"},
    24016: {"Unified_Ideograph", "Ideographic"},
    24017: {"Unified_Ideograph", "Ideographic"},
    24018: {"Unified_Ideograph", "Ideographic"},
    24019: {"Unified_Ideograph", "Ideographic"},
    24020: {"Unified_Ideograph", "Ideographic"},
    24021: {"Unified_Ideograph", "Ideographic"},
    24022: {"Unified_Ideograph", "Ideographic"},
    24023: {"Unified_Ideograph", "Ideographic"},
    24024: {"Unified_Ideograph", "Ideographic"},
    24025: {"Unified_Ideograph", "Ideographic"},
    24026: {"Unified_Ideograph", "Ideographic"},
    24027: {"Unified_Ideograph", "Ideographic"},
    24028: {"Unified_Ideograph", "Ideographic"},
    24029: {"Unified_Ideograph", "Ideographic"},
    24030: {"Unified_Ideograph", "Ideographic"},
    24031: {"Unified_Ideograph", "Ideographic"},
    24032: {"Unified_Ideograph", "Ideographic"},
    24033: {"Unified_Ideograph", "Ideographic"},
    24034: {"Unified_Ideograph", "Ideographic"},
    24035: {"Unified_Ideograph", "Ideographic"},
    24036: {"Unified_Ideograph", "Ideographic"},
    24037: {"Unified_Ideograph", "Ideographic"},
    24038: {"Unified_Ideograph", "Ideographic"},
    24039: {"Unified_Ideograph", "Ideographic"},
    24040: {"Unified_Ideograph", "Ideographic"},
    24041: {"Unified_Ideograph", "Ideographic"},
    24042: {"Unified_Ideograph", "Ideographic"},
    24043: {"Unified_Ideograph", "Ideographic"},
    24044: {"Unified_Ideograph", "Ideographic"},
    24045: {"Unified_Ideograph", "Ideographic"},
    24046: {"Unified_Ideograph", "Ideographic"},
    24047: {"Unified_Ideograph", "Ideographic"},
    24048: {"Unified_Ideograph", "Ideographic"},
    24049: {"Unified_Ideograph", "Ideographic"},
    24050: {"Unified_Ideograph", "Ideographic"},
    24051: {"Unified_Ideograph", "Ideographic"},
    24052: {"Unified_Ideograph", "Ideographic"},
    24053: {"Unified_Ideograph", "Ideographic"},
    24054: {"Unified_Ideograph", "Ideographic"},
    24055: {"Unified_Ideograph", "Ideographic"},
    24056: {"Unified_Ideograph", "Ideographic"},
    24057: {"Unified_Ideograph", "Ideographic"},
    24058: {"Unified_Ideograph", "Ideographic"},
    24059: {"Unified_Ideograph", "Ideographic"},
    24060: {"Unified_Ideograph", "Ideographic"},
    24061: {"Unified_Ideograph", "Ideographic"},
    24062: {"Unified_Ideograph", "Ideographic"},
    24063: {"Unified_Ideograph", "Ideographic"},
    24064: {"Unified_Ideograph", "Ideographic"},
    24065: {"Unified_Ideograph", "Ideographic"},
    24066: {"Unified_Ideograph", "Ideographic"},
    24067: {"Unified_Ideograph", "Ideographic"},
    24068: {"Unified_Ideograph", "Ideographic"},
    24069: {"Unified_Ideograph", "Ideographic"},
    24070: {"Unified_Ideograph", "Ideographic"},
    24071: {"Unified_Ideograph", "Ideographic"},
    24072: {"Unified_Ideograph", "Ideographic"},
    24073: {"Unified_Ideograph", "Ideographic"},
    24074: {"Unified_Ideograph", "Ideographic"},
    24075: {"Unified_Ideograph", "Ideographic"},
    24076: {"Unified_Ideograph", "Ideographic"},
    24077: {"Unified_Ideograph", "Ideographic"},
    24078: {"Unified_Ideograph", "Ideographic"},
    24079: {"Unified_Ideograph", "Ideographic"},
    24080: {"Unified_Ideograph", "Ideographic"},
    24081: {"Unified_Ideograph", "Ideographic"},
    24082: {"Unified_Ideograph", "Ideographic"},
    24083: {"Unified_Ideograph", "Ideographic"},
    24084: {"Unified_Ideograph", "Ideographic"},
    24085: {"Unified_Ideograph", "Ideographic"},
    24086: {"Unified_Ideograph", "Ideographic"},
    24087: {"Unified_Ideograph", "Ideographic"},
    24088: {"Unified_Ideograph", "Ideographic"},
    24089: {"Unified_Ideograph", "Ideographic"},
    24090: {"Unified_Ideograph", "Ideographic"},
    24091: {"Unified_Ideograph", "Ideographic"},
    24092: {"Unified_Ideograph", "Ideographic"},
    24093: {"Unified_Ideograph", "Ideographic"},
    24094: {"Unified_Ideograph", "Ideographic"},
    24095: {"Unified_Ideograph", "Ideographic"},
    24096: {"Unified_Ideograph", "Ideographic"},
    24097: {"Unified_Ideograph", "Ideographic"},
    24098: {"Unified_Ideograph", "Ideographic"},
    24099: {"Unified_Ideograph", "Ideographic"},
    24100: {"Unified_Ideograph", "Ideographic"},
    24101: {"Unified_Ideograph", "Ideographic"},
    24102: {"Unified_Ideograph", "Ideographic"},
    24103: {"Unified_Ideograph", "Ideographic"},
    24104: {"Unified_Ideograph", "Ideographic"},
    24105: {"Unified_Ideograph", "Ideographic"},
    24106: {"Unified_Ideograph", "Ideographic"},
    24107: {"Unified_Ideograph", "Ideographic"},
    24108: {"Unified_Ideograph", "Ideographic"},
    24109: {"Unified_Ideograph", "Ideographic"},
    24110: {"Unified_Ideograph", "Ideographic"},
    24111: {"Unified_Ideograph", "Ideographic"},
    24112: {"Unified_Ideograph", "Ideographic"},
    24113: {"Unified_Ideograph", "Ideographic"},
    24114: {"Unified_Ideograph", "Ideographic"},
    24115: {"Unified_Ideograph", "Ideographic"},
    24116: {"Unified_Ideograph", "Ideographic"},
    24117: {"Unified_Ideograph", "Ideographic"},
    24118: {"Unified_Ideograph", "Ideographic"},
    24119: {"Unified_Ideograph", "Ideographic"},
    24120: {"Unified_Ideograph", "Ideographic"},
    24121: {"Unified_Ideograph", "Ideographic"},
    24122: {"Unified_Ideograph", "Ideographic"},
    24123: {"Unified_Ideograph", "Ideographic"},
    24124: {"Unified_Ideograph", "Ideographic"},
    24125: {"Unified_Ideograph", "Ideographic"},
    24126: {"Unified_Ideograph", "Ideographic"},
    24127: {"Unified_Ideograph", "Ideographic"},
    24128: {"Unified_Ideograph", "Ideographic"},
    24129: {"Unified_Ideograph", "Ideographic"},
    24130: {"Unified_Ideograph", "Ideographic"},
    24131: {"Unified_Ideograph", "Ideographic"},
    24132: {"Unified_Ideograph", "Ideographic"},
    24133: {"Unified_Ideograph", "Ideographic"},
    24134: {"Unified_Ideograph", "Ideographic"},
    24135: {"Unified_Ideograph", "Ideographic"},
    24136: {"Unified_Ideograph", "Ideographic"},
    24137: {"Unified_Ideograph", "Ideographic"},
    24138: {"Unified_Ideograph", "Ideographic"},
    24139: {"Unified_Ideograph", "Ideographic"},
    24140: {"Unified_Ideograph", "Ideographic"},
    24141: {"Unified_Ideograph", "Ideographic"},
    24142: {"Unified_Ideograph", "Ideographic"},
    24143: {"Unified_Ideograph", "Ideographic"},
    24144: {"Unified_Ideograph", "Ideographic"},
    24145: {"Unified_Ideograph", "Ideographic"},
    24146: {"Unified_Ideograph", "Ideographic"},
    24147: {"Unified_Ideograph", "Ideographic"},
    24148: {"Unified_Ideograph", "Ideographic"},
    24149: {"Unified_Ideograph", "Ideographic"},
    24150: {"Unified_Ideograph", "Ideographic"},
    24151: {"Unified_Ideograph", "Ideographic"},
    24152: {"Unified_Ideograph", "Ideographic"},
    24153: {"Unified_Ideograph", "Ideographic"},
    24154: {"Unified_Ideograph", "Ideographic"},
    24155: {"Unified_Ideograph", "Ideographic"},
    24156: {"Unified_Ideograph", "Ideographic"},
    24157: {"Unified_Ideograph", "Ideographic"},
    24158: {"Unified_Ideograph", "Ideographic"},
    24159: {"Unified_Ideograph", "Ideographic"},
    24160: {"Unified_Ideograph", "Ideographic"},
    24161: {"Unified_Ideograph", "Ideographic"},
    24162: {"Unified_Ideograph", "Ideographic"},
    24163: {"Unified_Ideograph", "Ideographic"},
    24164: {"Unified_Ideograph", "Ideographic"},
    24165: {"Unified_Ideograph", "Ideographic"},
    24166: {"Unified_Ideograph", "Ideographic"},
    24167: {"Unified_Ideograph", "Ideographic"},
    24168: {"Unified_Ideograph", "Ideographic"},
    24169: {"Unified_Ideograph", "Ideographic"},
    24170: {"Unified_Ideograph", "Ideographic"},
    24171: {"Unified_Ideograph", "Ideographic"},
    24172: {"Unified_Ideograph", "Ideographic"},
    24173: {"Unified_Ideograph", "Ideographic"},
    24174: {"Unified_Ideograph", "Ideographic"},
    24175: {"Unified_Ideograph", "Ideographic"},
    24176: {"Unified_Ideograph", "Ideographic"},
    24177: {"Unified_Ideograph", "Ideographic"},
    24178: {"Unified_Ideograph", "Ideographic"},
    24179: {"Unified_Ideograph", "Ideographic"},
    24180: {"Unified_Ideograph", "Ideographic"},
    24181: {"Unified_Ideograph", "Ideographic"},
    24182: {"Unified_Ideograph", "Ideographic"},
    24183: {"Unified_Ideograph", "Ideographic"},
    24184: {"Unified_Ideograph", "Ideographic"},
    24185: {"Unified_Ideograph", "Ideographic"},
    24186: {"Unified_Ideograph", "Ideographic"},
    24187: {"Unified_Ideograph", "Ideographic"},
    24188: {"Unified_Ideograph", "Ideographic"},
    24189: {"Unified_Ideograph", "Ideographic"},
    24190: {"Unified_Ideograph", "Ideographic"},
    24191: {"Unified_Ideograph", "Ideographic"},
    24192: {"Unified_Ideograph", "Ideographic"},
    24193: {"Unified_Ideograph", "Ideographic"},
    24194: {"Unified_Ideograph", "Ideographic"},
    24195: {"Unified_Ideograph", "Ideographic"},
    24196: {"Unified_Ideograph", "Ideographic"},
    24197: {"Unified_Ideograph", "Ideographic"},
    24198: {"Unified_Ideograph", "Ideographic"},
    24199: {"Unified_Ideograph", "Ideographic"},
    24200: {"Unified_Ideograph", "Ideographic"},
    24201: {"Unified_Ideograph", "Ideographic"},
    24202: {"Unified_Ideograph", "Ideographic"},
    24203: {"Unified_Ideograph", "Ideographic"},
    24204: {"Unified_Ideograph", "Ideographic"},
    24205: {"Unified_Ideograph", "Ideographic"},
    24206: {"Unified_Ideograph", "Ideographic"},
    24207: {"Unified_Ideograph", "Ideographic"},
    24208: {"Unified_Ideograph", "Ideographic"},
    24209: {"Unified_Ideograph", "Ideographic"},
    24210: {"Unified_Ideograph", "Ideographic"},
    24211: {"Unified_Ideograph", "Ideographic"},
    24212: {"Unified_Ideograph", "Ideographic"},
    24213: {"Unified_Ideograph", "Ideographic"},
    24214: {"Unified_Ideograph", "Ideographic"},
    24215: {"Unified_Ideograph", "Ideographic"},
    24216: {"Unified_Ideograph", "Ideographic"},
    24217: {"Unified_Ideograph", "Ideographic"},
    24218: {"Unified_Ideograph", "Ideographic"},
    24219: {"Unified_Ideograph", "Ideographic"},
    24220: {"Unified_Ideograph", "Ideographic"},
    24221: {"Unified_Ideograph", "Ideographic"},
    24222: {"Unified_Ideograph", "Ideographic"},
    24223: {"Unified_Ideograph", "Ideographic"},
    24224: {"Unified_Ideograph", "Ideographic"},
    24225: {"Unified_Ideograph", "Ideographic"},
    24226: {"Unified_Ideograph", "Ideographic"},
    24227: {"Unified_Ideograph", "Ideographic"},
    24228: {"Unified_Ideograph", "Ideographic"},
    24229: {"Unified_Ideograph", "Ideographic"},
    24230: {"Unified_Ideograph", "Ideographic"},
    24231: {"Unified_Ideograph", "Ideographic"},
    24232: {"Unified_Ideograph", "Ideographic"},
    24233: {"Unified_Ideograph", "Ideographic"},
    24234: {"Unified_Ideograph", "Ideographic"},
    24235: {"Unified_Ideograph", "Ideographic"},
    24236: {"Unified_Ideograph", "Ideographic"},
    24237: {"Unified_Ideograph", "Ideographic"},
    24238: {"Unified_Ideograph", "Ideographic"},
    24239: {"Unified_Ideograph", "Ideographic"},
    24240: {"Unified_Ideograph", "Ideographic"},
    24241: {"Unified_Ideograph", "Ideographic"},
    24242: {"Unified_Ideograph", "Ideographic"},
    24243: {"Unified_Ideograph", "Ideographic"},
    24244: {"Unified_Ideograph", "Ideographic"},
    24245: {"Unified_Ideograph", "Ideographic"},
    24246: {"Unified_Ideograph", "Ideographic"},
    24247: {"Unified_Ideograph", "Ideographic"},
    24248: {"Unified_Ideograph", "Ideographic"},
    24249: {"Unified_Ideograph", "Ideographic"},
    24250: {"Unified_Ideograph", "Ideographic"},
    24251: {"Unified_Ideograph", "Ideographic"},
    24252: {"Unified_Ideograph", "Ideographic"},
    24253: {"Unified_Ideograph", "Ideographic"},
    24254: {"Unified_Ideograph", "Ideographic"},
    24255: {"Unified_Ideograph", "Ideographic"},
    24256: {"Unified_Ideograph", "Ideographic"},
    24257: {"Unified_Ideograph", "Ideographic"},
    24258: {"Unified_Ideograph", "Ideographic"},
    24259: {"Unified_Ideograph", "Ideographic"},
    24260: {"Unified_Ideograph", "Ideographic"},
    24261: {"Unified_Ideograph", "Ideographic"},
    24262: {"Unified_Ideograph", "Ideographic"},
    24263: {"Unified_Ideograph", "Ideographic"},
    24264: {"Unified_Ideograph", "Ideographic"},
    24265: {"Unified_Ideograph", "Ideographic"},
    24266: {"Unified_Ideograph", "Ideographic"},
    24267: {"Unified_Ideograph", "Ideographic"},
    24268: {"Unified_Ideograph", "Ideographic"},
    24269: {"Unified_Ideograph", "Ideographic"},
    24270: {"Unified_Ideograph", "Ideographic"},
    24271: {"Unified_Ideograph", "Ideographic"},
    24272: {"Unified_Ideograph", "Ideographic"},
    24273: {"Unified_Ideograph", "Ideographic"},
    24274: {"Unified_Ideograph", "Ideographic"},
    24275: {"Unified_Ideograph", "Ideographic"},
    24276: {"Unified_Ideograph", "Ideographic"},
    24277: {"Unified_Ideograph", "Ideographic"},
    24278: {"Unified_Ideograph", "Ideographic"},
    24279: {"Unified_Ideograph", "Ideographic"},
    24280: {"Unified_Ideograph", "Ideographic"},
    24281: {"Unified_Ideograph", "Ideographic"},
    24282: {"Unified_Ideograph", "Ideographic"},
    24283: {"Unified_Ideograph", "Ideographic"},
    24284: {"Unified_Ideograph", "Ideographic"},
    24285: {"Unified_Ideograph", "Ideographic"},
    24286: {"Unified_Ideograph", "Ideographic"},
    24287: {"Unified_Ideograph", "Ideographic"},
    24288: {"Unified_Ideograph", "Ideographic"},
    24289: {"Unified_Ideograph", "Ideographic"},
    24290: {"Unified_Ideograph", "Ideographic"},
    24291: {"Unified_Ideograph", "Ideographic"},
    24292: {"Unified_Ideograph", "Ideographic"},
    24293: {"Unified_Ideograph", "Ideographic"},
    24294: {"Unified_Ideograph", "Ideographic"},
    24295: {"Unified_Ideograph", "Ideographic"},
    24296: {"Unified_Ideograph", "Ideographic"},
    24297: {"Unified_Ideograph", "Ideographic"},
    24298: {"Unified_Ideograph", "Ideographic"},
    24299: {"Unified_Ideograph", "Ideographic"},
    24300: {"Unified_Ideograph", "Ideographic"},
    24301: {"Unified_Ideograph", "Ideographic"},
    24302: {"Unified_Ideograph", "Ideographic"},
    24303: {"Unified_Ideograph", "Ideographic"},
    24304: {"Unified_Ideograph", "Ideographic"},
    24305: {"Unified_Ideograph", "Ideographic"},
    24306: {"Unified_Ideograph", "Ideographic"},
    24307: {"Unified_Ideograph", "Ideographic"},
    24308: {"Unified_Ideograph", "Ideographic"},
    24309: {"Unified_Ideograph", "Ideographic"},
    24310: {"Unified_Ideograph", "Ideographic"},
    24311: {"Unified_Ideograph", "Ideographic"},
    24312: {"Unified_Ideograph", "Ideographic"},
    24313: {"Unified_Ideograph", "Ideographic"},
    24314: {"Unified_Ideograph", "Ideographic"},
    24315: {"Unified_Ideograph", "Ideographic"},
    24316: {"Unified_Ideograph", "Ideographic"},
    24317: {"Unified_Ideograph", "Ideographic"},
    24318: {"Unified_Ideograph", "Ideographic"},
    24319: {"Unified_Ideograph", "Ideographic"},
    24320: {"Unified_Ideograph", "Ideographic"},
    24321: {"Unified_Ideograph", "Ideographic"},
    24322: {"Unified_Ideograph", "Ideographic"},
    24323: {"Unified_Ideograph", "Ideographic"},
    24324: {"Unified_Ideograph", "Ideographic"},
    24325: {"Unified_Ideograph", "Ideographic"},
    24326: {"Unified_Ideograph", "Ideographic"},
    24327: {"Unified_Ideograph", "Ideographic"},
    24328: {"Unified_Ideograph", "Ideographic"},
    24329: {"Unified_Ideograph", "Ideographic"},
    24330: {"Unified_Ideograph", "Ideographic"},
    24331: {"Unified_Ideograph", "Ideographic"},
    24332: {"Unified_Ideograph", "Ideographic"},
    24333: {"Unified_Ideograph", "Ideographic"},
    24334: {"Unified_Ideograph", "Ideographic"},
    24335: {"Unified_Ideograph", "Ideographic"},
    24336: {"Unified_Ideograph", "Ideographic"},
    24337: {"Unified_Ideograph", "Ideographic"},
    24338: {"Unified_Ideograph", "Ideographic"},
    24339: {"Unified_Ideograph", "Ideographic"},
    24340: {"Unified_Ideograph", "Ideographic"},
    24341: {"Unified_Ideograph", "Ideographic"},
    24342: {"Unified_Ideograph", "Ideographic"},
    24343: {"Unified_Ideograph", "Ideographic"},
    24344: {"Unified_Ideograph", "Ideographic"},
    24345: {"Unified_Ideograph", "Ideographic"},
    24346: {"Unified_Ideograph", "Ideographic"},
    24347: {"Unified_Ideograph", "Ideographic"},
    24348: {"Unified_Ideograph", "Ideographic"},
    24349: {"Unified_Ideograph", "Ideographic"},
    24350: {"Unified_Ideograph", "Ideographic"},
    24351: {"Unified_Ideograph", "Ideographic"},
    24352: {"Unified_Ideograph", "Ideographic"},
    24353: {"Unified_Ideograph", "Ideographic"},
    24354: {"Unified_Ideograph", "Ideographic"},
    24355: {"Unified_Ideograph", "Ideographic"},
    24356: {"Unified_Ideograph", "Ideographic"},
    24357: {"Unified_Ideograph", "Ideographic"},
    24358: {"Unified_Ideograph", "Ideographic"},
    24359: {"Unified_Ideograph", "Ideographic"},
    24360: {"Unified_Ideograph", "Ideographic"},
    24361: {"Unified_Ideograph", "Ideographic"},
    24362: {"Unified_Ideograph", "Ideographic"},
    24363: {"Unified_Ideograph", "Ideographic"},
    24364: {"Unified_Ideograph", "Ideographic"},
    24365: {"Unified_Ideograph", "Ideographic"},
    24366: {"Unified_Ideograph", "Ideographic"},
    24367: {"Unified_Ideograph", "Ideographic"},
    24368: {"Unified_Ideograph", "Ideographic"},
    24369: {"Unified_Ideograph", "Ideographic"},
    24370: {"Unified_Ideograph", "Ideographic"},
    24371: {"Unified_Ideograph", "Ideographic"},
    24372: {"Unified_Ideograph", "Ideographic"},
    24373: {"Unified_Ideograph", "Ideographic"},
    24374: {"Unified_Ideograph", "Ideographic"},
    24375: {"Unified_Ideograph", "Ideographic"},
    24376: {"Unified_Ideograph", "Ideographic"},
    24377: {"Unified_Ideograph", "Ideographic"},
    24378: {"Unified_Ideograph", "Ideographic"},
    24379: {"Unified_Ideograph", "Ideographic"},
    24380: {"Unified_Ideograph", "Ideographic"},
    24381: {"Unified_Ideograph", "Ideographic"},
    24382: {"Unified_Ideograph", "Ideographic"},
    24383: {"Unified_Ideograph", "Ideographic"},
    24384: {"Unified_Ideograph", "Ideographic"},
    24385: {"Unified_Ideograph", "Ideographic"},
    24386: {"Unified_Ideograph", "Ideographic"},
    24387: {"Unified_Ideograph", "Ideographic"},
    24388: {"Unified_Ideograph", "Ideographic"},
    24389: {"Unified_Ideograph", "Ideographic"},
    24390: {"Unified_Ideograph", "Ideographic"},
    24391: {"Unified_Ideograph", "Ideographic"},
    24392: {"Unified_Ideograph", "Ideographic"},
    24393: {"Unified_Ideograph", "Ideographic"},
    24394: {"Unified_Ideograph", "Ideographic"},
    24395: {"Unified_Ideograph", "Ideographic"},
    24396: {"Unified_Ideograph", "Ideographic"},
    24397: {"Unified_Ideograph", "Ideographic"},
    24398: {"Unified_Ideograph", "Ideographic"},
    24399: {"Unified_Ideograph", "Ideographic"},
    24400: {"Unified_Ideograph", "Ideographic"},
    24401: {"Unified_Ideograph", "Ideographic"},
    24402: {"Unified_Ideograph", "Ideographic"},
    24403: {"Unified_Ideograph", "Ideographic"},
    24404: {"Unified_Ideograph", "Ideographic"},
    24405: {"Unified_Ideograph", "Ideographic"},
    24406: {"Unified_Ideograph", "Ideographic"},
    24407: {"Unified_Ideograph", "Ideographic"},
    24408: {"Unified_Ideograph", "Ideographic"},
    24409: {"Unified_Ideograph", "Ideographic"},
    24410: {"Unified_Ideograph", "Ideographic"},
    24411: {"Unified_Ideograph", "Ideographic"},
    24412: {"Unified_Ideograph", "Ideographic"},
    24413: {"Unified_Ideograph", "Ideographic"},
    24414: {"Unified_Ideograph", "Ideographic"},
    24415: {"Unified_Ideograph", "Ideographic"},
    24416: {"Unified_Ideograph", "Ideographic"},
    24417: {"Unified_Ideograph", "Ideographic"},
    24418: {"Unified_Ideograph", "Ideographic"},
    24419: {"Unified_Ideograph", "Ideographic"},
    24420: {"Unified_Ideograph", "Ideographic"},
    24421: {"Unified_Ideograph", "Ideographic"},
    24422: {"Unified_Ideograph", "Ideographic"},
    24423: {"Unified_Ideograph", "Ideographic"},
    24424: {"Unified_Ideograph", "Ideographic"},
    24425: {"Unified_Ideograph", "Ideographic"},
    24426: {"Unified_Ideograph", "Ideographic"},
    24427: {"Unified_Ideograph", "Ideographic"},
    24428: {"Unified_Ideograph", "Ideographic"},
    24429: {"Unified_Ideograph", "Ideographic"},
    24430: {"Unified_Ideograph", "Ideographic"},
    24431: {"Unified_Ideograph", "Ideographic"},
    24432: {"Unified_Ideograph", "Ideographic"},
    24433: {"Unified_Ideograph", "Ideographic"},
    24434: {"Unified_Ideograph", "Ideographic"},
    24435: {"Unified_Ideograph", "Ideographic"},
    24436: {"Unified_Ideograph", "Ideographic"},
    24437: {"Unified_Ideograph", "Ideographic"},
    24438: {"Unified_Ideograph", "Ideographic"},
    24439: {"Unified_Ideograph", "Ideographic"},
    24440: {"Unified_Ideograph", "Ideographic"},
    24441: {"Unified_Ideograph", "Ideographic"},
    24442: {"Unified_Ideograph", "Ideographic"},
    24443: {"Unified_Ideograph", "Ideographic"},
    24444: {"Unified_Ideograph", "Ideographic"},
    24445: {"Unified_Ideograph", "Ideographic"},
    24446: {"Unified_Ideograph", "Ideographic"},
    24447: {"Unified_Ideograph", "Ideographic"},
    24448: {"Unified_Ideograph", "Ideographic"},
    24449: {"Unified_Ideograph", "Ideographic"},
    24450: {"Unified_Ideograph", "Ideographic"},
    24451: {"Unified_Ideograph", "Ideographic"},
    24452: {"Unified_Ideograph", "Ideographic"},
    24453: {"Unified_Ideograph", "Ideographic"},
    24454: {"Unified_Ideograph", "Ideographic"},
    24455: {"Unified_Ideograph", "Ideographic"},
    24456: {"Unified_Ideograph", "Ideographic"},
    24457: {"Unified_Ideograph", "Ideographic"},
    24458: {"Unified_Ideograph", "Ideographic"},
    24459: {"Unified_Ideograph", "Ideographic"},
    24460: {"Unified_Ideograph", "Ideographic"},
    24461: {"Unified_Ideograph", "Ideographic"},
    24462: {"Unified_Ideograph", "Ideographic"},
    24463: {"Unified_Ideograph", "Ideographic"},
    24464: {"Unified_Ideograph", "Ideographic"},
    24465: {"Unified_Ideograph", "Ideographic"},
    24466: {"Unified_Ideograph", "Ideographic"},
    24467: {"Unified_Ideograph", "Ideographic"},
    24468: {"Unified_Ideograph", "Ideographic"},
    24469: {"Unified_Ideograph", "Ideographic"},
    24470: {"Unified_Ideograph", "Ideographic"},
    24471: {"Unified_Ideograph", "Ideographic"},
    24472: {"Unified_Ideograph", "Ideographic"},
    24473: {"Unified_Ideograph", "Ideographic"},
    24474: {"Unified_Ideograph", "Ideographic"},
    24475: {"Unified_Ideograph", "Ideographic"},
    24476: {"Unified_Ideograph", "Ideographic"},
    24477: {"Unified_Ideograph", "Ideographic"},
    24478: {"Unified_Ideograph", "Ideographic"},
    24479: {"Unified_Ideograph", "Ideographic"},
    24480: {"Unified_Ideograph", "Ideographic"},
    24481: {"Unified_Ideograph", "Ideographic"},
    24482: {"Unified_Ideograph", "Ideographic"},
    24483: {"Unified_Ideograph", "Ideographic"},
    24484: {"Unified_Ideograph", "Ideographic"},
    24485: {"Unified_Ideograph", "Ideographic"},
    24486: {"Unified_Ideograph", "Ideographic"},
    24487: {"Unified_Ideograph", "Ideographic"},
    24488: {"Unified_Ideograph", "Ideographic"},
    24489: {"Unified_Ideograph", "Ideographic"},
    24490: {"Unified_Ideograph", "Ideographic"},
    24491: {"Unified_Ideograph", "Ideographic"},
    24492: {"Unified_Ideograph", "Ideographic"},
    24493: {"Unified_Ideograph", "Ideographic"},
    24494: {"Unified_Ideograph", "Ideographic"},
    24495: {"Unified_Ideograph", "Ideographic"},
    24496: {"Unified_Ideograph", "Ideographic"},
    24497: {"Unified_Ideograph", "Ideographic"},
    24498: {"Unified_Ideograph", "Ideographic"},
    24499: {"Unified_Ideograph", "Ideographic"},
    24500: {"Unified_Ideograph", "Ideographic"},
    24501: {"Unified_Ideograph", "Ideographic"},
    24502: {"Unified_Ideograph", "Ideographic"},
    24503: {"Unified_Ideograph", "Ideographic"},
    24504: {"Unified_Ideograph", "Ideographic"},
    24505: {"Unified_Ideograph", "Ideographic"},
    24506: {"Unified_Ideograph", "Ideographic"},
    24507: {"Unified_Ideograph", "Ideographic"},
    24508: {"Unified_Ideograph", "Ideographic"},
    24509: {"Unified_Ideograph", "Ideographic"},
    24510: {"Unified_Ideograph", "Ideographic"},
    24511: {"Unified_Ideograph", "Ideographic"},
    24512: {"Unified_Ideograph", "Ideographic"},
    24513: {"Unified_Ideograph", "Ideographic"},
    24514: {"Unified_Ideograph", "Ideographic"},
    24515: {"Unified_Ideograph", "Ideographic"},
    24516: {"Unified_Ideograph", "Ideographic"},
    24517: {"Unified_Ideograph", "Ideographic"},
    24518: {"Unified_Ideograph", "Ideographic"},
    24519: {"Unified_Ideograph", "Ideographic"},
    24520: {"Unified_Ideograph", "Ideographic"},
    24521: {"Unified_Ideograph", "Ideographic"},
    24522: {"Unified_Ideograph", "Ideographic"},
    24523: {"Unified_Ideograph", "Ideographic"},
    24524: {"Unified_Ideograph", "Ideographic"},
    24525: {"Unified_Ideograph", "Ideographic"},
    24526: {"Unified_Ideograph", "Ideographic"},
    24527: {"Unified_Ideograph", "Ideographic"},
    24528: {"Unified_Ideograph", "Ideographic"},
    24529: {"Unified_Ideograph", "Ideographic"},
    24530: {"Unified_Ideograph", "Ideographic"},
    24531: {"Unified_Ideograph", "Ideographic"},
    24532: {"Unified_Ideograph", "Ideographic"},
    24533: {"Unified_Ideograph", "Ideographic"},
    24534: {"Unified_Ideograph", "Ideographic"},
    24535: {"Unified_Ideograph", "Ideographic"},
    24536: {"Unified_Ideograph", "Ideographic"},
    24537: {"Unified_Ideograph", "Ideographic"},
    24538: {"Unified_Ideograph", "Ideographic"},
    24539: {"Unified_Ideograph", "Ideographic"},
    24540: {"Unified_Ideograph", "Ideographic"},
    24541: {"Unified_Ideograph", "Ideographic"},
    24542: {"Unified_Ideograph", "Ideographic"},
    24543: {"Unified_Ideograph", "Ideographic"},
    24544: {"Unified_Ideograph", "Ideographic"},
    24545: {"Unified_Ideograph", "Ideographic"},
    24546: {"Unified_Ideograph", "Ideographic"},
    24547: {"Unified_Ideograph", "Ideographic"},
    24548: {"Unified_Ideograph", "Ideographic"},
    24549: {"Unified_Ideograph", "Ideographic"},
    24550: {"Unified_Ideograph", "Ideographic"},
    24551: {"Unified_Ideograph", "Ideographic"},
    24552: {"Unified_Ideograph", "Ideographic"},
    24553: {"Unified_Ideograph", "Ideographic"},
    24554: {"Unified_Ideograph", "Ideographic"},
    24555: {"Unified_Ideograph", "Ideographic"},
    24556: {"Unified_Ideograph", "Ideographic"},
    24557: {"Unified_Ideograph", "Ideographic"},
    24558: {"Unified_Ideograph", "Ideographic"},
    24559: {"Unified_Ideograph", "Ideographic"},
    24560: {"Unified_Ideograph", "Ideographic"},
    24561: {"Unified_Ideograph", "Ideographic"},
    24562: {"Unified_Ideograph", "Ideographic"},
    24563: {"Unified_Ideograph", "Ideographic"},
    24564: {"Unified_Ideograph", "Ideographic"},
    24565: {"Unified_Ideograph", "Ideographic"},
    24566: {"Unified_Ideograph", "Ideographic"},
    24567: {"Unified_Ideograph", "Ideographic"},
    24568: {"Unified_Ideograph", "Ideographic"},
    24569: {"Unified_Ideograph", "Ideographic"},
    24570: {"Unified_Ideograph", "Ideographic"},
    24571: {"Unified_Ideograph", "Ideographic"},
    24572: {"Unified_Ideograph", "Ideographic"},
    24573: {"Unified_Ideograph", "Ideographic"},
    24574: {"Unified_Ideograph", "Ideographic"},
    24575: {"Unified_Ideograph", "Ideographic"},
    24576: {"Unified_Ideograph", "Ideographic"},
    24577: {"Unified_Ideograph", "Ideographic"},
    24578: {"Unified_Ideograph", "Ideographic"},
    24579: {"Unified_Ideograph", "Ideographic"},
    24580: {"Unified_Ideograph", "Ideographic"},
    24581: {"Unified_Ideograph", "Ideographic"},
    24582: {"Unified_Ideograph", "Ideographic"},
    24583: {"Unified_Ideograph", "Ideographic"},
    24584: {"Unified_Ideograph", "Ideographic"},
    24585: {"Unified_Ideograph", "Ideographic"},
    24586: {"Unified_Ideograph", "Ideographic"},
    24587: {"Unified_Ideograph", "Ideographic"},
    24588: {"Unified_Ideograph", "Ideographic"},
    24589: {"Unified_Ideograph", "Ideographic"},
    24590: {"Unified_Ideograph", "Ideographic"},
    24591: {"Unified_Ideograph", "Ideographic"},
    24592: {"Unified_Ideograph", "Ideographic"},
    24593: {"Unified_Ideograph", "Ideographic"},
    24594: {"Unified_Ideograph", "Ideographic"},
    24595: {"Unified_Ideograph", "Ideographic"},
    24596: {"Unified_Ideograph", "Ideographic"},
    24597: {"Unified_Ideograph", "Ideographic"},
    24598: {"Unified_Ideograph", "Ideographic"},
    24599: {"Unified_Ideograph", "Ideographic"},
    24600: {"Unified_Ideograph", "Ideographic"},
    24601: {"Unified_Ideograph", "Ideographic"},
    24602: {"Unified_Ideograph", "Ideographic"},
    24603: {"Unified_Ideograph", "Ideographic"},
    24604: {"Unified_Ideograph", "Ideographic"},
    24605: {"Unified_Ideograph", "Ideographic"},
    24606: {"Unified_Ideograph", "Ideographic"},
    24607: {"Unified_Ideograph", "Ideographic"},
    24608: {"Unified_Ideograph", "Ideographic"},
    24609: {"Unified_Ideograph", "Ideographic"},
    24610: {"Unified_Ideograph", "Ideographic"},
    24611: {"Unified_Ideograph", "Ideographic"},
    24612: {"Unified_Ideograph", "Ideographic"},
    24613: {"Unified_Ideograph", "Ideographic"},
    24614: {"Unified_Ideograph", "Ideographic"},
    24615: {"Unified_Ideograph", "Ideographic"},
    24616: {"Unified_Ideograph", "Ideographic"},
    24617: {"Unified_Ideograph", "Ideographic"},
    24618: {"Unified_Ideograph", "Ideographic"},
    24619: {"Unified_Ideograph", "Ideographic"},
    24620: {"Unified_Ideograph", "Ideographic"},
    24621: {"Unified_Ideograph", "Ideographic"},
    24622: {"Unified_Ideograph", "Ideographic"},
    24623: {"Unified_Ideograph", "Ideographic"},
    24624: {"Unified_Ideograph", "Ideographic"},
    24625: {"Unified_Ideograph", "Ideographic"},
    24626: {"Unified_Ideograph", "Ideographic"},
    24627: {"Unified_Ideograph", "Ideographic"},
    24628: {"Unified_Ideograph", "Ideographic"},
    24629: {"Unified_Ideograph", "Ideographic"},
    24630: {"Unified_Ideograph", "Ideographic"},
    24631: {"Unified_Ideograph", "Ideographic"},
    24632: {"Unified_Ideograph", "Ideographic"},
    24633: {"Unified_Ideograph", "Ideographic"},
    24634: {"Unified_Ideograph", "Ideographic"},
    24635: {"Unified_Ideograph", "Ideographic"},
    24636: {"Unified_Ideograph", "Ideographic"},
    24637: {"Unified_Ideograph", "Ideographic"},
    24638: {"Unified_Ideograph", "Ideographic"},
    24639: {"Unified_Ideograph", "Ideographic"},
    24640: {"Unified_Ideograph", "Ideographic"},
    24641: {"Unified_Ideograph", "Ideographic"},
    24642: {"Unified_Ideograph", "Ideographic"},
    24643: {"Unified_Ideograph", "Ideographic"},
    24644: {"Unified_Ideograph", "Ideographic"},
    24645: {"Unified_Ideograph", "Ideographic"},
    24646: {"Unified_Ideograph", "Ideographic"},
    24647: {"Unified_Ideograph", "Ideographic"},
    24648: {"Unified_Ideograph", "Ideographic"},
    24649: {"Unified_Ideograph", "Ideographic"},
    24650: {"Unified_Ideograph", "Ideographic"},
    24651: {"Unified_Ideograph", "Ideographic"},
    24652: {"Unified_Ideograph", "Ideographic"},
    24653: {"Unified_Ideograph", "Ideographic"},
    24654: {"Unified_Ideograph", "Ideographic"},
    24655: {"Unified_Ideograph", "Ideographic"},
    24656: {"Unified_Ideograph", "Ideographic"},
    24657: {"Unified_Ideograph", "Ideographic"},
    24658: {"Unified_Ideograph", "Ideographic"},
    24659: {"Unified_Ideograph", "Ideographic"},
    24660: {"Unified_Ideograph", "Ideographic"},
    24661: {"Unified_Ideograph", "Ideographic"},
    24662: {"Unified_Ideograph", "Ideographic"},
    24663: {"Unified_Ideograph", "Ideographic"},
    24664: {"Unified_Ideograph", "Ideographic"},
    24665: {"Unified_Ideograph", "Ideographic"},
    24666: {"Unified_Ideograph", "Ideographic"},
    24667: {"Unified_Ideograph", "Ideographic"},
    24668: {"Unified_Ideograph", "Ideographic"},
    24669: {"Unified_Ideograph", "Ideographic"},
    24670: {"Unified_Ideograph", "Ideographic"},
    24671: {"Unified_Ideograph", "Ideographic"},
    24672: {"Unified_Ideograph", "Ideographic"},
    24673: {"Unified_Ideograph", "Ideographic"},
    24674: {"Unified_Ideograph", "Ideographic"},
    24675: {"Unified_Ideograph", "Ideographic"},
    24676: {"Unified_Ideograph", "Ideographic"},
    24677: {"Unified_Ideograph", "Ideographic"},
    24678: {"Unified_Ideograph", "Ideographic"},
    24679: {"Unified_Ideograph", "Ideographic"},
    24680: {"Unified_Ideograph", "Ideographic"},
    24681: {"Unified_Ideograph", "Ideographic"},
    24682: {"Unified_Ideograph", "Ideographic"},
    24683: {"Unified_Ideograph", "Ideographic"},
    24684: {"Unified_Ideograph", "Ideographic"},
    24685: {"Unified_Ideograph", "Ideographic"},
    24686: {"Unified_Ideograph", "Ideographic"},
    24687: {"Unified_Ideograph", "Ideographic"},
    24688: {"Unified_Ideograph", "Ideographic"},
    24689: {"Unified_Ideograph", "Ideographic"},
    24690: {"Unified_Ideograph", "Ideographic"},
    24691: {"Unified_Ideograph", "Ideographic"},
    24692: {"Unified_Ideograph", "Ideographic"},
    24693: {"Unified_Ideograph", "Ideographic"},
    24694: {"Unified_Ideograph", "Ideographic"},
    24695: {"Unified_Ideograph", "Ideographic"},
    24696: {"Unified_Ideograph", "Ideographic"},
    24697: {"Unified_Ideograph", "Ideographic"},
    24698: {"Unified_Ideograph", "Ideographic"},
    24699: {"Unified_Ideograph", "Ideographic"},
    24700: {"Unified_Ideograph", "Ideographic"},
    24701: {"Unified_Ideograph", "Ideographic"},
    24702: {"Unified_Ideograph", "Ideographic"},
    24703: {"Unified_Ideograph", "Ideographic"},
    24704: {"Unified_Ideograph", "Ideographic"},
    24705: {"Unified_Ideograph", "Ideographic"},
    24706: {"Unified_Ideograph", "Ideographic"},
    24707: {"Unified_Ideograph", "Ideographic"},
    24708: {"Unified_Ideograph", "Ideographic"},
    24709: {"Unified_Ideograph", "Ideographic"},
    24710: {"Unified_Ideograph", "Ideographic"},
    24711: {"Unified_Ideograph", "Ideographic"},
    24712: {"Unified_Ideograph", "Ideographic"},
    24713: {"Unified_Ideograph", "Ideographic"},
    24714: {"Unified_Ideograph", "Ideographic"},
    24715: {"Unified_Ideograph", "Ideographic"},
    24716: {"Unified_Ideograph", "Ideographic"},
    24717: {"Unified_Ideograph", "Ideographic"},
    24718: {"Unified_Ideograph", "Ideographic"},
    24719: {"Unified_Ideograph", "Ideographic"},
    24720: {"Unified_Ideograph", "Ideographic"},
    24721: {"Unified_Ideograph", "Ideographic"},
    24722: {"Unified_Ideograph", "Ideographic"},
    24723: {"Unified_Ideograph", "Ideographic"},
    24724: {"Unified_Ideograph", "Ideographic"},
    24725: {"Unified_Ideograph", "Ideographic"},
    24726: {"Unified_Ideograph", "Ideographic"},
    24727: {"Unified_Ideograph", "Ideographic"},
    24728: {"Unified_Ideograph", "Ideographic"},
    24729: {"Unified_Ideograph", "Ideographic"},
    24730: {"Unified_Ideograph", "Ideographic"},
    24731: {"Unified_Ideograph", "Ideographic"},
    24732: {"Unified_Ideograph", "Ideographic"},
    24733: {"Unified_Ideograph", "Ideographic"},
    24734: {"Unified_Ideograph", "Ideographic"},
    24735: {"Unified_Ideograph", "Ideographic"},
    24736: {"Unified_Ideograph", "Ideographic"},
    24737: {"Unified_Ideograph", "Ideographic"},
    24738: {"Unified_Ideograph", "Ideographic"},
    24739: {"Unified_Ideograph", "Ideographic"},
    24740: {"Unified_Ideograph", "Ideographic"},
    24741: {"Unified_Ideograph", "Ideographic"},
    24742: {"Unified_Ideograph", "Ideographic"},
    24743: {"Unified_Ideograph", "Ideographic"},
    24744: {"Unified_Ideograph", "Ideographic"},
    24745: {"Unified_Ideograph", "Ideographic"},
    24746: {"Unified_Ideograph", "Ideographic"},
    24747: {"Unified_Ideograph", "Ideographic"},
    24748: {"Unified_Ideograph", "Ideographic"},
    24749: {"Unified_Ideograph", "Ideographic"},
    24750: {"Unified_Ideograph", "Ideographic"},
    24751: {"Unified_Ideograph", "Ideographic"},
    24752: {"Unified_Ideograph", "Ideographic"},
    24753: {"Unified_Ideograph", "Ideographic"},
    24754: {"Unified_Ideograph", "Ideographic"},
    24755: {"Unified_Ideograph", "Ideographic"},
    24756: {"Unified_Ideograph", "Ideographic"},
    24757: {"Unified_Ideograph", "Ideographic"},
    24758: {"Unified_Ideograph", "Ideographic"},
    24759: {"Unified_Ideograph", "Ideographic"},
    24760: {"Unified_Ideograph", "Ideographic"},
    24761: {"Unified_Ideograph", "Ideographic"},
    24762: {"Unified_Ideograph", "Ideographic"},
    24763: {"Unified_Ideograph", "Ideographic"},
    24764: {"Unified_Ideograph", "Ideographic"},
    24765: {"Unified_Ideograph", "Ideographic"},
    24766: {"Unified_Ideograph", "Ideographic"},
    24767: {"Unified_Ideograph", "Ideographic"},
    24768: {"Unified_Ideograph", "Ideographic"},
    24769: {"Unified_Ideograph", "Ideographic"},
    24770: {"Unified_Ideograph", "Ideographic"},
    24771: {"Unified_Ideograph", "Ideographic"},
    24772: {"Unified_Ideograph", "Ideographic"},
    24773: {"Unified_Ideograph", "Ideographic"},
    24774: {"Unified_Ideograph", "Ideographic"},
    24775: {"Unified_Ideograph", "Ideographic"},
    24776: {"Unified_Ideograph", "Ideographic"},
    24777: {"Unified_Ideograph", "Ideographic"},
    24778: {"Unified_Ideograph", "Ideographic"},
    24779: {"Unified_Ideograph", "Ideographic"},
    24780: {"Unified_Ideograph", "Ideographic"},
    24781: {"Unified_Ideograph", "Ideographic"},
    24782: {"Unified_Ideograph", "Ideographic"},
    24783: {"Unified_Ideograph", "Ideographic"},
    24784: {"Unified_Ideograph", "Ideographic"},
    24785: {"Unified_Ideograph", "Ideographic"},
    24786: {"Unified_Ideograph", "Ideographic"},
    24787: {"Unified_Ideograph", "Ideographic"},
    24788: {"Unified_Ideograph", "Ideographic"},
    24789: {"Unified_Ideograph", "Ideographic"},
    24790: {"Unified_Ideograph", "Ideographic"},
    24791: {"Unified_Ideograph", "Ideographic"},
    24792: {"Unified_Ideograph", "Ideographic"},
    24793: {"Unified_Ideograph", "Ideographic"},
    24794: {"Unified_Ideograph", "Ideographic"},
    24795: {"Unified_Ideograph", "Ideographic"},
    24796: {"Unified_Ideograph", "Ideographic"},
    24797: {"Unified_Ideograph", "Ideographic"},
    24798: {"Unified_Ideograph", "Ideographic"},
    24799: {"Unified_Ideograph", "Ideographic"},
    24800: {"Unified_Ideograph", "Ideographic"},
    24801: {"Unified_Ideograph", "Ideographic"},
    24802: {"Unified_Ideograph", "Ideographic"},
    24803: {"Unified_Ideograph", "Ideographic"},
    24804: {"Unified_Ideograph", "Ideographic"},
    24805: {"Unified_Ideograph", "Ideographic"},
    24806: {"Unified_Ideograph", "Ideographic"},
    24807: {"Unified_Ideograph", "Ideographic"},
    24808: {"Unified_Ideograph", "Ideographic"},
    24809: {"Unified_Ideograph", "Ideographic"},
    24810: {"Unified_Ideograph", "Ideographic"},
    24811: {"Unified_Ideograph", "Ideographic"},
    24812: {"Unified_Ideograph", "Ideographic"},
    24813: {"Unified_Ideograph", "Ideographic"},
    24814: {"Unified_Ideograph", "Ideographic"},
    24815: {"Unified_Ideograph", "Ideographic"},
    24816: {"Unified_Ideograph", "Ideographic"},
    24817: {"Unified_Ideograph", "Ideographic"},
    24818: {"Unified_Ideograph", "Ideographic"},
    24819: {"Unified_Ideograph", "Ideographic"},
    24820: {"Unified_Ideograph", "Ideographic"},
    24821: {"Unified_Ideograph", "Ideographic"},
    24822: {"Unified_Ideograph", "Ideographic"},
    24823: {"Unified_Ideograph", "Ideographic"},
    24824: {"Unified_Ideograph", "Ideographic"},
    24825: {"Unified_Ideograph", "Ideographic"},
    24826: {"Unified_Ideograph", "Ideographic"},
    24827: {"Unified_Ideograph", "Ideographic"},
    24828: {"Unified_Ideograph", "Ideographic"},
    24829: {"Unified_Ideograph", "Ideographic"},
    24830: {"Unified_Ideograph", "Ideographic"},
    24831: {"Unified_Ideograph", "Ideographic"},
    24832: {"Unified_Ideograph", "Ideographic"},
    24833: {"Unified_Ideograph", "Ideographic"},
    24834: {"Unified_Ideograph", "Ideographic"},
    24835: {"Unified_Ideograph", "Ideographic"},
    24836: {"Unified_Ideograph", "Ideographic"},
    24837: {"Unified_Ideograph", "Ideographic"},
    24838: {"Unified_Ideograph", "Ideographic"},
    24839: {"Unified_Ideograph", "Ideographic"},
    24840: {"Unified_Ideograph", "Ideographic"},
    24841: {"Unified_Ideograph", "Ideographic"},
    24842: {"Unified_Ideograph", "Ideographic"},
    24843: {"Unified_Ideograph", "Ideographic"},
    24844: {"Unified_Ideograph", "Ideographic"},
    24845: {"Unified_Ideograph", "Ideographic"},
    24846: {"Unified_Ideograph", "Ideographic"},
    24847: {"Unified_Ideograph", "Ideographic"},
    24848: {"Unified_Ideograph", "Ideographic"},
    24849: {"Unified_Ideograph", "Ideographic"},
    24850: {"Unified_Ideograph", "Ideographic"},
    24851: {"Unified_Ideograph", "Ideographic"},
    24852: {"Unified_Ideograph", "Ideographic"},
    24853: {"Unified_Ideograph", "Ideographic"},
    24854: {"Unified_Ideograph", "Ideographic"},
    24855: {"Unified_Ideograph", "Ideographic"},
    24856: {"Unified_Ideograph", "Ideographic"},
    24857: {"Unified_Ideograph", "Ideographic"},
    24858: {"Unified_Ideograph", "Ideographic"},
    24859: {"Unified_Ideograph", "Ideographic"},
    24860: {"Unified_Ideograph", "Ideographic"},
    24861: {"Unified_Ideograph", "Ideographic"},
    24862: {"Unified_Ideograph", "Ideographic"},
    24863: {"Unified_Ideograph", "Ideographic"},
    24864: {"Unified_Ideograph", "Ideographic"},
    24865: {"Unified_Ideograph", "Ideographic"},
    24866: {"Unified_Ideograph", "Ideographic"},
    24867: {"Unified_Ideograph", "Ideographic"},
    24868: {"Unified_Ideograph", "Ideographic"},
    24869: {"Unified_Ideograph", "Ideographic"},
    24870: {"Unified_Ideograph", "Ideographic"},
    24871: {"Unified_Ideograph", "Ideographic"},
    24872: {"Unified_Ideograph", "Ideographic"},
    24873: {"Unified_Ideograph", "Ideographic"},
    24874: {"Unified_Ideograph", "Ideographic"},
    24875: {"Unified_Ideograph", "Ideographic"},
    24876: {"Unified_Ideograph", "Ideographic"},
    24877: {"Unified_Ideograph", "Ideographic"},
    24878: {"Unified_Ideograph", "Ideographic"},
    24879: {"Unified_Ideograph", "Ideographic"},
    24880: {"Unified_Ideograph", "Ideographic"},
    24881: {"Unified_Ideograph", "Ideographic"},
    24882: {"Unified_Ideograph", "Ideographic"},
    24883: {"Unified_Ideograph", "Ideographic"},
    24884: {"Unified_Ideograph", "Ideographic"},
    24885: {"Unified_Ideograph", "Ideographic"},
    24886: {"Unified_Ideograph", "Ideographic"},
    24887: {"Unified_Ideograph", "Ideographic"},
    24888: {"Unified_Ideograph", "Ideographic"},
    24889: {"Unified_Ideograph", "Ideographic"},
    24890: {"Unified_Ideograph", "Ideographic"},
    24891: {"Unified_Ideograph", "Ideographic"},
    24892: {"Unified_Ideograph", "Ideographic"},
    24893: {"Unified_Ideograph", "Ideographic"},
    24894: {"Unified_Ideograph", "Ideographic"},
    24895: {"Unified_Ideograph", "Ideographic"},
    24896: {"Unified_Ideograph", "Ideographic"},
    24897: {"Unified_Ideograph", "Ideographic"},
    24898: {"Unified_Ideograph", "Ideographic"},
    24899: {"Unified_Ideograph", "Ideographic"},
    24900: {"Unified_Ideograph", "Ideographic"},
    24901: {"Unified_Ideograph", "Ideographic"},
    24902: {"Unified_Ideograph", "Ideographic"},
    24903: {"Unified_Ideograph", "Ideographic"},
    24904: {"Unified_Ideograph", "Ideographic"},
    24905: {"Unified_Ideograph", "Ideographic"},
    24906: {"Unified_Ideograph", "Ideographic"},
    24907: {"Unified_Ideograph", "Ideographic"},
    24908: {"Unified_Ideograph", "Ideographic"},
    24909: {"Unified_Ideograph", "Ideographic"},
    24910: {"Unified_Ideograph", "Ideographic"},
    24911: {"Unified_Ideograph", "Ideographic"},
    24912: {"Unified_Ideograph", "Ideographic"},
    24913: {"Unified_Ideograph", "Ideographic"},
    24914: {"Unified_Ideograph", "Ideographic"},
    24915: {"Unified_Ideograph", "Ideographic"},
    24916: {"Unified_Ideograph", "Ideographic"},
    24917: {"Unified_Ideograph", "Ideographic"},
    24918: {"Unified_Ideograph", "Ideographic"},
    24919: {"Unified_Ideograph", "Ideographic"},
    24920: {"Unified_Ideograph", "Ideographic"},
    24921: {"Unified_Ideograph", "Ideographic"},
    24922: {"Unified_Ideograph", "Ideographic"},
    24923: {"Unified_Ideograph", "Ideographic"},
    24924: {"Unified_Ideograph", "Ideographic"},
    24925: {"Unified_Ideograph", "Ideographic"},
    24926: {"Unified_Ideograph", "Ideographic"},
    24927: {"Unified_Ideograph", "Ideographic"},
    24928: {"Unified_Ideograph", "Ideographic"},
    24929: {"Unified_Ideograph", "Ideographic"},
    24930: {"Unified_Ideograph", "Ideographic"},
    24931: {"Unified_Ideograph", "Ideographic"},
    24932: {"Unified_Ideograph", "Ideographic"},
    24933: {"Unified_Ideograph", "Ideographic"},
    24934: {"Unified_Ideograph", "Ideographic"},
    24935: {"Unified_Ideograph", "Ideographic"},
    24936: {"Unified_Ideograph", "Ideographic"},
    24937: {"Unified_Ideograph", "Ideographic"},
    24938: {"Unified_Ideograph", "Ideographic"},
    24939: {"Unified_Ideograph", "Ideographic"},
    24940: {"Unified_Ideograph", "Ideographic"},
    24941: {"Unified_Ideograph", "Ideographic"},
    24942: {"Unified_Ideograph", "Ideographic"},
    24943: {"Unified_Ideograph", "Ideographic"},
    24944: {"Unified_Ideograph", "Ideographic"},
    24945: {"Unified_Ideograph", "Ideographic"},
    24946: {"Unified_Ideograph", "Ideographic"},
    24947: {"Unified_Ideograph", "Ideographic"},
    24948: {"Unified_Ideograph", "Ideographic"},
    24949: {"Unified_Ideograph", "Ideographic"},
    24950: {"Unified_Ideograph", "Ideographic"},
    24951: {"Unified_Ideograph", "Ideographic"},
    24952: {"Unified_Ideograph", "Ideographic"},
    24953: {"Unified_Ideograph", "Ideographic"},
    24954: {"Unified_Ideograph", "Ideographic"},
    24955: {"Unified_Ideograph", "Ideographic"},
    24956: {"Unified_Ideograph", "Ideographic"},
    24957: {"Unified_Ideograph", "Ideographic"},
    24958: {"Unified_Ideograph", "Ideographic"},
    24959: {"Unified_Ideograph", "Ideographic"},
    24960: {"Unified_Ideograph", "Ideographic"},
    24961: {"Unified_Ideograph", "Ideographic"},
    24962: {"Unified_Ideograph", "Ideographic"},
    24963: {"Unified_Ideograph", "Ideographic"},
    24964: {"Unified_Ideograph", "Ideographic"},
    24965: {"Unified_Ideograph", "Ideographic"},
    24966: {"Unified_Ideograph", "Ideographic"},
    24967: {"Unified_Ideograph", "Ideographic"},
    24968: {"Unified_Ideograph", "Ideographic"},
    24969: {"Unified_Ideograph", "Ideographic"},
    24970: {"Unified_Ideograph", "Ideographic"},
    24971: {"Unified_Ideograph", "Ideographic"},
    24972: {"Unified_Ideograph", "Ideographic"},
    24973: {"Unified_Ideograph", "Ideographic"},
    24974: {"Unified_Ideograph", "Ideographic"},
    24975: {"Unified_Ideograph", "Ideographic"},
    24976: {"Unified_Ideograph", "Ideographic"},
    24977: {"Unified_Ideograph", "Ideographic"},
    24978: {"Unified_Ideograph", "Ideographic"},
    24979: {"Unified_Ideograph", "Ideographic"},
    24980: {"Unified_Ideograph", "Ideographic"},
    24981: {"Unified_Ideograph", "Ideographic"},
    24982: {"Unified_Ideograph", "Ideographic"},
    24983: {"Unified_Ideograph", "Ideographic"},
    24984: {"Unified_Ideograph", "Ideographic"},
    24985: {"Unified_Ideograph", "Ideographic"},
    24986: {"Unified_Ideograph", "Ideographic"},
    24987: {"Unified_Ideograph", "Ideographic"},
    24988: {"Unified_Ideograph", "Ideographic"},
    24989: {"Unified_Ideograph", "Ideographic"},
    24990: {"Unified_Ideograph", "Ideographic"},
    24991: {"Unified_Ideograph", "Ideographic"},
    24992: {"Unified_Ideograph", "Ideographic"},
    24993: {"Unified_Ideograph", "Ideographic"},
    24994: {"Unified_Ideograph", "Ideographic"},
    24995: {"Unified_Ideograph", "Ideographic"},
    24996: {"Unified_Ideograph", "Ideographic"},
    24997: {"Unified_Ideograph", "Ideographic"},
    24998: {"Unified_Ideograph", "Ideographic"},
    24999: {"Unified_Ideograph", "Ideographic"},
    25000: {"Unified_Ideograph", "Ideographic"},
    25001: {"Unified_Ideograph", "Ideographic"},
    25002: {"Unified_Ideograph", "Ideographic"},
    25003: {"Unified_Ideograph", "Ideographic"},
    25004: {"Unified_Ideograph", "Ideographic"},
    25005: {"Unified_Ideograph", "Ideographic"},
    25006: {"Unified_Ideograph", "Ideographic"},
    25007: {"Unified_Ideograph", "Ideographic"},
    25008: {"Unified_Ideograph", "Ideographic"},
    25009: {"Unified_Ideograph", "Ideographic"},
    25010: {"Unified_Ideograph", "Ideographic"},
    25011: {"Unified_Ideograph", "Ideographic"},
    25012: {"Unified_Ideograph", "Ideographic"},
    25013: {"Unified_Ideograph", "Ideographic"},
    25014: {"Unified_Ideograph", "Ideographic"},
    25015: {"Unified_Ideograph", "Ideographic"},
    25016: {"Unified_Ideograph", "Ideographic"},
    25017: {"Unified_Ideograph", "Ideographic"},
    25018: {"Unified_Ideograph", "Ideographic"},
    25019: {"Unified_Ideograph", "Ideographic"},
    25020: {"Unified_Ideograph", "Ideographic"},
    25021: {"Unified_Ideograph", "Ideographic"},
    25022: {"Unified_Ideograph", "Ideographic"},
    25023: {"Unified_Ideograph", "Ideographic"},
    25024: {"Unified_Ideograph", "Ideographic"},
    25025: {"Unified_Ideograph", "Ideographic"},
    25026: {"Unified_Ideograph", "Ideographic"},
    25027: {"Unified_Ideograph", "Ideographic"},
    25028: {"Unified_Ideograph", "Ideographic"},
    25029: {"Unified_Ideograph", "Ideographic"},
    25030: {"Unified_Ideograph", "Ideographic"},
    25031: {"Unified_Ideograph", "Ideographic"},
    25032: {"Unified_Ideograph", "Ideographic"},
    25033: {"Unified_Ideograph", "Ideographic"},
    25034: {"Unified_Ideograph", "Ideographic"},
    25035: {"Unified_Ideograph", "Ideographic"},
    25036: {"Unified_Ideograph", "Ideographic"},
    25037: {"Unified_Ideograph", "Ideographic"},
    25038: {"Unified_Ideograph", "Ideographic"},
    25039: {"Unified_Ideograph", "Ideographic"},
    25040: {"Unified_Ideograph", "Ideographic"},
    25041: {"Unified_Ideograph", "Ideographic"},
    25042: {"Unified_Ideograph", "Ideographic"},
    25043: {"Unified_Ideograph", "Ideographic"},
    25044: {"Unified_Ideograph", "Ideographic"},
    25045: {"Unified_Ideograph", "Ideographic"},
    25046: {"Unified_Ideograph", "Ideographic"},
    25047: {"Unified_Ideograph", "Ideographic"},
    25048: {"Unified_Ideograph", "Ideographic"},
    25049: {"Unified_Ideograph", "Ideographic"},
    25050: {"Unified_Ideograph", "Ideographic"},
    25051: {"Unified_Ideograph", "Ideographic"},
    25052: {"Unified_Ideograph", "Ideographic"},
    25053: {"Unified_Ideograph", "Ideographic"},
    25054: {"Unified_Ideograph", "Ideographic"},
    25055: {"Unified_Ideograph", "Ideographic"},
    25056: {"Unified_Ideograph", "Ideographic"},
    25057: {"Unified_Ideograph", "Ideographic"},
    25058: {"Unified_Ideograph", "Ideographic"},
    25059: {"Unified_Ideograph", "Ideographic"},
    25060: {"Unified_Ideograph", "Ideographic"},
    25061: {"Unified_Ideograph", "Ideographic"},
    25062: {"Unified_Ideograph", "Ideographic"},
    25063: {"Unified_Ideograph", "Ideographic"},
    25064: {"Unified_Ideograph", "Ideographic"},
    25065: {"Unified_Ideograph", "Ideographic"},
    25066: {"Unified_Ideograph", "Ideographic"},
    25067: {"Unified_Ideograph", "Ideographic"},
    25068: {"Unified_Ideograph", "Ideographic"},
    25069: {"Unified_Ideograph", "Ideographic"},
    25070: {"Unified_Ideograph", "Ideographic"},
    25071: {"Unified_Ideograph", "Ideographic"},
    25072: {"Unified_Ideograph", "Ideographic"},
    25073: {"Unified_Ideograph", "Ideographic"},
    25074: {"Unified_Ideograph", "Ideographic"},
    25075: {"Unified_Ideograph", "Ideographic"},
    25076: {"Unified_Ideograph", "Ideographic"},
    25077: {"Unified_Ideograph", "Ideographic"},
    25078: {"Unified_Ideograph", "Ideographic"},
    25079: {"Unified_Ideograph", "Ideographic"},
    25080: {"Unified_Ideograph", "Ideographic"},
    25081: {"Unified_Ideograph", "Ideographic"},
    25082: {"Unified_Ideograph", "Ideographic"},
    25083: {"Unified_Ideograph", "Ideographic"},
    25084: {"Unified_Ideograph", "Ideographic"},
    25085: {"Unified_Ideograph", "Ideographic"},
    25086: {"Unified_Ideograph", "Ideographic"},
    25087: {"Unified_Ideograph", "Ideographic"},
    25088: {"Unified_Ideograph", "Ideographic"},
    25089: {"Unified_Ideograph", "Ideographic"},
    25090: {"Unified_Ideograph", "Ideographic"},
    25091: {"Unified_Ideograph", "Ideographic"},
    25092: {"Unified_Ideograph", "Ideographic"},
    25093: {"Unified_Ideograph", "Ideographic"},
    25094: {"Unified_Ideograph", "Ideographic"},
    25095: {"Unified_Ideograph", "Ideographic"},
    25096: {"Unified_Ideograph", "Ideographic"},
    25097: {"Unified_Ideograph", "Ideographic"},
    25098: {"Unified_Ideograph", "Ideographic"},
    25099: {"Unified_Ideograph", "Ideographic"},
    25100: {"Unified_Ideograph", "Ideographic"},
    25101: {"Unified_Ideograph", "Ideographic"},
    25102: {"Unified_Ideograph", "Ideographic"},
    25103: {"Unified_Ideograph", "Ideographic"},
    25104: {"Unified_Ideograph", "Ideographic"},
    25105: {"Unified_Ideograph", "Ideographic"},
    25106: {"Unified_Ideograph", "Ideographic"},
    25107: {"Unified_Ideograph", "Ideographic"},
    25108: {"Unified_Ideograph", "Ideographic"},
    25109: {"Unified_Ideograph", "Ideographic"},
    25110: {"Unified_Ideograph", "Ideographic"},
    25111: {"Unified_Ideograph", "Ideographic"},
    25112: {"Unified_Ideograph", "Ideographic"},
    25113: {"Unified_Ideograph", "Ideographic"},
    25114: {"Unified_Ideograph", "Ideographic"},
    25115: {"Unified_Ideograph", "Ideographic"},
    25116: {"Unified_Ideograph", "Ideographic"},
    25117: {"Unified_Ideograph", "Ideographic"},
    25118: {"Unified_Ideograph", "Ideographic"},
    25119: {"Unified_Ideograph", "Ideographic"},
    25120: {"Unified_Ideograph", "Ideographic"},
    25121: {"Unified_Ideograph", "Ideographic"},
    25122: {"Unified_Ideograph", "Ideographic"},
    25123: {"Unified_Ideograph", "Ideographic"},
    25124: {"Unified_Ideograph", "Ideographic"},
    25125: {"Unified_Ideograph", "Ideographic"},
    25126: {"Unified_Ideograph", "Ideographic"},
    25127: {"Unified_Ideograph", "Ideographic"},
    25128: {"Unified_Ideograph", "Ideographic"},
    25129: {"Unified_Ideograph", "Ideographic"},
    25130: {"Unified_Ideograph", "Ideographic"},
    25131: {"Unified_Ideograph", "Ideographic"},
    25132: {"Unified_Ideograph", "Ideographic"},
    25133: {"Unified_Ideograph", "Ideographic"},
    25134: {"Unified_Ideograph", "Ideographic"},
    25135: {"Unified_Ideograph", "Ideographic"},
    25136: {"Unified_Ideograph", "Ideographic"},
    25137: {"Unified_Ideograph", "Ideographic"},
    25138: {"Unified_Ideograph", "Ideographic"},
    25139: {"Unified_Ideograph", "Ideographic"},
    25140: {"Unified_Ideograph", "Ideographic"},
    25141: {"Unified_Ideograph", "Ideographic"},
    25142: {"Unified_Ideograph", "Ideographic"},
    25143: {"Unified_Ideograph", "Ideographic"},
    25144: {"Unified_Ideograph", "Ideographic"},
    25145: {"Unified_Ideograph", "Ideographic"},
    25146: {"Unified_Ideograph", "Ideographic"},
    25147: {"Unified_Ideograph", "Ideographic"},
    25148: {"Unified_Ideograph", "Ideographic"},
    25149: {"Unified_Ideograph", "Ideographic"},
    25150: {"Unified_Ideograph", "Ideographic"},
    25151: {"Unified_Ideograph", "Ideographic"},
    25152: {"Unified_Ideograph", "Ideographic"},
    25153: {"Unified_Ideograph", "Ideographic"},
    25154: {"Unified_Ideograph", "Ideographic"},
    25155: {"Unified_Ideograph", "Ideographic"},
    25156: {"Unified_Ideograph", "Ideographic"},
    25157: {"Unified_Ideograph", "Ideographic"},
    25158: {"Unified_Ideograph", "Ideographic"},
    25159: {"Unified_Ideograph", "Ideographic"},
    25160: {"Unified_Ideograph", "Ideographic"},
    25161: {"Unified_Ideograph", "Ideographic"},
    25162: {"Unified_Ideograph", "Ideographic"},
    25163: {"Unified_Ideograph", "Ideographic"},
    25164: {"Unified_Ideograph", "Ideographic"},
    25165: {"Unified_Ideograph", "Ideographic"},
    25166: {"Unified_Ideograph", "Ideographic"},
    25167: {"Unified_Ideograph", "Ideographic"},
    25168: {"Unified_Ideograph", "Ideographic"},
    25169: {"Unified_Ideograph", "Ideographic"},
    25170: {"Unified_Ideograph", "Ideographic"},
    25171: {"Unified_Ideograph", "Ideographic"},
    25172: {"Unified_Ideograph", "Ideographic"},
    25173: {"Unified_Ideograph", "Ideographic"},
    25174: {"Unified_Ideograph", "Ideographic"},
    25175: {"Unified_Ideograph", "Ideographic"},
    25176: {"Unified_Ideograph", "Ideographic"},
    25177: {"Unified_Ideograph", "Ideographic"},
    25178: {"Unified_Ideograph", "Ideographic"},
    25179: {"Unified_Ideograph", "Ideographic"},
    25180: {"Unified_Ideograph", "Ideographic"},
    25181: {"Unified_Ideograph", "Ideographic"},
    25182: {"Unified_Ideograph", "Ideographic"},
    25183: {"Unified_Ideograph", "Ideographic"},
    25184: {"Unified_Ideograph", "Ideographic"},
    25185: {"Unified_Ideograph", "Ideographic"},
    25186: {"Unified_Ideograph", "Ideographic"},
    25187: {"Unified_Ideograph", "Ideographic"},
    25188: {"Unified_Ideograph", "Ideographic"},
    25189: {"Unified_Ideograph", "Ideographic"},
    25190: {"Unified_Ideograph", "Ideographic"},
    25191: {"Unified_Ideograph", "Ideographic"},
    25192: {"Unified_Ideograph", "Ideographic"},
    25193: {"Unified_Ideograph", "Ideographic"},
    25194: {"Unified_Ideograph", "Ideographic"},
    25195: {"Unified_Ideograph", "Ideographic"},
    25196: {"Unified_Ideograph", "Ideographic"},
    25197: {"Unified_Ideograph", "Ideographic"},
    25198: {"Unified_Ideograph", "Ideographic"},
    25199: {"Unified_Ideograph", "Ideographic"},
    25200: {"Unified_Ideograph", "Ideographic"},
    25201: {"Unified_Ideograph", "Ideographic"},
    25202: {"Unified_Ideograph", "Ideographic"},
    25203: {"Unified_Ideograph", "Ideographic"},
    25204: {"Unified_Ideograph", "Ideographic"},
    25205: {"Unified_Ideograph", "Ideographic"},
    25206: {"Unified_Ideograph", "Ideographic"},
    25207: {"Unified_Ideograph", "Ideographic"},
    25208: {"Unified_Ideograph", "Ideographic"},
    25209: {"Unified_Ideograph", "Ideographic"},
    25210: {"Unified_Ideograph", "Ideographic"},
    25211: {"Unified_Ideograph", "Ideographic"},
    25212: {"Unified_Ideograph", "Ideographic"},
    25213: {"Unified_Ideograph", "Ideographic"},
    25214: {"Unified_Ideograph", "Ideographic"},
    25215: {"Unified_Ideograph", "Ideographic"},
    25216: {"Unified_Ideograph", "Ideographic"},
    25217: {"Unified_Ideograph", "Ideographic"},
    25218: {"Unified_Ideograph", "Ideographic"},
    25219: {"Unified_Ideograph", "Ideographic"},
    25220: {"Unified_Ideograph", "Ideographic"},
    25221: {"Unified_Ideograph", "Ideographic"},
    25222: {"Unified_Ideograph", "Ideographic"},
    25223: {"Unified_Ideograph", "Ideographic"},
    25224: {"Unified_Ideograph", "Ideographic"},
    25225: {"Unified_Ideograph", "Ideographic"},
    25226: {"Unified_Ideograph", "Ideographic"},
    25227: {"Unified_Ideograph", "Ideographic"},
    25228: {"Unified_Ideograph", "Ideographic"},
    25229: {"Unified_Ideograph", "Ideographic"},
    25230: {"Unified_Ideograph", "Ideographic"},
    25231: {"Unified_Ideograph", "Ideographic"},
    25232: {"Unified_Ideograph", "Ideographic"},
    25233: {"Unified_Ideograph", "Ideographic"},
    25234: {"Unified_Ideograph", "Ideographic"},
    25235: {"Unified_Ideograph", "Ideographic"},
    25236: {"Unified_Ideograph", "Ideographic"},
    25237: {"Unified_Ideograph", "Ideographic"},
    25238: {"Unified_Ideograph", "Ideographic"},
    25239: {"Unified_Ideograph", "Ideographic"},
    25240: {"Unified_Ideograph", "Ideographic"},
    25241: {"Unified_Ideograph", "Ideographic"},
    25242: {"Unified_Ideograph", "Ideographic"},
    25243: {"Unified_Ideograph", "Ideographic"},
    25244: {"Unified_Ideograph", "Ideographic"},
    25245: {"Unified_Ideograph", "Ideographic"},
    25246: {"Unified_Ideograph", "Ideographic"},
    25247: {"Unified_Ideograph", "Ideographic"},
    25248: {"Unified_Ideograph", "Ideographic"},
    25249: {"Unified_Ideograph", "Ideographic"},
    25250: {"Unified_Ideograph", "Ideographic"},
    25251: {"Unified_Ideograph", "Ideographic"},
    25252: {"Unified_Ideograph", "Ideographic"},
    25253: {"Unified_Ideograph", "Ideographic"},
    25254: {"Unified_Ideograph", "Ideographic"},
    25255: {"Unified_Ideograph", "Ideographic"},
    25256: {"Unified_Ideograph", "Ideographic"},
    25257: {"Unified_Ideograph", "Ideographic"},
    25258: {"Unified_Ideograph", "Ideographic"},
    25259: {"Unified_Ideograph", "Ideographic"},
    25260: {"Unified_Ideograph", "Ideographic"},
    25261: {"Unified_Ideograph", "Ideographic"},
    25262: {"Unified_Ideograph", "Ideographic"},
    25263: {"Unified_Ideograph", "Ideographic"},
    25264: {"Unified_Ideograph", "Ideographic"},
    25265: {"Unified_Ideograph", "Ideographic"},
    25266: {"Unified_Ideograph", "Ideographic"},
    25267: {"Unified_Ideograph", "Ideographic"},
    25268: {"Unified_Ideograph", "Ideographic"},
    25269: {"Unified_Ideograph", "Ideographic"},
    25270: {"Unified_Ideograph", "Ideographic"},
    25271: {"Unified_Ideograph", "Ideographic"},
    25272: {"Unified_Ideograph", "Ideographic"},
    25273: {"Unified_Ideograph", "Ideographic"},
    25274: {"Unified_Ideograph", "Ideographic"},
    25275: {"Unified_Ideograph", "Ideographic"},
    25276: {"Unified_Ideograph", "Ideographic"},
    25277: {"Unified_Ideograph", "Ideographic"},
    25278: {"Unified_Ideograph", "Ideographic"},
    25279: {"Unified_Ideograph", "Ideographic"},
    25280: {"Unified_Ideograph", "Ideographic"},
    25281: {"Unified_Ideograph", "Ideographic"},
    25282: {"Unified_Ideograph", "Ideographic"},
    25283: {"Unified_Ideograph", "Ideographic"},
    25284: {"Unified_Ideograph", "Ideographic"},
    25285: {"Unified_Ideograph", "Ideographic"},
    25286: {"Unified_Ideograph", "Ideographic"},
    25287: {"Unified_Ideograph", "Ideographic"},
    25288: {"Unified_Ideograph", "Ideographic"},
    25289: {"Unified_Ideograph", "Ideographic"},
    25290: {"Unified_Ideograph", "Ideographic"},
    25291: {"Unified_Ideograph", "Ideographic"},
    25292: {"Unified_Ideograph", "Ideographic"},
    25293: {"Unified_Ideograph", "Ideographic"},
    25294: {"Unified_Ideograph", "Ideographic"},
    25295: {"Unified_Ideograph", "Ideographic"},
    25296: {"Unified_Ideograph", "Ideographic"},
    25297: {"Unified_Ideograph", "Ideographic"},
    25298: {"Unified_Ideograph", "Ideographic"},
    25299: {"Unified_Ideograph", "Ideographic"},
    25300: {"Unified_Ideograph", "Ideographic"},
    25301: {"Unified_Ideograph", "Ideographic"},
    25302: {"Unified_Ideograph", "Ideographic"},
    25303: {"Unified_Ideograph", "Ideographic"},
    25304: {"Unified_Ideograph", "Ideographic"},
    25305: {"Unified_Ideograph", "Ideographic"},
    25306: {"Unified_Ideograph", "Ideographic"},
    25307: {"Unified_Ideograph", "Ideographic"},
    25308: {"Unified_Ideograph", "Ideographic"},
    25309: {"Unified_Ideograph", "Ideographic"},
    25310: {"Unified_Ideograph", "Ideographic"},
    25311: {"Unified_Ideograph", "Ideographic"},
    25312: {"Unified_Ideograph", "Ideographic"},
    25313: {"Unified_Ideograph", "Ideographic"},
    25314: {"Unified_Ideograph", "Ideographic"},
    25315: {"Unified_Ideograph", "Ideographic"},
    25316: {"Unified_Ideograph", "Ideographic"},
    25317: {"Unified_Ideograph", "Ideographic"},
    25318: {"Unified_Ideograph", "Ideographic"},
    25319: {"Unified_Ideograph", "Ideographic"},
    25320: {"Unified_Ideograph", "Ideographic"},
    25321: {"Unified_Ideograph", "Ideographic"},
    25322: {"Unified_Ideograph", "Ideographic"},
    25323: {"Unified_Ideograph", "Ideographic"},
    25324: {"Unified_Ideograph", "Ideographic"},
    25325: {"Unified_Ideograph", "Ideographic"},
    25326: {"Unified_Ideograph", "Ideographic"},
    25327: {"Unified_Ideograph", "Ideographic"},
    25328: {"Unified_Ideograph", "Ideographic"},
    25329: {"Unified_Ideograph", "Ideographic"},
    25330: {"Unified_Ideograph", "Ideographic"},
    25331: {"Unified_Ideograph", "Ideographic"},
    25332: {"Unified_Ideograph", "Ideographic"},
    25333: {"Unified_Ideograph", "Ideographic"},
    25334: {"Unified_Ideograph", "Ideographic"},
    25335: {"Unified_Ideograph", "Ideographic"},
    25336: {"Unified_Ideograph", "Ideographic"},
    25337: {"Unified_Ideograph", "Ideographic"},
    25338: {"Unified_Ideograph", "Ideographic"},
    25339: {"Unified_Ideograph", "Ideographic"},
    25340: {"Unified_Ideograph", "Ideographic"},
    25341: {"Unified_Ideograph", "Ideographic"},
    25342: {"Unified_Ideograph", "Ideographic"},
    25343: {"Unified_Ideograph", "Ideographic"},
    25344: {"Unified_Ideograph", "Ideographic"},
    25345: {"Unified_Ideograph", "Ideographic"},
    25346: {"Unified_Ideograph", "Ideographic"},
    25347: {"Unified_Ideograph", "Ideographic"},
    25348: {"Unified_Ideograph", "Ideographic"},
    25349: {"Unified_Ideograph", "Ideographic"},
    25350: {"Unified_Ideograph", "Ideographic"},
    25351: {"Unified_Ideograph", "Ideographic"},
    25352: {"Unified_Ideograph", "Ideographic"},
    25353: {"Unified_Ideograph", "Ideographic"},
    25354: {"Unified_Ideograph", "Ideographic"},
    25355: {"Unified_Ideograph", "Ideographic"},
    25356: {"Unified_Ideograph", "Ideographic"},
    25357: {"Unified_Ideograph", "Ideographic"},
    25358: {"Unified_Ideograph", "Ideographic"},
    25359: {"Unified_Ideograph", "Ideographic"},
    25360: {"Unified_Ideograph", "Ideographic"},
    25361: {"Unified_Ideograph", "Ideographic"},
    25362: {"Unified_Ideograph", "Ideographic"},
    25363: {"Unified_Ideograph", "Ideographic"},
    25364: {"Unified_Ideograph", "Ideographic"},
    25365: {"Unified_Ideograph", "Ideographic"},
    25366: {"Unified_Ideograph", "Ideographic"},
    25367: {"Unified_Ideograph", "Ideographic"},
    25368: {"Unified_Ideograph", "Ideographic"},
    25369: {"Unified_Ideograph", "Ideographic"},
    25370: {"Unified_Ideograph", "Ideographic"},
    25371: {"Unified_Ideograph", "Ideographic"},
    25372: {"Unified_Ideograph", "Ideographic"},
    25373: {"Unified_Ideograph", "Ideographic"},
    25374: {"Unified_Ideograph", "Ideographic"},
    25375: {"Unified_Ideograph", "Ideographic"},
    25376: {"Unified_Ideograph", "Ideographic"},
    25377: {"Unified_Ideograph", "Ideographic"},
    25378: {"Unified_Ideograph", "Ideographic"},
    25379: {"Unified_Ideograph", "Ideographic"},
    25380: {"Unified_Ideograph", "Ideographic"},
    25381: {"Unified_Ideograph", "Ideographic"},
    25382: {"Unified_Ideograph", "Ideographic"},
    25383: {"Unified_Ideograph", "Ideographic"},
    25384: {"Unified_Ideograph", "Ideographic"},
    25385: {"Unified_Ideograph", "Ideographic"},
    25386: {"Unified_Ideograph", "Ideographic"},
    25387: {"Unified_Ideograph", "Ideographic"},
    25388: {"Unified_Ideograph", "Ideographic"},
    25389: {"Unified_Ideograph", "Ideographic"},
    25390: {"Unified_Ideograph", "Ideographic"},
    25391: {"Unified_Ideograph", "Ideographic"},
    25392: {"Unified_Ideograph", "Ideographic"},
    25393: {"Unified_Ideograph", "Ideographic"},
    25394: {"Unified_Ideograph", "Ideographic"},
    25395: {"Unified_Ideograph", "Ideographic"},
    25396: {"Unified_Ideograph", "Ideographic"},
    25397: {"Unified_Ideograph", "Ideographic"},
    25398: {"Unified_Ideograph", "Ideographic"},
    25399: {"Unified_Ideograph", "Ideographic"},
    25400: {"Unified_Ideograph", "Ideographic"},
    25401: {"Unified_Ideograph", "Ideographic"},
    25402: {"Unified_Ideograph", "Ideographic"},
    25403: {"Unified_Ideograph", "Ideographic"},
    25404: {"Unified_Ideograph", "Ideographic"},
    25405: {"Unified_Ideograph", "Ideographic"},
    25406: {"Unified_Ideograph", "Ideographic"},
    25407: {"Unified_Ideograph", "Ideographic"},
    25408: {"Unified_Ideograph", "Ideographic"},
    25409: {"Unified_Ideograph", "Ideographic"},
    25410: {"Unified_Ideograph", "Ideographic"},
    25411: {"Unified_Ideograph", "Ideographic"},
    25412: {"Unified_Ideograph", "Ideographic"},
    25413: {"Unified_Ideograph", "Ideographic"},
    25414: {"Unified_Ideograph", "Ideographic"},
    25415: {"Unified_Ideograph", "Ideographic"},
    25416: {"Unified_Ideograph", "Ideographic"},
    25417: {"Unified_Ideograph", "Ideographic"},
    25418: {"Unified_Ideograph", "Ideographic"},
    25419: {"Unified_Ideograph", "Ideographic"},
    25420: {"Unified_Ideograph", "Ideographic"},
    25421: {"Unified_Ideograph", "Ideographic"},
    25422: {"Unified_Ideograph", "Ideographic"},
    25423: {"Unified_Ideograph", "Ideographic"},
    25424: {"Unified_Ideograph", "Ideographic"},
    25425: {"Unified_Ideograph", "Ideographic"},
    25426: {"Unified_Ideograph", "Ideographic"},
    25427: {"Unified_Ideograph", "Ideographic"},
    25428: {"Unified_Ideograph", "Ideographic"},
    25429: {"Unified_Ideograph", "Ideographic"},
    25430: {"Unified_Ideograph", "Ideographic"},
    25431: {"Unified_Ideograph", "Ideographic"},
    25432: {"Unified_Ideograph", "Ideographic"},
    25433: {"Unified_Ideograph", "Ideographic"},
    25434: {"Unified_Ideograph", "Ideographic"},
    25435: {"Unified_Ideograph", "Ideographic"},
    25436: {"Unified_Ideograph", "Ideographic"},
    25437: {"Unified_Ideograph", "Ideographic"},
    25438: {"Unified_Ideograph", "Ideographic"},
    25439: {"Unified_Ideograph", "Ideographic"},
    25440: {"Unified_Ideograph", "Ideographic"},
    25441: {"Unified_Ideograph", "Ideographic"},
    25442: {"Unified_Ideograph", "Ideographic"},
    25443: {"Unified_Ideograph", "Ideographic"},
    25444: {"Unified_Ideograph", "Ideographic"},
    25445: {"Unified_Ideograph", "Ideographic"},
    25446: {"Unified_Ideograph", "Ideographic"},
    25447: {"Unified_Ideograph", "Ideographic"},
    25448: {"Unified_Ideograph", "Ideographic"},
    25449: {"Unified_Ideograph", "Ideographic"},
    25450: {"Unified_Ideograph", "Ideographic"},
    25451: {"Unified_Ideograph", "Ideographic"},
    25452: {"Unified_Ideograph", "Ideographic"},
    25453: {"Unified_Ideograph", "Ideographic"},
    25454: {"Unified_Ideograph", "Ideographic"},
    25455: {"Unified_Ideograph", "Ideographic"},
    25456: {"Unified_Ideograph", "Ideographic"},
    25457: {"Unified_Ideograph", "Ideographic"},
    25458: {"Unified_Ideograph", "Ideographic"},
    25459: {"Unified_Ideograph", "Ideographic"},
    25460: {"Unified_Ideograph", "Ideographic"},
    25461: {"Unified_Ideograph", "Ideographic"},
    25462: {"Unified_Ideograph", "Ideographic"},
    25463: {"Unified_Ideograph", "Ideographic"},
    25464: {"Unified_Ideograph", "Ideographic"},
    25465: {"Unified_Ideograph", "Ideographic"},
    25466: {"Unified_Ideograph", "Ideographic"},
    25467: {"Unified_Ideograph", "Ideographic"},
    25468: {"Unified_Ideograph", "Ideographic"},
    25469: {"Unified_Ideograph", "Ideographic"},
    25470: {"Unified_Ideograph", "Ideographic"},
    25471: {"Unified_Ideograph", "Ideographic"},
    25472: {"Unified_Ideograph", "Ideographic"},
    25473: {"Unified_Ideograph", "Ideographic"},
    25474: {"Unified_Ideograph", "Ideographic"},
    25475: {"Unified_Ideograph", "Ideographic"},
    25476: {"Unified_Ideograph", "Ideographic"},
    25477: {"Unified_Ideograph", "Ideographic"},
    25478: {"Unified_Ideograph", "Ideographic"},
    25479: {"Unified_Ideograph", "Ideographic"},
    25480: {"Unified_Ideograph", "Ideographic"},
    25481: {"Unified_Ideograph", "Ideographic"},
    25482: {"Unified_Ideograph", "Ideographic"},
    25483: {"Unified_Ideograph", "Ideographic"},
    25484: {"Unified_Ideograph", "Ideographic"},
    25485: {"Unified_Ideograph", "Ideographic"},
    25486: {"Unified_Ideograph", "Ideographic"},
    25487: {"Unified_Ideograph", "Ideographic"},
    25488: {"Unified_Ideograph", "Ideographic"},
    25489: {"Unified_Ideograph", "Ideographic"},
    25490: {"Unified_Ideograph", "Ideographic"},
    25491: {"Unified_Ideograph", "Ideographic"},
    25492: {"Unified_Ideograph", "Ideographic"},
    25493: {"Unified_Ideograph", "Ideographic"},
    25494: {"Unified_Ideograph", "Ideographic"},
    25495: {"Unified_Ideograph", "Ideographic"},
    25496: {"Unified_Ideograph", "Ideographic"},
    25497: {"Unified_Ideograph", "Ideographic"},
    25498: {"Unified_Ideograph", "Ideographic"},
    25499: {"Unified_Ideograph", "Ideographic"},
    25500: {"Unified_Ideograph", "Ideographic"},
    25501: {"Unified_Ideograph", "Ideographic"},
    25502: {"Unified_Ideograph", "Ideographic"},
    25503: {"Unified_Ideograph", "Ideographic"},
    25504: {"Unified_Ideograph", "Ideographic"},
    25505: {"Unified_Ideograph", "Ideographic"},
    25506: {"Unified_Ideograph", "Ideographic"},
    25507: {"Unified_Ideograph", "Ideographic"},
    25508: {"Unified_Ideograph", "Ideographic"},
    25509: {"Unified_Ideograph", "Ideographic"},
    25510: {"Unified_Ideograph", "Ideographic"},
    25511: {"Unified_Ideograph", "Ideographic"},
    25512: {"Unified_Ideograph", "Ideographic"},
    25513: {"Unified_Ideograph", "Ideographic"},
    25514: {"Unified_Ideograph", "Ideographic"},
    25515: {"Unified_Ideograph", "Ideographic"},
    25516: {"Unified_Ideograph", "Ideographic"},
    25517: {"Unified_Ideograph", "Ideographic"},
    25518: {"Unified_Ideograph", "Ideographic"},
    25519: {"Unified_Ideograph", "Ideographic"},
    25520: {"Unified_Ideograph", "Ideographic"},
    25521: {"Unified_Ideograph", "Ideographic"},
    25522: {"Unified_Ideograph", "Ideographic"},
    25523: {"Unified_Ideograph", "Ideographic"},
    25524: {"Unified_Ideograph", "Ideographic"},
    25525: {"Unified_Ideograph", "Ideographic"},
    25526: {"Unified_Ideograph", "Ideographic"},
    25527: {"Unified_Ideograph", "Ideographic"},
    25528: {"Unified_Ideograph", "Ideographic"},
    25529: {"Unified_Ideograph", "Ideographic"},
    25530: {"Unified_Ideograph", "Ideographic"},
    25531: {"Unified_Ideograph", "Ideographic"},
    25532: {"Unified_Ideograph", "Ideographic"},
    25533: {"Unified_Ideograph", "Ideographic"},
    25534: {"Unified_Ideograph", "Ideographic"},
    25535: {"Unified_Ideograph", "Ideographic"},
    25536: {"Unified_Ideograph", "Ideographic"},
    25537: {"Unified_Ideograph", "Ideographic"},
    25538: {"Unified_Ideograph", "Ideographic"},
    25539: {"Unified_Ideograph", "Ideographic"},
    25540: {"Unified_Ideograph", "Ideographic"},
    25541: {"Unified_Ideograph", "Ideographic"},
    25542: {"Unified_Ideograph", "Ideographic"},
    25543: {"Unified_Ideograph", "Ideographic"},
    25544: {"Unified_Ideograph", "Ideographic"},
    25545: {"Unified_Ideograph", "Ideographic"},
    25546: {"Unified_Ideograph", "Ideographic"},
    25547: {"Unified_Ideograph", "Ideographic"},
    25548: {"Unified_Ideograph", "Ideographic"},
    25549: {"Unified_Ideograph", "Ideographic"},
    25550: {"Unified_Ideograph", "Ideographic"},
    25551: {"Unified_Ideograph", "Ideographic"},
    25552: {"Unified_Ideograph", "Ideographic"},
    25553: {"Unified_Ideograph", "Ideographic"},
    25554: {"Unified_Ideograph", "Ideographic"},
    25555: {"Unified_Ideograph", "Ideographic"},
    25556: {"Unified_Ideograph", "Ideographic"},
    25557: {"Unified_Ideograph", "Ideographic"},
    25558: {"Unified_Ideograph", "Ideographic"},
    25559: {"Unified_Ideograph", "Ideographic"},
    25560: {"Unified_Ideograph", "Ideographic"},
    25561: {"Unified_Ideograph", "Ideographic"},
    25562: {"Unified_Ideograph", "Ideographic"},
    25563: {"Unified_Ideograph", "Ideographic"},
    25564: {"Unified_Ideograph", "Ideographic"},
    25565: {"Unified_Ideograph", "Ideographic"},
    25566: {"Unified_Ideograph", "Ideographic"},
    25567: {"Unified_Ideograph", "Ideographic"},
    25568: {"Unified_Ideograph", "Ideographic"},
    25569: {"Unified_Ideograph", "Ideographic"},
    25570: {"Unified_Ideograph", "Ideographic"},
    25571: {"Unified_Ideograph", "Ideographic"},
    25572: {"Unified_Ideograph", "Ideographic"},
    25573: {"Unified_Ideograph", "Ideographic"},
    25574: {"Unified_Ideograph", "Ideographic"},
    25575: {"Unified_Ideograph", "Ideographic"},
    25576: {"Unified_Ideograph", "Ideographic"},
    25577: {"Unified_Ideograph", "Ideographic"},
    25578: {"Unified_Ideograph", "Ideographic"},
    25579: {"Unified_Ideograph", "Ideographic"},
    25580: {"Unified_Ideograph", "Ideographic"},
    25581: {"Unified_Ideograph", "Ideographic"},
    25582: {"Unified_Ideograph", "Ideographic"},
    25583: {"Unified_Ideograph", "Ideographic"},
    25584: {"Unified_Ideograph", "Ideographic"},
    25585: {"Unified_Ideograph", "Ideographic"},
    25586: {"Unified_Ideograph", "Ideographic"},
    25587: {"Unified_Ideograph", "Ideographic"},
    25588: {"Unified_Ideograph", "Ideographic"},
    25589: {"Unified_Ideograph", "Ideographic"},
    25590: {"Unified_Ideograph", "Ideographic"},
    25591: {"Unified_Ideograph", "Ideographic"},
    25592: {"Unified_Ideograph", "Ideographic"},
    25593: {"Unified_Ideograph", "Ideographic"},
    25594: {"Unified_Ideograph", "Ideographic"},
    25595: {"Unified_Ideograph", "Ideographic"},
    25596: {"Unified_Ideograph", "Ideographic"},
    25597: {"Unified_Ideograph", "Ideographic"},
    25598: {"Unified_Ideograph", "Ideographic"},
    25599: {"Unified_Ideograph", "Ideographic"},
    25600: {"Unified_Ideograph", "Ideographic"},
    25601: {"Unified_Ideograph", "Ideographic"},
    25602: {"Unified_Ideograph", "Ideographic"},
    25603: {"Unified_Ideograph", "Ideographic"},
    25604: {"Unified_Ideograph", "Ideographic"},
    25605: {"Unified_Ideograph", "Ideographic"},
    25606: {"Unified_Ideograph", "Ideographic"},
    25607: {"Unified_Ideograph", "Ideographic"},
    25608: {"Unified_Ideograph", "Ideographic"},
    25609: {"Unified_Ideograph", "Ideographic"},
    25610: {"Unified_Ideograph", "Ideographic"},
    25611: {"Unified_Ideograph", "Ideographic"},
    25612: {"Unified_Ideograph", "Ideographic"},
    25613: {"Unified_Ideograph", "Ideographic"},
    25614: {"Unified_Ideograph", "Ideographic"},
    25615: {"Unified_Ideograph", "Ideographic"},
    25616: {"Unified_Ideograph", "Ideographic"},
    25617: {"Unified_Ideograph", "Ideographic"},
    25618: {"Unified_Ideograph", "Ideographic"},
    25619: {"Unified_Ideograph", "Ideographic"},
    25620: {"Unified_Ideograph", "Ideographic"},
    25621: {"Unified_Ideograph", "Ideographic"},
    25622: {"Unified_Ideograph", "Ideographic"},
    25623: {"Unified_Ideograph", "Ideographic"},
    25624: {"Unified_Ideograph", "Ideographic"},
    25625: {"Unified_Ideograph", "Ideographic"},
    25626: {"Unified_Ideograph", "Ideographic"},
    25627: {"Unified_Ideograph", "Ideographic"},
    25628: {"Unified_Ideograph", "Ideographic"},
    25629: {"Unified_Ideograph", "Ideographic"},
    25630: {"Unified_Ideograph", "Ideographic"},
    25631: {"Unified_Ideograph", "Ideographic"},
    25632: {"Unified_Ideograph", "Ideographic"},
    25633: {"Unified_Ideograph", "Ideographic"},
    25634: {"Unified_Ideograph", "Ideographic"},
    25635: {"Unified_Ideograph", "Ideographic"},
    25636: {"Unified_Ideograph", "Ideographic"},
    25637: {"Unified_Ideograph", "Ideographic"},
    25638: {"Unified_Ideograph", "Ideographic"},
    25639: {"Unified_Ideograph", "Ideographic"},
    25640: {"Unified_Ideograph", "Ideographic"},
    25641: {"Unified_Ideograph", "Ideographic"},
    25642: {"Unified_Ideograph", "Ideographic"},
    25643: {"Unified_Ideograph", "Ideographic"},
    25644: {"Unified_Ideograph", "Ideographic"},
    25645: {"Unified_Ideograph", "Ideographic"},
    25646: {"Unified_Ideograph", "Ideographic"},
    25647: {"Unified_Ideograph", "Ideographic"},
    25648: {"Unified_Ideograph", "Ideographic"},
    25649: {"Unified_Ideograph", "Ideographic"},
    25650: {"Unified_Ideograph", "Ideographic"},
    25651: {"Unified_Ideograph", "Ideographic"},
    25652: {"Unified_Ideograph", "Ideographic"},
    25653: {"Unified_Ideograph", "Ideographic"},
    25654: {"Unified_Ideograph", "Ideographic"},
    25655: {"Unified_Ideograph", "Ideographic"},
    25656: {"Unified_Ideograph", "Ideographic"},
    25657: {"Unified_Ideograph", "Ideographic"},
    25658: {"Unified_Ideograph", "Ideographic"},
    25659: {"Unified_Ideograph", "Ideographic"},
    25660: {"Unified_Ideograph", "Ideographic"},
    25661: {"Unified_Ideograph", "Ideographic"},
    25662: {"Unified_Ideograph", "Ideographic"},
    25663: {"Unified_Ideograph", "Ideographic"},
    25664: {"Unified_Ideograph", "Ideographic"},
    25665: {"Unified_Ideograph", "Ideographic"},
    25666: {"Unified_Ideograph", "Ideographic"},
    25667: {"Unified_Ideograph", "Ideographic"},
    25668: {"Unified_Ideograph", "Ideographic"},
    25669: {"Unified_Ideograph", "Ideographic"},
    25670: {"Unified_Ideograph", "Ideographic"},
    25671: {"Unified_Ideograph", "Ideographic"},
    25672: {"Unified_Ideograph", "Ideographic"},
    25673: {"Unified_Ideograph", "Ideographic"},
    25674: {"Unified_Ideograph", "Ideographic"},
    25675: {"Unified_Ideograph", "Ideographic"},
    25676: {"Unified_Ideograph", "Ideographic"},
    25677: {"Unified_Ideograph", "Ideographic"},
    25678: {"Unified_Ideograph", "Ideographic"},
    25679: {"Unified_Ideograph", "Ideographic"},
    25680: {"Unified_Ideograph", "Ideographic"},
    25681: {"Unified_Ideograph", "Ideographic"},
    25682: {"Unified_Ideograph", "Ideographic"},
    25683: {"Unified_Ideograph", "Ideographic"},
    25684: {"Unified_Ideograph", "Ideographic"},
    25685: {"Unified_Ideograph", "Ideographic"},
    25686: {"Unified_Ideograph", "Ideographic"},
    25687: {"Unified_Ideograph", "Ideographic"},
    25688: {"Unified_Ideograph", "Ideographic"},
    25689: {"Unified_Ideograph", "Ideographic"},
    25690: {"Unified_Ideograph", "Ideographic"},
    25691: {"Unified_Ideograph", "Ideographic"},
    25692: {"Unified_Ideograph", "Ideographic"},
    25693: {"Unified_Ideograph", "Ideographic"},
    25694: {"Unified_Ideograph", "Ideographic"},
    25695: {"Unified_Ideograph", "Ideographic"},
    25696: {"Unified_Ideograph", "Ideographic"},
    25697: {"Unified_Ideograph", "Ideographic"},
    25698: {"Unified_Ideograph", "Ideographic"},
    25699: {"Unified_Ideograph", "Ideographic"},
    25700: {"Unified_Ideograph", "Ideographic"},
    25701: {"Unified_Ideograph", "Ideographic"},
    25702: {"Unified_Ideograph", "Ideographic"},
    25703: {"Unified_Ideograph", "Ideographic"},
    25704: {"Unified_Ideograph", "Ideographic"},
    25705: {"Unified_Ideograph", "Ideographic"},
    25706: {"Unified_Ideograph", "Ideographic"},
    25707: {"Unified_Ideograph", "Ideographic"},
    25708: {"Unified_Ideograph", "Ideographic"},
    25709: {"Unified_Ideograph", "Ideographic"},
    25710: {"Unified_Ideograph", "Ideographic"},
    25711: {"Unified_Ideograph", "Ideographic"},
    25712: {"Unified_Ideograph", "Ideographic"},
    25713: {"Unified_Ideograph", "Ideographic"},
    25714: {"Unified_Ideograph", "Ideographic"},
    25715: {"Unified_Ideograph", "Ideographic"},
    25716: {"Unified_Ideograph", "Ideographic"},
    25717: {"Unified_Ideograph", "Ideographic"},
    25718: {"Unified_Ideograph", "Ideographic"},
    25719: {"Unified_Ideograph", "Ideographic"},
    25720: {"Unified_Ideograph", "Ideographic"},
    25721: {"Unified_Ideograph", "Ideographic"},
    25722: {"Unified_Ideograph", "Ideographic"},
    25723: {"Unified_Ideograph", "Ideographic"},
    25724: {"Unified_Ideograph", "Ideographic"},
    25725: {"Unified_Ideograph", "Ideographic"},
    25726: {"Unified_Ideograph", "Ideographic"},
    25727: {"Unified_Ideograph", "Ideographic"},
    25728: {"Unified_Ideograph", "Ideographic"},
    25729: {"Unified_Ideograph", "Ideographic"},
    25730: {"Unified_Ideograph", "Ideographic"},
    25731: {"Unified_Ideograph", "Ideographic"},
    25732: {"Unified_Ideograph", "Ideographic"},
    25733: {"Unified_Ideograph", "Ideographic"},
    25734: {"Unified_Ideograph", "Ideographic"},
    25735: {"Unified_Ideograph", "Ideographic"},
    25736: {"Unified_Ideograph", "Ideographic"},
    25737: {"Unified_Ideograph", "Ideographic"},
    25738: {"Unified_Ideograph", "Ideographic"},
    25739: {"Unified_Ideograph", "Ideographic"},
    25740: {"Unified_Ideograph", "Ideographic"},
    25741: {"Unified_Ideograph", "Ideographic"},
    25742: {"Unified_Ideograph", "Ideographic"},
    25743: {"Unified_Ideograph", "Ideographic"},
    25744: {"Unified_Ideograph", "Ideographic"},
    25745: {"Unified_Ideograph", "Ideographic"},
    25746: {"Unified_Ideograph", "Ideographic"},
    25747: {"Unified_Ideograph", "Ideographic"},
    25748: {"Unified_Ideograph", "Ideographic"},
    25749: {"Unified_Ideograph", "Ideographic"},
    25750: {"Unified_Ideograph", "Ideographic"},
    25751: {"Unified_Ideograph", "Ideographic"},
    25752: {"Unified_Ideograph", "Ideographic"},
    25753: {"Unified_Ideograph", "Ideographic"},
    25754: {"Unified_Ideograph", "Ideographic"},
    25755: {"Unified_Ideograph", "Ideographic"},
    25756: {"Unified_Ideograph", "Ideographic"},
    25757: {"Unified_Ideograph", "Ideographic"},
    25758: {"Unified_Ideograph", "Ideographic"},
    25759: {"Unified_Ideograph", "Ideographic"},
    25760: {"Unified_Ideograph", "Ideographic"},
    25761: {"Unified_Ideograph", "Ideographic"},
    25762: {"Unified_Ideograph", "Ideographic"},
    25763: {"Unified_Ideograph", "Ideographic"},
    25764: {"Unified_Ideograph", "Ideographic"},
    25765: {"Unified_Ideograph", "Ideographic"},
    25766: {"Unified_Ideograph", "Ideographic"},
    25767: {"Unified_Ideograph", "Ideographic"},
    25768: {"Unified_Ideograph", "Ideographic"},
    25769: {"Unified_Ideograph", "Ideographic"},
    25770: {"Unified_Ideograph", "Ideographic"},
    25771: {"Unified_Ideograph", "Ideographic"},
    25772: {"Unified_Ideograph", "Ideographic"},
    25773: {"Unified_Ideograph", "Ideographic"},
    25774: {"Unified_Ideograph", "Ideographic"},
    25775: {"Unified_Ideograph", "Ideographic"},
    25776: {"Unified_Ideograph", "Ideographic"},
    25777: {"Unified_Ideograph", "Ideographic"},
    25778: {"Unified_Ideograph", "Ideographic"},
    25779: {"Unified_Ideograph", "Ideographic"},
    25780: {"Unified_Ideograph", "Ideographic"},
    25781: {"Unified_Ideograph", "Ideographic"},
    25782: {"Unified_Ideograph", "Ideographic"},
    25783: {"Unified_Ideograph", "Ideographic"},
    25784: {"Unified_Ideograph", "Ideographic"},
    25785: {"Unified_Ideograph", "Ideographic"},
    25786: {"Unified_Ideograph", "Ideographic"},
    25787: {"Unified_Ideograph", "Ideographic"},
    25788: {"Unified_Ideograph", "Ideographic"},
    25789: {"Unified_Ideograph", "Ideographic"},
    25790: {"Unified_Ideograph", "Ideographic"},
    25791: {"Unified_Ideograph", "Ideographic"},
    25792: {"Unified_Ideograph", "Ideographic"},
    25793: {"Unified_Ideograph", "Ideographic"},
    25794: {"Unified_Ideograph", "Ideographic"},
    25795: {"Unified_Ideograph", "Ideographic"},
    25796: {"Unified_Ideograph", "Ideographic"},
    25797: {"Unified_Ideograph", "Ideographic"},
    25798: {"Unified_Ideograph", "Ideographic"},
    25799: {"Unified_Ideograph", "Ideographic"},
    25800: {"Unified_Ideograph", "Ideographic"},
    25801: {"Unified_Ideograph", "Ideographic"},
    25802: {"Unified_Ideograph", "Ideographic"},
    25803: {"Unified_Ideograph", "Ideographic"},
    25804: {"Unified_Ideograph", "Ideographic"},
    25805: {"Unified_Ideograph", "Ideographic"},
    25806: {"Unified_Ideograph", "Ideographic"},
    25807: {"Unified_Ideograph", "Ideographic"},
    25808: {"Unified_Ideograph", "Ideographic"},
    25809: {"Unified_Ideograph", "Ideographic"},
    25810: {"Unified_Ideograph", "Ideographic"},
    25811: {"Unified_Ideograph", "Ideographic"},
    25812: {"Unified_Ideograph", "Ideographic"},
    25813: {"Unified_Ideograph", "Ideographic"},
    25814: {"Unified_Ideograph", "Ideographic"},
    25815: {"Unified_Ideograph", "Ideographic"},
    25816: {"Unified_Ideograph", "Ideographic"},
    25817: {"Unified_Ideograph", "Ideographic"},
    25818: {"Unified_Ideograph", "Ideographic"},
    25819: {"Unified_Ideograph", "Ideographic"},
    25820: {"Unified_Ideograph", "Ideographic"},
    25821: {"Unified_Ideograph", "Ideographic"},
    25822: {"Unified_Ideograph", "Ideographic"},
    25823: {"Unified_Ideograph", "Ideographic"},
    25824: {"Unified_Ideograph", "Ideographic"},
    25825: {"Unified_Ideograph", "Ideographic"},
    25826: {"Unified_Ideograph", "Ideographic"},
    25827: {"Unified_Ideograph", "Ideographic"},
    25828: {"Unified_Ideograph", "Ideographic"},
    25829: {"Unified_Ideograph", "Ideographic"},
    25830: {"Unified_Ideograph", "Ideographic"},
    25831: {"Unified_Ideograph", "Ideographic"},
    25832: {"Unified_Ideograph", "Ideographic"},
    25833: {"Unified_Ideograph", "Ideographic"},
    25834: {"Unified_Ideograph", "Ideographic"},
    25835: {"Unified_Ideograph", "Ideographic"},
    25836: {"Unified_Ideograph", "Ideographic"},
    25837: {"Unified_Ideograph", "Ideographic"},
    25838: {"Unified_Ideograph", "Ideographic"},
    25839: {"Unified_Ideograph", "Ideographic"},
    25840: {"Unified_Ideograph", "Ideographic"},
    25841: {"Unified_Ideograph", "Ideographic"},
    25842: {"Unified_Ideograph", "Ideographic"},
    25843: {"Unified_Ideograph", "Ideographic"},
    25844: {"Unified_Ideograph", "Ideographic"},
    25845: {"Unified_Ideograph", "Ideographic"},
    25846: {"Unified_Ideograph", "Ideographic"},
    25847: {"Unified_Ideograph", "Ideographic"},
    25848: {"Unified_Ideograph", "Ideographic"},
    25849: {"Unified_Ideograph", "Ideographic"},
    25850: {"Unified_Ideograph", "Ideographic"},
    25851: {"Unified_Ideograph", "Ideographic"},
    25852: {"Unified_Ideograph", "Ideographic"},
    25853: {"Unified_Ideograph", "Ideographic"},
    25854: {"Unified_Ideograph", "Ideographic"},
    25855: {"Unified_Ideograph", "Ideographic"},
    25856: {"Unified_Ideograph", "Ideographic"},
    25857: {"Unified_Ideograph", "Ideographic"},
    25858: {"Unified_Ideograph", "Ideographic"},
    25859: {"Unified_Ideograph", "Ideographic"},
    25860: {"Unified_Ideograph", "Ideographic"},
    25861: {"Unified_Ideograph", "Ideographic"},
    25862: {"Unified_Ideograph", "Ideographic"},
    25863: {"Unified_Ideograph", "Ideographic"},
    25864: {"Unified_Ideograph", "Ideographic"},
    25865: {"Unified_Ideograph", "Ideographic"},
    25866: {"Unified_Ideograph", "Ideographic"},
    25867: {"Unified_Ideograph", "Ideographic"},
    25868: {"Unified_Ideograph", "Ideographic"},
    25869: {"Unified_Ideograph", "Ideographic"},
    25870: {"Unified_Ideograph", "Ideographic"},
    25871: {"Unified_Ideograph", "Ideographic"},
    25872: {"Unified_Ideograph", "Ideographic"},
    25873: {"Unified_Ideograph", "Ideographic"},
    25874: {"Unified_Ideograph", "Ideographic"},
    25875: {"Unified_Ideograph", "Ideographic"},
    25876: {"Unified_Ideograph", "Ideographic"},
    25877: {"Unified_Ideograph", "Ideographic"},
    25878: {"Unified_Ideograph", "Ideographic"},
    25879: {"Unified_Ideograph", "Ideographic"},
    25880: {"Unified_Ideograph", "Ideographic"},
    25881: {"Unified_Ideograph", "Ideographic"},
    25882: {"Unified_Ideograph", "Ideographic"},
    25883: {"Unified_Ideograph", "Ideographic"},
    25884: {"Unified_Ideograph", "Ideographic"},
    25885: {"Unified_Ideograph", "Ideographic"},
    25886: {"Unified_Ideograph", "Ideographic"},
    25887: {"Unified_Ideograph", "Ideographic"},
    25888: {"Unified_Ideograph", "Ideographic"},
    25889: {"Unified_Ideograph", "Ideographic"},
    25890: {"Unified_Ideograph", "Ideographic"},
    25891: {"Unified_Ideograph", "Ideographic"},
    25892: {"Unified_Ideograph", "Ideographic"},
    25893: {"Unified_Ideograph", "Ideographic"},
    25894: {"Unified_Ideograph", "Ideographic"},
    25895: {"Unified_Ideograph", "Ideographic"},
    25896: {"Unified_Ideograph", "Ideographic"},
    25897: {"Unified_Ideograph", "Ideographic"},
    25898: {"Unified_Ideograph", "Ideographic"},
    25899: {"Unified_Ideograph", "Ideographic"},
    25900: {"Unified_Ideograph", "Ideographic"},
    25901: {"Unified_Ideograph", "Ideographic"},
    25902: {"Unified_Ideograph", "Ideographic"},
    25903: {"Unified_Ideograph", "Ideographic"},
    25904: {"Unified_Ideograph", "Ideographic"},
    25905: {"Unified_Ideograph", "Ideographic"},
    25906: {"Unified_Ideograph", "Ideographic"},
    25907: {"Unified_Ideograph", "Ideographic"},
    25908: {"Unified_Ideograph", "Ideographic"},
    25909: {"Unified_Ideograph", "Ideographic"},
    25910: {"Unified_Ideograph", "Ideographic"},
    25911: {"Unified_Ideograph", "Ideographic"},
    25912: {"Unified_Ideograph", "Ideographic"},
    25913: {"Unified_Ideograph", "Ideographic"},
    25914: {"Unified_Ideograph", "Ideographic"},
    25915: {"Unified_Ideograph", "Ideographic"},
    25916: {"Unified_Ideograph", "Ideographic"},
    25917: {"Unified_Ideograph", "Ideographic"},
    25918: {"Unified_Ideograph", "Ideographic"},
    25919: {"Unified_Ideograph", "Ideographic"},
    25920: {"Unified_Ideograph", "Ideographic"},
    25921: {"Unified_Ideograph", "Ideographic"},
    25922: {"Unified_Ideograph", "Ideographic"},
    25923: {"Unified_Ideograph", "Ideographic"},
    25924: {"Unified_Ideograph", "Ideographic"},
    25925: {"Unified_Ideograph", "Ideographic"},
    25926: {"Unified_Ideograph", "Ideographic"},
    25927: {"Unified_Ideograph", "Ideographic"},
    25928: {"Unified_Ideograph", "Ideographic"},
    25929: {"Unified_Ideograph", "Ideographic"},
    25930: {"Unified_Ideograph", "Ideographic"},
    25931: {"Unified_Ideograph", "Ideographic"},
    25932: {"Unified_Ideograph", "Ideographic"},
    25933: {"Unified_Ideograph", "Ideographic"},
    25934: {"Unified_Ideograph", "Ideographic"},
    25935: {"Unified_Ideograph", "Ideographic"},
    25936: {"Unified_Ideograph", "Ideographic"},
    25937: {"Unified_Ideograph", "Ideographic"},
    25938: {"Unified_Ideograph", "Ideographic"},
    25939: {"Unified_Ideograph", "Ideographic"},
    25940: {"Unified_Ideograph", "Ideographic"},
    25941: {"Unified_Ideograph", "Ideographic"},
    25942: {"Unified_Ideograph", "Ideographic"},
    25943: {"Unified_Ideograph", "Ideographic"},
    25944: {"Unified_Ideograph", "Ideographic"},
    25945: {"Unified_Ideograph", "Ideographic"},
    25946: {"Unified_Ideograph", "Ideographic"},
    25947: {"Unified_Ideograph", "Ideographic"},
    25948: {"Unified_Ideograph", "Ideographic"},
    25949: {"Unified_Ideograph", "Ideographic"},
    25950: {"Unified_Ideograph", "Ideographic"},
    25951: {"Unified_Ideograph", "Ideographic"},
    25952: {"Unified_Ideograph", "Ideographic"},
    25953: {"Unified_Ideograph", "Ideographic"},
    25954: {"Unified_Ideograph", "Ideographic"},
    25955: {"Unified_Ideograph", "Ideographic"},
    25956: {"Unified_Ideograph", "Ideographic"},
    25957: {"Unified_Ideograph", "Ideographic"},
    25958: {"Unified_Ideograph", "Ideographic"},
    25959: {"Unified_Ideograph", "Ideographic"},
    25960: {"Unified_Ideograph", "Ideographic"},
    25961: {"Unified_Ideograph", "Ideographic"},
    25962: {"Unified_Ideograph", "Ideographic"},
    25963: {"Unified_Ideograph", "Ideographic"},
    25964: {"Unified_Ideograph", "Ideographic"},
    25965: {"Unified_Ideograph", "Ideographic"},
    25966: {"Unified_Ideograph", "Ideographic"},
    25967: {"Unified_Ideograph", "Ideographic"},
    25968: {"Unified_Ideograph", "Ideographic"},
    25969: {"Unified_Ideograph", "Ideographic"},
    25970: {"Unified_Ideograph", "Ideographic"},
    25971: {"Unified_Ideograph", "Ideographic"},
    25972: {"Unified_Ideograph", "Ideographic"},
    25973: {"Unified_Ideograph", "Ideographic"},
    25974: {"Unified_Ideograph", "Ideographic"},
    25975: {"Unified_Ideograph", "Ideographic"},
    25976: {"Unified_Ideograph", "Ideographic"},
    25977: {"Unified_Ideograph", "Ideographic"},
    25978: {"Unified_Ideograph", "Ideographic"},
    25979: {"Unified_Ideograph", "Ideographic"},
    25980: {"Unified_Ideograph", "Ideographic"},
    25981: {"Unified_Ideograph", "Ideographic"},
    25982: {"Unified_Ideograph", "Ideographic"},
    25983: {"Unified_Ideograph", "Ideographic"},
    25984: {"Unified_Ideograph", "Ideographic"},
    25985: {"Unified_Ideograph", "Ideographic"},
    25986: {"Unified_Ideograph", "Ideographic"},
    25987: {"Unified_Ideograph", "Ideographic"},
    25988: {"Unified_Ideograph", "Ideographic"},
    25989: {"Unified_Ideograph", "Ideographic"},
    25990: {"Unified_Ideograph", "Ideographic"},
    25991: {"Unified_Ideograph", "Ideographic"},
    25992: {"Unified_Ideograph", "Ideographic"},
    25993: {"Unified_Ideograph", "Ideographic"},
    25994: {"Unified_Ideograph", "Ideographic"},
    25995: {"Unified_Ideograph", "Ideographic"},
    25996: {"Unified_Ideograph", "Ideographic"},
    25997: {"Unified_Ideograph", "Ideographic"},
    25998: {"Unified_Ideograph", "Ideographic"},
    25999: {"Unified_Ideograph", "Ideographic"},
    26000: {"Unified_Ideograph", "Ideographic"},
    26001: {"Unified_Ideograph", "Ideographic"},
    26002: {"Unified_Ideograph", "Ideographic"},
    26003: {"Unified_Ideograph", "Ideographic"},
    26004: {"Unified_Ideograph", "Ideographic"},
    26005: {"Unified_Ideograph", "Ideographic"},
    26006: {"Unified_Ideograph", "Ideographic"},
    26007: {"Unified_Ideograph", "Ideographic"},
    26008: {"Unified_Ideograph", "Ideographic"},
    26009: {"Unified_Ideograph", "Ideographic"},
    26010: {"Unified_Ideograph", "Ideographic"},
    26011: {"Unified_Ideograph", "Ideographic"},
    26012: {"Unified_Ideograph", "Ideographic"},
    26013: {"Unified_Ideograph", "Ideographic"},
    26014: {"Unified_Ideograph", "Ideographic"},
    26015: {"Unified_Ideograph", "Ideographic"},
    26016: {"Unified_Ideograph", "Ideographic"},
    26017: {"Unified_Ideograph", "Ideographic"},
    26018: {"Unified_Ideograph", "Ideographic"},
    26019: {"Unified_Ideograph", "Ideographic"},
    26020: {"Unified_Ideograph", "Ideographic"},
    26021: {"Unified_Ideograph", "Ideographic"},
    26022: {"Unified_Ideograph", "Ideographic"},
    26023: {"Unified_Ideograph", "Ideographic"},
    26024: {"Unified_Ideograph", "Ideographic"},
    26025: {"Unified_Ideograph", "Ideographic"},
    26026: {"Unified_Ideograph", "Ideographic"},
    26027: {"Unified_Ideograph", "Ideographic"},
    26028: {"Unified_Ideograph", "Ideographic"},
    26029: {"Unified_Ideograph", "Ideographic"},
    26030: {"Unified_Ideograph", "Ideographic"},
    26031: {"Unified_Ideograph", "Ideographic"},
    26032: {"Unified_Ideograph", "Ideographic"},
    26033: {"Unified_Ideograph", "Ideographic"},
    26034: {"Unified_Ideograph", "Ideographic"},
    26035: {"Unified_Ideograph", "Ideographic"},
    26036: {"Unified_Ideograph", "Ideographic"},
    26037: {"Unified_Ideograph", "Ideographic"},
    26038: {"Unified_Ideograph", "Ideographic"},
    26039: {"Unified_Ideograph", "Ideographic"},
    26040: {"Unified_Ideograph", "Ideographic"},
    26041: {"Unified_Ideograph", "Ideographic"},
    26042: {"Unified_Ideograph", "Ideographic"},
    26043: {"Unified_Ideograph", "Ideographic"},
    26044: {"Unified_Ideograph", "Ideographic"},
    26045: {"Unified_Ideograph", "Ideographic"},
    26046: {"Unified_Ideograph", "Ideographic"},
    26047: {"Unified_Ideograph", "Ideographic"},
    26048: {"Unified_Ideograph", "Ideographic"},
    26049: {"Unified_Ideograph", "Ideographic"},
    26050: {"Unified_Ideograph", "Ideographic"},
    26051: {"Unified_Ideograph", "Ideographic"},
    26052: {"Unified_Ideograph", "Ideographic"},
    26053: {"Unified_Ideograph", "Ideographic"},
    26054: {"Unified_Ideograph", "Ideographic"},
    26055: {"Unified_Ideograph", "Ideographic"},
    26056: {"Unified_Ideograph", "Ideographic"},
    26057: {"Unified_Ideograph", "Ideographic"},
    26058: {"Unified_Ideograph", "Ideographic"},
    26059: {"Unified_Ideograph", "Ideographic"},
    26060: {"Unified_Ideograph", "Ideographic"},
    26061: {"Unified_Ideograph", "Ideographic"},
    26062: {"Unified_Ideograph", "Ideographic"},
    26063: {"Unified_Ideograph", "Ideographic"},
    26064: {"Unified_Ideograph", "Ideographic"},
    26065: {"Unified_Ideograph", "Ideographic"},
    26066: {"Unified_Ideograph", "Ideographic"},
    26067: {"Unified_Ideograph", "Ideographic"},
    26068: {"Unified_Ideograph", "Ideographic"},
    26069: {"Unified_Ideograph", "Ideographic"},
    26070: {"Unified_Ideograph", "Ideographic"},
    26071: {"Unified_Ideograph", "Ideographic"},
    26072: {"Unified_Ideograph", "Ideographic"},
    26073: {"Unified_Ideograph", "Ideographic"},
    26074: {"Unified_Ideograph", "Ideographic"},
    26075: {"Unified_Ideograph", "Ideographic"},
    26076: {"Unified_Ideograph", "Ideographic"},
    26077: {"Unified_Ideograph", "Ideographic"},
    26078: {"Unified_Ideograph", "Ideographic"},
    26079: {"Unified_Ideograph", "Ideographic"},
    26080: {"Unified_Ideograph", "Ideographic"},
    26081: {"Unified_Ideograph", "Ideographic"},
    26082: {"Unified_Ideograph", "Ideographic"},
    26083: {"Unified_Ideograph", "Ideographic"},
    26084: {"Unified_Ideograph", "Ideographic"},
    26085: {"Unified_Ideograph", "Ideographic"},
    26086: {"Unified_Ideograph", "Ideographic"},
    26087: {"Unified_Ideograph", "Ideographic"},
    26088: {"Unified_Ideograph", "Ideographic"},
    26089: {"Unified_Ideograph", "Ideographic"},
    26090: {"Unified_Ideograph", "Ideographic"},
    26091: {"Unified_Ideograph", "Ideographic"},
    26092: {"Unified_Ideograph", "Ideographic"},
    26093: {"Unified_Ideograph", "Ideographic"},
    26094: {"Unified_Ideograph", "Ideographic"},
    26095: {"Unified_Ideograph", "Ideographic"},
    26096: {"Unified_Ideograph", "Ideographic"},
    26097: {"Unified_Ideograph", "Ideographic"},
    26098: {"Unified_Ideograph", "Ideographic"},
    26099: {"Unified_Ideograph", "Ideographic"},
    26100: {"Unified_Ideograph", "Ideographic"},
    26101: {"Unified_Ideograph", "Ideographic"},
    26102: {"Unified_Ideograph", "Ideographic"},
    26103: {"Unified_Ideograph", "Ideographic"},
    26104: {"Unified_Ideograph", "Ideographic"},
    26105: {"Unified_Ideograph", "Ideographic"},
    26106: {"Unified_Ideograph", "Ideographic"},
    26107: {"Unified_Ideograph", "Ideographic"},
    26108: {"Unified_Ideograph", "Ideographic"},
    26109: {"Unified_Ideograph", "Ideographic"},
    26110: {"Unified_Ideograph", "Ideographic"},
    26111: {"Unified_Ideograph", "Ideographic"},
    26112: {"Unified_Ideograph", "Ideographic"},
    26113: {"Unified_Ideograph", "Ideographic"},
    26114: {"Unified_Ideograph", "Ideographic"},
    26115: {"Unified_Ideograph", "Ideographic"},
    26116: {"Unified_Ideograph", "Ideographic"},
    26117: {"Unified_Ideograph", "Ideographic"},
    26118: {"Unified_Ideograph", "Ideographic"},
    26119: {"Unified_Ideograph", "Ideographic"},
    26120: {"Unified_Ideograph", "Ideographic"},
    26121: {"Unified_Ideograph", "Ideographic"},
    26122: {"Unified_Ideograph", "Ideographic"},
    26123: {"Unified_Ideograph", "Ideographic"},
    26124: {"Unified_Ideograph", "Ideographic"},
    26125: {"Unified_Ideograph", "Ideographic"},
    26126: {"Unified_Ideograph", "Ideographic"},
    26127: {"Unified_Ideograph", "Ideographic"},
    26128: {"Unified_Ideograph", "Ideographic"},
    26129: {"Unified_Ideograph", "Ideographic"},
    26130: {"Unified_Ideograph", "Ideographic"},
    26131: {"Unified_Ideograph", "Ideographic"},
    26132: {"Unified_Ideograph", "Ideographic"},
    26133: {"Unified_Ideograph", "Ideographic"},
    26134: {"Unified_Ideograph", "Ideographic"},
    26135: {"Unified_Ideograph", "Ideographic"},
    26136: {"Unified_Ideograph", "Ideographic"},
    26137: {"Unified_Ideograph", "Ideographic"},
    26138: {"Unified_Ideograph", "Ideographic"},
    26139: {"Unified_Ideograph", "Ideographic"},
    26140: {"Unified_Ideograph", "Ideographic"},
    26141: {"Unified_Ideograph", "Ideographic"},
    26142: {"Unified_Ideograph", "Ideographic"},
    26143: {"Unified_Ideograph", "Ideographic"},
    26144: {"Unified_Ideograph", "Ideographic"},
    26145: {"Unified_Ideograph", "Ideographic"},
    26146: {"Unified_Ideograph", "Ideographic"},
    26147: {"Unified_Ideograph", "Ideographic"},
    26148: {"Unified_Ideograph", "Ideographic"},
    26149: {"Unified_Ideograph", "Ideographic"},
    26150: {"Unified_Ideograph", "Ideographic"},
    26151: {"Unified_Ideograph", "Ideographic"},
    26152: {"Unified_Ideograph", "Ideographic"},
    26153: {"Unified_Ideograph", "Ideographic"},
    26154: {"Unified_Ideograph", "Ideographic"},
    26155: {"Unified_Ideograph", "Ideographic"},
    26156: {"Unified_Ideograph", "Ideographic"},
    26157: {"Unified_Ideograph", "Ideographic"},
    26158: {"Unified_Ideograph", "Ideographic"},
    26159: {"Unified_Ideograph", "Ideographic"},
    26160: {"Unified_Ideograph", "Ideographic"},
    26161: {"Unified_Ideograph", "Ideographic"},
    26162: {"Unified_Ideograph", "Ideographic"},
    26163: {"Unified_Ideograph", "Ideographic"},
    26164: {"Unified_Ideograph", "Ideographic"},
    26165: {"Unified_Ideograph", "Ideographic"},
    26166: {"Unified_Ideograph", "Ideographic"},
    26167: {"Unified_Ideograph", "Ideographic"},
    26168: {"Unified_Ideograph", "Ideographic"},
    26169: {"Unified_Ideograph", "Ideographic"},
    26170: {"Unified_Ideograph", "Ideographic"},
    26171: {"Unified_Ideograph", "Ideographic"},
    26172: {"Unified_Ideograph", "Ideographic"},
    26173: {"Unified_Ideograph", "Ideographic"},
    26174: {"Unified_Ideograph", "Ideographic"},
    26175: {"Unified_Ideograph", "Ideographic"},
    26176: {"Unified_Ideograph", "Ideographic"},
    26177: {"Unified_Ideograph", "Ideographic"},
    26178: {"Unified_Ideograph", "Ideographic"},
    26179: {"Unified_Ideograph", "Ideographic"},
    26180: {"Unified_Ideograph", "Ideographic"},
    26181: {"Unified_Ideograph", "Ideographic"},
    26182: {"Unified_Ideograph", "Ideographic"},
    26183: {"Unified_Ideograph", "Ideographic"},
    26184: {"Unified_Ideograph", "Ideographic"},
    26185: {"Unified_Ideograph", "Ideographic"},
    26186: {"Unified_Ideograph", "Ideographic"},
    26187: {"Unified_Ideograph", "Ideographic"},
    26188: {"Unified_Ideograph", "Ideographic"},
    26189: {"Unified_Ideograph", "Ideographic"},
    26190: {"Unified_Ideograph", "Ideographic"},
    26191: {"Unified_Ideograph", "Ideographic"},
    26192: {"Unified_Ideograph", "Ideographic"},
    26193: {"Unified_Ideograph", "Ideographic"},
    26194: {"Unified_Ideograph", "Ideographic"},
    26195: {"Unified_Ideograph", "Ideographic"},
    26196: {"Unified_Ideograph", "Ideographic"},
    26197: {"Unified_Ideograph", "Ideographic"},
    26198: {"Unified_Ideograph", "Ideographic"},
    26199: {"Unified_Ideograph", "Ideographic"},
    26200: {"Unified_Ideograph", "Ideographic"},
    26201: {"Unified_Ideograph", "Ideographic"},
    26202: {"Unified_Ideograph", "Ideographic"},
    26203: {"Unified_Ideograph", "Ideographic"},
    26204: {"Unified_Ideograph", "Ideographic"},
    26205: {"Unified_Ideograph", "Ideographic"},
    26206: {"Unified_Ideograph", "Ideographic"},
    26207: {"Unified_Ideograph", "Ideographic"},
    26208: {"Unified_Ideograph", "Ideographic"},
    26209: {"Unified_Ideograph", "Ideographic"},
    26210: {"Unified_Ideograph", "Ideographic"},
    26211: {"Unified_Ideograph", "Ideographic"},
    26212: {"Unified_Ideograph", "Ideographic"},
    26213: {"Unified_Ideograph", "Ideographic"},
    26214: {"Unified_Ideograph", "Ideographic"},
    26215: {"Unified_Ideograph", "Ideographic"},
    26216: {"Unified_Ideograph", "Ideographic"},
    26217: {"Unified_Ideograph", "Ideographic"},
    26218: {"Unified_Ideograph", "Ideographic"},
    26219: {"Unified_Ideograph", "Ideographic"},
    26220: {"Unified_Ideograph", "Ideographic"},
    26221: {"Unified_Ideograph", "Ideographic"},
    26222: {"Unified_Ideograph", "Ideographic"},
    26223: {"Unified_Ideograph", "Ideographic"},
    26224: {"Unified_Ideograph", "Ideographic"},
    26225: {"Unified_Ideograph", "Ideographic"},
    26226: {"Unified_Ideograph", "Ideographic"},
    26227: {"Unified_Ideograph", "Ideographic"},
    26228: {"Unified_Ideograph", "Ideographic"},
    26229: {"Unified_Ideograph", "Ideographic"},
    26230: {"Unified_Ideograph", "Ideographic"},
    26231: {"Unified_Ideograph", "Ideographic"},
    26232: {"Unified_Ideograph", "Ideographic"},
    26233: {"Unified_Ideograph", "Ideographic"},
    26234: {"Unified_Ideograph", "Ideographic"},
    26235: {"Unified_Ideograph", "Ideographic"},
    26236: {"Unified_Ideograph", "Ideographic"},
    26237: {"Unified_Ideograph", "Ideographic"},
    26238: {"Unified_Ideograph", "Ideographic"},
    26239: {"Unified_Ideograph", "Ideographic"},
    26240: {"Unified_Ideograph", "Ideographic"},
    26241: {"Unified_Ideograph", "Ideographic"},
    26242: {"Unified_Ideograph", "Ideographic"},
    26243: {"Unified_Ideograph", "Ideographic"},
    26244: {"Unified_Ideograph", "Ideographic"},
    26245: {"Unified_Ideograph", "Ideographic"},
    26246: {"Unified_Ideograph", "Ideographic"},
    26247: {"Unified_Ideograph", "Ideographic"},
    26248: {"Unified_Ideograph", "Ideographic"},
    26249: {"Unified_Ideograph", "Ideographic"},
    26250: {"Unified_Ideograph", "Ideographic"},
    26251: {"Unified_Ideograph", "Ideographic"},
    26252: {"Unified_Ideograph", "Ideographic"},
    26253: {"Unified_Ideograph", "Ideographic"},
    26254: {"Unified_Ideograph", "Ideographic"},
    26255: {"Unified_Ideograph", "Ideographic"},
    26256: {"Unified_Ideograph", "Ideographic"},
    26257: {"Unified_Ideograph", "Ideographic"},
    26258: {"Unified_Ideograph", "Ideographic"},
    26259: {"Unified_Ideograph", "Ideographic"},
    26260: {"Unified_Ideograph", "Ideographic"},
    26261: {"Unified_Ideograph", "Ideographic"},
    26262: {"Unified_Ideograph", "Ideographic"},
    26263: {"Unified_Ideograph", "Ideographic"},
    26264: {"Unified_Ideograph", "Ideographic"},
    26265: {"Unified_Ideograph", "Ideographic"},
    26266: {"Unified_Ideograph", "Ideographic"},
    26267: {"Unified_Ideograph", "Ideographic"},
    26268: {"Unified_Ideograph", "Ideographic"},
    26269: {"Unified_Ideograph", "Ideographic"},
    26270: {"Unified_Ideograph", "Ideographic"},
    26271: {"Unified_Ideograph", "Ideographic"},
    26272: {"Unified_Ideograph", "Ideographic"},
    26273: {"Unified_Ideograph", "Ideographic"},
    26274: {"Unified_Ideograph", "Ideographic"},
    26275: {"Unified_Ideograph", "Ideographic"},
    26276: {"Unified_Ideograph", "Ideographic"},
    26277: {"Unified_Ideograph", "Ideographic"},
    26278: {"Unified_Ideograph", "Ideographic"},
    26279: {"Unified_Ideograph", "Ideographic"},
    26280: {"Unified_Ideograph", "Ideographic"},
    26281: {"Unified_Ideograph", "Ideographic"},
    26282: {"Unified_Ideograph", "Ideographic"},
    26283: {"Unified_Ideograph", "Ideographic"},
    26284: {"Unified_Ideograph", "Ideographic"},
    26285: {"Unified_Ideograph", "Ideographic"},
    26286: {"Unified_Ideograph", "Ideographic"},
    26287: {"Unified_Ideograph", "Ideographic"},
    26288: {"Unified_Ideograph", "Ideographic"},
    26289: {"Unified_Ideograph", "Ideographic"},
    26290: {"Unified_Ideograph", "Ideographic"},
    26291: {"Unified_Ideograph", "Ideographic"},
    26292: {"Unified_Ideograph", "Ideographic"},
    26293: {"Unified_Ideograph", "Ideographic"},
    26294: {"Unified_Ideograph", "Ideographic"},
    26295: {"Unified_Ideograph", "Ideographic"},
    26296: {"Unified_Ideograph", "Ideographic"},
    26297: {"Unified_Ideograph", "Ideographic"},
    26298: {"Unified_Ideograph", "Ideographic"},
    26299: {"Unified_Ideograph", "Ideographic"},
    26300: {"Unified_Ideograph", "Ideographic"},
    26301: {"Unified_Ideograph", "Ideographic"},
    26302: {"Unified_Ideograph", "Ideographic"},
    26303: {"Unified_Ideograph", "Ideographic"},
    26304: {"Unified_Ideograph", "Ideographic"},
    26305: {"Unified_Ideograph", "Ideographic"},
    26306: {"Unified_Ideograph", "Ideographic"},
    26307: {"Unified_Ideograph", "Ideographic"},
    26308: {"Unified_Ideograph", "Ideographic"},
    26309: {"Unified_Ideograph", "Ideographic"},
    26310: {"Unified_Ideograph", "Ideographic"},
    26311: {"Unified_Ideograph", "Ideographic"},
    26312: {"Unified_Ideograph", "Ideographic"},
    26313: {"Unified_Ideograph", "Ideographic"},
    26314: {"Unified_Ideograph", "Ideographic"},
    26315: {"Unified_Ideograph", "Ideographic"},
    26316: {"Unified_Ideograph", "Ideographic"},
    26317: {"Unified_Ideograph", "Ideographic"},
    26318: {"Unified_Ideograph", "Ideographic"},
    26319: {"Unified_Ideograph", "Ideographic"},
    26320: {"Unified_Ideograph", "Ideographic"},
    26321: {"Unified_Ideograph", "Ideographic"},
    26322: {"Unified_Ideograph", "Ideographic"},
    26323: {"Unified_Ideograph", "Ideographic"},
    26324: {"Unified_Ideograph", "Ideographic"},
    26325: {"Unified_Ideograph", "Ideographic"},
    26326: {"Unified_Ideograph", "Ideographic"},
    26327: {"Unified_Ideograph", "Ideographic"},
    26328: {"Unified_Ideograph", "Ideographic"},
    26329: {"Unified_Ideograph", "Ideographic"},
    26330: {"Unified_Ideograph", "Ideographic"},
    26331: {"Unified_Ideograph", "Ideographic"},
    26332: {"Unified_Ideograph", "Ideographic"},
    26333: {"Unified_Ideograph", "Ideographic"},
    26334: {"Unified_Ideograph", "Ideographic"},
    26335: {"Unified_Ideograph", "Ideographic"},
    26336: {"Unified_Ideograph", "Ideographic"},
    26337: {"Unified_Ideograph", "Ideographic"},
    26338: {"Unified_Ideograph", "Ideographic"},
    26339: {"Unified_Ideograph", "Ideographic"},
    26340: {"Unified_Ideograph", "Ideographic"},
    26341: {"Unified_Ideograph", "Ideographic"},
    26342: {"Unified_Ideograph", "Ideographic"},
    26343: {"Unified_Ideograph", "Ideographic"},
    26344: {"Unified_Ideograph", "Ideographic"},
    26345: {"Unified_Ideograph", "Ideographic"},
    26346: {"Unified_Ideograph", "Ideographic"},
    26347: {"Unified_Ideograph", "Ideographic"},
    26348: {"Unified_Ideograph", "Ideographic"},
    26349: {"Unified_Ideograph", "Ideographic"},
    26350: {"Unified_Ideograph", "Ideographic"},
    26351: {"Unified_Ideograph", "Ideographic"},
    26352: {"Unified_Ideograph", "Ideographic"},
    26353: {"Unified_Ideograph", "Ideographic"},
    26354: {"Unified_Ideograph", "Ideographic"},
    26355: {"Unified_Ideograph", "Ideographic"},
    26356: {"Unified_Ideograph", "Ideographic"},
    26357: {"Unified_Ideograph", "Ideographic"},
    26358: {"Unified_Ideograph", "Ideographic"},
    26359: {"Unified_Ideograph", "Ideographic"},
    26360: {"Unified_Ideograph", "Ideographic"},
    26361: {"Unified_Ideograph", "Ideographic"},
    26362: {"Unified_Ideograph", "Ideographic"},
    26363: {"Unified_Ideograph", "Ideographic"},
    26364: {"Unified_Ideograph", "Ideographic"},
    26365: {"Unified_Ideograph", "Ideographic"},
    26366: {"Unified_Ideograph", "Ideographic"},
    26367: {"Unified_Ideograph", "Ideographic"},
    26368: {"Unified_Ideograph", "Ideographic"},
    26369: {"Unified_Ideograph", "Ideographic"},
    26370: {"Unified_Ideograph", "Ideographic"},
    26371: {"Unified_Ideograph", "Ideographic"},
    26372: {"Unified_Ideograph", "Ideographic"},
    26373: {"Unified_Ideograph", "Ideographic"},
    26374: {"Unified_Ideograph", "Ideographic"},
    26375: {"Unified_Ideograph", "Ideographic"},
    26376: {"Unified_Ideograph", "Ideographic"},
    26377: {"Unified_Ideograph", "Ideographic"},
    26378: {"Unified_Ideograph", "Ideographic"},
    26379: {"Unified_Ideograph", "Ideographic"},
    26380: {"Unified_Ideograph", "Ideographic"},
    26381: {"Unified_Ideograph", "Ideographic"},
    26382: {"Unified_Ideograph", "Ideographic"},
    26383: {"Unified_Ideograph", "Ideographic"},
    26384: {"Unified_Ideograph", "Ideographic"},
    26385: {"Unified_Ideograph", "Ideographic"},
    26386: {"Unified_Ideograph", "Ideographic"},
    26387: {"Unified_Ideograph", "Ideographic"},
    26388: {"Unified_Ideograph", "Ideographic"},
    26389: {"Unified_Ideograph", "Ideographic"},
    26390: {"Unified_Ideograph", "Ideographic"},
    26391: {"Unified_Ideograph", "Ideographic"},
    26392: {"Unified_Ideograph", "Ideographic"},
    26393: {"Unified_Ideograph", "Ideographic"},
    26394: {"Unified_Ideograph", "Ideographic"},
    26395: {"Unified_Ideograph", "Ideographic"},
    26396: {"Unified_Ideograph", "Ideographic"},
    26397: {"Unified_Ideograph", "Ideographic"},
    26398: {"Unified_Ideograph", "Ideographic"},
    26399: {"Unified_Ideograph", "Ideographic"},
    26400: {"Unified_Ideograph", "Ideographic"},
    26401: {"Unified_Ideograph", "Ideographic"},
    26402: {"Unified_Ideograph", "Ideographic"},
    26403: {"Unified_Ideograph", "Ideographic"},
    26404: {"Unified_Ideograph", "Ideographic"},
    26405: {"Unified_Ideograph", "Ideographic"},
    26406: {"Unified_Ideograph", "Ideographic"},
    26407: {"Unified_Ideograph", "Ideographic"},
    26408: {"Unified_Ideograph", "Ideographic"},
    26409: {"Unified_Ideograph", "Ideographic"},
    26410: {"Unified_Ideograph", "Ideographic"},
    26411: {"Unified_Ideograph", "Ideographic"},
    26412: {"Unified_Ideograph", "Ideographic"},
    26413: {"Unified_Ideograph", "Ideographic"},
    26414: {"Unified_Ideograph", "Ideographic"},
    26415: {"Unified_Ideograph", "Ideographic"},
    26416: {"Unified_Ideograph", "Ideographic"},
    26417: {"Unified_Ideograph", "Ideographic"},
    26418: {"Unified_Ideograph", "Ideographic"},
    26419: {"Unified_Ideograph", "Ideographic"},
    26420: {"Unified_Ideograph", "Ideographic"},
    26421: {"Unified_Ideograph", "Ideographic"},
    26422: {"Unified_Ideograph", "Ideographic"},
    26423: {"Unified_Ideograph", "Ideographic"},
    26424: {"Unified_Ideograph", "Ideographic"},
    26425: {"Unified_Ideograph", "Ideographic"},
    26426: {"Unified_Ideograph", "Ideographic"},
    26427: {"Unified_Ideograph", "Ideographic"},
    26428: {"Unified_Ideograph", "Ideographic"},
    26429: {"Unified_Ideograph", "Ideographic"},
    26430: {"Unified_Ideograph", "Ideographic"},
    26431: {"Unified_Ideograph", "Ideographic"},
    26432: {"Unified_Ideograph", "Ideographic"},
    26433: {"Unified_Ideograph", "Ideographic"},
    26434: {"Unified_Ideograph", "Ideographic"},
    26435: {"Unified_Ideograph", "Ideographic"},
    26436: {"Unified_Ideograph", "Ideographic"},
    26437: {"Unified_Ideograph", "Ideographic"},
    26438: {"Unified_Ideograph", "Ideographic"},
    26439: {"Unified_Ideograph", "Ideographic"},
    26440: {"Unified_Ideograph", "Ideographic"},
    26441: {"Unified_Ideograph", "Ideographic"},
    26442: {"Unified_Ideograph", "Ideographic"},
    26443: {"Unified_Ideograph", "Ideographic"},
    26444: {"Unified_Ideograph", "Ideographic"},
    26445: {"Unified_Ideograph", "Ideographic"},
    26446: {"Unified_Ideograph", "Ideographic"},
    26447: {"Unified_Ideograph", "Ideographic"},
    26448: {"Unified_Ideograph", "Ideographic"},
    26449: {"Unified_Ideograph", "Ideographic"},
    26450: {"Unified_Ideograph", "Ideographic"},
    26451: {"Unified_Ideograph", "Ideographic"},
    26452: {"Unified_Ideograph", "Ideographic"},
    26453: {"Unified_Ideograph", "Ideographic"},
    26454: {"Unified_Ideograph", "Ideographic"},
    26455: {"Unified_Ideograph", "Ideographic"},
    26456: {"Unified_Ideograph", "Ideographic"},
    26457: {"Unified_Ideograph", "Ideographic"},
    26458: {"Unified_Ideograph", "Ideographic"},
    26459: {"Unified_Ideograph", "Ideographic"},
    26460: {"Unified_Ideograph", "Ideographic"},
    26461: {"Unified_Ideograph", "Ideographic"},
    26462: {"Unified_Ideograph", "Ideographic"},
    26463: {"Unified_Ideograph", "Ideographic"},
    26464: {"Unified_Ideograph", "Ideographic"},
    26465: {"Unified_Ideograph", "Ideographic"},
    26466: {"Unified_Ideograph", "Ideographic"},
    26467: {"Unified_Ideograph", "Ideographic"},
    26468: {"Unified_Ideograph", "Ideographic"},
    26469: {"Unified_Ideograph", "Ideographic"},
    26470: {"Unified_Ideograph", "Ideographic"},
    26471: {"Unified_Ideograph", "Ideographic"},
    26472: {"Unified_Ideograph", "Ideographic"},
    26473: {"Unified_Ideograph", "Ideographic"},
    26474: {"Unified_Ideograph", "Ideographic"},
    26475: {"Unified_Ideograph", "Ideographic"},
    26476: {"Unified_Ideograph", "Ideographic"},
    26477: {"Unified_Ideograph", "Ideographic"},
    26478: {"Unified_Ideograph", "Ideographic"},
    26479: {"Unified_Ideograph", "Ideographic"},
    26480: {"Unified_Ideograph", "Ideographic"},
    26481: {"Unified_Ideograph", "Ideographic"},
    26482: {"Unified_Ideograph", "Ideographic"},
    26483: {"Unified_Ideograph", "Ideographic"},
    26484: {"Unified_Ideograph", "Ideographic"},
    26485: {"Unified_Ideograph", "Ideographic"},
    26486: {"Unified_Ideograph", "Ideographic"},
    26487: {"Unified_Ideograph", "Ideographic"},
    26488: {"Unified_Ideograph", "Ideographic"},
    26489: {"Unified_Ideograph", "Ideographic"},
    26490: {"Unified_Ideograph", "Ideographic"},
    26491: {"Unified_Ideograph", "Ideographic"},
    26492: {"Unified_Ideograph", "Ideographic"},
    26493: {"Unified_Ideograph", "Ideographic"},
    26494: {"Unified_Ideograph", "Ideographic"},
    26495: {"Unified_Ideograph", "Ideographic"},
    26496: {"Unified_Ideograph", "Ideographic"},
    26497: {"Unified_Ideograph", "Ideographic"},
    26498: {"Unified_Ideograph", "Ideographic"},
    26499: {"Unified_Ideograph", "Ideographic"},
    26500: {"Unified_Ideograph", "Ideographic"},
    26501: {"Unified_Ideograph", "Ideographic"},
    26502: {"Unified_Ideograph", "Ideographic"},
    26503: {"Unified_Ideograph", "Ideographic"},
    26504: {"Unified_Ideograph", "Ideographic"},
    26505: {"Unified_Ideograph", "Ideographic"},
    26506: {"Unified_Ideograph", "Ideographic"},
    26507: {"Unified_Ideograph", "Ideographic"},
    26508: {"Unified_Ideograph", "Ideographic"},
    26509: {"Unified_Ideograph", "Ideographic"},
    26510: {"Unified_Ideograph", "Ideographic"},
    26511: {"Unified_Ideograph", "Ideographic"},
    26512: {"Unified_Ideograph", "Ideographic"},
    26513: {"Unified_Ideograph", "Ideographic"},
    26514: {"Unified_Ideograph", "Ideographic"},
    26515: {"Unified_Ideograph", "Ideographic"},
    26516: {"Unified_Ideograph", "Ideographic"},
    26517: {"Unified_Ideograph", "Ideographic"},
    26518: {"Unified_Ideograph", "Ideographic"},
    26519: {"Unified_Ideograph", "Ideographic"},
    26520: {"Unified_Ideograph", "Ideographic"},
    26521: {"Unified_Ideograph", "Ideographic"},
    26522: {"Unified_Ideograph", "Ideographic"},
    26523: {"Unified_Ideograph", "Ideographic"},
    26524: {"Unified_Ideograph", "Ideographic"},
    26525: {"Unified_Ideograph", "Ideographic"},
    26526: {"Unified_Ideograph", "Ideographic"},
    26527: {"Unified_Ideograph", "Ideographic"},
    26528: {"Unified_Ideograph", "Ideographic"},
    26529: {"Unified_Ideograph", "Ideographic"},
    26530: {"Unified_Ideograph", "Ideographic"},
    26531: {"Unified_Ideograph", "Ideographic"},
    26532: {"Unified_Ideograph", "Ideographic"},
    26533: {"Unified_Ideograph", "Ideographic"},
    26534: {"Unified_Ideograph", "Ideographic"},
    26535: {"Unified_Ideograph", "Ideographic"},
    26536: {"Unified_Ideograph", "Ideographic"},
    26537: {"Unified_Ideograph", "Ideographic"},
    26538: {"Unified_Ideograph", "Ideographic"},
    26539: {"Unified_Ideograph", "Ideographic"},
    26540: {"Unified_Ideograph", "Ideographic"},
    26541: {"Unified_Ideograph", "Ideographic"},
    26542: {"Unified_Ideograph", "Ideographic"},
    26543: {"Unified_Ideograph", "Ideographic"},
    26544: {"Unified_Ideograph", "Ideographic"},
    26545: {"Unified_Ideograph", "Ideographic"},
    26546: {"Unified_Ideograph", "Ideographic"},
    26547: {"Unified_Ideograph", "Ideographic"},
    26548: {"Unified_Ideograph", "Ideographic"},
    26549: {"Unified_Ideograph", "Ideographic"},
    26550: {"Unified_Ideograph", "Ideographic"},
    26551: {"Unified_Ideograph", "Ideographic"},
    26552: {"Unified_Ideograph", "Ideographic"},
    26553: {"Unified_Ideograph", "Ideographic"},
    26554: {"Unified_Ideograph", "Ideographic"},
    26555: {"Unified_Ideograph", "Ideographic"},
    26556: {"Unified_Ideograph", "Ideographic"},
    26557: {"Unified_Ideograph", "Ideographic"},
    26558: {"Unified_Ideograph", "Ideographic"},
    26559: {"Unified_Ideograph", "Ideographic"},
    26560: {"Unified_Ideograph", "Ideographic"},
    26561: {"Unified_Ideograph", "Ideographic"},
    26562: {"Unified_Ideograph", "Ideographic"},
    26563: {"Unified_Ideograph", "Ideographic"},
    26564: {"Unified_Ideograph", "Ideographic"},
    26565: {"Unified_Ideograph", "Ideographic"},
    26566: {"Unified_Ideograph", "Ideographic"},
    26567: {"Unified_Ideograph", "Ideographic"},
    26568: {"Unified_Ideograph", "Ideographic"},
    26569: {"Unified_Ideograph", "Ideographic"},
    26570: {"Unified_Ideograph", "Ideographic"},
    26571: {"Unified_Ideograph", "Ideographic"},
    26572: {"Unified_Ideograph", "Ideographic"},
    26573: {"Unified_Ideograph", "Ideographic"},
    26574: {"Unified_Ideograph", "Ideographic"},
    26575: {"Unified_Ideograph", "Ideographic"},
    26576: {"Unified_Ideograph", "Ideographic"},
    26577: {"Unified_Ideograph", "Ideographic"},
    26578: {"Unified_Ideograph", "Ideographic"},
    26579: {"Unified_Ideograph", "Ideographic"},
    26580: {"Unified_Ideograph", "Ideographic"},
    26581: {"Unified_Ideograph", "Ideographic"},
    26582: {"Unified_Ideograph", "Ideographic"},
    26583: {"Unified_Ideograph", "Ideographic"},
    26584: {"Unified_Ideograph", "Ideographic"},
    26585: {"Unified_Ideograph", "Ideographic"},
    26586: {"Unified_Ideograph", "Ideographic"},
    26587: {"Unified_Ideograph", "Ideographic"},
    26588: {"Unified_Ideograph", "Ideographic"},
    26589: {"Unified_Ideograph", "Ideographic"},
    26590: {"Unified_Ideograph", "Ideographic"},
    26591: {"Unified_Ideograph", "Ideographic"},
    26592: {"Unified_Ideograph", "Ideographic"},
    26593: {"Unified_Ideograph", "Ideographic"},
    26594: {"Unified_Ideograph", "Ideographic"},
    26595: {"Unified_Ideograph", "Ideographic"},
    26596: {"Unified_Ideograph", "Ideographic"},
    26597: {"Unified_Ideograph", "Ideographic"},
    26598: {"Unified_Ideograph", "Ideographic"},
    26599: {"Unified_Ideograph", "Ideographic"},
    26600: {"Unified_Ideograph", "Ideographic"},
    26601: {"Unified_Ideograph", "Ideographic"},
    26602: {"Unified_Ideograph", "Ideographic"},
    26603: {"Unified_Ideograph", "Ideographic"},
    26604: {"Unified_Ideograph", "Ideographic"},
    26605: {"Unified_Ideograph", "Ideographic"},
    26606: {"Unified_Ideograph", "Ideographic"},
    26607: {"Unified_Ideograph", "Ideographic"},
    26608: {"Unified_Ideograph", "Ideographic"},
    26609: {"Unified_Ideograph", "Ideographic"},
    26610: {"Unified_Ideograph", "Ideographic"},
    26611: {"Unified_Ideograph", "Ideographic"},
    26612: {"Unified_Ideograph", "Ideographic"},
    26613: {"Unified_Ideograph", "Ideographic"},
    26614: {"Unified_Ideograph", "Ideographic"},
    26615: {"Unified_Ideograph", "Ideographic"},
    26616: {"Unified_Ideograph", "Ideographic"},
    26617: {"Unified_Ideograph", "Ideographic"},
    26618: {"Unified_Ideograph", "Ideographic"},
    26619: {"Unified_Ideograph", "Ideographic"},
    26620: {"Unified_Ideograph", "Ideographic"},
    26621: {"Unified_Ideograph", "Ideographic"},
    26622: {"Unified_Ideograph", "Ideographic"},
    26623: {"Unified_Ideograph", "Ideographic"},
    26624: {"Unified_Ideograph", "Ideographic"},
    26625: {"Unified_Ideograph", "Ideographic"},
    26626: {"Unified_Ideograph", "Ideographic"},
    26627: {"Unified_Ideograph", "Ideographic"},
    26628: {"Unified_Ideograph", "Ideographic"},
    26629: {"Unified_Ideograph", "Ideographic"},
    26630: {"Unified_Ideograph", "Ideographic"},
    26631: {"Unified_Ideograph", "Ideographic"},
    26632: {"Unified_Ideograph", "Ideographic"},
    26633: {"Unified_Ideograph", "Ideographic"},
    26634: {"Unified_Ideograph", "Ideographic"},
    26635: {"Unified_Ideograph", "Ideographic"},
    26636: {"Unified_Ideograph", "Ideographic"},
    26637: {"Unified_Ideograph", "Ideographic"},
    26638: {"Unified_Ideograph", "Ideographic"},
    26639: {"Unified_Ideograph", "Ideographic"},
    26640: {"Unified_Ideograph", "Ideographic"},
    26641: {"Unified_Ideograph", "Ideographic"},
    26642: {"Unified_Ideograph", "Ideographic"},
    26643: {"Unified_Ideograph", "Ideographic"},
    26644: {"Unified_Ideograph", "Ideographic"},
    26645: {"Unified_Ideograph", "Ideographic"},
    26646: {"Unified_Ideograph", "Ideographic"},
    26647: {"Unified_Ideograph", "Ideographic"},
    26648: {"Unified_Ideograph", "Ideographic"},
    26649: {"Unified_Ideograph", "Ideographic"},
    26650: {"Unified_Ideograph", "Ideographic"},
    26651: {"Unified_Ideograph", "Ideographic"},
    26652: {"Unified_Ideograph", "Ideographic"},
    26653: {"Unified_Ideograph", "Ideographic"},
    26654: {"Unified_Ideograph", "Ideographic"},
    26655: {"Unified_Ideograph", "Ideographic"},
    26656: {"Unified_Ideograph", "Ideographic"},
    26657: {"Unified_Ideograph", "Ideographic"},
    26658: {"Unified_Ideograph", "Ideographic"},
    26659: {"Unified_Ideograph", "Ideographic"},
    26660: {"Unified_Ideograph", "Ideographic"},
    26661: {"Unified_Ideograph", "Ideographic"},
    26662: {"Unified_Ideograph", "Ideographic"},
    26663: {"Unified_Ideograph", "Ideographic"},
    26664: {"Unified_Ideograph", "Ideographic"},
    26665: {"Unified_Ideograph", "Ideographic"},
    26666: {"Unified_Ideograph", "Ideographic"},
    26667: {"Unified_Ideograph", "Ideographic"},
    26668: {"Unified_Ideograph", "Ideographic"},
    26669: {"Unified_Ideograph", "Ideographic"},
    26670: {"Unified_Ideograph", "Ideographic"},
    26671: {"Unified_Ideograph", "Ideographic"},
    26672: {"Unified_Ideograph", "Ideographic"},
    26673: {"Unified_Ideograph", "Ideographic"},
    26674: {"Unified_Ideograph", "Ideographic"},
    26675: {"Unified_Ideograph", "Ideographic"},
    26676: {"Unified_Ideograph", "Ideographic"},
    26677: {"Unified_Ideograph", "Ideographic"},
    26678: {"Unified_Ideograph", "Ideographic"},
    26679: {"Unified_Ideograph", "Ideographic"},
    26680: {"Unified_Ideograph", "Ideographic"},
    26681: {"Unified_Ideograph", "Ideographic"},
    26682: {"Unified_Ideograph", "Ideographic"},
    26683: {"Unified_Ideograph", "Ideographic"},
    26684: {"Unified_Ideograph", "Ideographic"},
    26685: {"Unified_Ideograph", "Ideographic"},
    26686: {"Unified_Ideograph", "Ideographic"},
    26687: {"Unified_Ideograph", "Ideographic"},
    26688: {"Unified_Ideograph", "Ideographic"},
    26689: {"Unified_Ideograph", "Ideographic"},
    26690: {"Unified_Ideograph", "Ideographic"},
    26691: {"Unified_Ideograph", "Ideographic"},
    26692: {"Unified_Ideograph", "Ideographic"},
    26693: {"Unified_Ideograph", "Ideographic"},
    26694: {"Unified_Ideograph", "Ideographic"},
    26695: {"Unified_Ideograph", "Ideographic"},
    26696: {"Unified_Ideograph", "Ideographic"},
    26697: {"Unified_Ideograph", "Ideographic"},
    26698: {"Unified_Ideograph", "Ideographic"},
    26699: {"Unified_Ideograph", "Ideographic"},
    26700: {"Unified_Ideograph", "Ideographic"},
    26701: {"Unified_Ideograph", "Ideographic"},
    26702: {"Unified_Ideograph", "Ideographic"},
    26703: {"Unified_Ideograph", "Ideographic"},
    26704: {"Unified_Ideograph", "Ideographic"},
    26705: {"Unified_Ideograph", "Ideographic"},
    26706: {"Unified_Ideograph", "Ideographic"},
    26707: {"Unified_Ideograph", "Ideographic"},
    26708: {"Unified_Ideograph", "Ideographic"},
    26709: {"Unified_Ideograph", "Ideographic"},
    26710: {"Unified_Ideograph", "Ideographic"},
    26711: {"Unified_Ideograph", "Ideographic"},
    26712: {"Unified_Ideograph", "Ideographic"},
    26713: {"Unified_Ideograph", "Ideographic"},
    26714: {"Unified_Ideograph", "Ideographic"},
    26715: {"Unified_Ideograph", "Ideographic"},
    26716: {"Unified_Ideograph", "Ideographic"},
    26717: {"Unified_Ideograph", "Ideographic"},
    26718: {"Unified_Ideograph", "Ideographic"},
    26719: {"Unified_Ideograph", "Ideographic"},
    26720: {"Unified_Ideograph", "Ideographic"},
    26721: {"Unified_Ideograph", "Ideographic"},
    26722: {"Unified_Ideograph", "Ideographic"},
    26723: {"Unified_Ideograph", "Ideographic"},
    26724: {"Unified_Ideograph", "Ideographic"},
    26725: {"Unified_Ideograph", "Ideographic"},
    26726: {"Unified_Ideograph", "Ideographic"},
    26727: {"Unified_Ideograph", "Ideographic"},
    26728: {"Unified_Ideograph", "Ideographic"},
    26729: {"Unified_Ideograph", "Ideographic"},
    26730: {"Unified_Ideograph", "Ideographic"},
    26731: {"Unified_Ideograph", "Ideographic"},
    26732: {"Unified_Ideograph", "Ideographic"},
    26733: {"Unified_Ideograph", "Ideographic"},
    26734: {"Unified_Ideograph", "Ideographic"},
    26735: {"Unified_Ideograph", "Ideographic"},
    26736: {"Unified_Ideograph", "Ideographic"},
    26737: {"Unified_Ideograph", "Ideographic"},
    26738: {"Unified_Ideograph", "Ideographic"},
    26739: {"Unified_Ideograph", "Ideographic"},
    26740: {"Unified_Ideograph", "Ideographic"},
    26741: {"Unified_Ideograph", "Ideographic"},
    26742: {"Unified_Ideograph", "Ideographic"},
    26743: {"Unified_Ideograph", "Ideographic"},
    26744: {"Unified_Ideograph", "Ideographic"},
    26745: {"Unified_Ideograph", "Ideographic"},
    26746: {"Unified_Ideograph", "Ideographic"},
    26747: {"Unified_Ideograph", "Ideographic"},
    26748: {"Unified_Ideograph", "Ideographic"},
    26749: {"Unified_Ideograph", "Ideographic"},
    26750: {"Unified_Ideograph", "Ideographic"},
    26751: {"Unified_Ideograph", "Ideographic"},
    26752: {"Unified_Ideograph", "Ideographic"},
    26753: {"Unified_Ideograph", "Ideographic"},
    26754: {"Unified_Ideograph", "Ideographic"},
    26755: {"Unified_Ideograph", "Ideographic"},
    26756: {"Unified_Ideograph", "Ideographic"},
    26757: {"Unified_Ideograph", "Ideographic"},
    26758: {"Unified_Ideograph", "Ideographic"},
    26759: {"Unified_Ideograph", "Ideographic"},
    26760: {"Unified_Ideograph", "Ideographic"},
    26761: {"Unified_Ideograph", "Ideographic"},
    26762: {"Unified_Ideograph", "Ideographic"},
    26763: {"Unified_Ideograph", "Ideographic"},
    26764: {"Unified_Ideograph", "Ideographic"},
    26765: {"Unified_Ideograph", "Ideographic"},
    26766: {"Unified_Ideograph", "Ideographic"},
    26767: {"Unified_Ideograph", "Ideographic"},
    26768: {"Unified_Ideograph", "Ideographic"},
    26769: {"Unified_Ideograph", "Ideographic"},
    26770: {"Unified_Ideograph", "Ideographic"},
    26771: {"Unified_Ideograph", "Ideographic"},
    26772: {"Unified_Ideograph", "Ideographic"},
    26773: {"Unified_Ideograph", "Ideographic"},
    26774: {"Unified_Ideograph", "Ideographic"},
    26775: {"Unified_Ideograph", "Ideographic"},
    26776: {"Unified_Ideograph", "Ideographic"},
    26777: {"Unified_Ideograph", "Ideographic"},
    26778: {"Unified_Ideograph", "Ideographic"},
    26779: {"Unified_Ideograph", "Ideographic"},
    26780: {"Unified_Ideograph", "Ideographic"},
    26781: {"Unified_Ideograph", "Ideographic"},
    26782: {"Unified_Ideograph", "Ideographic"},
    26783: {"Unified_Ideograph", "Ideographic"},
    26784: {"Unified_Ideograph", "Ideographic"},
    26785: {"Unified_Ideograph", "Ideographic"},
    26786: {"Unified_Ideograph", "Ideographic"},
    26787: {"Unified_Ideograph", "Ideographic"},
    26788: {"Unified_Ideograph", "Ideographic"},
    26789: {"Unified_Ideograph", "Ideographic"},
    26790: {"Unified_Ideograph", "Ideographic"},
    26791: {"Unified_Ideograph", "Ideographic"},
    26792: {"Unified_Ideograph", "Ideographic"},
    26793: {"Unified_Ideograph", "Ideographic"},
    26794: {"Unified_Ideograph", "Ideographic"},
    26795: {"Unified_Ideograph", "Ideographic"},
    26796: {"Unified_Ideograph", "Ideographic"},
    26797: {"Unified_Ideograph", "Ideographic"},
    26798: {"Unified_Ideograph", "Ideographic"},
    26799: {"Unified_Ideograph", "Ideographic"},
    26800: {"Unified_Ideograph", "Ideographic"},
    26801: {"Unified_Ideograph", "Ideographic"},
    26802: {"Unified_Ideograph", "Ideographic"},
    26803: {"Unified_Ideograph", "Ideographic"},
    26804: {"Unified_Ideograph", "Ideographic"},
    26805: {"Unified_Ideograph", "Ideographic"},
    26806: {"Unified_Ideograph", "Ideographic"},
    26807: {"Unified_Ideograph", "Ideographic"},
    26808: {"Unified_Ideograph", "Ideographic"},
    26809: {"Unified_Ideograph", "Ideographic"},
    26810: {"Unified_Ideograph", "Ideographic"},
    26811: {"Unified_Ideograph", "Ideographic"},
    26812: {"Unified_Ideograph", "Ideographic"},
    26813: {"Unified_Ideograph", "Ideographic"},
    26814: {"Unified_Ideograph", "Ideographic"},
    26815: {"Unified_Ideograph", "Ideographic"},
    26816: {"Unified_Ideograph", "Ideographic"},
    26817: {"Unified_Ideograph", "Ideographic"},
    26818: {"Unified_Ideograph", "Ideographic"},
    26819: {"Unified_Ideograph", "Ideographic"},
    26820: {"Unified_Ideograph", "Ideographic"},
    26821: {"Unified_Ideograph", "Ideographic"},
    26822: {"Unified_Ideograph", "Ideographic"},
    26823: {"Unified_Ideograph", "Ideographic"},
    26824: {"Unified_Ideograph", "Ideographic"},
    26825: {"Unified_Ideograph", "Ideographic"},
    26826: {"Unified_Ideograph", "Ideographic"},
    26827: {"Unified_Ideograph", "Ideographic"},
    26828: {"Unified_Ideograph", "Ideographic"},
    26829: {"Unified_Ideograph", "Ideographic"},
    26830: {"Unified_Ideograph", "Ideographic"},
    26831: {"Unified_Ideograph", "Ideographic"},
    26832: {"Unified_Ideograph", "Ideographic"},
    26833: {"Unified_Ideograph", "Ideographic"},
    26834: {"Unified_Ideograph", "Ideographic"},
    26835: {"Unified_Ideograph", "Ideographic"},
    26836: {"Unified_Ideograph", "Ideographic"},
    26837: {"Unified_Ideograph", "Ideographic"},
    26838: {"Unified_Ideograph", "Ideographic"},
    26839: {"Unified_Ideograph", "Ideographic"},
    26840: {"Unified_Ideograph", "Ideographic"},
    26841: {"Unified_Ideograph", "Ideographic"},
    26842: {"Unified_Ideograph", "Ideographic"},
    26843: {"Unified_Ideograph", "Ideographic"},
    26844: {"Unified_Ideograph", "Ideographic"},
    26845: {"Unified_Ideograph", "Ideographic"},
    26846: {"Unified_Ideograph", "Ideographic"},
    26847: {"Unified_Ideograph", "Ideographic"},
    26848: {"Unified_Ideograph", "Ideographic"},
    26849: {"Unified_Ideograph", "Ideographic"},
    26850: {"Unified_Ideograph", "Ideographic"},
    26851: {"Unified_Ideograph", "Ideographic"},
    26852: {"Unified_Ideograph", "Ideographic"},
    26853: {"Unified_Ideograph", "Ideographic"},
    26854: {"Unified_Ideograph", "Ideographic"},
    26855: {"Unified_Ideograph", "Ideographic"},
    26856: {"Unified_Ideograph", "Ideographic"},
    26857: {"Unified_Ideograph", "Ideographic"},
    26858: {"Unified_Ideograph", "Ideographic"},
    26859: {"Unified_Ideograph", "Ideographic"},
    26860: {"Unified_Ideograph", "Ideographic"},
    26861: {"Unified_Ideograph", "Ideographic"},
    26862: {"Unified_Ideograph", "Ideographic"},
    26863: {"Unified_Ideograph", "Ideographic"},
    26864: {"Unified_Ideograph", "Ideographic"},
    26865: {"Unified_Ideograph", "Ideographic"},
    26866: {"Unified_Ideograph", "Ideographic"},
    26867: {"Unified_Ideograph", "Ideographic"},
    26868: {"Unified_Ideograph", "Ideographic"},
    26869: {"Unified_Ideograph", "Ideographic"},
    26870: {"Unified_Ideograph", "Ideographic"},
    26871: {"Unified_Ideograph", "Ideographic"},
    26872: {"Unified_Ideograph", "Ideographic"},
    26873: {"Unified_Ideograph", "Ideographic"},
    26874: {"Unified_Ideograph", "Ideographic"},
    26875: {"Unified_Ideograph", "Ideographic"},
    26876: {"Unified_Ideograph", "Ideographic"},
    26877: {"Unified_Ideograph", "Ideographic"},
    26878: {"Unified_Ideograph", "Ideographic"},
    26879: {"Unified_Ideograph", "Ideographic"},
    26880: {"Unified_Ideograph", "Ideographic"},
    26881: {"Unified_Ideograph", "Ideographic"},
    26882: {"Unified_Ideograph", "Ideographic"},
    26883: {"Unified_Ideograph", "Ideographic"},
    26884: {"Unified_Ideograph", "Ideographic"},
    26885: {"Unified_Ideograph", "Ideographic"},
    26886: {"Unified_Ideograph", "Ideographic"},
    26887: {"Unified_Ideograph", "Ideographic"},
    26888: {"Unified_Ideograph", "Ideographic"},
    26889: {"Unified_Ideograph", "Ideographic"},
    26890: {"Unified_Ideograph", "Ideographic"},
    26891: {"Unified_Ideograph", "Ideographic"},
    26892: {"Unified_Ideograph", "Ideographic"},
    26893: {"Unified_Ideograph", "Ideographic"},
    26894: {"Unified_Ideograph", "Ideographic"},
    26895: {"Unified_Ideograph", "Ideographic"},
    26896: {"Unified_Ideograph", "Ideographic"},
    26897: {"Unified_Ideograph", "Ideographic"},
    26898: {"Unified_Ideograph", "Ideographic"},
    26899: {"Unified_Ideograph", "Ideographic"},
    26900: {"Unified_Ideograph", "Ideographic"},
    26901: {"Unified_Ideograph", "Ideographic"},
    26902: {"Unified_Ideograph", "Ideographic"},
    26903: {"Unified_Ideograph", "Ideographic"},
    26904: {"Unified_Ideograph", "Ideographic"},
    26905: {"Unified_Ideograph", "Ideographic"},
    26906: {"Unified_Ideograph", "Ideographic"},
    26907: {"Unified_Ideograph", "Ideographic"},
    26908: {"Unified_Ideograph", "Ideographic"},
    26909: {"Unified_Ideograph", "Ideographic"},
    26910: {"Unified_Ideograph", "Ideographic"},
    26911: {"Unified_Ideograph", "Ideographic"},
    26912: {"Unified_Ideograph", "Ideographic"},
    26913: {"Unified_Ideograph", "Ideographic"},
    26914: {"Unified_Ideograph", "Ideographic"},
    26915: {"Unified_Ideograph", "Ideographic"},
    26916: {"Unified_Ideograph", "Ideographic"},
    26917: {"Unified_Ideograph", "Ideographic"},
    26918: {"Unified_Ideograph", "Ideographic"},
    26919: {"Unified_Ideograph", "Ideographic"},
    26920: {"Unified_Ideograph", "Ideographic"},
    26921: {"Unified_Ideograph", "Ideographic"},
    26922: {"Unified_Ideograph", "Ideographic"},
    26923: {"Unified_Ideograph", "Ideographic"},
    26924: {"Unified_Ideograph", "Ideographic"},
    26925: {"Unified_Ideograph", "Ideographic"},
    26926: {"Unified_Ideograph", "Ideographic"},
    26927: {"Unified_Ideograph", "Ideographic"},
    26928: {"Unified_Ideograph", "Ideographic"},
    26929: {"Unified_Ideograph", "Ideographic"},
    26930: {"Unified_Ideograph", "Ideographic"},
    26931: {"Unified_Ideograph", "Ideographic"},
    26932: {"Unified_Ideograph", "Ideographic"},
    26933: {"Unified_Ideograph", "Ideographic"},
    26934: {"Unified_Ideograph", "Ideographic"},
    26935: {"Unified_Ideograph", "Ideographic"},
    26936: {"Unified_Ideograph", "Ideographic"},
    26937: {"Unified_Ideograph", "Ideographic"},
    26938: {"Unified_Ideograph", "Ideographic"},
    26939: {"Unified_Ideograph", "Ideographic"},
    26940: {"Unified_Ideograph", "Ideographic"},
    26941: {"Unified_Ideograph", "Ideographic"},
    26942: {"Unified_Ideograph", "Ideographic"},
    26943: {"Unified_Ideograph", "Ideographic"},
    26944: {"Unified_Ideograph", "Ideographic"},
    26945: {"Unified_Ideograph", "Ideographic"},
    26946: {"Unified_Ideograph", "Ideographic"},
    26947: {"Unified_Ideograph", "Ideographic"},
    26948: {"Unified_Ideograph", "Ideographic"},
    26949: {"Unified_Ideograph", "Ideographic"},
    26950: {"Unified_Ideograph", "Ideographic"},
    26951: {"Unified_Ideograph", "Ideographic"},
    26952: {"Unified_Ideograph", "Ideographic"},
    26953: {"Unified_Ideograph", "Ideographic"},
    26954: {"Unified_Ideograph", "Ideographic"},
    26955: {"Unified_Ideograph", "Ideographic"},
    26956: {"Unified_Ideograph", "Ideographic"},
    26957: {"Unified_Ideograph", "Ideographic"},
    26958: {"Unified_Ideograph", "Ideographic"},
    26959: {"Unified_Ideograph", "Ideographic"},
    26960: {"Unified_Ideograph", "Ideographic"},
    26961: {"Unified_Ideograph", "Ideographic"},
    26962: {"Unified_Ideograph", "Ideographic"},
    26963: {"Unified_Ideograph", "Ideographic"},
    26964: {"Unified_Ideograph", "Ideographic"},
    26965: {"Unified_Ideograph", "Ideographic"},
    26966: {"Unified_Ideograph", "Ideographic"},
    26967: {"Unified_Ideograph", "Ideographic"},
    26968: {"Unified_Ideograph", "Ideographic"},
    26969: {"Unified_Ideograph", "Ideographic"},
    26970: {"Unified_Ideograph", "Ideographic"},
    26971: {"Unified_Ideograph", "Ideographic"},
    26972: {"Unified_Ideograph", "Ideographic"},
    26973: {"Unified_Ideograph", "Ideographic"},
    26974: {"Unified_Ideograph", "Ideographic"},
    26975: {"Unified_Ideograph", "Ideographic"},
    26976: {"Unified_Ideograph", "Ideographic"},
    26977: {"Unified_Ideograph", "Ideographic"},
    26978: {"Unified_Ideograph", "Ideographic"},
    26979: {"Unified_Ideograph", "Ideographic"},
    26980: {"Unified_Ideograph", "Ideographic"},
    26981: {"Unified_Ideograph", "Ideographic"},
    26982: {"Unified_Ideograph", "Ideographic"},
    26983: {"Unified_Ideograph", "Ideographic"},
    26984: {"Unified_Ideograph", "Ideographic"},
    26985: {"Unified_Ideograph", "Ideographic"},
    26986: {"Unified_Ideograph", "Ideographic"},
    26987: {"Unified_Ideograph", "Ideographic"},
    26988: {"Unified_Ideograph", "Ideographic"},
    26989: {"Unified_Ideograph", "Ideographic"},
    26990: {"Unified_Ideograph", "Ideographic"},
    26991: {"Unified_Ideograph", "Ideographic"},
    26992: {"Unified_Ideograph", "Ideographic"},
    26993: {"Unified_Ideograph", "Ideographic"},
    26994: {"Unified_Ideograph", "Ideographic"},
    26995: {"Unified_Ideograph", "Ideographic"},
    26996: {"Unified_Ideograph", "Ideographic"},
    26997: {"Unified_Ideograph", "Ideographic"},
    26998: {"Unified_Ideograph", "Ideographic"},
    26999: {"Unified_Ideograph", "Ideographic"},
    27000: {"Unified_Ideograph", "Ideographic"},
    27001: {"Unified_Ideograph", "Ideographic"},
    27002: {"Unified_Ideograph", "Ideographic"},
    27003: {"Unified_Ideograph", "Ideographic"},
    27004: {"Unified_Ideograph", "Ideographic"},
    27005: {"Unified_Ideograph", "Ideographic"},
    27006: {"Unified_Ideograph", "Ideographic"},
    27007: {"Unified_Ideograph", "Ideographic"},
    27008: {"Unified_Ideograph", "Ideographic"},
    27009: {"Unified_Ideograph", "Ideographic"},
    27010: {"Unified_Ideograph", "Ideographic"},
    27011: {"Unified_Ideograph", "Ideographic"},
    27012: {"Unified_Ideograph", "Ideographic"},
    27013: {"Unified_Ideograph", "Ideographic"},
    27014: {"Unified_Ideograph", "Ideographic"},
    27015: {"Unified_Ideograph", "Ideographic"},
    27016: {"Unified_Ideograph", "Ideographic"},
    27017: {"Unified_Ideograph", "Ideographic"},
    27018: {"Unified_Ideograph", "Ideographic"},
    27019: {"Unified_Ideograph", "Ideographic"},
    27020: {"Unified_Ideograph", "Ideographic"},
    27021: {"Unified_Ideograph", "Ideographic"},
    27022: {"Unified_Ideograph", "Ideographic"},
    27023: {"Unified_Ideograph", "Ideographic"},
    27024: {"Unified_Ideograph", "Ideographic"},
    27025: {"Unified_Ideograph", "Ideographic"},
    27026: {"Unified_Ideograph", "Ideographic"},
    27027: {"Unified_Ideograph", "Ideographic"},
    27028: {"Unified_Ideograph", "Ideographic"},
    27029: {"Unified_Ideograph", "Ideographic"},
    27030: {"Unified_Ideograph", "Ideographic"},
    27031: {"Unified_Ideograph", "Ideographic"},
    27032: {"Unified_Ideograph", "Ideographic"},
    27033: {"Unified_Ideograph", "Ideographic"},
    27034: {"Unified_Ideograph", "Ideographic"},
    27035: {"Unified_Ideograph", "Ideographic"},
    27036: {"Unified_Ideograph", "Ideographic"},
    27037: {"Unified_Ideograph", "Ideographic"},
    27038: {"Unified_Ideograph", "Ideographic"},
    27039: {"Unified_Ideograph", "Ideographic"},
    27040: {"Unified_Ideograph", "Ideographic"},
    27041: {"Unified_Ideograph", "Ideographic"},
    27042: {"Unified_Ideograph", "Ideographic"},
    27043: {"Unified_Ideograph", "Ideographic"},
    27044: {"Unified_Ideograph", "Ideographic"},
    27045: {"Unified_Ideograph", "Ideographic"},
    27046: {"Unified_Ideograph", "Ideographic"},
    27047: {"Unified_Ideograph", "Ideographic"},
    27048: {"Unified_Ideograph", "Ideographic"},
    27049: {"Unified_Ideograph", "Ideographic"},
    27050: {"Unified_Ideograph", "Ideographic"},
    27051: {"Unified_Ideograph", "Ideographic"},
    27052: {"Unified_Ideograph", "Ideographic"},
    27053: {"Unified_Ideograph", "Ideographic"},
    27054: {"Unified_Ideograph", "Ideographic"},
    27055: {"Unified_Ideograph", "Ideographic"},
    27056: {"Unified_Ideograph", "Ideographic"},
    27057: {"Unified_Ideograph", "Ideographic"},
    27058: {"Unified_Ideograph", "Ideographic"},
    27059: {"Unified_Ideograph", "Ideographic"},
    27060: {"Unified_Ideograph", "Ideographic"},
    27061: {"Unified_Ideograph", "Ideographic"},
    27062: {"Unified_Ideograph", "Ideographic"},
    27063: {"Unified_Ideograph", "Ideographic"},
    27064: {"Unified_Ideograph", "Ideographic"},
    27065: {"Unified_Ideograph", "Ideographic"},
    27066: {"Unified_Ideograph", "Ideographic"},
    27067: {"Unified_Ideograph", "Ideographic"},
    27068: {"Unified_Ideograph", "Ideographic"},
    27069: {"Unified_Ideograph", "Ideographic"},
    27070: {"Unified_Ideograph", "Ideographic"},
    27071: {"Unified_Ideograph", "Ideographic"},
    27072: {"Unified_Ideograph", "Ideographic"},
    27073: {"Unified_Ideograph", "Ideographic"},
    27074: {"Unified_Ideograph", "Ideographic"},
    27075: {"Unified_Ideograph", "Ideographic"},
    27076: {"Unified_Ideograph", "Ideographic"},
    27077: {"Unified_Ideograph", "Ideographic"},
    27078: {"Unified_Ideograph", "Ideographic"},
    27079: {"Unified_Ideograph", "Ideographic"},
    27080: {"Unified_Ideograph", "Ideographic"},
    27081: {"Unified_Ideograph", "Ideographic"},
    27082: {"Unified_Ideograph", "Ideographic"},
    27083: {"Unified_Ideograph", "Ideographic"},
    27084: {"Unified_Ideograph", "Ideographic"},
    27085: {"Unified_Ideograph", "Ideographic"},
    27086: {"Unified_Ideograph", "Ideographic"},
    27087: {"Unified_Ideograph", "Ideographic"},
    27088: {"Unified_Ideograph", "Ideographic"},
    27089: {"Unified_Ideograph", "Ideographic"},
    27090: {"Unified_Ideograph", "Ideographic"},
    27091: {"Unified_Ideograph", "Ideographic"},
    27092: {"Unified_Ideograph", "Ideographic"},
    27093: {"Unified_Ideograph", "Ideographic"},
    27094: {"Unified_Ideograph", "Ideographic"},
    27095: {"Unified_Ideograph", "Ideographic"},
    27096: {"Unified_Ideograph", "Ideographic"},
    27097: {"Unified_Ideograph", "Ideographic"},
    27098: {"Unified_Ideograph", "Ideographic"},
    27099: {"Unified_Ideograph", "Ideographic"},
    27100: {"Unified_Ideograph", "Ideographic"},
    27101: {"Unified_Ideograph", "Ideographic"},
    27102: {"Unified_Ideograph", "Ideographic"},
    27103: {"Unified_Ideograph", "Ideographic"},
    27104: {"Unified_Ideograph", "Ideographic"},
    27105: {"Unified_Ideograph", "Ideographic"},
    27106: {"Unified_Ideograph", "Ideographic"},
    27107: {"Unified_Ideograph", "Ideographic"},
    27108: {"Unified_Ideograph", "Ideographic"},
    27109: {"Unified_Ideograph", "Ideographic"},
    27110: {"Unified_Ideograph", "Ideographic"},
    27111: {"Unified_Ideograph", "Ideographic"},
    27112: {"Unified_Ideograph", "Ideographic"},
    27113: {"Unified_Ideograph", "Ideographic"},
    27114: {"Unified_Ideograph", "Ideographic"},
    27115: {"Unified_Ideograph", "Ideographic"},
    27116: {"Unified_Ideograph", "Ideographic"},
    27117: {"Unified_Ideograph", "Ideographic"},
    27118: {"Unified_Ideograph", "Ideographic"},
    27119: {"Unified_Ideograph", "Ideographic"},
    27120: {"Unified_Ideograph", "Ideographic"},
    27121: {"Unified_Ideograph", "Ideographic"},
    27122: {"Unified_Ideograph", "Ideographic"},
    27123: {"Unified_Ideograph", "Ideographic"},
    27124: {"Unified_Ideograph", "Ideographic"},
    27125: {"Unified_Ideograph", "Ideographic"},
    27126: {"Unified_Ideograph", "Ideographic"},
    27127: {"Unified_Ideograph", "Ideographic"},
    27128: {"Unified_Ideograph", "Ideographic"},
    27129: {"Unified_Ideograph", "Ideographic"},
    27130: {"Unified_Ideograph", "Ideographic"},
    27131: {"Unified_Ideograph", "Ideographic"},
    27132: {"Unified_Ideograph", "Ideographic"},
    27133: {"Unified_Ideograph", "Ideographic"},
    27134: {"Unified_Ideograph", "Ideographic"},
    27135: {"Unified_Ideograph", "Ideographic"},
    27136: {"Unified_Ideograph", "Ideographic"},
    27137: {"Unified_Ideograph", "Ideographic"},
    27138: {"Unified_Ideograph", "Ideographic"},
    27139: {"Unified_Ideograph", "Ideographic"},
    27140: {"Unified_Ideograph", "Ideographic"},
    27141: {"Unified_Ideograph", "Ideographic"},
    27142: {"Unified_Ideograph", "Ideographic"},
    27143: {"Unified_Ideograph", "Ideographic"},
    27144: {"Unified_Ideograph", "Ideographic"},
    27145: {"Unified_Ideograph", "Ideographic"},
    27146: {"Unified_Ideograph", "Ideographic"},
    27147: {"Unified_Ideograph", "Ideographic"},
    27148: {"Unified_Ideograph", "Ideographic"},
    27149: {"Unified_Ideograph", "Ideographic"},
    27150: {"Unified_Ideograph", "Ideographic"},
    27151: {"Unified_Ideograph", "Ideographic"},
    27152: {"Unified_Ideograph", "Ideographic"},
    27153: {"Unified_Ideograph", "Ideographic"},
    27154: {"Unified_Ideograph", "Ideographic"},
    27155: {"Unified_Ideograph", "Ideographic"},
    27156: {"Unified_Ideograph", "Ideographic"},
    27157: {"Unified_Ideograph", "Ideographic"},
    27158: {"Unified_Ideograph", "Ideographic"},
    27159: {"Unified_Ideograph", "Ideographic"},
    27160: {"Unified_Ideograph", "Ideographic"},
    27161: {"Unified_Ideograph", "Ideographic"},
    27162: {"Unified_Ideograph", "Ideographic"},
    27163: {"Unified_Ideograph", "Ideographic"},
    27164: {"Unified_Ideograph", "Ideographic"},
    27165: {"Unified_Ideograph", "Ideographic"},
    27166: {"Unified_Ideograph", "Ideographic"},
    27167: {"Unified_Ideograph", "Ideographic"},
    27168: {"Unified_Ideograph", "Ideographic"},
    27169: {"Unified_Ideograph", "Ideographic"},
    27170: {"Unified_Ideograph", "Ideographic"},
    27171: {"Unified_Ideograph", "Ideographic"},
    27172: {"Unified_Ideograph", "Ideographic"},
    27173: {"Unified_Ideograph", "Ideographic"},
    27174: {"Unified_Ideograph", "Ideographic"},
    27175: {"Unified_Ideograph", "Ideographic"},
    27176: {"Unified_Ideograph", "Ideographic"},
    27177: {"Unified_Ideograph", "Ideographic"},
    27178: {"Unified_Ideograph", "Ideographic"},
    27179: {"Unified_Ideograph", "Ideographic"},
    27180: {"Unified_Ideograph", "Ideographic"},
    27181: {"Unified_Ideograph", "Ideographic"},
    27182: {"Unified_Ideograph", "Ideographic"},
    27183: {"Unified_Ideograph", "Ideographic"},
    27184: {"Unified_Ideograph", "Ideographic"},
    27185: {"Unified_Ideograph", "Ideographic"},
    27186: {"Unified_Ideograph", "Ideographic"},
    27187: {"Unified_Ideograph", "Ideographic"},
    27188: {"Unified_Ideograph", "Ideographic"},
    27189: {"Unified_Ideograph", "Ideographic"},
    27190: {"Unified_Ideograph", "Ideographic"},
    27191: {"Unified_Ideograph", "Ideographic"},
    27192: {"Unified_Ideograph", "Ideographic"},
    27193: {"Unified_Ideograph", "Ideographic"},
    27194: {"Unified_Ideograph", "Ideographic"},
    27195: {"Unified_Ideograph", "Ideographic"},
    27196: {"Unified_Ideograph", "Ideographic"},
    27197: {"Unified_Ideograph", "Ideographic"},
    27198: {"Unified_Ideograph", "Ideographic"},
    27199: {"Unified_Ideograph", "Ideographic"},
    27200: {"Unified_Ideograph", "Ideographic"},
    27201: {"Unified_Ideograph", "Ideographic"},
    27202: {"Unified_Ideograph", "Ideographic"},
    27203: {"Unified_Ideograph", "Ideographic"},
    27204: {"Unified_Ideograph", "Ideographic"},
    27205: {"Unified_Ideograph", "Ideographic"},
    27206: {"Unified_Ideograph", "Ideographic"},
    27207: {"Unified_Ideograph", "Ideographic"},
    27208: {"Unified_Ideograph", "Ideographic"},
    27209: {"Unified_Ideograph", "Ideographic"},
    27210: {"Unified_Ideograph", "Ideographic"},
    27211: {"Unified_Ideograph", "Ideographic"},
    27212: {"Unified_Ideograph", "Ideographic"},
    27213: {"Unified_Ideograph", "Ideographic"},
    27214: {"Unified_Ideograph", "Ideographic"},
    27215: {"Unified_Ideograph", "Ideographic"},
    27216: {"Unified_Ideograph", "Ideographic"},
    27217: {"Unified_Ideograph", "Ideographic"},
    27218: {"Unified_Ideograph", "Ideographic"},
    27219: {"Unified_Ideograph", "Ideographic"},
    27220: {"Unified_Ideograph", "Ideographic"},
    27221: {"Unified_Ideograph", "Ideographic"},
    27222: {"Unified_Ideograph", "Ideographic"},
    27223: {"Unified_Ideograph", "Ideographic"},
    27224: {"Unified_Ideograph", "Ideographic"},
    27225: {"Unified_Ideograph", "Ideographic"},
    27226: {"Unified_Ideograph", "Ideographic"},
    27227: {"Unified_Ideograph", "Ideographic"},
    27228: {"Unified_Ideograph", "Ideographic"},
    27229: {"Unified_Ideograph", "Ideographic"},
    27230: {"Unified_Ideograph", "Ideographic"},
    27231: {"Unified_Ideograph", "Ideographic"},
    27232: {"Unified_Ideograph", "Ideographic"},
    27233: {"Unified_Ideograph", "Ideographic"},
    27234: {"Unified_Ideograph", "Ideographic"},
    27235: {"Unified_Ideograph", "Ideographic"},
    27236: {"Unified_Ideograph", "Ideographic"},
    27237: {"Unified_Ideograph", "Ideographic"},
    27238: {"Unified_Ideograph", "Ideographic"},
    27239: {"Unified_Ideograph", "Ideographic"},
    27240: {"Unified_Ideograph", "Ideographic"},
    27241: {"Unified_Ideograph", "Ideographic"},
    27242: {"Unified_Ideograph", "Ideographic"},
    27243: {"Unified_Ideograph", "Ideographic"},
    27244: {"Unified_Ideograph", "Ideographic"},
    27245: {"Unified_Ideograph", "Ideographic"},
    27246: {"Unified_Ideograph", "Ideographic"},
    27247: {"Unified_Ideograph", "Ideographic"},
    27248: {"Unified_Ideograph", "Ideographic"},
    27249: {"Unified_Ideograph", "Ideographic"},
    27250: {"Unified_Ideograph", "Ideographic"},
    27251: {"Unified_Ideograph", "Ideographic"},
    27252: {"Unified_Ideograph", "Ideographic"},
    27253: {"Unified_Ideograph", "Ideographic"},
    27254: {"Unified_Ideograph", "Ideographic"},
    27255: {"Unified_Ideograph", "Ideographic"},
    27256: {"Unified_Ideograph", "Ideographic"},
    27257: {"Unified_Ideograph", "Ideographic"},
    27258: {"Unified_Ideograph", "Ideographic"},
    27259: {"Unified_Ideograph", "Ideographic"},
    27260: {"Unified_Ideograph", "Ideographic"},
    27261: {"Unified_Ideograph", "Ideographic"},
    27262: {"Unified_Ideograph", "Ideographic"},
    27263: {"Unified_Ideograph", "Ideographic"},
    27264: {"Unified_Ideograph", "Ideographic"},
    27265: {"Unified_Ideograph", "Ideographic"},
    27266: {"Unified_Ideograph", "Ideographic"},
    27267: {"Unified_Ideograph", "Ideographic"},
    27268: {"Unified_Ideograph", "Ideographic"},
    27269: {"Unified_Ideograph", "Ideographic"},
    27270: {"Unified_Ideograph", "Ideographic"},
    27271: {"Unified_Ideograph", "Ideographic"},
    27272: {"Unified_Ideograph", "Ideographic"},
    27273: {"Unified_Ideograph", "Ideographic"},
    27274: {"Unified_Ideograph", "Ideographic"},
    27275: {"Unified_Ideograph", "Ideographic"},
    27276: {"Unified_Ideograph", "Ideographic"},
    27277: {"Unified_Ideograph", "Ideographic"},
    27278: {"Unified_Ideograph", "Ideographic"},
    27279: {"Unified_Ideograph", "Ideographic"},
    27280: {"Unified_Ideograph", "Ideographic"},
    27281: {"Unified_Ideograph", "Ideographic"},
    27282: {"Unified_Ideograph", "Ideographic"},
    27283: {"Unified_Ideograph", "Ideographic"},
    27284: {"Unified_Ideograph", "Ideographic"},
    27285: {"Unified_Ideograph", "Ideographic"},
    27286: {"Unified_Ideograph", "Ideographic"},
    27287: {"Unified_Ideograph", "Ideographic"},
    27288: {"Unified_Ideograph", "Ideographic"},
    27289: {"Unified_Ideograph", "Ideographic"},
    27290: {"Unified_Ideograph", "Ideographic"},
    27291: {"Unified_Ideograph", "Ideographic"},
    27292: {"Unified_Ideograph", "Ideographic"},
    27293: {"Unified_Ideograph", "Ideographic"},
    27294: {"Unified_Ideograph", "Ideographic"},
    27295: {"Unified_Ideograph", "Ideographic"},
    27296: {"Unified_Ideograph", "Ideographic"},
    27297: {"Unified_Ideograph", "Ideographic"},
    27298: {"Unified_Ideograph", "Ideographic"},
    27299: {"Unified_Ideograph", "Ideographic"},
    27300: {"Unified_Ideograph", "Ideographic"},
    27301: {"Unified_Ideograph", "Ideographic"},
    27302: {"Unified_Ideograph", "Ideographic"},
    27303: {"Unified_Ideograph", "Ideographic"},
    27304: {"Unified_Ideograph", "Ideographic"},
    27305: {"Unified_Ideograph", "Ideographic"},
    27306: {"Unified_Ideograph", "Ideographic"},
    27307: {"Unified_Ideograph", "Ideographic"},
    27308: {"Unified_Ideograph", "Ideographic"},
    27309: {"Unified_Ideograph", "Ideographic"},
    27310: {"Unified_Ideograph", "Ideographic"},
    27311: {"Unified_Ideograph", "Ideographic"},
    27312: {"Unified_Ideograph", "Ideographic"},
    27313: {"Unified_Ideograph", "Ideographic"},
    27314: {"Unified_Ideograph", "Ideographic"},
    27315: {"Unified_Ideograph", "Ideographic"},
    27316: {"Unified_Ideograph", "Ideographic"},
    27317: {"Unified_Ideograph", "Ideographic"},
    27318: {"Unified_Ideograph", "Ideographic"},
    27319: {"Unified_Ideograph", "Ideographic"},
    27320: {"Unified_Ideograph", "Ideographic"},
    27321: {"Unified_Ideograph", "Ideographic"},
    27322: {"Unified_Ideograph", "Ideographic"},
    27323: {"Unified_Ideograph", "Ideographic"},
    27324: {"Unified_Ideograph", "Ideographic"},
    27325: {"Unified_Ideograph", "Ideographic"},
    27326: {"Unified_Ideograph", "Ideographic"},
    27327: {"Unified_Ideograph", "Ideographic"},
    27328: {"Unified_Ideograph", "Ideographic"},
    27329: {"Unified_Ideograph", "Ideographic"},
    27330: {"Unified_Ideograph", "Ideographic"},
    27331: {"Unified_Ideograph", "Ideographic"},
    27332: {"Unified_Ideograph", "Ideographic"},
    27333: {"Unified_Ideograph", "Ideographic"},
    27334: {"Unified_Ideograph", "Ideographic"},
    27335: {"Unified_Ideograph", "Ideographic"},
    27336: {"Unified_Ideograph", "Ideographic"},
    27337: {"Unified_Ideograph", "Ideographic"},
    27338: {"Unified_Ideograph", "Ideographic"},
    27339: {"Unified_Ideograph", "Ideographic"},
    27340: {"Unified_Ideograph", "Ideographic"},
    27341: {"Unified_Ideograph", "Ideographic"},
    27342: {"Unified_Ideograph", "Ideographic"},
    27343: {"Unified_Ideograph", "Ideographic"},
    27344: {"Unified_Ideograph", "Ideographic"},
    27345: {"Unified_Ideograph", "Ideographic"},
    27346: {"Unified_Ideograph", "Ideographic"},
    27347: {"Unified_Ideograph", "Ideographic"},
    27348: {"Unified_Ideograph", "Ideographic"},
    27349: {"Unified_Ideograph", "Ideographic"},
    27350: {"Unified_Ideograph", "Ideographic"},
    27351: {"Unified_Ideograph", "Ideographic"},
    27352: {"Unified_Ideograph", "Ideographic"},
    27353: {"Unified_Ideograph", "Ideographic"},
    27354: {"Unified_Ideograph", "Ideographic"},
    27355: {"Unified_Ideograph", "Ideographic"},
    27356: {"Unified_Ideograph", "Ideographic"},
    27357: {"Unified_Ideograph", "Ideographic"},
    27358: {"Unified_Ideograph", "Ideographic"},
    27359: {"Unified_Ideograph", "Ideographic"},
    27360: {"Unified_Ideograph", "Ideographic"},
    27361: {"Unified_Ideograph", "Ideographic"},
    27362: {"Unified_Ideograph", "Ideographic"},
    27363: {"Unified_Ideograph", "Ideographic"},
    27364: {"Unified_Ideograph", "Ideographic"},
    27365: {"Unified_Ideograph", "Ideographic"},
    27366: {"Unified_Ideograph", "Ideographic"},
    27367: {"Unified_Ideograph", "Ideographic"},
    27368: {"Unified_Ideograph", "Ideographic"},
    27369: {"Unified_Ideograph", "Ideographic"},
    27370: {"Unified_Ideograph", "Ideographic"},
    27371: {"Unified_Ideograph", "Ideographic"},
    27372: {"Unified_Ideograph", "Ideographic"},
    27373: {"Unified_Ideograph", "Ideographic"},
    27374: {"Unified_Ideograph", "Ideographic"},
    27375: {"Unified_Ideograph", "Ideographic"},
    27376: {"Unified_Ideograph", "Ideographic"},
    27377: {"Unified_Ideograph", "Ideographic"},
    27378: {"Unified_Ideograph", "Ideographic"},
    27379: {"Unified_Ideograph", "Ideographic"},
    27380: {"Unified_Ideograph", "Ideographic"},
    27381: {"Unified_Ideograph", "Ideographic"},
    27382: {"Unified_Ideograph", "Ideographic"},
    27383: {"Unified_Ideograph", "Ideographic"},
    27384: {"Unified_Ideograph", "Ideographic"},
    27385: {"Unified_Ideograph", "Ideographic"},
    27386: {"Unified_Ideograph", "Ideographic"},
    27387: {"Unified_Ideograph", "Ideographic"},
    27388: {"Unified_Ideograph", "Ideographic"},
    27389: {"Unified_Ideograph", "Ideographic"},
    27390: {"Unified_Ideograph", "Ideographic"},
    27391: {"Unified_Ideograph", "Ideographic"},
    27392: {"Unified_Ideograph", "Ideographic"},
    27393: {"Unified_Ideograph", "Ideographic"},
    27394: {"Unified_Ideograph", "Ideographic"},
    27395: {"Unified_Ideograph", "Ideographic"},
    27396: {"Unified_Ideograph", "Ideographic"},
    27397: {"Unified_Ideograph", "Ideographic"},
    27398: {"Unified_Ideograph", "Ideographic"},
    27399: {"Unified_Ideograph", "Ideographic"},
    27400: {"Unified_Ideograph", "Ideographic"},
    27401: {"Unified_Ideograph", "Ideographic"},
    27402: {"Unified_Ideograph", "Ideographic"},
    27403: {"Unified_Ideograph", "Ideographic"},
    27404: {"Unified_Ideograph", "Ideographic"},
    27405: {"Unified_Ideograph", "Ideographic"},
    27406: {"Unified_Ideograph", "Ideographic"},
    27407: {"Unified_Ideograph", "Ideographic"},
    27408: {"Unified_Ideograph", "Ideographic"},
    27409: {"Unified_Ideograph", "Ideographic"},
    27410: {"Unified_Ideograph", "Ideographic"},
    27411: {"Unified_Ideograph", "Ideographic"},
    27412: {"Unified_Ideograph", "Ideographic"},
    27413: {"Unified_Ideograph", "Ideographic"},
    27414: {"Unified_Ideograph", "Ideographic"},
    27415: {"Unified_Ideograph", "Ideographic"},
    27416: {"Unified_Ideograph", "Ideographic"},
    27417: {"Unified_Ideograph", "Ideographic"},
    27418: {"Unified_Ideograph", "Ideographic"},
    27419: {"Unified_Ideograph", "Ideographic"},
    27420: {"Unified_Ideograph", "Ideographic"},
    27421: {"Unified_Ideograph", "Ideographic"},
    27422: {"Unified_Ideograph", "Ideographic"},
    27423: {"Unified_Ideograph", "Ideographic"},
    27424: {"Unified_Ideograph", "Ideographic"},
    27425: {"Unified_Ideograph", "Ideographic"},
    27426: {"Unified_Ideograph", "Ideographic"},
    27427: {"Unified_Ideograph", "Ideographic"},
    27428: {"Unified_Ideograph", "Ideographic"},
    27429: {"Unified_Ideograph", "Ideographic"},
    27430: {"Unified_Ideograph", "Ideographic"},
    27431: {"Unified_Ideograph", "Ideographic"},
    27432: {"Unified_Ideograph", "Ideographic"},
    27433: {"Unified_Ideograph", "Ideographic"},
    27434: {"Unified_Ideograph", "Ideographic"},
    27435: {"Unified_Ideograph", "Ideographic"},
    27436: {"Unified_Ideograph", "Ideographic"},
    27437: {"Unified_Ideograph", "Ideographic"},
    27438: {"Unified_Ideograph", "Ideographic"},
    27439: {"Unified_Ideograph", "Ideographic"},
    27440: {"Unified_Ideograph", "Ideographic"},
    27441: {"Unified_Ideograph", "Ideographic"},
    27442: {"Unified_Ideograph", "Ideographic"},
    27443: {"Unified_Ideograph", "Ideographic"},
    27444: {"Unified_Ideograph", "Ideographic"},
    27445: {"Unified_Ideograph", "Ideographic"},
    27446: {"Unified_Ideograph", "Ideographic"},
    27447: {"Unified_Ideograph", "Ideographic"},
    27448: {"Unified_Ideograph", "Ideographic"},
    27449: {"Unified_Ideograph", "Ideographic"},
    27450: {"Unified_Ideograph", "Ideographic"},
    27451: {"Unified_Ideograph", "Ideographic"},
    27452: {"Unified_Ideograph", "Ideographic"},
    27453: {"Unified_Ideograph", "Ideographic"},
    27454: {"Unified_Ideograph", "Ideographic"},
    27455: {"Unified_Ideograph", "Ideographic"},
    27456: {"Unified_Ideograph", "Ideographic"},
    27457: {"Unified_Ideograph", "Ideographic"},
    27458: {"Unified_Ideograph", "Ideographic"},
    27459: {"Unified_Ideograph", "Ideographic"},
    27460: {"Unified_Ideograph", "Ideographic"},
    27461: {"Unified_Ideograph", "Ideographic"},
    27462: {"Unified_Ideograph", "Ideographic"},
    27463: {"Unified_Ideograph", "Ideographic"},
    27464: {"Unified_Ideograph", "Ideographic"},
    27465: {"Unified_Ideograph", "Ideographic"},
    27466: {"Unified_Ideograph", "Ideographic"},
    27467: {"Unified_Ideograph", "Ideographic"},
    27468: {"Unified_Ideograph", "Ideographic"},
    27469: {"Unified_Ideograph", "Ideographic"},
    27470: {"Unified_Ideograph", "Ideographic"},
    27471: {"Unified_Ideograph", "Ideographic"},
    27472: {"Unified_Ideograph", "Ideographic"},
    27473: {"Unified_Ideograph", "Ideographic"},
    27474: {"Unified_Ideograph", "Ideographic"},
    27475: {"Unified_Ideograph", "Ideographic"},
    27476: {"Unified_Ideograph", "Ideographic"},
    27477: {"Unified_Ideograph", "Ideographic"},
    27478: {"Unified_Ideograph", "Ideographic"},
    27479: {"Unified_Ideograph", "Ideographic"},
    27480: {"Unified_Ideograph", "Ideographic"},
    27481: {"Unified_Ideograph", "Ideographic"},
    27482: {"Unified_Ideograph", "Ideographic"},
    27483: {"Unified_Ideograph", "Ideographic"},
    27484: {"Unified_Ideograph", "Ideographic"},
    27485: {"Unified_Ideograph", "Ideographic"},
    27486: {"Unified_Ideograph", "Ideographic"},
    27487: {"Unified_Ideograph", "Ideographic"},
    27488: {"Unified_Ideograph", "Ideographic"},
    27489: {"Unified_Ideograph", "Ideographic"},
    27490: {"Unified_Ideograph", "Ideographic"},
    27491: {"Unified_Ideograph", "Ideographic"},
    27492: {"Unified_Ideograph", "Ideographic"},
    27493: {"Unified_Ideograph", "Ideographic"},
    27494: {"Unified_Ideograph", "Ideographic"},
    27495: {"Unified_Ideograph", "Ideographic"},
    27496: {"Unified_Ideograph", "Ideographic"},
    27497: {"Unified_Ideograph", "Ideographic"},
    27498: {"Unified_Ideograph", "Ideographic"},
    27499: {"Unified_Ideograph", "Ideographic"},
    27500: {"Unified_Ideograph", "Ideographic"},
    27501: {"Unified_Ideograph", "Ideographic"},
    27502: {"Unified_Ideograph", "Ideographic"},
    27503: {"Unified_Ideograph", "Ideographic"},
    27504: {"Unified_Ideograph", "Ideographic"},
    27505: {"Unified_Ideograph", "Ideographic"},
    27506: {"Unified_Ideograph", "Ideographic"},
    27507: {"Unified_Ideograph", "Ideographic"},
    27508: {"Unified_Ideograph", "Ideographic"},
    27509: {"Unified_Ideograph", "Ideographic"},
    27510: {"Unified_Ideograph", "Ideographic"},
    27511: {"Unified_Ideograph", "Ideographic"},
    27512: {"Unified_Ideograph", "Ideographic"},
    27513: {"Unified_Ideograph", "Ideographic"},
    27514: {"Unified_Ideograph", "Ideographic"},
    27515: {"Unified_Ideograph", "Ideographic"},
    27516: {"Unified_Ideograph", "Ideographic"},
    27517: {"Unified_Ideograph", "Ideographic"},
    27518: {"Unified_Ideograph", "Ideographic"},
    27519: {"Unified_Ideograph", "Ideographic"},
    27520: {"Unified_Ideograph", "Ideographic"},
    27521: {"Unified_Ideograph", "Ideographic"},
    27522: {"Unified_Ideograph", "Ideographic"},
    27523: {"Unified_Ideograph", "Ideographic"},
    27524: {"Unified_Ideograph", "Ideographic"},
    27525: {"Unified_Ideograph", "Ideographic"},
    27526: {"Unified_Ideograph", "Ideographic"},
    27527: {"Unified_Ideograph", "Ideographic"},
    27528: {"Unified_Ideograph", "Ideographic"},
    27529: {"Unified_Ideograph", "Ideographic"},
    27530: {"Unified_Ideograph", "Ideographic"},
    27531: {"Unified_Ideograph", "Ideographic"},
    27532: {"Unified_Ideograph", "Ideographic"},
    27533: {"Unified_Ideograph", "Ideographic"},
    27534: {"Unified_Ideograph", "Ideographic"},
    27535: {"Unified_Ideograph", "Ideographic"},
    27536: {"Unified_Ideograph", "Ideographic"},
    27537: {"Unified_Ideograph", "Ideographic"},
    27538: {"Unified_Ideograph", "Ideographic"},
    27539: {"Unified_Ideograph", "Ideographic"},
    27540: {"Unified_Ideograph", "Ideographic"},
    27541: {"Unified_Ideograph", "Ideographic"},
    27542: {"Unified_Ideograph", "Ideographic"},
    27543: {"Unified_Ideograph", "Ideographic"},
    27544: {"Unified_Ideograph", "Ideographic"},
    27545: {"Unified_Ideograph", "Ideographic"},
    27546: {"Unified_Ideograph", "Ideographic"},
    27547: {"Unified_Ideograph", "Ideographic"},
    27548: {"Unified_Ideograph", "Ideographic"},
    27549: {"Unified_Ideograph", "Ideographic"},
    27550: {"Unified_Ideograph", "Ideographic"},
    27551: {"Unified_Ideograph", "Ideographic"},
    27552: {"Unified_Ideograph", "Ideographic"},
    27553: {"Unified_Ideograph", "Ideographic"},
    27554: {"Unified_Ideograph", "Ideographic"},
    27555: {"Unified_Ideograph", "Ideographic"},
    27556: {"Unified_Ideograph", "Ideographic"},
    27557: {"Unified_Ideograph", "Ideographic"},
    27558: {"Unified_Ideograph", "Ideographic"},
    27559: {"Unified_Ideograph", "Ideographic"},
    27560: {"Unified_Ideograph", "Ideographic"},
    27561: {"Unified_Ideograph", "Ideographic"},
    27562: {"Unified_Ideograph", "Ideographic"},
    27563: {"Unified_Ideograph", "Ideographic"},
    27564: {"Unified_Ideograph", "Ideographic"},
    27565: {"Unified_Ideograph", "Ideographic"},
    27566: {"Unified_Ideograph", "Ideographic"},
    27567: {"Unified_Ideograph", "Ideographic"},
    27568: {"Unified_Ideograph", "Ideographic"},
    27569: {"Unified_Ideograph", "Ideographic"},
    27570: {"Unified_Ideograph", "Ideographic"},
    27571: {"Unified_Ideograph", "Ideographic"},
    27572: {"Unified_Ideograph", "Ideographic"},
    27573: {"Unified_Ideograph", "Ideographic"},
    27574: {"Unified_Ideograph", "Ideographic"},
    27575: {"Unified_Ideograph", "Ideographic"},
    27576: {"Unified_Ideograph", "Ideographic"},
    27577: {"Unified_Ideograph", "Ideographic"},
    27578: {"Unified_Ideograph", "Ideographic"},
    27579: {"Unified_Ideograph", "Ideographic"},
    27580: {"Unified_Ideograph", "Ideographic"},
    27581: {"Unified_Ideograph", "Ideographic"},
    27582: {"Unified_Ideograph", "Ideographic"},
    27583: {"Unified_Ideograph", "Ideographic"},
    27584: {"Unified_Ideograph", "Ideographic"},
    27585: {"Unified_Ideograph", "Ideographic"},
    27586: {"Unified_Ideograph", "Ideographic"},
    27587: {"Unified_Ideograph", "Ideographic"},
    27588: {"Unified_Ideograph", "Ideographic"},
    27589: {"Unified_Ideograph", "Ideographic"},
    27590: {"Unified_Ideograph", "Ideographic"},
    27591: {"Unified_Ideograph", "Ideographic"},
    27592: {"Unified_Ideograph", "Ideographic"},
    27593: {"Unified_Ideograph", "Ideographic"},
    27594: {"Unified_Ideograph", "Ideographic"},
    27595: {"Unified_Ideograph", "Ideographic"},
    27596: {"Unified_Ideograph", "Ideographic"},
    27597: {"Unified_Ideograph", "Ideographic"},
    27598: {"Unified_Ideograph", "Ideographic"},
    27599: {"Unified_Ideograph", "Ideographic"},
    27600: {"Unified_Ideograph", "Ideographic"},
    27601: {"Unified_Ideograph", "Ideographic"},
    27602: {"Unified_Ideograph", "Ideographic"},
    27603: {"Unified_Ideograph", "Ideographic"},
    27604: {"Unified_Ideograph", "Ideographic"},
    27605: {"Unified_Ideograph", "Ideographic"},
    27606: {"Unified_Ideograph", "Ideographic"},
    27607: {"Unified_Ideograph", "Ideographic"},
    27608: {"Unified_Ideograph", "Ideographic"},
    27609: {"Unified_Ideograph", "Ideographic"},
    27610: {"Unified_Ideograph", "Ideographic"},
    27611: {"Unified_Ideograph", "Ideographic"},
    27612: {"Unified_Ideograph", "Ideographic"},
    27613: {"Unified_Ideograph", "Ideographic"},
    27614: {"Unified_Ideograph", "Ideographic"},
    27615: {"Unified_Ideograph", "Ideographic"},
    27616: {"Unified_Ideograph", "Ideographic"},
    27617: {"Unified_Ideograph", "Ideographic"},
    27618: {"Unified_Ideograph", "Ideographic"},
    27619: {"Unified_Ideograph", "Ideographic"},
    27620: {"Unified_Ideograph", "Ideographic"},
    27621: {"Unified_Ideograph", "Ideographic"},
    27622: {"Unified_Ideograph", "Ideographic"},
    27623: {"Unified_Ideograph", "Ideographic"},
    27624: {"Unified_Ideograph", "Ideographic"},
    27625: {"Unified_Ideograph", "Ideographic"},
    27626: {"Unified_Ideograph", "Ideographic"},
    27627: {"Unified_Ideograph", "Ideographic"},
    27628: {"Unified_Ideograph", "Ideographic"},
    27629: {"Unified_Ideograph", "Ideographic"},
    27630: {"Unified_Ideograph", "Ideographic"},
    27631: {"Unified_Ideograph", "Ideographic"},
    27632: {"Unified_Ideograph", "Ideographic"},
    27633: {"Unified_Ideograph", "Ideographic"},
    27634: {"Unified_Ideograph", "Ideographic"},
    27635: {"Unified_Ideograph", "Ideographic"},
    27636: {"Unified_Ideograph", "Ideographic"},
    27637: {"Unified_Ideograph", "Ideographic"},
    27638: {"Unified_Ideograph", "Ideographic"},
    27639: {"Unified_Ideograph", "Ideographic"},
    27640: {"Unified_Ideograph", "Ideographic"},
    27641: {"Unified_Ideograph", "Ideographic"},
    27642: {"Unified_Ideograph", "Ideographic"},
    27643: {"Unified_Ideograph", "Ideographic"},
    27644: {"Unified_Ideograph", "Ideographic"},
    27645: {"Unified_Ideograph", "Ideographic"},
    27646: {"Unified_Ideograph", "Ideographic"},
    27647: {"Unified_Ideograph", "Ideographic"},
    27648: {"Unified_Ideograph", "Ideographic"},
    27649: {"Unified_Ideograph", "Ideographic"},
    27650: {"Unified_Ideograph", "Ideographic"},
    27651: {"Unified_Ideograph", "Ideographic"},
    27652: {"Unified_Ideograph", "Ideographic"},
    27653: {"Unified_Ideograph", "Ideographic"},
    27654: {"Unified_Ideograph", "Ideographic"},
    27655: {"Unified_Ideograph", "Ideographic"},
    27656: {"Unified_Ideograph", "Ideographic"},
    27657: {"Unified_Ideograph", "Ideographic"},
    27658: {"Unified_Ideograph", "Ideographic"},
    27659: {"Unified_Ideograph", "Ideographic"},
    27660: {"Unified_Ideograph", "Ideographic"},
    27661: {"Unified_Ideograph", "Ideographic"},
    27662: {"Unified_Ideograph", "Ideographic"},
    27663: {"Unified_Ideograph", "Ideographic"},
    27664: {"Unified_Ideograph", "Ideographic"},
    27665: {"Unified_Ideograph", "Ideographic"},
    27666: {"Unified_Ideograph", "Ideographic"},
    27667: {"Unified_Ideograph", "Ideographic"},
    27668: {"Unified_Ideograph", "Ideographic"},
    27669: {"Unified_Ideograph", "Ideographic"},
    27670: {"Unified_Ideograph", "Ideographic"},
    27671: {"Unified_Ideograph", "Ideographic"},
    27672: {"Unified_Ideograph", "Ideographic"},
    27673: {"Unified_Ideograph", "Ideographic"},
    27674: {"Unified_Ideograph", "Ideographic"},
    27675: {"Unified_Ideograph", "Ideographic"},
    27676: {"Unified_Ideograph", "Ideographic"},
    27677: {"Unified_Ideograph", "Ideographic"},
    27678: {"Unified_Ideograph", "Ideographic"},
    27679: {"Unified_Ideograph", "Ideographic"},
    27680: {"Unified_Ideograph", "Ideographic"},
    27681: {"Unified_Ideograph", "Ideographic"},
    27682: {"Unified_Ideograph", "Ideographic"},
    27683: {"Unified_Ideograph", "Ideographic"},
    27684: {"Unified_Ideograph", "Ideographic"},
    27685: {"Unified_Ideograph", "Ideographic"},
    27686: {"Unified_Ideograph", "Ideographic"},
    27687: {"Unified_Ideograph", "Ideographic"},
    27688: {"Unified_Ideograph", "Ideographic"},
    27689: {"Unified_Ideograph", "Ideographic"},
    27690: {"Unified_Ideograph", "Ideographic"},
    27691: {"Unified_Ideograph", "Ideographic"},
    27692: {"Unified_Ideograph", "Ideographic"},
    27693: {"Unified_Ideograph", "Ideographic"},
    27694: {"Unified_Ideograph", "Ideographic"},
    27695: {"Unified_Ideograph", "Ideographic"},
    27696: {"Unified_Ideograph", "Ideographic"},
    27697: {"Unified_Ideograph", "Ideographic"},
    27698: {"Unified_Ideograph", "Ideographic"},
    27699: {"Unified_Ideograph", "Ideographic"},
    27700: {"Unified_Ideograph", "Ideographic"},
    27701: {"Unified_Ideograph", "Ideographic"},
    27702: {"Unified_Ideograph", "Ideographic"},
    27703: {"Unified_Ideograph", "Ideographic"},
    27704: {"Unified_Ideograph", "Ideographic"},
    27705: {"Unified_Ideograph", "Ideographic"},
    27706: {"Unified_Ideograph", "Ideographic"},
    27707: {"Unified_Ideograph", "Ideographic"},
    27708: {"Unified_Ideograph", "Ideographic"},
    27709: {"Unified_Ideograph", "Ideographic"},
    27710: {"Unified_Ideograph", "Ideographic"},
    27711: {"Unified_Ideograph", "Ideographic"},
    27712: {"Unified_Ideograph", "Ideographic"},
    27713: {"Unified_Ideograph", "Ideographic"},
    27714: {"Unified_Ideograph", "Ideographic"},
    27715: {"Unified_Ideograph", "Ideographic"},
    27716: {"Unified_Ideograph", "Ideographic"},
    27717: {"Unified_Ideograph", "Ideographic"},
    27718: {"Unified_Ideograph", "Ideographic"},
    27719: {"Unified_Ideograph", "Ideographic"},
    27720: {"Unified_Ideograph", "Ideographic"},
    27721: {"Unified_Ideograph", "Ideographic"},
    27722: {"Unified_Ideograph", "Ideographic"},
    27723: {"Unified_Ideograph", "Ideographic"},
    27724: {"Unified_Ideograph", "Ideographic"},
    27725: {"Unified_Ideograph", "Ideographic"},
    27726: {"Unified_Ideograph", "Ideographic"},
    27727: {"Unified_Ideograph", "Ideographic"},
    27728: {"Unified_Ideograph", "Ideographic"},
    27729: {"Unified_Ideograph", "Ideographic"},
    27730: {"Unified_Ideograph", "Ideographic"},
    27731: {"Unified_Ideograph", "Ideographic"},
    27732: {"Unified_Ideograph", "Ideographic"},
    27733: {"Unified_Ideograph", "Ideographic"},
    27734: {"Unified_Ideograph", "Ideographic"},
    27735: {"Unified_Ideograph", "Ideographic"},
    27736: {"Unified_Ideograph", "Ideographic"},
    27737: {"Unified_Ideograph", "Ideographic"},
    27738: {"Unified_Ideograph", "Ideographic"},
    27739: {"Unified_Ideograph", "Ideographic"},
    27740: {"Unified_Ideograph", "Ideographic"},
    27741: {"Unified_Ideograph", "Ideographic"},
    27742: {"Unified_Ideograph", "Ideographic"},
    27743: {"Unified_Ideograph", "Ideographic"},
    27744: {"Unified_Ideograph", "Ideographic"},
    27745: {"Unified_Ideograph", "Ideographic"},
    27746: {"Unified_Ideograph", "Ideographic"},
    27747: {"Unified_Ideograph", "Ideographic"},
    27748: {"Unified_Ideograph", "Ideographic"},
    27749: {"Unified_Ideograph", "Ideographic"},
    27750: {"Unified_Ideograph", "Ideographic"},
    27751: {"Unified_Ideograph", "Ideographic"},
    27752: {"Unified_Ideograph", "Ideographic"},
    27753: {"Unified_Ideograph", "Ideographic"},
    27754: {"Unified_Ideograph", "Ideographic"},
    27755: {"Unified_Ideograph", "Ideographic"},
    27756: {"Unified_Ideograph", "Ideographic"},
    27757: {"Unified_Ideograph", "Ideographic"},
    27758: {"Unified_Ideograph", "Ideographic"},
    27759: {"Unified_Ideograph", "Ideographic"},
    27760: {"Unified_Ideograph", "Ideographic"},
    27761: {"Unified_Ideograph", "Ideographic"},
    27762: {"Unified_Ideograph", "Ideographic"},
    27763: {"Unified_Ideograph", "Ideographic"},
    27764: {"Unified_Ideograph", "Ideographic"},
    27765: {"Unified_Ideograph", "Ideographic"},
    27766: {"Unified_Ideograph", "Ideographic"},
    27767: {"Unified_Ideograph", "Ideographic"},
    27768: {"Unified_Ideograph", "Ideographic"},
    27769: {"Unified_Ideograph", "Ideographic"},
    27770: {"Unified_Ideograph", "Ideographic"},
    27771: {"Unified_Ideograph", "Ideographic"},
    27772: {"Unified_Ideograph", "Ideographic"},
    27773: {"Unified_Ideograph", "Ideographic"},
    27774: {"Unified_Ideograph", "Ideographic"},
    27775: {"Unified_Ideograph", "Ideographic"},
    27776: {"Unified_Ideograph", "Ideographic"},
    27777: {"Unified_Ideograph", "Ideographic"},
    27778: {"Unified_Ideograph", "Ideographic"},
    27779: {"Unified_Ideograph", "Ideographic"},
    27780: {"Unified_Ideograph", "Ideographic"},
    27781: {"Unified_Ideograph", "Ideographic"},
    27782: {"Unified_Ideograph", "Ideographic"},
    27783: {"Unified_Ideograph", "Ideographic"},
    27784: {"Unified_Ideograph", "Ideographic"},
    27785: {"Unified_Ideograph", "Ideographic"},
    27786: {"Unified_Ideograph", "Ideographic"},
    27787: {"Unified_Ideograph", "Ideographic"},
    27788: {"Unified_Ideograph", "Ideographic"},
    27789: {"Unified_Ideograph", "Ideographic"},
    27790: {"Unified_Ideograph", "Ideographic"},
    27791: {"Unified_Ideograph", "Ideographic"},
    27792: {"Unified_Ideograph", "Ideographic"},
    27793: {"Unified_Ideograph", "Ideographic"},
    27794: {"Unified_Ideograph", "Ideographic"},
    27795: {"Unified_Ideograph", "Ideographic"},
    27796: {"Unified_Ideograph", "Ideographic"},
    27797: {"Unified_Ideograph", "Ideographic"},
    27798: {"Unified_Ideograph", "Ideographic"},
    27799: {"Unified_Ideograph", "Ideographic"},
    27800: {"Unified_Ideograph", "Ideographic"},
    27801: {"Unified_Ideograph", "Ideographic"},
    27802: {"Unified_Ideograph", "Ideographic"},
    27803: {"Unified_Ideograph", "Ideographic"},
    27804: {"Unified_Ideograph", "Ideographic"},
    27805: {"Unified_Ideograph", "Ideographic"},
    27806: {"Unified_Ideograph", "Ideographic"},
    27807: {"Unified_Ideograph", "Ideographic"},
    27808: {"Unified_Ideograph", "Ideographic"},
    27809: {"Unified_Ideograph", "Ideographic"},
    27810: {"Unified_Ideograph", "Ideographic"},
    27811: {"Unified_Ideograph", "Ideographic"},
    27812: {"Unified_Ideograph", "Ideographic"},
    27813: {"Unified_Ideograph", "Ideographic"},
    27814: {"Unified_Ideograph", "Ideographic"},
    27815: {"Unified_Ideograph", "Ideographic"},
    27816: {"Unified_Ideograph", "Ideographic"},
    27817: {"Unified_Ideograph", "Ideographic"},
    27818: {"Unified_Ideograph", "Ideographic"},
    27819: {"Unified_Ideograph", "Ideographic"},
    27820: {"Unified_Ideograph", "Ideographic"},
    27821: {"Unified_Ideograph", "Ideographic"},
    27822: {"Unified_Ideograph", "Ideographic"},
    27823: {"Unified_Ideograph", "Ideographic"},
    27824: {"Unified_Ideograph", "Ideographic"},
    27825: {"Unified_Ideograph", "Ideographic"},
    27826: {"Unified_Ideograph", "Ideographic"},
    27827: {"Unified_Ideograph", "Ideographic"},
    27828: {"Unified_Ideograph", "Ideographic"},
    27829: {"Unified_Ideograph", "Ideographic"},
    27830: {"Unified_Ideograph", "Ideographic"},
    27831: {"Unified_Ideograph", "Ideographic"},
    27832: {"Unified_Ideograph", "Ideographic"},
    27833: {"Unified_Ideograph", "Ideographic"},
    27834: {"Unified_Ideograph", "Ideographic"},
    27835: {"Unified_Ideograph", "Ideographic"},
    27836: {"Unified_Ideograph", "Ideographic"},
    27837: {"Unified_Ideograph", "Ideographic"},
    27838: {"Unified_Ideograph", "Ideographic"},
    27839: {"Unified_Ideograph", "Ideographic"},
    27840: {"Unified_Ideograph", "Ideographic"},
    27841: {"Unified_Ideograph", "Ideographic"},
    27842: {"Unified_Ideograph", "Ideographic"},
    27843: {"Unified_Ideograph", "Ideographic"},
    27844: {"Unified_Ideograph", "Ideographic"},
    27845: {"Unified_Ideograph", "Ideographic"},
    27846: {"Unified_Ideograph", "Ideographic"},
    27847: {"Unified_Ideograph", "Ideographic"},
    27848: {"Unified_Ideograph", "Ideographic"},
    27849: {"Unified_Ideograph", "Ideographic"},
    27850: {"Unified_Ideograph", "Ideographic"},
    27851: {"Unified_Ideograph", "Ideographic"},
    27852: {"Unified_Ideograph", "Ideographic"},
    27853: {"Unified_Ideograph", "Ideographic"},
    27854: {"Unified_Ideograph", "Ideographic"},
    27855: {"Unified_Ideograph", "Ideographic"},
    27856: {"Unified_Ideograph", "Ideographic"},
    27857: {"Unified_Ideograph", "Ideographic"},
    27858: {"Unified_Ideograph", "Ideographic"},
    27859: {"Unified_Ideograph", "Ideographic"},
    27860: {"Unified_Ideograph", "Ideographic"},
    27861: {"Unified_Ideograph", "Ideographic"},
    27862: {"Unified_Ideograph", "Ideographic"},
    27863: {"Unified_Ideograph", "Ideographic"},
    27864: {"Unified_Ideograph", "Ideographic"},
    27865: {"Unified_Ideograph", "Ideographic"},
    27866: {"Unified_Ideograph", "Ideographic"},
    27867: {"Unified_Ideograph", "Ideographic"},
    27868: {"Unified_Ideograph", "Ideographic"},
    27869: {"Unified_Ideograph", "Ideographic"},
    27870: {"Unified_Ideograph", "Ideographic"},
    27871: {"Unified_Ideograph", "Ideographic"},
    27872: {"Unified_Ideograph", "Ideographic"},
    27873: {"Unified_Ideograph", "Ideographic"},
    27874: {"Unified_Ideograph", "Ideographic"},
    27875: {"Unified_Ideograph", "Ideographic"},
    27876: {"Unified_Ideograph", "Ideographic"},
    27877: {"Unified_Ideograph", "Ideographic"},
    27878: {"Unified_Ideograph", "Ideographic"},
    27879: {"Unified_Ideograph", "Ideographic"},
    27880: {"Unified_Ideograph", "Ideographic"},
    27881: {"Unified_Ideograph", "Ideographic"},
    27882: {"Unified_Ideograph", "Ideographic"},
    27883: {"Unified_Ideograph", "Ideographic"},
    27884: {"Unified_Ideograph", "Ideographic"},
    27885: {"Unified_Ideograph", "Ideographic"},
    27886: {"Unified_Ideograph", "Ideographic"},
    27887: {"Unified_Ideograph", "Ideographic"},
    27888: {"Unified_Ideograph", "Ideographic"},
    27889: {"Unified_Ideograph", "Ideographic"},
    27890: {"Unified_Ideograph", "Ideographic"},
    27891: {"Unified_Ideograph", "Ideographic"},
    27892: {"Unified_Ideograph", "Ideographic"},
    27893: {"Unified_Ideograph", "Ideographic"},
    27894: {"Unified_Ideograph", "Ideographic"},
    27895: {"Unified_Ideograph", "Ideographic"},
    27896: {"Unified_Ideograph", "Ideographic"},
    27897: {"Unified_Ideograph", "Ideographic"},
    27898: {"Unified_Ideograph", "Ideographic"},
    27899: {"Unified_Ideograph", "Ideographic"},
    27900: {"Unified_Ideograph", "Ideographic"},
    27901: {"Unified_Ideograph", "Ideographic"},
    27902: {"Unified_Ideograph", "Ideographic"},
    27903: {"Unified_Ideograph", "Ideographic"},
    27904: {"Unified_Ideograph", "Ideographic"},
    27905: {"Unified_Ideograph", "Ideographic"},
    27906: {"Unified_Ideograph", "Ideographic"},
    27907: {"Unified_Ideograph", "Ideographic"},
    27908: {"Unified_Ideograph", "Ideographic"},
    27909: {"Unified_Ideograph", "Ideographic"},
    27910: {"Unified_Ideograph", "Ideographic"},
    27911: {"Unified_Ideograph", "Ideographic"},
    27912: {"Unified_Ideograph", "Ideographic"},
    27913: {"Unified_Ideograph", "Ideographic"},
    27914: {"Unified_Ideograph", "Ideographic"},
    27915: {"Unified_Ideograph", "Ideographic"},
    27916: {"Unified_Ideograph", "Ideographic"},
    27917: {"Unified_Ideograph", "Ideographic"},
    27918: {"Unified_Ideograph", "Ideographic"},
    27919: {"Unified_Ideograph", "Ideographic"},
    27920: {"Unified_Ideograph", "Ideographic"},
    27921: {"Unified_Ideograph", "Ideographic"},
    27922: {"Unified_Ideograph", "Ideographic"},
    27923: {"Unified_Ideograph", "Ideographic"},
    27924: {"Unified_Ideograph", "Ideographic"},
    27925: {"Unified_Ideograph", "Ideographic"},
    27926: {"Unified_Ideograph", "Ideographic"},
    27927: {"Unified_Ideograph", "Ideographic"},
    27928: {"Unified_Ideograph", "Ideographic"},
    27929: {"Unified_Ideograph", "Ideographic"},
    27930: {"Unified_Ideograph", "Ideographic"},
    27931: {"Unified_Ideograph", "Ideographic"},
    27932: {"Unified_Ideograph", "Ideographic"},
    27933: {"Unified_Ideograph", "Ideographic"},
    27934: {"Unified_Ideograph", "Ideographic"},
    27935: {"Unified_Ideograph", "Ideographic"},
    27936: {"Unified_Ideograph", "Ideographic"},
    27937: {"Unified_Ideograph", "Ideographic"},
    27938: {"Unified_Ideograph", "Ideographic"},
    27939: {"Unified_Ideograph", "Ideographic"},
    27940: {"Unified_Ideograph", "Ideographic"},
    27941: {"Unified_Ideograph", "Ideographic"},
    27942: {"Unified_Ideograph", "Ideographic"},
    27943: {"Unified_Ideograph", "Ideographic"},
    27944: {"Unified_Ideograph", "Ideographic"},
    27945: {"Unified_Ideograph", "Ideographic"},
    27946: {"Unified_Ideograph", "Ideographic"},
    27947: {"Unified_Ideograph", "Ideographic"},
    27948: {"Unified_Ideograph", "Ideographic"},
    27949: {"Unified_Ideograph", "Ideographic"},
    27950: {"Unified_Ideograph", "Ideographic"},
    27951: {"Unified_Ideograph", "Ideographic"},
    27952: {"Unified_Ideograph", "Ideographic"},
    27953: {"Unified_Ideograph", "Ideographic"},
    27954: {"Unified_Ideograph", "Ideographic"},
    27955: {"Unified_Ideograph", "Ideographic"},
    27956: {"Unified_Ideograph", "Ideographic"},
    27957: {"Unified_Ideograph", "Ideographic"},
    27958: {"Unified_Ideograph", "Ideographic"},
    27959: {"Unified_Ideograph", "Ideographic"},
    27960: {"Unified_Ideograph", "Ideographic"},
    27961: {"Unified_Ideograph", "Ideographic"},
    27962: {"Unified_Ideograph", "Ideographic"},
    27963: {"Unified_Ideograph", "Ideographic"},
    27964: {"Unified_Ideograph", "Ideographic"},
    27965: {"Unified_Ideograph", "Ideographic"},
    27966: {"Unified_Ideograph", "Ideographic"},
    27967: {"Unified_Ideograph", "Ideographic"},
    27968: {"Unified_Ideograph", "Ideographic"},
    27969: {"Unified_Ideograph", "Ideographic"},
    27970: {"Unified_Ideograph", "Ideographic"},
    27971: {"Unified_Ideograph", "Ideographic"},
    27972: {"Unified_Ideograph", "Ideographic"},
    27973: {"Unified_Ideograph", "Ideographic"},
    27974: {"Unified_Ideograph", "Ideographic"},
    27975: {"Unified_Ideograph", "Ideographic"},
    27976: {"Unified_Ideograph", "Ideographic"},
    27977: {"Unified_Ideograph", "Ideographic"},
    27978: {"Unified_Ideograph", "Ideographic"},
    27979: {"Unified_Ideograph", "Ideographic"},
    27980: {"Unified_Ideograph", "Ideographic"},
    27981: {"Unified_Ideograph", "Ideographic"},
    27982: {"Unified_Ideograph", "Ideographic"},
    27983: {"Unified_Ideograph", "Ideographic"},
    27984: {"Unified_Ideograph", "Ideographic"},
    27985: {"Unified_Ideograph", "Ideographic"},
    27986: {"Unified_Ideograph", "Ideographic"},
    27987: {"Unified_Ideograph", "Ideographic"},
    27988: {"Unified_Ideograph", "Ideographic"},
    27989: {"Unified_Ideograph", "Ideographic"},
    27990: {"Unified_Ideograph", "Ideographic"},
    27991: {"Unified_Ideograph", "Ideographic"},
    27992: {"Unified_Ideograph", "Ideographic"},
    27993: {"Unified_Ideograph", "Ideographic"},
    27994: {"Unified_Ideograph", "Ideographic"},
    27995: {"Unified_Ideograph", "Ideographic"},
    27996: {"Unified_Ideograph", "Ideographic"},
    27997: {"Unified_Ideograph", "Ideographic"},
    27998: {"Unified_Ideograph", "Ideographic"},
    27999: {"Unified_Ideograph", "Ideographic"},
    28000: {"Unified_Ideograph", "Ideographic"},
    28001: {"Unified_Ideograph", "Ideographic"},
    28002: {"Unified_Ideograph", "Ideographic"},
    28003: {"Unified_Ideograph", "Ideographic"},
    28004: {"Unified_Ideograph", "Ideographic"},
    28005: {"Unified_Ideograph", "Ideographic"},
    28006: {"Unified_Ideograph", "Ideographic"},
    28007: {"Unified_Ideograph", "Ideographic"},
    28008: {"Unified_Ideograph", "Ideographic"},
    28009: {"Unified_Ideograph", "Ideographic"},
    28010: {"Unified_Ideograph", "Ideographic"},
    28011: {"Unified_Ideograph", "Ideographic"},
    28012: {"Unified_Ideograph", "Ideographic"},
    28013: {"Unified_Ideograph", "Ideographic"},
    28014: {"Unified_Ideograph", "Ideographic"},
    28015: {"Unified_Ideograph", "Ideographic"},
    28016: {"Unified_Ideograph", "Ideographic"},
    28017: {"Unified_Ideograph", "Ideographic"},
    28018: {"Unified_Ideograph", "Ideographic"},
    28019: {"Unified_Ideograph", "Ideographic"},
    28020: {"Unified_Ideograph", "Ideographic"},
    28021: {"Unified_Ideograph", "Ideographic"},
    28022: {"Unified_Ideograph", "Ideographic"},
    28023: {"Unified_Ideograph", "Ideographic"},
    28024: {"Unified_Ideograph", "Ideographic"},
    28025: {"Unified_Ideograph", "Ideographic"},
    28026: {"Unified_Ideograph", "Ideographic"},
    28027: {"Unified_Ideograph", "Ideographic"},
    28028: {"Unified_Ideograph", "Ideographic"},
    28029: {"Unified_Ideograph", "Ideographic"},
    28030: {"Unified_Ideograph", "Ideographic"},
    28031: {"Unified_Ideograph", "Ideographic"},
    28032: {"Unified_Ideograph", "Ideographic"},
    28033: {"Unified_Ideograph", "Ideographic"},
    28034: {"Unified_Ideograph", "Ideographic"},
    28035: {"Unified_Ideograph", "Ideographic"},
    28036: {"Unified_Ideograph", "Ideographic"},
    28037: {"Unified_Ideograph", "Ideographic"},
    28038: {"Unified_Ideograph", "Ideographic"},
    28039: {"Unified_Ideograph", "Ideographic"},
    28040: {"Unified_Ideograph", "Ideographic"},
    28041: {"Unified_Ideograph", "Ideographic"},
    28042: {"Unified_Ideograph", "Ideographic"},
    28043: {"Unified_Ideograph", "Ideographic"},
    28044: {"Unified_Ideograph", "Ideographic"},
    28045: {"Unified_Ideograph", "Ideographic"},
    28046: {"Unified_Ideograph", "Ideographic"},
    28047: {"Unified_Ideograph", "Ideographic"},
    28048: {"Unified_Ideograph", "Ideographic"},
    28049: {"Unified_Ideograph", "Ideographic"},
    28050: {"Unified_Ideograph", "Ideographic"},
    28051: {"Unified_Ideograph", "Ideographic"},
    28052: {"Unified_Ideograph", "Ideographic"},
    28053: {"Unified_Ideograph", "Ideographic"},
    28054: {"Unified_Ideograph", "Ideographic"},
    28055: {"Unified_Ideograph", "Ideographic"},
    28056: {"Unified_Ideograph", "Ideographic"},
    28057: {"Unified_Ideograph", "Ideographic"},
    28058: {"Unified_Ideograph", "Ideographic"},
    28059: {"Unified_Ideograph", "Ideographic"},
    28060: {"Unified_Ideograph", "Ideographic"},
    28061: {"Unified_Ideograph", "Ideographic"},
    28062: {"Unified_Ideograph", "Ideographic"},
    28063: {"Unified_Ideograph", "Ideographic"},
    28064: {"Unified_Ideograph", "Ideographic"},
    28065: {"Unified_Ideograph", "Ideographic"},
    28066: {"Unified_Ideograph", "Ideographic"},
    28067: {"Unified_Ideograph", "Ideographic"},
    28068: {"Unified_Ideograph", "Ideographic"},
    28069: {"Unified_Ideograph", "Ideographic"},
    28070: {"Unified_Ideograph", "Ideographic"},
    28071: {"Unified_Ideograph", "Ideographic"},
    28072: {"Unified_Ideograph", "Ideographic"},
    28073: {"Unified_Ideograph", "Ideographic"},
    28074: {"Unified_Ideograph", "Ideographic"},
    28075: {"Unified_Ideograph", "Ideographic"},
    28076: {"Unified_Ideograph", "Ideographic"},
    28077: {"Unified_Ideograph", "Ideographic"},
    28078: {"Unified_Ideograph", "Ideographic"},
    28079: {"Unified_Ideograph", "Ideographic"},
    28080: {"Unified_Ideograph", "Ideographic"},
    28081: {"Unified_Ideograph", "Ideographic"},
    28082: {"Unified_Ideograph", "Ideographic"},
    28083: {"Unified_Ideograph", "Ideographic"},
    28084: {"Unified_Ideograph", "Ideographic"},
    28085: {"Unified_Ideograph", "Ideographic"},
    28086: {"Unified_Ideograph", "Ideographic"},
    28087: {"Unified_Ideograph", "Ideographic"},
    28088: {"Unified_Ideograph", "Ideographic"},
    28089: {"Unified_Ideograph", "Ideographic"},
    28090: {"Unified_Ideograph", "Ideographic"},
    28091: {"Unified_Ideograph", "Ideographic"},
    28092: {"Unified_Ideograph", "Ideographic"},
    28093: {"Unified_Ideograph", "Ideographic"},
    28094: {"Unified_Ideograph", "Ideographic"},
    28095: {"Unified_Ideograph", "Ideographic"},
    28096: {"Unified_Ideograph", "Ideographic"},
    28097: {"Unified_Ideograph", "Ideographic"},
    28098: {"Unified_Ideograph", "Ideographic"},
    28099: {"Unified_Ideograph", "Ideographic"},
    28100: {"Unified_Ideograph", "Ideographic"},
    28101: {"Unified_Ideograph", "Ideographic"},
    28102: {"Unified_Ideograph", "Ideographic"},
    28103: {"Unified_Ideograph", "Ideographic"},
    28104: {"Unified_Ideograph", "Ideographic"},
    28105: {"Unified_Ideograph", "Ideographic"},
    28106: {"Unified_Ideograph", "Ideographic"},
    28107: {"Unified_Ideograph", "Ideographic"},
    28108: {"Unified_Ideograph", "Ideographic"},
    28109: {"Unified_Ideograph", "Ideographic"},
    28110: {"Unified_Ideograph", "Ideographic"},
    28111: {"Unified_Ideograph", "Ideographic"},
    28112: {"Unified_Ideograph", "Ideographic"},
    28113: {"Unified_Ideograph", "Ideographic"},
    28114: {"Unified_Ideograph", "Ideographic"},
    28115: {"Unified_Ideograph", "Ideographic"},
    28116: {"Unified_Ideograph", "Ideographic"},
    28117: {"Unified_Ideograph", "Ideographic"},
    28118: {"Unified_Ideograph", "Ideographic"},
    28119: {"Unified_Ideograph", "Ideographic"},
    28120: {"Unified_Ideograph", "Ideographic"},
    28121: {"Unified_Ideograph", "Ideographic"},
    28122: {"Unified_Ideograph", "Ideographic"},
    28123: {"Unified_Ideograph", "Ideographic"},
    28124: {"Unified_Ideograph", "Ideographic"},
    28125: {"Unified_Ideograph", "Ideographic"},
    28126: {"Unified_Ideograph", "Ideographic"},
    28127: {"Unified_Ideograph", "Ideographic"},
    28128: {"Unified_Ideograph", "Ideographic"},
    28129: {"Unified_Ideograph", "Ideographic"},
    28130: {"Unified_Ideograph", "Ideographic"},
    28131: {"Unified_Ideograph", "Ideographic"},
    28132: {"Unified_Ideograph", "Ideographic"},
    28133: {"Unified_Ideograph", "Ideographic"},
    28134: {"Unified_Ideograph", "Ideographic"},
    28135: {"Unified_Ideograph", "Ideographic"},
    28136: {"Unified_Ideograph", "Ideographic"},
    28137: {"Unified_Ideograph", "Ideographic"},
    28138: {"Unified_Ideograph", "Ideographic"},
    28139: {"Unified_Ideograph", "Ideographic"},
    28140: {"Unified_Ideograph", "Ideographic"},
    28141: {"Unified_Ideograph", "Ideographic"},
    28142: {"Unified_Ideograph", "Ideographic"},
    28143: {"Unified_Ideograph", "Ideographic"},
    28144: {"Unified_Ideograph", "Ideographic"},
    28145: {"Unified_Ideograph", "Ideographic"},
    28146: {"Unified_Ideograph", "Ideographic"},
    28147: {"Unified_Ideograph", "Ideographic"},
    28148: {"Unified_Ideograph", "Ideographic"},
    28149: {"Unified_Ideograph", "Ideographic"},
    28150: {"Unified_Ideograph", "Ideographic"},
    28151: {"Unified_Ideograph", "Ideographic"},
    28152: {"Unified_Ideograph", "Ideographic"},
    28153: {"Unified_Ideograph", "Ideographic"},
    28154: {"Unified_Ideograph", "Ideographic"},
    28155: {"Unified_Ideograph", "Ideographic"},
    28156: {"Unified_Ideograph", "Ideographic"},
    28157: {"Unified_Ideograph", "Ideographic"},
    28158: {"Unified_Ideograph", "Ideographic"},
    28159: {"Unified_Ideograph", "Ideographic"},
    28160: {"Unified_Ideograph", "Ideographic"},
    28161: {"Unified_Ideograph", "Ideographic"},
    28162: {"Unified_Ideograph", "Ideographic"},
    28163: {"Unified_Ideograph", "Ideographic"},
    28164: {"Unified_Ideograph", "Ideographic"},
    28165: {"Unified_Ideograph", "Ideographic"},
    28166: {"Unified_Ideograph", "Ideographic"},
    28167: {"Unified_Ideograph", "Ideographic"},
    28168: {"Unified_Ideograph", "Ideographic"},
    28169: {"Unified_Ideograph", "Ideographic"},
    28170: {"Unified_Ideograph", "Ideographic"},
    28171: {"Unified_Ideograph", "Ideographic"},
    28172: {"Unified_Ideograph", "Ideographic"},
    28173: {"Unified_Ideograph", "Ideographic"},
    28174: {"Unified_Ideograph", "Ideographic"},
    28175: {"Unified_Ideograph", "Ideographic"},
    28176: {"Unified_Ideograph", "Ideographic"},
    28177: {"Unified_Ideograph", "Ideographic"},
    28178: {"Unified_Ideograph", "Ideographic"},
    28179: {"Unified_Ideograph", "Ideographic"},
    28180: {"Unified_Ideograph", "Ideographic"},
    28181: {"Unified_Ideograph", "Ideographic"},
    28182: {"Unified_Ideograph", "Ideographic"},
    28183: {"Unified_Ideograph", "Ideographic"},
    28184: {"Unified_Ideograph", "Ideographic"},
    28185: {"Unified_Ideograph", "Ideographic"},
    28186: {"Unified_Ideograph", "Ideographic"},
    28187: {"Unified_Ideograph", "Ideographic"},
    28188: {"Unified_Ideograph", "Ideographic"},
    28189: {"Unified_Ideograph", "Ideographic"},
    28190: {"Unified_Ideograph", "Ideographic"},
    28191: {"Unified_Ideograph", "Ideographic"},
    28192: {"Unified_Ideograph", "Ideographic"},
    28193: {"Unified_Ideograph", "Ideographic"},
    28194: {"Unified_Ideograph", "Ideographic"},
    28195: {"Unified_Ideograph", "Ideographic"},
    28196: {"Unified_Ideograph", "Ideographic"},
    28197: {"Unified_Ideograph", "Ideographic"},
    28198: {"Unified_Ideograph", "Ideographic"},
    28199: {"Unified_Ideograph", "Ideographic"},
    28200: {"Unified_Ideograph", "Ideographic"},
    28201: {"Unified_Ideograph", "Ideographic"},
    28202: {"Unified_Ideograph", "Ideographic"},
    28203: {"Unified_Ideograph", "Ideographic"},
    28204: {"Unified_Ideograph", "Ideographic"},
    28205: {"Unified_Ideograph", "Ideographic"},
    28206: {"Unified_Ideograph", "Ideographic"},
    28207: {"Unified_Ideograph", "Ideographic"},
    28208: {"Unified_Ideograph", "Ideographic"},
    28209: {"Unified_Ideograph", "Ideographic"},
    28210: {"Unified_Ideograph", "Ideographic"},
    28211: {"Unified_Ideograph", "Ideographic"},
    28212: {"Unified_Ideograph", "Ideographic"},
    28213: {"Unified_Ideograph", "Ideographic"},
    28214: {"Unified_Ideograph", "Ideographic"},
    28215: {"Unified_Ideograph", "Ideographic"},
    28216: {"Unified_Ideograph", "Ideographic"},
    28217: {"Unified_Ideograph", "Ideographic"},
    28218: {"Unified_Ideograph", "Ideographic"},
    28219: {"Unified_Ideograph", "Ideographic"},
    28220: {"Unified_Ideograph", "Ideographic"},
    28221: {"Unified_Ideograph", "Ideographic"},
    28222: {"Unified_Ideograph", "Ideographic"},
    28223: {"Unified_Ideograph", "Ideographic"},
    28224: {"Unified_Ideograph", "Ideographic"},
    28225: {"Unified_Ideograph", "Ideographic"},
    28226: {"Unified_Ideograph", "Ideographic"},
    28227: {"Unified_Ideograph", "Ideographic"},
    28228: {"Unified_Ideograph", "Ideographic"},
    28229: {"Unified_Ideograph", "Ideographic"},
    28230: {"Unified_Ideograph", "Ideographic"},
    28231: {"Unified_Ideograph", "Ideographic"},
    28232: {"Unified_Ideograph", "Ideographic"},
    28233: {"Unified_Ideograph", "Ideographic"},
    28234: {"Unified_Ideograph", "Ideographic"},
    28235: {"Unified_Ideograph", "Ideographic"},
    28236: {"Unified_Ideograph", "Ideographic"},
    28237: {"Unified_Ideograph", "Ideographic"},
    28238: {"Unified_Ideograph", "Ideographic"},
    28239: {"Unified_Ideograph", "Ideographic"},
    28240: {"Unified_Ideograph", "Ideographic"},
    28241: {"Unified_Ideograph", "Ideographic"},
    28242: {"Unified_Ideograph", "Ideographic"},
    28243: {"Unified_Ideograph", "Ideographic"},
    28244: {"Unified_Ideograph", "Ideographic"},
    28245: {"Unified_Ideograph", "Ideographic"},
    28246: {"Unified_Ideograph", "Ideographic"},
    28247: {"Unified_Ideograph", "Ideographic"},
    28248: {"Unified_Ideograph", "Ideographic"},
    28249: {"Unified_Ideograph", "Ideographic"},
    28250: {"Unified_Ideograph", "Ideographic"},
    28251: {"Unified_Ideograph", "Ideographic"},
    28252: {"Unified_Ideograph", "Ideographic"},
    28253: {"Unified_Ideograph", "Ideographic"},
    28254: {"Unified_Ideograph", "Ideographic"},
    28255: {"Unified_Ideograph", "Ideographic"},
    28256: {"Unified_Ideograph", "Ideographic"},
    28257: {"Unified_Ideograph", "Ideographic"},
    28258: {"Unified_Ideograph", "Ideographic"},
    28259: {"Unified_Ideograph", "Ideographic"},
    28260: {"Unified_Ideograph", "Ideographic"},
    28261: {"Unified_Ideograph", "Ideographic"},
    28262: {"Unified_Ideograph", "Ideographic"},
    28263: {"Unified_Ideograph", "Ideographic"},
    28264: {"Unified_Ideograph", "Ideographic"},
    28265: {"Unified_Ideograph", "Ideographic"},
    28266: {"Unified_Ideograph", "Ideographic"},
    28267: {"Unified_Ideograph", "Ideographic"},
    28268: {"Unified_Ideograph", "Ideographic"},
    28269: {"Unified_Ideograph", "Ideographic"},
    28270: {"Unified_Ideograph", "Ideographic"},
    28271: {"Unified_Ideograph", "Ideographic"},
    28272: {"Unified_Ideograph", "Ideographic"},
    28273: {"Unified_Ideograph", "Ideographic"},
    28274: {"Unified_Ideograph", "Ideographic"},
    28275: {"Unified_Ideograph", "Ideographic"},
    28276: {"Unified_Ideograph", "Ideographic"},
    28277: {"Unified_Ideograph", "Ideographic"},
    28278: {"Unified_Ideograph", "Ideographic"},
    28279: {"Unified_Ideograph", "Ideographic"},
    28280: {"Unified_Ideograph", "Ideographic"},
    28281: {"Unified_Ideograph", "Ideographic"},
    28282: {"Unified_Ideograph", "Ideographic"},
    28283: {"Unified_Ideograph", "Ideographic"},
    28284: {"Unified_Ideograph", "Ideographic"},
    28285: {"Unified_Ideograph", "Ideographic"},
    28286: {"Unified_Ideograph", "Ideographic"},
    28287: {"Unified_Ideograph", "Ideographic"},
    28288: {"Unified_Ideograph", "Ideographic"},
    28289: {"Unified_Ideograph", "Ideographic"},
    28290: {"Unified_Ideograph", "Ideographic"},
    28291: {"Unified_Ideograph", "Ideographic"},
    28292: {"Unified_Ideograph", "Ideographic"},
    28293: {"Unified_Ideograph", "Ideographic"},
    28294: {"Unified_Ideograph", "Ideographic"},
    28295: {"Unified_Ideograph", "Ideographic"},
    28296: {"Unified_Ideograph", "Ideographic"},
    28297: {"Unified_Ideograph", "Ideographic"},
    28298: {"Unified_Ideograph", "Ideographic"},
    28299: {"Unified_Ideograph", "Ideographic"},
    28300: {"Unified_Ideograph", "Ideographic"},
    28301: {"Unified_Ideograph", "Ideographic"},
    28302: {"Unified_Ideograph", "Ideographic"},
    28303: {"Unified_Ideograph", "Ideographic"},
    28304: {"Unified_Ideograph", "Ideographic"},
    28305: {"Unified_Ideograph", "Ideographic"},
    28306: {"Unified_Ideograph", "Ideographic"},
    28307: {"Unified_Ideograph", "Ideographic"},
    28308: {"Unified_Ideograph", "Ideographic"},
    28309: {"Unified_Ideograph", "Ideographic"},
    28310: {"Unified_Ideograph", "Ideographic"},
    28311: {"Unified_Ideograph", "Ideographic"},
    28312: {"Unified_Ideograph", "Ideographic"},
    28313: {"Unified_Ideograph", "Ideographic"},
    28314: {"Unified_Ideograph", "Ideographic"},
    28315: {"Unified_Ideograph", "Ideographic"},
    28316: {"Unified_Ideograph", "Ideographic"},
    28317: {"Unified_Ideograph", "Ideographic"},
    28318: {"Unified_Ideograph", "Ideographic"},
    28319: {"Unified_Ideograph", "Ideographic"},
    28320: {"Unified_Ideograph", "Ideographic"},
    28321: {"Unified_Ideograph", "Ideographic"},
    28322: {"Unified_Ideograph", "Ideographic"},
    28323: {"Unified_Ideograph", "Ideographic"},
    28324: {"Unified_Ideograph", "Ideographic"},
    28325: {"Unified_Ideograph", "Ideographic"},
    28326: {"Unified_Ideograph", "Ideographic"},
    28327: {"Unified_Ideograph", "Ideographic"},
    28328: {"Unified_Ideograph", "Ideographic"},
    28329: {"Unified_Ideograph", "Ideographic"},
    28330: {"Unified_Ideograph", "Ideographic"},
    28331: {"Unified_Ideograph", "Ideographic"},
    28332: {"Unified_Ideograph", "Ideographic"},
    28333: {"Unified_Ideograph", "Ideographic"},
    28334: {"Unified_Ideograph", "Ideographic"},
    28335: {"Unified_Ideograph", "Ideographic"},
    28336: {"Unified_Ideograph", "Ideographic"},
    28337: {"Unified_Ideograph", "Ideographic"},
    28338: {"Unified_Ideograph", "Ideographic"},
    28339: {"Unified_Ideograph", "Ideographic"},
    28340: {"Unified_Ideograph", "Ideographic"},
    28341: {"Unified_Ideograph", "Ideographic"},
    28342: {"Unified_Ideograph", "Ideographic"},
    28343: {"Unified_Ideograph", "Ideographic"},
    28344: {"Unified_Ideograph", "Ideographic"},
    28345: {"Unified_Ideograph", "Ideographic"},
    28346: {"Unified_Ideograph", "Ideographic"},
    28347: {"Unified_Ideograph", "Ideographic"},
    28348: {"Unified_Ideograph", "Ideographic"},
    28349: {"Unified_Ideograph", "Ideographic"},
    28350: {"Unified_Ideograph", "Ideographic"},
    28351: {"Unified_Ideograph", "Ideographic"},
    28352: {"Unified_Ideograph", "Ideographic"},
    28353: {"Unified_Ideograph", "Ideographic"},
    28354: {"Unified_Ideograph", "Ideographic"},
    28355: {"Unified_Ideograph", "Ideographic"},
    28356: {"Unified_Ideograph", "Ideographic"},
    28357: {"Unified_Ideograph", "Ideographic"},
    28358: {"Unified_Ideograph", "Ideographic"},
    28359: {"Unified_Ideograph", "Ideographic"},
    28360: {"Unified_Ideograph", "Ideographic"},
    28361: {"Unified_Ideograph", "Ideographic"},
    28362: {"Unified_Ideograph", "Ideographic"},
    28363: {"Unified_Ideograph", "Ideographic"},
    28364: {"Unified_Ideograph", "Ideographic"},
    28365: {"Unified_Ideograph", "Ideographic"},
    28366: {"Unified_Ideograph", "Ideographic"},
    28367: {"Unified_Ideograph", "Ideographic"},
    28368: {"Unified_Ideograph", "Ideographic"},
    28369: {"Unified_Ideograph", "Ideographic"},
    28370: {"Unified_Ideograph", "Ideographic"},
    28371: {"Unified_Ideograph", "Ideographic"},
    28372: {"Unified_Ideograph", "Ideographic"},
    28373: {"Unified_Ideograph", "Ideographic"},
    28374: {"Unified_Ideograph", "Ideographic"},
    28375: {"Unified_Ideograph", "Ideographic"},
    28376: {"Unified_Ideograph", "Ideographic"},
    28377: {"Unified_Ideograph", "Ideographic"},
    28378: {"Unified_Ideograph", "Ideographic"},
    28379: {"Unified_Ideograph", "Ideographic"},
    28380: {"Unified_Ideograph", "Ideographic"},
    28381: {"Unified_Ideograph", "Ideographic"},
    28382: {"Unified_Ideograph", "Ideographic"},
    28383: {"Unified_Ideograph", "Ideographic"},
    28384: {"Unified_Ideograph", "Ideographic"},
    28385: {"Unified_Ideograph", "Ideographic"},
    28386: {"Unified_Ideograph", "Ideographic"},
    28387: {"Unified_Ideograph", "Ideographic"},
    28388: {"Unified_Ideograph", "Ideographic"},
    28389: {"Unified_Ideograph", "Ideographic"},
    28390: {"Unified_Ideograph", "Ideographic"},
    28391: {"Unified_Ideograph", "Ideographic"},
    28392: {"Unified_Ideograph", "Ideographic"},
    28393: {"Unified_Ideograph", "Ideographic"},
    28394: {"Unified_Ideograph", "Ideographic"},
    28395: {"Unified_Ideograph", "Ideographic"},
    28396: {"Unified_Ideograph", "Ideographic"},
    28397: {"Unified_Ideograph", "Ideographic"},
    28398: {"Unified_Ideograph", "Ideographic"},
    28399: {"Unified_Ideograph", "Ideographic"},
    28400: {"Unified_Ideograph", "Ideographic"},
    28401: {"Unified_Ideograph", "Ideographic"},
    28402: {"Unified_Ideograph", "Ideographic"},
    28403: {"Unified_Ideograph", "Ideographic"},
    28404: {"Unified_Ideograph", "Ideographic"},
    28405: {"Unified_Ideograph", "Ideographic"},
    28406: {"Unified_Ideograph", "Ideographic"},
    28407: {"Unified_Ideograph", "Ideographic"},
    28408: {"Unified_Ideograph", "Ideographic"},
    28409: {"Unified_Ideograph", "Ideographic"},
    28410: {"Unified_Ideograph", "Ideographic"},
    28411: {"Unified_Ideograph", "Ideographic"},
    28412: {"Unified_Ideograph", "Ideographic"},
    28413: {"Unified_Ideograph", "Ideographic"},
    28414: {"Unified_Ideograph", "Ideographic"},
    28415: {"Unified_Ideograph", "Ideographic"},
    28416: {"Unified_Ideograph", "Ideographic"},
    28417: {"Unified_Ideograph", "Ideographic"},
    28418: {"Unified_Ideograph", "Ideographic"},
    28419: {"Unified_Ideograph", "Ideographic"},
    28420: {"Unified_Ideograph", "Ideographic"},
    28421: {"Unified_Ideograph", "Ideographic"},
    28422: {"Unified_Ideograph", "Ideographic"},
    28423: {"Unified_Ideograph", "Ideographic"},
    28424: {"Unified_Ideograph", "Ideographic"},
    28425: {"Unified_Ideograph", "Ideographic"},
    28426: {"Unified_Ideograph", "Ideographic"},
    28427: {"Unified_Ideograph", "Ideographic"},
    28428: {"Unified_Ideograph", "Ideographic"},
    28429: {"Unified_Ideograph", "Ideographic"},
    28430: {"Unified_Ideograph", "Ideographic"},
    28431: {"Unified_Ideograph", "Ideographic"},
    28432: {"Unified_Ideograph", "Ideographic"},
    28433: {"Unified_Ideograph", "Ideographic"},
    28434: {"Unified_Ideograph", "Ideographic"},
    28435: {"Unified_Ideograph", "Ideographic"},
    28436: {"Unified_Ideograph", "Ideographic"},
    28437: {"Unified_Ideograph", "Ideographic"},
    28438: {"Unified_Ideograph", "Ideographic"},
    28439: {"Unified_Ideograph", "Ideographic"},
    28440: {"Unified_Ideograph", "Ideographic"},
    28441: {"Unified_Ideograph", "Ideographic"},
    28442: {"Unified_Ideograph", "Ideographic"},
    28443: {"Unified_Ideograph", "Ideographic"},
    28444: {"Unified_Ideograph", "Ideographic"},
    28445: {"Unified_Ideograph", "Ideographic"},
    28446: {"Unified_Ideograph", "Ideographic"},
    28447: {"Unified_Ideograph", "Ideographic"},
    28448: {"Unified_Ideograph", "Ideographic"},
    28449: {"Unified_Ideograph", "Ideographic"},
    28450: {"Unified_Ideograph", "Ideographic"},
    28451: {"Unified_Ideograph", "Ideographic"},
    28452: {"Unified_Ideograph", "Ideographic"},
    28453: {"Unified_Ideograph", "Ideographic"},
    28454: {"Unified_Ideograph", "Ideographic"},
    28455: {"Unified_Ideograph", "Ideographic"},
    28456: {"Unified_Ideograph", "Ideographic"},
    28457: {"Unified_Ideograph", "Ideographic"},
    28458: {"Unified_Ideograph", "Ideographic"},
    28459: {"Unified_Ideograph", "Ideographic"},
    28460: {"Unified_Ideograph", "Ideographic"},
    28461: {"Unified_Ideograph", "Ideographic"},
    28462: {"Unified_Ideograph", "Ideographic"},
    28463: {"Unified_Ideograph", "Ideographic"},
    28464: {"Unified_Ideograph", "Ideographic"},
    28465: {"Unified_Ideograph", "Ideographic"},
    28466: {"Unified_Ideograph", "Ideographic"},
    28467: {"Unified_Ideograph", "Ideographic"},
    28468: {"Unified_Ideograph", "Ideographic"},
    28469: {"Unified_Ideograph", "Ideographic"},
    28470: {"Unified_Ideograph", "Ideographic"},
    28471: {"Unified_Ideograph", "Ideographic"},
    28472: {"Unified_Ideograph", "Ideographic"},
    28473: {"Unified_Ideograph", "Ideographic"},
    28474: {"Unified_Ideograph", "Ideographic"},
    28475: {"Unified_Ideograph", "Ideographic"},
    28476: {"Unified_Ideograph", "Ideographic"},
    28477: {"Unified_Ideograph", "Ideographic"},
    28478: {"Unified_Ideograph", "Ideographic"},
    28479: {"Unified_Ideograph", "Ideographic"},
    28480: {"Unified_Ideograph", "Ideographic"},
    28481: {"Unified_Ideograph", "Ideographic"},
    28482: {"Unified_Ideograph", "Ideographic"},
    28483: {"Unified_Ideograph", "Ideographic"},
    28484: {"Unified_Ideograph", "Ideographic"},
    28485: {"Unified_Ideograph", "Ideographic"},
    28486: {"Unified_Ideograph", "Ideographic"},
    28487: {"Unified_Ideograph", "Ideographic"},
    28488: {"Unified_Ideograph", "Ideographic"},
    28489: {"Unified_Ideograph", "Ideographic"},
    28490: {"Unified_Ideograph", "Ideographic"},
    28491: {"Unified_Ideograph", "Ideographic"},
    28492: {"Unified_Ideograph", "Ideographic"},
    28493: {"Unified_Ideograph", "Ideographic"},
    28494: {"Unified_Ideograph", "Ideographic"},
    28495: {"Unified_Ideograph", "Ideographic"},
    28496: {"Unified_Ideograph", "Ideographic"},
    28497: {"Unified_Ideograph", "Ideographic"},
    28498: {"Unified_Ideograph", "Ideographic"},
    28499: {"Unified_Ideograph", "Ideographic"},
    28500: {"Unified_Ideograph", "Ideographic"},
    28501: {"Unified_Ideograph", "Ideographic"},
    28502: {"Unified_Ideograph", "Ideographic"},
    28503: {"Unified_Ideograph", "Ideographic"},
    28504: {"Unified_Ideograph", "Ideographic"},
    28505: {"Unified_Ideograph", "Ideographic"},
    28506: {"Unified_Ideograph", "Ideographic"},
    28507: {"Unified_Ideograph", "Ideographic"},
    28508: {"Unified_Ideograph", "Ideographic"},
    28509: {"Unified_Ideograph", "Ideographic"},
    28510: {"Unified_Ideograph", "Ideographic"},
    28511: {"Unified_Ideograph", "Ideographic"},
    28512: {"Unified_Ideograph", "Ideographic"},
    28513: {"Unified_Ideograph", "Ideographic"},
    28514: {"Unified_Ideograph", "Ideographic"},
    28515: {"Unified_Ideograph", "Ideographic"},
    28516: {"Unified_Ideograph", "Ideographic"},
    28517: {"Unified_Ideograph", "Ideographic"},
    28518: {"Unified_Ideograph", "Ideographic"},
    28519: {"Unified_Ideograph", "Ideographic"},
    28520: {"Unified_Ideograph", "Ideographic"},
    28521: {"Unified_Ideograph", "Ideographic"},
    28522: {"Unified_Ideograph", "Ideographic"},
    28523: {"Unified_Ideograph", "Ideographic"},
    28524: {"Unified_Ideograph", "Ideographic"},
    28525: {"Unified_Ideograph", "Ideographic"},
    28526: {"Unified_Ideograph", "Ideographic"},
    28527: {"Unified_Ideograph", "Ideographic"},
    28528: {"Unified_Ideograph", "Ideographic"},
    28529: {"Unified_Ideograph", "Ideographic"},
    28530: {"Unified_Ideograph", "Ideographic"},
    28531: {"Unified_Ideograph", "Ideographic"},
    28532: {"Unified_Ideograph", "Ideographic"},
    28533: {"Unified_Ideograph", "Ideographic"},
    28534: {"Unified_Ideograph", "Ideographic"},
    28535: {"Unified_Ideograph", "Ideographic"},
    28536: {"Unified_Ideograph", "Ideographic"},
    28537: {"Unified_Ideograph", "Ideographic"},
    28538: {"Unified_Ideograph", "Ideographic"},
    28539: {"Unified_Ideograph", "Ideographic"},
    28540: {"Unified_Ideograph", "Ideographic"},
    28541: {"Unified_Ideograph", "Ideographic"},
    28542: {"Unified_Ideograph", "Ideographic"},
    28543: {"Unified_Ideograph", "Ideographic"},
    28544: {"Unified_Ideograph", "Ideographic"},
    28545: {"Unified_Ideograph", "Ideographic"},
    28546: {"Unified_Ideograph", "Ideographic"},
    28547: {"Unified_Ideograph", "Ideographic"},
    28548: {"Unified_Ideograph", "Ideographic"},
    28549: {"Unified_Ideograph", "Ideographic"},
    28550: {"Unified_Ideograph", "Ideographic"},
    28551: {"Unified_Ideograph", "Ideographic"},
    28552: {"Unified_Ideograph", "Ideographic"},
    28553: {"Unified_Ideograph", "Ideographic"},
    28554: {"Unified_Ideograph", "Ideographic"},
    28555: {"Unified_Ideograph", "Ideographic"},
    28556: {"Unified_Ideograph", "Ideographic"},
    28557: {"Unified_Ideograph", "Ideographic"},
    28558: {"Unified_Ideograph", "Ideographic"},
    28559: {"Unified_Ideograph", "Ideographic"},
    28560: {"Unified_Ideograph", "Ideographic"},
    28561: {"Unified_Ideograph", "Ideographic"},
    28562: {"Unified_Ideograph", "Ideographic"},
    28563: {"Unified_Ideograph", "Ideographic"},
    28564: {"Unified_Ideograph", "Ideographic"},
    28565: {"Unified_Ideograph", "Ideographic"},
    28566: {"Unified_Ideograph", "Ideographic"},
    28567: {"Unified_Ideograph", "Ideographic"},
    28568: {"Unified_Ideograph", "Ideographic"},
    28569: {"Unified_Ideograph", "Ideographic"},
    28570: {"Unified_Ideograph", "Ideographic"},
    28571: {"Unified_Ideograph", "Ideographic"},
    28572: {"Unified_Ideograph", "Ideographic"},
    28573: {"Unified_Ideograph", "Ideographic"},
    28574: {"Unified_Ideograph", "Ideographic"},
    28575: {"Unified_Ideograph", "Ideographic"},
    28576: {"Unified_Ideograph", "Ideographic"},
    28577: {"Unified_Ideograph", "Ideographic"},
    28578: {"Unified_Ideograph", "Ideographic"},
    28579: {"Unified_Ideograph", "Ideographic"},
    28580: {"Unified_Ideograph", "Ideographic"},
    28581: {"Unified_Ideograph", "Ideographic"},
    28582: {"Unified_Ideograph", "Ideographic"},
    28583: {"Unified_Ideograph", "Ideographic"},
    28584: {"Unified_Ideograph", "Ideographic"},
    28585: {"Unified_Ideograph", "Ideographic"},
    28586: {"Unified_Ideograph", "Ideographic"},
    28587: {"Unified_Ideograph", "Ideographic"},
    28588: {"Unified_Ideograph", "Ideographic"},
    28589: {"Unified_Ideograph", "Ideographic"},
    28590: {"Unified_Ideograph", "Ideographic"},
    28591: {"Unified_Ideograph", "Ideographic"},
    28592: {"Unified_Ideograph", "Ideographic"},
    28593: {"Unified_Ideograph", "Ideographic"},
    28594: {"Unified_Ideograph", "Ideographic"},
    28595: {"Unified_Ideograph", "Ideographic"},
    28596: {"Unified_Ideograph", "Ideographic"},
    28597: {"Unified_Ideograph", "Ideographic"},
    28598: {"Unified_Ideograph", "Ideographic"},
    28599: {"Unified_Ideograph", "Ideographic"},
    28600: {"Unified_Ideograph", "Ideographic"},
    28601: {"Unified_Ideograph", "Ideographic"},
    28602: {"Unified_Ideograph", "Ideographic"},
    28603: {"Unified_Ideograph", "Ideographic"},
    28604: {"Unified_Ideograph", "Ideographic"},
    28605: {"Unified_Ideograph", "Ideographic"},
    28606: {"Unified_Ideograph", "Ideographic"},
    28607: {"Unified_Ideograph", "Ideographic"},
    28608: {"Unified_Ideograph", "Ideographic"},
    28609: {"Unified_Ideograph", "Ideographic"},
    28610: {"Unified_Ideograph", "Ideographic"},
    28611: {"Unified_Ideograph", "Ideographic"},
    28612: {"Unified_Ideograph", "Ideographic"},
    28613: {"Unified_Ideograph", "Ideographic"},
    28614: {"Unified_Ideograph", "Ideographic"},
    28615: {"Unified_Ideograph", "Ideographic"},
    28616: {"Unified_Ideograph", "Ideographic"},
    28617: {"Unified_Ideograph", "Ideographic"},
    28618: {"Unified_Ideograph", "Ideographic"},
    28619: {"Unified_Ideograph", "Ideographic"},
    28620: {"Unified_Ideograph", "Ideographic"},
    28621: {"Unified_Ideograph", "Ideographic"},
    28622: {"Unified_Ideograph", "Ideographic"},
    28623: {"Unified_Ideograph", "Ideographic"},
    28624: {"Unified_Ideograph", "Ideographic"},
    28625: {"Unified_Ideograph", "Ideographic"},
    28626: {"Unified_Ideograph", "Ideographic"},
    28627: {"Unified_Ideograph", "Ideographic"},
    28628: {"Unified_Ideograph", "Ideographic"},
    28629: {"Unified_Ideograph", "Ideographic"},
    28630: {"Unified_Ideograph", "Ideographic"},
    28631: {"Unified_Ideograph", "Ideographic"},
    28632: {"Unified_Ideograph", "Ideographic"},
    28633: {"Unified_Ideograph", "Ideographic"},
    28634: {"Unified_Ideograph", "Ideographic"},
    28635: {"Unified_Ideograph", "Ideographic"},
    28636: {"Unified_Ideograph", "Ideographic"},
    28637: {"Unified_Ideograph", "Ideographic"},
    28638: {"Unified_Ideograph", "Ideographic"},
    28639: {"Unified_Ideograph", "Ideographic"},
    28640: {"Unified_Ideograph", "Ideographic"},
    28641: {"Unified_Ideograph", "Ideographic"},
    28642: {"Unified_Ideograph", "Ideographic"},
    28643: {"Unified_Ideograph", "Ideographic"},
    28644: {"Unified_Ideograph", "Ideographic"},
    28645: {"Unified_Ideograph", "Ideographic"},
    28646: {"Unified_Ideograph", "Ideographic"},
    28647: {"Unified_Ideograph", "Ideographic"},
    28648: {"Unified_Ideograph", "Ideographic"},
    28649: {"Unified_Ideograph", "Ideographic"},
    28650: {"Unified_Ideograph", "Ideographic"},
    28651: {"Unified_Ideograph", "Ideographic"},
    28652: {"Unified_Ideograph", "Ideographic"},
    28653: {"Unified_Ideograph", "Ideographic"},
    28654: {"Unified_Ideograph", "Ideographic"},
    28655: {"Unified_Ideograph", "Ideographic"},
    28656: {"Unified_Ideograph", "Ideographic"},
    28657: {"Unified_Ideograph", "Ideographic"},
    28658: {"Unified_Ideograph", "Ideographic"},
    28659: {"Unified_Ideograph", "Ideographic"},
    28660: {"Unified_Ideograph", "Ideographic"},
    28661: {"Unified_Ideograph", "Ideographic"},
    28662: {"Unified_Ideograph", "Ideographic"},
    28663: {"Unified_Ideograph", "Ideographic"},
    28664: {"Unified_Ideograph", "Ideographic"},
    28665: {"Unified_Ideograph", "Ideographic"},
    28666: {"Unified_Ideograph", "Ideographic"},
    28667: {"Unified_Ideograph", "Ideographic"},
    28668: {"Unified_Ideograph", "Ideographic"},
    28669: {"Unified_Ideograph", "Ideographic"},
    28670: {"Unified_Ideograph", "Ideographic"},
    28671: {"Unified_Ideograph", "Ideographic"},
    28672: {"Unified_Ideograph", "Ideographic"},
    28673: {"Unified_Ideograph", "Ideographic"},
    28674: {"Unified_Ideograph", "Ideographic"},
    28675: {"Unified_Ideograph", "Ideographic"},
    28676: {"Unified_Ideograph", "Ideographic"},
    28677: {"Unified_Ideograph", "Ideographic"},
    28678: {"Unified_Ideograph", "Ideographic"},
    28679: {"Unified_Ideograph", "Ideographic"},
    28680: {"Unified_Ideograph", "Ideographic"},
    28681: {"Unified_Ideograph", "Ideographic"},
    28682: {"Unified_Ideograph", "Ideographic"},
    28683: {"Unified_Ideograph", "Ideographic"},
    28684: {"Unified_Ideograph", "Ideographic"},
    28685: {"Unified_Ideograph", "Ideographic"},
    28686: {"Unified_Ideograph", "Ideographic"},
    28687: {"Unified_Ideograph", "Ideographic"},
    28688: {"Unified_Ideograph", "Ideographic"},
    28689: {"Unified_Ideograph", "Ideographic"},
    28690: {"Unified_Ideograph", "Ideographic"},
    28691: {"Unified_Ideograph", "Ideographic"},
    28692: {"Unified_Ideograph", "Ideographic"},
    28693: {"Unified_Ideograph", "Ideographic"},
    28694: {"Unified_Ideograph", "Ideographic"},
    28695: {"Unified_Ideograph", "Ideographic"},
    28696: {"Unified_Ideograph", "Ideographic"},
    28697: {"Unified_Ideograph", "Ideographic"},
    28698: {"Unified_Ideograph", "Ideographic"},
    28699: {"Unified_Ideograph", "Ideographic"},
    28700: {"Unified_Ideograph", "Ideographic"},
    28701: {"Unified_Ideograph", "Ideographic"},
    28702: {"Unified_Ideograph", "Ideographic"},
    28703: {"Unified_Ideograph", "Ideographic"},
    28704: {"Unified_Ideograph", "Ideographic"},
    28705: {"Unified_Ideograph", "Ideographic"},
    28706: {"Unified_Ideograph", "Ideographic"},
    28707: {"Unified_Ideograph", "Ideographic"},
    28708: {"Unified_Ideograph", "Ideographic"},
    28709: {"Unified_Ideograph", "Ideographic"},
    28710: {"Unified_Ideograph", "Ideographic"},
    28711: {"Unified_Ideograph", "Ideographic"},
    28712: {"Unified_Ideograph", "Ideographic"},
    28713: {"Unified_Ideograph", "Ideographic"},
    28714: {"Unified_Ideograph", "Ideographic"},
    28715: {"Unified_Ideograph", "Ideographic"},
    28716: {"Unified_Ideograph", "Ideographic"},
    28717: {"Unified_Ideograph", "Ideographic"},
    28718: {"Unified_Ideograph", "Ideographic"},
    28719: {"Unified_Ideograph", "Ideographic"},
    28720: {"Unified_Ideograph", "Ideographic"},
    28721: {"Unified_Ideograph", "Ideographic"},
    28722: {"Unified_Ideograph", "Ideographic"},
    28723: {"Unified_Ideograph", "Ideographic"},
    28724: {"Unified_Ideograph", "Ideographic"},
    28725: {"Unified_Ideograph", "Ideographic"},
    28726: {"Unified_Ideograph", "Ideographic"},
    28727: {"Unified_Ideograph", "Ideographic"},
    28728: {"Unified_Ideograph", "Ideographic"},
    28729: {"Unified_Ideograph", "Ideographic"},
    28730: {"Unified_Ideograph", "Ideographic"},
    28731: {"Unified_Ideograph", "Ideographic"},
    28732: {"Unified_Ideograph", "Ideographic"},
    28733: {"Unified_Ideograph", "Ideographic"},
    28734: {"Unified_Ideograph", "Ideographic"},
    28735: {"Unified_Ideograph", "Ideographic"},
    28736: {"Unified_Ideograph", "Ideographic"},
    28737: {"Unified_Ideograph", "Ideographic"},
    28738: {"Unified_Ideograph", "Ideographic"},
    28739: {"Unified_Ideograph", "Ideographic"},
    28740: {"Unified_Ideograph", "Ideographic"},
    28741: {"Unified_Ideograph", "Ideographic"},
    28742: {"Unified_Ideograph", "Ideographic"},
    28743: {"Unified_Ideograph", "Ideographic"},
    28744: {"Unified_Ideograph", "Ideographic"},
    28745: {"Unified_Ideograph", "Ideographic"},
    28746: {"Unified_Ideograph", "Ideographic"},
    28747: {"Unified_Ideograph", "Ideographic"},
    28748: {"Unified_Ideograph", "Ideographic"},
    28749: {"Unified_Ideograph", "Ideographic"},
    28750: {"Unified_Ideograph", "Ideographic"},
    28751: {"Unified_Ideograph", "Ideographic"},
    28752: {"Unified_Ideograph", "Ideographic"},
    28753: {"Unified_Ideograph", "Ideographic"},
    28754: {"Unified_Ideograph", "Ideographic"},
    28755: {"Unified_Ideograph", "Ideographic"},
    28756: {"Unified_Ideograph", "Ideographic"},
    28757: {"Unified_Ideograph", "Ideographic"},
    28758: {"Unified_Ideograph", "Ideographic"},
    28759: {"Unified_Ideograph", "Ideographic"},
    28760: {"Unified_Ideograph", "Ideographic"},
    28761: {"Unified_Ideograph", "Ideographic"},
    28762: {"Unified_Ideograph", "Ideographic"},
    28763: {"Unified_Ideograph", "Ideographic"},
    28764: {"Unified_Ideograph", "Ideographic"},
    28765: {"Unified_Ideograph", "Ideographic"},
    28766: {"Unified_Ideograph", "Ideographic"},
    28767: {"Unified_Ideograph", "Ideographic"},
    28768: {"Unified_Ideograph", "Ideographic"},
    28769: {"Unified_Ideograph", "Ideographic"},
    28770: {"Unified_Ideograph", "Ideographic"},
    28771: {"Unified_Ideograph", "Ideographic"},
    28772: {"Unified_Ideograph", "Ideographic"},
    28773: {"Unified_Ideograph", "Ideographic"},
    28774: {"Unified_Ideograph", "Ideographic"},
    28775: {"Unified_Ideograph", "Ideographic"},
    28776: {"Unified_Ideograph", "Ideographic"},
    28777: {"Unified_Ideograph", "Ideographic"},
    28778: {"Unified_Ideograph", "Ideographic"},
    28779: {"Unified_Ideograph", "Ideographic"},
    28780: {"Unified_Ideograph", "Ideographic"},
    28781: {"Unified_Ideograph", "Ideographic"},
    28782: {"Unified_Ideograph", "Ideographic"},
    28783: {"Unified_Ideograph", "Ideographic"},
    28784: {"Unified_Ideograph", "Ideographic"},
    28785: {"Unified_Ideograph", "Ideographic"},
    28786: {"Unified_Ideograph", "Ideographic"},
    28787: {"Unified_Ideograph", "Ideographic"},
    28788: {"Unified_Ideograph", "Ideographic"},
    28789: {"Unified_Ideograph", "Ideographic"},
    28790: {"Unified_Ideograph", "Ideographic"},
    28791: {"Unified_Ideograph", "Ideographic"},
    28792: {"Unified_Ideograph", "Ideographic"},
    28793: {"Unified_Ideograph", "Ideographic"},
    28794: {"Unified_Ideograph", "Ideographic"},
    28795: {"Unified_Ideograph", "Ideographic"},
    28796: {"Unified_Ideograph", "Ideographic"},
    28797: {"Unified_Ideograph", "Ideographic"},
    28798: {"Unified_Ideograph", "Ideographic"},
    28799: {"Unified_Ideograph", "Ideographic"},
    28800: {"Unified_Ideograph", "Ideographic"},
    28801: {"Unified_Ideograph", "Ideographic"},
    28802: {"Unified_Ideograph", "Ideographic"},
    28803: {"Unified_Ideograph", "Ideographic"},
    28804: {"Unified_Ideograph", "Ideographic"},
    28805: {"Unified_Ideograph", "Ideographic"},
    28806: {"Unified_Ideograph", "Ideographic"},
    28807: {"Unified_Ideograph", "Ideographic"},
    28808: {"Unified_Ideograph", "Ideographic"},
    28809: {"Unified_Ideograph", "Ideographic"},
    28810: {"Unified_Ideograph", "Ideographic"},
    28811: {"Unified_Ideograph", "Ideographic"},
    28812: {"Unified_Ideograph", "Ideographic"},
    28813: {"Unified_Ideograph", "Ideographic"},
    28814: {"Unified_Ideograph", "Ideographic"},
    28815: {"Unified_Ideograph", "Ideographic"},
    28816: {"Unified_Ideograph", "Ideographic"},
    28817: {"Unified_Ideograph", "Ideographic"},
    28818: {"Unified_Ideograph", "Ideographic"},
    28819: {"Unified_Ideograph", "Ideographic"},
    28820: {"Unified_Ideograph", "Ideographic"},
    28821: {"Unified_Ideograph", "Ideographic"},
    28822: {"Unified_Ideograph", "Ideographic"},
    28823: {"Unified_Ideograph", "Ideographic"},
    28824: {"Unified_Ideograph", "Ideographic"},
    28825: {"Unified_Ideograph", "Ideographic"},
    28826: {"Unified_Ideograph", "Ideographic"},
    28827: {"Unified_Ideograph", "Ideographic"},
    28828: {"Unified_Ideograph", "Ideographic"},
    28829: {"Unified_Ideograph", "Ideographic"},
    28830: {"Unified_Ideograph", "Ideographic"},
    28831: {"Unified_Ideograph", "Ideographic"},
    28832: {"Unified_Ideograph", "Ideographic"},
    28833: {"Unified_Ideograph", "Ideographic"},
    28834: {"Unified_Ideograph", "Ideographic"},
    28835: {"Unified_Ideograph", "Ideographic"},
    28836: {"Unified_Ideograph", "Ideographic"},
    28837: {"Unified_Ideograph", "Ideographic"},
    28838: {"Unified_Ideograph", "Ideographic"},
    28839: {"Unified_Ideograph", "Ideographic"},
    28840: {"Unified_Ideograph", "Ideographic"},
    28841: {"Unified_Ideograph", "Ideographic"},
    28842: {"Unified_Ideograph", "Ideographic"},
    28843: {"Unified_Ideograph", "Ideographic"},
    28844: {"Unified_Ideograph", "Ideographic"},
    28845: {"Unified_Ideograph", "Ideographic"},
    28846: {"Unified_Ideograph", "Ideographic"},
    28847: {"Unified_Ideograph", "Ideographic"},
    28848: {"Unified_Ideograph", "Ideographic"},
    28849: {"Unified_Ideograph", "Ideographic"},
    28850: {"Unified_Ideograph", "Ideographic"},
    28851: {"Unified_Ideograph", "Ideographic"},
    28852: {"Unified_Ideograph", "Ideographic"},
    28853: {"Unified_Ideograph", "Ideographic"},
    28854: {"Unified_Ideograph", "Ideographic"},
    28855: {"Unified_Ideograph", "Ideographic"},
    28856: {"Unified_Ideograph", "Ideographic"},
    28857: {"Unified_Ideograph", "Ideographic"},
    28858: {"Unified_Ideograph", "Ideographic"},
    28859: {"Unified_Ideograph", "Ideographic"},
    28860: {"Unified_Ideograph", "Ideographic"},
    28861: {"Unified_Ideograph", "Ideographic"},
    28862: {"Unified_Ideograph", "Ideographic"},
    28863: {"Unified_Ideograph", "Ideographic"},
    28864: {"Unified_Ideograph", "Ideographic"},
    28865: {"Unified_Ideograph", "Ideographic"},
    28866: {"Unified_Ideograph", "Ideographic"},
    28867: {"Unified_Ideograph", "Ideographic"},
    28868: {"Unified_Ideograph", "Ideographic"},
    28869: {"Unified_Ideograph", "Ideographic"},
    28870: {"Unified_Ideograph", "Ideographic"},
    28871: {"Unified_Ideograph", "Ideographic"},
    28872: {"Unified_Ideograph", "Ideographic"},
    28873: {"Unified_Ideograph", "Ideographic"},
    28874: {"Unified_Ideograph", "Ideographic"},
    28875: {"Unified_Ideograph", "Ideographic"},
    28876: {"Unified_Ideograph", "Ideographic"},
    28877: {"Unified_Ideograph", "Ideographic"},
    28878: {"Unified_Ideograph", "Ideographic"},
    28879: {"Unified_Ideograph", "Ideographic"},
    28880: {"Unified_Ideograph", "Ideographic"},
    28881: {"Unified_Ideograph", "Ideographic"},
    28882: {"Unified_Ideograph", "Ideographic"},
    28883: {"Unified_Ideograph", "Ideographic"},
    28884: {"Unified_Ideograph", "Ideographic"},
    28885: {"Unified_Ideograph", "Ideographic"},
    28886: {"Unified_Ideograph", "Ideographic"},
    28887: {"Unified_Ideograph", "Ideographic"},
    28888: {"Unified_Ideograph", "Ideographic"},
    28889: {"Unified_Ideograph", "Ideographic"},
    28890: {"Unified_Ideograph", "Ideographic"},
    28891: {"Unified_Ideograph", "Ideographic"},
    28892: {"Unified_Ideograph", "Ideographic"},
    28893: {"Unified_Ideograph", "Ideographic"},
    28894: {"Unified_Ideograph", "Ideographic"},
    28895: {"Unified_Ideograph", "Ideographic"},
    28896: {"Unified_Ideograph", "Ideographic"},
    28897: {"Unified_Ideograph", "Ideographic"},
    28898: {"Unified_Ideograph", "Ideographic"},
    28899: {"Unified_Ideograph", "Ideographic"},
    28900: {"Unified_Ideograph", "Ideographic"},
    28901: {"Unified_Ideograph", "Ideographic"},
    28902: {"Unified_Ideograph", "Ideographic"},
    28903: {"Unified_Ideograph", "Ideographic"},
    28904: {"Unified_Ideograph", "Ideographic"},
    28905: {"Unified_Ideograph", "Ideographic"},
    28906: {"Unified_Ideograph", "Ideographic"},
    28907: {"Unified_Ideograph", "Ideographic"},
    28908: {"Unified_Ideograph", "Ideographic"},
    28909: {"Unified_Ideograph", "Ideographic"},
    28910: {"Unified_Ideograph", "Ideographic"},
    28911: {"Unified_Ideograph", "Ideographic"},
    28912: {"Unified_Ideograph", "Ideographic"},
    28913: {"Unified_Ideograph", "Ideographic"},
    28914: {"Unified_Ideograph", "Ideographic"},
    28915: {"Unified_Ideograph", "Ideographic"},
    28916: {"Unified_Ideograph", "Ideographic"},
    28917: {"Unified_Ideograph", "Ideographic"},
    28918: {"Unified_Ideograph", "Ideographic"},
    28919: {"Unified_Ideograph", "Ideographic"},
    28920: {"Unified_Ideograph", "Ideographic"},
    28921: {"Unified_Ideograph", "Ideographic"},
    28922: {"Unified_Ideograph", "Ideographic"},
    28923: {"Unified_Ideograph", "Ideographic"},
    28924: {"Unified_Ideograph", "Ideographic"},
    28925: {"Unified_Ideograph", "Ideographic"},
    28926: {"Unified_Ideograph", "Ideographic"},
    28927: {"Unified_Ideograph", "Ideographic"},
    28928: {"Unified_Ideograph", "Ideographic"},
    28929: {"Unified_Ideograph", "Ideographic"},
    28930: {"Unified_Ideograph", "Ideographic"},
    28931: {"Unified_Ideograph", "Ideographic"},
    28932: {"Unified_Ideograph", "Ideographic"},
    28933: {"Unified_Ideograph", "Ideographic"},
    28934: {"Unified_Ideograph", "Ideographic"},
    28935: {"Unified_Ideograph", "Ideographic"},
    28936: {"Unified_Ideograph", "Ideographic"},
    28937: {"Unified_Ideograph", "Ideographic"},
    28938: {"Unified_Ideograph", "Ideographic"},
    28939: {"Unified_Ideograph", "Ideographic"},
    28940: {"Unified_Ideograph", "Ideographic"},
    28941: {"Unified_Ideograph", "Ideographic"},
    28942: {"Unified_Ideograph", "Ideographic"},
    28943: {"Unified_Ideograph", "Ideographic"},
    28944: {"Unified_Ideograph", "Ideographic"},
    28945: {"Unified_Ideograph", "Ideographic"},
    28946: {"Unified_Ideograph", "Ideographic"},
    28947: {"Unified_Ideograph", "Ideographic"},
    28948: {"Unified_Ideograph", "Ideographic"},
    28949: {"Unified_Ideograph", "Ideographic"},
    28950: {"Unified_Ideograph", "Ideographic"},
    28951: {"Unified_Ideograph", "Ideographic"},
    28952: {"Unified_Ideograph", "Ideographic"},
    28953: {"Unified_Ideograph", "Ideographic"},
    28954: {"Unified_Ideograph", "Ideographic"},
    28955: {"Unified_Ideograph", "Ideographic"},
    28956: {"Unified_Ideograph", "Ideographic"},
    28957: {"Unified_Ideograph", "Ideographic"},
    28958: {"Unified_Ideograph", "Ideographic"},
    28959: {"Unified_Ideograph", "Ideographic"},
    28960: {"Unified_Ideograph", "Ideographic"},
    28961: {"Unified_Ideograph", "Ideographic"},
    28962: {"Unified_Ideograph", "Ideographic"},
    28963: {"Unified_Ideograph", "Ideographic"},
    28964: {"Unified_Ideograph", "Ideographic"},
    28965: {"Unified_Ideograph", "Ideographic"},
    28966: {"Unified_Ideograph", "Ideographic"},
    28967: {"Unified_Ideograph", "Ideographic"},
    28968: {"Unified_Ideograph", "Ideographic"},
    28969: {"Unified_Ideograph", "Ideographic"},
    28970: {"Unified_Ideograph", "Ideographic"},
    28971: {"Unified_Ideograph", "Ideographic"},
    28972: {"Unified_Ideograph", "Ideographic"},
    28973: {"Unified_Ideograph", "Ideographic"},
    28974: {"Unified_Ideograph", "Ideographic"},
    28975: {"Unified_Ideograph", "Ideographic"},
    28976: {"Unified_Ideograph", "Ideographic"},
    28977: {"Unified_Ideograph", "Ideographic"},
    28978: {"Unified_Ideograph", "Ideographic"},
    28979: {"Unified_Ideograph", "Ideographic"},
    28980: {"Unified_Ideograph", "Ideographic"},
    28981: {"Unified_Ideograph", "Ideographic"},
    28982: {"Unified_Ideograph", "Ideographic"},
    28983: {"Unified_Ideograph", "Ideographic"},
    28984: {"Unified_Ideograph", "Ideographic"},
    28985: {"Unified_Ideograph", "Ideographic"},
    28986: {"Unified_Ideograph", "Ideographic"},
    28987: {"Unified_Ideograph", "Ideographic"},
    28988: {"Unified_Ideograph", "Ideographic"},
    28989: {"Unified_Ideograph", "Ideographic"},
    28990: {"Unified_Ideograph", "Ideographic"},
    28991: {"Unified_Ideograph", "Ideographic"},
    28992: {"Unified_Ideograph", "Ideographic"},
    28993: {"Unified_Ideograph", "Ideographic"},
    28994: {"Unified_Ideograph", "Ideographic"},
    28995: {"Unified_Ideograph", "Ideographic"},
    28996: {"Unified_Ideograph", "Ideographic"},
    28997: {"Unified_Ideograph", "Ideographic"},
    28998: {"Unified_Ideograph", "Ideographic"},
    28999: {"Unified_Ideograph", "Ideographic"},
    29000: {"Unified_Ideograph", "Ideographic"},
    29001: {"Unified_Ideograph", "Ideographic"},
    29002: {"Unified_Ideograph", "Ideographic"},
    29003: {"Unified_Ideograph", "Ideographic"},
    29004: {"Unified_Ideograph", "Ideographic"},
    29005: {"Unified_Ideograph", "Ideographic"},
    29006: {"Unified_Ideograph", "Ideographic"},
    29007: {"Unified_Ideograph", "Ideographic"},
    29008: {"Unified_Ideograph", "Ideographic"},
    29009: {"Unified_Ideograph", "Ideographic"},
    29010: {"Unified_Ideograph", "Ideographic"},
    29011: {"Unified_Ideograph", "Ideographic"},
    29012: {"Unified_Ideograph", "Ideographic"},
    29013: {"Unified_Ideograph", "Ideographic"},
    29014: {"Unified_Ideograph", "Ideographic"},
    29015: {"Unified_Ideograph", "Ideographic"},
    29016: {"Unified_Ideograph", "Ideographic"},
    29017: {"Unified_Ideograph", "Ideographic"},
    29018: {"Unified_Ideograph", "Ideographic"},
    29019: {"Unified_Ideograph", "Ideographic"},
    29020: {"Unified_Ideograph", "Ideographic"},
    29021: {"Unified_Ideograph", "Ideographic"},
    29022: {"Unified_Ideograph", "Ideographic"},
    29023: {"Unified_Ideograph", "Ideographic"},
    29024: {"Unified_Ideograph", "Ideographic"},
    29025: {"Unified_Ideograph", "Ideographic"},
    29026: {"Unified_Ideograph", "Ideographic"},
    29027: {"Unified_Ideograph", "Ideographic"},
    29028: {"Unified_Ideograph", "Ideographic"},
    29029: {"Unified_Ideograph", "Ideographic"},
    29030: {"Unified_Ideograph", "Ideographic"},
    29031: {"Unified_Ideograph", "Ideographic"},
    29032: {"Unified_Ideograph", "Ideographic"},
    29033: {"Unified_Ideograph", "Ideographic"},
    29034: {"Unified_Ideograph", "Ideographic"},
    29035: {"Unified_Ideograph", "Ideographic"},
    29036: {"Unified_Ideograph", "Ideographic"},
    29037: {"Unified_Ideograph", "Ideographic"},
    29038: {"Unified_Ideograph", "Ideographic"},
    29039: {"Unified_Ideograph", "Ideographic"},
    29040: {"Unified_Ideograph", "Ideographic"},
    29041: {"Unified_Ideograph", "Ideographic"},
    29042: {"Unified_Ideograph", "Ideographic"},
    29043: {"Unified_Ideograph", "Ideographic"},
    29044: {"Unified_Ideograph", "Ideographic"},
    29045: {"Unified_Ideograph", "Ideographic"},
    29046: {"Unified_Ideograph", "Ideographic"},
    29047: {"Unified_Ideograph", "Ideographic"},
    29048: {"Unified_Ideograph", "Ideographic"},
    29049: {"Unified_Ideograph", "Ideographic"},
    29050: {"Unified_Ideograph", "Ideographic"},
    29051: {"Unified_Ideograph", "Ideographic"},
    29052: {"Unified_Ideograph", "Ideographic"},
    29053: {"Unified_Ideograph", "Ideographic"},
    29054: {"Unified_Ideograph", "Ideographic"},
    29055: {"Unified_Ideograph", "Ideographic"},
    29056: {"Unified_Ideograph", "Ideographic"},
    29057: {"Unified_Ideograph", "Ideographic"},
    29058: {"Unified_Ideograph", "Ideographic"},
    29059: {"Unified_Ideograph", "Ideographic"},
    29060: {"Unified_Ideograph", "Ideographic"},
    29061: {"Unified_Ideograph", "Ideographic"},
    29062: {"Unified_Ideograph", "Ideographic"},
    29063: {"Unified_Ideograph", "Ideographic"},
    29064: {"Unified_Ideograph", "Ideographic"},
    29065: {"Unified_Ideograph", "Ideographic"},
    29066: {"Unified_Ideograph", "Ideographic"},
    29067: {"Unified_Ideograph", "Ideographic"},
    29068: {"Unified_Ideograph", "Ideographic"},
    29069: {"Unified_Ideograph", "Ideographic"},
    29070: {"Unified_Ideograph", "Ideographic"},
    29071: {"Unified_Ideograph", "Ideographic"},
    29072: {"Unified_Ideograph", "Ideographic"},
    29073: {"Unified_Ideograph", "Ideographic"},
    29074: {"Unified_Ideograph", "Ideographic"},
    29075: {"Unified_Ideograph", "Ideographic"},
    29076: {"Unified_Ideograph", "Ideographic"},
    29077: {"Unified_Ideograph", "Ideographic"},
    29078: {"Unified_Ideograph", "Ideographic"},
    29079: {"Unified_Ideograph", "Ideographic"},
    29080: {"Unified_Ideograph", "Ideographic"},
    29081: {"Unified_Ideograph", "Ideographic"},
    29082: {"Unified_Ideograph", "Ideographic"},
    29083: {"Unified_Ideograph", "Ideographic"},
    29084: {"Unified_Ideograph", "Ideographic"},
    29085: {"Unified_Ideograph", "Ideographic"},
    29086: {"Unified_Ideograph", "Ideographic"},
    29087: {"Unified_Ideograph", "Ideographic"},
    29088: {"Unified_Ideograph", "Ideographic"},
    29089: {"Unified_Ideograph", "Ideographic"},
    29090: {"Unified_Ideograph", "Ideographic"},
    29091: {"Unified_Ideograph", "Ideographic"},
    29092: {"Unified_Ideograph", "Ideographic"},
    29093: {"Unified_Ideograph", "Ideographic"},
    29094: {"Unified_Ideograph", "Ideographic"},
    29095: {"Unified_Ideograph", "Ideographic"},
    29096: {"Unified_Ideograph", "Ideographic"},
    29097: {"Unified_Ideograph", "Ideographic"},
    29098: {"Unified_Ideograph", "Ideographic"},
    29099: {"Unified_Ideograph", "Ideographic"},
    29100: {"Unified_Ideograph", "Ideographic"},
    29101: {"Unified_Ideograph", "Ideographic"},
    29102: {"Unified_Ideograph", "Ideographic"},
    29103: {"Unified_Ideograph", "Ideographic"},
    29104: {"Unified_Ideograph", "Ideographic"},
    29105: {"Unified_Ideograph", "Ideographic"},
    29106: {"Unified_Ideograph", "Ideographic"},
    29107: {"Unified_Ideograph", "Ideographic"},
    29108: {"Unified_Ideograph", "Ideographic"},
    29109: {"Unified_Ideograph", "Ideographic"},
    29110: {"Unified_Ideograph", "Ideographic"},
    29111: {"Unified_Ideograph", "Ideographic"},
    29112: {"Unified_Ideograph", "Ideographic"},
    29113: {"Unified_Ideograph", "Ideographic"},
    29114: {"Unified_Ideograph", "Ideographic"},
    29115: {"Unified_Ideograph", "Ideographic"},
    29116: {"Unified_Ideograph", "Ideographic"},
    29117: {"Unified_Ideograph", "Ideographic"},
    29118: {"Unified_Ideograph", "Ideographic"},
    29119: {"Unified_Ideograph", "Ideographic"},
    29120: {"Unified_Ideograph", "Ideographic"},
    29121: {"Unified_Ideograph", "Ideographic"},
    29122: {"Unified_Ideograph", "Ideographic"},
    29123: {"Unified_Ideograph", "Ideographic"},
    29124: {"Unified_Ideograph", "Ideographic"},
    29125: {"Unified_Ideograph", "Ideographic"},
    29126: {"Unified_Ideograph", "Ideographic"},
    29127: {"Unified_Ideograph", "Ideographic"},
    29128: {"Unified_Ideograph", "Ideographic"},
    29129: {"Unified_Ideograph", "Ideographic"},
    29130: {"Unified_Ideograph", "Ideographic"},
    29131: {"Unified_Ideograph", "Ideographic"},
    29132: {"Unified_Ideograph", "Ideographic"},
    29133: {"Unified_Ideograph", "Ideographic"},
    29134: {"Unified_Ideograph", "Ideographic"},
    29135: {"Unified_Ideograph", "Ideographic"},
    29136: {"Unified_Ideograph", "Ideographic"},
    29137: {"Unified_Ideograph", "Ideographic"},
    29138: {"Unified_Ideograph", "Ideographic"},
    29139: {"Unified_Ideograph", "Ideographic"},
    29140: {"Unified_Ideograph", "Ideographic"},
    29141: {"Unified_Ideograph", "Ideographic"},
    29142: {"Unified_Ideograph", "Ideographic"},
    29143: {"Unified_Ideograph", "Ideographic"},
    29144: {"Unified_Ideograph", "Ideographic"},
    29145: {"Unified_Ideograph", "Ideographic"},
    29146: {"Unified_Ideograph", "Ideographic"},
    29147: {"Unified_Ideograph", "Ideographic"},
    29148: {"Unified_Ideograph", "Ideographic"},
    29149: {"Unified_Ideograph", "Ideographic"},
    29150: {"Unified_Ideograph", "Ideographic"},
    29151: {"Unified_Ideograph", "Ideographic"},
    29152: {"Unified_Ideograph", "Ideographic"},
    29153: {"Unified_Ideograph", "Ideographic"},
    29154: {"Unified_Ideograph", "Ideographic"},
    29155: {"Unified_Ideograph", "Ideographic"},
    29156: {"Unified_Ideograph", "Ideographic"},
    29157: {"Unified_Ideograph", "Ideographic"},
    29158: {"Unified_Ideograph", "Ideographic"},
    29159: {"Unified_Ideograph", "Ideographic"},
    29160: {"Unified_Ideograph", "Ideographic"},
    29161: {"Unified_Ideograph", "Ideographic"},
    29162: {"Unified_Ideograph", "Ideographic"},
    29163: {"Unified_Ideograph", "Ideographic"},
    29164: {"Unified_Ideograph", "Ideographic"},
    29165: {"Unified_Ideograph", "Ideographic"},
    29166: {"Unified_Ideograph", "Ideographic"},
    29167: {"Unified_Ideograph", "Ideographic"},
    29168: {"Unified_Ideograph", "Ideographic"},
    29169: {"Unified_Ideograph", "Ideographic"},
    29170: {"Unified_Ideograph", "Ideographic"},
    29171: {"Unified_Ideograph", "Ideographic"},
    29172: {"Unified_Ideograph", "Ideographic"},
    29173: {"Unified_Ideograph", "Ideographic"},
    29174: {"Unified_Ideograph", "Ideographic"},
    29175: {"Unified_Ideograph", "Ideographic"},
    29176: {"Unified_Ideograph", "Ideographic"},
    29177: {"Unified_Ideograph", "Ideographic"},
    29178: {"Unified_Ideograph", "Ideographic"},
    29179: {"Unified_Ideograph", "Ideographic"},
    29180: {"Unified_Ideograph", "Ideographic"},
    29181: {"Unified_Ideograph", "Ideographic"},
    29182: {"Unified_Ideograph", "Ideographic"},
    29183: {"Unified_Ideograph", "Ideographic"},
    29184: {"Unified_Ideograph", "Ideographic"},
    29185: {"Unified_Ideograph", "Ideographic"},
    29186: {"Unified_Ideograph", "Ideographic"},
    29187: {"Unified_Ideograph", "Ideographic"},
    29188: {"Unified_Ideograph", "Ideographic"},
    29189: {"Unified_Ideograph", "Ideographic"},
    29190: {"Unified_Ideograph", "Ideographic"},
    29191: {"Unified_Ideograph", "Ideographic"},
    29192: {"Unified_Ideograph", "Ideographic"},
    29193: {"Unified_Ideograph", "Ideographic"},
    29194: {"Unified_Ideograph", "Ideographic"},
    29195: {"Unified_Ideograph", "Ideographic"},
    29196: {"Unified_Ideograph", "Ideographic"},
    29197: {"Unified_Ideograph", "Ideographic"},
    29198: {"Unified_Ideograph", "Ideographic"},
    29199: {"Unified_Ideograph", "Ideographic"},
    29200: {"Unified_Ideograph", "Ideographic"},
    29201: {"Unified_Ideograph", "Ideographic"},
    29202: {"Unified_Ideograph", "Ideographic"},
    29203: {"Unified_Ideograph", "Ideographic"},
    29204: {"Unified_Ideograph", "Ideographic"},
    29205: {"Unified_Ideograph", "Ideographic"},
    29206: {"Unified_Ideograph", "Ideographic"},
    29207: {"Unified_Ideograph", "Ideographic"},
    29208: {"Unified_Ideograph", "Ideographic"},
    29209: {"Unified_Ideograph", "Ideographic"},
    29210: {"Unified_Ideograph", "Ideographic"},
    29211: {"Unified_Ideograph", "Ideographic"},
    29212: {"Unified_Ideograph", "Ideographic"},
    29213: {"Unified_Ideograph", "Ideographic"},
    29214: {"Unified_Ideograph", "Ideographic"},
    29215: {"Unified_Ideograph", "Ideographic"},
    29216: {"Unified_Ideograph", "Ideographic"},
    29217: {"Unified_Ideograph", "Ideographic"},
    29218: {"Unified_Ideograph", "Ideographic"},
    29219: {"Unified_Ideograph", "Ideographic"},
    29220: {"Unified_Ideograph", "Ideographic"},
    29221: {"Unified_Ideograph", "Ideographic"},
    29222: {"Unified_Ideograph", "Ideographic"},
    29223: {"Unified_Ideograph", "Ideographic"},
    29224: {"Unified_Ideograph", "Ideographic"},
    29225: {"Unified_Ideograph", "Ideographic"},
    29226: {"Unified_Ideograph", "Ideographic"},
    29227: {"Unified_Ideograph", "Ideographic"},
    29228: {"Unified_Ideograph", "Ideographic"},
    29229: {"Unified_Ideograph", "Ideographic"},
    29230: {"Unified_Ideograph", "Ideographic"},
    29231: {"Unified_Ideograph", "Ideographic"},
    29232: {"Unified_Ideograph", "Ideographic"},
    29233: {"Unified_Ideograph", "Ideographic"},
    29234: {"Unified_Ideograph", "Ideographic"},
    29235: {"Unified_Ideograph", "Ideographic"},
    29236: {"Unified_Ideograph", "Ideographic"},
    29237: {"Unified_Ideograph", "Ideographic"},
    29238: {"Unified_Ideograph", "Ideographic"},
    29239: {"Unified_Ideograph", "Ideographic"},
    29240: {"Unified_Ideograph", "Ideographic"},
    29241: {"Unified_Ideograph", "Ideographic"},
    29242: {"Unified_Ideograph", "Ideographic"},
    29243: {"Unified_Ideograph", "Ideographic"},
    29244: {"Unified_Ideograph", "Ideographic"},
    29245: {"Unified_Ideograph", "Ideographic"},
    29246: {"Unified_Ideograph", "Ideographic"},
    29247: {"Unified_Ideograph", "Ideographic"},
    29248: {"Unified_Ideograph", "Ideographic"},
    29249: {"Unified_Ideograph", "Ideographic"},
    29250: {"Unified_Ideograph", "Ideographic"},
    29251: {"Unified_Ideograph", "Ideographic"},
    29252: {"Unified_Ideograph", "Ideographic"},
    29253: {"Unified_Ideograph", "Ideographic"},
    29254: {"Unified_Ideograph", "Ideographic"},
    29255: {"Unified_Ideograph", "Ideographic"},
    29256: {"Unified_Ideograph", "Ideographic"},
    29257: {"Unified_Ideograph", "Ideographic"},
    29258: {"Unified_Ideograph", "Ideographic"},
    29259: {"Unified_Ideograph", "Ideographic"},
    29260: {"Unified_Ideograph", "Ideographic"},
    29261: {"Unified_Ideograph", "Ideographic"},
    29262: {"Unified_Ideograph", "Ideographic"},
    29263: {"Unified_Ideograph", "Ideographic"},
    29264: {"Unified_Ideograph", "Ideographic"},
    29265: {"Unified_Ideograph", "Ideographic"},
    29266: {"Unified_Ideograph", "Ideographic"},
    29267: {"Unified_Ideograph", "Ideographic"},
    29268: {"Unified_Ideograph", "Ideographic"},
    29269: {"Unified_Ideograph", "Ideographic"},
    29270: {"Unified_Ideograph", "Ideographic"},
    29271: {"Unified_Ideograph", "Ideographic"},
    29272: {"Unified_Ideograph", "Ideographic"},
    29273: {"Unified_Ideograph", "Ideographic"},
    29274: {"Unified_Ideograph", "Ideographic"},
    29275: {"Unified_Ideograph", "Ideographic"},
    29276: {"Unified_Ideograph", "Ideographic"},
    29277: {"Unified_Ideograph", "Ideographic"},
    29278: {"Unified_Ideograph", "Ideographic"},
    29279: {"Unified_Ideograph", "Ideographic"},
    29280: {"Unified_Ideograph", "Ideographic"},
    29281: {"Unified_Ideograph", "Ideographic"},
    29282: {"Unified_Ideograph", "Ideographic"},
    29283: {"Unified_Ideograph", "Ideographic"},
    29284: {"Unified_Ideograph", "Ideographic"},
    29285: {"Unified_Ideograph", "Ideographic"},
    29286: {"Unified_Ideograph", "Ideographic"},
    29287: {"Unified_Ideograph", "Ideographic"},
    29288: {"Unified_Ideograph", "Ideographic"},
    29289: {"Unified_Ideograph", "Ideographic"},
    29290: {"Unified_Ideograph", "Ideographic"},
    29291: {"Unified_Ideograph", "Ideographic"},
    29292: {"Unified_Ideograph", "Ideographic"},
    29293: {"Unified_Ideograph", "Ideographic"},
    29294: {"Unified_Ideograph", "Ideographic"},
    29295: {"Unified_Ideograph", "Ideographic"},
    29296: {"Unified_Ideograph", "Ideographic"},
    29297: {"Unified_Ideograph", "Ideographic"},
    29298: {"Unified_Ideograph", "Ideographic"},
    29299: {"Unified_Ideograph", "Ideographic"},
    29300: {"Unified_Ideograph", "Ideographic"},
    29301: {"Unified_Ideograph", "Ideographic"},
    29302: {"Unified_Ideograph", "Ideographic"},
    29303: {"Unified_Ideograph", "Ideographic"},
    29304: {"Unified_Ideograph", "Ideographic"},
    29305: {"Unified_Ideograph", "Ideographic"},
    29306: {"Unified_Ideograph", "Ideographic"},
    29307: {"Unified_Ideograph", "Ideographic"},
    29308: {"Unified_Ideograph", "Ideographic"},
    29309: {"Unified_Ideograph", "Ideographic"},
    29310: {"Unified_Ideograph", "Ideographic"},
    29311: {"Unified_Ideograph", "Ideographic"},
    29312: {"Unified_Ideograph", "Ideographic"},
    29313: {"Unified_Ideograph", "Ideographic"},
    29314: {"Unified_Ideograph", "Ideographic"},
    29315: {"Unified_Ideograph", "Ideographic"},
    29316: {"Unified_Ideograph", "Ideographic"},
    29317: {"Unified_Ideograph", "Ideographic"},
    29318: {"Unified_Ideograph", "Ideographic"},
    29319: {"Unified_Ideograph", "Ideographic"},
    29320: {"Unified_Ideograph", "Ideographic"},
    29321: {"Unified_Ideograph", "Ideographic"},
    29322: {"Unified_Ideograph", "Ideographic"},
    29323: {"Unified_Ideograph", "Ideographic"},
    29324: {"Unified_Ideograph", "Ideographic"},
    29325: {"Unified_Ideograph", "Ideographic"},
    29326: {"Unified_Ideograph", "Ideographic"},
    29327: {"Unified_Ideograph", "Ideographic"},
    29328: {"Unified_Ideograph", "Ideographic"},
    29329: {"Unified_Ideograph", "Ideographic"},
    29330: {"Unified_Ideograph", "Ideographic"},
    29331: {"Unified_Ideograph", "Ideographic"},
    29332: {"Unified_Ideograph", "Ideographic"},
    29333: {"Unified_Ideograph", "Ideographic"},
    29334: {"Unified_Ideograph", "Ideographic"},
    29335: {"Unified_Ideograph", "Ideographic"},
    29336: {"Unified_Ideograph", "Ideographic"},
    29337: {"Unified_Ideograph", "Ideographic"},
    29338: {"Unified_Ideograph", "Ideographic"},
    29339: {"Unified_Ideograph", "Ideographic"},
    29340: {"Unified_Ideograph", "Ideographic"},
    29341: {"Unified_Ideograph", "Ideographic"},
    29342: {"Unified_Ideograph", "Ideographic"},
    29343: {"Unified_Ideograph", "Ideographic"},
    29344: {"Unified_Ideograph", "Ideographic"},
    29345: {"Unified_Ideograph", "Ideographic"},
    29346: {"Unified_Ideograph", "Ideographic"},
    29347: {"Unified_Ideograph", "Ideographic"},
    29348: {"Unified_Ideograph", "Ideographic"},
    29349: {"Unified_Ideograph", "Ideographic"},
    29350: {"Unified_Ideograph", "Ideographic"},
    29351: {"Unified_Ideograph", "Ideographic"},
    29352: {"Unified_Ideograph", "Ideographic"},
    29353: {"Unified_Ideograph", "Ideographic"},
    29354: {"Unified_Ideograph", "Ideographic"},
    29355: {"Unified_Ideograph", "Ideographic"},
    29356: {"Unified_Ideograph", "Ideographic"},
    29357: {"Unified_Ideograph", "Ideographic"},
    29358: {"Unified_Ideograph", "Ideographic"},
    29359: {"Unified_Ideograph", "Ideographic"},
    29360: {"Unified_Ideograph", "Ideographic"},
    29361: {"Unified_Ideograph", "Ideographic"},
    29362: {"Unified_Ideograph", "Ideographic"},
    29363: {"Unified_Ideograph", "Ideographic"},
    29364: {"Unified_Ideograph", "Ideographic"},
    29365: {"Unified_Ideograph", "Ideographic"},
    29366: {"Unified_Ideograph", "Ideographic"},
    29367: {"Unified_Ideograph", "Ideographic"},
    29368: {"Unified_Ideograph", "Ideographic"},
    29369: {"Unified_Ideograph", "Ideographic"},
    29370: {"Unified_Ideograph", "Ideographic"},
    29371: {"Unified_Ideograph", "Ideographic"},
    29372: {"Unified_Ideograph", "Ideographic"},
    29373: {"Unified_Ideograph", "Ideographic"},
    29374: {"Unified_Ideograph", "Ideographic"},
    29375: {"Unified_Ideograph", "Ideographic"},
    29376: {"Unified_Ideograph", "Ideographic"},
    29377: {"Unified_Ideograph", "Ideographic"},
    29378: {"Unified_Ideograph", "Ideographic"},
    29379: {"Unified_Ideograph", "Ideographic"},
    29380: {"Unified_Ideograph", "Ideographic"},
    29381: {"Unified_Ideograph", "Ideographic"},
    29382: {"Unified_Ideograph", "Ideographic"},
    29383: {"Unified_Ideograph", "Ideographic"},
    29384: {"Unified_Ideograph", "Ideographic"},
    29385: {"Unified_Ideograph", "Ideographic"},
    29386: {"Unified_Ideograph", "Ideographic"},
    29387: {"Unified_Ideograph", "Ideographic"},
    29388: {"Unified_Ideograph", "Ideographic"},
    29389: {"Unified_Ideograph", "Ideographic"},
    29390: {"Unified_Ideograph", "Ideographic"},
    29391: {"Unified_Ideograph", "Ideographic"},
    29392: {"Unified_Ideograph", "Ideographic"},
    29393: {"Unified_Ideograph", "Ideographic"},
    29394: {"Unified_Ideograph", "Ideographic"},
    29395: {"Unified_Ideograph", "Ideographic"},
    29396: {"Unified_Ideograph", "Ideographic"},
    29397: {"Unified_Ideograph", "Ideographic"},
    29398: {"Unified_Ideograph", "Ideographic"},
    29399: {"Unified_Ideograph", "Ideographic"},
    29400: {"Unified_Ideograph", "Ideographic"},
    29401: {"Unified_Ideograph", "Ideographic"},
    29402: {"Unified_Ideograph", "Ideographic"},
    29403: {"Unified_Ideograph", "Ideographic"},
    29404: {"Unified_Ideograph", "Ideographic"},
    29405: {"Unified_Ideograph", "Ideographic"},
    29406: {"Unified_Ideograph", "Ideographic"},
    29407: {"Unified_Ideograph", "Ideographic"},
    29408: {"Unified_Ideograph", "Ideographic"},
    29409: {"Unified_Ideograph", "Ideographic"},
    29410: {"Unified_Ideograph", "Ideographic"},
    29411: {"Unified_Ideograph", "Ideographic"},
    29412: {"Unified_Ideograph", "Ideographic"},
    29413: {"Unified_Ideograph", "Ideographic"},
    29414: {"Unified_Ideograph", "Ideographic"},
    29415: {"Unified_Ideograph", "Ideographic"},
    29416: {"Unified_Ideograph", "Ideographic"},
    29417: {"Unified_Ideograph", "Ideographic"},
    29418: {"Unified_Ideograph", "Ideographic"},
    29419: {"Unified_Ideograph", "Ideographic"},
    29420: {"Unified_Ideograph", "Ideographic"},
    29421: {"Unified_Ideograph", "Ideographic"},
    29422: {"Unified_Ideograph", "Ideographic"},
    29423: {"Unified_Ideograph", "Ideographic"},
    29424: {"Unified_Ideograph", "Ideographic"},
    29425: {"Unified_Ideograph", "Ideographic"},
    29426: {"Unified_Ideograph", "Ideographic"},
    29427: {"Unified_Ideograph", "Ideographic"},
    29428: {"Unified_Ideograph", "Ideographic"},
    29429: {"Unified_Ideograph", "Ideographic"},
    29430: {"Unified_Ideograph", "Ideographic"},
    29431: {"Unified_Ideograph", "Ideographic"},
    29432: {"Unified_Ideograph", "Ideographic"},
    29433: {"Unified_Ideograph", "Ideographic"},
    29434: {"Unified_Ideograph", "Ideographic"},
    29435: {"Unified_Ideograph", "Ideographic"},
    29436: {"Unified_Ideograph", "Ideographic"},
    29437: {"Unified_Ideograph", "Ideographic"},
    29438: {"Unified_Ideograph", "Ideographic"},
    29439: {"Unified_Ideograph", "Ideographic"},
    29440: {"Unified_Ideograph", "Ideographic"},
    29441: {"Unified_Ideograph", "Ideographic"},
    29442: {"Unified_Ideograph", "Ideographic"},
    29443: {"Unified_Ideograph", "Ideographic"},
    29444: {"Unified_Ideograph", "Ideographic"},
    29445: {"Unified_Ideograph", "Ideographic"},
    29446: {"Unified_Ideograph", "Ideographic"},
    29447: {"Unified_Ideograph", "Ideographic"},
    29448: {"Unified_Ideograph", "Ideographic"},
    29449: {"Unified_Ideograph", "Ideographic"},
    29450: {"Unified_Ideograph", "Ideographic"},
    29451: {"Unified_Ideograph", "Ideographic"},
    29452: {"Unified_Ideograph", "Ideographic"},
    29453: {"Unified_Ideograph", "Ideographic"},
    29454: {"Unified_Ideograph", "Ideographic"},
    29455: {"Unified_Ideograph", "Ideographic"},
    29456: {"Unified_Ideograph", "Ideographic"},
    29457: {"Unified_Ideograph", "Ideographic"},
    29458: {"Unified_Ideograph", "Ideographic"},
    29459: {"Unified_Ideograph", "Ideographic"},
    29460: {"Unified_Ideograph", "Ideographic"},
    29461: {"Unified_Ideograph", "Ideographic"},
    29462: {"Unified_Ideograph", "Ideographic"},
    29463: {"Unified_Ideograph", "Ideographic"},
    29464: {"Unified_Ideograph", "Ideographic"},
    29465: {"Unified_Ideograph", "Ideographic"},
    29466: {"Unified_Ideograph", "Ideographic"},
    29467: {"Unified_Ideograph", "Ideographic"},
    29468: {"Unified_Ideograph", "Ideographic"},
    29469: {"Unified_Ideograph", "Ideographic"},
    29470: {"Unified_Ideograph", "Ideographic"},
    29471: {"Unified_Ideograph", "Ideographic"},
    29472: {"Unified_Ideograph", "Ideographic"},
    29473: {"Unified_Ideograph", "Ideographic"},
    29474: {"Unified_Ideograph", "Ideographic"},
    29475: {"Unified_Ideograph", "Ideographic"},
    29476: {"Unified_Ideograph", "Ideographic"},
    29477: {"Unified_Ideograph", "Ideographic"},
    29478: {"Unified_Ideograph", "Ideographic"},
    29479: {"Unified_Ideograph", "Ideographic"},
    29480: {"Unified_Ideograph", "Ideographic"},
    29481: {"Unified_Ideograph", "Ideographic"},
    29482: {"Unified_Ideograph", "Ideographic"},
    29483: {"Unified_Ideograph", "Ideographic"},
    29484: {"Unified_Ideograph", "Ideographic"},
    29485: {"Unified_Ideograph", "Ideographic"},
    29486: {"Unified_Ideograph", "Ideographic"},
    29487: {"Unified_Ideograph", "Ideographic"},
    29488: {"Unified_Ideograph", "Ideographic"},
    29489: {"Unified_Ideograph", "Ideographic"},
    29490: {"Unified_Ideograph", "Ideographic"},
    29491: {"Unified_Ideograph", "Ideographic"},
    29492: {"Unified_Ideograph", "Ideographic"},
    29493: {"Unified_Ideograph", "Ideographic"},
    29494: {"Unified_Ideograph", "Ideographic"},
    29495: {"Unified_Ideograph", "Ideographic"},
    29496: {"Unified_Ideograph", "Ideographic"},
    29497: {"Unified_Ideograph", "Ideographic"},
    29498: {"Unified_Ideograph", "Ideographic"},
    29499: {"Unified_Ideograph", "Ideographic"},
    29500: {"Unified_Ideograph", "Ideographic"},
    29501: {"Unified_Ideograph", "Ideographic"},
    29502: {"Unified_Ideograph", "Ideographic"},
    29503: {"Unified_Ideograph", "Ideographic"},
    29504: {"Unified_Ideograph", "Ideographic"},
    29505: {"Unified_Ideograph", "Ideographic"},
    29506: {"Unified_Ideograph", "Ideographic"},
    29507: {"Unified_Ideograph", "Ideographic"},
    29508: {"Unified_Ideograph", "Ideographic"},
    29509: {"Unified_Ideograph", "Ideographic"},
    29510: {"Unified_Ideograph", "Ideographic"},
    29511: {"Unified_Ideograph", "Ideographic"},
    29512: {"Unified_Ideograph", "Ideographic"},
    29513: {"Unified_Ideograph", "Ideographic"},
    29514: {"Unified_Ideograph", "Ideographic"},
    29515: {"Unified_Ideograph", "Ideographic"},
    29516: {"Unified_Ideograph", "Ideographic"},
    29517: {"Unified_Ideograph", "Ideographic"},
    29518: {"Unified_Ideograph", "Ideographic"},
    29519: {"Unified_Ideograph", "Ideographic"},
    29520: {"Unified_Ideograph", "Ideographic"},
    29521: {"Unified_Ideograph", "Ideographic"},
    29522: {"Unified_Ideograph", "Ideographic"},
    29523: {"Unified_Ideograph", "Ideographic"},
    29524: {"Unified_Ideograph", "Ideographic"},
    29525: {"Unified_Ideograph", "Ideographic"},
    29526: {"Unified_Ideograph", "Ideographic"},
    29527: {"Unified_Ideograph", "Ideographic"},
    29528: {"Unified_Ideograph", "Ideographic"},
    29529: {"Unified_Ideograph", "Ideographic"},
    29530: {"Unified_Ideograph", "Ideographic"},
    29531: {"Unified_Ideograph", "Ideographic"},
    29532: {"Unified_Ideograph", "Ideographic"},
    29533: {"Unified_Ideograph", "Ideographic"},
    29534: {"Unified_Ideograph", "Ideographic"},
    29535: {"Unified_Ideograph", "Ideographic"},
    29536: {"Unified_Ideograph", "Ideographic"},
    29537: {"Unified_Ideograph", "Ideographic"},
    29538: {"Unified_Ideograph", "Ideographic"},
    29539: {"Unified_Ideograph", "Ideographic"},
    29540: {"Unified_Ideograph", "Ideographic"},
    29541: {"Unified_Ideograph", "Ideographic"},
    29542: {"Unified_Ideograph", "Ideographic"},
    29543: {"Unified_Ideograph", "Ideographic"},
    29544: {"Unified_Ideograph", "Ideographic"},
    29545: {"Unified_Ideograph", "Ideographic"},
    29546: {"Unified_Ideograph", "Ideographic"},
    29547: {"Unified_Ideograph", "Ideographic"},
    29548: {"Unified_Ideograph", "Ideographic"},
    29549: {"Unified_Ideograph", "Ideographic"},
    29550: {"Unified_Ideograph", "Ideographic"},
    29551: {"Unified_Ideograph", "Ideographic"},
    29552: {"Unified_Ideograph", "Ideographic"},
    29553: {"Unified_Ideograph", "Ideographic"},
    29554: {"Unified_Ideograph", "Ideographic"},
    29555: {"Unified_Ideograph", "Ideographic"},
    29556: {"Unified_Ideograph", "Ideographic"},
    29557: {"Unified_Ideograph", "Ideographic"},
    29558: {"Unified_Ideograph", "Ideographic"},
    29559: {"Unified_Ideograph", "Ideographic"},
    29560: {"Unified_Ideograph", "Ideographic"},
    29561: {"Unified_Ideograph", "Ideographic"},
    29562: {"Unified_Ideograph", "Ideographic"},
    29563: {"Unified_Ideograph", "Ideographic"},
    29564: {"Unified_Ideograph", "Ideographic"},
    29565: {"Unified_Ideograph", "Ideographic"},
    29566: {"Unified_Ideograph", "Ideographic"},
    29567: {"Unified_Ideograph", "Ideographic"},
    29568: {"Unified_Ideograph", "Ideographic"},
    29569: {"Unified_Ideograph", "Ideographic"},
    29570: {"Unified_Ideograph", "Ideographic"},
    29571: {"Unified_Ideograph", "Ideographic"},
    29572: {"Unified_Ideograph", "Ideographic"},
    29573: {"Unified_Ideograph", "Ideographic"},
    29574: {"Unified_Ideograph", "Ideographic"},
    29575: {"Unified_Ideograph", "Ideographic"},
    29576: {"Unified_Ideograph", "Ideographic"},
    29577: {"Unified_Ideograph", "Ideographic"},
    29578: {"Unified_Ideograph", "Ideographic"},
    29579: {"Unified_Ideograph", "Ideographic"},
    29580: {"Unified_Ideograph", "Ideographic"},
    29581: {"Unified_Ideograph", "Ideographic"},
    29582: {"Unified_Ideograph", "Ideographic"},
    29583: {"Unified_Ideograph", "Ideographic"},
    29584: {"Unified_Ideograph", "Ideographic"},
    29585: {"Unified_Ideograph", "Ideographic"},
    29586: {"Unified_Ideograph", "Ideographic"},
    29587: {"Unified_Ideograph", "Ideographic"},
    29588: {"Unified_Ideograph", "Ideographic"},
    29589: {"Unified_Ideograph", "Ideographic"},
    29590: {"Unified_Ideograph", "Ideographic"},
    29591: {"Unified_Ideograph", "Ideographic"},
    29592: {"Unified_Ideograph", "Ideographic"},
    29593: {"Unified_Ideograph", "Ideographic"},
    29594: {"Unified_Ideograph", "Ideographic"},
    29595: {"Unified_Ideograph", "Ideographic"},
    29596: {"Unified_Ideograph", "Ideographic"},
    29597: {"Unified_Ideograph", "Ideographic"},
    29598: {"Unified_Ideograph", "Ideographic"},
    29599: {"Unified_Ideograph", "Ideographic"},
    29600: {"Unified_Ideograph", "Ideographic"},
    29601: {"Unified_Ideograph", "Ideographic"},
    29602: {"Unified_Ideograph", "Ideographic"},
    29603: {"Unified_Ideograph", "Ideographic"},
    29604: {"Unified_Ideograph", "Ideographic"},
    29605: {"Unified_Ideograph", "Ideographic"},
    29606: {"Unified_Ideograph", "Ideographic"},
    29607: {"Unified_Ideograph", "Ideographic"},
    29608: {"Unified_Ideograph", "Ideographic"},
    29609: {"Unified_Ideograph", "Ideographic"},
    29610: {"Unified_Ideograph", "Ideographic"},
    29611: {"Unified_Ideograph", "Ideographic"},
    29612: {"Unified_Ideograph", "Ideographic"},
    29613: {"Unified_Ideograph", "Ideographic"},
    29614: {"Unified_Ideograph", "Ideographic"},
    29615: {"Unified_Ideograph", "Ideographic"},
    29616: {"Unified_Ideograph", "Ideographic"},
    29617: {"Unified_Ideograph", "Ideographic"},
    29618: {"Unified_Ideograph", "Ideographic"},
    29619: {"Unified_Ideograph", "Ideographic"},
    29620: {"Unified_Ideograph", "Ideographic"},
    29621: {"Unified_Ideograph", "Ideographic"},
    29622: {"Unified_Ideograph", "Ideographic"},
    29623: {"Unified_Ideograph", "Ideographic"},
    29624: {"Unified_Ideograph", "Ideographic"},
    29625: {"Unified_Ideograph", "Ideographic"},
    29626: {"Unified_Ideograph", "Ideographic"},
    29627: {"Unified_Ideograph", "Ideographic"},
    29628: {"Unified_Ideograph", "Ideographic"},
    29629: {"Unified_Ideograph", "Ideographic"},
    29630: {"Unified_Ideograph", "Ideographic"},
    29631: {"Unified_Ideograph", "Ideographic"},
    29632: {"Unified_Ideograph", "Ideographic"},
    29633: {"Unified_Ideograph", "Ideographic"},
    29634: {"Unified_Ideograph", "Ideographic"},
    29635: {"Unified_Ideograph", "Ideographic"},
    29636: {"Unified_Ideograph", "Ideographic"},
    29637: {"Unified_Ideograph", "Ideographic"},
    29638: {"Unified_Ideograph", "Ideographic"},
    29639: {"Unified_Ideograph", "Ideographic"},
    29640: {"Unified_Ideograph", "Ideographic"},
    29641: {"Unified_Ideograph", "Ideographic"},
    29642: {"Unified_Ideograph", "Ideographic"},
    29643: {"Unified_Ideograph", "Ideographic"},
    29644: {"Unified_Ideograph", "Ideographic"},
    29645: {"Unified_Ideograph", "Ideographic"},
    29646: {"Unified_Ideograph", "Ideographic"},
    29647: {"Unified_Ideograph", "Ideographic"},
    29648: {"Unified_Ideograph", "Ideographic"},
    29649: {"Unified_Ideograph", "Ideographic"},
    29650: {"Unified_Ideograph", "Ideographic"},
    29651: {"Unified_Ideograph", "Ideographic"},
    29652: {"Unified_Ideograph", "Ideographic"},
    29653: {"Unified_Ideograph", "Ideographic"},
    29654: {"Unified_Ideograph", "Ideographic"},
    29655: {"Unified_Ideograph", "Ideographic"},
    29656: {"Unified_Ideograph", "Ideographic"},
    29657: {"Unified_Ideograph", "Ideographic"},
    29658: {"Unified_Ideograph", "Ideographic"},
    29659: {"Unified_Ideograph", "Ideographic"},
    29660: {"Unified_Ideograph", "Ideographic"},
    29661: {"Unified_Ideograph", "Ideographic"},
    29662: {"Unified_Ideograph", "Ideographic"},
    29663: {"Unified_Ideograph", "Ideographic"},
    29664: {"Unified_Ideograph", "Ideographic"},
    29665: {"Unified_Ideograph", "Ideographic"},
    29666: {"Unified_Ideograph", "Ideographic"},
    29667: {"Unified_Ideograph", "Ideographic"},
    29668: {"Unified_Ideograph", "Ideographic"},
    29669: {"Unified_Ideograph", "Ideographic"},
    29670: {"Unified_Ideograph", "Ideographic"},
    29671: {"Unified_Ideograph", "Ideographic"},
    29672: {"Unified_Ideograph", "Ideographic"},
    29673: {"Unified_Ideograph", "Ideographic"},
    29674: {"Unified_Ideograph", "Ideographic"},
    29675: {"Unified_Ideograph", "Ideographic"},
    29676: {"Unified_Ideograph", "Ideographic"},
    29677: {"Unified_Ideograph", "Ideographic"},
    29678: {"Unified_Ideograph", "Ideographic"},
    29679: {"Unified_Ideograph", "Ideographic"},
    29680: {"Unified_Ideograph", "Ideographic"},
    29681: {"Unified_Ideograph", "Ideographic"},
    29682: {"Unified_Ideograph", "Ideographic"},
    29683: {"Unified_Ideograph", "Ideographic"},
    29684: {"Unified_Ideograph", "Ideographic"},
    29685: {"Unified_Ideograph", "Ideographic"},
    29686: {"Unified_Ideograph", "Ideographic"},
    29687: {"Unified_Ideograph", "Ideographic"},
    29688: {"Unified_Ideograph", "Ideographic"},
    29689: {"Unified_Ideograph", "Ideographic"},
    29690: {"Unified_Ideograph", "Ideographic"},
    29691: {"Unified_Ideograph", "Ideographic"},
    29692: {"Unified_Ideograph", "Ideographic"},
    29693: {"Unified_Ideograph", "Ideographic"},
    29694: {"Unified_Ideograph", "Ideographic"},
    29695: {"Unified_Ideograph", "Ideographic"},
    29696: {"Unified_Ideograph", "Ideographic"},
    29697: {"Unified_Ideograph", "Ideographic"},
    29698: {"Unified_Ideograph", "Ideographic"},
    29699: {"Unified_Ideograph", "Ideographic"},
    29700: {"Unified_Ideograph", "Ideographic"},
    29701: {"Unified_Ideograph", "Ideographic"},
    29702: {"Unified_Ideograph", "Ideographic"},
    29703: {"Unified_Ideograph", "Ideographic"},
    29704: {"Unified_Ideograph", "Ideographic"},
    29705: {"Unified_Ideograph", "Ideographic"},
    29706: {"Unified_Ideograph", "Ideographic"},
    29707: {"Unified_Ideograph", "Ideographic"},
    29708: {"Unified_Ideograph", "Ideographic"},
    29709: {"Unified_Ideograph", "Ideographic"},
    29710: {"Unified_Ideograph", "Ideographic"},
    29711: {"Unified_Ideograph", "Ideographic"},
    29712: {"Unified_Ideograph", "Ideographic"},
    29713: {"Unified_Ideograph", "Ideographic"},
    29714: {"Unified_Ideograph", "Ideographic"},
    29715: {"Unified_Ideograph", "Ideographic"},
    29716: {"Unified_Ideograph", "Ideographic"},
    29717: {"Unified_Ideograph", "Ideographic"},
    29718: {"Unified_Ideograph", "Ideographic"},
    29719: {"Unified_Ideograph", "Ideographic"},
    29720: {"Unified_Ideograph", "Ideographic"},
    29721: {"Unified_Ideograph", "Ideographic"},
    29722: {"Unified_Ideograph", "Ideographic"},
    29723: {"Unified_Ideograph", "Ideographic"},
    29724: {"Unified_Ideograph", "Ideographic"},
    29725: {"Unified_Ideograph", "Ideographic"},
    29726: {"Unified_Ideograph", "Ideographic"},
    29727: {"Unified_Ideograph", "Ideographic"},
    29728: {"Unified_Ideograph", "Ideographic"},
    29729: {"Unified_Ideograph", "Ideographic"},
    29730: {"Unified_Ideograph", "Ideographic"},
    29731: {"Unified_Ideograph", "Ideographic"},
    29732: {"Unified_Ideograph", "Ideographic"},
    29733: {"Unified_Ideograph", "Ideographic"},
    29734: {"Unified_Ideograph", "Ideographic"},
    29735: {"Unified_Ideograph", "Ideographic"},
    29736: {"Unified_Ideograph", "Ideographic"},
    29737: {"Unified_Ideograph", "Ideographic"},
    29738: {"Unified_Ideograph", "Ideographic"},
    29739: {"Unified_Ideograph", "Ideographic"},
    29740: {"Unified_Ideograph", "Ideographic"},
    29741: {"Unified_Ideograph", "Ideographic"},
    29742: {"Unified_Ideograph", "Ideographic"},
    29743: {"Unified_Ideograph", "Ideographic"},
    29744: {"Unified_Ideograph", "Ideographic"},
    29745: {"Unified_Ideograph", "Ideographic"},
    29746: {"Unified_Ideograph", "Ideographic"},
    29747: {"Unified_Ideograph", "Ideographic"},
    29748: {"Unified_Ideograph", "Ideographic"},
    29749: {"Unified_Ideograph", "Ideographic"},
    29750: {"Unified_Ideograph", "Ideographic"},
    29751: {"Unified_Ideograph", "Ideographic"},
    29752: {"Unified_Ideograph", "Ideographic"},
    29753: {"Unified_Ideograph", "Ideographic"},
    29754: {"Unified_Ideograph", "Ideographic"},
    29755: {"Unified_Ideograph", "Ideographic"},
    29756: {"Unified_Ideograph", "Ideographic"},
    29757: {"Unified_Ideograph", "Ideographic"},
    29758: {"Unified_Ideograph", "Ideographic"},
    29759: {"Unified_Ideograph", "Ideographic"},
    29760: {"Unified_Ideograph", "Ideographic"},
    29761: {"Unified_Ideograph", "Ideographic"},
    29762: {"Unified_Ideograph", "Ideographic"},
    29763: {"Unified_Ideograph", "Ideographic"},
    29764: {"Unified_Ideograph", "Ideographic"},
    29765: {"Unified_Ideograph", "Ideographic"},
    29766: {"Unified_Ideograph", "Ideographic"},
    29767: {"Unified_Ideograph", "Ideographic"},
    29768: {"Unified_Ideograph", "Ideographic"},
    29769: {"Unified_Ideograph", "Ideographic"},
    29770: {"Unified_Ideograph", "Ideographic"},
    29771: {"Unified_Ideograph", "Ideographic"},
    29772: {"Unified_Ideograph", "Ideographic"},
    29773: {"Unified_Ideograph", "Ideographic"},
    29774: {"Unified_Ideograph", "Ideographic"},
    29775: {"Unified_Ideograph", "Ideographic"},
    29776: {"Unified_Ideograph", "Ideographic"},
    29777: {"Unified_Ideograph", "Ideographic"},
    29778: {"Unified_Ideograph", "Ideographic"},
    29779: {"Unified_Ideograph", "Ideographic"},
    29780: {"Unified_Ideograph", "Ideographic"},
    29781: {"Unified_Ideograph", "Ideographic"},
    29782: {"Unified_Ideograph", "Ideographic"},
    29783: {"Unified_Ideograph", "Ideographic"},
    29784: {"Unified_Ideograph", "Ideographic"},
    29785: {"Unified_Ideograph", "Ideographic"},
    29786: {"Unified_Ideograph", "Ideographic"},
    29787: {"Unified_Ideograph", "Ideographic"},
    29788: {"Unified_Ideograph", "Ideographic"},
    29789: {"Unified_Ideograph", "Ideographic"},
    29790: {"Unified_Ideograph", "Ideographic"},
    29791: {"Unified_Ideograph", "Ideographic"},
    29792: {"Unified_Ideograph", "Ideographic"},
    29793: {"Unified_Ideograph", "Ideographic"},
    29794: {"Unified_Ideograph", "Ideographic"},
    29795: {"Unified_Ideograph", "Ideographic"},
    29796: {"Unified_Ideograph", "Ideographic"},
    29797: {"Unified_Ideograph", "Ideographic"},
    29798: {"Unified_Ideograph", "Ideographic"},
    29799: {"Unified_Ideograph", "Ideographic"},
    29800: {"Unified_Ideograph", "Ideographic"},
    29801: {"Unified_Ideograph", "Ideographic"},
    29802: {"Unified_Ideograph", "Ideographic"},
    29803: {"Unified_Ideograph", "Ideographic"},
    29804: {"Unified_Ideograph", "Ideographic"},
    29805: {"Unified_Ideograph", "Ideographic"},
    29806: {"Unified_Ideograph", "Ideographic"},
    29807: {"Unified_Ideograph", "Ideographic"},
    29808: {"Unified_Ideograph", "Ideographic"},
    29809: {"Unified_Ideograph", "Ideographic"},
    29810: {"Unified_Ideograph", "Ideographic"},
    29811: {"Unified_Ideograph", "Ideographic"},
    29812: {"Unified_Ideograph", "Ideographic"},
    29813: {"Unified_Ideograph", "Ideographic"},
    29814: {"Unified_Ideograph", "Ideographic"},
    29815: {"Unified_Ideograph", "Ideographic"},
    29816: {"Unified_Ideograph", "Ideographic"},
    29817: {"Unified_Ideograph", "Ideographic"},
    29818: {"Unified_Ideograph", "Ideographic"},
    29819: {"Unified_Ideograph", "Ideographic"},
    29820: {"Unified_Ideograph", "Ideographic"},
    29821: {"Unified_Ideograph", "Ideographic"},
    29822: {"Unified_Ideograph", "Ideographic"},
    29823: {"Unified_Ideograph", "Ideographic"},
    29824: {"Unified_Ideograph", "Ideographic"},
    29825: {"Unified_Ideograph", "Ideographic"},
    29826: {"Unified_Ideograph", "Ideographic"},
    29827: {"Unified_Ideograph", "Ideographic"},
    29828: {"Unified_Ideograph", "Ideographic"},
    29829: {"Unified_Ideograph", "Ideographic"},
    29830: {"Unified_Ideograph", "Ideographic"},
    29831: {"Unified_Ideograph", "Ideographic"},
    29832: {"Unified_Ideograph", "Ideographic"},
    29833: {"Unified_Ideograph", "Ideographic"},
    29834: {"Unified_Ideograph", "Ideographic"},
    29835: {"Unified_Ideograph", "Ideographic"},
    29836: {"Unified_Ideograph", "Ideographic"},
    29837: {"Unified_Ideograph", "Ideographic"},
    29838: {"Unified_Ideograph", "Ideographic"},
    29839: {"Unified_Ideograph", "Ideographic"},
    29840: {"Unified_Ideograph", "Ideographic"},
    29841: {"Unified_Ideograph", "Ideographic"},
    29842: {"Unified_Ideograph", "Ideographic"},
    29843: {"Unified_Ideograph", "Ideographic"},
    29844: {"Unified_Ideograph", "Ideographic"},
    29845: {"Unified_Ideograph", "Ideographic"},
    29846: {"Unified_Ideograph", "Ideographic"},
    29847: {"Unified_Ideograph", "Ideographic"},
    29848: {"Unified_Ideograph", "Ideographic"},
    29849: {"Unified_Ideograph", "Ideographic"},
    29850: {"Unified_Ideograph", "Ideographic"},
    29851: {"Unified_Ideograph", "Ideographic"},
    29852: {"Unified_Ideograph", "Ideographic"},
    29853: {"Unified_Ideograph", "Ideographic"},
    29854: {"Unified_Ideograph", "Ideographic"},
    29855: {"Unified_Ideograph", "Ideographic"},
    29856: {"Unified_Ideograph", "Ideographic"},
    29857: {"Unified_Ideograph", "Ideographic"},
    29858: {"Unified_Ideograph", "Ideographic"},
    29859: {"Unified_Ideograph", "Ideographic"},
    29860: {"Unified_Ideograph", "Ideographic"},
    29861: {"Unified_Ideograph", "Ideographic"},
    29862: {"Unified_Ideograph", "Ideographic"},
    29863: {"Unified_Ideograph", "Ideographic"},
    29864: {"Unified_Ideograph", "Ideographic"},
    29865: {"Unified_Ideograph", "Ideographic"},
    29866: {"Unified_Ideograph", "Ideographic"},
    29867: {"Unified_Ideograph", "Ideographic"},
    29868: {"Unified_Ideograph", "Ideographic"},
    29869: {"Unified_Ideograph", "Ideographic"},
    29870: {"Unified_Ideograph", "Ideographic"},
    29871: {"Unified_Ideograph", "Ideographic"},
    29872: {"Unified_Ideograph", "Ideographic"},
    29873: {"Unified_Ideograph", "Ideographic"},
    29874: {"Unified_Ideograph", "Ideographic"},
    29875: {"Unified_Ideograph", "Ideographic"},
    29876: {"Unified_Ideograph", "Ideographic"},
    29877: {"Unified_Ideograph", "Ideographic"},
    29878: {"Unified_Ideograph", "Ideographic"},
    29879: {"Unified_Ideograph", "Ideographic"},
    29880: {"Unified_Ideograph", "Ideographic"},
    29881: {"Unified_Ideograph", "Ideographic"},
    29882: {"Unified_Ideograph", "Ideographic"},
    29883: {"Unified_Ideograph", "Ideographic"},
    29884: {"Unified_Ideograph", "Ideographic"},
    29885: {"Unified_Ideograph", "Ideographic"},
    29886: {"Unified_Ideograph", "Ideographic"},
    29887: {"Unified_Ideograph", "Ideographic"},
    29888: {"Unified_Ideograph", "Ideographic"},
    29889: {"Unified_Ideograph", "Ideographic"},
    29890: {"Unified_Ideograph", "Ideographic"},
    29891: {"Unified_Ideograph", "Ideographic"},
    29892: {"Unified_Ideograph", "Ideographic"},
    29893: {"Unified_Ideograph", "Ideographic"},
    29894: {"Unified_Ideograph", "Ideographic"},
    29895: {"Unified_Ideograph", "Ideographic"},
    29896: {"Unified_Ideograph", "Ideographic"},
    29897: {"Unified_Ideograph", "Ideographic"},
    29898: {"Unified_Ideograph", "Ideographic"},
    29899: {"Unified_Ideograph", "Ideographic"},
    29900: {"Unified_Ideograph", "Ideographic"},
    29901: {"Unified_Ideograph", "Ideographic"},
    29902: {"Unified_Ideograph", "Ideographic"},
    29903: {"Unified_Ideograph", "Ideographic"},
    29904: {"Unified_Ideograph", "Ideographic"},
    29905: {"Unified_Ideograph", "Ideographic"},
    29906: {"Unified_Ideograph", "Ideographic"},
    29907: {"Unified_Ideograph", "Ideographic"},
    29908: {"Unified_Ideograph", "Ideographic"},
    29909: {"Unified_Ideograph", "Ideographic"},
    29910: {"Unified_Ideograph", "Ideographic"},
    29911: {"Unified_Ideograph", "Ideographic"},
    29912: {"Unified_Ideograph", "Ideographic"},
    29913: {"Unified_Ideograph", "Ideographic"},
    29914: {"Unified_Ideograph", "Ideographic"},
    29915: {"Unified_Ideograph", "Ideographic"},
    29916: {"Unified_Ideograph", "Ideographic"},
    29917: {"Unified_Ideograph", "Ideographic"},
    29918: {"Unified_Ideograph", "Ideographic"},
    29919: {"Unified_Ideograph", "Ideographic"},
    29920: {"Unified_Ideograph", "Ideographic"},
    29921: {"Unified_Ideograph", "Ideographic"},
    29922: {"Unified_Ideograph", "Ideographic"},
    29923: {"Unified_Ideograph", "Ideographic"},
    29924: {"Unified_Ideograph", "Ideographic"},
    29925: {"Unified_Ideograph", "Ideographic"},
    29926: {"Unified_Ideograph", "Ideographic"},
    29927: {"Unified_Ideograph", "Ideographic"},
    29928: {"Unified_Ideograph", "Ideographic"},
    29929: {"Unified_Ideograph", "Ideographic"},
    29930: {"Unified_Ideograph", "Ideographic"},
    29931: {"Unified_Ideograph", "Ideographic"},
    29932: {"Unified_Ideograph", "Ideographic"},
    29933: {"Unified_Ideograph", "Ideographic"},
    29934: {"Unified_Ideograph", "Ideographic"},
    29935: {"Unified_Ideograph", "Ideographic"},
    29936: {"Unified_Ideograph", "Ideographic"},
    29937: {"Unified_Ideograph", "Ideographic"},
    29938: {"Unified_Ideograph", "Ideographic"},
    29939: {"Unified_Ideograph", "Ideographic"},
    29940: {"Unified_Ideograph", "Ideographic"},
    29941: {"Unified_Ideograph", "Ideographic"},
    29942: {"Unified_Ideograph", "Ideographic"},
    29943: {"Unified_Ideograph", "Ideographic"},
    29944: {"Unified_Ideograph", "Ideographic"},
    29945: {"Unified_Ideograph", "Ideographic"},
    29946: {"Unified_Ideograph", "Ideographic"},
    29947: {"Unified_Ideograph", "Ideographic"},
    29948: {"Unified_Ideograph", "Ideographic"},
    29949: {"Unified_Ideograph", "Ideographic"},
    29950: {"Unified_Ideograph", "Ideographic"},
    29951: {"Unified_Ideograph", "Ideographic"},
    29952: {"Unified_Ideograph", "Ideographic"},
    29953: {"Unified_Ideograph", "Ideographic"},
    29954: {"Unified_Ideograph", "Ideographic"},
    29955: {"Unified_Ideograph", "Ideographic"},
    29956: {"Unified_Ideograph", "Ideographic"},
    29957: {"Unified_Ideograph", "Ideographic"},
    29958: {"Unified_Ideograph", "Ideographic"},
    29959: {"Unified_Ideograph", "Ideographic"},
    29960: {"Unified_Ideograph", "Ideographic"},
    29961: {"Unified_Ideograph", "Ideographic"},
    29962: {"Unified_Ideograph", "Ideographic"},
    29963: {"Unified_Ideograph", "Ideographic"},
    29964: {"Unified_Ideograph", "Ideographic"},
    29965: {"Unified_Ideograph", "Ideographic"},
    29966: {"Unified_Ideograph", "Ideographic"},
    29967: {"Unified_Ideograph", "Ideographic"},
    29968: {"Unified_Ideograph", "Ideographic"},
    29969: {"Unified_Ideograph", "Ideographic"},
    29970: {"Unified_Ideograph", "Ideographic"},
    29971: {"Unified_Ideograph", "Ideographic"},
    29972: {"Unified_Ideograph", "Ideographic"},
    29973: {"Unified_Ideograph", "Ideographic"},
    29974: {"Unified_Ideograph", "Ideographic"},
    29975: {"Unified_Ideograph", "Ideographic"},
    29976: {"Unified_Ideograph", "Ideographic"},
    29977: {"Unified_Ideograph", "Ideographic"},
    29978: {"Unified_Ideograph", "Ideographic"},
    29979: {"Unified_Ideograph", "Ideographic"},
    29980: {"Unified_Ideograph", "Ideographic"},
    29981: {"Unified_Ideograph", "Ideographic"},
    29982: {"Unified_Ideograph", "Ideographic"},
    29983: {"Unified_Ideograph", "Ideographic"},
    29984: {"Unified_Ideograph", "Ideographic"},
    29985: {"Unified_Ideograph", "Ideographic"},
    29986: {"Unified_Ideograph", "Ideographic"},
    29987: {"Unified_Ideograph", "Ideographic"},
    29988: {"Unified_Ideograph", "Ideographic"},
    29989: {"Unified_Ideograph", "Ideographic"},
    29990: {"Unified_Ideograph", "Ideographic"},
    29991: {"Unified_Ideograph", "Ideographic"},
    29992: {"Unified_Ideograph", "Ideographic"},
    29993: {"Unified_Ideograph", "Ideographic"},
    29994: {"Unified_Ideograph", "Ideographic"},
    29995: {"Unified_Ideograph", "Ideographic"},
    29996: {"Unified_Ideograph", "Ideographic"},
    29997: {"Unified_Ideograph", "Ideographic"},
    29998: {"Unified_Ideograph", "Ideographic"},
    29999: {"Unified_Ideograph", "Ideographic"},
    30000: {"Unified_Ideograph", "Ideographic"},
    30001: {"Unified_Ideograph", "Ideographic"},
    30002: {"Unified_Ideograph", "Ideographic"},
    30003: {"Unified_Ideograph", "Ideographic"},
    30004: {"Unified_Ideograph", "Ideographic"},
    30005: {"Unified_Ideograph", "Ideographic"},
    30006: {"Unified_Ideograph", "Ideographic"},
    30007: {"Unified_Ideograph", "Ideographic"},
    30008: {"Unified_Ideograph", "Ideographic"},
    30009: {"Unified_Ideograph", "Ideographic"},
    30010: {"Unified_Ideograph", "Ideographic"},
    30011: {"Unified_Ideograph", "Ideographic"},
    30012: {"Unified_Ideograph", "Ideographic"},
    30013: {"Unified_Ideograph", "Ideographic"},
    30014: {"Unified_Ideograph", "Ideographic"},
    30015: {"Unified_Ideograph", "Ideographic"},
    30016: {"Unified_Ideograph", "Ideographic"},
    30017: {"Unified_Ideograph", "Ideographic"},
    30018: {"Unified_Ideograph", "Ideographic"},
    30019: {"Unified_Ideograph", "Ideographic"},
    30020: {"Unified_Ideograph", "Ideographic"},
    30021: {"Unified_Ideograph", "Ideographic"},
    30022: {"Unified_Ideograph", "Ideographic"},
    30023: {"Unified_Ideograph", "Ideographic"},
    30024: {"Unified_Ideograph", "Ideographic"},
    30025: {"Unified_Ideograph", "Ideographic"},
    30026: {"Unified_Ideograph", "Ideographic"},
    30027: {"Unified_Ideograph", "Ideographic"},
    30028: {"Unified_Ideograph", "Ideographic"},
    30029: {"Unified_Ideograph", "Ideographic"},
    30030: {"Unified_Ideograph", "Ideographic"},
    30031: {"Unified_Ideograph", "Ideographic"},
    30032: {"Unified_Ideograph", "Ideographic"},
    30033: {"Unified_Ideograph", "Ideographic"},
    30034: {"Unified_Ideograph", "Ideographic"},
    30035: {"Unified_Ideograph", "Ideographic"},
    30036: {"Unified_Ideograph", "Ideographic"},
    30037: {"Unified_Ideograph", "Ideographic"},
    30038: {"Unified_Ideograph", "Ideographic"},
    30039: {"Unified_Ideograph", "Ideographic"},
    30040: {"Unified_Ideograph", "Ideographic"},
    30041: {"Unified_Ideograph", "Ideographic"},
    30042: {"Unified_Ideograph", "Ideographic"},
    30043: {"Unified_Ideograph", "Ideographic"},
    30044: {"Unified_Ideograph", "Ideographic"},
    30045: {"Unified_Ideograph", "Ideographic"},
    30046: {"Unified_Ideograph", "Ideographic"},
    30047: {"Unified_Ideograph", "Ideographic"},
    30048: {"Unified_Ideograph", "Ideographic"},
    30049: {"Unified_Ideograph", "Ideographic"},
    30050: {"Unified_Ideograph", "Ideographic"},
    30051: {"Unified_Ideograph", "Ideographic"},
    30052: {"Unified_Ideograph", "Ideographic"},
    30053: {"Unified_Ideograph", "Ideographic"},
    30054: {"Unified_Ideograph", "Ideographic"},
    30055: {"Unified_Ideograph", "Ideographic"},
    30056: {"Unified_Ideograph", "Ideographic"},
    30057: {"Unified_Ideograph", "Ideographic"},
    30058: {"Unified_Ideograph", "Ideographic"},
    30059: {"Unified_Ideograph", "Ideographic"},
    30060: {"Unified_Ideograph", "Ideographic"},
    30061: {"Unified_Ideograph", "Ideographic"},
    30062: {"Unified_Ideograph", "Ideographic"},
    30063: {"Unified_Ideograph", "Ideographic"},
    30064: {"Unified_Ideograph", "Ideographic"},
    30065: {"Unified_Ideograph", "Ideographic"},
    30066: {"Unified_Ideograph", "Ideographic"},
    30067: {"Unified_Ideograph", "Ideographic"},
    30068: {"Unified_Ideograph", "Ideographic"},
    30069: {"Unified_Ideograph", "Ideographic"},
    30070: {"Unified_Ideograph", "Ideographic"},
    30071: {"Unified_Ideograph", "Ideographic"},
    30072: {"Unified_Ideograph", "Ideographic"},
    30073: {"Unified_Ideograph", "Ideographic"},
    30074: {"Unified_Ideograph", "Ideographic"},
    30075: {"Unified_Ideograph", "Ideographic"},
    30076: {"Unified_Ideograph", "Ideographic"},
    30077: {"Unified_Ideograph", "Ideographic"},
    30078: {"Unified_Ideograph", "Ideographic"},
    30079: {"Unified_Ideograph", "Ideographic"},
    30080: {"Unified_Ideograph", "Ideographic"},
    30081: {"Unified_Ideograph", "Ideographic"},
    30082: {"Unified_Ideograph", "Ideographic"},
    30083: {"Unified_Ideograph", "Ideographic"},
    30084: {"Unified_Ideograph", "Ideographic"},
    30085: {"Unified_Ideograph", "Ideographic"},
    30086: {"Unified_Ideograph", "Ideographic"},
    30087: {"Unified_Ideograph", "Ideographic"},
    30088: {"Unified_Ideograph", "Ideographic"},
    30089: {"Unified_Ideograph", "Ideographic"},
    30090: {"Unified_Ideograph", "Ideographic"},
    30091: {"Unified_Ideograph", "Ideographic"},
    30092: {"Unified_Ideograph", "Ideographic"},
    30093: {"Unified_Ideograph", "Ideographic"},
    30094: {"Unified_Ideograph", "Ideographic"},
    30095: {"Unified_Ideograph", "Ideographic"},
    30096: {"Unified_Ideograph", "Ideographic"},
    30097: {"Unified_Ideograph", "Ideographic"},
    30098: {"Unified_Ideograph", "Ideographic"},
    30099: {"Unified_Ideograph", "Ideographic"},
    30100: {"Unified_Ideograph", "Ideographic"},
    30101: {"Unified_Ideograph", "Ideographic"},
    30102: {"Unified_Ideograph", "Ideographic"},
    30103: {"Unified_Ideograph", "Ideographic"},
    30104: {"Unified_Ideograph", "Ideographic"},
    30105: {"Unified_Ideograph", "Ideographic"},
    30106: {"Unified_Ideograph", "Ideographic"},
    30107: {"Unified_Ideograph", "Ideographic"},
    30108: {"Unified_Ideograph", "Ideographic"},
    30109: {"Unified_Ideograph", "Ideographic"},
    30110: {"Unified_Ideograph", "Ideographic"},
    30111: {"Unified_Ideograph", "Ideographic"},
    30112: {"Unified_Ideograph", "Ideographic"},
    30113: {"Unified_Ideograph", "Ideographic"},
    30114: {"Unified_Ideograph", "Ideographic"},
    30115: {"Unified_Ideograph", "Ideographic"},
    30116: {"Unified_Ideograph", "Ideographic"},
    30117: {"Unified_Ideograph", "Ideographic"},
    30118: {"Unified_Ideograph", "Ideographic"},
    30119: {"Unified_Ideograph", "Ideographic"},
    30120: {"Unified_Ideograph", "Ideographic"},
    30121: {"Unified_Ideograph", "Ideographic"},
    30122: {"Unified_Ideograph", "Ideographic"},
    30123: {"Unified_Ideograph", "Ideographic"},
    30124: {"Unified_Ideograph", "Ideographic"},
    30125: {"Unified_Ideograph", "Ideographic"},
    30126: {"Unified_Ideograph", "Ideographic"},
    30127: {"Unified_Ideograph", "Ideographic"},
    30128: {"Unified_Ideograph", "Ideographic"},
    30129: {"Unified_Ideograph", "Ideographic"},
    30130: {"Unified_Ideograph", "Ideographic"},
    30131: {"Unified_Ideograph", "Ideographic"},
    30132: {"Unified_Ideograph", "Ideographic"},
    30133: {"Unified_Ideograph", "Ideographic"},
    30134: {"Unified_Ideograph", "Ideographic"},
    30135: {"Unified_Ideograph", "Ideographic"},
    30136: {"Unified_Ideograph", "Ideographic"},
    30137: {"Unified_Ideograph", "Ideographic"},
    30138: {"Unified_Ideograph", "Ideographic"},
    30139: {"Unified_Ideograph", "Ideographic"},
    30140: {"Unified_Ideograph", "Ideographic"},
    30141: {"Unified_Ideograph", "Ideographic"},
    30142: {"Unified_Ideograph", "Ideographic"},
    30143: {"Unified_Ideograph", "Ideographic"},
    30144: {"Unified_Ideograph", "Ideographic"},
    30145: {"Unified_Ideograph", "Ideographic"},
    30146: {"Unified_Ideograph", "Ideographic"},
    30147: {"Unified_Ideograph", "Ideographic"},
    30148: {"Unified_Ideograph", "Ideographic"},
    30149: {"Unified_Ideograph", "Ideographic"},
    30150: {"Unified_Ideograph", "Ideographic"},
    30151: {"Unified_Ideograph", "Ideographic"},
    30152: {"Unified_Ideograph", "Ideographic"},
    30153: {"Unified_Ideograph", "Ideographic"},
    30154: {"Unified_Ideograph", "Ideographic"},
    30155: {"Unified_Ideograph", "Ideographic"},
    30156: {"Unified_Ideograph", "Ideographic"},
    30157: {"Unified_Ideograph", "Ideographic"},
    30158: {"Unified_Ideograph", "Ideographic"},
    30159: {"Unified_Ideograph", "Ideographic"},
    30160: {"Unified_Ideograph", "Ideographic"},
    30161: {"Unified_Ideograph", "Ideographic"},
    30162: {"Unified_Ideograph", "Ideographic"},
    30163: {"Unified_Ideograph", "Ideographic"},
    30164: {"Unified_Ideograph", "Ideographic"},
    30165: {"Unified_Ideograph", "Ideographic"},
    30166: {"Unified_Ideograph", "Ideographic"},
    30167: {"Unified_Ideograph", "Ideographic"},
    30168: {"Unified_Ideograph", "Ideographic"},
    30169: {"Unified_Ideograph", "Ideographic"},
    30170: {"Unified_Ideograph", "Ideographic"},
    30171: {"Unified_Ideograph", "Ideographic"},
    30172: {"Unified_Ideograph", "Ideographic"},
    30173: {"Unified_Ideograph", "Ideographic"},
    30174: {"Unified_Ideograph", "Ideographic"},
    30175: {"Unified_Ideograph", "Ideographic"},
    30176: {"Unified_Ideograph", "Ideographic"},
    30177: {"Unified_Ideograph", "Ideographic"},
    30178: {"Unified_Ideograph", "Ideographic"},
    30179: {"Unified_Ideograph", "Ideographic"},
    30180: {"Unified_Ideograph", "Ideographic"},
    30181: {"Unified_Ideograph", "Ideographic"},
    30182: {"Unified_Ideograph", "Ideographic"},
    30183: {"Unified_Ideograph", "Ideographic"},
    30184: {"Unified_Ideograph", "Ideographic"},
    30185: {"Unified_Ideograph", "Ideographic"},
    30186: {"Unified_Ideograph", "Ideographic"},
    30187: {"Unified_Ideograph", "Ideographic"},
    30188: {"Unified_Ideograph", "Ideographic"},
    30189: {"Unified_Ideograph", "Ideographic"},
    30190: {"Unified_Ideograph", "Ideographic"},
    30191: {"Unified_Ideograph", "Ideographic"},
    30192: {"Unified_Ideograph", "Ideographic"},
    30193: {"Unified_Ideograph", "Ideographic"},
    30194: {"Unified_Ideograph", "Ideographic"},
    30195: {"Unified_Ideograph", "Ideographic"},
    30196: {"Unified_Ideograph", "Ideographic"},
    30197: {"Unified_Ideograph", "Ideographic"},
    30198: {"Unified_Ideograph", "Ideographic"},
    30199: {"Unified_Ideograph", "Ideographic"},
    30200: {"Unified_Ideograph", "Ideographic"},
    30201: {"Unified_Ideograph", "Ideographic"},
    30202: {"Unified_Ideograph", "Ideographic"},
    30203: {"Unified_Ideograph", "Ideographic"},
    30204: {"Unified_Ideograph", "Ideographic"},
    30205: {"Unified_Ideograph", "Ideographic"},
    30206: {"Unified_Ideograph", "Ideographic"},
    30207: {"Unified_Ideograph", "Ideographic"},
    30208: {"Unified_Ideograph", "Ideographic"},
    30209: {"Unified_Ideograph", "Ideographic"},
    30210: {"Unified_Ideograph", "Ideographic"},
    30211: {"Unified_Ideograph", "Ideographic"},
    30212: {"Unified_Ideograph", "Ideographic"},
    30213: {"Unified_Ideograph", "Ideographic"},
    30214: {"Unified_Ideograph", "Ideographic"},
    30215: {"Unified_Ideograph", "Ideographic"},
    30216: {"Unified_Ideograph", "Ideographic"},
    30217: {"Unified_Ideograph", "Ideographic"},
    30218: {"Unified_Ideograph", "Ideographic"},
    30219: {"Unified_Ideograph", "Ideographic"},
    30220: {"Unified_Ideograph", "Ideographic"},
    30221: {"Unified_Ideograph", "Ideographic"},
    30222: {"Unified_Ideograph", "Ideographic"},
    30223: {"Unified_Ideograph", "Ideographic"},
    30224: {"Unified_Ideograph", "Ideographic"},
    30225: {"Unified_Ideograph", "Ideographic"},
    30226: {"Unified_Ideograph", "Ideographic"},
    30227: {"Unified_Ideograph", "Ideographic"},
    30228: {"Unified_Ideograph", "Ideographic"},
    30229: {"Unified_Ideograph", "Ideographic"},
    30230: {"Unified_Ideograph", "Ideographic"},
    30231: {"Unified_Ideograph", "Ideographic"},
    30232: {"Unified_Ideograph", "Ideographic"},
    30233: {"Unified_Ideograph", "Ideographic"},
    30234: {"Unified_Ideograph", "Ideographic"},
    30235: {"Unified_Ideograph", "Ideographic"},
    30236: {"Unified_Ideograph", "Ideographic"},
    30237: {"Unified_Ideograph", "Ideographic"},
    30238: {"Unified_Ideograph", "Ideographic"},
    30239: {"Unified_Ideograph", "Ideographic"},
    30240: {"Unified_Ideograph", "Ideographic"},
    30241: {"Unified_Ideograph", "Ideographic"},
    30242: {"Unified_Ideograph", "Ideographic"},
    30243: {"Unified_Ideograph", "Ideographic"},
    30244: {"Unified_Ideograph", "Ideographic"},
    30245: {"Unified_Ideograph", "Ideographic"},
    30246: {"Unified_Ideograph", "Ideographic"},
    30247: {"Unified_Ideograph", "Ideographic"},
    30248: {"Unified_Ideograph", "Ideographic"},
    30249: {"Unified_Ideograph", "Ideographic"},
    30250: {"Unified_Ideograph", "Ideographic"},
    30251: {"Unified_Ideograph", "Ideographic"},
    30252: {"Unified_Ideograph", "Ideographic"},
    30253: {"Unified_Ideograph", "Ideographic"},
    30254: {"Unified_Ideograph", "Ideographic"},
    30255: {"Unified_Ideograph", "Ideographic"},
    30256: {"Unified_Ideograph", "Ideographic"},
    30257: {"Unified_Ideograph", "Ideographic"},
    30258: {"Unified_Ideograph", "Ideographic"},
    30259: {"Unified_Ideograph", "Ideographic"},
    30260: {"Unified_Ideograph", "Ideographic"},
    30261: {"Unified_Ideograph", "Ideographic"},
    30262: {"Unified_Ideograph", "Ideographic"},
    30263: {"Unified_Ideograph", "Ideographic"},
    30264: {"Unified_Ideograph", "Ideographic"},
    30265: {"Unified_Ideograph", "Ideographic"},
    30266: {"Unified_Ideograph", "Ideographic"},
    30267: {"Unified_Ideograph", "Ideographic"},
    30268: {"Unified_Ideograph", "Ideographic"},
    30269: {"Unified_Ideograph", "Ideographic"},
    30270: {"Unified_Ideograph", "Ideographic"},
    30271: {"Unified_Ideograph", "Ideographic"},
    30272: {"Unified_Ideograph", "Ideographic"},
    30273: {"Unified_Ideograph", "Ideographic"},
    30274: {"Unified_Ideograph", "Ideographic"},
    30275: {"Unified_Ideograph", "Ideographic"},
    30276: {"Unified_Ideograph", "Ideographic"},
    30277: {"Unified_Ideograph", "Ideographic"},
    30278: {"Unified_Ideograph", "Ideographic"},
    30279: {"Unified_Ideograph", "Ideographic"},
    30280: {"Unified_Ideograph", "Ideographic"},
    30281: {"Unified_Ideograph", "Ideographic"},
    30282: {"Unified_Ideograph", "Ideographic"},
    30283: {"Unified_Ideograph", "Ideographic"},
    30284: {"Unified_Ideograph", "Ideographic"},
    30285: {"Unified_Ideograph", "Ideographic"},
    30286: {"Unified_Ideograph", "Ideographic"},
    30287: {"Unified_Ideograph", "Ideographic"},
    30288: {"Unified_Ideograph", "Ideographic"},
    30289: {"Unified_Ideograph", "Ideographic"},
    30290: {"Unified_Ideograph", "Ideographic"},
    30291: {"Unified_Ideograph", "Ideographic"},
    30292: {"Unified_Ideograph", "Ideographic"},
    30293: {"Unified_Ideograph", "Ideographic"},
    30294: {"Unified_Ideograph", "Ideographic"},
    30295: {"Unified_Ideograph", "Ideographic"},
    30296: {"Unified_Ideograph", "Ideographic"},
    30297: {"Unified_Ideograph", "Ideographic"},
    30298: {"Unified_Ideograph", "Ideographic"},
    30299: {"Unified_Ideograph", "Ideographic"},
    30300: {"Unified_Ideograph", "Ideographic"},
    30301: {"Unified_Ideograph", "Ideographic"},
    30302: {"Unified_Ideograph", "Ideographic"},
    30303: {"Unified_Ideograph", "Ideographic"},
    30304: {"Unified_Ideograph", "Ideographic"},
    30305: {"Unified_Ideograph", "Ideographic"},
    30306: {"Unified_Ideograph", "Ideographic"},
    30307: {"Unified_Ideograph", "Ideographic"},
    30308: {"Unified_Ideograph", "Ideographic"},
    30309: {"Unified_Ideograph", "Ideographic"},
    30310: {"Unified_Ideograph", "Ideographic"},
    30311: {"Unified_Ideograph", "Ideographic"},
    30312: {"Unified_Ideograph", "Ideographic"},
    30313: {"Unified_Ideograph", "Ideographic"},
    30314: {"Unified_Ideograph", "Ideographic"},
    30315: {"Unified_Ideograph", "Ideographic"},
    30316: {"Unified_Ideograph", "Ideographic"},
    30317: {"Unified_Ideograph", "Ideographic"},
    30318: {"Unified_Ideograph", "Ideographic"},
    30319: {"Unified_Ideograph", "Ideographic"},
    30320: {"Unified_Ideograph", "Ideographic"},
    30321: {"Unified_Ideograph", "Ideographic"},
    30322: {"Unified_Ideograph", "Ideographic"},
    30323: {"Unified_Ideograph", "Ideographic"},
    30324: {"Unified_Ideograph", "Ideographic"},
    30325: {"Unified_Ideograph", "Ideographic"},
    30326: {"Unified_Ideograph", "Ideographic"},
    30327: {"Unified_Ideograph", "Ideographic"},
    30328: {"Unified_Ideograph", "Ideographic"},
    30329: {"Unified_Ideograph", "Ideographic"},
    30330: {"Unified_Ideograph", "Ideographic"},
    30331: {"Unified_Ideograph", "Ideographic"},
    30332: {"Unified_Ideograph", "Ideographic"},
    30333: {"Unified_Ideograph", "Ideographic"},
    30334: {"Unified_Ideograph", "Ideographic"},
    30335: {"Unified_Ideograph", "Ideographic"},
    30336: {"Unified_Ideograph", "Ideographic"},
    30337: {"Unified_Ideograph", "Ideographic"},
    30338: {"Unified_Ideograph", "Ideographic"},
    30339: {"Unified_Ideograph", "Ideographic"},
    30340: {"Unified_Ideograph", "Ideographic"},
    30341: {"Unified_Ideograph", "Ideographic"},
    30342: {"Unified_Ideograph", "Ideographic"},
    30343: {"Unified_Ideograph", "Ideographic"},
    30344: {"Unified_Ideograph", "Ideographic"},
    30345: {"Unified_Ideograph", "Ideographic"},
    30346: {"Unified_Ideograph", "Ideographic"},
    30347: {"Unified_Ideograph", "Ideographic"},
    30348: {"Unified_Ideograph", "Ideographic"},
    30349: {"Unified_Ideograph", "Ideographic"},
    30350: {"Unified_Ideograph", "Ideographic"},
    30351: {"Unified_Ideograph", "Ideographic"},
    30352: {"Unified_Ideograph", "Ideographic"},
    30353: {"Unified_Ideograph", "Ideographic"},
    30354: {"Unified_Ideograph", "Ideographic"},
    30355: {"Unified_Ideograph", "Ideographic"},
    30356: {"Unified_Ideograph", "Ideographic"},
    30357: {"Unified_Ideograph", "Ideographic"},
    30358: {"Unified_Ideograph", "Ideographic"},
    30359: {"Unified_Ideograph", "Ideographic"},
    30360: {"Unified_Ideograph", "Ideographic"},
    30361: {"Unified_Ideograph", "Ideographic"},
    30362: {"Unified_Ideograph", "Ideographic"},
    30363: {"Unified_Ideograph", "Ideographic"},
    30364: {"Unified_Ideograph", "Ideographic"},
    30365: {"Unified_Ideograph", "Ideographic"},
    30366: {"Unified_Ideograph", "Ideographic"},
    30367: {"Unified_Ideograph", "Ideographic"},
    30368: {"Unified_Ideograph", "Ideographic"},
    30369: {"Unified_Ideograph", "Ideographic"},
    30370: {"Unified_Ideograph", "Ideographic"},
    30371: {"Unified_Ideograph", "Ideographic"},
    30372: {"Unified_Ideograph", "Ideographic"},
    30373: {"Unified_Ideograph", "Ideographic"},
    30374: {"Unified_Ideograph", "Ideographic"},
    30375: {"Unified_Ideograph", "Ideographic"},
    30376: {"Unified_Ideograph", "Ideographic"},
    30377: {"Unified_Ideograph", "Ideographic"},
    30378: {"Unified_Ideograph", "Ideographic"},
    30379: {"Unified_Ideograph", "Ideographic"},
    30380: {"Unified_Ideograph", "Ideographic"},
    30381: {"Unified_Ideograph", "Ideographic"},
    30382: {"Unified_Ideograph", "Ideographic"},
    30383: {"Unified_Ideograph", "Ideographic"},
    30384: {"Unified_Ideograph", "Ideographic"},
    30385: {"Unified_Ideograph", "Ideographic"},
    30386: {"Unified_Ideograph", "Ideographic"},
    30387: {"Unified_Ideograph", "Ideographic"},
    30388: {"Unified_Ideograph", "Ideographic"},
    30389: {"Unified_Ideograph", "Ideographic"},
    30390: {"Unified_Ideograph", "Ideographic"},
    30391: {"Unified_Ideograph", "Ideographic"},
    30392: {"Unified_Ideograph", "Ideographic"},
    30393: {"Unified_Ideograph", "Ideographic"},
    30394: {"Unified_Ideograph", "Ideographic"},
    30395: {"Unified_Ideograph", "Ideographic"},
    30396: {"Unified_Ideograph", "Ideographic"},
    30397: {"Unified_Ideograph", "Ideographic"},
    30398: {"Unified_Ideograph", "Ideographic"},
    30399: {"Unified_Ideograph", "Ideographic"},
    30400: {"Unified_Ideograph", "Ideographic"},
    30401: {"Unified_Ideograph", "Ideographic"},
    30402: {"Unified_Ideograph", "Ideographic"},
    30403: {"Unified_Ideograph", "Ideographic"},
    30404: {"Unified_Ideograph", "Ideographic"},
    30405: {"Unified_Ideograph", "Ideographic"},
    30406: {"Unified_Ideograph", "Ideographic"},
    30407: {"Unified_Ideograph", "Ideographic"},
    30408: {"Unified_Ideograph", "Ideographic"},
    30409: {"Unified_Ideograph", "Ideographic"},
    30410: {"Unified_Ideograph", "Ideographic"},
    30411: {"Unified_Ideograph", "Ideographic"},
    30412: {"Unified_Ideograph", "Ideographic"},
    30413: {"Unified_Ideograph", "Ideographic"},
    30414: {"Unified_Ideograph", "Ideographic"},
    30415: {"Unified_Ideograph", "Ideographic"},
    30416: {"Unified_Ideograph", "Ideographic"},
    30417: {"Unified_Ideograph", "Ideographic"},
    30418: {"Unified_Ideograph", "Ideographic"},
    30419: {"Unified_Ideograph", "Ideographic"},
    30420: {"Unified_Ideograph", "Ideographic"},
    30421: {"Unified_Ideograph", "Ideographic"},
    30422: {"Unified_Ideograph", "Ideographic"},
    30423: {"Unified_Ideograph", "Ideographic"},
    30424: {"Unified_Ideograph", "Ideographic"},
    30425: {"Unified_Ideograph", "Ideographic"},
    30426: {"Unified_Ideograph", "Ideographic"},
    30427: {"Unified_Ideograph", "Ideographic"},
    30428: {"Unified_Ideograph", "Ideographic"},
    30429: {"Unified_Ideograph", "Ideographic"},
    30430: {"Unified_Ideograph", "Ideographic"},
    30431: {"Unified_Ideograph", "Ideographic"},
    30432: {"Unified_Ideograph", "Ideographic"},
    30433: {"Unified_Ideograph", "Ideographic"},
    30434: {"Unified_Ideograph", "Ideographic"},
    30435: {"Unified_Ideograph", "Ideographic"},
    30436: {"Unified_Ideograph", "Ideographic"},
    30437: {"Unified_Ideograph", "Ideographic"},
    30438: {"Unified_Ideograph", "Ideographic"},
    30439: {"Unified_Ideograph", "Ideographic"},
    30440: {"Unified_Ideograph", "Ideographic"},
    30441: {"Unified_Ideograph", "Ideographic"},
    30442: {"Unified_Ideograph", "Ideographic"},
    30443: {"Unified_Ideograph", "Ideographic"},
    30444: {"Unified_Ideograph", "Ideographic"},
    30445: {"Unified_Ideograph", "Ideographic"},
    30446: {"Unified_Ideograph", "Ideographic"},
    30447: {"Unified_Ideograph", "Ideographic"},
    30448: {"Unified_Ideograph", "Ideographic"},
    30449: {"Unified_Ideograph", "Ideographic"},
    30450: {"Unified_Ideograph", "Ideographic"},
    30451: {"Unified_Ideograph", "Ideographic"},
    30452: {"Unified_Ideograph", "Ideographic"},
    30453: {"Unified_Ideograph", "Ideographic"},
    30454: {"Unified_Ideograph", "Ideographic"},
    30455: {"Unified_Ideograph", "Ideographic"},
    30456: {"Unified_Ideograph", "Ideographic"},
    30457: {"Unified_Ideograph", "Ideographic"},
    30458: {"Unified_Ideograph", "Ideographic"},
    30459: {"Unified_Ideograph", "Ideographic"},
    30460: {"Unified_Ideograph", "Ideographic"},
    30461: {"Unified_Ideograph", "Ideographic"},
    30462: {"Unified_Ideograph", "Ideographic"},
    30463: {"Unified_Ideograph", "Ideographic"},
    30464: {"Unified_Ideograph", "Ideographic"},
    30465: {"Unified_Ideograph", "Ideographic"},
    30466: {"Unified_Ideograph", "Ideographic"},
    30467: {"Unified_Ideograph", "Ideographic"},
    30468: {"Unified_Ideograph", "Ideographic"},
    30469: {"Unified_Ideograph", "Ideographic"},
    30470: {"Unified_Ideograph", "Ideographic"},
    30471: {"Unified_Ideograph", "Ideographic"},
    30472: {"Unified_Ideograph", "Ideographic"},
    30473: {"Unified_Ideograph", "Ideographic"},
    30474: {"Unified_Ideograph", "Ideographic"},
    30475: {"Unified_Ideograph", "Ideographic"},
    30476: {"Unified_Ideograph", "Ideographic"},
    30477: {"Unified_Ideograph", "Ideographic"},
    30478: {"Unified_Ideograph", "Ideographic"},
    30479: {"Unified_Ideograph", "Ideographic"},
    30480: {"Unified_Ideograph", "Ideographic"},
    30481: {"Unified_Ideograph", "Ideographic"},
    30482: {"Unified_Ideograph", "Ideographic"},
    30483: {"Unified_Ideograph", "Ideographic"},
    30484: {"Unified_Ideograph", "Ideographic"},
    30485: {"Unified_Ideograph", "Ideographic"},
    30486: {"Unified_Ideograph", "Ideographic"},
    30487: {"Unified_Ideograph", "Ideographic"},
    30488: {"Unified_Ideograph", "Ideographic"},
    30489: {"Unified_Ideograph", "Ideographic"},
    30490: {"Unified_Ideograph", "Ideographic"},
    30491: {"Unified_Ideograph", "Ideographic"},
    30492: {"Unified_Ideograph", "Ideographic"},
    30493: {"Unified_Ideograph", "Ideographic"},
    30494: {"Unified_Ideograph", "Ideographic"},
    30495: {"Unified_Ideograph", "Ideographic"},
    30496: {"Unified_Ideograph", "Ideographic"},
    30497: {"Unified_Ideograph", "Ideographic"},
    30498: {"Unified_Ideograph", "Ideographic"},
    30499: {"Unified_Ideograph", "Ideographic"},
    30500: {"Unified_Ideograph", "Ideographic"},
    30501: {"Unified_Ideograph", "Ideographic"},
    30502: {"Unified_Ideograph", "Ideographic"},
    30503: {"Unified_Ideograph", "Ideographic"},
    30504: {"Unified_Ideograph", "Ideographic"},
    30505: {"Unified_Ideograph", "Ideographic"},
    30506: {"Unified_Ideograph", "Ideographic"},
    30507: {"Unified_Ideograph", "Ideographic"},
    30508: {"Unified_Ideograph", "Ideographic"},
    30509: {"Unified_Ideograph", "Ideographic"},
    30510: {"Unified_Ideograph", "Ideographic"},
    30511: {"Unified_Ideograph", "Ideographic"},
    30512: {"Unified_Ideograph", "Ideographic"},
    30513: {"Unified_Ideograph", "Ideographic"},
    30514: {"Unified_Ideograph", "Ideographic"},
    30515: {"Unified_Ideograph", "Ideographic"},
    30516: {"Unified_Ideograph", "Ideographic"},
    30517: {"Unified_Ideograph", "Ideographic"},
    30518: {"Unified_Ideograph", "Ideographic"},
    30519: {"Unified_Ideograph", "Ideographic"},
    30520: {"Unified_Ideograph", "Ideographic"},
    30521: {"Unified_Ideograph", "Ideographic"},
    30522: {"Unified_Ideograph", "Ideographic"},
    30523: {"Unified_Ideograph", "Ideographic"},
    30524: {"Unified_Ideograph", "Ideographic"},
    30525: {"Unified_Ideograph", "Ideographic"},
    30526: {"Unified_Ideograph", "Ideographic"},
    30527: {"Unified_Ideograph", "Ideographic"},
    30528: {"Unified_Ideograph", "Ideographic"},
    30529: {"Unified_Ideograph", "Ideographic"},
    30530: {"Unified_Ideograph", "Ideographic"},
    30531: {"Unified_Ideograph", "Ideographic"},
    30532: {"Unified_Ideograph", "Ideographic"},
    30533: {"Unified_Ideograph", "Ideographic"},
    30534: {"Unified_Ideograph", "Ideographic"},
    30535: {"Unified_Ideograph", "Ideographic"},
    30536: {"Unified_Ideograph", "Ideographic"},
    30537: {"Unified_Ideograph", "Ideographic"},
    30538: {"Unified_Ideograph", "Ideographic"},
    30539: {"Unified_Ideograph", "Ideographic"},
    30540: {"Unified_Ideograph", "Ideographic"},
    30541: {"Unified_Ideograph", "Ideographic"},
    30542: {"Unified_Ideograph", "Ideographic"},
    30543: {"Unified_Ideograph", "Ideographic"},
    30544: {"Unified_Ideograph", "Ideographic"},
    30545: {"Unified_Ideograph", "Ideographic"},
    30546: {"Unified_Ideograph", "Ideographic"},
    30547: {"Unified_Ideograph", "Ideographic"},
    30548: {"Unified_Ideograph", "Ideographic"},
    30549: {"Unified_Ideograph", "Ideographic"},
    30550: {"Unified_Ideograph", "Ideographic"},
    30551: {"Unified_Ideograph", "Ideographic"},
    30552: {"Unified_Ideograph", "Ideographic"},
    30553: {"Unified_Ideograph", "Ideographic"},
    30554: {"Unified_Ideograph", "Ideographic"},
    30555: {"Unified_Ideograph", "Ideographic"},
    30556: {"Unified_Ideograph", "Ideographic"},
    30557: {"Unified_Ideograph", "Ideographic"},
    30558: {"Unified_Ideograph", "Ideographic"},
    30559: {"Unified_Ideograph", "Ideographic"},
    30560: {"Unified_Ideograph", "Ideographic"},
    30561: {"Unified_Ideograph", "Ideographic"},
    30562: {"Unified_Ideograph", "Ideographic"},
    30563: {"Unified_Ideograph", "Ideographic"},
    30564: {"Unified_Ideograph", "Ideographic"},
    30565: {"Unified_Ideograph", "Ideographic"},
    30566: {"Unified_Ideograph", "Ideographic"},
    30567: {"Unified_Ideograph", "Ideographic"},
    30568: {"Unified_Ideograph", "Ideographic"},
    30569: {"Unified_Ideograph", "Ideographic"},
    30570: {"Unified_Ideograph", "Ideographic"},
    30571: {"Unified_Ideograph", "Ideographic"},
    30572: {"Unified_Ideograph", "Ideographic"},
    30573: {"Unified_Ideograph", "Ideographic"},
    30574: {"Unified_Ideograph", "Ideographic"},
    30575: {"Unified_Ideograph", "Ideographic"},
    30576: {"Unified_Ideograph", "Ideographic"},
    30577: {"Unified_Ideograph", "Ideographic"},
    30578: {"Unified_Ideograph", "Ideographic"},
    30579: {"Unified_Ideograph", "Ideographic"},
    30580: {"Unified_Ideograph", "Ideographic"},
    30581: {"Unified_Ideograph", "Ideographic"},
    30582: {"Unified_Ideograph", "Ideographic"},
    30583: {"Unified_Ideograph", "Ideographic"},
    30584: {"Unified_Ideograph", "Ideographic"},
    30585: {"Unified_Ideograph", "Ideographic"},
    30586: {"Unified_Ideograph", "Ideographic"},
    30587: {"Unified_Ideograph", "Ideographic"},
    30588: {"Unified_Ideograph", "Ideographic"},
    30589: {"Unified_Ideograph", "Ideographic"},
    30590: {"Unified_Ideograph", "Ideographic"},
    30591: {"Unified_Ideograph", "Ideographic"},
    30592: {"Unified_Ideograph", "Ideographic"},
    30593: {"Unified_Ideograph", "Ideographic"},
    30594: {"Unified_Ideograph", "Ideographic"},
    30595: {"Unified_Ideograph", "Ideographic"},
    30596: {"Unified_Ideograph", "Ideographic"},
    30597: {"Unified_Ideograph", "Ideographic"},
    30598: {"Unified_Ideograph", "Ideographic"},
    30599: {"Unified_Ideograph", "Ideographic"},
    30600: {"Unified_Ideograph", "Ideographic"},
    30601: {"Unified_Ideograph", "Ideographic"},
    30602: {"Unified_Ideograph", "Ideographic"},
    30603: {"Unified_Ideograph", "Ideographic"},
    30604: {"Unified_Ideograph", "Ideographic"},
    30605: {"Unified_Ideograph", "Ideographic"},
    30606: {"Unified_Ideograph", "Ideographic"},
    30607: {"Unified_Ideograph", "Ideographic"},
    30608: {"Unified_Ideograph", "Ideographic"},
    30609: {"Unified_Ideograph", "Ideographic"},
    30610: {"Unified_Ideograph", "Ideographic"},
    30611: {"Unified_Ideograph", "Ideographic"},
    30612: {"Unified_Ideograph", "Ideographic"},
    30613: {"Unified_Ideograph", "Ideographic"},
    30614: {"Unified_Ideograph", "Ideographic"},
    30615: {"Unified_Ideograph", "Ideographic"},
    30616: {"Unified_Ideograph", "Ideographic"},
    30617: {"Unified_Ideograph", "Ideographic"},
    30618: {"Unified_Ideograph", "Ideographic"},
    30619: {"Unified_Ideograph", "Ideographic"},
    30620: {"Unified_Ideograph", "Ideographic"},
    30621: {"Unified_Ideograph", "Ideographic"},
    30622: {"Unified_Ideograph", "Ideographic"},
    30623: {"Unified_Ideograph", "Ideographic"},
    30624: {"Unified_Ideograph", "Ideographic"},
    30625: {"Unified_Ideograph", "Ideographic"},
    30626: {"Unified_Ideograph", "Ideographic"},
    30627: {"Unified_Ideograph", "Ideographic"},
    30628: {"Unified_Ideograph", "Ideographic"},
    30629: {"Unified_Ideograph", "Ideographic"},
    30630: {"Unified_Ideograph", "Ideographic"},
    30631: {"Unified_Ideograph", "Ideographic"},
    30632: {"Unified_Ideograph", "Ideographic"},
    30633: {"Unified_Ideograph", "Ideographic"},
    30634: {"Unified_Ideograph", "Ideographic"},
    30635: {"Unified_Ideograph", "Ideographic"},
    30636: {"Unified_Ideograph", "Ideographic"},
    30637: {"Unified_Ideograph", "Ideographic"},
    30638: {"Unified_Ideograph", "Ideographic"},
    30639: {"Unified_Ideograph", "Ideographic"},
    30640: {"Unified_Ideograph", "Ideographic"},
    30641: {"Unified_Ideograph", "Ideographic"},
    30642: {"Unified_Ideograph", "Ideographic"},
    30643: {"Unified_Ideograph", "Ideographic"},
    30644: {"Unified_Ideograph", "Ideographic"},
    30645: {"Unified_Ideograph", "Ideographic"},
    30646: {"Unified_Ideograph", "Ideographic"},
    30647: {"Unified_Ideograph", "Ideographic"},
    30648: {"Unified_Ideograph", "Ideographic"},
    30649: {"Unified_Ideograph", "Ideographic"},
    30650: {"Unified_Ideograph", "Ideographic"},
    30651: {"Unified_Ideograph", "Ideographic"},
    30652: {"Unified_Ideograph", "Ideographic"},
    30653: {"Unified_Ideograph", "Ideographic"},
    30654: {"Unified_Ideograph", "Ideographic"},
    30655: {"Unified_Ideograph", "Ideographic"},
    30656: {"Unified_Ideograph", "Ideographic"},
    30657: {"Unified_Ideograph", "Ideographic"},
    30658: {"Unified_Ideograph", "Ideographic"},
    30659: {"Unified_Ideograph", "Ideographic"},
    30660: {"Unified_Ideograph", "Ideographic"},
    30661: {"Unified_Ideograph", "Ideographic"},
    30662: {"Unified_Ideograph", "Ideographic"},
    30663: {"Unified_Ideograph", "Ideographic"},
    30664: {"Unified_Ideograph", "Ideographic"},
    30665: {"Unified_Ideograph", "Ideographic"},
    30666: {"Unified_Ideograph", "Ideographic"},
    30667: {"Unified_Ideograph", "Ideographic"},
    30668: {"Unified_Ideograph", "Ideographic"},
    30669: {"Unified_Ideograph", "Ideographic"},
    30670: {"Unified_Ideograph", "Ideographic"},
    30671: {"Unified_Ideograph", "Ideographic"},
    30672: {"Unified_Ideograph", "Ideographic"},
    30673: {"Unified_Ideograph", "Ideographic"},
    30674: {"Unified_Ideograph", "Ideographic"},
    30675: {"Unified_Ideograph", "Ideographic"},
    30676: {"Unified_Ideograph", "Ideographic"},
    30677: {"Unified_Ideograph", "Ideographic"},
    30678: {"Unified_Ideograph", "Ideographic"},
    30679: {"Unified_Ideograph", "Ideographic"},
    30680: {"Unified_Ideograph", "Ideographic"},
    30681: {"Unified_Ideograph", "Ideographic"},
    30682: {"Unified_Ideograph", "Ideographic"},
    30683: {"Unified_Ideograph", "Ideographic"},
    30684: {"Unified_Ideograph", "Ideographic"},
    30685: {"Unified_Ideograph", "Ideographic"},
    30686: {"Unified_Ideograph", "Ideographic"},
    30687: {"Unified_Ideograph", "Ideographic"},
    30688: {"Unified_Ideograph", "Ideographic"},
    30689: {"Unified_Ideograph", "Ideographic"},
    30690: {"Unified_Ideograph", "Ideographic"},
    30691: {"Unified_Ideograph", "Ideographic"},
    30692: {"Unified_Ideograph", "Ideographic"},
    30693: {"Unified_Ideograph", "Ideographic"},
    30694: {"Unified_Ideograph", "Ideographic"},
    30695: {"Unified_Ideograph", "Ideographic"},
    30696: {"Unified_Ideograph", "Ideographic"},
    30697: {"Unified_Ideograph", "Ideographic"},
    30698: {"Unified_Ideograph", "Ideographic"},
    30699: {"Unified_Ideograph", "Ideographic"},
    30700: {"Unified_Ideograph", "Ideographic"},
    30701: {"Unified_Ideograph", "Ideographic"},
    30702: {"Unified_Ideograph", "Ideographic"},
    30703: {"Unified_Ideograph", "Ideographic"},
    30704: {"Unified_Ideograph", "Ideographic"},
    30705: {"Unified_Ideograph", "Ideographic"},
    30706: {"Unified_Ideograph", "Ideographic"},
    30707: {"Unified_Ideograph", "Ideographic"},
    30708: {"Unified_Ideograph", "Ideographic"},
    30709: {"Unified_Ideograph", "Ideographic"},
    30710: {"Unified_Ideograph", "Ideographic"},
    30711: {"Unified_Ideograph", "Ideographic"},
    30712: {"Unified_Ideograph", "Ideographic"},
    30713: {"Unified_Ideograph", "Ideographic"},
    30714: {"Unified_Ideograph", "Ideographic"},
    30715: {"Unified_Ideograph", "Ideographic"},
    30716: {"Unified_Ideograph", "Ideographic"},
    30717: {"Unified_Ideograph", "Ideographic"},
    30718: {"Unified_Ideograph", "Ideographic"},
    30719: {"Unified_Ideograph", "Ideographic"},
    30720: {"Unified_Ideograph", "Ideographic"},
    30721: {"Unified_Ideograph", "Ideographic"},
    30722: {"Unified_Ideograph", "Ideographic"},
    30723: {"Unified_Ideograph", "Ideographic"},
    30724: {"Unified_Ideograph", "Ideographic"},
    30725: {"Unified_Ideograph", "Ideographic"},
    30726: {"Unified_Ideograph", "Ideographic"},
    30727: {"Unified_Ideograph", "Ideographic"},
    30728: {"Unified_Ideograph", "Ideographic"},
    30729: {"Unified_Ideograph", "Ideographic"},
    30730: {"Unified_Ideograph", "Ideographic"},
    30731: {"Unified_Ideograph", "Ideographic"},
    30732: {"Unified_Ideograph", "Ideographic"},
    30733: {"Unified_Ideograph", "Ideographic"},
    30734: {"Unified_Ideograph", "Ideographic"},
    30735: {"Unified_Ideograph", "Ideographic"},
    30736: {"Unified_Ideograph", "Ideographic"},
    30737: {"Unified_Ideograph", "Ideographic"},
    30738: {"Unified_Ideograph", "Ideographic"},
    30739: {"Unified_Ideograph", "Ideographic"},
    30740: {"Unified_Ideograph", "Ideographic"},
    30741: {"Unified_Ideograph", "Ideographic"},
    30742: {"Unified_Ideograph", "Ideographic"},
    30743: {"Unified_Ideograph", "Ideographic"},
    30744: {"Unified_Ideograph", "Ideographic"},
    30745: {"Unified_Ideograph", "Ideographic"},
    30746: {"Unified_Ideograph", "Ideographic"},
    30747: {"Unified_Ideograph", "Ideographic"},
    30748: {"Unified_Ideograph", "Ideographic"},
    30749: {"Unified_Ideograph", "Ideographic"},
    30750: {"Unified_Ideograph", "Ideographic"},
    30751: {"Unified_Ideograph", "Ideographic"},
    30752: {"Unified_Ideograph", "Ideographic"},
    30753: {"Unified_Ideograph", "Ideographic"},
    30754: {"Unified_Ideograph", "Ideographic"},
    30755: {"Unified_Ideograph", "Ideographic"},
    30756: {"Unified_Ideograph", "Ideographic"},
    30757: {"Unified_Ideograph", "Ideographic"},
    30758: {"Unified_Ideograph", "Ideographic"},
    30759: {"Unified_Ideograph", "Ideographic"},
    30760: {"Unified_Ideograph", "Ideographic"},
    30761: {"Unified_Ideograph", "Ideographic"},
    30762: {"Unified_Ideograph", "Ideographic"},
    30763: {"Unified_Ideograph", "Ideographic"},
    30764: {"Unified_Ideograph", "Ideographic"},
    30765: {"Unified_Ideograph", "Ideographic"},
    30766: {"Unified_Ideograph", "Ideographic"},
    30767: {"Unified_Ideograph", "Ideographic"},
    30768: {"Unified_Ideograph", "Ideographic"},
    30769: {"Unified_Ideograph", "Ideographic"},
    30770: {"Unified_Ideograph", "Ideographic"},
    30771: {"Unified_Ideograph", "Ideographic"},
    30772: {"Unified_Ideograph", "Ideographic"},
    30773: {"Unified_Ideograph", "Ideographic"},
    30774: {"Unified_Ideograph", "Ideographic"},
    30775: {"Unified_Ideograph", "Ideographic"},
    30776: {"Unified_Ideograph", "Ideographic"},
    30777: {"Unified_Ideograph", "Ideographic"},
    30778: {"Unified_Ideograph", "Ideographic"},
    30779: {"Unified_Ideograph", "Ideographic"},
    30780: {"Unified_Ideograph", "Ideographic"},
    30781: {"Unified_Ideograph", "Ideographic"},
    30782: {"Unified_Ideograph", "Ideographic"},
    30783: {"Unified_Ideograph", "Ideographic"},
    30784: {"Unified_Ideograph", "Ideographic"},
    30785: {"Unified_Ideograph", "Ideographic"},
    30786: {"Unified_Ideograph", "Ideographic"},
    30787: {"Unified_Ideograph", "Ideographic"},
    30788: {"Unified_Ideograph", "Ideographic"},
    30789: {"Unified_Ideograph", "Ideographic"},
    30790: {"Unified_Ideograph", "Ideographic"},
    30791: {"Unified_Ideograph", "Ideographic"},
    30792: {"Unified_Ideograph", "Ideographic"},
    30793: {"Unified_Ideograph", "Ideographic"},
    30794: {"Unified_Ideograph", "Ideographic"},
    30795: {"Unified_Ideograph", "Ideographic"},
    30796: {"Unified_Ideograph", "Ideographic"},
    30797: {"Unified_Ideograph", "Ideographic"},
    30798: {"Unified_Ideograph", "Ideographic"},
    30799: {"Unified_Ideograph", "Ideographic"},
    30800: {"Unified_Ideograph", "Ideographic"},
    30801: {"Unified_Ideograph", "Ideographic"},
    30802: {"Unified_Ideograph", "Ideographic"},
    30803: {"Unified_Ideograph", "Ideographic"},
    30804: {"Unified_Ideograph", "Ideographic"},
    30805: {"Unified_Ideograph", "Ideographic"},
    30806: {"Unified_Ideograph", "Ideographic"},
    30807: {"Unified_Ideograph", "Ideographic"},
    30808: {"Unified_Ideograph", "Ideographic"},
    30809: {"Unified_Ideograph", "Ideographic"},
    30810: {"Unified_Ideograph", "Ideographic"},
    30811: {"Unified_Ideograph", "Ideographic"},
    30812: {"Unified_Ideograph", "Ideographic"},
    30813: {"Unified_Ideograph", "Ideographic"},
    30814: {"Unified_Ideograph", "Ideographic"},
    30815: {"Unified_Ideograph", "Ideographic"},
    30816: {"Unified_Ideograph", "Ideographic"},
    30817: {"Unified_Ideograph", "Ideographic"},
    30818: {"Unified_Ideograph", "Ideographic"},
    30819: {"Unified_Ideograph", "Ideographic"},
    30820: {"Unified_Ideograph", "Ideographic"},
    30821: {"Unified_Ideograph", "Ideographic"},
    30822: {"Unified_Ideograph", "Ideographic"},
    30823: {"Unified_Ideograph", "Ideographic"},
    30824: {"Unified_Ideograph", "Ideographic"},
    30825: {"Unified_Ideograph", "Ideographic"},
    30826: {"Unified_Ideograph", "Ideographic"},
    30827: {"Unified_Ideograph", "Ideographic"},
    30828: {"Unified_Ideograph", "Ideographic"},
    30829: {"Unified_Ideograph", "Ideographic"},
    30830: {"Unified_Ideograph", "Ideographic"},
    30831: {"Unified_Ideograph", "Ideographic"},
    30832: {"Unified_Ideograph", "Ideographic"},
    30833: {"Unified_Ideograph", "Ideographic"},
    30834: {"Unified_Ideograph", "Ideographic"},
    30835: {"Unified_Ideograph", "Ideographic"},
    30836: {"Unified_Ideograph", "Ideographic"},
    30837: {"Unified_Ideograph", "Ideographic"},
    30838: {"Unified_Ideograph", "Ideographic"},
    30839: {"Unified_Ideograph", "Ideographic"},
    30840: {"Unified_Ideograph", "Ideographic"},
    30841: {"Unified_Ideograph", "Ideographic"},
    30842: {"Unified_Ideograph", "Ideographic"},
    30843: {"Unified_Ideograph", "Ideographic"},
    30844: {"Unified_Ideograph", "Ideographic"},
    30845: {"Unified_Ideograph", "Ideographic"},
    30846: {"Unified_Ideograph", "Ideographic"},
    30847: {"Unified_Ideograph", "Ideographic"},
    30848: {"Unified_Ideograph", "Ideographic"},
    30849: {"Unified_Ideograph", "Ideographic"},
    30850: {"Unified_Ideograph", "Ideographic"},
    30851: {"Unified_Ideograph", "Ideographic"},
    30852: {"Unified_Ideograph", "Ideographic"},
    30853: {"Unified_Ideograph", "Ideographic"},
    30854: {"Unified_Ideograph", "Ideographic"},
    30855: {"Unified_Ideograph", "Ideographic"},
    30856: {"Unified_Ideograph", "Ideographic"},
    30857: {"Unified_Ideograph", "Ideographic"},
    30858: {"Unified_Ideograph", "Ideographic"},
    30859: {"Unified_Ideograph", "Ideographic"},
    30860: {"Unified_Ideograph", "Ideographic"},
    30861: {"Unified_Ideograph", "Ideographic"},
    30862: {"Unified_Ideograph", "Ideographic"},
    30863: {"Unified_Ideograph", "Ideographic"},
    30864: {"Unified_Ideograph", "Ideographic"},
    30865: {"Unified_Ideograph", "Ideographic"},
    30866: {"Unified_Ideograph", "Ideographic"},
    30867: {"Unified_Ideograph", "Ideographic"},
    30868: {"Unified_Ideograph", "Ideographic"},
    30869: {"Unified_Ideograph", "Ideographic"},
    30870: {"Unified_Ideograph", "Ideographic"},
    30871: {"Unified_Ideograph", "Ideographic"},
    30872: {"Unified_Ideograph", "Ideographic"},
    30873: {"Unified_Ideograph", "Ideographic"},
    30874: {"Unified_Ideograph", "Ideographic"},
    30875: {"Unified_Ideograph", "Ideographic"},
    30876: {"Unified_Ideograph", "Ideographic"},
    30877: {"Unified_Ideograph", "Ideographic"},
    30878: {"Unified_Ideograph", "Ideographic"},
    30879: {"Unified_Ideograph", "Ideographic"},
    30880: {"Unified_Ideograph", "Ideographic"},
    30881: {"Unified_Ideograph", "Ideographic"},
    30882: {"Unified_Ideograph", "Ideographic"},
    30883: {"Unified_Ideograph", "Ideographic"},
    30884: {"Unified_Ideograph", "Ideographic"},
    30885: {"Unified_Ideograph", "Ideographic"},
    30886: {"Unified_Ideograph", "Ideographic"},
    30887: {"Unified_Ideograph", "Ideographic"},
    30888: {"Unified_Ideograph", "Ideographic"},
    30889: {"Unified_Ideograph", "Ideographic"},
    30890: {"Unified_Ideograph", "Ideographic"},
    30891: {"Unified_Ideograph", "Ideographic"},
    30892: {"Unified_Ideograph", "Ideographic"},
    30893: {"Unified_Ideograph", "Ideographic"},
    30894: {"Unified_Ideograph", "Ideographic"},
    30895: {"Unified_Ideograph", "Ideographic"},
    30896: {"Unified_Ideograph", "Ideographic"},
    30897: {"Unified_Ideograph", "Ideographic"},
    30898: {"Unified_Ideograph", "Ideographic"},
    30899: {"Unified_Ideograph", "Ideographic"},
    30900: {"Unified_Ideograph", "Ideographic"},
    30901: {"Unified_Ideograph", "Ideographic"},
    30902: {"Unified_Ideograph", "Ideographic"},
    30903: {"Unified_Ideograph", "Ideographic"},
    30904: {"Unified_Ideograph", "Ideographic"},
    30905: {"Unified_Ideograph", "Ideographic"},
    30906: {"Unified_Ideograph", "Ideographic"},
    30907: {"Unified_Ideograph", "Ideographic"},
    30908: {"Unified_Ideograph", "Ideographic"},
    30909: {"Unified_Ideograph", "Ideographic"},
    30910: {"Unified_Ideograph", "Ideographic"},
    30911: {"Unified_Ideograph", "Ideographic"},
    30912: {"Unified_Ideograph", "Ideographic"},
    30913: {"Unified_Ideograph", "Ideographic"},
    30914: {"Unified_Ideograph", "Ideographic"},
    30915: {"Unified_Ideograph", "Ideographic"},
    30916: {"Unified_Ideograph", "Ideographic"},
    30917: {"Unified_Ideograph", "Ideographic"},
    30918: {"Unified_Ideograph", "Ideographic"},
    30919: {"Unified_Ideograph", "Ideographic"},
    30920: {"Unified_Ideograph", "Ideographic"},
    30921: {"Unified_Ideograph", "Ideographic"},
    30922: {"Unified_Ideograph", "Ideographic"},
    30923: {"Unified_Ideograph", "Ideographic"},
    30924: {"Unified_Ideograph", "Ideographic"},
    30925: {"Unified_Ideograph", "Ideographic"},
    30926: {"Unified_Ideograph", "Ideographic"},
    30927: {"Unified_Ideograph", "Ideographic"},
    30928: {"Unified_Ideograph", "Ideographic"},
    30929: {"Unified_Ideograph", "Ideographic"},
    30930: {"Unified_Ideograph", "Ideographic"},
    30931: {"Unified_Ideograph", "Ideographic"},
    30932: {"Unified_Ideograph", "Ideographic"},
    30933: {"Unified_Ideograph", "Ideographic"},
    30934: {"Unified_Ideograph", "Ideographic"},
    30935: {"Unified_Ideograph", "Ideographic"},
    30936: {"Unified_Ideograph", "Ideographic"},
    30937: {"Unified_Ideograph", "Ideographic"},
    30938: {"Unified_Ideograph", "Ideographic"},
    30939: {"Unified_Ideograph", "Ideographic"},
    30940: {"Unified_Ideograph", "Ideographic"},
    30941: {"Unified_Ideograph", "Ideographic"},
    30942: {"Unified_Ideograph", "Ideographic"},
    30943: {"Unified_Ideograph", "Ideographic"},
    30944: {"Unified_Ideograph", "Ideographic"},
    30945: {"Unified_Ideograph", "Ideographic"},
    30946: {"Unified_Ideograph", "Ideographic"},
    30947: {"Unified_Ideograph", "Ideographic"},
    30948: {"Unified_Ideograph", "Ideographic"},
    30949: {"Unified_Ideograph", "Ideographic"},
    30950: {"Unified_Ideograph", "Ideographic"},
    30951: {"Unified_Ideograph", "Ideographic"},
    30952: {"Unified_Ideograph", "Ideographic"},
    30953: {"Unified_Ideograph", "Ideographic"},
    30954: {"Unified_Ideograph", "Ideographic"},
    30955: {"Unified_Ideograph", "Ideographic"},
    30956: {"Unified_Ideograph", "Ideographic"},
    30957: {"Unified_Ideograph", "Ideographic"},
    30958: {"Unified_Ideograph", "Ideographic"},
    30959: {"Unified_Ideograph", "Ideographic"},
    30960: {"Unified_Ideograph", "Ideographic"},
    30961: {"Unified_Ideograph", "Ideographic"},
    30962: {"Unified_Ideograph", "Ideographic"},
    30963: {"Unified_Ideograph", "Ideographic"},
    30964: {"Unified_Ideograph", "Ideographic"},
    30965: {"Unified_Ideograph", "Ideographic"},
    30966: {"Unified_Ideograph", "Ideographic"},
    30967: {"Unified_Ideograph", "Ideographic"},
    30968: {"Unified_Ideograph", "Ideographic"},
    30969: {"Unified_Ideograph", "Ideographic"},
    30970: {"Unified_Ideograph", "Ideographic"},
    30971: {"Unified_Ideograph", "Ideographic"},
    30972: {"Unified_Ideograph", "Ideographic"},
    30973: {"Unified_Ideograph", "Ideographic"},
    30974: {"Unified_Ideograph", "Ideographic"},
    30975: {"Unified_Ideograph", "Ideographic"},
    30976: {"Unified_Ideograph", "Ideographic"},
    30977: {"Unified_Ideograph", "Ideographic"},
    30978: {"Unified_Ideograph", "Ideographic"},
    30979: {"Unified_Ideograph", "Ideographic"},
    30980: {"Unified_Ideograph", "Ideographic"},
    30981: {"Unified_Ideograph", "Ideographic"},
    30982: {"Unified_Ideograph", "Ideographic"},
    30983: {"Unified_Ideograph", "Ideographic"},
    30984: {"Unified_Ideograph", "Ideographic"},
    30985: {"Unified_Ideograph", "Ideographic"},
    30986: {"Unified_Ideograph", "Ideographic"},
    30987: {"Unified_Ideograph", "Ideographic"},
    30988: {"Unified_Ideograph", "Ideographic"},
    30989: {"Unified_Ideograph", "Ideographic"},
    30990: {"Unified_Ideograph", "Ideographic"},
    30991: {"Unified_Ideograph", "Ideographic"},
    30992: {"Unified_Ideograph", "Ideographic"},
    30993: {"Unified_Ideograph", "Ideographic"},
    30994: {"Unified_Ideograph", "Ideographic"},
    30995: {"Unified_Ideograph", "Ideographic"},
    30996: {"Unified_Ideograph", "Ideographic"},
    30997: {"Unified_Ideograph", "Ideographic"},
    30998: {"Unified_Ideograph", "Ideographic"},
    30999: {"Unified_Ideograph", "Ideographic"},
    31000: {"Unified_Ideograph", "Ideographic"},
    31001: {"Unified_Ideograph", "Ideographic"},
    31002: {"Unified_Ideograph", "Ideographic"},
    31003: {"Unified_Ideograph", "Ideographic"},
    31004: {"Unified_Ideograph", "Ideographic"},
    31005: {"Unified_Ideograph", "Ideographic"},
    31006: {"Unified_Ideograph", "Ideographic"},
    31007: {"Unified_Ideograph", "Ideographic"},
    31008: {"Unified_Ideograph", "Ideographic"},
    31009: {"Unified_Ideograph", "Ideographic"},
    31010: {"Unified_Ideograph", "Ideographic"},
    31011: {"Unified_Ideograph", "Ideographic"},
    31012: {"Unified_Ideograph", "Ideographic"},
    31013: {"Unified_Ideograph", "Ideographic"},
    31014: {"Unified_Ideograph", "Ideographic"},
    31015: {"Unified_Ideograph", "Ideographic"},
    31016: {"Unified_Ideograph", "Ideographic"},
    31017: {"Unified_Ideograph", "Ideographic"},
    31018: {"Unified_Ideograph", "Ideographic"},
    31019: {"Unified_Ideograph", "Ideographic"},
    31020: {"Unified_Ideograph", "Ideographic"},
    31021: {"Unified_Ideograph", "Ideographic"},
    31022: {"Unified_Ideograph", "Ideographic"},
    31023: {"Unified_Ideograph", "Ideographic"},
    31024: {"Unified_Ideograph", "Ideographic"},
    31025: {"Unified_Ideograph", "Ideographic"},
    31026: {"Unified_Ideograph", "Ideographic"},
    31027: {"Unified_Ideograph", "Ideographic"},
    31028: {"Unified_Ideograph", "Ideographic"},
    31029: {"Unified_Ideograph", "Ideographic"},
    31030: {"Unified_Ideograph", "Ideographic"},
    31031: {"Unified_Ideograph", "Ideographic"},
    31032: {"Unified_Ideograph", "Ideographic"},
    31033: {"Unified_Ideograph", "Ideographic"},
    31034: {"Unified_Ideograph", "Ideographic"},
    31035: {"Unified_Ideograph", "Ideographic"},
    31036: {"Unified_Ideograph", "Ideographic"},
    31037: {"Unified_Ideograph", "Ideographic"},
    31038: {"Unified_Ideograph", "Ideographic"},
    31039: {"Unified_Ideograph", "Ideographic"},
    31040: {"Unified_Ideograph", "Ideographic"},
    31041: {"Unified_Ideograph", "Ideographic"},
    31042: {"Unified_Ideograph", "Ideographic"},
    31043: {"Unified_Ideograph", "Ideographic"},
    31044: {"Unified_Ideograph", "Ideographic"},
    31045: {"Unified_Ideograph", "Ideographic"},
    31046: {"Unified_Ideograph", "Ideographic"},
    31047: {"Unified_Ideograph", "Ideographic"},
    31048: {"Unified_Ideograph", "Ideographic"},
    31049: {"Unified_Ideograph", "Ideographic"},
    31050: {"Unified_Ideograph", "Ideographic"},
    31051: {"Unified_Ideograph", "Ideographic"},
    31052: {"Unified_Ideograph", "Ideographic"},
    31053: {"Unified_Ideograph", "Ideographic"},
    31054: {"Unified_Ideograph", "Ideographic"},
    31055: {"Unified_Ideograph", "Ideographic"},
    31056: {"Unified_Ideograph", "Ideographic"},
    31057: {"Unified_Ideograph", "Ideographic"},
    31058: {"Unified_Ideograph", "Ideographic"},
    31059: {"Unified_Ideograph", "Ideographic"},
    31060: {"Unified_Ideograph", "Ideographic"},
    31061: {"Unified_Ideograph", "Ideographic"},
    31062: {"Unified_Ideograph", "Ideographic"},
    31063: {"Unified_Ideograph", "Ideographic"},
    31064: {"Unified_Ideograph", "Ideographic"},
    31065: {"Unified_Ideograph", "Ideographic"},
    31066: {"Unified_Ideograph", "Ideographic"},
    31067: {"Unified_Ideograph", "Ideographic"},
    31068: {"Unified_Ideograph", "Ideographic"},
    31069: {"Unified_Ideograph", "Ideographic"},
    31070: {"Unified_Ideograph", "Ideographic"},
    31071: {"Unified_Ideograph", "Ideographic"},
    31072: {"Unified_Ideograph", "Ideographic"},
    31073: {"Unified_Ideograph", "Ideographic"},
    31074: {"Unified_Ideograph", "Ideographic"},
    31075: {"Unified_Ideograph", "Ideographic"},
    31076: {"Unified_Ideograph", "Ideographic"},
    31077: {"Unified_Ideograph", "Ideographic"},
    31078: {"Unified_Ideograph", "Ideographic"},
    31079: {"Unified_Ideograph", "Ideographic"},
    31080: {"Unified_Ideograph", "Ideographic"},
    31081: {"Unified_Ideograph", "Ideographic"},
    31082: {"Unified_Ideograph", "Ideographic"},
    31083: {"Unified_Ideograph", "Ideographic"},
    31084: {"Unified_Ideograph", "Ideographic"},
    31085: {"Unified_Ideograph", "Ideographic"},
    31086: {"Unified_Ideograph", "Ideographic"},
    31087: {"Unified_Ideograph", "Ideographic"},
    31088: {"Unified_Ideograph", "Ideographic"},
    31089: {"Unified_Ideograph", "Ideographic"},
    31090: {"Unified_Ideograph", "Ideographic"},
    31091: {"Unified_Ideograph", "Ideographic"},
    31092: {"Unified_Ideograph", "Ideographic"},
    31093: {"Unified_Ideograph", "Ideographic"},
    31094: {"Unified_Ideograph", "Ideographic"},
    31095: {"Unified_Ideograph", "Ideographic"},
    31096: {"Unified_Ideograph", "Ideographic"},
    31097: {"Unified_Ideograph", "Ideographic"},
    31098: {"Unified_Ideograph", "Ideographic"},
    31099: {"Unified_Ideograph", "Ideographic"},
    31100: {"Unified_Ideograph", "Ideographic"},
    31101: {"Unified_Ideograph", "Ideographic"},
    31102: {"Unified_Ideograph", "Ideographic"},
    31103: {"Unified_Ideograph", "Ideographic"},
    31104: {"Unified_Ideograph", "Ideographic"},
    31105: {"Unified_Ideograph", "Ideographic"},
    31106: {"Unified_Ideograph", "Ideographic"},
    31107: {"Unified_Ideograph", "Ideographic"},
    31108: {"Unified_Ideograph", "Ideographic"},
    31109: {"Unified_Ideograph", "Ideographic"},
    31110: {"Unified_Ideograph", "Ideographic"},
    31111: {"Unified_Ideograph", "Ideographic"},
    31112: {"Unified_Ideograph", "Ideographic"},
    31113: {"Unified_Ideograph", "Ideographic"},
    31114: {"Unified_Ideograph", "Ideographic"},
    31115: {"Unified_Ideograph", "Ideographic"},
    31116: {"Unified_Ideograph", "Ideographic"},
    31117: {"Unified_Ideograph", "Ideographic"},
    31118: {"Unified_Ideograph", "Ideographic"},
    31119: {"Unified_Ideograph", "Ideographic"},
    31120: {"Unified_Ideograph", "Ideographic"},
    31121: {"Unified_Ideograph", "Ideographic"},
    31122: {"Unified_Ideograph", "Ideographic"},
    31123: {"Unified_Ideograph", "Ideographic"},
    31124: {"Unified_Ideograph", "Ideographic"},
    31125: {"Unified_Ideograph", "Ideographic"},
    31126: {"Unified_Ideograph", "Ideographic"},
    31127: {"Unified_Ideograph", "Ideographic"},
    31128: {"Unified_Ideograph", "Ideographic"},
    31129: {"Unified_Ideograph", "Ideographic"},
    31130: {"Unified_Ideograph", "Ideographic"},
    31131: {"Unified_Ideograph", "Ideographic"},
    31132: {"Unified_Ideograph", "Ideographic"},
    31133: {"Unified_Ideograph", "Ideographic"},
    31134: {"Unified_Ideograph", "Ideographic"},
    31135: {"Unified_Ideograph", "Ideographic"},
    31136: {"Unified_Ideograph", "Ideographic"},
    31137: {"Unified_Ideograph", "Ideographic"},
    31138: {"Unified_Ideograph", "Ideographic"},
    31139: {"Unified_Ideograph", "Ideographic"},
    31140: {"Unified_Ideograph", "Ideographic"},
    31141: {"Unified_Ideograph", "Ideographic"},
    31142: {"Unified_Ideograph", "Ideographic"},
    31143: {"Unified_Ideograph", "Ideographic"},
    31144: {"Unified_Ideograph", "Ideographic"},
    31145: {"Unified_Ideograph", "Ideographic"},
    31146: {"Unified_Ideograph", "Ideographic"},
    31147: {"Unified_Ideograph", "Ideographic"},
    31148: {"Unified_Ideograph", "Ideographic"},
    31149: {"Unified_Ideograph", "Ideographic"},
    31150: {"Unified_Ideograph", "Ideographic"},
    31151: {"Unified_Ideograph", "Ideographic"},
    31152: {"Unified_Ideograph", "Ideographic"},
    31153: {"Unified_Ideograph", "Ideographic"},
    31154: {"Unified_Ideograph", "Ideographic"},
    31155: {"Unified_Ideograph", "Ideographic"},
    31156: {"Unified_Ideograph", "Ideographic"},
    31157: {"Unified_Ideograph", "Ideographic"},
    31158: {"Unified_Ideograph", "Ideographic"},
    31159: {"Unified_Ideograph", "Ideographic"},
    31160: {"Unified_Ideograph", "Ideographic"},
    31161: {"Unified_Ideograph", "Ideographic"},
    31162: {"Unified_Ideograph", "Ideographic"},
    31163: {"Unified_Ideograph", "Ideographic"},
    31164: {"Unified_Ideograph", "Ideographic"},
    31165: {"Unified_Ideograph", "Ideographic"},
    31166: {"Unified_Ideograph", "Ideographic"},
    31167: {"Unified_Ideograph", "Ideographic"},
    31168: {"Unified_Ideograph", "Ideographic"},
    31169: {"Unified_Ideograph", "Ideographic"},
    31170: {"Unified_Ideograph", "Ideographic"},
    31171: {"Unified_Ideograph", "Ideographic"},
    31172: {"Unified_Ideograph", "Ideographic"},
    31173: {"Unified_Ideograph", "Ideographic"},
    31174: {"Unified_Ideograph", "Ideographic"},
    31175: {"Unified_Ideograph", "Ideographic"},
    31176: {"Unified_Ideograph", "Ideographic"},
    31177: {"Unified_Ideograph", "Ideographic"},
    31178: {"Unified_Ideograph", "Ideographic"},
    31179: {"Unified_Ideograph", "Ideographic"},
    31180: {"Unified_Ideograph", "Ideographic"},
    31181: {"Unified_Ideograph", "Ideographic"},
    31182: {"Unified_Ideograph", "Ideographic"},
    31183: {"Unified_Ideograph", "Ideographic"},
    31184: {"Unified_Ideograph", "Ideographic"},
    31185: {"Unified_Ideograph", "Ideographic"},
    31186: {"Unified_Ideograph", "Ideographic"},
    31187: {"Unified_Ideograph", "Ideographic"},
    31188: {"Unified_Ideograph", "Ideographic"},
    31189: {"Unified_Ideograph", "Ideographic"},
    31190: {"Unified_Ideograph", "Ideographic"},
    31191: {"Unified_Ideograph", "Ideographic"},
    31192: {"Unified_Ideograph", "Ideographic"},
    31193: {"Unified_Ideograph", "Ideographic"},
    31194: {"Unified_Ideograph", "Ideographic"},
    31195: {"Unified_Ideograph", "Ideographic"},
    31196: {"Unified_Ideograph", "Ideographic"},
    31197: {"Unified_Ideograph", "Ideographic"},
    31198: {"Unified_Ideograph", "Ideographic"},
    31199: {"Unified_Ideograph", "Ideographic"},
    31200: {"Unified_Ideograph", "Ideographic"},
    31201: {"Unified_Ideograph", "Ideographic"},
    31202: {"Unified_Ideograph", "Ideographic"},
    31203: {"Unified_Ideograph", "Ideographic"},
    31204: {"Unified_Ideograph", "Ideographic"},
    31205: {"Unified_Ideograph", "Ideographic"},
    31206: {"Unified_Ideograph", "Ideographic"},
    31207: {"Unified_Ideograph", "Ideographic"},
    31208: {"Unified_Ideograph", "Ideographic"},
    31209: {"Unified_Ideograph", "Ideographic"},
    31210: {"Unified_Ideograph", "Ideographic"},
    31211: {"Unified_Ideograph", "Ideographic"},
    31212: {"Unified_Ideograph", "Ideographic"},
    31213: {"Unified_Ideograph", "Ideographic"},
    31214: {"Unified_Ideograph", "Ideographic"},
    31215: {"Unified_Ideograph", "Ideographic"},
    31216: {"Unified_Ideograph", "Ideographic"},
    31217: {"Unified_Ideograph", "Ideographic"},
    31218: {"Unified_Ideograph", "Ideographic"},
    31219: {"Unified_Ideograph", "Ideographic"},
    31220: {"Unified_Ideograph", "Ideographic"},
    31221: {"Unified_Ideograph", "Ideographic"},
    31222: {"Unified_Ideograph", "Ideographic"},
    31223: {"Unified_Ideograph", "Ideographic"},
    31224: {"Unified_Ideograph", "Ideographic"},
    31225: {"Unified_Ideograph", "Ideographic"},
    31226: {"Unified_Ideograph", "Ideographic"},
    31227: {"Unified_Ideograph", "Ideographic"},
    31228: {"Unified_Ideograph", "Ideographic"},
    31229: {"Unified_Ideograph", "Ideographic"},
    31230: {"Unified_Ideograph", "Ideographic"},
    31231: {"Unified_Ideograph", "Ideographic"},
    31232: {"Unified_Ideograph", "Ideographic"},
    31233: {"Unified_Ideograph", "Ideographic"},
    31234: {"Unified_Ideograph", "Ideographic"},
    31235: {"Unified_Ideograph", "Ideographic"},
    31236: {"Unified_Ideograph", "Ideographic"},
    31237: {"Unified_Ideograph", "Ideographic"},
    31238: {"Unified_Ideograph", "Ideographic"},
    31239: {"Unified_Ideograph", "Ideographic"},
    31240: {"Unified_Ideograph", "Ideographic"},
    31241: {"Unified_Ideograph", "Ideographic"},
    31242: {"Unified_Ideograph", "Ideographic"},
    31243: {"Unified_Ideograph", "Ideographic"},
    31244: {"Unified_Ideograph", "Ideographic"},
    31245: {"Unified_Ideograph", "Ideographic"},
    31246: {"Unified_Ideograph", "Ideographic"},
    31247: {"Unified_Ideograph", "Ideographic"},
    31248: {"Unified_Ideograph", "Ideographic"},
    31249: {"Unified_Ideograph", "Ideographic"},
    31250: {"Unified_Ideograph", "Ideographic"},
    31251: {"Unified_Ideograph", "Ideographic"},
    31252: {"Unified_Ideograph", "Ideographic"},
    31253: {"Unified_Ideograph", "Ideographic"},
    31254: {"Unified_Ideograph", "Ideographic"},
    31255: {"Unified_Ideograph", "Ideographic"},
    31256: {"Unified_Ideograph", "Ideographic"},
    31257: {"Unified_Ideograph", "Ideographic"},
    31258: {"Unified_Ideograph", "Ideographic"},
    31259: {"Unified_Ideograph", "Ideographic"},
    31260: {"Unified_Ideograph", "Ideographic"},
    31261: {"Unified_Ideograph", "Ideographic"},
    31262: {"Unified_Ideograph", "Ideographic"},
    31263: {"Unified_Ideograph", "Ideographic"},
    31264: {"Unified_Ideograph", "Ideographic"},
    31265: {"Unified_Ideograph", "Ideographic"},
    31266: {"Unified_Ideograph", "Ideographic"},
    31267: {"Unified_Ideograph", "Ideographic"},
    31268: {"Unified_Ideograph", "Ideographic"},
    31269: {"Unified_Ideograph", "Ideographic"},
    31270: {"Unified_Ideograph", "Ideographic"},
    31271: {"Unified_Ideograph", "Ideographic"},
    31272: {"Unified_Ideograph", "Ideographic"},
    31273: {"Unified_Ideograph", "Ideographic"},
    31274: {"Unified_Ideograph", "Ideographic"},
    31275: {"Unified_Ideograph", "Ideographic"},
    31276: {"Unified_Ideograph", "Ideographic"},
    31277: {"Unified_Ideograph", "Ideographic"},
    31278: {"Unified_Ideograph", "Ideographic"},
    31279: {"Unified_Ideograph", "Ideographic"},
    31280: {"Unified_Ideograph", "Ideographic"},
    31281: {"Unified_Ideograph", "Ideographic"},
    31282: {"Unified_Ideograph", "Ideographic"},
    31283: {"Unified_Ideograph", "Ideographic"},
    31284: {"Unified_Ideograph", "Ideographic"},
    31285: {"Unified_Ideograph", "Ideographic"},
    31286: {"Unified_Ideograph", "Ideographic"},
    31287: {"Unified_Ideograph", "Ideographic"},
    31288: {"Unified_Ideograph", "Ideographic"},
    31289: {"Unified_Ideograph", "Ideographic"},
    31290: {"Unified_Ideograph", "Ideographic"},
    31291: {"Unified_Ideograph", "Ideographic"},
    31292: {"Unified_Ideograph", "Ideographic"},
    31293: {"Unified_Ideograph", "Ideographic"},
    31294: {"Unified_Ideograph", "Ideographic"},
    31295: {"Unified_Ideograph", "Ideographic"},
    31296: {"Unified_Ideograph", "Ideographic"},
    31297: {"Unified_Ideograph", "Ideographic"},
    31298: {"Unified_Ideograph", "Ideographic"},
    31299: {"Unified_Ideograph", "Ideographic"},
    31300: {"Unified_Ideograph", "Ideographic"},
    31301: {"Unified_Ideograph", "Ideographic"},
    31302: {"Unified_Ideograph", "Ideographic"},
    31303: {"Unified_Ideograph", "Ideographic"},
    31304: {"Unified_Ideograph", "Ideographic"},
    31305: {"Unified_Ideograph", "Ideographic"},
    31306: {"Unified_Ideograph", "Ideographic"},
    31307: {"Unified_Ideograph", "Ideographic"},
    31308: {"Unified_Ideograph", "Ideographic"},
    31309: {"Unified_Ideograph", "Ideographic"},
    31310: {"Unified_Ideograph", "Ideographic"},
    31311: {"Unified_Ideograph", "Ideographic"},
    31312: {"Unified_Ideograph", "Ideographic"},
    31313: {"Unified_Ideograph", "Ideographic"},
    31314: {"Unified_Ideograph", "Ideographic"},
    31315: {"Unified_Ideograph", "Ideographic"},
    31316: {"Unified_Ideograph", "Ideographic"},
    31317: {"Unified_Ideograph", "Ideographic"},
    31318: {"Unified_Ideograph", "Ideographic"},
    31319: {"Unified_Ideograph", "Ideographic"},
    31320: {"Unified_Ideograph", "Ideographic"},
    31321: {"Unified_Ideograph", "Ideographic"},
    31322: {"Unified_Ideograph", "Ideographic"},
    31323: {"Unified_Ideograph", "Ideographic"},
    31324: {"Unified_Ideograph", "Ideographic"},
    31325: {"Unified_Ideograph", "Ideographic"},
    31326: {"Unified_Ideograph", "Ideographic"},
    31327: {"Unified_Ideograph", "Ideographic"},
    31328: {"Unified_Ideograph", "Ideographic"},
    31329: {"Unified_Ideograph", "Ideographic"},
    31330: {"Unified_Ideograph", "Ideographic"},
    31331: {"Unified_Ideograph", "Ideographic"},
    31332: {"Unified_Ideograph", "Ideographic"},
    31333: {"Unified_Ideograph", "Ideographic"},
    31334: {"Unified_Ideograph", "Ideographic"},
    31335: {"Unified_Ideograph", "Ideographic"},
    31336: {"Unified_Ideograph", "Ideographic"},
    31337: {"Unified_Ideograph", "Ideographic"},
    31338: {"Unified_Ideograph", "Ideographic"},
    31339: {"Unified_Ideograph", "Ideographic"},
    31340: {"Unified_Ideograph", "Ideographic"},
    31341: {"Unified_Ideograph", "Ideographic"},
    31342: {"Unified_Ideograph", "Ideographic"},
    31343: {"Unified_Ideograph", "Ideographic"},
    31344: {"Unified_Ideograph", "Ideographic"},
    31345: {"Unified_Ideograph", "Ideographic"},
    31346: {"Unified_Ideograph", "Ideographic"},
    31347: {"Unified_Ideograph", "Ideographic"},
    31348: {"Unified_Ideograph", "Ideographic"},
    31349: {"Unified_Ideograph", "Ideographic"},
    31350: {"Unified_Ideograph", "Ideographic"},
    31351: {"Unified_Ideograph", "Ideographic"},
    31352: {"Unified_Ideograph", "Ideographic"},
    31353: {"Unified_Ideograph", "Ideographic"},
    31354: {"Unified_Ideograph", "Ideographic"},
    31355: {"Unified_Ideograph", "Ideographic"},
    31356: {"Unified_Ideograph", "Ideographic"},
    31357: {"Unified_Ideograph", "Ideographic"},
    31358: {"Unified_Ideograph", "Ideographic"},
    31359: {"Unified_Ideograph", "Ideographic"},
    31360: {"Unified_Ideograph", "Ideographic"},
    31361: {"Unified_Ideograph", "Ideographic"},
    31362: {"Unified_Ideograph", "Ideographic"},
    31363: {"Unified_Ideograph", "Ideographic"},
    31364: {"Unified_Ideograph", "Ideographic"},
    31365: {"Unified_Ideograph", "Ideographic"},
    31366: {"Unified_Ideograph", "Ideographic"},
    31367: {"Unified_Ideograph", "Ideographic"},
    31368: {"Unified_Ideograph", "Ideographic"},
    31369: {"Unified_Ideograph", "Ideographic"},
    31370: {"Unified_Ideograph", "Ideographic"},
    31371: {"Unified_Ideograph", "Ideographic"},
    31372: {"Unified_Ideograph", "Ideographic"},
    31373: {"Unified_Ideograph", "Ideographic"},
    31374: {"Unified_Ideograph", "Ideographic"},
    31375: {"Unified_Ideograph", "Ideographic"},
    31376: {"Unified_Ideograph", "Ideographic"},
    31377: {"Unified_Ideograph", "Ideographic"},
    31378: {"Unified_Ideograph", "Ideographic"},
    31379: {"Unified_Ideograph", "Ideographic"},
    31380: {"Unified_Ideograph", "Ideographic"},
    31381: {"Unified_Ideograph", "Ideographic"},
    31382: {"Unified_Ideograph", "Ideographic"},
    31383: {"Unified_Ideograph", "Ideographic"},
    31384: {"Unified_Ideograph", "Ideographic"},
    31385: {"Unified_Ideograph", "Ideographic"},
    31386: {"Unified_Ideograph", "Ideographic"},
    31387: {"Unified_Ideograph", "Ideographic"},
    31388: {"Unified_Ideograph", "Ideographic"},
    31389: {"Unified_Ideograph", "Ideographic"},
    31390: {"Unified_Ideograph", "Ideographic"},
    31391: {"Unified_Ideograph", "Ideographic"},
    31392: {"Unified_Ideograph", "Ideographic"},
    31393: {"Unified_Ideograph", "Ideographic"},
    31394: {"Unified_Ideograph", "Ideographic"},
    31395: {"Unified_Ideograph", "Ideographic"},
    31396: {"Unified_Ideograph", "Ideographic"},
    31397: {"Unified_Ideograph", "Ideographic"},
    31398: {"Unified_Ideograph", "Ideographic"},
    31399: {"Unified_Ideograph", "Ideographic"},
    31400: {"Unified_Ideograph", "Ideographic"},
    31401: {"Unified_Ideograph", "Ideographic"},
    31402: {"Unified_Ideograph", "Ideographic"},
    31403: {"Unified_Ideograph", "Ideographic"},
    31404: {"Unified_Ideograph", "Ideographic"},
    31405: {"Unified_Ideograph", "Ideographic"},
    31406: {"Unified_Ideograph", "Ideographic"},
    31407: {"Unified_Ideograph", "Ideographic"},
    31408: {"Unified_Ideograph", "Ideographic"},
    31409: {"Unified_Ideograph", "Ideographic"},
    31410: {"Unified_Ideograph", "Ideographic"},
    31411: {"Unified_Ideograph", "Ideographic"},
    31412: {"Unified_Ideograph", "Ideographic"},
    31413: {"Unified_Ideograph", "Ideographic"},
    31414: {"Unified_Ideograph", "Ideographic"},
    31415: {"Unified_Ideograph", "Ideographic"},
    31416: {"Unified_Ideograph", "Ideographic"},
    31417: {"Unified_Ideograph", "Ideographic"},
    31418: {"Unified_Ideograph", "Ideographic"},
    31419: {"Unified_Ideograph", "Ideographic"},
    31420: {"Unified_Ideograph", "Ideographic"},
    31421: {"Unified_Ideograph", "Ideographic"},
    31422: {"Unified_Ideograph", "Ideographic"},
    31423: {"Unified_Ideograph", "Ideographic"},
    31424: {"Unified_Ideograph", "Ideographic"},
    31425: {"Unified_Ideograph", "Ideographic"},
    31426: {"Unified_Ideograph", "Ideographic"},
    31427: {"Unified_Ideograph", "Ideographic"},
    31428: {"Unified_Ideograph", "Ideographic"},
    31429: {"Unified_Ideograph", "Ideographic"},
    31430: {"Unified_Ideograph", "Ideographic"},
    31431: {"Unified_Ideograph", "Ideographic"},
    31432: {"Unified_Ideograph", "Ideographic"},
    31433: {"Unified_Ideograph", "Ideographic"},
    31434: {"Unified_Ideograph", "Ideographic"},
    31435: {"Unified_Ideograph", "Ideographic"},
    31436: {"Unified_Ideograph", "Ideographic"},
    31437: {"Unified_Ideograph", "Ideographic"},
    31438: {"Unified_Ideograph", "Ideographic"},
    31439: {"Unified_Ideograph", "Ideographic"},
    31440: {"Unified_Ideograph", "Ideographic"},
    31441: {"Unified_Ideograph", "Ideographic"},
    31442: {"Unified_Ideograph", "Ideographic"},
    31443: {"Unified_Ideograph", "Ideographic"},
    31444: {"Unified_Ideograph", "Ideographic"},
    31445: {"Unified_Ideograph", "Ideographic"},
    31446: {"Unified_Ideograph", "Ideographic"},
    31447: {"Unified_Ideograph", "Ideographic"},
    31448: {"Unified_Ideograph", "Ideographic"},
    31449: {"Unified_Ideograph", "Ideographic"},
    31450: {"Unified_Ideograph", "Ideographic"},
    31451: {"Unified_Ideograph", "Ideographic"},
    31452: {"Unified_Ideograph", "Ideographic"},
    31453: {"Unified_Ideograph", "Ideographic"},
    31454: {"Unified_Ideograph", "Ideographic"},
    31455: {"Unified_Ideograph", "Ideographic"},
    31456: {"Unified_Ideograph", "Ideographic"},
    31457: {"Unified_Ideograph", "Ideographic"},
    31458: {"Unified_Ideograph", "Ideographic"},
    31459: {"Unified_Ideograph", "Ideographic"},
    31460: {"Unified_Ideograph", "Ideographic"},
    31461: {"Unified_Ideograph", "Ideographic"},
    31462: {"Unified_Ideograph", "Ideographic"},
    31463: {"Unified_Ideograph", "Ideographic"},
    31464: {"Unified_Ideograph", "Ideographic"},
    31465: {"Unified_Ideograph", "Ideographic"},
    31466: {"Unified_Ideograph", "Ideographic"},
    31467: {"Unified_Ideograph", "Ideographic"},
    31468: {"Unified_Ideograph", "Ideographic"},
    31469: {"Unified_Ideograph", "Ideographic"},
    31470: {"Unified_Ideograph", "Ideographic"},
    31471: {"Unified_Ideograph", "Ideographic"},
    31472: {"Unified_Ideograph", "Ideographic"},
    31473: {"Unified_Ideograph", "Ideographic"},
    31474: {"Unified_Ideograph", "Ideographic"},
    31475: {"Unified_Ideograph", "Ideographic"},
    31476: {"Unified_Ideograph", "Ideographic"},
    31477: {"Unified_Ideograph", "Ideographic"},
    31478: {"Unified_Ideograph", "Ideographic"},
    31479: {"Unified_Ideograph", "Ideographic"},
    31480: {"Unified_Ideograph", "Ideographic"},
    31481: {"Unified_Ideograph", "Ideographic"},
    31482: {"Unified_Ideograph", "Ideographic"},
    31483: {"Unified_Ideograph", "Ideographic"},
    31484: {"Unified_Ideograph", "Ideographic"},
    31485: {"Unified_Ideograph", "Ideographic"},
    31486: {"Unified_Ideograph", "Ideographic"},
    31487: {"Unified_Ideograph", "Ideographic"},
    31488: {"Unified_Ideograph", "Ideographic"},
    31489: {"Unified_Ideograph", "Ideographic"},
    31490: {"Unified_Ideograph", "Ideographic"},
    31491: {"Unified_Ideograph", "Ideographic"},
    31492: {"Unified_Ideograph", "Ideographic"},
    31493: {"Unified_Ideograph", "Ideographic"},
    31494: {"Unified_Ideograph", "Ideographic"},
    31495: {"Unified_Ideograph", "Ideographic"},
    31496: {"Unified_Ideograph", "Ideographic"},
    31497: {"Unified_Ideograph", "Ideographic"},
    31498: {"Unified_Ideograph", "Ideographic"},
    31499: {"Unified_Ideograph", "Ideographic"},
    31500: {"Unified_Ideograph", "Ideographic"},
    31501: {"Unified_Ideograph", "Ideographic"},
    31502: {"Unified_Ideograph", "Ideographic"},
    31503: {"Unified_Ideograph", "Ideographic"},
    31504: {"Unified_Ideograph", "Ideographic"},
    31505: {"Unified_Ideograph", "Ideographic"},
    31506: {"Unified_Ideograph", "Ideographic"},
    31507: {"Unified_Ideograph", "Ideographic"},
    31508: {"Unified_Ideograph", "Ideographic"},
    31509: {"Unified_Ideograph", "Ideographic"},
    31510: {"Unified_Ideograph", "Ideographic"},
    31511: {"Unified_Ideograph", "Ideographic"},
    31512: {"Unified_Ideograph", "Ideographic"},
    31513: {"Unified_Ideograph", "Ideographic"},
    31514: {"Unified_Ideograph", "Ideographic"},
    31515: {"Unified_Ideograph", "Ideographic"},
    31516: {"Unified_Ideograph", "Ideographic"},
    31517: {"Unified_Ideograph", "Ideographic"},
    31518: {"Unified_Ideograph", "Ideographic"},
    31519: {"Unified_Ideograph", "Ideographic"},
    31520: {"Unified_Ideograph", "Ideographic"},
    31521: {"Unified_Ideograph", "Ideographic"},
    31522: {"Unified_Ideograph", "Ideographic"},
    31523: {"Unified_Ideograph", "Ideographic"},
    31524: {"Unified_Ideograph", "Ideographic"},
    31525: {"Unified_Ideograph", "Ideographic"},
    31526: {"Unified_Ideograph", "Ideographic"},
    31527: {"Unified_Ideograph", "Ideographic"},
    31528: {"Unified_Ideograph", "Ideographic"},
    31529: {"Unified_Ideograph", "Ideographic"},
    31530: {"Unified_Ideograph", "Ideographic"},
    31531: {"Unified_Ideograph", "Ideographic"},
    31532: {"Unified_Ideograph", "Ideographic"},
    31533: {"Unified_Ideograph", "Ideographic"},
    31534: {"Unified_Ideograph", "Ideographic"},
    31535: {"Unified_Ideograph", "Ideographic"},
    31536: {"Unified_Ideograph", "Ideographic"},
    31537: {"Unified_Ideograph", "Ideographic"},
    31538: {"Unified_Ideograph", "Ideographic"},
    31539: {"Unified_Ideograph", "Ideographic"},
    31540: {"Unified_Ideograph", "Ideographic"},
    31541: {"Unified_Ideograph", "Ideographic"},
    31542: {"Unified_Ideograph", "Ideographic"},
    31543: {"Unified_Ideograph", "Ideographic"},
    31544: {"Unified_Ideograph", "Ideographic"},
    31545: {"Unified_Ideograph", "Ideographic"},
    31546: {"Unified_Ideograph", "Ideographic"},
    31547: {"Unified_Ideograph", "Ideographic"},
    31548: {"Unified_Ideograph", "Ideographic"},
    31549: {"Unified_Ideograph", "Ideographic"},
    31550: {"Unified_Ideograph", "Ideographic"},
    31551: {"Unified_Ideograph", "Ideographic"},
    31552: {"Unified_Ideograph", "Ideographic"},
    31553: {"Unified_Ideograph", "Ideographic"},
    31554: {"Unified_Ideograph", "Ideographic"},
    31555: {"Unified_Ideograph", "Ideographic"},
    31556: {"Unified_Ideograph", "Ideographic"},
    31557: {"Unified_Ideograph", "Ideographic"},
    31558: {"Unified_Ideograph", "Ideographic"},
    31559: {"Unified_Ideograph", "Ideographic"},
    31560: {"Unified_Ideograph", "Ideographic"},
    31561: {"Unified_Ideograph", "Ideographic"},
    31562: {"Unified_Ideograph", "Ideographic"},
    31563: {"Unified_Ideograph", "Ideographic"},
    31564: {"Unified_Ideograph", "Ideographic"},
    31565: {"Unified_Ideograph", "Ideographic"},
    31566: {"Unified_Ideograph", "Ideographic"},
    31567: {"Unified_Ideograph", "Ideographic"},
    31568: {"Unified_Ideograph", "Ideographic"},
    31569: {"Unified_Ideograph", "Ideographic"},
    31570: {"Unified_Ideograph", "Ideographic"},
    31571: {"Unified_Ideograph", "Ideographic"},
    31572: {"Unified_Ideograph", "Ideographic"},
    31573: {"Unified_Ideograph", "Ideographic"},
    31574: {"Unified_Ideograph", "Ideographic"},
    31575: {"Unified_Ideograph", "Ideographic"},
    31576: {"Unified_Ideograph", "Ideographic"},
    31577: {"Unified_Ideograph", "Ideographic"},
    31578: {"Unified_Ideograph", "Ideographic"},
    31579: {"Unified_Ideograph", "Ideographic"},
    31580: {"Unified_Ideograph", "Ideographic"},
    31581: {"Unified_Ideograph", "Ideographic"},
    31582: {"Unified_Ideograph", "Ideographic"},
    31583: {"Unified_Ideograph", "Ideographic"},
    31584: {"Unified_Ideograph", "Ideographic"},
    31585: {"Unified_Ideograph", "Ideographic"},
    31586: {"Unified_Ideograph", "Ideographic"},
    31587: {"Unified_Ideograph", "Ideographic"},
    31588: {"Unified_Ideograph", "Ideographic"},
    31589: {"Unified_Ideograph", "Ideographic"},
    31590: {"Unified_Ideograph", "Ideographic"},
    31591: {"Unified_Ideograph", "Ideographic"},
    31592: {"Unified_Ideograph", "Ideographic"},
    31593: {"Unified_Ideograph", "Ideographic"},
    31594: {"Unified_Ideograph", "Ideographic"},
    31595: {"Unified_Ideograph", "Ideographic"},
    31596: {"Unified_Ideograph", "Ideographic"},
    31597: {"Unified_Ideograph", "Ideographic"},
    31598: {"Unified_Ideograph", "Ideographic"},
    31599: {"Unified_Ideograph", "Ideographic"},
    31600: {"Unified_Ideograph", "Ideographic"},
    31601: {"Unified_Ideograph", "Ideographic"},
    31602: {"Unified_Ideograph", "Ideographic"},
    31603: {"Unified_Ideograph", "Ideographic"},
    31604: {"Unified_Ideograph", "Ideographic"},
    31605: {"Unified_Ideograph", "Ideographic"},
    31606: {"Unified_Ideograph", "Ideographic"},
    31607: {"Unified_Ideograph", "Ideographic"},
    31608: {"Unified_Ideograph", "Ideographic"},
    31609: {"Unified_Ideograph", "Ideographic"},
    31610: {"Unified_Ideograph", "Ideographic"},
    31611: {"Unified_Ideograph", "Ideographic"},
    31612: {"Unified_Ideograph", "Ideographic"},
    31613: {"Unified_Ideograph", "Ideographic"},
    31614: {"Unified_Ideograph", "Ideographic"},
    31615: {"Unified_Ideograph", "Ideographic"},
    31616: {"Unified_Ideograph", "Ideographic"},
    31617: {"Unified_Ideograph", "Ideographic"},
    31618: {"Unified_Ideograph", "Ideographic"},
    31619: {"Unified_Ideograph", "Ideographic"},
    31620: {"Unified_Ideograph", "Ideographic"},
    31621: {"Unified_Ideograph", "Ideographic"},
    31622: {"Unified_Ideograph", "Ideographic"},
    31623: {"Unified_Ideograph", "Ideographic"},
    31624: {"Unified_Ideograph", "Ideographic"},
    31625: {"Unified_Ideograph", "Ideographic"},
    31626: {"Unified_Ideograph", "Ideographic"},
    31627: {"Unified_Ideograph", "Ideographic"},
    31628: {"Unified_Ideograph", "Ideographic"},
    31629: {"Unified_Ideograph", "Ideographic"},
    31630: {"Unified_Ideograph", "Ideographic"},
    31631: {"Unified_Ideograph", "Ideographic"},
    31632: {"Unified_Ideograph", "Ideographic"},
    31633: {"Unified_Ideograph", "Ideographic"},
    31634: {"Unified_Ideograph", "Ideographic"},
    31635: {"Unified_Ideograph", "Ideographic"},
    31636: {"Unified_Ideograph", "Ideographic"},
    31637: {"Unified_Ideograph", "Ideographic"},
    31638: {"Unified_Ideograph", "Ideographic"},
    31639: {"Unified_Ideograph", "Ideographic"},
    31640: {"Unified_Ideograph", "Ideographic"},
    31641: {"Unified_Ideograph", "Ideographic"},
    31642: {"Unified_Ideograph", "Ideographic"},
    31643: {"Unified_Ideograph", "Ideographic"},
    31644: {"Unified_Ideograph", "Ideographic"},
    31645: {"Unified_Ideograph", "Ideographic"},
    31646: {"Unified_Ideograph", "Ideographic"},
    31647: {"Unified_Ideograph", "Ideographic"},
    31648: {"Unified_Ideograph", "Ideographic"},
    31649: {"Unified_Ideograph", "Ideographic"},
    31650: {"Unified_Ideograph", "Ideographic"},
    31651: {"Unified_Ideograph", "Ideographic"},
    31652: {"Unified_Ideograph", "Ideographic"},
    31653: {"Unified_Ideograph", "Ideographic"},
    31654: {"Unified_Ideograph", "Ideographic"},
    31655: {"Unified_Ideograph", "Ideographic"},
    31656: {"Unified_Ideograph", "Ideographic"},
    31657: {"Unified_Ideograph", "Ideographic"},
    31658: {"Unified_Ideograph", "Ideographic"},
    31659: {"Unified_Ideograph", "Ideographic"},
    31660: {"Unified_Ideograph", "Ideographic"},
    31661: {"Unified_Ideograph", "Ideographic"},
    31662: {"Unified_Ideograph", "Ideographic"},
    31663: {"Unified_Ideograph", "Ideographic"},
    31664: {"Unified_Ideograph", "Ideographic"},
    31665: {"Unified_Ideograph", "Ideographic"},
    31666: {"Unified_Ideograph", "Ideographic"},
    31667: {"Unified_Ideograph", "Ideographic"},
    31668: {"Unified_Ideograph", "Ideographic"},
    31669: {"Unified_Ideograph", "Ideographic"},
    31670: {"Unified_Ideograph", "Ideographic"},
    31671: {"Unified_Ideograph", "Ideographic"},
    31672: {"Unified_Ideograph", "Ideographic"},
    31673: {"Unified_Ideograph", "Ideographic"},
    31674: {"Unified_Ideograph", "Ideographic"},
    31675: {"Unified_Ideograph", "Ideographic"},
    31676: {"Unified_Ideograph", "Ideographic"},
    31677: {"Unified_Ideograph", "Ideographic"},
    31678: {"Unified_Ideograph", "Ideographic"},
    31679: {"Unified_Ideograph", "Ideographic"},
    31680: {"Unified_Ideograph", "Ideographic"},
    31681: {"Unified_Ideograph", "Ideographic"},
    31682: {"Unified_Ideograph", "Ideographic"},
    31683: {"Unified_Ideograph", "Ideographic"},
    31684: {"Unified_Ideograph", "Ideographic"},
    31685: {"Unified_Ideograph", "Ideographic"},
    31686: {"Unified_Ideograph", "Ideographic"},
    31687: {"Unified_Ideograph", "Ideographic"},
    31688: {"Unified_Ideograph", "Ideographic"},
    31689: {"Unified_Ideograph", "Ideographic"},
    31690: {"Unified_Ideograph", "Ideographic"},
    31691: {"Unified_Ideograph", "Ideographic"},
    31692: {"Unified_Ideograph", "Ideographic"},
    31693: {"Unified_Ideograph", "Ideographic"},
    31694: {"Unified_Ideograph", "Ideographic"},
    31695: {"Unified_Ideograph", "Ideographic"},
    31696: {"Unified_Ideograph", "Ideographic"},
    31697: {"Unified_Ideograph", "Ideographic"},
    31698: {"Unified_Ideograph", "Ideographic"},
    31699: {"Unified_Ideograph", "Ideographic"},
    31700: {"Unified_Ideograph", "Ideographic"},
    31701: {"Unified_Ideograph", "Ideographic"},
    31702: {"Unified_Ideograph", "Ideographic"},
    31703: {"Unified_Ideograph", "Ideographic"},
    31704: {"Unified_Ideograph", "Ideographic"},
    31705: {"Unified_Ideograph", "Ideographic"},
    31706: {"Unified_Ideograph", "Ideographic"},
    31707: {"Unified_Ideograph", "Ideographic"},
    31708: {"Unified_Ideograph", "Ideographic"},
    31709: {"Unified_Ideograph", "Ideographic"},
    31710: {"Unified_Ideograph", "Ideographic"},
    31711: {"Unified_Ideograph", "Ideographic"},
    31712: {"Unified_Ideograph", "Ideographic"},
    31713: {"Unified_Ideograph", "Ideographic"},
    31714: {"Unified_Ideograph", "Ideographic"},
    31715: {"Unified_Ideograph", "Ideographic"},
    31716: {"Unified_Ideograph", "Ideographic"},
    31717: {"Unified_Ideograph", "Ideographic"},
    31718: {"Unified_Ideograph", "Ideographic"},
    31719: {"Unified_Ideograph", "Ideographic"},
    31720: {"Unified_Ideograph", "Ideographic"},
    31721: {"Unified_Ideograph", "Ideographic"},
    31722: {"Unified_Ideograph", "Ideographic"},
    31723: {"Unified_Ideograph", "Ideographic"},
    31724: {"Unified_Ideograph", "Ideographic"},
    31725: {"Unified_Ideograph", "Ideographic"},
    31726: {"Unified_Ideograph", "Ideographic"},
    31727: {"Unified_Ideograph", "Ideographic"},
    31728: {"Unified_Ideograph", "Ideographic"},
    31729: {"Unified_Ideograph", "Ideographic"},
    31730: {"Unified_Ideograph", "Ideographic"},
    31731: {"Unified_Ideograph", "Ideographic"},
    31732: {"Unified_Ideograph", "Ideographic"},
    31733: {"Unified_Ideograph", "Ideographic"},
    31734: {"Unified_Ideograph", "Ideographic"},
    31735: {"Unified_Ideograph", "Ideographic"},
    31736: {"Unified_Ideograph", "Ideographic"},
    31737: {"Unified_Ideograph", "Ideographic"},
    31738: {"Unified_Ideograph", "Ideographic"},
    31739: {"Unified_Ideograph", "Ideographic"},
    31740: {"Unified_Ideograph", "Ideographic"},
    31741: {"Unified_Ideograph", "Ideographic"},
    31742: {"Unified_Ideograph", "Ideographic"},
    31743: {"Unified_Ideograph", "Ideographic"},
    31744: {"Unified_Ideograph", "Ideographic"},
    31745: {"Unified_Ideograph", "Ideographic"},
    31746: {"Unified_Ideograph", "Ideographic"},
    31747: {"Unified_Ideograph", "Ideographic"},
    31748: {"Unified_Ideograph", "Ideographic"},
    31749: {"Unified_Ideograph", "Ideographic"},
    31750: {"Unified_Ideograph", "Ideographic"},
    31751: {"Unified_Ideograph", "Ideographic"},
    31752: {"Unified_Ideograph", "Ideographic"},
    31753: {"Unified_Ideograph", "Ideographic"},
    31754: {"Unified_Ideograph", "Ideographic"},
    31755: {"Unified_Ideograph", "Ideographic"},
    31756: {"Unified_Ideograph", "Ideographic"},
    31757: {"Unified_Ideograph", "Ideographic"},
    31758: {"Unified_Ideograph", "Ideographic"},
    31759: {"Unified_Ideograph", "Ideographic"},
    31760: {"Unified_Ideograph", "Ideographic"},
    31761: {"Unified_Ideograph", "Ideographic"},
    31762: {"Unified_Ideograph", "Ideographic"},
    31763: {"Unified_Ideograph", "Ideographic"},
    31764: {"Unified_Ideograph", "Ideographic"},
    31765: {"Unified_Ideograph", "Ideographic"},
    31766: {"Unified_Ideograph", "Ideographic"},
    31767: {"Unified_Ideograph", "Ideographic"},
    31768: {"Unified_Ideograph", "Ideographic"},
    31769: {"Unified_Ideograph", "Ideographic"},
    31770: {"Unified_Ideograph", "Ideographic"},
    31771: {"Unified_Ideograph", "Ideographic"},
    31772: {"Unified_Ideograph", "Ideographic"},
    31773: {"Unified_Ideograph", "Ideographic"},
    31774: {"Unified_Ideograph", "Ideographic"},
    31775: {"Unified_Ideograph", "Ideographic"},
    31776: {"Unified_Ideograph", "Ideographic"},
    31777: {"Unified_Ideograph", "Ideographic"},
    31778: {"Unified_Ideograph", "Ideographic"},
    31779: {"Unified_Ideograph", "Ideographic"},
    31780: {"Unified_Ideograph", "Ideographic"},
    31781: {"Unified_Ideograph", "Ideographic"},
    31782: {"Unified_Ideograph", "Ideographic"},
    31783: {"Unified_Ideograph", "Ideographic"},
    31784: {"Unified_Ideograph", "Ideographic"},
    31785: {"Unified_Ideograph", "Ideographic"},
    31786: {"Unified_Ideograph", "Ideographic"},
    31787: {"Unified_Ideograph", "Ideographic"},
    31788: {"Unified_Ideograph", "Ideographic"},
    31789: {"Unified_Ideograph", "Ideographic"},
    31790: {"Unified_Ideograph", "Ideographic"},
    31791: {"Unified_Ideograph", "Ideographic"},
    31792: {"Unified_Ideograph", "Ideographic"},
    31793: {"Unified_Ideograph", "Ideographic"},
    31794: {"Unified_Ideograph", "Ideographic"},
    31795: {"Unified_Ideograph", "Ideographic"},
    31796: {"Unified_Ideograph", "Ideographic"},
    31797: {"Unified_Ideograph", "Ideographic"},
    31798: {"Unified_Ideograph", "Ideographic"},
    31799: {"Unified_Ideograph", "Ideographic"},
    31800: {"Unified_Ideograph", "Ideographic"},
    31801: {"Unified_Ideograph", "Ideographic"},
    31802: {"Unified_Ideograph", "Ideographic"},
    31803: {"Unified_Ideograph", "Ideographic"},
    31804: {"Unified_Ideograph", "Ideographic"},
    31805: {"Unified_Ideograph", "Ideographic"},
    31806: {"Unified_Ideograph", "Ideographic"},
    31807: {"Unified_Ideograph", "Ideographic"},
    31808: {"Unified_Ideograph", "Ideographic"},
    31809: {"Unified_Ideograph", "Ideographic"},
    31810: {"Unified_Ideograph", "Ideographic"},
    31811: {"Unified_Ideograph", "Ideographic"},
    31812: {"Unified_Ideograph", "Ideographic"},
    31813: {"Unified_Ideograph", "Ideographic"},
    31814: {"Unified_Ideograph", "Ideographic"},
    31815: {"Unified_Ideograph", "Ideographic"},
    31816: {"Unified_Ideograph", "Ideographic"},
    31817: {"Unified_Ideograph", "Ideographic"},
    31818: {"Unified_Ideograph", "Ideographic"},
    31819: {"Unified_Ideograph", "Ideographic"},
    31820: {"Unified_Ideograph", "Ideographic"},
    31821: {"Unified_Ideograph", "Ideographic"},
    31822: {"Unified_Ideograph", "Ideographic"},
    31823: {"Unified_Ideograph", "Ideographic"},
    31824: {"Unified_Ideograph", "Ideographic"},
    31825: {"Unified_Ideograph", "Ideographic"},
    31826: {"Unified_Ideograph", "Ideographic"},
    31827: {"Unified_Ideograph", "Ideographic"},
    31828: {"Unified_Ideograph", "Ideographic"},
    31829: {"Unified_Ideograph", "Ideographic"},
    31830: {"Unified_Ideograph", "Ideographic"},
    31831: {"Unified_Ideograph", "Ideographic"},
    31832: {"Unified_Ideograph", "Ideographic"},
    31833: {"Unified_Ideograph", "Ideographic"},
    31834: {"Unified_Ideograph", "Ideographic"},
    31835: {"Unified_Ideograph", "Ideographic"},
    31836: {"Unified_Ideograph", "Ideographic"},
    31837: {"Unified_Ideograph", "Ideographic"},
    31838: {"Unified_Ideograph", "Ideographic"},
    31839: {"Unified_Ideograph", "Ideographic"},
    31840: {"Unified_Ideograph", "Ideographic"},
    31841: {"Unified_Ideograph", "Ideographic"},
    31842: {"Unified_Ideograph", "Ideographic"},
    31843: {"Unified_Ideograph", "Ideographic"},
    31844: {"Unified_Ideograph", "Ideographic"},
    31845: {"Unified_Ideograph", "Ideographic"},
    31846: {"Unified_Ideograph", "Ideographic"},
    31847: {"Unified_Ideograph", "Ideographic"},
    31848: {"Unified_Ideograph", "Ideographic"},
    31849: {"Unified_Ideograph", "Ideographic"},
    31850: {"Unified_Ideograph", "Ideographic"},
    31851: {"Unified_Ideograph", "Ideographic"},
    31852: {"Unified_Ideograph", "Ideographic"},
    31853: {"Unified_Ideograph", "Ideographic"},
    31854: {"Unified_Ideograph", "Ideographic"},
    31855: {"Unified_Ideograph", "Ideographic"},
    31856: {"Unified_Ideograph", "Ideographic"},
    31857: {"Unified_Ideograph", "Ideographic"},
    31858: {"Unified_Ideograph", "Ideographic"},
    31859: {"Unified_Ideograph", "Ideographic"},
    31860: {"Unified_Ideograph", "Ideographic"},
    31861: {"Unified_Ideograph", "Ideographic"},
    31862: {"Unified_Ideograph", "Ideographic"},
    31863: {"Unified_Ideograph", "Ideographic"},
    31864: {"Unified_Ideograph", "Ideographic"},
    31865: {"Unified_Ideograph", "Ideographic"},
    31866: {"Unified_Ideograph", "Ideographic"},
    31867: {"Unified_Ideograph", "Ideographic"},
    31868: {"Unified_Ideograph", "Ideographic"},
    31869: {"Unified_Ideograph", "Ideographic"},
    31870: {"Unified_Ideograph", "Ideographic"},
    31871: {"Unified_Ideograph", "Ideographic"},
    31872: {"Unified_Ideograph", "Ideographic"},
    31873: {"Unified_Ideograph", "Ideographic"},
    31874: {"Unified_Ideograph", "Ideographic"},
    31875: {"Unified_Ideograph", "Ideographic"},
    31876: {"Unified_Ideograph", "Ideographic"},
    31877: {"Unified_Ideograph", "Ideographic"},
    31878: {"Unified_Ideograph", "Ideographic"},
    31879: {"Unified_Ideograph", "Ideographic"},
    31880: {"Unified_Ideograph", "Ideographic"},
    31881: {"Unified_Ideograph", "Ideographic"},
    31882: {"Unified_Ideograph", "Ideographic"},
    31883: {"Unified_Ideograph", "Ideographic"},
    31884: {"Unified_Ideograph", "Ideographic"},
    31885: {"Unified_Ideograph", "Ideographic"},
    31886: {"Unified_Ideograph", "Ideographic"},
    31887: {"Unified_Ideograph", "Ideographic"},
    31888: {"Unified_Ideograph", "Ideographic"},
    31889: {"Unified_Ideograph", "Ideographic"},
    31890: {"Unified_Ideograph", "Ideographic"},
    31891: {"Unified_Ideograph", "Ideographic"},
    31892: {"Unified_Ideograph", "Ideographic"},
    31893: {"Unified_Ideograph", "Ideographic"},
    31894: {"Unified_Ideograph", "Ideographic"},
    31895: {"Unified_Ideograph", "Ideographic"},
    31896: {"Unified_Ideograph", "Ideographic"},
    31897: {"Unified_Ideograph", "Ideographic"},
    31898: {"Unified_Ideograph", "Ideographic"},
    31899: {"Unified_Ideograph", "Ideographic"},
    31900: {"Unified_Ideograph", "Ideographic"},
    31901: {"Unified_Ideograph", "Ideographic"},
    31902: {"Unified_Ideograph", "Ideographic"},
    31903: {"Unified_Ideograph", "Ideographic"},
    31904: {"Unified_Ideograph", "Ideographic"},
    31905: {"Unified_Ideograph", "Ideographic"},
    31906: {"Unified_Ideograph", "Ideographic"},
    31907: {"Unified_Ideograph", "Ideographic"},
    31908: {"Unified_Ideograph", "Ideographic"},
    31909: {"Unified_Ideograph", "Ideographic"},
    31910: {"Unified_Ideograph", "Ideographic"},
    31911: {"Unified_Ideograph", "Ideographic"},
    31912: {"Unified_Ideograph", "Ideographic"},
    31913: {"Unified_Ideograph", "Ideographic"},
    31914: {"Unified_Ideograph", "Ideographic"},
    31915: {"Unified_Ideograph", "Ideographic"},
    31916: {"Unified_Ideograph", "Ideographic"},
    31917: {"Unified_Ideograph", "Ideographic"},
    31918: {"Unified_Ideograph", "Ideographic"},
    31919: {"Unified_Ideograph", "Ideographic"},
    31920: {"Unified_Ideograph", "Ideographic"},
    31921: {"Unified_Ideograph", "Ideographic"},
    31922: {"Unified_Ideograph", "Ideographic"},
    31923: {"Unified_Ideograph", "Ideographic"},
    31924: {"Unified_Ideograph", "Ideographic"},
    31925: {"Unified_Ideograph", "Ideographic"},
    31926: {"Unified_Ideograph", "Ideographic"},
    31927: {"Unified_Ideograph", "Ideographic"},
    31928: {"Unified_Ideograph", "Ideographic"},
    31929: {"Unified_Ideograph", "Ideographic"},
    31930: {"Unified_Ideograph", "Ideographic"},
    31931: {"Unified_Ideograph", "Ideographic"},
    31932: {"Unified_Ideograph", "Ideographic"},
    31933: {"Unified_Ideograph", "Ideographic"},
    31934: {"Unified_Ideograph", "Ideographic"},
    31935: {"Unified_Ideograph", "Ideographic"},
    31936: {"Unified_Ideograph", "Ideographic"},
    31937: {"Unified_Ideograph", "Ideographic"},
    31938: {"Unified_Ideograph", "Ideographic"},
    31939: {"Unified_Ideograph", "Ideographic"},
    31940: {"Unified_Ideograph", "Ideographic"},
    31941: {"Unified_Ideograph", "Ideographic"},
    31942: {"Unified_Ideograph", "Ideographic"},
    31943: {"Unified_Ideograph", "Ideographic"},
    31944: {"Unified_Ideograph", "Ideographic"},
    31945: {"Unified_Ideograph", "Ideographic"},
    31946: {"Unified_Ideograph", "Ideographic"},
    31947: {"Unified_Ideograph", "Ideographic"},
    31948: {"Unified_Ideograph", "Ideographic"},
    31949: {"Unified_Ideograph", "Ideographic"},
    31950: {"Unified_Ideograph", "Ideographic"},
    31951: {"Unified_Ideograph", "Ideographic"},
    31952: {"Unified_Ideograph", "Ideographic"},
    31953: {"Unified_Ideograph", "Ideographic"},
    31954: {"Unified_Ideograph", "Ideographic"},
    31955: {"Unified_Ideograph", "Ideographic"},
    31956: {"Unified_Ideograph", "Ideographic"},
    31957: {"Unified_Ideograph", "Ideographic"},
    31958: {"Unified_Ideograph", "Ideographic"},
    31959: {"Unified_Ideograph", "Ideographic"},
    31960: {"Unified_Ideograph", "Ideographic"},
    31961: {"Unified_Ideograph", "Ideographic"},
    31962: {"Unified_Ideograph", "Ideographic"},
    31963: {"Unified_Ideograph", "Ideographic"},
    31964: {"Unified_Ideograph", "Ideographic"},
    31965: {"Unified_Ideograph", "Ideographic"},
    31966: {"Unified_Ideograph", "Ideographic"},
    31967: {"Unified_Ideograph", "Ideographic"},
    31968: {"Unified_Ideograph", "Ideographic"},
    31969: {"Unified_Ideograph", "Ideographic"},
    31970: {"Unified_Ideograph", "Ideographic"},
    31971: {"Unified_Ideograph", "Ideographic"},
    31972: {"Unified_Ideograph", "Ideographic"},
    31973: {"Unified_Ideograph", "Ideographic"},
    31974: {"Unified_Ideograph", "Ideographic"},
    31975: {"Unified_Ideograph", "Ideographic"},
    31976: {"Unified_Ideograph", "Ideographic"},
    31977: {"Unified_Ideograph", "Ideographic"},
    31978: {"Unified_Ideograph", "Ideographic"},
    31979: {"Unified_Ideograph", "Ideographic"},
    31980: {"Unified_Ideograph", "Ideographic"},
    31981: {"Unified_Ideograph", "Ideographic"},
    31982: {"Unified_Ideograph", "Ideographic"},
    31983: {"Unified_Ideograph", "Ideographic"},
    31984: {"Unified_Ideograph", "Ideographic"},
    31985: {"Unified_Ideograph", "Ideographic"},
    31986: {"Unified_Ideograph", "Ideographic"},
    31987: {"Unified_Ideograph", "Ideographic"},
    31988: {"Unified_Ideograph", "Ideographic"},
    31989: {"Unified_Ideograph", "Ideographic"},
    31990: {"Unified_Ideograph", "Ideographic"},
    31991: {"Unified_Ideograph", "Ideographic"},
    31992: {"Unified_Ideograph", "Ideographic"},
    31993: {"Unified_Ideograph", "Ideographic"},
    31994: {"Unified_Ideograph", "Ideographic"},
    31995: {"Unified_Ideograph", "Ideographic"},
    31996: {"Unified_Ideograph", "Ideographic"},
    31997: {"Unified_Ideograph", "Ideographic"},
    31998: {"Unified_Ideograph", "Ideographic"},
    31999: {"Unified_Ideograph", "Ideographic"},
    32000: {"Unified_Ideograph", "Ideographic"},
    32001: {"Unified_Ideograph", "Ideographic"},
    32002: {"Unified_Ideograph", "Ideographic"},
    32003: {"Unified_Ideograph", "Ideographic"},
    32004: {"Unified_Ideograph", "Ideographic"},
    32005: {"Unified_Ideograph", "Ideographic"},
    32006: {"Unified_Ideograph", "Ideographic"},
    32007: {"Unified_Ideograph", "Ideographic"},
    32008: {"Unified_Ideograph", "Ideographic"},
    32009: {"Unified_Ideograph", "Ideographic"},
    32010: {"Unified_Ideograph", "Ideographic"},
    32011: {"Unified_Ideograph", "Ideographic"},
    32012: {"Unified_Ideograph", "Ideographic"},
    32013: {"Unified_Ideograph", "Ideographic"},
    32014: {"Unified_Ideograph", "Ideographic"},
    32015: {"Unified_Ideograph", "Ideographic"},
    32016: {"Unified_Ideograph", "Ideographic"},
    32017: {"Unified_Ideograph", "Ideographic"},
    32018: {"Unified_Ideograph", "Ideographic"},
    32019: {"Unified_Ideograph", "Ideographic"},
    32020: {"Unified_Ideograph", "Ideographic"},
    32021: {"Unified_Ideograph", "Ideographic"},
    32022: {"Unified_Ideograph", "Ideographic"},
    32023: {"Unified_Ideograph", "Ideographic"},
    32024: {"Unified_Ideograph", "Ideographic"},
    32025: {"Unified_Ideograph", "Ideographic"},
    32026: {"Unified_Ideograph", "Ideographic"},
    32027: {"Unified_Ideograph", "Ideographic"},
    32028: {"Unified_Ideograph", "Ideographic"},
    32029: {"Unified_Ideograph", "Ideographic"},
    32030: {"Unified_Ideograph", "Ideographic"},
    32031: {"Unified_Ideograph", "Ideographic"},
    32032: {"Unified_Ideograph", "Ideographic"},
    32033: {"Unified_Ideograph", "Ideographic"},
    32034: {"Unified_Ideograph", "Ideographic"},
    32035: {"Unified_Ideograph", "Ideographic"},
    32036: {"Unified_Ideograph", "Ideographic"},
    32037: {"Unified_Ideograph", "Ideographic"},
    32038: {"Unified_Ideograph", "Ideographic"},
    32039: {"Unified_Ideograph", "Ideographic"},
    32040: {"Unified_Ideograph", "Ideographic"},
    32041: {"Unified_Ideograph", "Ideographic"},
    32042: {"Unified_Ideograph", "Ideographic"},
    32043: {"Unified_Ideograph", "Ideographic"},
    32044: {"Unified_Ideograph", "Ideographic"},
    32045: {"Unified_Ideograph", "Ideographic"},
    32046: {"Unified_Ideograph", "Ideographic"},
    32047: {"Unified_Ideograph", "Ideographic"},
    32048: {"Unified_Ideograph", "Ideographic"},
    32049: {"Unified_Ideograph", "Ideographic"},
    32050: {"Unified_Ideograph", "Ideographic"},
    32051: {"Unified_Ideograph", "Ideographic"},
    32052: {"Unified_Ideograph", "Ideographic"},
    32053: {"Unified_Ideograph", "Ideographic"},
    32054: {"Unified_Ideograph", "Ideographic"},
    32055: {"Unified_Ideograph", "Ideographic"},
    32056: {"Unified_Ideograph", "Ideographic"},
    32057: {"Unified_Ideograph", "Ideographic"},
    32058: {"Unified_Ideograph", "Ideographic"},
    32059: {"Unified_Ideograph", "Ideographic"},
    32060: {"Unified_Ideograph", "Ideographic"},
    32061: {"Unified_Ideograph", "Ideographic"},
    32062: {"Unified_Ideograph", "Ideographic"},
    32063: {"Unified_Ideograph", "Ideographic"},
    32064: {"Unified_Ideograph", "Ideographic"},
    32065: {"Unified_Ideograph", "Ideographic"},
    32066: {"Unified_Ideograph", "Ideographic"},
    32067: {"Unified_Ideograph", "Ideographic"},
    32068: {"Unified_Ideograph", "Ideographic"},
    32069: {"Unified_Ideograph", "Ideographic"},
    32070: {"Unified_Ideograph", "Ideographic"},
    32071: {"Unified_Ideograph", "Ideographic"},
    32072: {"Unified_Ideograph", "Ideographic"},
    32073: {"Unified_Ideograph", "Ideographic"},
    32074: {"Unified_Ideograph", "Ideographic"},
    32075: {"Unified_Ideograph", "Ideographic"},
    32076: {"Unified_Ideograph", "Ideographic"},
    32077: {"Unified_Ideograph", "Ideographic"},
    32078: {"Unified_Ideograph", "Ideographic"},
    32079: {"Unified_Ideograph", "Ideographic"},
    32080: {"Unified_Ideograph", "Ideographic"},
    32081: {"Unified_Ideograph", "Ideographic"},
    32082: {"Unified_Ideograph", "Ideographic"},
    32083: {"Unified_Ideograph", "Ideographic"},
    32084: {"Unified_Ideograph", "Ideographic"},
    32085: {"Unified_Ideograph", "Ideographic"},
    32086: {"Unified_Ideograph", "Ideographic"},
    32087: {"Unified_Ideograph", "Ideographic"},
    32088: {"Unified_Ideograph", "Ideographic"},
    32089: {"Unified_Ideograph", "Ideographic"},
    32090: {"Unified_Ideograph", "Ideographic"},
    32091: {"Unified_Ideograph", "Ideographic"},
    32092: {"Unified_Ideograph", "Ideographic"},
    32093: {"Unified_Ideograph", "Ideographic"},
    32094: {"Unified_Ideograph", "Ideographic"},
    32095: {"Unified_Ideograph", "Ideographic"},
    32096: {"Unified_Ideograph", "Ideographic"},
    32097: {"Unified_Ideograph", "Ideographic"},
    32098: {"Unified_Ideograph", "Ideographic"},
    32099: {"Unified_Ideograph", "Ideographic"},
    32100: {"Unified_Ideograph", "Ideographic"},
    32101: {"Unified_Ideograph", "Ideographic"},
    32102: {"Unified_Ideograph", "Ideographic"},
    32103: {"Unified_Ideograph", "Ideographic"},
    32104: {"Unified_Ideograph", "Ideographic"},
    32105: {"Unified_Ideograph", "Ideographic"},
    32106: {"Unified_Ideograph", "Ideographic"},
    32107: {"Unified_Ideograph", "Ideographic"},
    32108: {"Unified_Ideograph", "Ideographic"},
    32109: {"Unified_Ideograph", "Ideographic"},
    32110: {"Unified_Ideograph", "Ideographic"},
    32111: {"Unified_Ideograph", "Ideographic"},
    32112: {"Unified_Ideograph", "Ideographic"},
    32113: {"Unified_Ideograph", "Ideographic"},
    32114: {"Unified_Ideograph", "Ideographic"},
    32115: {"Unified_Ideograph", "Ideographic"},
    32116: {"Unified_Ideograph", "Ideographic"},
    32117: {"Unified_Ideograph", "Ideographic"},
    32118: {"Unified_Ideograph", "Ideographic"},
    32119: {"Unified_Ideograph", "Ideographic"},
    32120: {"Unified_Ideograph", "Ideographic"},
    32121: {"Unified_Ideograph", "Ideographic"},
    32122: {"Unified_Ideograph", "Ideographic"},
    32123: {"Unified_Ideograph", "Ideographic"},
    32124: {"Unified_Ideograph", "Ideographic"},
    32125: {"Unified_Ideograph", "Ideographic"},
    32126: {"Unified_Ideograph", "Ideographic"},
    32127: {"Unified_Ideograph", "Ideographic"},
    32128: {"Unified_Ideograph", "Ideographic"},
    32129: {"Unified_Ideograph", "Ideographic"},
    32130: {"Unified_Ideograph", "Ideographic"},
    32131: {"Unified_Ideograph", "Ideographic"},
    32132: {"Unified_Ideograph", "Ideographic"},
    32133: {"Unified_Ideograph", "Ideographic"},
    32134: {"Unified_Ideograph", "Ideographic"},
    32135: {"Unified_Ideograph", "Ideographic"},
    32136: {"Unified_Ideograph", "Ideographic"},
    32137: {"Unified_Ideograph", "Ideographic"},
    32138: {"Unified_Ideograph", "Ideographic"},
    32139: {"Unified_Ideograph", "Ideographic"},
    32140: {"Unified_Ideograph", "Ideographic"},
    32141: {"Unified_Ideograph", "Ideographic"},
    32142: {"Unified_Ideograph", "Ideographic"},
    32143: {"Unified_Ideograph", "Ideographic"},
    32144: {"Unified_Ideograph", "Ideographic"},
    32145: {"Unified_Ideograph", "Ideographic"},
    32146: {"Unified_Ideograph", "Ideographic"},
    32147: {"Unified_Ideograph", "Ideographic"},
    32148: {"Unified_Ideograph", "Ideographic"},
    32149: {"Unified_Ideograph", "Ideographic"},
    32150: {"Unified_Ideograph", "Ideographic"},
    32151: {"Unified_Ideograph", "Ideographic"},
    32152: {"Unified_Ideograph", "Ideographic"},
    32153: {"Unified_Ideograph", "Ideographic"},
    32154: {"Unified_Ideograph", "Ideographic"},
    32155: {"Unified_Ideograph", "Ideographic"},
    32156: {"Unified_Ideograph", "Ideographic"},
    32157: {"Unified_Ideograph", "Ideographic"},
    32158: {"Unified_Ideograph", "Ideographic"},
    32159: {"Unified_Ideograph", "Ideographic"},
    32160: {"Unified_Ideograph", "Ideographic"},
    32161: {"Unified_Ideograph", "Ideographic"},
    32162: {"Unified_Ideograph", "Ideographic"},
    32163: {"Unified_Ideograph", "Ideographic"},
    32164: {"Unified_Ideograph", "Ideographic"},
    32165: {"Unified_Ideograph", "Ideographic"},
    32166: {"Unified_Ideograph", "Ideographic"},
    32167: {"Unified_Ideograph", "Ideographic"},
    32168: {"Unified_Ideograph", "Ideographic"},
    32169: {"Unified_Ideograph", "Ideographic"},
    32170: {"Unified_Ideograph", "Ideographic"},
    32171: {"Unified_Ideograph", "Ideographic"},
    32172: {"Unified_Ideograph", "Ideographic"},
    32173: {"Unified_Ideograph", "Ideographic"},
    32174: {"Unified_Ideograph", "Ideographic"},
    32175: {"Unified_Ideograph", "Ideographic"},
    32176: {"Unified_Ideograph", "Ideographic"},
    32177: {"Unified_Ideograph", "Ideographic"},
    32178: {"Unified_Ideograph", "Ideographic"},
    32179: {"Unified_Ideograph", "Ideographic"},
    32180: {"Unified_Ideograph", "Ideographic"},
    32181: {"Unified_Ideograph", "Ideographic"},
    32182: {"Unified_Ideograph", "Ideographic"},
    32183: {"Unified_Ideograph", "Ideographic"},
    32184: {"Unified_Ideograph", "Ideographic"},
    32185: {"Unified_Ideograph", "Ideographic"},
    32186: {"Unified_Ideograph", "Ideographic"},
    32187: {"Unified_Ideograph", "Ideographic"},
    32188: {"Unified_Ideograph", "Ideographic"},
    32189: {"Unified_Ideograph", "Ideographic"},
    32190: {"Unified_Ideograph", "Ideographic"},
    32191: {"Unified_Ideograph", "Ideographic"},
    32192: {"Unified_Ideograph", "Ideographic"},
    32193: {"Unified_Ideograph", "Ideographic"},
    32194: {"Unified_Ideograph", "Ideographic"},
    32195: {"Unified_Ideograph", "Ideographic"},
    32196: {"Unified_Ideograph", "Ideographic"},
    32197: {"Unified_Ideograph", "Ideographic"},
    32198: {"Unified_Ideograph", "Ideographic"},
    32199: {"Unified_Ideograph", "Ideographic"},
    32200: {"Unified_Ideograph", "Ideographic"},
    32201: {"Unified_Ideograph", "Ideographic"},
    32202: {"Unified_Ideograph", "Ideographic"},
    32203: {"Unified_Ideograph", "Ideographic"},
    32204: {"Unified_Ideograph", "Ideographic"},
    32205: {"Unified_Ideograph", "Ideographic"},
    32206: {"Unified_Ideograph", "Ideographic"},
    32207: {"Unified_Ideograph", "Ideographic"},
    32208: {"Unified_Ideograph", "Ideographic"},
    32209: {"Unified_Ideograph", "Ideographic"},
    32210: {"Unified_Ideograph", "Ideographic"},
    32211: {"Unified_Ideograph", "Ideographic"},
    32212: {"Unified_Ideograph", "Ideographic"},
    32213: {"Unified_Ideograph", "Ideographic"},
    32214: {"Unified_Ideograph", "Ideographic"},
    32215: {"Unified_Ideograph", "Ideographic"},
    32216: {"Unified_Ideograph", "Ideographic"},
    32217: {"Unified_Ideograph", "Ideographic"},
    32218: {"Unified_Ideograph", "Ideographic"},
    32219: {"Unified_Ideograph", "Ideographic"},
    32220: {"Unified_Ideograph", "Ideographic"},
    32221: {"Unified_Ideograph", "Ideographic"},
    32222: {"Unified_Ideograph", "Ideographic"},
    32223: {"Unified_Ideograph", "Ideographic"},
    32224: {"Unified_Ideograph", "Ideographic"},
    32225: {"Unified_Ideograph", "Ideographic"},
    32226: {"Unified_Ideograph", "Ideographic"},
    32227: {"Unified_Ideograph", "Ideographic"},
    32228: {"Unified_Ideograph", "Ideographic"},
    32229: {"Unified_Ideograph", "Ideographic"},
    32230: {"Unified_Ideograph", "Ideographic"},
    32231: {"Unified_Ideograph", "Ideographic"},
    32232: {"Unified_Ideograph", "Ideographic"},
    32233: {"Unified_Ideograph", "Ideographic"},
    32234: {"Unified_Ideograph", "Ideographic"},
    32235: {"Unified_Ideograph", "Ideographic"},
    32236: {"Unified_Ideograph", "Ideographic"},
    32237: {"Unified_Ideograph", "Ideographic"},
    32238: {"Unified_Ideograph", "Ideographic"},
    32239: {"Unified_Ideograph", "Ideographic"},
    32240: {"Unified_Ideograph", "Ideographic"},
    32241: {"Unified_Ideograph", "Ideographic"},
    32242: {"Unified_Ideograph", "Ideographic"},
    32243: {"Unified_Ideograph", "Ideographic"},
    32244: {"Unified_Ideograph", "Ideographic"},
    32245: {"Unified_Ideograph", "Ideographic"},
    32246: {"Unified_Ideograph", "Ideographic"},
    32247: {"Unified_Ideograph", "Ideographic"},
    32248: {"Unified_Ideograph", "Ideographic"},
    32249: {"Unified_Ideograph", "Ideographic"},
    32250: {"Unified_Ideograph", "Ideographic"},
    32251: {"Unified_Ideograph", "Ideographic"},
    32252: {"Unified_Ideograph", "Ideographic"},
    32253: {"Unified_Ideograph", "Ideographic"},
    32254: {"Unified_Ideograph", "Ideographic"},
    32255: {"Unified_Ideograph", "Ideographic"},
    32256: {"Unified_Ideograph", "Ideographic"},
    32257: {"Unified_Ideograph", "Ideographic"},
    32258: {"Unified_Ideograph", "Ideographic"},
    32259: {"Unified_Ideograph", "Ideographic"},
    32260: {"Unified_Ideograph", "Ideographic"},
    32261: {"Unified_Ideograph", "Ideographic"},
    32262: {"Unified_Ideograph", "Ideographic"},
    32263: {"Unified_Ideograph", "Ideographic"},
    32264: {"Unified_Ideograph", "Ideographic"},
    32265: {"Unified_Ideograph", "Ideographic"},
    32266: {"Unified_Ideograph", "Ideographic"},
    32267: {"Unified_Ideograph", "Ideographic"},
    32268: {"Unified_Ideograph", "Ideographic"},
    32269: {"Unified_Ideograph", "Ideographic"},
    32270: {"Unified_Ideograph", "Ideographic"},
    32271: {"Unified_Ideograph", "Ideographic"},
    32272: {"Unified_Ideograph", "Ideographic"},
    32273: {"Unified_Ideograph", "Ideographic"},
    32274: {"Unified_Ideograph", "Ideographic"},
    32275: {"Unified_Ideograph", "Ideographic"},
    32276: {"Unified_Ideograph", "Ideographic"},
    32277: {"Unified_Ideograph", "Ideographic"},
    32278: {"Unified_Ideograph", "Ideographic"},
    32279: {"Unified_Ideograph", "Ideographic"},
    32280: {"Unified_Ideograph", "Ideographic"},
    32281: {"Unified_Ideograph", "Ideographic"},
    32282: {"Unified_Ideograph", "Ideographic"},
    32283: {"Unified_Ideograph", "Ideographic"},
    32284: {"Unified_Ideograph", "Ideographic"},
    32285: {"Unified_Ideograph", "Ideographic"},
    32286: {"Unified_Ideograph", "Ideographic"},
    32287: {"Unified_Ideograph", "Ideographic"},
    32288: {"Unified_Ideograph", "Ideographic"},
    32289: {"Unified_Ideograph", "Ideographic"},
    32290: {"Unified_Ideograph", "Ideographic"},
    32291: {"Unified_Ideograph", "Ideographic"},
    32292: {"Unified_Ideograph", "Ideographic"},
    32293: {"Unified_Ideograph", "Ideographic"},
    32294: {"Unified_Ideograph", "Ideographic"},
    32295: {"Unified_Ideograph", "Ideographic"},
    32296: {"Unified_Ideograph", "Ideographic"},
    32297: {"Unified_Ideograph", "Ideographic"},
    32298: {"Unified_Ideograph", "Ideographic"},
    32299: {"Unified_Ideograph", "Ideographic"},
    32300: {"Unified_Ideograph", "Ideographic"},
    32301: {"Unified_Ideograph", "Ideographic"},
    32302: {"Unified_Ideograph", "Ideographic"},
    32303: {"Unified_Ideograph", "Ideographic"},
    32304: {"Unified_Ideograph", "Ideographic"},
    32305: {"Unified_Ideograph", "Ideographic"},
    32306: {"Unified_Ideograph", "Ideographic"},
    32307: {"Unified_Ideograph", "Ideographic"},
    32308: {"Unified_Ideograph", "Ideographic"},
    32309: {"Unified_Ideograph", "Ideographic"},
    32310: {"Unified_Ideograph", "Ideographic"},
    32311: {"Unified_Ideograph", "Ideographic"},
    32312: {"Unified_Ideograph", "Ideographic"},
    32313: {"Unified_Ideograph", "Ideographic"},
    32314: {"Unified_Ideograph", "Ideographic"},
    32315: {"Unified_Ideograph", "Ideographic"},
    32316: {"Unified_Ideograph", "Ideographic"},
    32317: {"Unified_Ideograph", "Ideographic"},
    32318: {"Unified_Ideograph", "Ideographic"},
    32319: {"Unified_Ideograph", "Ideographic"},
    32320: {"Unified_Ideograph", "Ideographic"},
    32321: {"Unified_Ideograph", "Ideographic"},
    32322: {"Unified_Ideograph", "Ideographic"},
    32323: {"Unified_Ideograph", "Ideographic"},
    32324: {"Unified_Ideograph", "Ideographic"},
    32325: {"Unified_Ideograph", "Ideographic"},
    32326: {"Unified_Ideograph", "Ideographic"},
    32327: {"Unified_Ideograph", "Ideographic"},
    32328: {"Unified_Ideograph", "Ideographic"},
    32329: {"Unified_Ideograph", "Ideographic"},
    32330: {"Unified_Ideograph", "Ideographic"},
    32331: {"Unified_Ideograph", "Ideographic"},
    32332: {"Unified_Ideograph", "Ideographic"},
    32333: {"Unified_Ideograph", "Ideographic"},
    32334: {"Unified_Ideograph", "Ideographic"},
    32335: {"Unified_Ideograph", "Ideographic"},
    32336: {"Unified_Ideograph", "Ideographic"},
    32337: {"Unified_Ideograph", "Ideographic"},
    32338: {"Unified_Ideograph", "Ideographic"},
    32339: {"Unified_Ideograph", "Ideographic"},
    32340: {"Unified_Ideograph", "Ideographic"},
    32341: {"Unified_Ideograph", "Ideographic"},
    32342: {"Unified_Ideograph", "Ideographic"},
    32343: {"Unified_Ideograph", "Ideographic"},
    32344: {"Unified_Ideograph", "Ideographic"},
    32345: {"Unified_Ideograph", "Ideographic"},
    32346: {"Unified_Ideograph", "Ideographic"},
    32347: {"Unified_Ideograph", "Ideographic"},
    32348: {"Unified_Ideograph", "Ideographic"},
    32349: {"Unified_Ideograph", "Ideographic"},
    32350: {"Unified_Ideograph", "Ideographic"},
    32351: {"Unified_Ideograph", "Ideographic"},
    32352: {"Unified_Ideograph", "Ideographic"},
    32353: {"Unified_Ideograph", "Ideographic"},
    32354: {"Unified_Ideograph", "Ideographic"},
    32355: {"Unified_Ideograph", "Ideographic"},
    32356: {"Unified_Ideograph", "Ideographic"},
    32357: {"Unified_Ideograph", "Ideographic"},
    32358: {"Unified_Ideograph", "Ideographic"},
    32359: {"Unified_Ideograph", "Ideographic"},
    32360: {"Unified_Ideograph", "Ideographic"},
    32361: {"Unified_Ideograph", "Ideographic"},
    32362: {"Unified_Ideograph", "Ideographic"},
    32363: {"Unified_Ideograph", "Ideographic"},
    32364: {"Unified_Ideograph", "Ideographic"},
    32365: {"Unified_Ideograph", "Ideographic"},
    32366: {"Unified_Ideograph", "Ideographic"},
    32367: {"Unified_Ideograph", "Ideographic"},
    32368: {"Unified_Ideograph", "Ideographic"},
    32369: {"Unified_Ideograph", "Ideographic"},
    32370: {"Unified_Ideograph", "Ideographic"},
    32371: {"Unified_Ideograph", "Ideographic"},
    32372: {"Unified_Ideograph", "Ideographic"},
    32373: {"Unified_Ideograph", "Ideographic"},
    32374: {"Unified_Ideograph", "Ideographic"},
    32375: {"Unified_Ideograph", "Ideographic"},
    32376: {"Unified_Ideograph", "Ideographic"},
    32377: {"Unified_Ideograph", "Ideographic"},
    32378: {"Unified_Ideograph", "Ideographic"},
    32379: {"Unified_Ideograph", "Ideographic"},
    32380: {"Unified_Ideograph", "Ideographic"},
    32381: {"Unified_Ideograph", "Ideographic"},
    32382: {"Unified_Ideograph", "Ideographic"},
    32383: {"Unified_Ideograph", "Ideographic"},
    32384: {"Unified_Ideograph", "Ideographic"},
    32385: {"Unified_Ideograph", "Ideographic"},
    32386: {"Unified_Ideograph", "Ideographic"},
    32387: {"Unified_Ideograph", "Ideographic"},
    32388: {"Unified_Ideograph", "Ideographic"},
    32389: {"Unified_Ideograph", "Ideographic"},
    32390: {"Unified_Ideograph", "Ideographic"},
    32391: {"Unified_Ideograph", "Ideographic"},
    32392: {"Unified_Ideograph", "Ideographic"},
    32393: {"Unified_Ideograph", "Ideographic"},
    32394: {"Unified_Ideograph", "Ideographic"},
    32395: {"Unified_Ideograph", "Ideographic"},
    32396: {"Unified_Ideograph", "Ideographic"},
    32397: {"Unified_Ideograph", "Ideographic"},
    32398: {"Unified_Ideograph", "Ideographic"},
    32399: {"Unified_Ideograph", "Ideographic"},
    32400: {"Unified_Ideograph", "Ideographic"},
    32401: {"Unified_Ideograph", "Ideographic"},
    32402: {"Unified_Ideograph", "Ideographic"},
    32403: {"Unified_Ideograph", "Ideographic"},
    32404: {"Unified_Ideograph", "Ideographic"},
    32405: {"Unified_Ideograph", "Ideographic"},
    32406: {"Unified_Ideograph", "Ideographic"},
    32407: {"Unified_Ideograph", "Ideographic"},
    32408: {"Unified_Ideograph", "Ideographic"},
    32409: {"Unified_Ideograph", "Ideographic"},
    32410: {"Unified_Ideograph", "Ideographic"},
    32411: {"Unified_Ideograph", "Ideographic"},
    32412: {"Unified_Ideograph", "Ideographic"},
    32413: {"Unified_Ideograph", "Ideographic"},
    32414: {"Unified_Ideograph", "Ideographic"},
    32415: {"Unified_Ideograph", "Ideographic"},
    32416: {"Unified_Ideograph", "Ideographic"},
    32417: {"Unified_Ideograph", "Ideographic"},
    32418: {"Unified_Ideograph", "Ideographic"},
    32419: {"Unified_Ideograph", "Ideographic"},
    32420: {"Unified_Ideograph", "Ideographic"},
    32421: {"Unified_Ideograph", "Ideographic"},
    32422: {"Unified_Ideograph", "Ideographic"},
    32423: {"Unified_Ideograph", "Ideographic"},
    32424: {"Unified_Ideograph", "Ideographic"},
    32425: {"Unified_Ideograph", "Ideographic"},
    32426: {"Unified_Ideograph", "Ideographic"},
    32427: {"Unified_Ideograph", "Ideographic"},
    32428: {"Unified_Ideograph", "Ideographic"},
    32429: {"Unified_Ideograph", "Ideographic"},
    32430: {"Unified_Ideograph", "Ideographic"},
    32431: {"Unified_Ideograph", "Ideographic"},
    32432: {"Unified_Ideograph", "Ideographic"},
    32433: {"Unified_Ideograph", "Ideographic"},
    32434: {"Unified_Ideograph", "Ideographic"},
    32435: {"Unified_Ideograph", "Ideographic"},
    32436: {"Unified_Ideograph", "Ideographic"},
    32437: {"Unified_Ideograph", "Ideographic"},
    32438: {"Unified_Ideograph", "Ideographic"},
    32439: {"Unified_Ideograph", "Ideographic"},
    32440: {"Unified_Ideograph", "Ideographic"},
    32441: {"Unified_Ideograph", "Ideographic"},
    32442: {"Unified_Ideograph", "Ideographic"},
    32443: {"Unified_Ideograph", "Ideographic"},
    32444: {"Unified_Ideograph", "Ideographic"},
    32445: {"Unified_Ideograph", "Ideographic"},
    32446: {"Unified_Ideograph", "Ideographic"},
    32447: {"Unified_Ideograph", "Ideographic"},
    32448: {"Unified_Ideograph", "Ideographic"},
    32449: {"Unified_Ideograph", "Ideographic"},
    32450: {"Unified_Ideograph", "Ideographic"},
    32451: {"Unified_Ideograph", "Ideographic"},
    32452: {"Unified_Ideograph", "Ideographic"},
    32453: {"Unified_Ideograph", "Ideographic"},
    32454: {"Unified_Ideograph", "Ideographic"},
    32455: {"Unified_Ideograph", "Ideographic"},
    32456: {"Unified_Ideograph", "Ideographic"},
    32457: {"Unified_Ideograph", "Ideographic"},
    32458: {"Unified_Ideograph", "Ideographic"},
    32459: {"Unified_Ideograph", "Ideographic"},
    32460: {"Unified_Ideograph", "Ideographic"},
    32461: {"Unified_Ideograph", "Ideographic"},
    32462: {"Unified_Ideograph", "Ideographic"},
    32463: {"Unified_Ideograph", "Ideographic"},
    32464: {"Unified_Ideograph", "Ideographic"},
    32465: {"Unified_Ideograph", "Ideographic"},
    32466: {"Unified_Ideograph", "Ideographic"},
    32467: {"Unified_Ideograph", "Ideographic"},
    32468: {"Unified_Ideograph", "Ideographic"},
    32469: {"Unified_Ideograph", "Ideographic"},
    32470: {"Unified_Ideograph", "Ideographic"},
    32471: {"Unified_Ideograph", "Ideographic"},
    32472: {"Unified_Ideograph", "Ideographic"},
    32473: {"Unified_Ideograph", "Ideographic"},
    32474: {"Unified_Ideograph", "Ideographic"},
    32475: {"Unified_Ideograph", "Ideographic"},
    32476: {"Unified_Ideograph", "Ideographic"},
    32477: {"Unified_Ideograph", "Ideographic"},
    32478: {"Unified_Ideograph", "Ideographic"},
    32479: {"Unified_Ideograph", "Ideographic"},
    32480: {"Unified_Ideograph", "Ideographic"},
    32481: {"Unified_Ideograph", "Ideographic"},
    32482: {"Unified_Ideograph", "Ideographic"},
    32483: {"Unified_Ideograph", "Ideographic"},
    32484: {"Unified_Ideograph", "Ideographic"},
    32485: {"Unified_Ideograph", "Ideographic"},
    32486: {"Unified_Ideograph", "Ideographic"},
    32487: {"Unified_Ideograph", "Ideographic"},
    32488: {"Unified_Ideograph", "Ideographic"},
    32489: {"Unified_Ideograph", "Ideographic"},
    32490: {"Unified_Ideograph", "Ideographic"},
    32491: {"Unified_Ideograph", "Ideographic"},
    32492: {"Unified_Ideograph", "Ideographic"},
    32493: {"Unified_Ideograph", "Ideographic"},
    32494: {"Unified_Ideograph", "Ideographic"},
    32495: {"Unified_Ideograph", "Ideographic"},
    32496: {"Unified_Ideograph", "Ideographic"},
    32497: {"Unified_Ideograph", "Ideographic"},
    32498: {"Unified_Ideograph", "Ideographic"},
    32499: {"Unified_Ideograph", "Ideographic"},
    32500: {"Unified_Ideograph", "Ideographic"},
    32501: {"Unified_Ideograph", "Ideographic"},
    32502: {"Unified_Ideograph", "Ideographic"},
    32503: {"Unified_Ideograph", "Ideographic"},
    32504: {"Unified_Ideograph", "Ideographic"},
    32505: {"Unified_Ideograph", "Ideographic"},
    32506: {"Unified_Ideograph", "Ideographic"},
    32507: {"Unified_Ideograph", "Ideographic"},
    32508: {"Unified_Ideograph", "Ideographic"},
    32509: {"Unified_Ideograph", "Ideographic"},
    32510: {"Unified_Ideograph", "Ideographic"},
    32511: {"Unified_Ideograph", "Ideographic"},
    32512: {"Unified_Ideograph", "Ideographic"},
    32513: {"Unified_Ideograph", "Ideographic"},
    32514: {"Unified_Ideograph", "Ideographic"},
    32515: {"Unified_Ideograph", "Ideographic"},
    32516: {"Unified_Ideograph", "Ideographic"},
    32517: {"Unified_Ideograph", "Ideographic"},
    32518: {"Unified_Ideograph", "Ideographic"},
    32519: {"Unified_Ideograph", "Ideographic"},
    32520: {"Unified_Ideograph", "Ideographic"},
    32521: {"Unified_Ideograph", "Ideographic"},
    32522: {"Unified_Ideograph", "Ideographic"},
    32523: {"Unified_Ideograph", "Ideographic"},
    32524: {"Unified_Ideograph", "Ideographic"},
    32525: {"Unified_Ideograph", "Ideographic"},
    32526: {"Unified_Ideograph", "Ideographic"},
    32527: {"Unified_Ideograph", "Ideographic"},
    32528: {"Unified_Ideograph", "Ideographic"},
    32529: {"Unified_Ideograph", "Ideographic"},
    32530: {"Unified_Ideograph", "Ideographic"},
    32531: {"Unified_Ideograph", "Ideographic"},
    32532: {"Unified_Ideograph", "Ideographic"},
    32533: {"Unified_Ideograph", "Ideographic"},
    32534: {"Unified_Ideograph", "Ideographic"},
    32535: {"Unified_Ideograph", "Ideographic"},
    32536: {"Unified_Ideograph", "Ideographic"},
    32537: {"Unified_Ideograph", "Ideographic"},
    32538: {"Unified_Ideograph", "Ideographic"},
    32539: {"Unified_Ideograph", "Ideographic"},
    32540: {"Unified_Ideograph", "Ideographic"},
    32541: {"Unified_Ideograph", "Ideographic"},
    32542: {"Unified_Ideograph", "Ideographic"},
    32543: {"Unified_Ideograph", "Ideographic"},
    32544: {"Unified_Ideograph", "Ideographic"},
    32545: {"Unified_Ideograph", "Ideographic"},
    32546: {"Unified_Ideograph", "Ideographic"},
    32547: {"Unified_Ideograph", "Ideographic"},
    32548: {"Unified_Ideograph", "Ideographic"},
    32549: {"Unified_Ideograph", "Ideographic"},
    32550: {"Unified_Ideograph", "Ideographic"},
    32551: {"Unified_Ideograph", "Ideographic"},
    32552: {"Unified_Ideograph", "Ideographic"},
    32553: {"Unified_Ideograph", "Ideographic"},
    32554: {"Unified_Ideograph", "Ideographic"},
    32555: {"Unified_Ideograph", "Ideographic"},
    32556: {"Unified_Ideograph", "Ideographic"},
    32557: {"Unified_Ideograph", "Ideographic"},
    32558: {"Unified_Ideograph", "Ideographic"},
    32559: {"Unified_Ideograph", "Ideographic"},
    32560: {"Unified_Ideograph", "Ideographic"},
    32561: {"Unified_Ideograph", "Ideographic"},
    32562: {"Unified_Ideograph", "Ideographic"},
    32563: {"Unified_Ideograph", "Ideographic"},
    32564: {"Unified_Ideograph", "Ideographic"},
    32565: {"Unified_Ideograph", "Ideographic"},
    32566: {"Unified_Ideograph", "Ideographic"},
    32567: {"Unified_Ideograph", "Ideographic"},
    32568: {"Unified_Ideograph", "Ideographic"},
    32569: {"Unified_Ideograph", "Ideographic"},
    32570: {"Unified_Ideograph", "Ideographic"},
    32571: {"Unified_Ideograph", "Ideographic"},
    32572: {"Unified_Ideograph", "Ideographic"},
    32573: {"Unified_Ideograph", "Ideographic"},
    32574: {"Unified_Ideograph", "Ideographic"},
    32575: {"Unified_Ideograph", "Ideographic"},
    32576: {"Unified_Ideograph", "Ideographic"},
    32577: {"Unified_Ideograph", "Ideographic"},
    32578: {"Unified_Ideograph", "Ideographic"},
    32579: {"Unified_Ideograph", "Ideographic"},
    32580: {"Unified_Ideograph", "Ideographic"},
    32581: {"Unified_Ideograph", "Ideographic"},
    32582: {"Unified_Ideograph", "Ideographic"},
    32583: {"Unified_Ideograph", "Ideographic"},
    32584: {"Unified_Ideograph", "Ideographic"},
    32585: {"Unified_Ideograph", "Ideographic"},
    32586: {"Unified_Ideograph", "Ideographic"},
    32587: {"Unified_Ideograph", "Ideographic"},
    32588: {"Unified_Ideograph", "Ideographic"},
    32589: {"Unified_Ideograph", "Ideographic"},
    32590: {"Unified_Ideograph", "Ideographic"},
    32591: {"Unified_Ideograph", "Ideographic"},
    32592: {"Unified_Ideograph", "Ideographic"},
    32593: {"Unified_Ideograph", "Ideographic"},
    32594: {"Unified_Ideograph", "Ideographic"},
    32595: {"Unified_Ideograph", "Ideographic"},
    32596: {"Unified_Ideograph", "Ideographic"},
    32597: {"Unified_Ideograph", "Ideographic"},
    32598: {"Unified_Ideograph", "Ideographic"},
    32599: {"Unified_Ideograph", "Ideographic"},
    32600: {"Unified_Ideograph", "Ideographic"},
    32601: {"Unified_Ideograph", "Ideographic"},
    32602: {"Unified_Ideograph", "Ideographic"},
    32603: {"Unified_Ideograph", "Ideographic"},
    32604: {"Unified_Ideograph", "Ideographic"},
    32605: {"Unified_Ideograph", "Ideographic"},
    32606: {"Unified_Ideograph", "Ideographic"},
    32607: {"Unified_Ideograph", "Ideographic"},
    32608: {"Unified_Ideograph", "Ideographic"},
    32609: {"Unified_Ideograph", "Ideographic"},
    32610: {"Unified_Ideograph", "Ideographic"},
    32611: {"Unified_Ideograph", "Ideographic"},
    32612: {"Unified_Ideograph", "Ideographic"},
    32613: {"Unified_Ideograph", "Ideographic"},
    32614: {"Unified_Ideograph", "Ideographic"},
    32615: {"Unified_Ideograph", "Ideographic"},
    32616: {"Unified_Ideograph", "Ideographic"},
    32617: {"Unified_Ideograph", "Ideographic"},
    32618: {"Unified_Ideograph", "Ideographic"},
    32619: {"Unified_Ideograph", "Ideographic"},
    32620: {"Unified_Ideograph", "Ideographic"},
    32621: {"Unified_Ideograph", "Ideographic"},
    32622: {"Unified_Ideograph", "Ideographic"},
    32623: {"Unified_Ideograph", "Ideographic"},
    32624: {"Unified_Ideograph", "Ideographic"},
    32625: {"Unified_Ideograph", "Ideographic"},
    32626: {"Unified_Ideograph", "Ideographic"},
    32627: {"Unified_Ideograph", "Ideographic"},
    32628: {"Unified_Ideograph", "Ideographic"},
    32629: {"Unified_Ideograph", "Ideographic"},
    32630: {"Unified_Ideograph", "Ideographic"},
    32631: {"Unified_Ideograph", "Ideographic"},
    32632: {"Unified_Ideograph", "Ideographic"},
    32633: {"Unified_Ideograph", "Ideographic"},
    32634: {"Unified_Ideograph", "Ideographic"},
    32635: {"Unified_Ideograph", "Ideographic"},
    32636: {"Unified_Ideograph", "Ideographic"},
    32637: {"Unified_Ideograph", "Ideographic"},
    32638: {"Unified_Ideograph", "Ideographic"},
    32639: {"Unified_Ideograph", "Ideographic"},
    32640: {"Unified_Ideograph", "Ideographic"},
    32641: {"Unified_Ideograph", "Ideographic"},
    32642: {"Unified_Ideograph", "Ideographic"},
    32643: {"Unified_Ideograph", "Ideographic"},
    32644: {"Unified_Ideograph", "Ideographic"},
    32645: {"Unified_Ideograph", "Ideographic"},
    32646: {"Unified_Ideograph", "Ideographic"},
    32647: {"Unified_Ideograph", "Ideographic"},
    32648: {"Unified_Ideograph", "Ideographic"},
    32649: {"Unified_Ideograph", "Ideographic"},
    32650: {"Unified_Ideograph", "Ideographic"},
    32651: {"Unified_Ideograph", "Ideographic"},
    32652: {"Unified_Ideograph", "Ideographic"},
    32653: {"Unified_Ideograph", "Ideographic"},
    32654: {"Unified_Ideograph", "Ideographic"},
    32655: {"Unified_Ideograph", "Ideographic"},
    32656: {"Unified_Ideograph", "Ideographic"},
    32657: {"Unified_Ideograph", "Ideographic"},
    32658: {"Unified_Ideograph", "Ideographic"},
    32659: {"Unified_Ideograph", "Ideographic"},
    32660: {"Unified_Ideograph", "Ideographic"},
    32661: {"Unified_Ideograph", "Ideographic"},
    32662: {"Unified_Ideograph", "Ideographic"},
    32663: {"Unified_Ideograph", "Ideographic"},
    32664: {"Unified_Ideograph", "Ideographic"},
    32665: {"Unified_Ideograph", "Ideographic"},
    32666: {"Unified_Ideograph", "Ideographic"},
    32667: {"Unified_Ideograph", "Ideographic"},
    32668: {"Unified_Ideograph", "Ideographic"},
    32669: {"Unified_Ideograph", "Ideographic"},
    32670: {"Unified_Ideograph", "Ideographic"},
    32671: {"Unified_Ideograph", "Ideographic"},
    32672: {"Unified_Ideograph", "Ideographic"},
    32673: {"Unified_Ideograph", "Ideographic"},
    32674: {"Unified_Ideograph", "Ideographic"},
    32675: {"Unified_Ideograph", "Ideographic"},
    32676: {"Unified_Ideograph", "Ideographic"},
    32677: {"Unified_Ideograph", "Ideographic"},
    32678: {"Unified_Ideograph", "Ideographic"},
    32679: {"Unified_Ideograph", "Ideographic"},
    32680: {"Unified_Ideograph", "Ideographic"},
    32681: {"Unified_Ideograph", "Ideographic"},
    32682: {"Unified_Ideograph", "Ideographic"},
    32683: {"Unified_Ideograph", "Ideographic"},
    32684: {"Unified_Ideograph", "Ideographic"},
    32685: {"Unified_Ideograph", "Ideographic"},
    32686: {"Unified_Ideograph", "Ideographic"},
    32687: {"Unified_Ideograph", "Ideographic"},
    32688: {"Unified_Ideograph", "Ideographic"},
    32689: {"Unified_Ideograph", "Ideographic"},
    32690: {"Unified_Ideograph", "Ideographic"},
    32691: {"Unified_Ideograph", "Ideographic"},
    32692: {"Unified_Ideograph", "Ideographic"},
    32693: {"Unified_Ideograph", "Ideographic"},
    32694: {"Unified_Ideograph", "Ideographic"},
    32695: {"Unified_Ideograph", "Ideographic"},
    32696: {"Unified_Ideograph", "Ideographic"},
    32697: {"Unified_Ideograph", "Ideographic"},
    32698: {"Unified_Ideograph", "Ideographic"},
    32699: {"Unified_Ideograph", "Ideographic"},
    32700: {"Unified_Ideograph", "Ideographic"},
    32701: {"Unified_Ideograph", "Ideographic"},
    32702: {"Unified_Ideograph", "Ideographic"},
    32703: {"Unified_Ideograph", "Ideographic"},
    32704: {"Unified_Ideograph", "Ideographic"},
    32705: {"Unified_Ideograph", "Ideographic"},
    32706: {"Unified_Ideograph", "Ideographic"},
    32707: {"Unified_Ideograph", "Ideographic"},
    32708: {"Unified_Ideograph", "Ideographic"},
    32709: {"Unified_Ideograph", "Ideographic"},
    32710: {"Unified_Ideograph", "Ideographic"},
    32711: {"Unified_Ideograph", "Ideographic"},
    32712: {"Unified_Ideograph", "Ideographic"},
    32713: {"Unified_Ideograph", "Ideographic"},
    32714: {"Unified_Ideograph", "Ideographic"},
    32715: {"Unified_Ideograph", "Ideographic"},
    32716: {"Unified_Ideograph", "Ideographic"},
    32717: {"Unified_Ideograph", "Ideographic"},
    32718: {"Unified_Ideograph", "Ideographic"},
    32719: {"Unified_Ideograph", "Ideographic"},
    32720: {"Unified_Ideograph", "Ideographic"},
    32721: {"Unified_Ideograph", "Ideographic"},
    32722: {"Unified_Ideograph", "Ideographic"},
    32723: {"Unified_Ideograph", "Ideographic"},
    32724: {"Unified_Ideograph", "Ideographic"},
    32725: {"Unified_Ideograph", "Ideographic"},
    32726: {"Unified_Ideograph", "Ideographic"},
    32727: {"Unified_Ideograph", "Ideographic"},
    32728: {"Unified_Ideograph", "Ideographic"},
    32729: {"Unified_Ideograph", "Ideographic"},
    32730: {"Unified_Ideograph", "Ideographic"},
    32731: {"Unified_Ideograph", "Ideographic"},
    32732: {"Unified_Ideograph", "Ideographic"},
    32733: {"Unified_Ideograph", "Ideographic"},
    32734: {"Unified_Ideograph", "Ideographic"},
    32735: {"Unified_Ideograph", "Ideographic"},
    32736: {"Unified_Ideograph", "Ideographic"},
    32737: {"Unified_Ideograph", "Ideographic"},
    32738: {"Unified_Ideograph", "Ideographic"},
    32739: {"Unified_Ideograph", "Ideographic"},
    32740: {"Unified_Ideograph", "Ideographic"},
    32741: {"Unified_Ideograph", "Ideographic"},
    32742: {"Unified_Ideograph", "Ideographic"},
    32743: {"Unified_Ideograph", "Ideographic"},
    32744: {"Unified_Ideograph", "Ideographic"},
    32745: {"Unified_Ideograph", "Ideographic"},
    32746: {"Unified_Ideograph", "Ideographic"},
    32747: {"Unified_Ideograph", "Ideographic"},
    32748: {"Unified_Ideograph", "Ideographic"},
    32749: {"Unified_Ideograph", "Ideographic"},
    32750: {"Unified_Ideograph", "Ideographic"},
    32751: {"Unified_Ideograph", "Ideographic"},
    32752: {"Unified_Ideograph", "Ideographic"},
    32753: {"Unified_Ideograph", "Ideographic"},
    32754: {"Unified_Ideograph", "Ideographic"},
    32755: {"Unified_Ideograph", "Ideographic"},
    32756: {"Unified_Ideograph", "Ideographic"},
    32757: {"Unified_Ideograph", "Ideographic"},
    32758: {"Unified_Ideograph", "Ideographic"},
    32759: {"Unified_Ideograph", "Ideographic"},
    32760: {"Unified_Ideograph", "Ideographic"},
    32761: {"Unified_Ideograph", "Ideographic"},
    32762: {"Unified_Ideograph", "Ideographic"},
    32763: {"Unified_Ideograph", "Ideographic"},
    32764: {"Unified_Ideograph", "Ideographic"},
    32765: {"Unified_Ideograph", "Ideographic"},
    32766: {"Unified_Ideograph", "Ideographic"},
    32767: {"Unified_Ideograph", "Ideographic"},
    32768: {"Unified_Ideograph", "Ideographic"},
    32769: {"Unified_Ideograph", "Ideographic"},
    32770: {"Unified_Ideograph", "Ideographic"},
    32771: {"Unified_Ideograph", "Ideographic"},
    32772: {"Unified_Ideograph", "Ideographic"},
    32773: {"Unified_Ideograph", "Ideographic"},
    32774: {"Unified_Ideograph", "Ideographic"},
    32775: {"Unified_Ideograph", "Ideographic"},
    32776: {"Unified_Ideograph", "Ideographic"},
    32777: {"Unified_Ideograph", "Ideographic"},
    32778: {"Unified_Ideograph", "Ideographic"},
    32779: {"Unified_Ideograph", "Ideographic"},
    32780: {"Unified_Ideograph", "Ideographic"},
    32781: {"Unified_Ideograph", "Ideographic"},
    32782: {"Unified_Ideograph", "Ideographic"},
    32783: {"Unified_Ideograph", "Ideographic"},
    32784: {"Unified_Ideograph", "Ideographic"},
    32785: {"Unified_Ideograph", "Ideographic"},
    32786: {"Unified_Ideograph", "Ideographic"},
    32787: {"Unified_Ideograph", "Ideographic"},
    32788: {"Unified_Ideograph", "Ideographic"},
    32789: {"Unified_Ideograph", "Ideographic"},
    32790: {"Unified_Ideograph", "Ideographic"},
    32791: {"Unified_Ideograph", "Ideographic"},
    32792: {"Unified_Ideograph", "Ideographic"},
    32793: {"Unified_Ideograph", "Ideographic"},
    32794: {"Unified_Ideograph", "Ideographic"},
    32795: {"Unified_Ideograph", "Ideographic"},
    32796: {"Unified_Ideograph", "Ideographic"},
    32797: {"Unified_Ideograph", "Ideographic"},
    32798: {"Unified_Ideograph", "Ideographic"},
    32799: {"Unified_Ideograph", "Ideographic"},
    32800: {"Unified_Ideograph", "Ideographic"},
    32801: {"Unified_Ideograph", "Ideographic"},
    32802: {"Unified_Ideograph", "Ideographic"},
    32803: {"Unified_Ideograph", "Ideographic"},
    32804: {"Unified_Ideograph", "Ideographic"},
    32805: {"Unified_Ideograph", "Ideographic"},
    32806: {"Unified_Ideograph", "Ideographic"},
    32807: {"Unified_Ideograph", "Ideographic"},
    32808: {"Unified_Ideograph", "Ideographic"},
    32809: {"Unified_Ideograph", "Ideographic"},
    32810: {"Unified_Ideograph", "Ideographic"},
    32811: {"Unified_Ideograph", "Ideographic"},
    32812: {"Unified_Ideograph", "Ideographic"},
    32813: {"Unified_Ideograph", "Ideographic"},
    32814: {"Unified_Ideograph", "Ideographic"},
    32815: {"Unified_Ideograph", "Ideographic"},
    32816: {"Unified_Ideograph", "Ideographic"},
    32817: {"Unified_Ideograph", "Ideographic"},
    32818: {"Unified_Ideograph", "Ideographic"},
    32819: {"Unified_Ideograph", "Ideographic"},
    32820: {"Unified_Ideograph", "Ideographic"},
    32821: {"Unified_Ideograph", "Ideographic"},
    32822: {"Unified_Ideograph", "Ideographic"},
    32823: {"Unified_Ideograph", "Ideographic"},
    32824: {"Unified_Ideograph", "Ideographic"},
    32825: {"Unified_Ideograph", "Ideographic"},
    32826: {"Unified_Ideograph", "Ideographic"},
    32827: {"Unified_Ideograph", "Ideographic"},
    32828: {"Unified_Ideograph", "Ideographic"},
    32829: {"Unified_Ideograph", "Ideographic"},
    32830: {"Unified_Ideograph", "Ideographic"},
    32831: {"Unified_Ideograph", "Ideographic"},
    32832: {"Unified_Ideograph", "Ideographic"},
    32833: {"Unified_Ideograph", "Ideographic"},
    32834: {"Unified_Ideograph", "Ideographic"},
    32835: {"Unified_Ideograph", "Ideographic"},
    32836: {"Unified_Ideograph", "Ideographic"},
    32837: {"Unified_Ideograph", "Ideographic"},
    32838: {"Unified_Ideograph", "Ideographic"},
    32839: {"Unified_Ideograph", "Ideographic"},
    32840: {"Unified_Ideograph", "Ideographic"},
    32841: {"Unified_Ideograph", "Ideographic"},
    32842: {"Unified_Ideograph", "Ideographic"},
    32843: {"Unified_Ideograph", "Ideographic"},
    32844: {"Unified_Ideograph", "Ideographic"},
    32845: {"Unified_Ideograph", "Ideographic"},
    32846: {"Unified_Ideograph", "Ideographic"},
    32847: {"Unified_Ideograph", "Ideographic"},
    32848: {"Unified_Ideograph", "Ideographic"},
    32849: {"Unified_Ideograph", "Ideographic"},
    32850: {"Unified_Ideograph", "Ideographic"},
    32851: {"Unified_Ideograph", "Ideographic"},
    32852: {"Unified_Ideograph", "Ideographic"},
    32853: {"Unified_Ideograph", "Ideographic"},
    32854: {"Unified_Ideograph", "Ideographic"},
    32855: {"Unified_Ideograph", "Ideographic"},
    32856: {"Unified_Ideograph", "Ideographic"},
    32857: {"Unified_Ideograph", "Ideographic"},
    32858: {"Unified_Ideograph", "Ideographic"},
    32859: {"Unified_Ideograph", "Ideographic"},
    32860: {"Unified_Ideograph", "Ideographic"},
    32861: {"Unified_Ideograph", "Ideographic"},
    32862: {"Unified_Ideograph", "Ideographic"},
    32863: {"Unified_Ideograph", "Ideographic"},
    32864: {"Unified_Ideograph", "Ideographic"},
    32865: {"Unified_Ideograph", "Ideographic"},
    32866: {"Unified_Ideograph", "Ideographic"},
    32867: {"Unified_Ideograph", "Ideographic"},
    32868: {"Unified_Ideograph", "Ideographic"},
    32869: {"Unified_Ideograph", "Ideographic"},
    32870: {"Unified_Ideograph", "Ideographic"},
    32871: {"Unified_Ideograph", "Ideographic"},
    32872: {"Unified_Ideograph", "Ideographic"},
    32873: {"Unified_Ideograph", "Ideographic"},
    32874: {"Unified_Ideograph", "Ideographic"},
    32875: {"Unified_Ideograph", "Ideographic"},
    32876: {"Unified_Ideograph", "Ideographic"},
    32877: {"Unified_Ideograph", "Ideographic"},
    32878: {"Unified_Ideograph", "Ideographic"},
    32879: {"Unified_Ideograph", "Ideographic"},
    32880: {"Unified_Ideograph", "Ideographic"},
    32881: {"Unified_Ideograph", "Ideographic"},
    32882: {"Unified_Ideograph", "Ideographic"},
    32883: {"Unified_Ideograph", "Ideographic"},
    32884: {"Unified_Ideograph", "Ideographic"},
    32885: {"Unified_Ideograph", "Ideographic"},
    32886: {"Unified_Ideograph", "Ideographic"},
    32887: {"Unified_Ideograph", "Ideographic"},
    32888: {"Unified_Ideograph", "Ideographic"},
    32889: {"Unified_Ideograph", "Ideographic"},
    32890: {"Unified_Ideograph", "Ideographic"},
    32891: {"Unified_Ideograph", "Ideographic"},
    32892: {"Unified_Ideograph", "Ideographic"},
    32893: {"Unified_Ideograph", "Ideographic"},
    32894: {"Unified_Ideograph", "Ideographic"},
    32895: {"Unified_Ideograph", "Ideographic"},
    32896: {"Unified_Ideograph", "Ideographic"},
    32897: {"Unified_Ideograph", "Ideographic"},
    32898: {"Unified_Ideograph", "Ideographic"},
    32899: {"Unified_Ideograph", "Ideographic"},
    32900: {"Unified_Ideograph", "Ideographic"},
    32901: {"Unified_Ideograph", "Ideographic"},
    32902: {"Unified_Ideograph", "Ideographic"},
    32903: {"Unified_Ideograph", "Ideographic"},
    32904: {"Unified_Ideograph", "Ideographic"},
    32905: {"Unified_Ideograph", "Ideographic"},
    32906: {"Unified_Ideograph", "Ideographic"},
    32907: {"Unified_Ideograph", "Ideographic"},
    32908: {"Unified_Ideograph", "Ideographic"},
    32909: {"Unified_Ideograph", "Ideographic"},
    32910: {"Unified_Ideograph", "Ideographic"},
    32911: {"Unified_Ideograph", "Ideographic"},
    32912: {"Unified_Ideograph", "Ideographic"},
    32913: {"Unified_Ideograph", "Ideographic"},
    32914: {"Unified_Ideograph", "Ideographic"},
    32915: {"Unified_Ideograph", "Ideographic"},
    32916: {"Unified_Ideograph", "Ideographic"},
    32917: {"Unified_Ideograph", "Ideographic"},
    32918: {"Unified_Ideograph", "Ideographic"},
    32919: {"Unified_Ideograph", "Ideographic"},
    32920: {"Unified_Ideograph", "Ideographic"},
    32921: {"Unified_Ideograph", "Ideographic"},
    32922: {"Unified_Ideograph", "Ideographic"},
    32923: {"Unified_Ideograph", "Ideographic"},
    32924: {"Unified_Ideograph", "Ideographic"},
    32925: {"Unified_Ideograph", "Ideographic"},
    32926: {"Unified_Ideograph", "Ideographic"},
    32927: {"Unified_Ideograph", "Ideographic"},
    32928: {"Unified_Ideograph", "Ideographic"},
    32929: {"Unified_Ideograph", "Ideographic"},
    32930: {"Unified_Ideograph", "Ideographic"},
    32931: {"Unified_Ideograph", "Ideographic"},
    32932: {"Unified_Ideograph", "Ideographic"},
    32933: {"Unified_Ideograph", "Ideographic"},
    32934: {"Unified_Ideograph", "Ideographic"},
    32935: {"Unified_Ideograph", "Ideographic"},
    32936: {"Unified_Ideograph", "Ideographic"},
    32937: {"Unified_Ideograph", "Ideographic"},
    32938: {"Unified_Ideograph", "Ideographic"},
    32939: {"Unified_Ideograph", "Ideographic"},
    32940: {"Unified_Ideograph", "Ideographic"},
    32941: {"Unified_Ideograph", "Ideographic"},
    32942: {"Unified_Ideograph", "Ideographic"},
    32943: {"Unified_Ideograph", "Ideographic"},
    32944: {"Unified_Ideograph", "Ideographic"},
    32945: {"Unified_Ideograph", "Ideographic"},
    32946: {"Unified_Ideograph", "Ideographic"},
    32947: {"Unified_Ideograph", "Ideographic"},
    32948: {"Unified_Ideograph", "Ideographic"},
    32949: {"Unified_Ideograph", "Ideographic"},
    32950: {"Unified_Ideograph", "Ideographic"},
    32951: {"Unified_Ideograph", "Ideographic"},
    32952: {"Unified_Ideograph", "Ideographic"},
    32953: {"Unified_Ideograph", "Ideographic"},
    32954: {"Unified_Ideograph", "Ideographic"},
    32955: {"Unified_Ideograph", "Ideographic"},
    32956: {"Unified_Ideograph", "Ideographic"},
    32957: {"Unified_Ideograph", "Ideographic"},
    32958: {"Unified_Ideograph", "Ideographic"},
    32959: {"Unified_Ideograph", "Ideographic"},
    32960: {"Unified_Ideograph", "Ideographic"},
    32961: {"Unified_Ideograph", "Ideographic"},
    32962: {"Unified_Ideograph", "Ideographic"},
    32963: {"Unified_Ideograph", "Ideographic"},
    32964: {"Unified_Ideograph", "Ideographic"},
    32965: {"Unified_Ideograph", "Ideographic"},
    32966: {"Unified_Ideograph", "Ideographic"},
    32967: {"Unified_Ideograph", "Ideographic"},
    32968: {"Unified_Ideograph", "Ideographic"},
    32969: {"Unified_Ideograph", "Ideographic"},
    32970: {"Unified_Ideograph", "Ideographic"},
    32971: {"Unified_Ideograph", "Ideographic"},
    32972: {"Unified_Ideograph", "Ideographic"},
    32973: {"Unified_Ideograph", "Ideographic"},
    32974: {"Unified_Ideograph", "Ideographic"},
    32975: {"Unified_Ideograph", "Ideographic"},
    32976: {"Unified_Ideograph", "Ideographic"},
    32977: {"Unified_Ideograph", "Ideographic"},
    32978: {"Unified_Ideograph", "Ideographic"},
    32979: {"Unified_Ideograph", "Ideographic"},
    32980: {"Unified_Ideograph", "Ideographic"},
    32981: {"Unified_Ideograph", "Ideographic"},
    32982: {"Unified_Ideograph", "Ideographic"},
    32983: {"Unified_Ideograph", "Ideographic"},
    32984: {"Unified_Ideograph", "Ideographic"},
    32985: {"Unified_Ideograph", "Ideographic"},
    32986: {"Unified_Ideograph", "Ideographic"},
    32987: {"Unified_Ideograph", "Ideographic"},
    32988: {"Unified_Ideograph", "Ideographic"},
    32989: {"Unified_Ideograph", "Ideographic"},
    32990: {"Unified_Ideograph", "Ideographic"},
    32991: {"Unified_Ideograph", "Ideographic"},
    32992: {"Unified_Ideograph", "Ideographic"},
    32993: {"Unified_Ideograph", "Ideographic"},
    32994: {"Unified_Ideograph", "Ideographic"},
    32995: {"Unified_Ideograph", "Ideographic"},
    32996: {"Unified_Ideograph", "Ideographic"},
    32997: {"Unified_Ideograph", "Ideographic"},
    32998: {"Unified_Ideograph", "Ideographic"},
    32999: {"Unified_Ideograph", "Ideographic"},
    33000: {"Unified_Ideograph", "Ideographic"},
    33001: {"Unified_Ideograph", "Ideographic"},
    33002: {"Unified_Ideograph", "Ideographic"},
    33003: {"Unified_Ideograph", "Ideographic"},
    33004: {"Unified_Ideograph", "Ideographic"},
    33005: {"Unified_Ideograph", "Ideographic"},
    33006: {"Unified_Ideograph", "Ideographic"},
    33007: {"Unified_Ideograph", "Ideographic"},
    33008: {"Unified_Ideograph", "Ideographic"},
    33009: {"Unified_Ideograph", "Ideographic"},
    33010: {"Unified_Ideograph", "Ideographic"},
    33011: {"Unified_Ideograph", "Ideographic"},
    33012: {"Unified_Ideograph", "Ideographic"},
    33013: {"Unified_Ideograph", "Ideographic"},
    33014: {"Unified_Ideograph", "Ideographic"},
    33015: {"Unified_Ideograph", "Ideographic"},
    33016: {"Unified_Ideograph", "Ideographic"},
    33017: {"Unified_Ideograph", "Ideographic"},
    33018: {"Unified_Ideograph", "Ideographic"},
    33019: {"Unified_Ideograph", "Ideographic"},
    33020: {"Unified_Ideograph", "Ideographic"},
    33021: {"Unified_Ideograph", "Ideographic"},
    33022: {"Unified_Ideograph", "Ideographic"},
    33023: {"Unified_Ideograph", "Ideographic"},
    33024: {"Unified_Ideograph", "Ideographic"},
    33025: {"Unified_Ideograph", "Ideographic"},
    33026: {"Unified_Ideograph", "Ideographic"},
    33027: {"Unified_Ideograph", "Ideographic"},
    33028: {"Unified_Ideograph", "Ideographic"},
    33029: {"Unified_Ideograph", "Ideographic"},
    33030: {"Unified_Ideograph", "Ideographic"},
    33031: {"Unified_Ideograph", "Ideographic"},
    33032: {"Unified_Ideograph", "Ideographic"},
    33033: {"Unified_Ideograph", "Ideographic"},
    33034: {"Unified_Ideograph", "Ideographic"},
    33035: {"Unified_Ideograph", "Ideographic"},
    33036: {"Unified_Ideograph", "Ideographic"},
    33037: {"Unified_Ideograph", "Ideographic"},
    33038: {"Unified_Ideograph", "Ideographic"},
    33039: {"Unified_Ideograph", "Ideographic"},
    33040: {"Unified_Ideograph", "Ideographic"},
    33041: {"Unified_Ideograph", "Ideographic"},
    33042: {"Unified_Ideograph", "Ideographic"},
    33043: {"Unified_Ideograph", "Ideographic"},
    33044: {"Unified_Ideograph", "Ideographic"},
    33045: {"Unified_Ideograph", "Ideographic"},
    33046: {"Unified_Ideograph", "Ideographic"},
    33047: {"Unified_Ideograph", "Ideographic"},
    33048: {"Unified_Ideograph", "Ideographic"},
    33049: {"Unified_Ideograph", "Ideographic"},
    33050: {"Unified_Ideograph", "Ideographic"},
    33051: {"Unified_Ideograph", "Ideographic"},
    33052: {"Unified_Ideograph", "Ideographic"},
    33053: {"Unified_Ideograph", "Ideographic"},
    33054: {"Unified_Ideograph", "Ideographic"},
    33055: {"Unified_Ideograph", "Ideographic"},
    33056: {"Unified_Ideograph", "Ideographic"},
    33057: {"Unified_Ideograph", "Ideographic"},
    33058: {"Unified_Ideograph", "Ideographic"},
    33059: {"Unified_Ideograph", "Ideographic"},
    33060: {"Unified_Ideograph", "Ideographic"},
    33061: {"Unified_Ideograph", "Ideographic"},
    33062: {"Unified_Ideograph", "Ideographic"},
    33063: {"Unified_Ideograph", "Ideographic"},
    33064: {"Unified_Ideograph", "Ideographic"},
    33065: {"Unified_Ideograph", "Ideographic"},
    33066: {"Unified_Ideograph", "Ideographic"},
    33067: {"Unified_Ideograph", "Ideographic"},
    33068: {"Unified_Ideograph", "Ideographic"},
    33069: {"Unified_Ideograph", "Ideographic"},
    33070: {"Unified_Ideograph", "Ideographic"},
    33071: {"Unified_Ideograph", "Ideographic"},
    33072: {"Unified_Ideograph", "Ideographic"},
    33073: {"Unified_Ideograph", "Ideographic"},
    33074: {"Unified_Ideograph", "Ideographic"},
    33075: {"Unified_Ideograph", "Ideographic"},
    33076: {"Unified_Ideograph", "Ideographic"},
    33077: {"Unified_Ideograph", "Ideographic"},
    33078: {"Unified_Ideograph", "Ideographic"},
    33079: {"Unified_Ideograph", "Ideographic"},
    33080: {"Unified_Ideograph", "Ideographic"},
    33081: {"Unified_Ideograph", "Ideographic"},
    33082: {"Unified_Ideograph", "Ideographic"},
    33083: {"Unified_Ideograph", "Ideographic"},
    33084: {"Unified_Ideograph", "Ideographic"},
    33085: {"Unified_Ideograph", "Ideographic"},
    33086: {"Unified_Ideograph", "Ideographic"},
    33087: {"Unified_Ideograph", "Ideographic"},
    33088: {"Unified_Ideograph", "Ideographic"},
    33089: {"Unified_Ideograph", "Ideographic"},
    33090: {"Unified_Ideograph", "Ideographic"},
    33091: {"Unified_Ideograph", "Ideographic"},
    33092: {"Unified_Ideograph", "Ideographic"},
    33093: {"Unified_Ideograph", "Ideographic"},
    33094: {"Unified_Ideograph", "Ideographic"},
    33095: {"Unified_Ideograph", "Ideographic"},
    33096: {"Unified_Ideograph", "Ideographic"},
    33097: {"Unified_Ideograph", "Ideographic"},
    33098: {"Unified_Ideograph", "Ideographic"},
    33099: {"Unified_Ideograph", "Ideographic"},
    33100: {"Unified_Ideograph", "Ideographic"},
    33101: {"Unified_Ideograph", "Ideographic"},
    33102: {"Unified_Ideograph", "Ideographic"},
    33103: {"Unified_Ideograph", "Ideographic"},
    33104: {"Unified_Ideograph", "Ideographic"},
    33105: {"Unified_Ideograph", "Ideographic"},
    33106: {"Unified_Ideograph", "Ideographic"},
    33107: {"Unified_Ideograph", "Ideographic"},
    33108: {"Unified_Ideograph", "Ideographic"},
    33109: {"Unified_Ideograph", "Ideographic"},
    33110: {"Unified_Ideograph", "Ideographic"},
    33111: {"Unified_Ideograph", "Ideographic"},
    33112: {"Unified_Ideograph", "Ideographic"},
    33113: {"Unified_Ideograph", "Ideographic"},
    33114: {"Unified_Ideograph", "Ideographic"},
    33115: {"Unified_Ideograph", "Ideographic"},
    33116: {"Unified_Ideograph", "Ideographic"},
    33117: {"Unified_Ideograph", "Ideographic"},
    33118: {"Unified_Ideograph", "Ideographic"},
    33119: {"Unified_Ideograph", "Ideographic"},
    33120: {"Unified_Ideograph", "Ideographic"},
    33121: {"Unified_Ideograph", "Ideographic"},
    33122: {"Unified_Ideograph", "Ideographic"},
    33123: {"Unified_Ideograph", "Ideographic"},
    33124: {"Unified_Ideograph", "Ideographic"},
    33125: {"Unified_Ideograph", "Ideographic"},
    33126: {"Unified_Ideograph", "Ideographic"},
    33127: {"Unified_Ideograph", "Ideographic"},
    33128: {"Unified_Ideograph", "Ideographic"},
    33129: {"Unified_Ideograph", "Ideographic"},
    33130: {"Unified_Ideograph", "Ideographic"},
    33131: {"Unified_Ideograph", "Ideographic"},
    33132: {"Unified_Ideograph", "Ideographic"},
    33133: {"Unified_Ideograph", "Ideographic"},
    33134: {"Unified_Ideograph", "Ideographic"},
    33135: {"Unified_Ideograph", "Ideographic"},
    33136: {"Unified_Ideograph", "Ideographic"},
    33137: {"Unified_Ideograph", "Ideographic"},
    33138: {"Unified_Ideograph", "Ideographic"},
    33139: {"Unified_Ideograph", "Ideographic"},
    33140: {"Unified_Ideograph", "Ideographic"},
    33141: {"Unified_Ideograph", "Ideographic"},
    33142: {"Unified_Ideograph", "Ideographic"},
    33143: {"Unified_Ideograph", "Ideographic"},
    33144: {"Unified_Ideograph", "Ideographic"},
    33145: {"Unified_Ideograph", "Ideographic"},
    33146: {"Unified_Ideograph", "Ideographic"},
    33147: {"Unified_Ideograph", "Ideographic"},
    33148: {"Unified_Ideograph", "Ideographic"},
    33149: {"Unified_Ideograph", "Ideographic"},
    33150: {"Unified_Ideograph", "Ideographic"},
    33151: {"Unified_Ideograph", "Ideographic"},
    33152: {"Unified_Ideograph", "Ideographic"},
    33153: {"Unified_Ideograph", "Ideographic"},
    33154: {"Unified_Ideograph", "Ideographic"},
    33155: {"Unified_Ideograph", "Ideographic"},
    33156: {"Unified_Ideograph", "Ideographic"},
    33157: {"Unified_Ideograph", "Ideographic"},
    33158: {"Unified_Ideograph", "Ideographic"},
    33159: {"Unified_Ideograph", "Ideographic"},
    33160: {"Unified_Ideograph", "Ideographic"},
    33161: {"Unified_Ideograph", "Ideographic"},
    33162: {"Unified_Ideograph", "Ideographic"},
    33163: {"Unified_Ideograph", "Ideographic"},
    33164: {"Unified_Ideograph", "Ideographic"},
    33165: {"Unified_Ideograph", "Ideographic"},
    33166: {"Unified_Ideograph", "Ideographic"},
    33167: {"Unified_Ideograph", "Ideographic"},
    33168: {"Unified_Ideograph", "Ideographic"},
    33169: {"Unified_Ideograph", "Ideographic"},
    33170: {"Unified_Ideograph", "Ideographic"},
    33171: {"Unified_Ideograph", "Ideographic"},
    33172: {"Unified_Ideograph", "Ideographic"},
    33173: {"Unified_Ideograph", "Ideographic"},
    33174: {"Unified_Ideograph", "Ideographic"},
    33175: {"Unified_Ideograph", "Ideographic"},
    33176: {"Unified_Ideograph", "Ideographic"},
    33177: {"Unified_Ideograph", "Ideographic"},
    33178: {"Unified_Ideograph", "Ideographic"},
    33179: {"Unified_Ideograph", "Ideographic"},
    33180: {"Unified_Ideograph", "Ideographic"},
    33181: {"Unified_Ideograph", "Ideographic"},
    33182: {"Unified_Ideograph", "Ideographic"},
    33183: {"Unified_Ideograph", "Ideographic"},
    33184: {"Unified_Ideograph", "Ideographic"},
    33185: {"Unified_Ideograph", "Ideographic"},
    33186: {"Unified_Ideograph", "Ideographic"},
    33187: {"Unified_Ideograph", "Ideographic"},
    33188: {"Unified_Ideograph", "Ideographic"},
    33189: {"Unified_Ideograph", "Ideographic"},
    33190: {"Unified_Ideograph", "Ideographic"},
    33191: {"Unified_Ideograph", "Ideographic"},
    33192: {"Unified_Ideograph", "Ideographic"},
    33193: {"Unified_Ideograph", "Ideographic"},
    33194: {"Unified_Ideograph", "Ideographic"},
    33195: {"Unified_Ideograph", "Ideographic"},
    33196: {"Unified_Ideograph", "Ideographic"},
    33197: {"Unified_Ideograph", "Ideographic"},
    33198: {"Unified_Ideograph", "Ideographic"},
    33199: {"Unified_Ideograph", "Ideographic"},
    33200: {"Unified_Ideograph", "Ideographic"},
    33201: {"Unified_Ideograph", "Ideographic"},
    33202: {"Unified_Ideograph", "Ideographic"},
    33203: {"Unified_Ideograph", "Ideographic"},
    33204: {"Unified_Ideograph", "Ideographic"},
    33205: {"Unified_Ideograph", "Ideographic"},
    33206: {"Unified_Ideograph", "Ideographic"},
    33207: {"Unified_Ideograph", "Ideographic"},
    33208: {"Unified_Ideograph", "Ideographic"},
    33209: {"Unified_Ideograph", "Ideographic"},
    33210: {"Unified_Ideograph", "Ideographic"},
    33211: {"Unified_Ideograph", "Ideographic"},
    33212: {"Unified_Ideograph", "Ideographic"},
    33213: {"Unified_Ideograph", "Ideographic"},
    33214: {"Unified_Ideograph", "Ideographic"},
    33215: {"Unified_Ideograph", "Ideographic"},
    33216: {"Unified_Ideograph", "Ideographic"},
    33217: {"Unified_Ideograph", "Ideographic"},
    33218: {"Unified_Ideograph", "Ideographic"},
    33219: {"Unified_Ideograph", "Ideographic"},
    33220: {"Unified_Ideograph", "Ideographic"},
    33221: {"Unified_Ideograph", "Ideographic"},
    33222: {"Unified_Ideograph", "Ideographic"},
    33223: {"Unified_Ideograph", "Ideographic"},
    33224: {"Unified_Ideograph", "Ideographic"},
    33225: {"Unified_Ideograph", "Ideographic"},
    33226: {"Unified_Ideograph", "Ideographic"},
    33227: {"Unified_Ideograph", "Ideographic"},
    33228: {"Unified_Ideograph", "Ideographic"},
    33229: {"Unified_Ideograph", "Ideographic"},
    33230: {"Unified_Ideograph", "Ideographic"},
    33231: {"Unified_Ideograph", "Ideographic"},
    33232: {"Unified_Ideograph", "Ideographic"},
    33233: {"Unified_Ideograph", "Ideographic"},
    33234: {"Unified_Ideograph", "Ideographic"},
    33235: {"Unified_Ideograph", "Ideographic"},
    33236: {"Unified_Ideograph", "Ideographic"},
    33237: {"Unified_Ideograph", "Ideographic"},
    33238: {"Unified_Ideograph", "Ideographic"},
    33239: {"Unified_Ideograph", "Ideographic"},
    33240: {"Unified_Ideograph", "Ideographic"},
    33241: {"Unified_Ideograph", "Ideographic"},
    33242: {"Unified_Ideograph", "Ideographic"},
    33243: {"Unified_Ideograph", "Ideographic"},
    33244: {"Unified_Ideograph", "Ideographic"},
    33245: {"Unified_Ideograph", "Ideographic"},
    33246: {"Unified_Ideograph", "Ideographic"},
    33247: {"Unified_Ideograph", "Ideographic"},
    33248: {"Unified_Ideograph", "Ideographic"},
    33249: {"Unified_Ideograph", "Ideographic"},
    33250: {"Unified_Ideograph", "Ideographic"},
    33251: {"Unified_Ideograph", "Ideographic"},
    33252: {"Unified_Ideograph", "Ideographic"},
    33253: {"Unified_Ideograph", "Ideographic"},
    33254: {"Unified_Ideograph", "Ideographic"},
    33255: {"Unified_Ideograph", "Ideographic"},
    33256: {"Unified_Ideograph", "Ideographic"},
    33257: {"Unified_Ideograph", "Ideographic"},
    33258: {"Unified_Ideograph", "Ideographic"},
    33259: {"Unified_Ideograph", "Ideographic"},
    33260: {"Unified_Ideograph", "Ideographic"},
    33261: {"Unified_Ideograph", "Ideographic"},
    33262: {"Unified_Ideograph", "Ideographic"},
    33263: {"Unified_Ideograph", "Ideographic"},
    33264: {"Unified_Ideograph", "Ideographic"},
    33265: {"Unified_Ideograph", "Ideographic"},
    33266: {"Unified_Ideograph", "Ideographic"},
    33267: {"Unified_Ideograph", "Ideographic"},
    33268: {"Unified_Ideograph", "Ideographic"},
    33269: {"Unified_Ideograph", "Ideographic"},
    33270: {"Unified_Ideograph", "Ideographic"},
    33271: {"Unified_Ideograph", "Ideographic"},
    33272: {"Unified_Ideograph", "Ideographic"},
    33273: {"Unified_Ideograph", "Ideographic"},
    33274: {"Unified_Ideograph", "Ideographic"},
    33275: {"Unified_Ideograph", "Ideographic"},
    33276: {"Unified_Ideograph", "Ideographic"},
    33277: {"Unified_Ideograph", "Ideographic"},
    33278: {"Unified_Ideograph", "Ideographic"},
    33279: {"Unified_Ideograph", "Ideographic"},
    33280: {"Unified_Ideograph", "Ideographic"},
    33281: {"Unified_Ideograph", "Ideographic"},
    33282: {"Unified_Ideograph", "Ideographic"},
    33283: {"Unified_Ideograph", "Ideographic"},
    33284: {"Unified_Ideograph", "Ideographic"},
    33285: {"Unified_Ideograph", "Ideographic"},
    33286: {"Unified_Ideograph", "Ideographic"},
    33287: {"Unified_Ideograph", "Ideographic"},
    33288: {"Unified_Ideograph", "Ideographic"},
    33289: {"Unified_Ideograph", "Ideographic"},
    33290: {"Unified_Ideograph", "Ideographic"},
    33291: {"Unified_Ideograph", "Ideographic"},
    33292: {"Unified_Ideograph", "Ideographic"},
    33293: {"Unified_Ideograph", "Ideographic"},
    33294: {"Unified_Ideograph", "Ideographic"},
    33295: {"Unified_Ideograph", "Ideographic"},
    33296: {"Unified_Ideograph", "Ideographic"},
    33297: {"Unified_Ideograph", "Ideographic"},
    33298: {"Unified_Ideograph", "Ideographic"},
    33299: {"Unified_Ideograph", "Ideographic"},
    33300: {"Unified_Ideograph", "Ideographic"},
    33301: {"Unified_Ideograph", "Ideographic"},
    33302: {"Unified_Ideograph", "Ideographic"},
    33303: {"Unified_Ideograph", "Ideographic"},
    33304: {"Unified_Ideograph", "Ideographic"},
    33305: {"Unified_Ideograph", "Ideographic"},
    33306: {"Unified_Ideograph", "Ideographic"},
    33307: {"Unified_Ideograph", "Ideographic"},
    33308: {"Unified_Ideograph", "Ideographic"},
    33309: {"Unified_Ideograph", "Ideographic"},
    33310: {"Unified_Ideograph", "Ideographic"},
    33311: {"Unified_Ideograph", "Ideographic"},
    33312: {"Unified_Ideograph", "Ideographic"},
    33313: {"Unified_Ideograph", "Ideographic"},
    33314: {"Unified_Ideograph", "Ideographic"},
    33315: {"Unified_Ideograph", "Ideographic"},
    33316: {"Unified_Ideograph", "Ideographic"},
    33317: {"Unified_Ideograph", "Ideographic"},
    33318: {"Unified_Ideograph", "Ideographic"},
    33319: {"Unified_Ideograph", "Ideographic"},
    33320: {"Unified_Ideograph", "Ideographic"},
    33321: {"Unified_Ideograph", "Ideographic"},
    33322: {"Unified_Ideograph", "Ideographic"},
    33323: {"Unified_Ideograph", "Ideographic"},
    33324: {"Unified_Ideograph", "Ideographic"},
    33325: {"Unified_Ideograph", "Ideographic"},
    33326: {"Unified_Ideograph", "Ideographic"},
    33327: {"Unified_Ideograph", "Ideographic"},
    33328: {"Unified_Ideograph", "Ideographic"},
    33329: {"Unified_Ideograph", "Ideographic"},
    33330: {"Unified_Ideograph", "Ideographic"},
    33331: {"Unified_Ideograph", "Ideographic"},
    33332: {"Unified_Ideograph", "Ideographic"},
    33333: {"Unified_Ideograph", "Ideographic"},
    33334: {"Unified_Ideograph", "Ideographic"},
    33335: {"Unified_Ideograph", "Ideographic"},
    33336: {"Unified_Ideograph", "Ideographic"},
    33337: {"Unified_Ideograph", "Ideographic"},
    33338: {"Unified_Ideograph", "Ideographic"},
    33339: {"Unified_Ideograph", "Ideographic"},
    33340: {"Unified_Ideograph", "Ideographic"},
    33341: {"Unified_Ideograph", "Ideographic"},
    33342: {"Unified_Ideograph", "Ideographic"},
    33343: {"Unified_Ideograph", "Ideographic"},
    33344: {"Unified_Ideograph", "Ideographic"},
    33345: {"Unified_Ideograph", "Ideographic"},
    33346: {"Unified_Ideograph", "Ideographic"},
    33347: {"Unified_Ideograph", "Ideographic"},
    33348: {"Unified_Ideograph", "Ideographic"},
    33349: {"Unified_Ideograph", "Ideographic"},
    33350: {"Unified_Ideograph", "Ideographic"},
    33351: {"Unified_Ideograph", "Ideographic"},
    33352: {"Unified_Ideograph", "Ideographic"},
    33353: {"Unified_Ideograph", "Ideographic"},
    33354: {"Unified_Ideograph", "Ideographic"},
    33355: {"Unified_Ideograph", "Ideographic"},
    33356: {"Unified_Ideograph", "Ideographic"},
    33357: {"Unified_Ideograph", "Ideographic"},
    33358: {"Unified_Ideograph", "Ideographic"},
    33359: {"Unified_Ideograph", "Ideographic"},
    33360: {"Unified_Ideograph", "Ideographic"},
    33361: {"Unified_Ideograph", "Ideographic"},
    33362: {"Unified_Ideograph", "Ideographic"},
    33363: {"Unified_Ideograph", "Ideographic"},
    33364: {"Unified_Ideograph", "Ideographic"},
    33365: {"Unified_Ideograph", "Ideographic"},
    33366: {"Unified_Ideograph", "Ideographic"},
    33367: {"Unified_Ideograph", "Ideographic"},
    33368: {"Unified_Ideograph", "Ideographic"},
    33369: {"Unified_Ideograph", "Ideographic"},
    33370: {"Unified_Ideograph", "Ideographic"},
    33371: {"Unified_Ideograph", "Ideographic"},
    33372: {"Unified_Ideograph", "Ideographic"},
    33373: {"Unified_Ideograph", "Ideographic"},
    33374: {"Unified_Ideograph", "Ideographic"},
    33375: {"Unified_Ideograph", "Ideographic"},
    33376: {"Unified_Ideograph", "Ideographic"},
    33377: {"Unified_Ideograph", "Ideographic"},
    33378: {"Unified_Ideograph", "Ideographic"},
    33379: {"Unified_Ideograph", "Ideographic"},
    33380: {"Unified_Ideograph", "Ideographic"},
    33381: {"Unified_Ideograph", "Ideographic"},
    33382: {"Unified_Ideograph", "Ideographic"},
    33383: {"Unified_Ideograph", "Ideographic"},
    33384: {"Unified_Ideograph", "Ideographic"},
    33385: {"Unified_Ideograph", "Ideographic"},
    33386: {"Unified_Ideograph", "Ideographic"},
    33387: {"Unified_Ideograph", "Ideographic"},
    33388: {"Unified_Ideograph", "Ideographic"},
    33389: {"Unified_Ideograph", "Ideographic"},
    33390: {"Unified_Ideograph", "Ideographic"},
    33391: {"Unified_Ideograph", "Ideographic"},
    33392: {"Unified_Ideograph", "Ideographic"},
    33393: {"Unified_Ideograph", "Ideographic"},
    33394: {"Unified_Ideograph", "Ideographic"},
    33395: {"Unified_Ideograph", "Ideographic"},
    33396: {"Unified_Ideograph", "Ideographic"},
    33397: {"Unified_Ideograph", "Ideographic"},
    33398: {"Unified_Ideograph", "Ideographic"},
    33399: {"Unified_Ideograph", "Ideographic"},
    33400: {"Unified_Ideograph", "Ideographic"},
    33401: {"Unified_Ideograph", "Ideographic"},
    33402: {"Unified_Ideograph", "Ideographic"},
    33403: {"Unified_Ideograph", "Ideographic"},
    33404: {"Unified_Ideograph", "Ideographic"},
    33405: {"Unified_Ideograph", "Ideographic"},
    33406: {"Unified_Ideograph", "Ideographic"},
    33407: {"Unified_Ideograph", "Ideographic"},
    33408: {"Unified_Ideograph", "Ideographic"},
    33409: {"Unified_Ideograph", "Ideographic"},
    33410: {"Unified_Ideograph", "Ideographic"},
    33411: {"Unified_Ideograph", "Ideographic"},
    33412: {"Unified_Ideograph", "Ideographic"},
    33413: {"Unified_Ideograph", "Ideographic"},
    33414: {"Unified_Ideograph", "Ideographic"},
    33415: {"Unified_Ideograph", "Ideographic"},
    33416: {"Unified_Ideograph", "Ideographic"},
    33417: {"Unified_Ideograph", "Ideographic"},
    33418: {"Unified_Ideograph", "Ideographic"},
    33419: {"Unified_Ideograph", "Ideographic"},
    33420: {"Unified_Ideograph", "Ideographic"},
    33421: {"Unified_Ideograph", "Ideographic"},
    33422: {"Unified_Ideograph", "Ideographic"},
    33423: {"Unified_Ideograph", "Ideographic"},
    33424: {"Unified_Ideograph", "Ideographic"},
    33425: {"Unified_Ideograph", "Ideographic"},
    33426: {"Unified_Ideograph", "Ideographic"},
    33427: {"Unified_Ideograph", "Ideographic"},
    33428: {"Unified_Ideograph", "Ideographic"},
    33429: {"Unified_Ideograph", "Ideographic"},
    33430: {"Unified_Ideograph", "Ideographic"},
    33431: {"Unified_Ideograph", "Ideographic"},
    33432: {"Unified_Ideograph", "Ideographic"},
    33433: {"Unified_Ideograph", "Ideographic"},
    33434: {"Unified_Ideograph", "Ideographic"},
    33435: {"Unified_Ideograph", "Ideographic"},
    33436: {"Unified_Ideograph", "Ideographic"},
    33437: {"Unified_Ideograph", "Ideographic"},
    33438: {"Unified_Ideograph", "Ideographic"},
    33439: {"Unified_Ideograph", "Ideographic"},
    33440: {"Unified_Ideograph", "Ideographic"},
    33441: {"Unified_Ideograph", "Ideographic"},
    33442: {"Unified_Ideograph", "Ideographic"},
    33443: {"Unified_Ideograph", "Ideographic"},
    33444: {"Unified_Ideograph", "Ideographic"},
    33445: {"Unified_Ideograph", "Ideographic"},
    33446: {"Unified_Ideograph", "Ideographic"},
    33447: {"Unified_Ideograph", "Ideographic"},
    33448: {"Unified_Ideograph", "Ideographic"},
    33449: {"Unified_Ideograph", "Ideographic"},
    33450: {"Unified_Ideograph", "Ideographic"},
    33451: {"Unified_Ideograph", "Ideographic"},
    33452: {"Unified_Ideograph", "Ideographic"},
    33453: {"Unified_Ideograph", "Ideographic"},
    33454: {"Unified_Ideograph", "Ideographic"},
    33455: {"Unified_Ideograph", "Ideographic"},
    33456: {"Unified_Ideograph", "Ideographic"},
    33457: {"Unified_Ideograph", "Ideographic"},
    33458: {"Unified_Ideograph", "Ideographic"},
    33459: {"Unified_Ideograph", "Ideographic"},
    33460: {"Unified_Ideograph", "Ideographic"},
    33461: {"Unified_Ideograph", "Ideographic"},
    33462: {"Unified_Ideograph", "Ideographic"},
    33463: {"Unified_Ideograph", "Ideographic"},
    33464: {"Unified_Ideograph", "Ideographic"},
    33465: {"Unified_Ideograph", "Ideographic"},
    33466: {"Unified_Ideograph", "Ideographic"},
    33467: {"Unified_Ideograph", "Ideographic"},
    33468: {"Unified_Ideograph", "Ideographic"},
    33469: {"Unified_Ideograph", "Ideographic"},
    33470: {"Unified_Ideograph", "Ideographic"},
    33471: {"Unified_Ideograph", "Ideographic"},
    33472: {"Unified_Ideograph", "Ideographic"},
    33473: {"Unified_Ideograph", "Ideographic"},
    33474: {"Unified_Ideograph", "Ideographic"},
    33475: {"Unified_Ideograph", "Ideographic"},
    33476: {"Unified_Ideograph", "Ideographic"},
    33477: {"Unified_Ideograph", "Ideographic"},
    33478: {"Unified_Ideograph", "Ideographic"},
    33479: {"Unified_Ideograph", "Ideographic"},
    33480: {"Unified_Ideograph", "Ideographic"},
    33481: {"Unified_Ideograph", "Ideographic"},
    33482: {"Unified_Ideograph", "Ideographic"},
    33483: {"Unified_Ideograph", "Ideographic"},
    33484: {"Unified_Ideograph", "Ideographic"},
    33485: {"Unified_Ideograph", "Ideographic"},
    33486: {"Unified_Ideograph", "Ideographic"},
    33487: {"Unified_Ideograph", "Ideographic"},
    33488: {"Unified_Ideograph", "Ideographic"},
    33489: {"Unified_Ideograph", "Ideographic"},
    33490: {"Unified_Ideograph", "Ideographic"},
    33491: {"Unified_Ideograph", "Ideographic"},
    33492: {"Unified_Ideograph", "Ideographic"},
    33493: {"Unified_Ideograph", "Ideographic"},
    33494: {"Unified_Ideograph", "Ideographic"},
    33495: {"Unified_Ideograph", "Ideographic"},
    33496: {"Unified_Ideograph", "Ideographic"},
    33497: {"Unified_Ideograph", "Ideographic"},
    33498: {"Unified_Ideograph", "Ideographic"},
    33499: {"Unified_Ideograph", "Ideographic"},
    33500: {"Unified_Ideograph", "Ideographic"},
    33501: {"Unified_Ideograph", "Ideographic"},
    33502: {"Unified_Ideograph", "Ideographic"},
    33503: {"Unified_Ideograph", "Ideographic"},
    33504: {"Unified_Ideograph", "Ideographic"},
    33505: {"Unified_Ideograph", "Ideographic"},
    33506: {"Unified_Ideograph", "Ideographic"},
    33507: {"Unified_Ideograph", "Ideographic"},
    33508: {"Unified_Ideograph", "Ideographic"},
    33509: {"Unified_Ideograph", "Ideographic"},
    33510: {"Unified_Ideograph", "Ideographic"},
    33511: {"Unified_Ideograph", "Ideographic"},
    33512: {"Unified_Ideograph", "Ideographic"},
    33513: {"Unified_Ideograph", "Ideographic"},
    33514: {"Unified_Ideograph", "Ideographic"},
    33515: {"Unified_Ideograph", "Ideographic"},
    33516: {"Unified_Ideograph", "Ideographic"},
    33517: {"Unified_Ideograph", "Ideographic"},
    33518: {"Unified_Ideograph", "Ideographic"},
    33519: {"Unified_Ideograph", "Ideographic"},
    33520: {"Unified_Ideograph", "Ideographic"},
    33521: {"Unified_Ideograph", "Ideographic"},
    33522: {"Unified_Ideograph", "Ideographic"},
    33523: {"Unified_Ideograph", "Ideographic"},
    33524: {"Unified_Ideograph", "Ideographic"},
    33525: {"Unified_Ideograph", "Ideographic"},
    33526: {"Unified_Ideograph", "Ideographic"},
    33527: {"Unified_Ideograph", "Ideographic"},
    33528: {"Unified_Ideograph", "Ideographic"},
    33529: {"Unified_Ideograph", "Ideographic"},
    33530: {"Unified_Ideograph", "Ideographic"},
    33531: {"Unified_Ideograph", "Ideographic"},
    33532: {"Unified_Ideograph", "Ideographic"},
    33533: {"Unified_Ideograph", "Ideographic"},
    33534: {"Unified_Ideograph", "Ideographic"},
    33535: {"Unified_Ideograph", "Ideographic"},
    33536: {"Unified_Ideograph", "Ideographic"},
    33537: {"Unified_Ideograph", "Ideographic"},
    33538: {"Unified_Ideograph", "Ideographic"},
    33539: {"Unified_Ideograph", "Ideographic"},
    33540: {"Unified_Ideograph", "Ideographic"},
    33541: {"Unified_Ideograph", "Ideographic"},
    33542: {"Unified_Ideograph", "Ideographic"},
    33543: {"Unified_Ideograph", "Ideographic"},
    33544: {"Unified_Ideograph", "Ideographic"},
    33545: {"Unified_Ideograph", "Ideographic"},
    33546: {"Unified_Ideograph", "Ideographic"},
    33547: {"Unified_Ideograph", "Ideographic"},
    33548: {"Unified_Ideograph", "Ideographic"},
    33549: {"Unified_Ideograph", "Ideographic"},
    33550: {"Unified_Ideograph", "Ideographic"},
    33551: {"Unified_Ideograph", "Ideographic"},
    33552: {"Unified_Ideograph", "Ideographic"},
    33553: {"Unified_Ideograph", "Ideographic"},
    33554: {"Unified_Ideograph", "Ideographic"},
    33555: {"Unified_Ideograph", "Ideographic"},
    33556: {"Unified_Ideograph", "Ideographic"},
    33557: {"Unified_Ideograph", "Ideographic"},
    33558: {"Unified_Ideograph", "Ideographic"},
    33559: {"Unified_Ideograph", "Ideographic"},
    33560: {"Unified_Ideograph", "Ideographic"},
    33561: {"Unified_Ideograph", "Ideographic"},
    33562: {"Unified_Ideograph", "Ideographic"},
    33563: {"Unified_Ideograph", "Ideographic"},
    33564: {"Unified_Ideograph", "Ideographic"},
    33565: {"Unified_Ideograph", "Ideographic"},
    33566: {"Unified_Ideograph", "Ideographic"},
    33567: {"Unified_Ideograph", "Ideographic"},
    33568: {"Unified_Ideograph", "Ideographic"},
    33569: {"Unified_Ideograph", "Ideographic"},
    33570: {"Unified_Ideograph", "Ideographic"},
    33571: {"Unified_Ideograph", "Ideographic"},
    33572: {"Unified_Ideograph", "Ideographic"},
    33573: {"Unified_Ideograph", "Ideographic"},
    33574: {"Unified_Ideograph", "Ideographic"},
    33575: {"Unified_Ideograph", "Ideographic"},
    33576: {"Unified_Ideograph", "Ideographic"},
    33577: {"Unified_Ideograph", "Ideographic"},
    33578: {"Unified_Ideograph", "Ideographic"},
    33579: {"Unified_Ideograph", "Ideographic"},
    33580: {"Unified_Ideograph", "Ideographic"},
    33581: {"Unified_Ideograph", "Ideographic"},
    33582: {"Unified_Ideograph", "Ideographic"},
    33583: {"Unified_Ideograph", "Ideographic"},
    33584: {"Unified_Ideograph", "Ideographic"},
    33585: {"Unified_Ideograph", "Ideographic"},
    33586: {"Unified_Ideograph", "Ideographic"},
    33587: {"Unified_Ideograph", "Ideographic"},
    33588: {"Unified_Ideograph", "Ideographic"},
    33589: {"Unified_Ideograph", "Ideographic"},
    33590: {"Unified_Ideograph", "Ideographic"},
    33591: {"Unified_Ideograph", "Ideographic"},
    33592: {"Unified_Ideograph", "Ideographic"},
    33593: {"Unified_Ideograph", "Ideographic"},
    33594: {"Unified_Ideograph", "Ideographic"},
    33595: {"Unified_Ideograph", "Ideographic"},
    33596: {"Unified_Ideograph", "Ideographic"},
    33597: {"Unified_Ideograph", "Ideographic"},
    33598: {"Unified_Ideograph", "Ideographic"},
    33599: {"Unified_Ideograph", "Ideographic"},
    33600: {"Unified_Ideograph", "Ideographic"},
    33601: {"Unified_Ideograph", "Ideographic"},
    33602: {"Unified_Ideograph", "Ideographic"},
    33603: {"Unified_Ideograph", "Ideographic"},
    33604: {"Unified_Ideograph", "Ideographic"},
    33605: {"Unified_Ideograph", "Ideographic"},
    33606: {"Unified_Ideograph", "Ideographic"},
    33607: {"Unified_Ideograph", "Ideographic"},
    33608: {"Unified_Ideograph", "Ideographic"},
    33609: {"Unified_Ideograph", "Ideographic"},
    33610: {"Unified_Ideograph", "Ideographic"},
    33611: {"Unified_Ideograph", "Ideographic"},
    33612: {"Unified_Ideograph", "Ideographic"},
    33613: {"Unified_Ideograph", "Ideographic"},
    33614: {"Unified_Ideograph", "Ideographic"},
    33615: {"Unified_Ideograph", "Ideographic"},
    33616: {"Unified_Ideograph", "Ideographic"},
    33617: {"Unified_Ideograph", "Ideographic"},
    33618: {"Unified_Ideograph", "Ideographic"},
    33619: {"Unified_Ideograph", "Ideographic"},
    33620: {"Unified_Ideograph", "Ideographic"},
    33621: {"Unified_Ideograph", "Ideographic"},
    33622: {"Unified_Ideograph", "Ideographic"},
    33623: {"Unified_Ideograph", "Ideographic"},
    33624: {"Unified_Ideograph", "Ideographic"},
    33625: {"Unified_Ideograph", "Ideographic"},
    33626: {"Unified_Ideograph", "Ideographic"},
    33627: {"Unified_Ideograph", "Ideographic"},
    33628: {"Unified_Ideograph", "Ideographic"},
    33629: {"Unified_Ideograph", "Ideographic"},
    33630: {"Unified_Ideograph", "Ideographic"},
    33631: {"Unified_Ideograph", "Ideographic"},
    33632: {"Unified_Ideograph", "Ideographic"},
    33633: {"Unified_Ideograph", "Ideographic"},
    33634: {"Unified_Ideograph", "Ideographic"},
    33635: {"Unified_Ideograph", "Ideographic"},
    33636: {"Unified_Ideograph", "Ideographic"},
    33637: {"Unified_Ideograph", "Ideographic"},
    33638: {"Unified_Ideograph", "Ideographic"},
    33639: {"Unified_Ideograph", "Ideographic"},
    33640: {"Unified_Ideograph", "Ideographic"},
    33641: {"Unified_Ideograph", "Ideographic"},
    33642: {"Unified_Ideograph", "Ideographic"},
    33643: {"Unified_Ideograph", "Ideographic"},
    33644: {"Unified_Ideograph", "Ideographic"},
    33645: {"Unified_Ideograph", "Ideographic"},
    33646: {"Unified_Ideograph", "Ideographic"},
    33647: {"Unified_Ideograph", "Ideographic"},
    33648: {"Unified_Ideograph", "Ideographic"},
    33649: {"Unified_Ideograph", "Ideographic"},
    33650: {"Unified_Ideograph", "Ideographic"},
    33651: {"Unified_Ideograph", "Ideographic"},
    33652: {"Unified_Ideograph", "Ideographic"},
    33653: {"Unified_Ideograph", "Ideographic"},
    33654: {"Unified_Ideograph", "Ideographic"},
    33655: {"Unified_Ideograph", "Ideographic"},
    33656: {"Unified_Ideograph", "Ideographic"},
    33657: {"Unified_Ideograph", "Ideographic"},
    33658: {"Unified_Ideograph", "Ideographic"},
    33659: {"Unified_Ideograph", "Ideographic"},
    33660: {"Unified_Ideograph", "Ideographic"},
    33661: {"Unified_Ideograph", "Ideographic"},
    33662: {"Unified_Ideograph", "Ideographic"},
    33663: {"Unified_Ideograph", "Ideographic"},
    33664: {"Unified_Ideograph", "Ideographic"},
    33665: {"Unified_Ideograph", "Ideographic"},
    33666: {"Unified_Ideograph", "Ideographic"},
    33667: {"Unified_Ideograph", "Ideographic"},
    33668: {"Unified_Ideograph", "Ideographic"},
    33669: {"Unified_Ideograph", "Ideographic"},
    33670: {"Unified_Ideograph", "Ideographic"},
    33671: {"Unified_Ideograph", "Ideographic"},
    33672: {"Unified_Ideograph", "Ideographic"},
    33673: {"Unified_Ideograph", "Ideographic"},
    33674: {"Unified_Ideograph", "Ideographic"},
    33675: {"Unified_Ideograph", "Ideographic"},
    33676: {"Unified_Ideograph", "Ideographic"},
    33677: {"Unified_Ideograph", "Ideographic"},
    33678: {"Unified_Ideograph", "Ideographic"},
    33679: {"Unified_Ideograph", "Ideographic"},
    33680: {"Unified_Ideograph", "Ideographic"},
    33681: {"Unified_Ideograph", "Ideographic"},
    33682: {"Unified_Ideograph", "Ideographic"},
    33683: {"Unified_Ideograph", "Ideographic"},
    33684: {"Unified_Ideograph", "Ideographic"},
    33685: {"Unified_Ideograph", "Ideographic"},
    33686: {"Unified_Ideograph", "Ideographic"},
    33687: {"Unified_Ideograph", "Ideographic"},
    33688: {"Unified_Ideograph", "Ideographic"},
    33689: {"Unified_Ideograph", "Ideographic"},
    33690: {"Unified_Ideograph", "Ideographic"},
    33691: {"Unified_Ideograph", "Ideographic"},
    33692: {"Unified_Ideograph", "Ideographic"},
    33693: {"Unified_Ideograph", "Ideographic"},
    33694: {"Unified_Ideograph", "Ideographic"},
    33695: {"Unified_Ideograph", "Ideographic"},
    33696: {"Unified_Ideograph", "Ideographic"},
    33697: {"Unified_Ideograph", "Ideographic"},
    33698: {"Unified_Ideograph", "Ideographic"},
    33699: {"Unified_Ideograph", "Ideographic"},
    33700: {"Unified_Ideograph", "Ideographic"},
    33701: {"Unified_Ideograph", "Ideographic"},
    33702: {"Unified_Ideograph", "Ideographic"},
    33703: {"Unified_Ideograph", "Ideographic"},
    33704: {"Unified_Ideograph", "Ideographic"},
    33705: {"Unified_Ideograph", "Ideographic"},
    33706: {"Unified_Ideograph", "Ideographic"},
    33707: {"Unified_Ideograph", "Ideographic"},
    33708: {"Unified_Ideograph", "Ideographic"},
    33709: {"Unified_Ideograph", "Ideographic"},
    33710: {"Unified_Ideograph", "Ideographic"},
    33711: {"Unified_Ideograph", "Ideographic"},
    33712: {"Unified_Ideograph", "Ideographic"},
    33713: {"Unified_Ideograph", "Ideographic"},
    33714: {"Unified_Ideograph", "Ideographic"},
    33715: {"Unified_Ideograph", "Ideographic"},
    33716: {"Unified_Ideograph", "Ideographic"},
    33717: {"Unified_Ideograph", "Ideographic"},
    33718: {"Unified_Ideograph", "Ideographic"},
    33719: {"Unified_Ideograph", "Ideographic"},
    33720: {"Unified_Ideograph", "Ideographic"},
    33721: {"Unified_Ideograph", "Ideographic"},
    33722: {"Unified_Ideograph", "Ideographic"},
    33723: {"Unified_Ideograph", "Ideographic"},
    33724: {"Unified_Ideograph", "Ideographic"},
    33725: {"Unified_Ideograph", "Ideographic"},
    33726: {"Unified_Ideograph", "Ideographic"},
    33727: {"Unified_Ideograph", "Ideographic"},
    33728: {"Unified_Ideograph", "Ideographic"},
    33729: {"Unified_Ideograph", "Ideographic"},
    33730: {"Unified_Ideograph", "Ideographic"},
    33731: {"Unified_Ideograph", "Ideographic"},
    33732: {"Unified_Ideograph", "Ideographic"},
    33733: {"Unified_Ideograph", "Ideographic"},
    33734: {"Unified_Ideograph", "Ideographic"},
    33735: {"Unified_Ideograph", "Ideographic"},
    33736: {"Unified_Ideograph", "Ideographic"},
    33737: {"Unified_Ideograph", "Ideographic"},
    33738: {"Unified_Ideograph", "Ideographic"},
    33739: {"Unified_Ideograph", "Ideographic"},
    33740: {"Unified_Ideograph", "Ideographic"},
    33741: {"Unified_Ideograph", "Ideographic"},
    33742: {"Unified_Ideograph", "Ideographic"},
    33743: {"Unified_Ideograph", "Ideographic"},
    33744: {"Unified_Ideograph", "Ideographic"},
    33745: {"Unified_Ideograph", "Ideographic"},
    33746: {"Unified_Ideograph", "Ideographic"},
    33747: {"Unified_Ideograph", "Ideographic"},
    33748: {"Unified_Ideograph", "Ideographic"},
    33749: {"Unified_Ideograph", "Ideographic"},
    33750: {"Unified_Ideograph", "Ideographic"},
    33751: {"Unified_Ideograph", "Ideographic"},
    33752: {"Unified_Ideograph", "Ideographic"},
    33753: {"Unified_Ideograph", "Ideographic"},
    33754: {"Unified_Ideograph", "Ideographic"},
    33755: {"Unified_Ideograph", "Ideographic"},
    33756: {"Unified_Ideograph", "Ideographic"},
    33757: {"Unified_Ideograph", "Ideographic"},
    33758: {"Unified_Ideograph", "Ideographic"},
    33759: {"Unified_Ideograph", "Ideographic"},
    33760: {"Unified_Ideograph", "Ideographic"},
    33761: {"Unified_Ideograph", "Ideographic"},
    33762: {"Unified_Ideograph", "Ideographic"},
    33763: {"Unified_Ideograph", "Ideographic"},
    33764: {"Unified_Ideograph", "Ideographic"},
    33765: {"Unified_Ideograph", "Ideographic"},
    33766: {"Unified_Ideograph", "Ideographic"},
    33767: {"Unified_Ideograph", "Ideographic"},
    33768: {"Unified_Ideograph", "Ideographic"},
    33769: {"Unified_Ideograph", "Ideographic"},
    33770: {"Unified_Ideograph", "Ideographic"},
    33771: {"Unified_Ideograph", "Ideographic"},
    33772: {"Unified_Ideograph", "Ideographic"},
    33773: {"Unified_Ideograph", "Ideographic"},
    33774: {"Unified_Ideograph", "Ideographic"},
    33775: {"Unified_Ideograph", "Ideographic"},
    33776: {"Unified_Ideograph", "Ideographic"},
    33777: {"Unified_Ideograph", "Ideographic"},
    33778: {"Unified_Ideograph", "Ideographic"},
    33779: {"Unified_Ideograph", "Ideographic"},
    33780: {"Unified_Ideograph", "Ideographic"},
    33781: {"Unified_Ideograph", "Ideographic"},
    33782: {"Unified_Ideograph", "Ideographic"},
    33783: {"Unified_Ideograph", "Ideographic"},
    33784: {"Unified_Ideograph", "Ideographic"},
    33785: {"Unified_Ideograph", "Ideographic"},
    33786: {"Unified_Ideograph", "Ideographic"},
    33787: {"Unified_Ideograph", "Ideographic"},
    33788: {"Unified_Ideograph", "Ideographic"},
    33789: {"Unified_Ideograph", "Ideographic"},
    33790: {"Unified_Ideograph", "Ideographic"},
    33791: {"Unified_Ideograph", "Ideographic"},
    33792: {"Unified_Ideograph", "Ideographic"},
    33793: {"Unified_Ideograph", "Ideographic"},
    33794: {"Unified_Ideograph", "Ideographic"},
    33795: {"Unified_Ideograph", "Ideographic"},
    33796: {"Unified_Ideograph", "Ideographic"},
    33797: {"Unified_Ideograph", "Ideographic"},
    33798: {"Unified_Ideograph", "Ideographic"},
    33799: {"Unified_Ideograph", "Ideographic"},
    33800: {"Unified_Ideograph", "Ideographic"},
    33801: {"Unified_Ideograph", "Ideographic"},
    33802: {"Unified_Ideograph", "Ideographic"},
    33803: {"Unified_Ideograph", "Ideographic"},
    33804: {"Unified_Ideograph", "Ideographic"},
    33805: {"Unified_Ideograph", "Ideographic"},
    33806: {"Unified_Ideograph", "Ideographic"},
    33807: {"Unified_Ideograph", "Ideographic"},
    33808: {"Unified_Ideograph", "Ideographic"},
    33809: {"Unified_Ideograph", "Ideographic"},
    33810: {"Unified_Ideograph", "Ideographic"},
    33811: {"Unified_Ideograph", "Ideographic"},
    33812: {"Unified_Ideograph", "Ideographic"},
    33813: {"Unified_Ideograph", "Ideographic"},
    33814: {"Unified_Ideograph", "Ideographic"},
    33815: {"Unified_Ideograph", "Ideographic"},
    33816: {"Unified_Ideograph", "Ideographic"},
    33817: {"Unified_Ideograph", "Ideographic"},
    33818: {"Unified_Ideograph", "Ideographic"},
    33819: {"Unified_Ideograph", "Ideographic"},
    33820: {"Unified_Ideograph", "Ideographic"},
    33821: {"Unified_Ideograph", "Ideographic"},
    33822: {"Unified_Ideograph", "Ideographic"},
    33823: {"Unified_Ideograph", "Ideographic"},
    33824: {"Unified_Ideograph", "Ideographic"},
    33825: {"Unified_Ideograph", "Ideographic"},
    33826: {"Unified_Ideograph", "Ideographic"},
    33827: {"Unified_Ideograph", "Ideographic"},
    33828: {"Unified_Ideograph", "Ideographic"},
    33829: {"Unified_Ideograph", "Ideographic"},
    33830: {"Unified_Ideograph", "Ideographic"},
    33831: {"Unified_Ideograph", "Ideographic"},
    33832: {"Unified_Ideograph", "Ideographic"},
    33833: {"Unified_Ideograph", "Ideographic"},
    33834: {"Unified_Ideograph", "Ideographic"},
    33835: {"Unified_Ideograph", "Ideographic"},
    33836: {"Unified_Ideograph", "Ideographic"},
    33837: {"Unified_Ideograph", "Ideographic"},
    33838: {"Unified_Ideograph", "Ideographic"},
    33839: {"Unified_Ideograph", "Ideographic"},
    33840: {"Unified_Ideograph", "Ideographic"},
    33841: {"Unified_Ideograph", "Ideographic"},
    33842: {"Unified_Ideograph", "Ideographic"},
    33843: {"Unified_Ideograph", "Ideographic"},
    33844: {"Unified_Ideograph", "Ideographic"},
    33845: {"Unified_Ideograph", "Ideographic"},
    33846: {"Unified_Ideograph", "Ideographic"},
    33847: {"Unified_Ideograph", "Ideographic"},
    33848: {"Unified_Ideograph", "Ideographic"},
    33849: {"Unified_Ideograph", "Ideographic"},
    33850: {"Unified_Ideograph", "Ideographic"},
    33851: {"Unified_Ideograph", "Ideographic"},
    33852: {"Unified_Ideograph", "Ideographic"},
    33853: {"Unified_Ideograph", "Ideographic"},
    33854: {"Unified_Ideograph", "Ideographic"},
    33855: {"Unified_Ideograph", "Ideographic"},
    33856: {"Unified_Ideograph", "Ideographic"},
    33857: {"Unified_Ideograph", "Ideographic"},
    33858: {"Unified_Ideograph", "Ideographic"},
    33859: {"Unified_Ideograph", "Ideographic"},
    33860: {"Unified_Ideograph", "Ideographic"},
    33861: {"Unified_Ideograph", "Ideographic"},
    33862: {"Unified_Ideograph", "Ideographic"},
    33863: {"Unified_Ideograph", "Ideographic"},
    33864: {"Unified_Ideograph", "Ideographic"},
    33865: {"Unified_Ideograph", "Ideographic"},
    33866: {"Unified_Ideograph", "Ideographic"},
    33867: {"Unified_Ideograph", "Ideographic"},
    33868: {"Unified_Ideograph", "Ideographic"},
    33869: {"Unified_Ideograph", "Ideographic"},
    33870: {"Unified_Ideograph", "Ideographic"},
    33871: {"Unified_Ideograph", "Ideographic"},
    33872: {"Unified_Ideograph", "Ideographic"},
    33873: {"Unified_Ideograph", "Ideographic"},
    33874: {"Unified_Ideograph", "Ideographic"},
    33875: {"Unified_Ideograph", "Ideographic"},
    33876: {"Unified_Ideograph", "Ideographic"},
    33877: {"Unified_Ideograph", "Ideographic"},
    33878: {"Unified_Ideograph", "Ideographic"},
    33879: {"Unified_Ideograph", "Ideographic"},
    33880: {"Unified_Ideograph", "Ideographic"},
    33881: {"Unified_Ideograph", "Ideographic"},
    33882: {"Unified_Ideograph", "Ideographic"},
    33883: {"Unified_Ideograph", "Ideographic"},
    33884: {"Unified_Ideograph", "Ideographic"},
    33885: {"Unified_Ideograph", "Ideographic"},
    33886: {"Unified_Ideograph", "Ideographic"},
    33887: {"Unified_Ideograph", "Ideographic"},
    33888: {"Unified_Ideograph", "Ideographic"},
    33889: {"Unified_Ideograph", "Ideographic"},
    33890: {"Unified_Ideograph", "Ideographic"},
    33891: {"Unified_Ideograph", "Ideographic"},
    33892: {"Unified_Ideograph", "Ideographic"},
    33893: {"Unified_Ideograph", "Ideographic"},
    33894: {"Unified_Ideograph", "Ideographic"},
    33895: {"Unified_Ideograph", "Ideographic"},
    33896: {"Unified_Ideograph", "Ideographic"},
    33897: {"Unified_Ideograph", "Ideographic"},
    33898: {"Unified_Ideograph", "Ideographic"},
    33899: {"Unified_Ideograph", "Ideographic"},
    33900: {"Unified_Ideograph", "Ideographic"},
    33901: {"Unified_Ideograph", "Ideographic"},
    33902: {"Unified_Ideograph", "Ideographic"},
    33903: {"Unified_Ideograph", "Ideographic"},
    33904: {"Unified_Ideograph", "Ideographic"},
    33905: {"Unified_Ideograph", "Ideographic"},
    33906: {"Unified_Ideograph", "Ideographic"},
    33907: {"Unified_Ideograph", "Ideographic"},
    33908: {"Unified_Ideograph", "Ideographic"},
    33909: {"Unified_Ideograph", "Ideographic"},
    33910: {"Unified_Ideograph", "Ideographic"},
    33911: {"Unified_Ideograph", "Ideographic"},
    33912: {"Unified_Ideograph", "Ideographic"},
    33913: {"Unified_Ideograph", "Ideographic"},
    33914: {"Unified_Ideograph", "Ideographic"},
    33915: {"Unified_Ideograph", "Ideographic"},
    33916: {"Unified_Ideograph", "Ideographic"},
    33917: {"Unified_Ideograph", "Ideographic"},
    33918: {"Unified_Ideograph", "Ideographic"},
    33919: {"Unified_Ideograph", "Ideographic"},
    33920: {"Unified_Ideograph", "Ideographic"},
    33921: {"Unified_Ideograph", "Ideographic"},
    33922: {"Unified_Ideograph", "Ideographic"},
    33923: {"Unified_Ideograph", "Ideographic"},
    33924: {"Unified_Ideograph", "Ideographic"},
    33925: {"Unified_Ideograph", "Ideographic"},
    33926: {"Unified_Ideograph", "Ideographic"},
    33927: {"Unified_Ideograph", "Ideographic"},
    33928: {"Unified_Ideograph", "Ideographic"},
    33929: {"Unified_Ideograph", "Ideographic"},
    33930: {"Unified_Ideograph", "Ideographic"},
    33931: {"Unified_Ideograph", "Ideographic"},
    33932: {"Unified_Ideograph", "Ideographic"},
    33933: {"Unified_Ideograph", "Ideographic"},
    33934: {"Unified_Ideograph", "Ideographic"},
    33935: {"Unified_Ideograph", "Ideographic"},
    33936: {"Unified_Ideograph", "Ideographic"},
    33937: {"Unified_Ideograph", "Ideographic"},
    33938: {"Unified_Ideograph", "Ideographic"},
    33939: {"Unified_Ideograph", "Ideographic"},
    33940: {"Unified_Ideograph", "Ideographic"},
    33941: {"Unified_Ideograph", "Ideographic"},
    33942: {"Unified_Ideograph", "Ideographic"},
    33943: {"Unified_Ideograph", "Ideographic"},
    33944: {"Unified_Ideograph", "Ideographic"},
    33945: {"Unified_Ideograph", "Ideographic"},
    33946: {"Unified_Ideograph", "Ideographic"},
    33947: {"Unified_Ideograph", "Ideographic"},
    33948: {"Unified_Ideograph", "Ideographic"},
    33949: {"Unified_Ideograph", "Ideographic"},
    33950: {"Unified_Ideograph", "Ideographic"},
    33951: {"Unified_Ideograph", "Ideographic"},
    33952: {"Unified_Ideograph", "Ideographic"},
    33953: {"Unified_Ideograph", "Ideographic"},
    33954: {"Unified_Ideograph", "Ideographic"},
    33955: {"Unified_Ideograph", "Ideographic"},
    33956: {"Unified_Ideograph", "Ideographic"},
    33957: {"Unified_Ideograph", "Ideographic"},
    33958: {"Unified_Ideograph", "Ideographic"},
    33959: {"Unified_Ideograph", "Ideographic"},
    33960: {"Unified_Ideograph", "Ideographic"},
    33961: {"Unified_Ideograph", "Ideographic"},
    33962: {"Unified_Ideograph", "Ideographic"},
    33963: {"Unified_Ideograph", "Ideographic"},
    33964: {"Unified_Ideograph", "Ideographic"},
    33965: {"Unified_Ideograph", "Ideographic"},
    33966: {"Unified_Ideograph", "Ideographic"},
    33967: {"Unified_Ideograph", "Ideographic"},
    33968: {"Unified_Ideograph", "Ideographic"},
    33969: {"Unified_Ideograph", "Ideographic"},
    33970: {"Unified_Ideograph", "Ideographic"},
    33971: {"Unified_Ideograph", "Ideographic"},
    33972: {"Unified_Ideograph", "Ideographic"},
    33973: {"Unified_Ideograph", "Ideographic"},
    33974: {"Unified_Ideograph", "Ideographic"},
    33975: {"Unified_Ideograph", "Ideographic"},
    33976: {"Unified_Ideograph", "Ideographic"},
    33977: {"Unified_Ideograph", "Ideographic"},
    33978: {"Unified_Ideograph", "Ideographic"},
    33979: {"Unified_Ideograph", "Ideographic"},
    33980: {"Unified_Ideograph", "Ideographic"},
    33981: {"Unified_Ideograph", "Ideographic"},
    33982: {"Unified_Ideograph", "Ideographic"},
    33983: {"Unified_Ideograph", "Ideographic"},
    33984: {"Unified_Ideograph", "Ideographic"},
    33985: {"Unified_Ideograph", "Ideographic"},
    33986: {"Unified_Ideograph", "Ideographic"},
    33987: {"Unified_Ideograph", "Ideographic"},
    33988: {"Unified_Ideograph", "Ideographic"},
    33989: {"Unified_Ideograph", "Ideographic"},
    33990: {"Unified_Ideograph", "Ideographic"},
    33991: {"Unified_Ideograph", "Ideographic"},
    33992: {"Unified_Ideograph", "Ideographic"},
    33993: {"Unified_Ideograph", "Ideographic"},
    33994: {"Unified_Ideograph", "Ideographic"},
    33995: {"Unified_Ideograph", "Ideographic"},
    33996: {"Unified_Ideograph", "Ideographic"},
    33997: {"Unified_Ideograph", "Ideographic"},
    33998: {"Unified_Ideograph", "Ideographic"},
    33999: {"Unified_Ideograph", "Ideographic"},
    34000: {"Unified_Ideograph", "Ideographic"},
    34001: {"Unified_Ideograph", "Ideographic"},
    34002: {"Unified_Ideograph", "Ideographic"},
    34003: {"Unified_Ideograph", "Ideographic"},
    34004: {"Unified_Ideograph", "Ideographic"},
    34005: {"Unified_Ideograph", "Ideographic"},
    34006: {"Unified_Ideograph", "Ideographic"},
    34007: {"Unified_Ideograph", "Ideographic"},
    34008: {"Unified_Ideograph", "Ideographic"},
    34009: {"Unified_Ideograph", "Ideographic"},
    34010: {"Unified_Ideograph", "Ideographic"},
    34011: {"Unified_Ideograph", "Ideographic"},
    34012: {"Unified_Ideograph", "Ideographic"},
    34013: {"Unified_Ideograph", "Ideographic"},
    34014: {"Unified_Ideograph", "Ideographic"},
    34015: {"Unified_Ideograph", "Ideographic"},
    34016: {"Unified_Ideograph", "Ideographic"},
    34017: {"Unified_Ideograph", "Ideographic"},
    34018: {"Unified_Ideograph", "Ideographic"},
    34019: {"Unified_Ideograph", "Ideographic"},
    34020: {"Unified_Ideograph", "Ideographic"},
    34021: {"Unified_Ideograph", "Ideographic"},
    34022: {"Unified_Ideograph", "Ideographic"},
    34023: {"Unified_Ideograph", "Ideographic"},
    34024: {"Unified_Ideograph", "Ideographic"},
    34025: {"Unified_Ideograph", "Ideographic"},
    34026: {"Unified_Ideograph", "Ideographic"},
    34027: {"Unified_Ideograph", "Ideographic"},
    34028: {"Unified_Ideograph", "Ideographic"},
    34029: {"Unified_Ideograph", "Ideographic"},
    34030: {"Unified_Ideograph", "Ideographic"},
    34031: {"Unified_Ideograph", "Ideographic"},
    34032: {"Unified_Ideograph", "Ideographic"},
    34033: {"Unified_Ideograph", "Ideographic"},
    34034: {"Unified_Ideograph", "Ideographic"},
    34035: {"Unified_Ideograph", "Ideographic"},
    34036: {"Unified_Ideograph", "Ideographic"},
    34037: {"Unified_Ideograph", "Ideographic"},
    34038: {"Unified_Ideograph", "Ideographic"},
    34039: {"Unified_Ideograph", "Ideographic"},
    34040: {"Unified_Ideograph", "Ideographic"},
    34041: {"Unified_Ideograph", "Ideographic"},
    34042: {"Unified_Ideograph", "Ideographic"},
    34043: {"Unified_Ideograph", "Ideographic"},
    34044: {"Unified_Ideograph", "Ideographic"},
    34045: {"Unified_Ideograph", "Ideographic"},
    34046: {"Unified_Ideograph", "Ideographic"},
    34047: {"Unified_Ideograph", "Ideographic"},
    34048: {"Unified_Ideograph", "Ideographic"},
    34049: {"Unified_Ideograph", "Ideographic"},
    34050: {"Unified_Ideograph", "Ideographic"},
    34051: {"Unified_Ideograph", "Ideographic"},
    34052: {"Unified_Ideograph", "Ideographic"},
    34053: {"Unified_Ideograph", "Ideographic"},
    34054: {"Unified_Ideograph", "Ideographic"},
    34055: {"Unified_Ideograph", "Ideographic"},
    34056: {"Unified_Ideograph", "Ideographic"},
    34057: {"Unified_Ideograph", "Ideographic"},
    34058: {"Unified_Ideograph", "Ideographic"},
    34059: {"Unified_Ideograph", "Ideographic"},
    34060: {"Unified_Ideograph", "Ideographic"},
    34061: {"Unified_Ideograph", "Ideographic"},
    34062: {"Unified_Ideograph", "Ideographic"},
    34063: {"Unified_Ideograph", "Ideographic"},
    34064: {"Unified_Ideograph", "Ideographic"},
    34065: {"Unified_Ideograph", "Ideographic"},
    34066: {"Unified_Ideograph", "Ideographic"},
    34067: {"Unified_Ideograph", "Ideographic"},
    34068: {"Unified_Ideograph", "Ideographic"},
    34069: {"Unified_Ideograph", "Ideographic"},
    34070: {"Unified_Ideograph", "Ideographic"},
    34071: {"Unified_Ideograph", "Ideographic"},
    34072: {"Unified_Ideograph", "Ideographic"},
    34073: {"Unified_Ideograph", "Ideographic"},
    34074: {"Unified_Ideograph", "Ideographic"},
    34075: {"Unified_Ideograph", "Ideographic"},
    34076: {"Unified_Ideograph", "Ideographic"},
    34077: {"Unified_Ideograph", "Ideographic"},
    34078: {"Unified_Ideograph", "Ideographic"},
    34079: {"Unified_Ideograph", "Ideographic"},
    34080: {"Unified_Ideograph", "Ideographic"},
    34081: {"Unified_Ideograph", "Ideographic"},
    34082: {"Unified_Ideograph", "Ideographic"},
    34083: {"Unified_Ideograph", "Ideographic"},
    34084: {"Unified_Ideograph", "Ideographic"},
    34085: {"Unified_Ideograph", "Ideographic"},
    34086: {"Unified_Ideograph", "Ideographic"},
    34087: {"Unified_Ideograph", "Ideographic"},
    34088: {"Unified_Ideograph", "Ideographic"},
    34089: {"Unified_Ideograph", "Ideographic"},
    34090: {"Unified_Ideograph", "Ideographic"},
    34091: {"Unified_Ideograph", "Ideographic"},
    34092: {"Unified_Ideograph", "Ideographic"},
    34093: {"Unified_Ideograph", "Ideographic"},
    34094: {"Unified_Ideograph", "Ideographic"},
    34095: {"Unified_Ideograph", "Ideographic"},
    34096: {"Unified_Ideograph", "Ideographic"},
    34097: {"Unified_Ideograph", "Ideographic"},
    34098: {"Unified_Ideograph", "Ideographic"},
    34099: {"Unified_Ideograph", "Ideographic"},
    34100: {"Unified_Ideograph", "Ideographic"},
    34101: {"Unified_Ideograph", "Ideographic"},
    34102: {"Unified_Ideograph", "Ideographic"},
    34103: {"Unified_Ideograph", "Ideographic"},
    34104: {"Unified_Ideograph", "Ideographic"},
    34105: {"Unified_Ideograph", "Ideographic"},
    34106: {"Unified_Ideograph", "Ideographic"},
    34107: {"Unified_Ideograph", "Ideographic"},
    34108: {"Unified_Ideograph", "Ideographic"},
    34109: {"Unified_Ideograph", "Ideographic"},
    34110: {"Unified_Ideograph", "Ideographic"},
    34111: {"Unified_Ideograph", "Ideographic"},
    34112: {"Unified_Ideograph", "Ideographic"},
    34113: {"Unified_Ideograph", "Ideographic"},
    34114: {"Unified_Ideograph", "Ideographic"},
    34115: {"Unified_Ideograph", "Ideographic"},
    34116: {"Unified_Ideograph", "Ideographic"},
    34117: {"Unified_Ideograph", "Ideographic"},
    34118: {"Unified_Ideograph", "Ideographic"},
    34119: {"Unified_Ideograph", "Ideographic"},
    34120: {"Unified_Ideograph", "Ideographic"},
    34121: {"Unified_Ideograph", "Ideographic"},
    34122: {"Unified_Ideograph", "Ideographic"},
    34123: {"Unified_Ideograph", "Ideographic"},
    34124: {"Unified_Ideograph", "Ideographic"},
    34125: {"Unified_Ideograph", "Ideographic"},
    34126: {"Unified_Ideograph", "Ideographic"},
    34127: {"Unified_Ideograph", "Ideographic"},
    34128: {"Unified_Ideograph", "Ideographic"},
    34129: {"Unified_Ideograph", "Ideographic"},
    34130: {"Unified_Ideograph", "Ideographic"},
    34131: {"Unified_Ideograph", "Ideographic"},
    34132: {"Unified_Ideograph", "Ideographic"},
    34133: {"Unified_Ideograph", "Ideographic"},
    34134: {"Unified_Ideograph", "Ideographic"},
    34135: {"Unified_Ideograph", "Ideographic"},
    34136: {"Unified_Ideograph", "Ideographic"},
    34137: {"Unified_Ideograph", "Ideographic"},
    34138: {"Unified_Ideograph", "Ideographic"},
    34139: {"Unified_Ideograph", "Ideographic"},
    34140: {"Unified_Ideograph", "Ideographic"},
    34141: {"Unified_Ideograph", "Ideographic"},
    34142: {"Unified_Ideograph", "Ideographic"},
    34143: {"Unified_Ideograph", "Ideographic"},
    34144: {"Unified_Ideograph", "Ideographic"},
    34145: {"Unified_Ideograph", "Ideographic"},
    34146: {"Unified_Ideograph", "Ideographic"},
    34147: {"Unified_Ideograph", "Ideographic"},
    34148: {"Unified_Ideograph", "Ideographic"},
    34149: {"Unified_Ideograph", "Ideographic"},
    34150: {"Unified_Ideograph", "Ideographic"},
    34151: {"Unified_Ideograph", "Ideographic"},
    34152: {"Unified_Ideograph", "Ideographic"},
    34153: {"Unified_Ideograph", "Ideographic"},
    34154: {"Unified_Ideograph", "Ideographic"},
    34155: {"Unified_Ideograph", "Ideographic"},
    34156: {"Unified_Ideograph", "Ideographic"},
    34157: {"Unified_Ideograph", "Ideographic"},
    34158: {"Unified_Ideograph", "Ideographic"},
    34159: {"Unified_Ideograph", "Ideographic"},
    34160: {"Unified_Ideograph", "Ideographic"},
    34161: {"Unified_Ideograph", "Ideographic"},
    34162: {"Unified_Ideograph", "Ideographic"},
    34163: {"Unified_Ideograph", "Ideographic"},
    34164: {"Unified_Ideograph", "Ideographic"},
    34165: {"Unified_Ideograph", "Ideographic"},
    34166: {"Unified_Ideograph", "Ideographic"},
    34167: {"Unified_Ideograph", "Ideographic"},
    34168: {"Unified_Ideograph", "Ideographic"},
    34169: {"Unified_Ideograph", "Ideographic"},
    34170: {"Unified_Ideograph", "Ideographic"},
    34171: {"Unified_Ideograph", "Ideographic"},
    34172: {"Unified_Ideograph", "Ideographic"},
    34173: {"Unified_Ideograph", "Ideographic"},
    34174: {"Unified_Ideograph", "Ideographic"},
    34175: {"Unified_Ideograph", "Ideographic"},
    34176: {"Unified_Ideograph", "Ideographic"},
    34177: {"Unified_Ideograph", "Ideographic"},
    34178: {"Unified_Ideograph", "Ideographic"},
    34179: {"Unified_Ideograph", "Ideographic"},
    34180: {"Unified_Ideograph", "Ideographic"},
    34181: {"Unified_Ideograph", "Ideographic"},
    34182: {"Unified_Ideograph", "Ideographic"},
    34183: {"Unified_Ideograph", "Ideographic"},
    34184: {"Unified_Ideograph", "Ideographic"},
    34185: {"Unified_Ideograph", "Ideographic"},
    34186: {"Unified_Ideograph", "Ideographic"},
    34187: {"Unified_Ideograph", "Ideographic"},
    34188: {"Unified_Ideograph", "Ideographic"},
    34189: {"Unified_Ideograph", "Ideographic"},
    34190: {"Unified_Ideograph", "Ideographic"},
    34191: {"Unified_Ideograph", "Ideographic"},
    34192: {"Unified_Ideograph", "Ideographic"},
    34193: {"Unified_Ideograph", "Ideographic"},
    34194: {"Unified_Ideograph", "Ideographic"},
    34195: {"Unified_Ideograph", "Ideographic"},
    34196: {"Unified_Ideograph", "Ideographic"},
    34197: {"Unified_Ideograph", "Ideographic"},
    34198: {"Unified_Ideograph", "Ideographic"},
    34199: {"Unified_Ideograph", "Ideographic"},
    34200: {"Unified_Ideograph", "Ideographic"},
    34201: {"Unified_Ideograph", "Ideographic"},
    34202: {"Unified_Ideograph", "Ideographic"},
    34203: {"Unified_Ideograph", "Ideographic"},
    34204: {"Unified_Ideograph", "Ideographic"},
    34205: {"Unified_Ideograph", "Ideographic"},
    34206: {"Unified_Ideograph", "Ideographic"},
    34207: {"Unified_Ideograph", "Ideographic"},
    34208: {"Unified_Ideograph", "Ideographic"},
    34209: {"Unified_Ideograph", "Ideographic"},
    34210: {"Unified_Ideograph", "Ideographic"},
    34211: {"Unified_Ideograph", "Ideographic"},
    34212: {"Unified_Ideograph", "Ideographic"},
    34213: {"Unified_Ideograph", "Ideographic"},
    34214: {"Unified_Ideograph", "Ideographic"},
    34215: {"Unified_Ideograph", "Ideographic"},
    34216: {"Unified_Ideograph", "Ideographic"},
    34217: {"Unified_Ideograph", "Ideographic"},
    34218: {"Unified_Ideograph", "Ideographic"},
    34219: {"Unified_Ideograph", "Ideographic"},
    34220: {"Unified_Ideograph", "Ideographic"},
    34221: {"Unified_Ideograph", "Ideographic"},
    34222: {"Unified_Ideograph", "Ideographic"},
    34223: {"Unified_Ideograph", "Ideographic"},
    34224: {"Unified_Ideograph", "Ideographic"},
    34225: {"Unified_Ideograph", "Ideographic"},
    34226: {"Unified_Ideograph", "Ideographic"},
    34227: {"Unified_Ideograph", "Ideographic"},
    34228: {"Unified_Ideograph", "Ideographic"},
    34229: {"Unified_Ideograph", "Ideographic"},
    34230: {"Unified_Ideograph", "Ideographic"},
    34231: {"Unified_Ideograph", "Ideographic"},
    34232: {"Unified_Ideograph", "Ideographic"},
    34233: {"Unified_Ideograph", "Ideographic"},
    34234: {"Unified_Ideograph", "Ideographic"},
    34235: {"Unified_Ideograph", "Ideographic"},
    34236: {"Unified_Ideograph", "Ideographic"},
    34237: {"Unified_Ideograph", "Ideographic"},
    34238: {"Unified_Ideograph", "Ideographic"},
    34239: {"Unified_Ideograph", "Ideographic"},
    34240: {"Unified_Ideograph", "Ideographic"},
    34241: {"Unified_Ideograph", "Ideographic"},
    34242: {"Unified_Ideograph", "Ideographic"},
    34243: {"Unified_Ideograph", "Ideographic"},
    34244: {"Unified_Ideograph", "Ideographic"},
    34245: {"Unified_Ideograph", "Ideographic"},
    34246: {"Unified_Ideograph", "Ideographic"},
    34247: {"Unified_Ideograph", "Ideographic"},
    34248: {"Unified_Ideograph", "Ideographic"},
    34249: {"Unified_Ideograph", "Ideographic"},
    34250: {"Unified_Ideograph", "Ideographic"},
    34251: {"Unified_Ideograph", "Ideographic"},
    34252: {"Unified_Ideograph", "Ideographic"},
    34253: {"Unified_Ideograph", "Ideographic"},
    34254: {"Unified_Ideograph", "Ideographic"},
    34255: {"Unified_Ideograph", "Ideographic"},
    34256: {"Unified_Ideograph", "Ideographic"},
    34257: {"Unified_Ideograph", "Ideographic"},
    34258: {"Unified_Ideograph", "Ideographic"},
    34259: {"Unified_Ideograph", "Ideographic"},
    34260: {"Unified_Ideograph", "Ideographic"},
    34261: {"Unified_Ideograph", "Ideographic"},
    34262: {"Unified_Ideograph", "Ideographic"},
    34263: {"Unified_Ideograph", "Ideographic"},
    34264: {"Unified_Ideograph", "Ideographic"},
    34265: {"Unified_Ideograph", "Ideographic"},
    34266: {"Unified_Ideograph", "Ideographic"},
    34267: {"Unified_Ideograph", "Ideographic"},
    34268: {"Unified_Ideograph", "Ideographic"},
    34269: {"Unified_Ideograph", "Ideographic"},
    34270: {"Unified_Ideograph", "Ideographic"},
    34271: {"Unified_Ideograph", "Ideographic"},
    34272: {"Unified_Ideograph", "Ideographic"},
    34273: {"Unified_Ideograph", "Ideographic"},
    34274: {"Unified_Ideograph", "Ideographic"},
    34275: {"Unified_Ideograph", "Ideographic"},
    34276: {"Unified_Ideograph", "Ideographic"},
    34277: {"Unified_Ideograph", "Ideographic"},
    34278: {"Unified_Ideograph", "Ideographic"},
    34279: {"Unified_Ideograph", "Ideographic"},
    34280: {"Unified_Ideograph", "Ideographic"},
    34281: {"Unified_Ideograph", "Ideographic"},
    34282: {"Unified_Ideograph", "Ideographic"},
    34283: {"Unified_Ideograph", "Ideographic"},
    34284: {"Unified_Ideograph", "Ideographic"},
    34285: {"Unified_Ideograph", "Ideographic"},
    34286: {"Unified_Ideograph", "Ideographic"},
    34287: {"Unified_Ideograph", "Ideographic"},
    34288: {"Unified_Ideograph", "Ideographic"},
    34289: {"Unified_Ideograph", "Ideographic"},
    34290: {"Unified_Ideograph", "Ideographic"},
    34291: {"Unified_Ideograph", "Ideographic"},
    34292: {"Unified_Ideograph", "Ideographic"},
    34293: {"Unified_Ideograph", "Ideographic"},
    34294: {"Unified_Ideograph", "Ideographic"},
    34295: {"Unified_Ideograph", "Ideographic"},
    34296: {"Unified_Ideograph", "Ideographic"},
    34297: {"Unified_Ideograph", "Ideographic"},
    34298: {"Unified_Ideograph", "Ideographic"},
    34299: {"Unified_Ideograph", "Ideographic"},
    34300: {"Unified_Ideograph", "Ideographic"},
    34301: {"Unified_Ideograph", "Ideographic"},
    34302: {"Unified_Ideograph", "Ideographic"},
    34303: {"Unified_Ideograph", "Ideographic"},
    34304: {"Unified_Ideograph", "Ideographic"},
    34305: {"Unified_Ideograph", "Ideographic"},
    34306: {"Unified_Ideograph", "Ideographic"},
    34307: {"Unified_Ideograph", "Ideographic"},
    34308: {"Unified_Ideograph", "Ideographic"},
    34309: {"Unified_Ideograph", "Ideographic"},
    34310: {"Unified_Ideograph", "Ideographic"},
    34311: {"Unified_Ideograph", "Ideographic"},
    34312: {"Unified_Ideograph", "Ideographic"},
    34313: {"Unified_Ideograph", "Ideographic"},
    34314: {"Unified_Ideograph", "Ideographic"},
    34315: {"Unified_Ideograph", "Ideographic"},
    34316: {"Unified_Ideograph", "Ideographic"},
    34317: {"Unified_Ideograph", "Ideographic"},
    34318: {"Unified_Ideograph", "Ideographic"},
    34319: {"Unified_Ideograph", "Ideographic"},
    34320: {"Unified_Ideograph", "Ideographic"},
    34321: {"Unified_Ideograph", "Ideographic"},
    34322: {"Unified_Ideograph", "Ideographic"},
    34323: {"Unified_Ideograph", "Ideographic"},
    34324: {"Unified_Ideograph", "Ideographic"},
    34325: {"Unified_Ideograph", "Ideographic"},
    34326: {"Unified_Ideograph", "Ideographic"},
    34327: {"Unified_Ideograph", "Ideographic"},
    34328: {"Unified_Ideograph", "Ideographic"},
    34329: {"Unified_Ideograph", "Ideographic"},
    34330: {"Unified_Ideograph", "Ideographic"},
    34331: {"Unified_Ideograph", "Ideographic"},
    34332: {"Unified_Ideograph", "Ideographic"},
    34333: {"Unified_Ideograph", "Ideographic"},
    34334: {"Unified_Ideograph", "Ideographic"},
    34335: {"Unified_Ideograph", "Ideographic"},
    34336: {"Unified_Ideograph", "Ideographic"},
    34337: {"Unified_Ideograph", "Ideographic"},
    34338: {"Unified_Ideograph", "Ideographic"},
    34339: {"Unified_Ideograph", "Ideographic"},
    34340: {"Unified_Ideograph", "Ideographic"},
    34341: {"Unified_Ideograph", "Ideographic"},
    34342: {"Unified_Ideograph", "Ideographic"},
    34343: {"Unified_Ideograph", "Ideographic"},
    34344: {"Unified_Ideograph", "Ideographic"},
    34345: {"Unified_Ideograph", "Ideographic"},
    34346: {"Unified_Ideograph", "Ideographic"},
    34347: {"Unified_Ideograph", "Ideographic"},
    34348: {"Unified_Ideograph", "Ideographic"},
    34349: {"Unified_Ideograph", "Ideographic"},
    34350: {"Unified_Ideograph", "Ideographic"},
    34351: {"Unified_Ideograph", "Ideographic"},
    34352: {"Unified_Ideograph", "Ideographic"},
    34353: {"Unified_Ideograph", "Ideographic"},
    34354: {"Unified_Ideograph", "Ideographic"},
    34355: {"Unified_Ideograph", "Ideographic"},
    34356: {"Unified_Ideograph", "Ideographic"},
    34357: {"Unified_Ideograph", "Ideographic"},
    34358: {"Unified_Ideograph", "Ideographic"},
    34359: {"Unified_Ideograph", "Ideographic"},
    34360: {"Unified_Ideograph", "Ideographic"},
    34361: {"Unified_Ideograph", "Ideographic"},
    34362: {"Unified_Ideograph", "Ideographic"},
    34363: {"Unified_Ideograph", "Ideographic"},
    34364: {"Unified_Ideograph", "Ideographic"},
    34365: {"Unified_Ideograph", "Ideographic"},
    34366: {"Unified_Ideograph", "Ideographic"},
    34367: {"Unified_Ideograph", "Ideographic"},
    34368: {"Unified_Ideograph", "Ideographic"},
    34369: {"Unified_Ideograph", "Ideographic"},
    34370: {"Unified_Ideograph", "Ideographic"},
    34371: {"Unified_Ideograph", "Ideographic"},
    34372: {"Unified_Ideograph", "Ideographic"},
    34373: {"Unified_Ideograph", "Ideographic"},
    34374: {"Unified_Ideograph", "Ideographic"},
    34375: {"Unified_Ideograph", "Ideographic"},
    34376: {"Unified_Ideograph", "Ideographic"},
    34377: {"Unified_Ideograph", "Ideographic"},
    34378: {"Unified_Ideograph", "Ideographic"},
    34379: {"Unified_Ideograph", "Ideographic"},
    34380: {"Unified_Ideograph", "Ideographic"},
    34381: {"Unified_Ideograph", "Ideographic"},
    34382: {"Unified_Ideograph", "Ideographic"},
    34383: {"Unified_Ideograph", "Ideographic"},
    34384: {"Unified_Ideograph", "Ideographic"},
    34385: {"Unified_Ideograph", "Ideographic"},
    34386: {"Unified_Ideograph", "Ideographic"},
    34387: {"Unified_Ideograph", "Ideographic"},
    34388: {"Unified_Ideograph", "Ideographic"},
    34389: {"Unified_Ideograph", "Ideographic"},
    34390: {"Unified_Ideograph", "Ideographic"},
    34391: {"Unified_Ideograph", "Ideographic"},
    34392: {"Unified_Ideograph", "Ideographic"},
    34393: {"Unified_Ideograph", "Ideographic"},
    34394: {"Unified_Ideograph", "Ideographic"},
    34395: {"Unified_Ideograph", "Ideographic"},
    34396: {"Unified_Ideograph", "Ideographic"},
    34397: {"Unified_Ideograph", "Ideographic"},
    34398: {"Unified_Ideograph", "Ideographic"},
    34399: {"Unified_Ideograph", "Ideographic"},
    34400: {"Unified_Ideograph", "Ideographic"},
    34401: {"Unified_Ideograph", "Ideographic"},
    34402: {"Unified_Ideograph", "Ideographic"},
    34403: {"Unified_Ideograph", "Ideographic"},
    34404: {"Unified_Ideograph", "Ideographic"},
    34405: {"Unified_Ideograph", "Ideographic"},
    34406: {"Unified_Ideograph", "Ideographic"},
    34407: {"Unified_Ideograph", "Ideographic"},
    34408: {"Unified_Ideograph", "Ideographic"},
    34409: {"Unified_Ideograph", "Ideographic"},
    34410: {"Unified_Ideograph", "Ideographic"},
    34411: {"Unified_Ideograph", "Ideographic"},
    34412: {"Unified_Ideograph", "Ideographic"},
    34413: {"Unified_Ideograph", "Ideographic"},
    34414: {"Unified_Ideograph", "Ideographic"},
    34415: {"Unified_Ideograph", "Ideographic"},
    34416: {"Unified_Ideograph", "Ideographic"},
    34417: {"Unified_Ideograph", "Ideographic"},
    34418: {"Unified_Ideograph", "Ideographic"},
    34419: {"Unified_Ideograph", "Ideographic"},
    34420: {"Unified_Ideograph", "Ideographic"},
    34421: {"Unified_Ideograph", "Ideographic"},
    34422: {"Unified_Ideograph", "Ideographic"},
    34423: {"Unified_Ideograph", "Ideographic"},
    34424: {"Unified_Ideograph", "Ideographic"},
    34425: {"Unified_Ideograph", "Ideographic"},
    34426: {"Unified_Ideograph", "Ideographic"},
    34427: {"Unified_Ideograph", "Ideographic"},
    34428: {"Unified_Ideograph", "Ideographic"},
    34429: {"Unified_Ideograph", "Ideographic"},
    34430: {"Unified_Ideograph", "Ideographic"},
    34431: {"Unified_Ideograph", "Ideographic"},
    34432: {"Unified_Ideograph", "Ideographic"},
    34433: {"Unified_Ideograph", "Ideographic"},
    34434: {"Unified_Ideograph", "Ideographic"},
    34435: {"Unified_Ideograph", "Ideographic"},
    34436: {"Unified_Ideograph", "Ideographic"},
    34437: {"Unified_Ideograph", "Ideographic"},
    34438: {"Unified_Ideograph", "Ideographic"},
    34439: {"Unified_Ideograph", "Ideographic"},
    34440: {"Unified_Ideograph", "Ideographic"},
    34441: {"Unified_Ideograph", "Ideographic"},
    34442: {"Unified_Ideograph", "Ideographic"},
    34443: {"Unified_Ideograph", "Ideographic"},
    34444: {"Unified_Ideograph", "Ideographic"},
    34445: {"Unified_Ideograph", "Ideographic"},
    34446: {"Unified_Ideograph", "Ideographic"},
    34447: {"Unified_Ideograph", "Ideographic"},
    34448: {"Unified_Ideograph", "Ideographic"},
    34449: {"Unified_Ideograph", "Ideographic"},
    34450: {"Unified_Ideograph", "Ideographic"},
    34451: {"Unified_Ideograph", "Ideographic"},
    34452: {"Unified_Ideograph", "Ideographic"},
    34453: {"Unified_Ideograph", "Ideographic"},
    34454: {"Unified_Ideograph", "Ideographic"},
    34455: {"Unified_Ideograph", "Ideographic"},
    34456: {"Unified_Ideograph", "Ideographic"},
    34457: {"Unified_Ideograph", "Ideographic"},
    34458: {"Unified_Ideograph", "Ideographic"},
    34459: {"Unified_Ideograph", "Ideographic"},
    34460: {"Unified_Ideograph", "Ideographic"},
    34461: {"Unified_Ideograph", "Ideographic"},
    34462: {"Unified_Ideograph", "Ideographic"},
    34463: {"Unified_Ideograph", "Ideographic"},
    34464: {"Unified_Ideograph", "Ideographic"},
    34465: {"Unified_Ideograph", "Ideographic"},
    34466: {"Unified_Ideograph", "Ideographic"},
    34467: {"Unified_Ideograph", "Ideographic"},
    34468: {"Unified_Ideograph", "Ideographic"},
    34469: {"Unified_Ideograph", "Ideographic"},
    34470: {"Unified_Ideograph", "Ideographic"},
    34471: {"Unified_Ideograph", "Ideographic"},
    34472: {"Unified_Ideograph", "Ideographic"},
    34473: {"Unified_Ideograph", "Ideographic"},
    34474: {"Unified_Ideograph", "Ideographic"},
    34475: {"Unified_Ideograph", "Ideographic"},
    34476: {"Unified_Ideograph", "Ideographic"},
    34477: {"Unified_Ideograph", "Ideographic"},
    34478: {"Unified_Ideograph", "Ideographic"},
    34479: {"Unified_Ideograph", "Ideographic"},
    34480: {"Unified_Ideograph", "Ideographic"},
    34481: {"Unified_Ideograph", "Ideographic"},
    34482: {"Unified_Ideograph", "Ideographic"},
    34483: {"Unified_Ideograph", "Ideographic"},
    34484: {"Unified_Ideograph", "Ideographic"},
    34485: {"Unified_Ideograph", "Ideographic"},
    34486: {"Unified_Ideograph", "Ideographic"},
    34487: {"Unified_Ideograph", "Ideographic"},
    34488: {"Unified_Ideograph", "Ideographic"},
    34489: {"Unified_Ideograph", "Ideographic"},
    34490: {"Unified_Ideograph", "Ideographic"},
    34491: {"Unified_Ideograph", "Ideographic"},
    34492: {"Unified_Ideograph", "Ideographic"},
    34493: {"Unified_Ideograph", "Ideographic"},
    34494: {"Unified_Ideograph", "Ideographic"},
    34495: {"Unified_Ideograph", "Ideographic"},
    34496: {"Unified_Ideograph", "Ideographic"},
    34497: {"Unified_Ideograph", "Ideographic"},
    34498: {"Unified_Ideograph", "Ideographic"},
    34499: {"Unified_Ideograph", "Ideographic"},
    34500: {"Unified_Ideograph", "Ideographic"},
    34501: {"Unified_Ideograph", "Ideographic"},
    34502: {"Unified_Ideograph", "Ideographic"},
    34503: {"Unified_Ideograph", "Ideographic"},
    34504: {"Unified_Ideograph", "Ideographic"},
    34505: {"Unified_Ideograph", "Ideographic"},
    34506: {"Unified_Ideograph", "Ideographic"},
    34507: {"Unified_Ideograph", "Ideographic"},
    34508: {"Unified_Ideograph", "Ideographic"},
    34509: {"Unified_Ideograph", "Ideographic"},
    34510: {"Unified_Ideograph", "Ideographic"},
    34511: {"Unified_Ideograph", "Ideographic"},
    34512: {"Unified_Ideograph", "Ideographic"},
    34513: {"Unified_Ideograph", "Ideographic"},
    34514: {"Unified_Ideograph", "Ideographic"},
    34515: {"Unified_Ideograph", "Ideographic"},
    34516: {"Unified_Ideograph", "Ideographic"},
    34517: {"Unified_Ideograph", "Ideographic"},
    34518: {"Unified_Ideograph", "Ideographic"},
    34519: {"Unified_Ideograph", "Ideographic"},
    34520: {"Unified_Ideograph", "Ideographic"},
    34521: {"Unified_Ideograph", "Ideographic"},
    34522: {"Unified_Ideograph", "Ideographic"},
    34523: {"Unified_Ideograph", "Ideographic"},
    34524: {"Unified_Ideograph", "Ideographic"},
    34525: {"Unified_Ideograph", "Ideographic"},
    34526: {"Unified_Ideograph", "Ideographic"},
    34527: {"Unified_Ideograph", "Ideographic"},
    34528: {"Unified_Ideograph", "Ideographic"},
    34529: {"Unified_Ideograph", "Ideographic"},
    34530: {"Unified_Ideograph", "Ideographic"},
    34531: {"Unified_Ideograph", "Ideographic"},
    34532: {"Unified_Ideograph", "Ideographic"},
    34533: {"Unified_Ideograph", "Ideographic"},
    34534: {"Unified_Ideograph", "Ideographic"},
    34535: {"Unified_Ideograph", "Ideographic"},
    34536: {"Unified_Ideograph", "Ideographic"},
    34537: {"Unified_Ideograph", "Ideographic"},
    34538: {"Unified_Ideograph", "Ideographic"},
    34539: {"Unified_Ideograph", "Ideographic"},
    34540: {"Unified_Ideograph", "Ideographic"},
    34541: {"Unified_Ideograph", "Ideographic"},
    34542: {"Unified_Ideograph", "Ideographic"},
    34543: {"Unified_Ideograph", "Ideographic"},
    34544: {"Unified_Ideograph", "Ideographic"},
    34545: {"Unified_Ideograph", "Ideographic"},
    34546: {"Unified_Ideograph", "Ideographic"},
    34547: {"Unified_Ideograph", "Ideographic"},
    34548: {"Unified_Ideograph", "Ideographic"},
    34549: {"Unified_Ideograph", "Ideographic"},
    34550: {"Unified_Ideograph", "Ideographic"},
    34551: {"Unified_Ideograph", "Ideographic"},
    34552: {"Unified_Ideograph", "Ideographic"},
    34553: {"Unified_Ideograph", "Ideographic"},
    34554: {"Unified_Ideograph", "Ideographic"},
    34555: {"Unified_Ideograph", "Ideographic"},
    34556: {"Unified_Ideograph", "Ideographic"},
    34557: {"Unified_Ideograph", "Ideographic"},
    34558: {"Unified_Ideograph", "Ideographic"},
    34559: {"Unified_Ideograph", "Ideographic"},
    34560: {"Unified_Ideograph", "Ideographic"},
    34561: {"Unified_Ideograph", "Ideographic"},
    34562: {"Unified_Ideograph", "Ideographic"},
    34563: {"Unified_Ideograph", "Ideographic"},
    34564: {"Unified_Ideograph", "Ideographic"},
    34565: {"Unified_Ideograph", "Ideographic"},
    34566: {"Unified_Ideograph", "Ideographic"},
    34567: {"Unified_Ideograph", "Ideographic"},
    34568: {"Unified_Ideograph", "Ideographic"},
    34569: {"Unified_Ideograph", "Ideographic"},
    34570: {"Unified_Ideograph", "Ideographic"},
    34571: {"Unified_Ideograph", "Ideographic"},
    34572: {"Unified_Ideograph", "Ideographic"},
    34573: {"Unified_Ideograph", "Ideographic"},
    34574: {"Unified_Ideograph", "Ideographic"},
    34575: {"Unified_Ideograph", "Ideographic"},
    34576: {"Unified_Ideograph", "Ideographic"},
    34577: {"Unified_Ideograph", "Ideographic"},
    34578: {"Unified_Ideograph", "Ideographic"},
    34579: {"Unified_Ideograph", "Ideographic"},
    34580: {"Unified_Ideograph", "Ideographic"},
    34581: {"Unified_Ideograph", "Ideographic"},
    34582: {"Unified_Ideograph", "Ideographic"},
    34583: {"Unified_Ideograph", "Ideographic"},
    34584: {"Unified_Ideograph", "Ideographic"},
    34585: {"Unified_Ideograph", "Ideographic"},
    34586: {"Unified_Ideograph", "Ideographic"},
    34587: {"Unified_Ideograph", "Ideographic"},
    34588: {"Unified_Ideograph", "Ideographic"},
    34589: {"Unified_Ideograph", "Ideographic"},
    34590: {"Unified_Ideograph", "Ideographic"},
    34591: {"Unified_Ideograph", "Ideographic"},
    34592: {"Unified_Ideograph", "Ideographic"},
    34593: {"Unified_Ideograph", "Ideographic"},
    34594: {"Unified_Ideograph", "Ideographic"},
    34595: {"Unified_Ideograph", "Ideographic"},
    34596: {"Unified_Ideograph", "Ideographic"},
    34597: {"Unified_Ideograph", "Ideographic"},
    34598: {"Unified_Ideograph", "Ideographic"},
    34599: {"Unified_Ideograph", "Ideographic"},
    34600: {"Unified_Ideograph", "Ideographic"},
    34601: {"Unified_Ideograph", "Ideographic"},
    34602: {"Unified_Ideograph", "Ideographic"},
    34603: {"Unified_Ideograph", "Ideographic"},
    34604: {"Unified_Ideograph", "Ideographic"},
    34605: {"Unified_Ideograph", "Ideographic"},
    34606: {"Unified_Ideograph", "Ideographic"},
    34607: {"Unified_Ideograph", "Ideographic"},
    34608: {"Unified_Ideograph", "Ideographic"},
    34609: {"Unified_Ideograph", "Ideographic"},
    34610: {"Unified_Ideograph", "Ideographic"},
    34611: {"Unified_Ideograph", "Ideographic"},
    34612: {"Unified_Ideograph", "Ideographic"},
    34613: {"Unified_Ideograph", "Ideographic"},
    34614: {"Unified_Ideograph", "Ideographic"},
    34615: {"Unified_Ideograph", "Ideographic"},
    34616: {"Unified_Ideograph", "Ideographic"},
    34617: {"Unified_Ideograph", "Ideographic"},
    34618: {"Unified_Ideograph", "Ideographic"},
    34619: {"Unified_Ideograph", "Ideographic"},
    34620: {"Unified_Ideograph", "Ideographic"},
    34621: {"Unified_Ideograph", "Ideographic"},
    34622: {"Unified_Ideograph", "Ideographic"},
    34623: {"Unified_Ideograph", "Ideographic"},
    34624: {"Unified_Ideograph", "Ideographic"},
    34625: {"Unified_Ideograph", "Ideographic"},
    34626: {"Unified_Ideograph", "Ideographic"},
    34627: {"Unified_Ideograph", "Ideographic"},
    34628: {"Unified_Ideograph", "Ideographic"},
    34629: {"Unified_Ideograph", "Ideographic"},
    34630: {"Unified_Ideograph", "Ideographic"},
    34631: {"Unified_Ideograph", "Ideographic"},
    34632: {"Unified_Ideograph", "Ideographic"},
    34633: {"Unified_Ideograph", "Ideographic"},
    34634: {"Unified_Ideograph", "Ideographic"},
    34635: {"Unified_Ideograph", "Ideographic"},
    34636: {"Unified_Ideograph", "Ideographic"},
    34637: {"Unified_Ideograph", "Ideographic"},
    34638: {"Unified_Ideograph", "Ideographic"},
    34639: {"Unified_Ideograph", "Ideographic"},
    34640: {"Unified_Ideograph", "Ideographic"},
    34641: {"Unified_Ideograph", "Ideographic"},
    34642: {"Unified_Ideograph", "Ideographic"},
    34643: {"Unified_Ideograph", "Ideographic"},
    34644: {"Unified_Ideograph", "Ideographic"},
    34645: {"Unified_Ideograph", "Ideographic"},
    34646: {"Unified_Ideograph", "Ideographic"},
    34647: {"Unified_Ideograph", "Ideographic"},
    34648: {"Unified_Ideograph", "Ideographic"},
    34649: {"Unified_Ideograph", "Ideographic"},
    34650: {"Unified_Ideograph", "Ideographic"},
    34651: {"Unified_Ideograph", "Ideographic"},
    34652: {"Unified_Ideograph", "Ideographic"},
    34653: {"Unified_Ideograph", "Ideographic"},
    34654: {"Unified_Ideograph", "Ideographic"},
    34655: {"Unified_Ideograph", "Ideographic"},
    34656: {"Unified_Ideograph", "Ideographic"},
    34657: {"Unified_Ideograph", "Ideographic"},
    34658: {"Unified_Ideograph", "Ideographic"},
    34659: {"Unified_Ideograph", "Ideographic"},
    34660: {"Unified_Ideograph", "Ideographic"},
    34661: {"Unified_Ideograph", "Ideographic"},
    34662: {"Unified_Ideograph", "Ideographic"},
    34663: {"Unified_Ideograph", "Ideographic"},
    34664: {"Unified_Ideograph", "Ideographic"},
    34665: {"Unified_Ideograph", "Ideographic"},
    34666: {"Unified_Ideograph", "Ideographic"},
    34667: {"Unified_Ideograph", "Ideographic"},
    34668: {"Unified_Ideograph", "Ideographic"},
    34669: {"Unified_Ideograph", "Ideographic"},
    34670: {"Unified_Ideograph", "Ideographic"},
    34671: {"Unified_Ideograph", "Ideographic"},
    34672: {"Unified_Ideograph", "Ideographic"},
    34673: {"Unified_Ideograph", "Ideographic"},
    34674: {"Unified_Ideograph", "Ideographic"},
    34675: {"Unified_Ideograph", "Ideographic"},
    34676: {"Unified_Ideograph", "Ideographic"},
    34677: {"Unified_Ideograph", "Ideographic"},
    34678: {"Unified_Ideograph", "Ideographic"},
    34679: {"Unified_Ideograph", "Ideographic"},
    34680: {"Unified_Ideograph", "Ideographic"},
    34681: {"Unified_Ideograph", "Ideographic"},
    34682: {"Unified_Ideograph", "Ideographic"},
    34683: {"Unified_Ideograph", "Ideographic"},
    34684: {"Unified_Ideograph", "Ideographic"},
    34685: {"Unified_Ideograph", "Ideographic"},
    34686: {"Unified_Ideograph", "Ideographic"},
    34687: {"Unified_Ideograph", "Ideographic"},
    34688: {"Unified_Ideograph", "Ideographic"},
    34689: {"Unified_Ideograph", "Ideographic"},
    34690: {"Unified_Ideograph", "Ideographic"},
    34691: {"Unified_Ideograph", "Ideographic"},
    34692: {"Unified_Ideograph", "Ideographic"},
    34693: {"Unified_Ideograph", "Ideographic"},
    34694: {"Unified_Ideograph", "Ideographic"},
    34695: {"Unified_Ideograph", "Ideographic"},
    34696: {"Unified_Ideograph", "Ideographic"},
    34697: {"Unified_Ideograph", "Ideographic"},
    34698: {"Unified_Ideograph", "Ideographic"},
    34699: {"Unified_Ideograph", "Ideographic"},
    34700: {"Unified_Ideograph", "Ideographic"},
    34701: {"Unified_Ideograph", "Ideographic"},
    34702: {"Unified_Ideograph", "Ideographic"},
    34703: {"Unified_Ideograph", "Ideographic"},
    34704: {"Unified_Ideograph", "Ideographic"},
    34705: {"Unified_Ideograph", "Ideographic"},
    34706: {"Unified_Ideograph", "Ideographic"},
    34707: {"Unified_Ideograph", "Ideographic"},
    34708: {"Unified_Ideograph", "Ideographic"},
    34709: {"Unified_Ideograph", "Ideographic"},
    34710: {"Unified_Ideograph", "Ideographic"},
    34711: {"Unified_Ideograph", "Ideographic"},
    34712: {"Unified_Ideograph", "Ideographic"},
    34713: {"Unified_Ideograph", "Ideographic"},
    34714: {"Unified_Ideograph", "Ideographic"},
    34715: {"Unified_Ideograph", "Ideographic"},
    34716: {"Unified_Ideograph", "Ideographic"},
    34717: {"Unified_Ideograph", "Ideographic"},
    34718: {"Unified_Ideograph", "Ideographic"},
    34719: {"Unified_Ideograph", "Ideographic"},
    34720: {"Unified_Ideograph", "Ideographic"},
    34721: {"Unified_Ideograph", "Ideographic"},
    34722: {"Unified_Ideograph", "Ideographic"},
    34723: {"Unified_Ideograph", "Ideographic"},
    34724: {"Unified_Ideograph", "Ideographic"},
    34725: {"Unified_Ideograph", "Ideographic"},
    34726: {"Unified_Ideograph", "Ideographic"},
    34727: {"Unified_Ideograph", "Ideographic"},
    34728: {"Unified_Ideograph", "Ideographic"},
    34729: {"Unified_Ideograph", "Ideographic"},
    34730: {"Unified_Ideograph", "Ideographic"},
    34731: {"Unified_Ideograph", "Ideographic"},
    34732: {"Unified_Ideograph", "Ideographic"},
    34733: {"Unified_Ideograph", "Ideographic"},
    34734: {"Unified_Ideograph", "Ideographic"},
    34735: {"Unified_Ideograph", "Ideographic"},
    34736: {"Unified_Ideograph", "Ideographic"},
    34737: {"Unified_Ideograph", "Ideographic"},
    34738: {"Unified_Ideograph", "Ideographic"},
    34739: {"Unified_Ideograph", "Ideographic"},
    34740: {"Unified_Ideograph", "Ideographic"},
    34741: {"Unified_Ideograph", "Ideographic"},
    34742: {"Unified_Ideograph", "Ideographic"},
    34743: {"Unified_Ideograph", "Ideographic"},
    34744: {"Unified_Ideograph", "Ideographic"},
    34745: {"Unified_Ideograph", "Ideographic"},
    34746: {"Unified_Ideograph", "Ideographic"},
    34747: {"Unified_Ideograph", "Ideographic"},
    34748: {"Unified_Ideograph", "Ideographic"},
    34749: {"Unified_Ideograph", "Ideographic"},
    34750: {"Unified_Ideograph", "Ideographic"},
    34751: {"Unified_Ideograph", "Ideographic"},
    34752: {"Unified_Ideograph", "Ideographic"},
    34753: {"Unified_Ideograph", "Ideographic"},
    34754: {"Unified_Ideograph", "Ideographic"},
    34755: {"Unified_Ideograph", "Ideographic"},
    34756: {"Unified_Ideograph", "Ideographic"},
    34757: {"Unified_Ideograph", "Ideographic"},
    34758: {"Unified_Ideograph", "Ideographic"},
    34759: {"Unified_Ideograph", "Ideographic"},
    34760: {"Unified_Ideograph", "Ideographic"},
    34761: {"Unified_Ideograph", "Ideographic"},
    34762: {"Unified_Ideograph", "Ideographic"},
    34763: {"Unified_Ideograph", "Ideographic"},
    34764: {"Unified_Ideograph", "Ideographic"},
    34765: {"Unified_Ideograph", "Ideographic"},
    34766: {"Unified_Ideograph", "Ideographic"},
    34767: {"Unified_Ideograph", "Ideographic"},
    34768: {"Unified_Ideograph", "Ideographic"},
    34769: {"Unified_Ideograph", "Ideographic"},
    34770: {"Unified_Ideograph", "Ideographic"},
    34771: {"Unified_Ideograph", "Ideographic"},
    34772: {"Unified_Ideograph", "Ideographic"},
    34773: {"Unified_Ideograph", "Ideographic"},
    34774: {"Unified_Ideograph", "Ideographic"},
    34775: {"Unified_Ideograph", "Ideographic"},
    34776: {"Unified_Ideograph", "Ideographic"},
    34777: {"Unified_Ideograph", "Ideographic"},
    34778: {"Unified_Ideograph", "Ideographic"},
    34779: {"Unified_Ideograph", "Ideographic"},
    34780: {"Unified_Ideograph", "Ideographic"},
    34781: {"Unified_Ideograph", "Ideographic"},
    34782: {"Unified_Ideograph", "Ideographic"},
    34783: {"Unified_Ideograph", "Ideographic"},
    34784: {"Unified_Ideograph", "Ideographic"},
    34785: {"Unified_Ideograph", "Ideographic"},
    34786: {"Unified_Ideograph", "Ideographic"},
    34787: {"Unified_Ideograph", "Ideographic"},
    34788: {"Unified_Ideograph", "Ideographic"},
    34789: {"Unified_Ideograph", "Ideographic"},
    34790: {"Unified_Ideograph", "Ideographic"},
    34791: {"Unified_Ideograph", "Ideographic"},
    34792: {"Unified_Ideograph", "Ideographic"},
    34793: {"Unified_Ideograph", "Ideographic"},
    34794: {"Unified_Ideograph", "Ideographic"},
    34795: {"Unified_Ideograph", "Ideographic"},
    34796: {"Unified_Ideograph", "Ideographic"},
    34797: {"Unified_Ideograph", "Ideographic"},
    34798: {"Unified_Ideograph", "Ideographic"},
    34799: {"Unified_Ideograph", "Ideographic"},
    34800: {"Unified_Ideograph", "Ideographic"},
    34801: {"Unified_Ideograph", "Ideographic"},
    34802: {"Unified_Ideograph", "Ideographic"},
    34803: {"Unified_Ideograph", "Ideographic"},
    34804: {"Unified_Ideograph", "Ideographic"},
    34805: {"Unified_Ideograph", "Ideographic"},
    34806: {"Unified_Ideograph", "Ideographic"},
    34807: {"Unified_Ideograph", "Ideographic"},
    34808: {"Unified_Ideograph", "Ideographic"},
    34809: {"Unified_Ideograph", "Ideographic"},
    34810: {"Unified_Ideograph", "Ideographic"},
    34811: {"Unified_Ideograph", "Ideographic"},
    34812: {"Unified_Ideograph", "Ideographic"},
    34813: {"Unified_Ideograph", "Ideographic"},
    34814: {"Unified_Ideograph", "Ideographic"},
    34815: {"Unified_Ideograph", "Ideographic"},
    34816: {"Unified_Ideograph", "Ideographic"},
    34817: {"Unified_Ideograph", "Ideographic"},
    34818: {"Unified_Ideograph", "Ideographic"},
    34819: {"Unified_Ideograph", "Ideographic"},
    34820: {"Unified_Ideograph", "Ideographic"},
    34821: {"Unified_Ideograph", "Ideographic"},
    34822: {"Unified_Ideograph", "Ideographic"},
    34823: {"Unified_Ideograph", "Ideographic"},
    34824: {"Unified_Ideograph", "Ideographic"},
    34825: {"Unified_Ideograph", "Ideographic"},
    34826: {"Unified_Ideograph", "Ideographic"},
    34827: {"Unified_Ideograph", "Ideographic"},
    34828: {"Unified_Ideograph", "Ideographic"},
    34829: {"Unified_Ideograph", "Ideographic"},
    34830: {"Unified_Ideograph", "Ideographic"},
    34831: {"Unified_Ideograph", "Ideographic"},
    34832: {"Unified_Ideograph", "Ideographic"},
    34833: {"Unified_Ideograph", "Ideographic"},
    34834: {"Unified_Ideograph", "Ideographic"},
    34835: {"Unified_Ideograph", "Ideographic"},
    34836: {"Unified_Ideograph", "Ideographic"},
    34837: {"Unified_Ideograph", "Ideographic"},
    34838: {"Unified_Ideograph", "Ideographic"},
    34839: {"Unified_Ideograph", "Ideographic"},
    34840: {"Unified_Ideograph", "Ideographic"},
    34841: {"Unified_Ideograph", "Ideographic"},
    34842: {"Unified_Ideograph", "Ideographic"},
    34843: {"Unified_Ideograph", "Ideographic"},
    34844: {"Unified_Ideograph", "Ideographic"},
    34845: {"Unified_Ideograph", "Ideographic"},
    34846: {"Unified_Ideograph", "Ideographic"},
    34847: {"Unified_Ideograph", "Ideographic"},
    34848: {"Unified_Ideograph", "Ideographic"},
    34849: {"Unified_Ideograph", "Ideographic"},
    34850: {"Unified_Ideograph", "Ideographic"},
    34851: {"Unified_Ideograph", "Ideographic"},
    34852: {"Unified_Ideograph", "Ideographic"},
    34853: {"Unified_Ideograph", "Ideographic"},
    34854: {"Unified_Ideograph", "Ideographic"},
    34855: {"Unified_Ideograph", "Ideographic"},
    34856: {"Unified_Ideograph", "Ideographic"},
    34857: {"Unified_Ideograph", "Ideographic"},
    34858: {"Unified_Ideograph", "Ideographic"},
    34859: {"Unified_Ideograph", "Ideographic"},
    34860: {"Unified_Ideograph", "Ideographic"},
    34861: {"Unified_Ideograph", "Ideographic"},
    34862: {"Unified_Ideograph", "Ideographic"},
    34863: {"Unified_Ideograph", "Ideographic"},
    34864: {"Unified_Ideograph", "Ideographic"},
    34865: {"Unified_Ideograph", "Ideographic"},
    34866: {"Unified_Ideograph", "Ideographic"},
    34867: {"Unified_Ideograph", "Ideographic"},
    34868: {"Unified_Ideograph", "Ideographic"},
    34869: {"Unified_Ideograph", "Ideographic"},
    34870: {"Unified_Ideograph", "Ideographic"},
    34871: {"Unified_Ideograph", "Ideographic"},
    34872: {"Unified_Ideograph", "Ideographic"},
    34873: {"Unified_Ideograph", "Ideographic"},
    34874: {"Unified_Ideograph", "Ideographic"},
    34875: {"Unified_Ideograph", "Ideographic"},
    34876: {"Unified_Ideograph", "Ideographic"},
    34877: {"Unified_Ideograph", "Ideographic"},
    34878: {"Unified_Ideograph", "Ideographic"},
    34879: {"Unified_Ideograph", "Ideographic"},
    34880: {"Unified_Ideograph", "Ideographic"},
    34881: {"Unified_Ideograph", "Ideographic"},
    34882: {"Unified_Ideograph", "Ideographic"},
    34883: {"Unified_Ideograph", "Ideographic"},
    34884: {"Unified_Ideograph", "Ideographic"},
    34885: {"Unified_Ideograph", "Ideographic"},
    34886: {"Unified_Ideograph", "Ideographic"},
    34887: {"Unified_Ideograph", "Ideographic"},
    34888: {"Unified_Ideograph", "Ideographic"},
    34889: {"Unified_Ideograph", "Ideographic"},
    34890: {"Unified_Ideograph", "Ideographic"},
    34891: {"Unified_Ideograph", "Ideographic"},
    34892: {"Unified_Ideograph", "Ideographic"},
    34893: {"Unified_Ideograph", "Ideographic"},
    34894: {"Unified_Ideograph", "Ideographic"},
    34895: {"Unified_Ideograph", "Ideographic"},
    34896: {"Unified_Ideograph", "Ideographic"},
    34897: {"Unified_Ideograph", "Ideographic"},
    34898: {"Unified_Ideograph", "Ideographic"},
    34899: {"Unified_Ideograph", "Ideographic"},
    34900: {"Unified_Ideograph", "Ideographic"},
    34901: {"Unified_Ideograph", "Ideographic"},
    34902: {"Unified_Ideograph", "Ideographic"},
    34903: {"Unified_Ideograph", "Ideographic"},
    34904: {"Unified_Ideograph", "Ideographic"},
    34905: {"Unified_Ideograph", "Ideographic"},
    34906: {"Unified_Ideograph", "Ideographic"},
    34907: {"Unified_Ideograph", "Ideographic"},
    34908: {"Unified_Ideograph", "Ideographic"},
    34909: {"Unified_Ideograph", "Ideographic"},
    34910: {"Unified_Ideograph", "Ideographic"},
    34911: {"Unified_Ideograph", "Ideographic"},
    34912: {"Unified_Ideograph", "Ideographic"},
    34913: {"Unified_Ideograph", "Ideographic"},
    34914: {"Unified_Ideograph", "Ideographic"},
    34915: {"Unified_Ideograph", "Ideographic"},
    34916: {"Unified_Ideograph", "Ideographic"},
    34917: {"Unified_Ideograph", "Ideographic"},
    34918: {"Unified_Ideograph", "Ideographic"},
    34919: {"Unified_Ideograph", "Ideographic"},
    34920: {"Unified_Ideograph", "Ideographic"},
    34921: {"Unified_Ideograph", "Ideographic"},
    34922: {"Unified_Ideograph", "Ideographic"},
    34923: {"Unified_Ideograph", "Ideographic"},
    34924: {"Unified_Ideograph", "Ideographic"},
    34925: {"Unified_Ideograph", "Ideographic"},
    34926: {"Unified_Ideograph", "Ideographic"},
    34927: {"Unified_Ideograph", "Ideographic"},
    34928: {"Unified_Ideograph", "Ideographic"},
    34929: {"Unified_Ideograph", "Ideographic"},
    34930: {"Unified_Ideograph", "Ideographic"},
    34931: {"Unified_Ideograph", "Ideographic"},
    34932: {"Unified_Ideograph", "Ideographic"},
    34933: {"Unified_Ideograph", "Ideographic"},
    34934: {"Unified_Ideograph", "Ideographic"},
    34935: {"Unified_Ideograph", "Ideographic"},
    34936: {"Unified_Ideograph", "Ideographic"},
    34937: {"Unified_Ideograph", "Ideographic"},
    34938: {"Unified_Ideograph", "Ideographic"},
    34939: {"Unified_Ideograph", "Ideographic"},
    34940: {"Unified_Ideograph", "Ideographic"},
    34941: {"Unified_Ideograph", "Ideographic"},
    34942: {"Unified_Ideograph", "Ideographic"},
    34943: {"Unified_Ideograph", "Ideographic"},
    34944: {"Unified_Ideograph", "Ideographic"},
    34945: {"Unified_Ideograph", "Ideographic"},
    34946: {"Unified_Ideograph", "Ideographic"},
    34947: {"Unified_Ideograph", "Ideographic"},
    34948: {"Unified_Ideograph", "Ideographic"},
    34949: {"Unified_Ideograph", "Ideographic"},
    34950: {"Unified_Ideograph", "Ideographic"},
    34951: {"Unified_Ideograph", "Ideographic"},
    34952: {"Unified_Ideograph", "Ideographic"},
    34953: {"Unified_Ideograph", "Ideographic"},
    34954: {"Unified_Ideograph", "Ideographic"},
    34955: {"Unified_Ideograph", "Ideographic"},
    34956: {"Unified_Ideograph", "Ideographic"},
    34957: {"Unified_Ideograph", "Ideographic"},
    34958: {"Unified_Ideograph", "Ideographic"},
    34959: {"Unified_Ideograph", "Ideographic"},
    34960: {"Unified_Ideograph", "Ideographic"},
    34961: {"Unified_Ideograph", "Ideographic"},
    34962: {"Unified_Ideograph", "Ideographic"},
    34963: {"Unified_Ideograph", "Ideographic"},
    34964: {"Unified_Ideograph", "Ideographic"},
    34965: {"Unified_Ideograph", "Ideographic"},
    34966: {"Unified_Ideograph", "Ideographic"},
    34967: {"Unified_Ideograph", "Ideographic"},
    34968: {"Unified_Ideograph", "Ideographic"},
    34969: {"Unified_Ideograph", "Ideographic"},
    34970: {"Unified_Ideograph", "Ideographic"},
    34971: {"Unified_Ideograph", "Ideographic"},
    34972: {"Unified_Ideograph", "Ideographic"},
    34973: {"Unified_Ideograph", "Ideographic"},
    34974: {"Unified_Ideograph", "Ideographic"},
    34975: {"Unified_Ideograph", "Ideographic"},
    34976: {"Unified_Ideograph", "Ideographic"},
    34977: {"Unified_Ideograph", "Ideographic"},
    34978: {"Unified_Ideograph", "Ideographic"},
    34979: {"Unified_Ideograph", "Ideographic"},
    34980: {"Unified_Ideograph", "Ideographic"},
    34981: {"Unified_Ideograph", "Ideographic"},
    34982: {"Unified_Ideograph", "Ideographic"},
    34983: {"Unified_Ideograph", "Ideographic"},
    34984: {"Unified_Ideograph", "Ideographic"},
    34985: {"Unified_Ideograph", "Ideographic"},
    34986: {"Unified_Ideograph", "Ideographic"},
    34987: {"Unified_Ideograph", "Ideographic"},
    34988: {"Unified_Ideograph", "Ideographic"},
    34989: {"Unified_Ideograph", "Ideographic"},
    34990: {"Unified_Ideograph", "Ideographic"},
    34991: {"Unified_Ideograph", "Ideographic"},
    34992: {"Unified_Ideograph", "Ideographic"},
    34993: {"Unified_Ideograph", "Ideographic"},
    34994: {"Unified_Ideograph", "Ideographic"},
    34995: {"Unified_Ideograph", "Ideographic"},
    34996: {"Unified_Ideograph", "Ideographic"},
    34997: {"Unified_Ideograph", "Ideographic"},
    34998: {"Unified_Ideograph", "Ideographic"},
    34999: {"Unified_Ideograph", "Ideographic"},
    35000: {"Unified_Ideograph", "Ideographic"},
    35001: {"Unified_Ideograph", "Ideographic"},
    35002: {"Unified_Ideograph", "Ideographic"},
    35003: {"Unified_Ideograph", "Ideographic"},
    35004: {"Unified_Ideograph", "Ideographic"},
    35005: {"Unified_Ideograph", "Ideographic"},
    35006: {"Unified_Ideograph", "Ideographic"},
    35007: {"Unified_Ideograph", "Ideographic"},
    35008: {"Unified_Ideograph", "Ideographic"},
    35009: {"Unified_Ideograph", "Ideographic"},
    35010: {"Unified_Ideograph", "Ideographic"},
    35011: {"Unified_Ideograph", "Ideographic"},
    35012: {"Unified_Ideograph", "Ideographic"},
    35013: {"Unified_Ideograph", "Ideographic"},
    35014: {"Unified_Ideograph", "Ideographic"},
    35015: {"Unified_Ideograph", "Ideographic"},
    35016: {"Unified_Ideograph", "Ideographic"},
    35017: {"Unified_Ideograph", "Ideographic"},
    35018: {"Unified_Ideograph", "Ideographic"},
    35019: {"Unified_Ideograph", "Ideographic"},
    35020: {"Unified_Ideograph", "Ideographic"},
    35021: {"Unified_Ideograph", "Ideographic"},
    35022: {"Unified_Ideograph", "Ideographic"},
    35023: {"Unified_Ideograph", "Ideographic"},
    35024: {"Unified_Ideograph", "Ideographic"},
    35025: {"Unified_Ideograph", "Ideographic"},
    35026: {"Unified_Ideograph", "Ideographic"},
    35027: {"Unified_Ideograph", "Ideographic"},
    35028: {"Unified_Ideograph", "Ideographic"},
    35029: {"Unified_Ideograph", "Ideographic"},
    35030: {"Unified_Ideograph", "Ideographic"},
    35031: {"Unified_Ideograph", "Ideographic"},
    35032: {"Unified_Ideograph", "Ideographic"},
    35033: {"Unified_Ideograph", "Ideographic"},
    35034: {"Unified_Ideograph", "Ideographic"},
    35035: {"Unified_Ideograph", "Ideographic"},
    35036: {"Unified_Ideograph", "Ideographic"},
    35037: {"Unified_Ideograph", "Ideographic"},
    35038: {"Unified_Ideograph", "Ideographic"},
    35039: {"Unified_Ideograph", "Ideographic"},
    35040: {"Unified_Ideograph", "Ideographic"},
    35041: {"Unified_Ideograph", "Ideographic"},
    35042: {"Unified_Ideograph", "Ideographic"},
    35043: {"Unified_Ideograph", "Ideographic"},
    35044: {"Unified_Ideograph", "Ideographic"},
    35045: {"Unified_Ideograph", "Ideographic"},
    35046: {"Unified_Ideograph", "Ideographic"},
    35047: {"Unified_Ideograph", "Ideographic"},
    35048: {"Unified_Ideograph", "Ideographic"},
    35049: {"Unified_Ideograph", "Ideographic"},
    35050: {"Unified_Ideograph", "Ideographic"},
    35051: {"Unified_Ideograph", "Ideographic"},
    35052: {"Unified_Ideograph", "Ideographic"},
    35053: {"Unified_Ideograph", "Ideographic"},
    35054: {"Unified_Ideograph", "Ideographic"},
    35055: {"Unified_Ideograph", "Ideographic"},
    35056: {"Unified_Ideograph", "Ideographic"},
    35057: {"Unified_Ideograph", "Ideographic"},
    35058: {"Unified_Ideograph", "Ideographic"},
    35059: {"Unified_Ideograph", "Ideographic"},
    35060: {"Unified_Ideograph", "Ideographic"},
    35061: {"Unified_Ideograph", "Ideographic"},
    35062: {"Unified_Ideograph", "Ideographic"},
    35063: {"Unified_Ideograph", "Ideographic"},
    35064: {"Unified_Ideograph", "Ideographic"},
    35065: {"Unified_Ideograph", "Ideographic"},
    35066: {"Unified_Ideograph", "Ideographic"},
    35067: {"Unified_Ideograph", "Ideographic"},
    35068: {"Unified_Ideograph", "Ideographic"},
    35069: {"Unified_Ideograph", "Ideographic"},
    35070: {"Unified_Ideograph", "Ideographic"},
    35071: {"Unified_Ideograph", "Ideographic"},
    35072: {"Unified_Ideograph", "Ideographic"},
    35073: {"Unified_Ideograph", "Ideographic"},
    35074: {"Unified_Ideograph", "Ideographic"},
    35075: {"Unified_Ideograph", "Ideographic"},
    35076: {"Unified_Ideograph", "Ideographic"},
    35077: {"Unified_Ideograph", "Ideographic"},
    35078: {"Unified_Ideograph", "Ideographic"},
    35079: {"Unified_Ideograph", "Ideographic"},
    35080: {"Unified_Ideograph", "Ideographic"},
    35081: {"Unified_Ideograph", "Ideographic"},
    35082: {"Unified_Ideograph", "Ideographic"},
    35083: {"Unified_Ideograph", "Ideographic"},
    35084: {"Unified_Ideograph", "Ideographic"},
    35085: {"Unified_Ideograph", "Ideographic"},
    35086: {"Unified_Ideograph", "Ideographic"},
    35087: {"Unified_Ideograph", "Ideographic"},
    35088: {"Unified_Ideograph", "Ideographic"},
    35089: {"Unified_Ideograph", "Ideographic"},
    35090: {"Unified_Ideograph", "Ideographic"},
    35091: {"Unified_Ideograph", "Ideographic"},
    35092: {"Unified_Ideograph", "Ideographic"},
    35093: {"Unified_Ideograph", "Ideographic"},
    35094: {"Unified_Ideograph", "Ideographic"},
    35095: {"Unified_Ideograph", "Ideographic"},
    35096: {"Unified_Ideograph", "Ideographic"},
    35097: {"Unified_Ideograph", "Ideographic"},
    35098: {"Unified_Ideograph", "Ideographic"},
    35099: {"Unified_Ideograph", "Ideographic"},
    35100: {"Unified_Ideograph", "Ideographic"},
    35101: {"Unified_Ideograph", "Ideographic"},
    35102: {"Unified_Ideograph", "Ideographic"},
    35103: {"Unified_Ideograph", "Ideographic"},
    35104: {"Unified_Ideograph", "Ideographic"},
    35105: {"Unified_Ideograph", "Ideographic"},
    35106: {"Unified_Ideograph", "Ideographic"},
    35107: {"Unified_Ideograph", "Ideographic"},
    35108: {"Unified_Ideograph", "Ideographic"},
    35109: {"Unified_Ideograph", "Ideographic"},
    35110: {"Unified_Ideograph", "Ideographic"},
    35111: {"Unified_Ideograph", "Ideographic"},
    35112: {"Unified_Ideograph", "Ideographic"},
    35113: {"Unified_Ideograph", "Ideographic"},
    35114: {"Unified_Ideograph", "Ideographic"},
    35115: {"Unified_Ideograph", "Ideographic"},
    35116: {"Unified_Ideograph", "Ideographic"},
    35117: {"Unified_Ideograph", "Ideographic"},
    35118: {"Unified_Ideograph", "Ideographic"},
    35119: {"Unified_Ideograph", "Ideographic"},
    35120: {"Unified_Ideograph", "Ideographic"},
    35121: {"Unified_Ideograph", "Ideographic"},
    35122: {"Unified_Ideograph", "Ideographic"},
    35123: {"Unified_Ideograph", "Ideographic"},
    35124: {"Unified_Ideograph", "Ideographic"},
    35125: {"Unified_Ideograph", "Ideographic"},
    35126: {"Unified_Ideograph", "Ideographic"},
    35127: {"Unified_Ideograph", "Ideographic"},
    35128: {"Unified_Ideograph", "Ideographic"},
    35129: {"Unified_Ideograph", "Ideographic"},
    35130: {"Unified_Ideograph", "Ideographic"},
    35131: {"Unified_Ideograph", "Ideographic"},
    35132: {"Unified_Ideograph", "Ideographic"},
    35133: {"Unified_Ideograph", "Ideographic"},
    35134: {"Unified_Ideograph", "Ideographic"},
    35135: {"Unified_Ideograph", "Ideographic"},
    35136: {"Unified_Ideograph", "Ideographic"},
    35137: {"Unified_Ideograph", "Ideographic"},
    35138: {"Unified_Ideograph", "Ideographic"},
    35139: {"Unified_Ideograph", "Ideographic"},
    35140: {"Unified_Ideograph", "Ideographic"},
    35141: {"Unified_Ideograph", "Ideographic"},
    35142: {"Unified_Ideograph", "Ideographic"},
    35143: {"Unified_Ideograph", "Ideographic"},
    35144: {"Unified_Ideograph", "Ideographic"},
    35145: {"Unified_Ideograph", "Ideographic"},
    35146: {"Unified_Ideograph", "Ideographic"},
    35147: {"Unified_Ideograph", "Ideographic"},
    35148: {"Unified_Ideograph", "Ideographic"},
    35149: {"Unified_Ideograph", "Ideographic"},
    35150: {"Unified_Ideograph", "Ideographic"},
    35151: {"Unified_Ideograph", "Ideographic"},
    35152: {"Unified_Ideograph", "Ideographic"},
    35153: {"Unified_Ideograph", "Ideographic"},
    35154: {"Unified_Ideograph", "Ideographic"},
    35155: {"Unified_Ideograph", "Ideographic"},
    35156: {"Unified_Ideograph", "Ideographic"},
    35157: {"Unified_Ideograph", "Ideographic"},
    35158: {"Unified_Ideograph", "Ideographic"},
    35159: {"Unified_Ideograph", "Ideographic"},
    35160: {"Unified_Ideograph", "Ideographic"},
    35161: {"Unified_Ideograph", "Ideographic"},
    35162: {"Unified_Ideograph", "Ideographic"},
    35163: {"Unified_Ideograph", "Ideographic"},
    35164: {"Unified_Ideograph", "Ideographic"},
    35165: {"Unified_Ideograph", "Ideographic"},
    35166: {"Unified_Ideograph", "Ideographic"},
    35167: {"Unified_Ideograph", "Ideographic"},
    35168: {"Unified_Ideograph", "Ideographic"},
    35169: {"Unified_Ideograph", "Ideographic"},
    35170: {"Unified_Ideograph", "Ideographic"},
    35171: {"Unified_Ideograph", "Ideographic"},
    35172: {"Unified_Ideograph", "Ideographic"},
    35173: {"Unified_Ideograph", "Ideographic"},
    35174: {"Unified_Ideograph", "Ideographic"},
    35175: {"Unified_Ideograph", "Ideographic"},
    35176: {"Unified_Ideograph", "Ideographic"},
    35177: {"Unified_Ideograph", "Ideographic"},
    35178: {"Unified_Ideograph", "Ideographic"},
    35179: {"Unified_Ideograph", "Ideographic"},
    35180: {"Unified_Ideograph", "Ideographic"},
    35181: {"Unified_Ideograph", "Ideographic"},
    35182: {"Unified_Ideograph", "Ideographic"},
    35183: {"Unified_Ideograph", "Ideographic"},
    35184: {"Unified_Ideograph", "Ideographic"},
    35185: {"Unified_Ideograph", "Ideographic"},
    35186: {"Unified_Ideograph", "Ideographic"},
    35187: {"Unified_Ideograph", "Ideographic"},
    35188: {"Unified_Ideograph", "Ideographic"},
    35189: {"Unified_Ideograph", "Ideographic"},
    35190: {"Unified_Ideograph", "Ideographic"},
    35191: {"Unified_Ideograph", "Ideographic"},
    35192: {"Unified_Ideograph", "Ideographic"},
    35193: {"Unified_Ideograph", "Ideographic"},
    35194: {"Unified_Ideograph", "Ideographic"},
    35195: {"Unified_Ideograph", "Ideographic"},
    35196: {"Unified_Ideograph", "Ideographic"},
    35197: {"Unified_Ideograph", "Ideographic"},
    35198: {"Unified_Ideograph", "Ideographic"},
    35199: {"Unified_Ideograph", "Ideographic"},
    35200: {"Unified_Ideograph", "Ideographic"},
    35201: {"Unified_Ideograph", "Ideographic"},
    35202: {"Unified_Ideograph", "Ideographic"},
    35203: {"Unified_Ideograph", "Ideographic"},
    35204: {"Unified_Ideograph", "Ideographic"},
    35205: {"Unified_Ideograph", "Ideographic"},
    35206: {"Unified_Ideograph", "Ideographic"},
    35207: {"Unified_Ideograph", "Ideographic"},
    35208: {"Unified_Ideograph", "Ideographic"},
    35209: {"Unified_Ideograph", "Ideographic"},
    35210: {"Unified_Ideograph", "Ideographic"},
    35211: {"Unified_Ideograph", "Ideographic"},
    35212: {"Unified_Ideograph", "Ideographic"},
    35213: {"Unified_Ideograph", "Ideographic"},
    35214: {"Unified_Ideograph", "Ideographic"},
    35215: {"Unified_Ideograph", "Ideographic"},
    35216: {"Unified_Ideograph", "Ideographic"},
    35217: {"Unified_Ideograph", "Ideographic"},
    35218: {"Unified_Ideograph", "Ideographic"},
    35219: {"Unified_Ideograph", "Ideographic"},
    35220: {"Unified_Ideograph", "Ideographic"},
    35221: {"Unified_Ideograph", "Ideographic"},
    35222: {"Unified_Ideograph", "Ideographic"},
    35223: {"Unified_Ideograph", "Ideographic"},
    35224: {"Unified_Ideograph", "Ideographic"},
    35225: {"Unified_Ideograph", "Ideographic"},
    35226: {"Unified_Ideograph", "Ideographic"},
    35227: {"Unified_Ideograph", "Ideographic"},
    35228: {"Unified_Ideograph", "Ideographic"},
    35229: {"Unified_Ideograph", "Ideographic"},
    35230: {"Unified_Ideograph", "Ideographic"},
    35231: {"Unified_Ideograph", "Ideographic"},
    35232: {"Unified_Ideograph", "Ideographic"},
    35233: {"Unified_Ideograph", "Ideographic"},
    35234: {"Unified_Ideograph", "Ideographic"},
    35235: {"Unified_Ideograph", "Ideographic"},
    35236: {"Unified_Ideograph", "Ideographic"},
    35237: {"Unified_Ideograph", "Ideographic"},
    35238: {"Unified_Ideograph", "Ideographic"},
    35239: {"Unified_Ideograph", "Ideographic"},
    35240: {"Unified_Ideograph", "Ideographic"},
    35241: {"Unified_Ideograph", "Ideographic"},
    35242: {"Unified_Ideograph", "Ideographic"},
    35243: {"Unified_Ideograph", "Ideographic"},
    35244: {"Unified_Ideograph", "Ideographic"},
    35245: {"Unified_Ideograph", "Ideographic"},
    35246: {"Unified_Ideograph", "Ideographic"},
    35247: {"Unified_Ideograph", "Ideographic"},
    35248: {"Unified_Ideograph", "Ideographic"},
    35249: {"Unified_Ideograph", "Ideographic"},
    35250: {"Unified_Ideograph", "Ideographic"},
    35251: {"Unified_Ideograph", "Ideographic"},
    35252: {"Unified_Ideograph", "Ideographic"},
    35253: {"Unified_Ideograph", "Ideographic"},
    35254: {"Unified_Ideograph", "Ideographic"},
    35255: {"Unified_Ideograph", "Ideographic"},
    35256: {"Unified_Ideograph", "Ideographic"},
    35257: {"Unified_Ideograph", "Ideographic"},
    35258: {"Unified_Ideograph", "Ideographic"},
    35259: {"Unified_Ideograph", "Ideographic"},
    35260: {"Unified_Ideograph", "Ideographic"},
    35261: {"Unified_Ideograph", "Ideographic"},
    35262: {"Unified_Ideograph", "Ideographic"},
    35263: {"Unified_Ideograph", "Ideographic"},
    35264: {"Unified_Ideograph", "Ideographic"},
    35265: {"Unified_Ideograph", "Ideographic"},
    35266: {"Unified_Ideograph", "Ideographic"},
    35267: {"Unified_Ideograph", "Ideographic"},
    35268: {"Unified_Ideograph", "Ideographic"},
    35269: {"Unified_Ideograph", "Ideographic"},
    35270: {"Unified_Ideograph", "Ideographic"},
    35271: {"Unified_Ideograph", "Ideographic"},
    35272: {"Unified_Ideograph", "Ideographic"},
    35273: {"Unified_Ideograph", "Ideographic"},
    35274: {"Unified_Ideograph", "Ideographic"},
    35275: {"Unified_Ideograph", "Ideographic"},
    35276: {"Unified_Ideograph", "Ideographic"},
    35277: {"Unified_Ideograph", "Ideographic"},
    35278: {"Unified_Ideograph", "Ideographic"},
    35279: {"Unified_Ideograph", "Ideographic"},
    35280: {"Unified_Ideograph", "Ideographic"},
    35281: {"Unified_Ideograph", "Ideographic"},
    35282: {"Unified_Ideograph", "Ideographic"},
    35283: {"Unified_Ideograph", "Ideographic"},
    35284: {"Unified_Ideograph", "Ideographic"},
    35285: {"Unified_Ideograph", "Ideographic"},
    35286: {"Unified_Ideograph", "Ideographic"},
    35287: {"Unified_Ideograph", "Ideographic"},
    35288: {"Unified_Ideograph", "Ideographic"},
    35289: {"Unified_Ideograph", "Ideographic"},
    35290: {"Unified_Ideograph", "Ideographic"},
    35291: {"Unified_Ideograph", "Ideographic"},
    35292: {"Unified_Ideograph", "Ideographic"},
    35293: {"Unified_Ideograph", "Ideographic"},
    35294: {"Unified_Ideograph", "Ideographic"},
    35295: {"Unified_Ideograph", "Ideographic"},
    35296: {"Unified_Ideograph", "Ideographic"},
    35297: {"Unified_Ideograph", "Ideographic"},
    35298: {"Unified_Ideograph", "Ideographic"},
    35299: {"Unified_Ideograph", "Ideographic"},
    35300: {"Unified_Ideograph", "Ideographic"},
    35301: {"Unified_Ideograph", "Ideographic"},
    35302: {"Unified_Ideograph", "Ideographic"},
    35303: {"Unified_Ideograph", "Ideographic"},
    35304: {"Unified_Ideograph", "Ideographic"},
    35305: {"Unified_Ideograph", "Ideographic"},
    35306: {"Unified_Ideograph", "Ideographic"},
    35307: {"Unified_Ideograph", "Ideographic"},
    35308: {"Unified_Ideograph", "Ideographic"},
    35309: {"Unified_Ideograph", "Ideographic"},
    35310: {"Unified_Ideograph", "Ideographic"},
    35311: {"Unified_Ideograph", "Ideographic"},
    35312: {"Unified_Ideograph", "Ideographic"},
    35313: {"Unified_Ideograph", "Ideographic"},
    35314: {"Unified_Ideograph", "Ideographic"},
    35315: {"Unified_Ideograph", "Ideographic"},
    35316: {"Unified_Ideograph", "Ideographic"},
    35317: {"Unified_Ideograph", "Ideographic"},
    35318: {"Unified_Ideograph", "Ideographic"},
    35319: {"Unified_Ideograph", "Ideographic"},
    35320: {"Unified_Ideograph", "Ideographic"},
    35321: {"Unified_Ideograph", "Ideographic"},
    35322: {"Unified_Ideograph", "Ideographic"},
    35323: {"Unified_Ideograph", "Ideographic"},
    35324: {"Unified_Ideograph", "Ideographic"},
    35325: {"Unified_Ideograph", "Ideographic"},
    35326: {"Unified_Ideograph", "Ideographic"},
    35327: {"Unified_Ideograph", "Ideographic"},
    35328: {"Unified_Ideograph", "Ideographic"},
    35329: {"Unified_Ideograph", "Ideographic"},
    35330: {"Unified_Ideograph", "Ideographic"},
    35331: {"Unified_Ideograph", "Ideographic"},
    35332: {"Unified_Ideograph", "Ideographic"},
    35333: {"Unified_Ideograph", "Ideographic"},
    35334: {"Unified_Ideograph", "Ideographic"},
    35335: {"Unified_Ideograph", "Ideographic"},
    35336: {"Unified_Ideograph", "Ideographic"},
    35337: {"Unified_Ideograph", "Ideographic"},
    35338: {"Unified_Ideograph", "Ideographic"},
    35339: {"Unified_Ideograph", "Ideographic"},
    35340: {"Unified_Ideograph", "Ideographic"},
    35341: {"Unified_Ideograph", "Ideographic"},
    35342: {"Unified_Ideograph", "Ideographic"},
    35343: {"Unified_Ideograph", "Ideographic"},
    35344: {"Unified_Ideograph", "Ideographic"},
    35345: {"Unified_Ideograph", "Ideographic"},
    35346: {"Unified_Ideograph", "Ideographic"},
    35347: {"Unified_Ideograph", "Ideographic"},
    35348: {"Unified_Ideograph", "Ideographic"},
    35349: {"Unified_Ideograph", "Ideographic"},
    35350: {"Unified_Ideograph", "Ideographic"},
    35351: {"Unified_Ideograph", "Ideographic"},
    35352: {"Unified_Ideograph", "Ideographic"},
    35353: {"Unified_Ideograph", "Ideographic"},
    35354: {"Unified_Ideograph", "Ideographic"},
    35355: {"Unified_Ideograph", "Ideographic"},
    35356: {"Unified_Ideograph", "Ideographic"},
    35357: {"Unified_Ideograph", "Ideographic"},
    35358: {"Unified_Ideograph", "Ideographic"},
    35359: {"Unified_Ideograph", "Ideographic"},
    35360: {"Unified_Ideograph", "Ideographic"},
    35361: {"Unified_Ideograph", "Ideographic"},
    35362: {"Unified_Ideograph", "Ideographic"},
    35363: {"Unified_Ideograph", "Ideographic"},
    35364: {"Unified_Ideograph", "Ideographic"},
    35365: {"Unified_Ideograph", "Ideographic"},
    35366: {"Unified_Ideograph", "Ideographic"},
    35367: {"Unified_Ideograph", "Ideographic"},
    35368: {"Unified_Ideograph", "Ideographic"},
    35369: {"Unified_Ideograph", "Ideographic"},
    35370: {"Unified_Ideograph", "Ideographic"},
    35371: {"Unified_Ideograph", "Ideographic"},
    35372: {"Unified_Ideograph", "Ideographic"},
    35373: {"Unified_Ideograph", "Ideographic"},
    35374: {"Unified_Ideograph", "Ideographic"},
    35375: {"Unified_Ideograph", "Ideographic"},
    35376: {"Unified_Ideograph", "Ideographic"},
    35377: {"Unified_Ideograph", "Ideographic"},
    35378: {"Unified_Ideograph", "Ideographic"},
    35379: {"Unified_Ideograph", "Ideographic"},
    35380: {"Unified_Ideograph", "Ideographic"},
    35381: {"Unified_Ideograph", "Ideographic"},
    35382: {"Unified_Ideograph", "Ideographic"},
    35383: {"Unified_Ideograph", "Ideographic"},
    35384: {"Unified_Ideograph", "Ideographic"},
    35385: {"Unified_Ideograph", "Ideographic"},
    35386: {"Unified_Ideograph", "Ideographic"},
    35387: {"Unified_Ideograph", "Ideographic"},
    35388: {"Unified_Ideograph", "Ideographic"},
    35389: {"Unified_Ideograph", "Ideographic"},
    35390: {"Unified_Ideograph", "Ideographic"},
    35391: {"Unified_Ideograph", "Ideographic"},
    35392: {"Unified_Ideograph", "Ideographic"},
    35393: {"Unified_Ideograph", "Ideographic"},
    35394: {"Unified_Ideograph", "Ideographic"},
    35395: {"Unified_Ideograph", "Ideographic"},
    35396: {"Unified_Ideograph", "Ideographic"},
    35397: {"Unified_Ideograph", "Ideographic"},
    35398: {"Unified_Ideograph", "Ideographic"},
    35399: {"Unified_Ideograph", "Ideographic"},
    35400: {"Unified_Ideograph", "Ideographic"},
    35401: {"Unified_Ideograph", "Ideographic"},
    35402: {"Unified_Ideograph", "Ideographic"},
    35403: {"Unified_Ideograph", "Ideographic"},
    35404: {"Unified_Ideograph", "Ideographic"},
    35405: {"Unified_Ideograph", "Ideographic"},
    35406: {"Unified_Ideograph", "Ideographic"},
    35407: {"Unified_Ideograph", "Ideographic"},
    35408: {"Unified_Ideograph", "Ideographic"},
    35409: {"Unified_Ideograph", "Ideographic"},
    35410: {"Unified_Ideograph", "Ideographic"},
    35411: {"Unified_Ideograph", "Ideographic"},
    35412: {"Unified_Ideograph", "Ideographic"},
    35413: {"Unified_Ideograph", "Ideographic"},
    35414: {"Unified_Ideograph", "Ideographic"},
    35415: {"Unified_Ideograph", "Ideographic"},
    35416: {"Unified_Ideograph", "Ideographic"},
    35417: {"Unified_Ideograph", "Ideographic"},
    35418: {"Unified_Ideograph", "Ideographic"},
    35419: {"Unified_Ideograph", "Ideographic"},
    35420: {"Unified_Ideograph", "Ideographic"},
    35421: {"Unified_Ideograph", "Ideographic"},
    35422: {"Unified_Ideograph", "Ideographic"},
    35423: {"Unified_Ideograph", "Ideographic"},
    35424: {"Unified_Ideograph", "Ideographic"},
    35425: {"Unified_Ideograph", "Ideographic"},
    35426: {"Unified_Ideograph", "Ideographic"},
    35427: {"Unified_Ideograph", "Ideographic"},
    35428: {"Unified_Ideograph", "Ideographic"},
    35429: {"Unified_Ideograph", "Ideographic"},
    35430: {"Unified_Ideograph", "Ideographic"},
    35431: {"Unified_Ideograph", "Ideographic"},
    35432: {"Unified_Ideograph", "Ideographic"},
    35433: {"Unified_Ideograph", "Ideographic"},
    35434: {"Unified_Ideograph", "Ideographic"},
    35435: {"Unified_Ideograph", "Ideographic"},
    35436: {"Unified_Ideograph", "Ideographic"},
    35437: {"Unified_Ideograph", "Ideographic"},
    35438: {"Unified_Ideograph", "Ideographic"},
    35439: {"Unified_Ideograph", "Ideographic"},
    35440: {"Unified_Ideograph", "Ideographic"},
    35441: {"Unified_Ideograph", "Ideographic"},
    35442: {"Unified_Ideograph", "Ideographic"},
    35443: {"Unified_Ideograph", "Ideographic"},
    35444: {"Unified_Ideograph", "Ideographic"},
    35445: {"Unified_Ideograph", "Ideographic"},
    35446: {"Unified_Ideograph", "Ideographic"},
    35447: {"Unified_Ideograph", "Ideographic"},
    35448: {"Unified_Ideograph", "Ideographic"},
    35449: {"Unified_Ideograph", "Ideographic"},
    35450: {"Unified_Ideograph", "Ideographic"},
    35451: {"Unified_Ideograph", "Ideographic"},
    35452: {"Unified_Ideograph", "Ideographic"},
    35453: {"Unified_Ideograph", "Ideographic"},
    35454: {"Unified_Ideograph", "Ideographic"},
    35455: {"Unified_Ideograph", "Ideographic"},
    35456: {"Unified_Ideograph", "Ideographic"},
    35457: {"Unified_Ideograph", "Ideographic"},
    35458: {"Unified_Ideograph", "Ideographic"},
    35459: {"Unified_Ideograph", "Ideographic"},
    35460: {"Unified_Ideograph", "Ideographic"},
    35461: {"Unified_Ideograph", "Ideographic"},
    35462: {"Unified_Ideograph", "Ideographic"},
    35463: {"Unified_Ideograph", "Ideographic"},
    35464: {"Unified_Ideograph", "Ideographic"},
    35465: {"Unified_Ideograph", "Ideographic"},
    35466: {"Unified_Ideograph", "Ideographic"},
    35467: {"Unified_Ideograph", "Ideographic"},
    35468: {"Unified_Ideograph", "Ideographic"},
    35469: {"Unified_Ideograph", "Ideographic"},
    35470: {"Unified_Ideograph", "Ideographic"},
    35471: {"Unified_Ideograph", "Ideographic"},
    35472: {"Unified_Ideograph", "Ideographic"},
    35473: {"Unified_Ideograph", "Ideographic"},
    35474: {"Unified_Ideograph", "Ideographic"},
    35475: {"Unified_Ideograph", "Ideographic"},
    35476: {"Unified_Ideograph", "Ideographic"},
    35477: {"Unified_Ideograph", "Ideographic"},
    35478: {"Unified_Ideograph", "Ideographic"},
    35479: {"Unified_Ideograph", "Ideographic"},
    35480: {"Unified_Ideograph", "Ideographic"},
    35481: {"Unified_Ideograph", "Ideographic"},
    35482: {"Unified_Ideograph", "Ideographic"},
    35483: {"Unified_Ideograph", "Ideographic"},
    35484: {"Unified_Ideograph", "Ideographic"},
    35485: {"Unified_Ideograph", "Ideographic"},
    35486: {"Unified_Ideograph", "Ideographic"},
    35487: {"Unified_Ideograph", "Ideographic"},
    35488: {"Unified_Ideograph", "Ideographic"},
    35489: {"Unified_Ideograph", "Ideographic"},
    35490: {"Unified_Ideograph", "Ideographic"},
    35491: {"Unified_Ideograph", "Ideographic"},
    35492: {"Unified_Ideograph", "Ideographic"},
    35493: {"Unified_Ideograph", "Ideographic"},
    35494: {"Unified_Ideograph", "Ideographic"},
    35495: {"Unified_Ideograph", "Ideographic"},
    35496: {"Unified_Ideograph", "Ideographic"},
    35497: {"Unified_Ideograph", "Ideographic"},
    35498: {"Unified_Ideograph", "Ideographic"},
    35499: {"Unified_Ideograph", "Ideographic"},
    35500: {"Unified_Ideograph", "Ideographic"},
    35501: {"Unified_Ideograph", "Ideographic"},
    35502: {"Unified_Ideograph", "Ideographic"},
    35503: {"Unified_Ideograph", "Ideographic"},
    35504: {"Unified_Ideograph", "Ideographic"},
    35505: {"Unified_Ideograph", "Ideographic"},
    35506: {"Unified_Ideograph", "Ideographic"},
    35507: {"Unified_Ideograph", "Ideographic"},
    35508: {"Unified_Ideograph", "Ideographic"},
    35509: {"Unified_Ideograph", "Ideographic"},
    35510: {"Unified_Ideograph", "Ideographic"},
    35511: {"Unified_Ideograph", "Ideographic"},
    35512: {"Unified_Ideograph", "Ideographic"},
    35513: {"Unified_Ideograph", "Ideographic"},
    35514: {"Unified_Ideograph", "Ideographic"},
    35515: {"Unified_Ideograph", "Ideographic"},
    35516: {"Unified_Ideograph", "Ideographic"},
    35517: {"Unified_Ideograph", "Ideographic"},
    35518: {"Unified_Ideograph", "Ideographic"},
    35519: {"Unified_Ideograph", "Ideographic"},
    35520: {"Unified_Ideograph", "Ideographic"},
    35521: {"Unified_Ideograph", "Ideographic"},
    35522: {"Unified_Ideograph", "Ideographic"},
    35523: {"Unified_Ideograph", "Ideographic"},
    35524: {"Unified_Ideograph", "Ideographic"},
    35525: {"Unified_Ideograph", "Ideographic"},
    35526: {"Unified_Ideograph", "Ideographic"},
    35527: {"Unified_Ideograph", "Ideographic"},
    35528: {"Unified_Ideograph", "Ideographic"},
    35529: {"Unified_Ideograph", "Ideographic"},
    35530: {"Unified_Ideograph", "Ideographic"},
    35531: {"Unified_Ideograph", "Ideographic"},
    35532: {"Unified_Ideograph", "Ideographic"},
    35533: {"Unified_Ideograph", "Ideographic"},
    35534: {"Unified_Ideograph", "Ideographic"},
    35535: {"Unified_Ideograph", "Ideographic"},
    35536: {"Unified_Ideograph", "Ideographic"},
    35537: {"Unified_Ideograph", "Ideographic"},
    35538: {"Unified_Ideograph", "Ideographic"},
    35539: {"Unified_Ideograph", "Ideographic"},
    35540: {"Unified_Ideograph", "Ideographic"},
    35541: {"Unified_Ideograph", "Ideographic"},
    35542: {"Unified_Ideograph", "Ideographic"},
    35543: {"Unified_Ideograph", "Ideographic"},
    35544: {"Unified_Ideograph", "Ideographic"},
    35545: {"Unified_Ideograph", "Ideographic"},
    35546: {"Unified_Ideograph", "Ideographic"},
    35547: {"Unified_Ideograph", "Ideographic"},
    35548: {"Unified_Ideograph", "Ideographic"},
    35549: {"Unified_Ideograph", "Ideographic"},
    35550: {"Unified_Ideograph", "Ideographic"},
    35551: {"Unified_Ideograph", "Ideographic"},
    35552: {"Unified_Ideograph", "Ideographic"},
    35553: {"Unified_Ideograph", "Ideographic"},
    35554: {"Unified_Ideograph", "Ideographic"},
    35555: {"Unified_Ideograph", "Ideographic"},
    35556: {"Unified_Ideograph", "Ideographic"},
    35557: {"Unified_Ideograph", "Ideographic"},
    35558: {"Unified_Ideograph", "Ideographic"},
    35559: {"Unified_Ideograph", "Ideographic"},
    35560: {"Unified_Ideograph", "Ideographic"},
    35561: {"Unified_Ideograph", "Ideographic"},
    35562: {"Unified_Ideograph", "Ideographic"},
    35563: {"Unified_Ideograph", "Ideographic"},
    35564: {"Unified_Ideograph", "Ideographic"},
    35565: {"Unified_Ideograph", "Ideographic"},
    35566: {"Unified_Ideograph", "Ideographic"},
    35567: {"Unified_Ideograph", "Ideographic"},
    35568: {"Unified_Ideograph", "Ideographic"},
    35569: {"Unified_Ideograph", "Ideographic"},
    35570: {"Unified_Ideograph", "Ideographic"},
    35571: {"Unified_Ideograph", "Ideographic"},
    35572: {"Unified_Ideograph", "Ideographic"},
    35573: {"Unified_Ideograph", "Ideographic"},
    35574: {"Unified_Ideograph", "Ideographic"},
    35575: {"Unified_Ideograph", "Ideographic"},
    35576: {"Unified_Ideograph", "Ideographic"},
    35577: {"Unified_Ideograph", "Ideographic"},
    35578: {"Unified_Ideograph", "Ideographic"},
    35579: {"Unified_Ideograph", "Ideographic"},
    35580: {"Unified_Ideograph", "Ideographic"},
    35581: {"Unified_Ideograph", "Ideographic"},
    35582: {"Unified_Ideograph", "Ideographic"},
    35583: {"Unified_Ideograph", "Ideographic"},
    35584: {"Unified_Ideograph", "Ideographic"},
    35585: {"Unified_Ideograph", "Ideographic"},
    35586: {"Unified_Ideograph", "Ideographic"},
    35587: {"Unified_Ideograph", "Ideographic"},
    35588: {"Unified_Ideograph", "Ideographic"},
    35589: {"Unified_Ideograph", "Ideographic"},
    35590: {"Unified_Ideograph", "Ideographic"},
    35591: {"Unified_Ideograph", "Ideographic"},
    35592: {"Unified_Ideograph", "Ideographic"},
    35593: {"Unified_Ideograph", "Ideographic"},
    35594: {"Unified_Ideograph", "Ideographic"},
    35595: {"Unified_Ideograph", "Ideographic"},
    35596: {"Unified_Ideograph", "Ideographic"},
    35597: {"Unified_Ideograph", "Ideographic"},
    35598: {"Unified_Ideograph", "Ideographic"},
    35599: {"Unified_Ideograph", "Ideographic"},
    35600: {"Unified_Ideograph", "Ideographic"},
    35601: {"Unified_Ideograph", "Ideographic"},
    35602: {"Unified_Ideograph", "Ideographic"},
    35603: {"Unified_Ideograph", "Ideographic"},
    35604: {"Unified_Ideograph", "Ideographic"},
    35605: {"Unified_Ideograph", "Ideographic"},
    35606: {"Unified_Ideograph", "Ideographic"},
    35607: {"Unified_Ideograph", "Ideographic"},
    35608: {"Unified_Ideograph", "Ideographic"},
    35609: {"Unified_Ideograph", "Ideographic"},
    35610: {"Unified_Ideograph", "Ideographic"},
    35611: {"Unified_Ideograph", "Ideographic"},
    35612: {"Unified_Ideograph", "Ideographic"},
    35613: {"Unified_Ideograph", "Ideographic"},
    35614: {"Unified_Ideograph", "Ideographic"},
    35615: {"Unified_Ideograph", "Ideographic"},
    35616: {"Unified_Ideograph", "Ideographic"},
    35617: {"Unified_Ideograph", "Ideographic"},
    35618: {"Unified_Ideograph", "Ideographic"},
    35619: {"Unified_Ideograph", "Ideographic"},
    35620: {"Unified_Ideograph", "Ideographic"},
    35621: {"Unified_Ideograph", "Ideographic"},
    35622: {"Unified_Ideograph", "Ideographic"},
    35623: {"Unified_Ideograph", "Ideographic"},
    35624: {"Unified_Ideograph", "Ideographic"},
    35625: {"Unified_Ideograph", "Ideographic"},
    35626: {"Unified_Ideograph", "Ideographic"},
    35627: {"Unified_Ideograph", "Ideographic"},
    35628: {"Unified_Ideograph", "Ideographic"},
    35629: {"Unified_Ideograph", "Ideographic"},
    35630: {"Unified_Ideograph", "Ideographic"},
    35631: {"Unified_Ideograph", "Ideographic"},
    35632: {"Unified_Ideograph", "Ideographic"},
    35633: {"Unified_Ideograph", "Ideographic"},
    35634: {"Unified_Ideograph", "Ideographic"},
    35635: {"Unified_Ideograph", "Ideographic"},
    35636: {"Unified_Ideograph", "Ideographic"},
    35637: {"Unified_Ideograph", "Ideographic"},
    35638: {"Unified_Ideograph", "Ideographic"},
    35639: {"Unified_Ideograph", "Ideographic"},
    35640: {"Unified_Ideograph", "Ideographic"},
    35641: {"Unified_Ideograph", "Ideographic"},
    35642: {"Unified_Ideograph", "Ideographic"},
    35643: {"Unified_Ideograph", "Ideographic"},
    35644: {"Unified_Ideograph", "Ideographic"},
    35645: {"Unified_Ideograph", "Ideographic"},
    35646: {"Unified_Ideograph", "Ideographic"},
    35647: {"Unified_Ideograph", "Ideographic"},
    35648: {"Unified_Ideograph", "Ideographic"},
    35649: {"Unified_Ideograph", "Ideographic"},
    35650: {"Unified_Ideograph", "Ideographic"},
    35651: {"Unified_Ideograph", "Ideographic"},
    35652: {"Unified_Ideograph", "Ideographic"},
    35653: {"Unified_Ideograph", "Ideographic"},
    35654: {"Unified_Ideograph", "Ideographic"},
    35655: {"Unified_Ideograph", "Ideographic"},
    35656: {"Unified_Ideograph", "Ideographic"},
    35657: {"Unified_Ideograph", "Ideographic"},
    35658: {"Unified_Ideograph", "Ideographic"},
    35659: {"Unified_Ideograph", "Ideographic"},
    35660: {"Unified_Ideograph", "Ideographic"},
    35661: {"Unified_Ideograph", "Ideographic"},
    35662: {"Unified_Ideograph", "Ideographic"},
    35663: {"Unified_Ideograph", "Ideographic"},
    35664: {"Unified_Ideograph", "Ideographic"},
    35665: {"Unified_Ideograph", "Ideographic"},
    35666: {"Unified_Ideograph", "Ideographic"},
    35667: {"Unified_Ideograph", "Ideographic"},
    35668: {"Unified_Ideograph", "Ideographic"},
    35669: {"Unified_Ideograph", "Ideographic"},
    35670: {"Unified_Ideograph", "Ideographic"},
    35671: {"Unified_Ideograph", "Ideographic"},
    35672: {"Unified_Ideograph", "Ideographic"},
    35673: {"Unified_Ideograph", "Ideographic"},
    35674: {"Unified_Ideograph", "Ideographic"},
    35675: {"Unified_Ideograph", "Ideographic"},
    35676: {"Unified_Ideograph", "Ideographic"},
    35677: {"Unified_Ideograph", "Ideographic"},
    35678: {"Unified_Ideograph", "Ideographic"},
    35679: {"Unified_Ideograph", "Ideographic"},
    35680: {"Unified_Ideograph", "Ideographic"},
    35681: {"Unified_Ideograph", "Ideographic"},
    35682: {"Unified_Ideograph", "Ideographic"},
    35683: {"Unified_Ideograph", "Ideographic"},
    35684: {"Unified_Ideograph", "Ideographic"},
    35685: {"Unified_Ideograph", "Ideographic"},
    35686: {"Unified_Ideograph", "Ideographic"},
    35687: {"Unified_Ideograph", "Ideographic"},
    35688: {"Unified_Ideograph", "Ideographic"},
    35689: {"Unified_Ideograph", "Ideographic"},
    35690: {"Unified_Ideograph", "Ideographic"},
    35691: {"Unified_Ideograph", "Ideographic"},
    35692: {"Unified_Ideograph", "Ideographic"},
    35693: {"Unified_Ideograph", "Ideographic"},
    35694: {"Unified_Ideograph", "Ideographic"},
    35695: {"Unified_Ideograph", "Ideographic"},
    35696: {"Unified_Ideograph", "Ideographic"},
    35697: {"Unified_Ideograph", "Ideographic"},
    35698: {"Unified_Ideograph", "Ideographic"},
    35699: {"Unified_Ideograph", "Ideographic"},
    35700: {"Unified_Ideograph", "Ideographic"},
    35701: {"Unified_Ideograph", "Ideographic"},
    35702: {"Unified_Ideograph", "Ideographic"},
    35703: {"Unified_Ideograph", "Ideographic"},
    35704: {"Unified_Ideograph", "Ideographic"},
    35705: {"Unified_Ideograph", "Ideographic"},
    35706: {"Unified_Ideograph", "Ideographic"},
    35707: {"Unified_Ideograph", "Ideographic"},
    35708: {"Unified_Ideograph", "Ideographic"},
    35709: {"Unified_Ideograph", "Ideographic"},
    35710: {"Unified_Ideograph", "Ideographic"},
    35711: {"Unified_Ideograph", "Ideographic"},
    35712: {"Unified_Ideograph", "Ideographic"},
    35713: {"Unified_Ideograph", "Ideographic"},
    35714: {"Unified_Ideograph", "Ideographic"},
    35715: {"Unified_Ideograph", "Ideographic"},
    35716: {"Unified_Ideograph", "Ideographic"},
    35717: {"Unified_Ideograph", "Ideographic"},
    35718: {"Unified_Ideograph", "Ideographic"},
    35719: {"Unified_Ideograph", "Ideographic"},
    35720: {"Unified_Ideograph", "Ideographic"},
    35721: {"Unified_Ideograph", "Ideographic"},
    35722: {"Unified_Ideograph", "Ideographic"},
    35723: {"Unified_Ideograph", "Ideographic"},
    35724: {"Unified_Ideograph", "Ideographic"},
    35725: {"Unified_Ideograph", "Ideographic"},
    35726: {"Unified_Ideograph", "Ideographic"},
    35727: {"Unified_Ideograph", "Ideographic"},
    35728: {"Unified_Ideograph", "Ideographic"},
    35729: {"Unified_Ideograph", "Ideographic"},
    35730: {"Unified_Ideograph", "Ideographic"},
    35731: {"Unified_Ideograph", "Ideographic"},
    35732: {"Unified_Ideograph", "Ideographic"},
    35733: {"Unified_Ideograph", "Ideographic"},
    35734: {"Unified_Ideograph", "Ideographic"},
    35735: {"Unified_Ideograph", "Ideographic"},
    35736: {"Unified_Ideograph", "Ideographic"},
    35737: {"Unified_Ideograph", "Ideographic"},
    35738: {"Unified_Ideograph", "Ideographic"},
    35739: {"Unified_Ideograph", "Ideographic"},
    35740: {"Unified_Ideograph", "Ideographic"},
    35741: {"Unified_Ideograph", "Ideographic"},
    35742: {"Unified_Ideograph", "Ideographic"},
    35743: {"Unified_Ideograph", "Ideographic"},
    35744: {"Unified_Ideograph", "Ideographic"},
    35745: {"Unified_Ideograph", "Ideographic"},
    35746: {"Unified_Ideograph", "Ideographic"},
    35747: {"Unified_Ideograph", "Ideographic"},
    35748: {"Unified_Ideograph", "Ideographic"},
    35749: {"Unified_Ideograph", "Ideographic"},
    35750: {"Unified_Ideograph", "Ideographic"},
    35751: {"Unified_Ideograph", "Ideographic"},
    35752: {"Unified_Ideograph", "Ideographic"},
    35753: {"Unified_Ideograph", "Ideographic"},
    35754: {"Unified_Ideograph", "Ideographic"},
    35755: {"Unified_Ideograph", "Ideographic"},
    35756: {"Unified_Ideograph", "Ideographic"},
    35757: {"Unified_Ideograph", "Ideographic"},
    35758: {"Unified_Ideograph", "Ideographic"},
    35759: {"Unified_Ideograph", "Ideographic"},
    35760: {"Unified_Ideograph", "Ideographic"},
    35761: {"Unified_Ideograph", "Ideographic"},
    35762: {"Unified_Ideograph", "Ideographic"},
    35763: {"Unified_Ideograph", "Ideographic"},
    35764: {"Unified_Ideograph", "Ideographic"},
    35765: {"Unified_Ideograph", "Ideographic"},
    35766: {"Unified_Ideograph", "Ideographic"},
    35767: {"Unified_Ideograph", "Ideographic"},
    35768: {"Unified_Ideograph", "Ideographic"},
    35769: {"Unified_Ideograph", "Ideographic"},
    35770: {"Unified_Ideograph", "Ideographic"},
    35771: {"Unified_Ideograph", "Ideographic"},
    35772: {"Unified_Ideograph", "Ideographic"},
    35773: {"Unified_Ideograph", "Ideographic"},
    35774: {"Unified_Ideograph", "Ideographic"},
    35775: {"Unified_Ideograph", "Ideographic"},
    35776: {"Unified_Ideograph", "Ideographic"},
    35777: {"Unified_Ideograph", "Ideographic"},
    35778: {"Unified_Ideograph", "Ideographic"},
    35779: {"Unified_Ideograph", "Ideographic"},
    35780: {"Unified_Ideograph", "Ideographic"},
    35781: {"Unified_Ideograph", "Ideographic"},
    35782: {"Unified_Ideograph", "Ideographic"},
    35783: {"Unified_Ideograph", "Ideographic"},
    35784: {"Unified_Ideograph", "Ideographic"},
    35785: {"Unified_Ideograph", "Ideographic"},
    35786: {"Unified_Ideograph", "Ideographic"},
    35787: {"Unified_Ideograph", "Ideographic"},
    35788: {"Unified_Ideograph", "Ideographic"},
    35789: {"Unified_Ideograph", "Ideographic"},
    35790: {"Unified_Ideograph", "Ideographic"},
    35791: {"Unified_Ideograph", "Ideographic"},
    35792: {"Unified_Ideograph", "Ideographic"},
    35793: {"Unified_Ideograph", "Ideographic"},
    35794: {"Unified_Ideograph", "Ideographic"},
    35795: {"Unified_Ideograph", "Ideographic"},
    35796: {"Unified_Ideograph", "Ideographic"},
    35797: {"Unified_Ideograph", "Ideographic"},
    35798: {"Unified_Ideograph", "Ideographic"},
    35799: {"Unified_Ideograph", "Ideographic"},
    35800: {"Unified_Ideograph", "Ideographic"},
    35801: {"Unified_Ideograph", "Ideographic"},
    35802: {"Unified_Ideograph", "Ideographic"},
    35803: {"Unified_Ideograph", "Ideographic"},
    35804: {"Unified_Ideograph", "Ideographic"},
    35805: {"Unified_Ideograph", "Ideographic"},
    35806: {"Unified_Ideograph", "Ideographic"},
    35807: {"Unified_Ideograph", "Ideographic"},
    35808: {"Unified_Ideograph", "Ideographic"},
    35809: {"Unified_Ideograph", "Ideographic"},
    35810: {"Unified_Ideograph", "Ideographic"},
    35811: {"Unified_Ideograph", "Ideographic"},
    35812: {"Unified_Ideograph", "Ideographic"},
    35813: {"Unified_Ideograph", "Ideographic"},
    35814: {"Unified_Ideograph", "Ideographic"},
    35815: {"Unified_Ideograph", "Ideographic"},
    35816: {"Unified_Ideograph", "Ideographic"},
    35817: {"Unified_Ideograph", "Ideographic"},
    35818: {"Unified_Ideograph", "Ideographic"},
    35819: {"Unified_Ideograph", "Ideographic"},
    35820: {"Unified_Ideograph", "Ideographic"},
    35821: {"Unified_Ideograph", "Ideographic"},
    35822: {"Unified_Ideograph", "Ideographic"},
    35823: {"Unified_Ideograph", "Ideographic"},
    35824: {"Unified_Ideograph", "Ideographic"},
    35825: {"Unified_Ideograph", "Ideographic"},
    35826: {"Unified_Ideograph", "Ideographic"},
    35827: {"Unified_Ideograph", "Ideographic"},
    35828: {"Unified_Ideograph", "Ideographic"},
    35829: {"Unified_Ideograph", "Ideographic"},
    35830: {"Unified_Ideograph", "Ideographic"},
    35831: {"Unified_Ideograph", "Ideographic"},
    35832: {"Unified_Ideograph", "Ideographic"},
    35833: {"Unified_Ideograph", "Ideographic"},
    35834: {"Unified_Ideograph", "Ideographic"},
    35835: {"Unified_Ideograph", "Ideographic"},
    35836: {"Unified_Ideograph", "Ideographic"},
    35837: {"Unified_Ideograph", "Ideographic"},
    35838: {"Unified_Ideograph", "Ideographic"},
    35839: {"Unified_Ideograph", "Ideographic"},
    35840: {"Unified_Ideograph", "Ideographic"},
    35841: {"Unified_Ideograph", "Ideographic"},
    35842: {"Unified_Ideograph", "Ideographic"},
    35843: {"Unified_Ideograph", "Ideographic"},
    35844: {"Unified_Ideograph", "Ideographic"},
    35845: {"Unified_Ideograph", "Ideographic"},
    35846: {"Unified_Ideograph", "Ideographic"},
    35847: {"Unified_Ideograph", "Ideographic"},
    35848: {"Unified_Ideograph", "Ideographic"},
    35849: {"Unified_Ideograph", "Ideographic"},
    35850: {"Unified_Ideograph", "Ideographic"},
    35851: {"Unified_Ideograph", "Ideographic"},
    35852: {"Unified_Ideograph", "Ideographic"},
    35853: {"Unified_Ideograph", "Ideographic"},
    35854: {"Unified_Ideograph", "Ideographic"},
    35855: {"Unified_Ideograph", "Ideographic"},
    35856: {"Unified_Ideograph", "Ideographic"},
    35857: {"Unified_Ideograph", "Ideographic"},
    35858: {"Unified_Ideograph", "Ideographic"},
    35859: {"Unified_Ideograph", "Ideographic"},
    35860: {"Unified_Ideograph", "Ideographic"},
    35861: {"Unified_Ideograph", "Ideographic"},
    35862: {"Unified_Ideograph", "Ideographic"},
    35863: {"Unified_Ideograph", "Ideographic"},
    35864: {"Unified_Ideograph", "Ideographic"},
    35865: {"Unified_Ideograph", "Ideographic"},
    35866: {"Unified_Ideograph", "Ideographic"},
    35867: {"Unified_Ideograph", "Ideographic"},
    35868: {"Unified_Ideograph", "Ideographic"},
    35869: {"Unified_Ideograph", "Ideographic"},
    35870: {"Unified_Ideograph", "Ideographic"},
    35871: {"Unified_Ideograph", "Ideographic"},
    35872: {"Unified_Ideograph", "Ideographic"},
    35873: {"Unified_Ideograph", "Ideographic"},
    35874: {"Unified_Ideograph", "Ideographic"},
    35875: {"Unified_Ideograph", "Ideographic"},
    35876: {"Unified_Ideograph", "Ideographic"},
    35877: {"Unified_Ideograph", "Ideographic"},
    35878: {"Unified_Ideograph", "Ideographic"},
    35879: {"Unified_Ideograph", "Ideographic"},
    35880: {"Unified_Ideograph", "Ideographic"},
    35881: {"Unified_Ideograph", "Ideographic"},
    35882: {"Unified_Ideograph", "Ideographic"},
    35883: {"Unified_Ideograph", "Ideographic"},
    35884: {"Unified_Ideograph", "Ideographic"},
    35885: {"Unified_Ideograph", "Ideographic"},
    35886: {"Unified_Ideograph", "Ideographic"},
    35887: {"Unified_Ideograph", "Ideographic"},
    35888: {"Unified_Ideograph", "Ideographic"},
    35889: {"Unified_Ideograph", "Ideographic"},
    35890: {"Unified_Ideograph", "Ideographic"},
    35891: {"Unified_Ideograph", "Ideographic"},
    35892: {"Unified_Ideograph", "Ideographic"},
    35893: {"Unified_Ideograph", "Ideographic"},
    35894: {"Unified_Ideograph", "Ideographic"},
    35895: {"Unified_Ideograph", "Ideographic"},
    35896: {"Unified_Ideograph", "Ideographic"},
    35897: {"Unified_Ideograph", "Ideographic"},
    35898: {"Unified_Ideograph", "Ideographic"},
    35899: {"Unified_Ideograph", "Ideographic"},
    35900: {"Unified_Ideograph", "Ideographic"},
    35901: {"Unified_Ideograph", "Ideographic"},
    35902: {"Unified_Ideograph", "Ideographic"},
    35903: {"Unified_Ideograph", "Ideographic"},
    35904: {"Unified_Ideograph", "Ideographic"},
    35905: {"Unified_Ideograph", "Ideographic"},
    35906: {"Unified_Ideograph", "Ideographic"},
    35907: {"Unified_Ideograph", "Ideographic"},
    35908: {"Unified_Ideograph", "Ideographic"},
    35909: {"Unified_Ideograph", "Ideographic"},
    35910: {"Unified_Ideograph", "Ideographic"},
    35911: {"Unified_Ideograph", "Ideographic"},
    35912: {"Unified_Ideograph", "Ideographic"},
    35913: {"Unified_Ideograph", "Ideographic"},
    35914: {"Unified_Ideograph", "Ideographic"},
    35915: {"Unified_Ideograph", "Ideographic"},
    35916: {"Unified_Ideograph", "Ideographic"},
    35917: {"Unified_Ideograph", "Ideographic"},
    35918: {"Unified_Ideograph", "Ideographic"},
    35919: {"Unified_Ideograph", "Ideographic"},
    35920: {"Unified_Ideograph", "Ideographic"},
    35921: {"Unified_Ideograph", "Ideographic"},
    35922: {"Unified_Ideograph", "Ideographic"},
    35923: {"Unified_Ideograph", "Ideographic"},
    35924: {"Unified_Ideograph", "Ideographic"},
    35925: {"Unified_Ideograph", "Ideographic"},
    35926: {"Unified_Ideograph", "Ideographic"},
    35927: {"Unified_Ideograph", "Ideographic"},
    35928: {"Unified_Ideograph", "Ideographic"},
    35929: {"Unified_Ideograph", "Ideographic"},
    35930: {"Unified_Ideograph", "Ideographic"},
    35931: {"Unified_Ideograph", "Ideographic"},
    35932: {"Unified_Ideograph", "Ideographic"},
    35933: {"Unified_Ideograph", "Ideographic"},
    35934: {"Unified_Ideograph", "Ideographic"},
    35935: {"Unified_Ideograph", "Ideographic"},
    35936: {"Unified_Ideograph", "Ideographic"},
    35937: {"Unified_Ideograph", "Ideographic"},
    35938: {"Unified_Ideograph", "Ideographic"},
    35939: {"Unified_Ideograph", "Ideographic"},
    35940: {"Unified_Ideograph", "Ideographic"},
    35941: {"Unified_Ideograph", "Ideographic"},
    35942: {"Unified_Ideograph", "Ideographic"},
    35943: {"Unified_Ideograph", "Ideographic"},
    35944: {"Unified_Ideograph", "Ideographic"},
    35945: {"Unified_Ideograph", "Ideographic"},
    35946: {"Unified_Ideograph", "Ideographic"},
    35947: {"Unified_Ideograph", "Ideographic"},
    35948: {"Unified_Ideograph", "Ideographic"},
    35949: {"Unified_Ideograph", "Ideographic"},
    35950: {"Unified_Ideograph", "Ideographic"},
    35951: {"Unified_Ideograph", "Ideographic"},
    35952: {"Unified_Ideograph", "Ideographic"},
    35953: {"Unified_Ideograph", "Ideographic"},
    35954: {"Unified_Ideograph", "Ideographic"},
    35955: {"Unified_Ideograph", "Ideographic"},
    35956: {"Unified_Ideograph", "Ideographic"},
    35957: {"Unified_Ideograph", "Ideographic"},
    35958: {"Unified_Ideograph", "Ideographic"},
    35959: {"Unified_Ideograph", "Ideographic"},
    35960: {"Unified_Ideograph", "Ideographic"},
    35961: {"Unified_Ideograph", "Ideographic"},
    35962: {"Unified_Ideograph", "Ideographic"},
    35963: {"Unified_Ideograph", "Ideographic"},
    35964: {"Unified_Ideograph", "Ideographic"},
    35965: {"Unified_Ideograph", "Ideographic"},
    35966: {"Unified_Ideograph", "Ideographic"},
    35967: {"Unified_Ideograph", "Ideographic"},
    35968: {"Unified_Ideograph", "Ideographic"},
    35969: {"Unified_Ideograph", "Ideographic"},
    35970: {"Unified_Ideograph", "Ideographic"},
    35971: {"Unified_Ideograph", "Ideographic"},
    35972: {"Unified_Ideograph", "Ideographic"},
    35973: {"Unified_Ideograph", "Ideographic"},
    35974: {"Unified_Ideograph", "Ideographic"},
    35975: {"Unified_Ideograph", "Ideographic"},
    35976: {"Unified_Ideograph", "Ideographic"},
    35977: {"Unified_Ideograph", "Ideographic"},
    35978: {"Unified_Ideograph", "Ideographic"},
    35979: {"Unified_Ideograph", "Ideographic"},
    35980: {"Unified_Ideograph", "Ideographic"},
    35981: {"Unified_Ideograph", "Ideographic"},
    35982: {"Unified_Ideograph", "Ideographic"},
    35983: {"Unified_Ideograph", "Ideographic"},
    35984: {"Unified_Ideograph", "Ideographic"},
    35985: {"Unified_Ideograph", "Ideographic"},
    35986: {"Unified_Ideograph", "Ideographic"},
    35987: {"Unified_Ideograph", "Ideographic"},
    35988: {"Unified_Ideograph", "Ideographic"},
    35989: {"Unified_Ideograph", "Ideographic"},
    35990: {"Unified_Ideograph", "Ideographic"},
    35991: {"Unified_Ideograph", "Ideographic"},
    35992: {"Unified_Ideograph", "Ideographic"},
    35993: {"Unified_Ideograph", "Ideographic"},
    35994: {"Unified_Ideograph", "Ideographic"},
    35995: {"Unified_Ideograph", "Ideographic"},
    35996: {"Unified_Ideograph", "Ideographic"},
    35997: {"Unified_Ideograph", "Ideographic"},
    35998: {"Unified_Ideograph", "Ideographic"},
    35999: {"Unified_Ideograph", "Ideographic"},
    36000: {"Unified_Ideograph", "Ideographic"},
    36001: {"Unified_Ideograph", "Ideographic"},
    36002: {"Unified_Ideograph", "Ideographic"},
    36003: {"Unified_Ideograph", "Ideographic"},
    36004: {"Unified_Ideograph", "Ideographic"},
    36005: {"Unified_Ideograph", "Ideographic"},
    36006: {"Unified_Ideograph", "Ideographic"},
    36007: {"Unified_Ideograph", "Ideographic"},
    36008: {"Unified_Ideograph", "Ideographic"},
    36009: {"Unified_Ideograph", "Ideographic"},
    36010: {"Unified_Ideograph", "Ideographic"},
    36011: {"Unified_Ideograph", "Ideographic"},
    36012: {"Unified_Ideograph", "Ideographic"},
    36013: {"Unified_Ideograph", "Ideographic"},
    36014: {"Unified_Ideograph", "Ideographic"},
    36015: {"Unified_Ideograph", "Ideographic"},
    36016: {"Unified_Ideograph", "Ideographic"},
    36017: {"Unified_Ideograph", "Ideographic"},
    36018: {"Unified_Ideograph", "Ideographic"},
    36019: {"Unified_Ideograph", "Ideographic"},
    36020: {"Unified_Ideograph", "Ideographic"},
    36021: {"Unified_Ideograph", "Ideographic"},
    36022: {"Unified_Ideograph", "Ideographic"},
    36023: {"Unified_Ideograph", "Ideographic"},
    36024: {"Unified_Ideograph", "Ideographic"},
    36025: {"Unified_Ideograph", "Ideographic"},
    36026: {"Unified_Ideograph", "Ideographic"},
    36027: {"Unified_Ideograph", "Ideographic"},
    36028: {"Unified_Ideograph", "Ideographic"},
    36029: {"Unified_Ideograph", "Ideographic"},
    36030: {"Unified_Ideograph", "Ideographic"},
    36031: {"Unified_Ideograph", "Ideographic"},
    36032: {"Unified_Ideograph", "Ideographic"},
    36033: {"Unified_Ideograph", "Ideographic"},
    36034: {"Unified_Ideograph", "Ideographic"},
    36035: {"Unified_Ideograph", "Ideographic"},
    36036: {"Unified_Ideograph", "Ideographic"},
    36037: {"Unified_Ideograph", "Ideographic"},
    36038: {"Unified_Ideograph", "Ideographic"},
    36039: {"Unified_Ideograph", "Ideographic"},
    36040: {"Unified_Ideograph", "Ideographic"},
    36041: {"Unified_Ideograph", "Ideographic"},
    36042: {"Unified_Ideograph", "Ideographic"},
    36043: {"Unified_Ideograph", "Ideographic"},
    36044: {"Unified_Ideograph", "Ideographic"},
    36045: {"Unified_Ideograph", "Ideographic"},
    36046: {"Unified_Ideograph", "Ideographic"},
    36047: {"Unified_Ideograph", "Ideographic"},
    36048: {"Unified_Ideograph", "Ideographic"},
    36049: {"Unified_Ideograph", "Ideographic"},
    36050: {"Unified_Ideograph", "Ideographic"},
    36051: {"Unified_Ideograph", "Ideographic"},
    36052: {"Unified_Ideograph", "Ideographic"},
    36053: {"Unified_Ideograph", "Ideographic"},
    36054: {"Unified_Ideograph", "Ideographic"},
    36055: {"Unified_Ideograph", "Ideographic"},
    36056: {"Unified_Ideograph", "Ideographic"},
    36057: {"Unified_Ideograph", "Ideographic"},
    36058: {"Unified_Ideograph", "Ideographic"},
    36059: {"Unified_Ideograph", "Ideographic"},
    36060: {"Unified_Ideograph", "Ideographic"},
    36061: {"Unified_Ideograph", "Ideographic"},
    36062: {"Unified_Ideograph", "Ideographic"},
    36063: {"Unified_Ideograph", "Ideographic"},
    36064: {"Unified_Ideograph", "Ideographic"},
    36065: {"Unified_Ideograph", "Ideographic"},
    36066: {"Unified_Ideograph", "Ideographic"},
    36067: {"Unified_Ideograph", "Ideographic"},
    36068: {"Unified_Ideograph", "Ideographic"},
    36069: {"Unified_Ideograph", "Ideographic"},
    36070: {"Unified_Ideograph", "Ideographic"},
    36071: {"Unified_Ideograph", "Ideographic"},
    36072: {"Unified_Ideograph", "Ideographic"},
    36073: {"Unified_Ideograph", "Ideographic"},
    36074: {"Unified_Ideograph", "Ideographic"},
    36075: {"Unified_Ideograph", "Ideographic"},
    36076: {"Unified_Ideograph", "Ideographic"},
    36077: {"Unified_Ideograph", "Ideographic"},
    36078: {"Unified_Ideograph", "Ideographic"},
    36079: {"Unified_Ideograph", "Ideographic"},
    36080: {"Unified_Ideograph", "Ideographic"},
    36081: {"Unified_Ideograph", "Ideographic"},
    36082: {"Unified_Ideograph", "Ideographic"},
    36083: {"Unified_Ideograph", "Ideographic"},
    36084: {"Unified_Ideograph", "Ideographic"},
    36085: {"Unified_Ideograph", "Ideographic"},
    36086: {"Unified_Ideograph", "Ideographic"},
    36087: {"Unified_Ideograph", "Ideographic"},
    36088: {"Unified_Ideograph", "Ideographic"},
    36089: {"Unified_Ideograph", "Ideographic"},
    36090: {"Unified_Ideograph", "Ideographic"},
    36091: {"Unified_Ideograph", "Ideographic"},
    36092: {"Unified_Ideograph", "Ideographic"},
    36093: {"Unified_Ideograph", "Ideographic"},
    36094: {"Unified_Ideograph", "Ideographic"},
    36095: {"Unified_Ideograph", "Ideographic"},
    36096: {"Unified_Ideograph", "Ideographic"},
    36097: {"Unified_Ideograph", "Ideographic"},
    36098: {"Unified_Ideograph", "Ideographic"},
    36099: {"Unified_Ideograph", "Ideographic"},
    36100: {"Unified_Ideograph", "Ideographic"},
    36101: {"Unified_Ideograph", "Ideographic"},
    36102: {"Unified_Ideograph", "Ideographic"},
    36103: {"Unified_Ideograph", "Ideographic"},
    36104: {"Unified_Ideograph", "Ideographic"},
    36105: {"Unified_Ideograph", "Ideographic"},
    36106: {"Unified_Ideograph", "Ideographic"},
    36107: {"Unified_Ideograph", "Ideographic"},
    36108: {"Unified_Ideograph", "Ideographic"},
    36109: {"Unified_Ideograph", "Ideographic"},
    36110: {"Unified_Ideograph", "Ideographic"},
    36111: {"Unified_Ideograph", "Ideographic"},
    36112: {"Unified_Ideograph", "Ideographic"},
    36113: {"Unified_Ideograph", "Ideographic"},
    36114: {"Unified_Ideograph", "Ideographic"},
    36115: {"Unified_Ideograph", "Ideographic"},
    36116: {"Unified_Ideograph", "Ideographic"},
    36117: {"Unified_Ideograph", "Ideographic"},
    36118: {"Unified_Ideograph", "Ideographic"},
    36119: {"Unified_Ideograph", "Ideographic"},
    36120: {"Unified_Ideograph", "Ideographic"},
    36121: {"Unified_Ideograph", "Ideographic"},
    36122: {"Unified_Ideograph", "Ideographic"},
    36123: {"Unified_Ideograph", "Ideographic"},
    36124: {"Unified_Ideograph", "Ideographic"},
    36125: {"Unified_Ideograph", "Ideographic"},
    36126: {"Unified_Ideograph", "Ideographic"},
    36127: {"Unified_Ideograph", "Ideographic"},
    36128: {"Unified_Ideograph", "Ideographic"},
    36129: {"Unified_Ideograph", "Ideographic"},
    36130: {"Unified_Ideograph", "Ideographic"},
    36131: {"Unified_Ideograph", "Ideographic"},
    36132: {"Unified_Ideograph", "Ideographic"},
    36133: {"Unified_Ideograph", "Ideographic"},
    36134: {"Unified_Ideograph", "Ideographic"},
    36135: {"Unified_Ideograph", "Ideographic"},
    36136: {"Unified_Ideograph", "Ideographic"},
    36137: {"Unified_Ideograph", "Ideographic"},
    36138: {"Unified_Ideograph", "Ideographic"},
    36139: {"Unified_Ideograph", "Ideographic"},
    36140: {"Unified_Ideograph", "Ideographic"},
    36141: {"Unified_Ideograph", "Ideographic"},
    36142: {"Unified_Ideograph", "Ideographic"},
    36143: {"Unified_Ideograph", "Ideographic"},
    36144: {"Unified_Ideograph", "Ideographic"},
    36145: {"Unified_Ideograph", "Ideographic"},
    36146: {"Unified_Ideograph", "Ideographic"},
    36147: {"Unified_Ideograph", "Ideographic"},
    36148: {"Unified_Ideograph", "Ideographic"},
    36149: {"Unified_Ideograph", "Ideographic"},
    36150: {"Unified_Ideograph", "Ideographic"},
    36151: {"Unified_Ideograph", "Ideographic"},
    36152: {"Unified_Ideograph", "Ideographic"},
    36153: {"Unified_Ideograph", "Ideographic"},
    36154: {"Unified_Ideograph", "Ideographic"},
    36155: {"Unified_Ideograph", "Ideographic"},
    36156: {"Unified_Ideograph", "Ideographic"},
    36157: {"Unified_Ideograph", "Ideographic"},
    36158: {"Unified_Ideograph", "Ideographic"},
    36159: {"Unified_Ideograph", "Ideographic"},
    36160: {"Unified_Ideograph", "Ideographic"},
    36161: {"Unified_Ideograph", "Ideographic"},
    36162: {"Unified_Ideograph", "Ideographic"},
    36163: {"Unified_Ideograph", "Ideographic"},
    36164: {"Unified_Ideograph", "Ideographic"},
    36165: {"Unified_Ideograph", "Ideographic"},
    36166: {"Unified_Ideograph", "Ideographic"},
    36167: {"Unified_Ideograph", "Ideographic"},
    36168: {"Unified_Ideograph", "Ideographic"},
    36169: {"Unified_Ideograph", "Ideographic"},
    36170: {"Unified_Ideograph", "Ideographic"},
    36171: {"Unified_Ideograph", "Ideographic"},
    36172: {"Unified_Ideograph", "Ideographic"},
    36173: {"Unified_Ideograph", "Ideographic"},
    36174: {"Unified_Ideograph", "Ideographic"},
    36175: {"Unified_Ideograph", "Ideographic"},
    36176: {"Unified_Ideograph", "Ideographic"},
    36177: {"Unified_Ideograph", "Ideographic"},
    36178: {"Unified_Ideograph", "Ideographic"},
    36179: {"Unified_Ideograph", "Ideographic"},
    36180: {"Unified_Ideograph", "Ideographic"},
    36181: {"Unified_Ideograph", "Ideographic"},
    36182: {"Unified_Ideograph", "Ideographic"},
    36183: {"Unified_Ideograph", "Ideographic"},
    36184: {"Unified_Ideograph", "Ideographic"},
    36185: {"Unified_Ideograph", "Ideographic"},
    36186: {"Unified_Ideograph", "Ideographic"},
    36187: {"Unified_Ideograph", "Ideographic"},
    36188: {"Unified_Ideograph", "Ideographic"},
    36189: {"Unified_Ideograph", "Ideographic"},
    36190: {"Unified_Ideograph", "Ideographic"},
    36191: {"Unified_Ideograph", "Ideographic"},
    36192: {"Unified_Ideograph", "Ideographic"},
    36193: {"Unified_Ideograph", "Ideographic"},
    36194: {"Unified_Ideograph", "Ideographic"},
    36195: {"Unified_Ideograph", "Ideographic"},
    36196: {"Unified_Ideograph", "Ideographic"},
    36197: {"Unified_Ideograph", "Ideographic"},
    36198: {"Unified_Ideograph", "Ideographic"},
    36199: {"Unified_Ideograph", "Ideographic"},
    36200: {"Unified_Ideograph", "Ideographic"},
    36201: {"Unified_Ideograph", "Ideographic"},
    36202: {"Unified_Ideograph", "Ideographic"},
    36203: {"Unified_Ideograph", "Ideographic"},
    36204: {"Unified_Ideograph", "Ideographic"},
    36205: {"Unified_Ideograph", "Ideographic"},
    36206: {"Unified_Ideograph", "Ideographic"},
    36207: {"Unified_Ideograph", "Ideographic"},
    36208: {"Unified_Ideograph", "Ideographic"},
    36209: {"Unified_Ideograph", "Ideographic"},
    36210: {"Unified_Ideograph", "Ideographic"},
    36211: {"Unified_Ideograph", "Ideographic"},
    36212: {"Unified_Ideograph", "Ideographic"},
    36213: {"Unified_Ideograph", "Ideographic"},
    36214: {"Unified_Ideograph", "Ideographic"},
    36215: {"Unified_Ideograph", "Ideographic"},
    36216: {"Unified_Ideograph", "Ideographic"},
    36217: {"Unified_Ideograph", "Ideographic"},
    36218: {"Unified_Ideograph", "Ideographic"},
    36219: {"Unified_Ideograph", "Ideographic"},
    36220: {"Unified_Ideograph", "Ideographic"},
    36221: {"Unified_Ideograph", "Ideographic"},
    36222: {"Unified_Ideograph", "Ideographic"},
    36223: {"Unified_Ideograph", "Ideographic"},
    36224: {"Unified_Ideograph", "Ideographic"},
    36225: {"Unified_Ideograph", "Ideographic"},
    36226: {"Unified_Ideograph", "Ideographic"},
    36227: {"Unified_Ideograph", "Ideographic"},
    36228: {"Unified_Ideograph", "Ideographic"},
    36229: {"Unified_Ideograph", "Ideographic"},
    36230: {"Unified_Ideograph", "Ideographic"},
    36231: {"Unified_Ideograph", "Ideographic"},
    36232: {"Unified_Ideograph", "Ideographic"},
    36233: {"Unified_Ideograph", "Ideographic"},
    36234: {"Unified_Ideograph", "Ideographic"},
    36235: {"Unified_Ideograph", "Ideographic"},
    36236: {"Unified_Ideograph", "Ideographic"},
    36237: {"Unified_Ideograph", "Ideographic"},
    36238: {"Unified_Ideograph", "Ideographic"},
    36239: {"Unified_Ideograph", "Ideographic"},
    36240: {"Unified_Ideograph", "Ideographic"},
    36241: {"Unified_Ideograph", "Ideographic"},
    36242: {"Unified_Ideograph", "Ideographic"},
    36243: {"Unified_Ideograph", "Ideographic"},
    36244: {"Unified_Ideograph", "Ideographic"},
    36245: {"Unified_Ideograph", "Ideographic"},
    36246: {"Unified_Ideograph", "Ideographic"},
    36247: {"Unified_Ideograph", "Ideographic"},
    36248: {"Unified_Ideograph", "Ideographic"},
    36249: {"Unified_Ideograph", "Ideographic"},
    36250: {"Unified_Ideograph", "Ideographic"},
    36251: {"Unified_Ideograph", "Ideographic"},
    36252: {"Unified_Ideograph", "Ideographic"},
    36253: {"Unified_Ideograph", "Ideographic"},
    36254: {"Unified_Ideograph", "Ideographic"},
    36255: {"Unified_Ideograph", "Ideographic"},
    36256: {"Unified_Ideograph", "Ideographic"},
    36257: {"Unified_Ideograph", "Ideographic"},
    36258: {"Unified_Ideograph", "Ideographic"},
    36259: {"Unified_Ideograph", "Ideographic"},
    36260: {"Unified_Ideograph", "Ideographic"},
    36261: {"Unified_Ideograph", "Ideographic"},
    36262: {"Unified_Ideograph", "Ideographic"},
    36263: {"Unified_Ideograph", "Ideographic"},
    36264: {"Unified_Ideograph", "Ideographic"},
    36265: {"Unified_Ideograph", "Ideographic"},
    36266: {"Unified_Ideograph", "Ideographic"},
    36267: {"Unified_Ideograph", "Ideographic"},
    36268: {"Unified_Ideograph", "Ideographic"},
    36269: {"Unified_Ideograph", "Ideographic"},
    36270: {"Unified_Ideograph", "Ideographic"},
    36271: {"Unified_Ideograph", "Ideographic"},
    36272: {"Unified_Ideograph", "Ideographic"},
    36273: {"Unified_Ideograph", "Ideographic"},
    36274: {"Unified_Ideograph", "Ideographic"},
    36275: {"Unified_Ideograph", "Ideographic"},
    36276: {"Unified_Ideograph", "Ideographic"},
    36277: {"Unified_Ideograph", "Ideographic"},
    36278: {"Unified_Ideograph", "Ideographic"},
    36279: {"Unified_Ideograph", "Ideographic"},
    36280: {"Unified_Ideograph", "Ideographic"},
    36281: {"Unified_Ideograph", "Ideographic"},
    36282: {"Unified_Ideograph", "Ideographic"},
    36283: {"Unified_Ideograph", "Ideographic"},
    36284: {"Unified_Ideograph", "Ideographic"},
    36285: {"Unified_Ideograph", "Ideographic"},
    36286: {"Unified_Ideograph", "Ideographic"},
    36287: {"Unified_Ideograph", "Ideographic"},
    36288: {"Unified_Ideograph", "Ideographic"},
    36289: {"Unified_Ideograph", "Ideographic"},
    36290: {"Unified_Ideograph", "Ideographic"},
    36291: {"Unified_Ideograph", "Ideographic"},
    36292: {"Unified_Ideograph", "Ideographic"},
    36293: {"Unified_Ideograph", "Ideographic"},
    36294: {"Unified_Ideograph", "Ideographic"},
    36295: {"Unified_Ideograph", "Ideographic"},
    36296: {"Unified_Ideograph", "Ideographic"},
    36297: {"Unified_Ideograph", "Ideographic"},
    36298: {"Unified_Ideograph", "Ideographic"},
    36299: {"Unified_Ideograph", "Ideographic"},
    36300: {"Unified_Ideograph", "Ideographic"},
    36301: {"Unified_Ideograph", "Ideographic"},
    36302: {"Unified_Ideograph", "Ideographic"},
    36303: {"Unified_Ideograph", "Ideographic"},
    36304: {"Unified_Ideograph", "Ideographic"},
    36305: {"Unified_Ideograph", "Ideographic"},
    36306: {"Unified_Ideograph", "Ideographic"},
    36307: {"Unified_Ideograph", "Ideographic"},
    36308: {"Unified_Ideograph", "Ideographic"},
    36309: {"Unified_Ideograph", "Ideographic"},
    36310: {"Unified_Ideograph", "Ideographic"},
    36311: {"Unified_Ideograph", "Ideographic"},
    36312: {"Unified_Ideograph", "Ideographic"},
    36313: {"Unified_Ideograph", "Ideographic"},
    36314: {"Unified_Ideograph", "Ideographic"},
    36315: {"Unified_Ideograph", "Ideographic"},
    36316: {"Unified_Ideograph", "Ideographic"},
    36317: {"Unified_Ideograph", "Ideographic"},
    36318: {"Unified_Ideograph", "Ideographic"},
    36319: {"Unified_Ideograph", "Ideographic"},
    36320: {"Unified_Ideograph", "Ideographic"},
    36321: {"Unified_Ideograph", "Ideographic"},
    36322: {"Unified_Ideograph", "Ideographic"},
    36323: {"Unified_Ideograph", "Ideographic"},
    36324: {"Unified_Ideograph", "Ideographic"},
    36325: {"Unified_Ideograph", "Ideographic"},
    36326: {"Unified_Ideograph", "Ideographic"},
    36327: {"Unified_Ideograph", "Ideographic"},
    36328: {"Unified_Ideograph", "Ideographic"},
    36329: {"Unified_Ideograph", "Ideographic"},
    36330: {"Unified_Ideograph", "Ideographic"},
    36331: {"Unified_Ideograph", "Ideographic"},
    36332: {"Unified_Ideograph", "Ideographic"},
    36333: {"Unified_Ideograph", "Ideographic"},
    36334: {"Unified_Ideograph", "Ideographic"},
    36335: {"Unified_Ideograph", "Ideographic"},
    36336: {"Unified_Ideograph", "Ideographic"},
    36337: {"Unified_Ideograph", "Ideographic"},
    36338: {"Unified_Ideograph", "Ideographic"},
    36339: {"Unified_Ideograph", "Ideographic"},
    36340: {"Unified_Ideograph", "Ideographic"},
    36341: {"Unified_Ideograph", "Ideographic"},
    36342: {"Unified_Ideograph", "Ideographic"},
    36343: {"Unified_Ideograph", "Ideographic"},
    36344: {"Unified_Ideograph", "Ideographic"},
    36345: {"Unified_Ideograph", "Ideographic"},
    36346: {"Unified_Ideograph", "Ideographic"},
    36347: {"Unified_Ideograph", "Ideographic"},
    36348: {"Unified_Ideograph", "Ideographic"},
    36349: {"Unified_Ideograph", "Ideographic"},
    36350: {"Unified_Ideograph", "Ideographic"},
    36351: {"Unified_Ideograph", "Ideographic"},
    36352: {"Unified_Ideograph", "Ideographic"},
    36353: {"Unified_Ideograph", "Ideographic"},
    36354: {"Unified_Ideograph", "Ideographic"},
    36355: {"Unified_Ideograph", "Ideographic"},
    36356: {"Unified_Ideograph", "Ideographic"},
    36357: {"Unified_Ideograph", "Ideographic"},
    36358: {"Unified_Ideograph", "Ideographic"},
    36359: {"Unified_Ideograph", "Ideographic"},
    36360: {"Unified_Ideograph", "Ideographic"},
    36361: {"Unified_Ideograph", "Ideographic"},
    36362: {"Unified_Ideograph", "Ideographic"},
    36363: {"Unified_Ideograph", "Ideographic"},
    36364: {"Unified_Ideograph", "Ideographic"},
    36365: {"Unified_Ideograph", "Ideographic"},
    36366: {"Unified_Ideograph", "Ideographic"},
    36367: {"Unified_Ideograph", "Ideographic"},
    36368: {"Unified_Ideograph", "Ideographic"},
    36369: {"Unified_Ideograph", "Ideographic"},
    36370: {"Unified_Ideograph", "Ideographic"},
    36371: {"Unified_Ideograph", "Ideographic"},
    36372: {"Unified_Ideograph", "Ideographic"},
    36373: {"Unified_Ideograph", "Ideographic"},
    36374: {"Unified_Ideograph", "Ideographic"},
    36375: {"Unified_Ideograph", "Ideographic"},
    36376: {"Unified_Ideograph", "Ideographic"},
    36377: {"Unified_Ideograph", "Ideographic"},
    36378: {"Unified_Ideograph", "Ideographic"},
    36379: {"Unified_Ideograph", "Ideographic"},
    36380: {"Unified_Ideograph", "Ideographic"},
    36381: {"Unified_Ideograph", "Ideographic"},
    36382: {"Unified_Ideograph", "Ideographic"},
    36383: {"Unified_Ideograph", "Ideographic"},
    36384: {"Unified_Ideograph", "Ideographic"},
    36385: {"Unified_Ideograph", "Ideographic"},
    36386: {"Unified_Ideograph", "Ideographic"},
    36387: {"Unified_Ideograph", "Ideographic"},
    36388: {"Unified_Ideograph", "Ideographic"},
    36389: {"Unified_Ideograph", "Ideographic"},
    36390: {"Unified_Ideograph", "Ideographic"},
    36391: {"Unified_Ideograph", "Ideographic"},
    36392: {"Unified_Ideograph", "Ideographic"},
    36393: {"Unified_Ideograph", "Ideographic"},
    36394: {"Unified_Ideograph", "Ideographic"},
    36395: {"Unified_Ideograph", "Ideographic"},
    36396: {"Unified_Ideograph", "Ideographic"},
    36397: {"Unified_Ideograph", "Ideographic"},
    36398: {"Unified_Ideograph", "Ideographic"},
    36399: {"Unified_Ideograph", "Ideographic"},
    36400: {"Unified_Ideograph", "Ideographic"},
    36401: {"Unified_Ideograph", "Ideographic"},
    36402: {"Unified_Ideograph", "Ideographic"},
    36403: {"Unified_Ideograph", "Ideographic"},
    36404: {"Unified_Ideograph", "Ideographic"},
    36405: {"Unified_Ideograph", "Ideographic"},
    36406: {"Unified_Ideograph", "Ideographic"},
    36407: {"Unified_Ideograph", "Ideographic"},
    36408: {"Unified_Ideograph", "Ideographic"},
    36409: {"Unified_Ideograph", "Ideographic"},
    36410: {"Unified_Ideograph", "Ideographic"},
    36411: {"Unified_Ideograph", "Ideographic"},
    36412: {"Unified_Ideograph", "Ideographic"},
    36413: {"Unified_Ideograph", "Ideographic"},
    36414: {"Unified_Ideograph", "Ideographic"},
    36415: {"Unified_Ideograph", "Ideographic"},
    36416: {"Unified_Ideograph", "Ideographic"},
    36417: {"Unified_Ideograph", "Ideographic"},
    36418: {"Unified_Ideograph", "Ideographic"},
    36419: {"Unified_Ideograph", "Ideographic"},
    36420: {"Unified_Ideograph", "Ideographic"},
    36421: {"Unified_Ideograph", "Ideographic"},
    36422: {"Unified_Ideograph", "Ideographic"},
    36423: {"Unified_Ideograph", "Ideographic"},
    36424: {"Unified_Ideograph", "Ideographic"},
    36425: {"Unified_Ideograph", "Ideographic"},
    36426: {"Unified_Ideograph", "Ideographic"},
    36427: {"Unified_Ideograph", "Ideographic"},
    36428: {"Unified_Ideograph", "Ideographic"},
    36429: {"Unified_Ideograph", "Ideographic"},
    36430: {"Unified_Ideograph", "Ideographic"},
    36431: {"Unified_Ideograph", "Ideographic"},
    36432: {"Unified_Ideograph", "Ideographic"},
    36433: {"Unified_Ideograph", "Ideographic"},
    36434: {"Unified_Ideograph", "Ideographic"},
    36435: {"Unified_Ideograph", "Ideographic"},
    36436: {"Unified_Ideograph", "Ideographic"},
    36437: {"Unified_Ideograph", "Ideographic"},
    36438: {"Unified_Ideograph", "Ideographic"},
    36439: {"Unified_Ideograph", "Ideographic"},
    36440: {"Unified_Ideograph", "Ideographic"},
    36441: {"Unified_Ideograph", "Ideographic"},
    36442: {"Unified_Ideograph", "Ideographic"},
    36443: {"Unified_Ideograph", "Ideographic"},
    36444: {"Unified_Ideograph", "Ideographic"},
    36445: {"Unified_Ideograph", "Ideographic"},
    36446: {"Unified_Ideograph", "Ideographic"},
    36447: {"Unified_Ideograph", "Ideographic"},
    36448: {"Unified_Ideograph", "Ideographic"},
    36449: {"Unified_Ideograph", "Ideographic"},
    36450: {"Unified_Ideograph", "Ideographic"},
    36451: {"Unified_Ideograph", "Ideographic"},
    36452: {"Unified_Ideograph", "Ideographic"},
    36453: {"Unified_Ideograph", "Ideographic"},
    36454: {"Unified_Ideograph", "Ideographic"},
    36455: {"Unified_Ideograph", "Ideographic"},
    36456: {"Unified_Ideograph", "Ideographic"},
    36457: {"Unified_Ideograph", "Ideographic"},
    36458: {"Unified_Ideograph", "Ideographic"},
    36459: {"Unified_Ideograph", "Ideographic"},
    36460: {"Unified_Ideograph", "Ideographic"},
    36461: {"Unified_Ideograph", "Ideographic"},
    36462: {"Unified_Ideograph", "Ideographic"},
    36463: {"Unified_Ideograph", "Ideographic"},
    36464: {"Unified_Ideograph", "Ideographic"},
    36465: {"Unified_Ideograph", "Ideographic"},
    36466: {"Unified_Ideograph", "Ideographic"},
    36467: {"Unified_Ideograph", "Ideographic"},
    36468: {"Unified_Ideograph", "Ideographic"},
    36469: {"Unified_Ideograph", "Ideographic"},
    36470: {"Unified_Ideograph", "Ideographic"},
    36471: {"Unified_Ideograph", "Ideographic"},
    36472: {"Unified_Ideograph", "Ideographic"},
    36473: {"Unified_Ideograph", "Ideographic"},
    36474: {"Unified_Ideograph", "Ideographic"},
    36475: {"Unified_Ideograph", "Ideographic"},
    36476: {"Unified_Ideograph", "Ideographic"},
    36477: {"Unified_Ideograph", "Ideographic"},
    36478: {"Unified_Ideograph", "Ideographic"},
    36479: {"Unified_Ideograph", "Ideographic"},
    36480: {"Unified_Ideograph", "Ideographic"},
    36481: {"Unified_Ideograph", "Ideographic"},
    36482: {"Unified_Ideograph", "Ideographic"},
    36483: {"Unified_Ideograph", "Ideographic"},
    36484: {"Unified_Ideograph", "Ideographic"},
    36485: {"Unified_Ideograph", "Ideographic"},
    36486: {"Unified_Ideograph", "Ideographic"},
    36487: {"Unified_Ideograph", "Ideographic"},
    36488: {"Unified_Ideograph", "Ideographic"},
    36489: {"Unified_Ideograph", "Ideographic"},
    36490: {"Unified_Ideograph", "Ideographic"},
    36491: {"Unified_Ideograph", "Ideographic"},
    36492: {"Unified_Ideograph", "Ideographic"},
    36493: {"Unified_Ideograph", "Ideographic"},
    36494: {"Unified_Ideograph", "Ideographic"},
    36495: {"Unified_Ideograph", "Ideographic"},
    36496: {"Unified_Ideograph", "Ideographic"},
    36497: {"Unified_Ideograph", "Ideographic"},
    36498: {"Unified_Ideograph", "Ideographic"},
    36499: {"Unified_Ideograph", "Ideographic"},
    36500: {"Unified_Ideograph", "Ideographic"},
    36501: {"Unified_Ideograph", "Ideographic"},
    36502: {"Unified_Ideograph", "Ideographic"},
    36503: {"Unified_Ideograph", "Ideographic"},
    36504: {"Unified_Ideograph", "Ideographic"},
    36505: {"Unified_Ideograph", "Ideographic"},
    36506: {"Unified_Ideograph", "Ideographic"},
    36507: {"Unified_Ideograph", "Ideographic"},
    36508: {"Unified_Ideograph", "Ideographic"},
    36509: {"Unified_Ideograph", "Ideographic"},
    36510: {"Unified_Ideograph", "Ideographic"},
    36511: {"Unified_Ideograph", "Ideographic"},
    36512: {"Unified_Ideograph", "Ideographic"},
    36513: {"Unified_Ideograph", "Ideographic"},
    36514: {"Unified_Ideograph", "Ideographic"},
    36515: {"Unified_Ideograph", "Ideographic"},
    36516: {"Unified_Ideograph", "Ideographic"},
    36517: {"Unified_Ideograph", "Ideographic"},
    36518: {"Unified_Ideograph", "Ideographic"},
    36519: {"Unified_Ideograph", "Ideographic"},
    36520: {"Unified_Ideograph", "Ideographic"},
    36521: {"Unified_Ideograph", "Ideographic"},
    36522: {"Unified_Ideograph", "Ideographic"},
    36523: {"Unified_Ideograph", "Ideographic"},
    36524: {"Unified_Ideograph", "Ideographic"},
    36525: {"Unified_Ideograph", "Ideographic"},
    36526: {"Unified_Ideograph", "Ideographic"},
    36527: {"Unified_Ideograph", "Ideographic"},
    36528: {"Unified_Ideograph", "Ideographic"},
    36529: {"Unified_Ideograph", "Ideographic"},
    36530: {"Unified_Ideograph", "Ideographic"},
    36531: {"Unified_Ideograph", "Ideographic"},
    36532: {"Unified_Ideograph", "Ideographic"},
    36533: {"Unified_Ideograph", "Ideographic"},
    36534: {"Unified_Ideograph", "Ideographic"},
    36535: {"Unified_Ideograph", "Ideographic"},
    36536: {"Unified_Ideograph", "Ideographic"},
    36537: {"Unified_Ideograph", "Ideographic"},
    36538: {"Unified_Ideograph", "Ideographic"},
    36539: {"Unified_Ideograph", "Ideographic"},
    36540: {"Unified_Ideograph", "Ideographic"},
    36541: {"Unified_Ideograph", "Ideographic"},
    36542: {"Unified_Ideograph", "Ideographic"},
    36543: {"Unified_Ideograph", "Ideographic"},
    36544: {"Unified_Ideograph", "Ideographic"},
    36545: {"Unified_Ideograph", "Ideographic"},
    36546: {"Unified_Ideograph", "Ideographic"},
    36547: {"Unified_Ideograph", "Ideographic"},
    36548: {"Unified_Ideograph", "Ideographic"},
    36549: {"Unified_Ideograph", "Ideographic"},
    36550: {"Unified_Ideograph", "Ideographic"},
    36551: {"Unified_Ideograph", "Ideographic"},
    36552: {"Unified_Ideograph", "Ideographic"},
    36553: {"Unified_Ideograph", "Ideographic"},
    36554: {"Unified_Ideograph", "Ideographic"},
    36555: {"Unified_Ideograph", "Ideographic"},
    36556: {"Unified_Ideograph", "Ideographic"},
    36557: {"Unified_Ideograph", "Ideographic"},
    36558: {"Unified_Ideograph", "Ideographic"},
    36559: {"Unified_Ideograph", "Ideographic"},
    36560: {"Unified_Ideograph", "Ideographic"},
    36561: {"Unified_Ideograph", "Ideographic"},
    36562: {"Unified_Ideograph", "Ideographic"},
    36563: {"Unified_Ideograph", "Ideographic"},
    36564: {"Unified_Ideograph", "Ideographic"},
    36565: {"Unified_Ideograph", "Ideographic"},
    36566: {"Unified_Ideograph", "Ideographic"},
    36567: {"Unified_Ideograph", "Ideographic"},
    36568: {"Unified_Ideograph", "Ideographic"},
    36569: {"Unified_Ideograph", "Ideographic"},
    36570: {"Unified_Ideograph", "Ideographic"},
    36571: {"Unified_Ideograph", "Ideographic"},
    36572: {"Unified_Ideograph", "Ideographic"},
    36573: {"Unified_Ideograph", "Ideographic"},
    36574: {"Unified_Ideograph", "Ideographic"},
    36575: {"Unified_Ideograph", "Ideographic"},
    36576: {"Unified_Ideograph", "Ideographic"},
    36577: {"Unified_Ideograph", "Ideographic"},
    36578: {"Unified_Ideograph", "Ideographic"},
    36579: {"Unified_Ideograph", "Ideographic"},
    36580: {"Unified_Ideograph", "Ideographic"},
    36581: {"Unified_Ideograph", "Ideographic"},
    36582: {"Unified_Ideograph", "Ideographic"},
    36583: {"Unified_Ideograph", "Ideographic"},
    36584: {"Unified_Ideograph", "Ideographic"},
    36585: {"Unified_Ideograph", "Ideographic"},
    36586: {"Unified_Ideograph", "Ideographic"},
    36587: {"Unified_Ideograph", "Ideographic"},
    36588: {"Unified_Ideograph", "Ideographic"},
    36589: {"Unified_Ideograph", "Ideographic"},
    36590: {"Unified_Ideograph", "Ideographic"},
    36591: {"Unified_Ideograph", "Ideographic"},
    36592: {"Unified_Ideograph", "Ideographic"},
    36593: {"Unified_Ideograph", "Ideographic"},
    36594: {"Unified_Ideograph", "Ideographic"},
    36595: {"Unified_Ideograph", "Ideographic"},
    36596: {"Unified_Ideograph", "Ideographic"},
    36597: {"Unified_Ideograph", "Ideographic"},
    36598: {"Unified_Ideograph", "Ideographic"},
    36599: {"Unified_Ideograph", "Ideographic"},
    36600: {"Unified_Ideograph", "Ideographic"},
    36601: {"Unified_Ideograph", "Ideographic"},
    36602: {"Unified_Ideograph", "Ideographic"},
    36603: {"Unified_Ideograph", "Ideographic"},
    36604: {"Unified_Ideograph", "Ideographic"},
    36605: {"Unified_Ideograph", "Ideographic"},
    36606: {"Unified_Ideograph", "Ideographic"},
    36607: {"Unified_Ideograph", "Ideographic"},
    36608: {"Unified_Ideograph", "Ideographic"},
    36609: {"Unified_Ideograph", "Ideographic"},
    36610: {"Unified_Ideograph", "Ideographic"},
    36611: {"Unified_Ideograph", "Ideographic"},
    36612: {"Unified_Ideograph", "Ideographic"},
    36613: {"Unified_Ideograph", "Ideographic"},
    36614: {"Unified_Ideograph", "Ideographic"},
    36615: {"Unified_Ideograph", "Ideographic"},
    36616: {"Unified_Ideograph", "Ideographic"},
    36617: {"Unified_Ideograph", "Ideographic"},
    36618: {"Unified_Ideograph", "Ideographic"},
    36619: {"Unified_Ideograph", "Ideographic"},
    36620: {"Unified_Ideograph", "Ideographic"},
    36621: {"Unified_Ideograph", "Ideographic"},
    36622: {"Unified_Ideograph", "Ideographic"},
    36623: {"Unified_Ideograph", "Ideographic"},
    36624: {"Unified_Ideograph", "Ideographic"},
    36625: {"Unified_Ideograph", "Ideographic"},
    36626: {"Unified_Ideograph", "Ideographic"},
    36627: {"Unified_Ideograph", "Ideographic"},
    36628: {"Unified_Ideograph", "Ideographic"},
    36629: {"Unified_Ideograph", "Ideographic"},
    36630: {"Unified_Ideograph", "Ideographic"},
    36631: {"Unified_Ideograph", "Ideographic"},
    36632: {"Unified_Ideograph", "Ideographic"},
    36633: {"Unified_Ideograph", "Ideographic"},
    36634: {"Unified_Ideograph", "Ideographic"},
    36635: {"Unified_Ideograph", "Ideographic"},
    36636: {"Unified_Ideograph", "Ideographic"},
    36637: {"Unified_Ideograph", "Ideographic"},
    36638: {"Unified_Ideograph", "Ideographic"},
    36639: {"Unified_Ideograph", "Ideographic"},
    36640: {"Unified_Ideograph", "Ideographic"},
    36641: {"Unified_Ideograph", "Ideographic"},
    36642: {"Unified_Ideograph", "Ideographic"},
    36643: {"Unified_Ideograph", "Ideographic"},
    36644: {"Unified_Ideograph", "Ideographic"},
    36645: {"Unified_Ideograph", "Ideographic"},
    36646: {"Unified_Ideograph", "Ideographic"},
    36647: {"Unified_Ideograph", "Ideographic"},
    36648: {"Unified_Ideograph", "Ideographic"},
    36649: {"Unified_Ideograph", "Ideographic"},
    36650: {"Unified_Ideograph", "Ideographic"},
    36651: {"Unified_Ideograph", "Ideographic"},
    36652: {"Unified_Ideograph", "Ideographic"},
    36653: {"Unified_Ideograph", "Ideographic"},
    36654: {"Unified_Ideograph", "Ideographic"},
    36655: {"Unified_Ideograph", "Ideographic"},
    36656: {"Unified_Ideograph", "Ideographic"},
    36657: {"Unified_Ideograph", "Ideographic"},
    36658: {"Unified_Ideograph", "Ideographic"},
    36659: {"Unified_Ideograph", "Ideographic"},
    36660: {"Unified_Ideograph", "Ideographic"},
    36661: {"Unified_Ideograph", "Ideographic"},
    36662: {"Unified_Ideograph", "Ideographic"},
    36663: {"Unified_Ideograph", "Ideographic"},
    36664: {"Unified_Ideograph", "Ideographic"},
    36665: {"Unified_Ideograph", "Ideographic"},
    36666: {"Unified_Ideograph", "Ideographic"},
    36667: {"Unified_Ideograph", "Ideographic"},
    36668: {"Unified_Ideograph", "Ideographic"},
    36669: {"Unified_Ideograph", "Ideographic"},
    36670: {"Unified_Ideograph", "Ideographic"},
    36671: {"Unified_Ideograph", "Ideographic"},
    36672: {"Unified_Ideograph", "Ideographic"},
    36673: {"Unified_Ideograph", "Ideographic"},
    36674: {"Unified_Ideograph", "Ideographic"},
    36675: {"Unified_Ideograph", "Ideographic"},
    36676: {"Unified_Ideograph", "Ideographic"},
    36677: {"Unified_Ideograph", "Ideographic"},
    36678: {"Unified_Ideograph", "Ideographic"},
    36679: {"Unified_Ideograph", "Ideographic"},
    36680: {"Unified_Ideograph", "Ideographic"},
    36681: {"Unified_Ideograph", "Ideographic"},
    36682: {"Unified_Ideograph", "Ideographic"},
    36683: {"Unified_Ideograph", "Ideographic"},
    36684: {"Unified_Ideograph", "Ideographic"},
    36685: {"Unified_Ideograph", "Ideographic"},
    36686: {"Unified_Ideograph", "Ideographic"},
    36687: {"Unified_Ideograph", "Ideographic"},
    36688: {"Unified_Ideograph", "Ideographic"},
    36689: {"Unified_Ideograph", "Ideographic"},
    36690: {"Unified_Ideograph", "Ideographic"},
    36691: {"Unified_Ideograph", "Ideographic"},
    36692: {"Unified_Ideograph", "Ideographic"},
    36693: {"Unified_Ideograph", "Ideographic"},
    36694: {"Unified_Ideograph", "Ideographic"},
    36695: {"Unified_Ideograph", "Ideographic"},
    36696: {"Unified_Ideograph", "Ideographic"},
    36697: {"Unified_Ideograph", "Ideographic"},
    36698: {"Unified_Ideograph", "Ideographic"},
    36699: {"Unified_Ideograph", "Ideographic"},
    36700: {"Unified_Ideograph", "Ideographic"},
    36701: {"Unified_Ideograph", "Ideographic"},
    36702: {"Unified_Ideograph", "Ideographic"},
    36703: {"Unified_Ideograph", "Ideographic"},
    36704: {"Unified_Ideograph", "Ideographic"},
    36705: {"Unified_Ideograph", "Ideographic"},
    36706: {"Unified_Ideograph", "Ideographic"},
    36707: {"Unified_Ideograph", "Ideographic"},
    36708: {"Unified_Ideograph", "Ideographic"},
    36709: {"Unified_Ideograph", "Ideographic"},
    36710: {"Unified_Ideograph", "Ideographic"},
    36711: {"Unified_Ideograph", "Ideographic"},
    36712: {"Unified_Ideograph", "Ideographic"},
    36713: {"Unified_Ideograph", "Ideographic"},
    36714: {"Unified_Ideograph", "Ideographic"},
    36715: {"Unified_Ideograph", "Ideographic"},
    36716: {"Unified_Ideograph", "Ideographic"},
    36717: {"Unified_Ideograph", "Ideographic"},
    36718: {"Unified_Ideograph", "Ideographic"},
    36719: {"Unified_Ideograph", "Ideographic"},
    36720: {"Unified_Ideograph", "Ideographic"},
    36721: {"Unified_Ideograph", "Ideographic"},
    36722: {"Unified_Ideograph", "Ideographic"},
    36723: {"Unified_Ideograph", "Ideographic"},
    36724: {"Unified_Ideograph", "Ideographic"},
    36725: {"Unified_Ideograph", "Ideographic"},
    36726: {"Unified_Ideograph", "Ideographic"},
    36727: {"Unified_Ideograph", "Ideographic"},
    36728: {"Unified_Ideograph", "Ideographic"},
    36729: {"Unified_Ideograph", "Ideographic"},
    36730: {"Unified_Ideograph", "Ideographic"},
    36731: {"Unified_Ideograph", "Ideographic"},
    36732: {"Unified_Ideograph", "Ideographic"},
    36733: {"Unified_Ideograph", "Ideographic"},
    36734: {"Unified_Ideograph", "Ideographic"},
    36735: {"Unified_Ideograph", "Ideographic"},
    36736: {"Unified_Ideograph", "Ideographic"},
    36737: {"Unified_Ideograph", "Ideographic"},
    36738: {"Unified_Ideograph", "Ideographic"},
    36739: {"Unified_Ideograph", "Ideographic"},
    36740: {"Unified_Ideograph", "Ideographic"},
    36741: {"Unified_Ideograph", "Ideographic"},
    36742: {"Unified_Ideograph", "Ideographic"},
    36743: {"Unified_Ideograph", "Ideographic"},
    36744: {"Unified_Ideograph", "Ideographic"},
    36745: {"Unified_Ideograph", "Ideographic"},
    36746: {"Unified_Ideograph", "Ideographic"},
    36747: {"Unified_Ideograph", "Ideographic"},
    36748: {"Unified_Ideograph", "Ideographic"},
    36749: {"Unified_Ideograph", "Ideographic"},
    36750: {"Unified_Ideograph", "Ideographic"},
    36751: {"Unified_Ideograph", "Ideographic"},
    36752: {"Unified_Ideograph", "Ideographic"},
    36753: {"Unified_Ideograph", "Ideographic"},
    36754: {"Unified_Ideograph", "Ideographic"},
    36755: {"Unified_Ideograph", "Ideographic"},
    36756: {"Unified_Ideograph", "Ideographic"},
    36757: {"Unified_Ideograph", "Ideographic"},
    36758: {"Unified_Ideograph", "Ideographic"},
    36759: {"Unified_Ideograph", "Ideographic"},
    36760: {"Unified_Ideograph", "Ideographic"},
    36761: {"Unified_Ideograph", "Ideographic"},
    36762: {"Unified_Ideograph", "Ideographic"},
    36763: {"Unified_Ideograph", "Ideographic"},
    36764: {"Unified_Ideograph", "Ideographic"},
    36765: {"Unified_Ideograph", "Ideographic"},
    36766: {"Unified_Ideograph", "Ideographic"},
    36767: {"Unified_Ideograph", "Ideographic"},
    36768: {"Unified_Ideograph", "Ideographic"},
    36769: {"Unified_Ideograph", "Ideographic"},
    36770: {"Unified_Ideograph", "Ideographic"},
    36771: {"Unified_Ideograph", "Ideographic"},
    36772: {"Unified_Ideograph", "Ideographic"},
    36773: {"Unified_Ideograph", "Ideographic"},
    36774: {"Unified_Ideograph", "Ideographic"},
    36775: {"Unified_Ideograph", "Ideographic"},
    36776: {"Unified_Ideograph", "Ideographic"},
    36777: {"Unified_Ideograph", "Ideographic"},
    36778: {"Unified_Ideograph", "Ideographic"},
    36779: {"Unified_Ideograph", "Ideographic"},
    36780: {"Unified_Ideograph", "Ideographic"},
    36781: {"Unified_Ideograph", "Ideographic"},
    36782: {"Unified_Ideograph", "Ideographic"},
    36783: {"Unified_Ideograph", "Ideographic"},
    36784: {"Unified_Ideograph", "Ideographic"},
    36785: {"Unified_Ideograph", "Ideographic"},
    36786: {"Unified_Ideograph", "Ideographic"},
    36787: {"Unified_Ideograph", "Ideographic"},
    36788: {"Unified_Ideograph", "Ideographic"},
    36789: {"Unified_Ideograph", "Ideographic"},
    36790: {"Unified_Ideograph", "Ideographic"},
    36791: {"Unified_Ideograph", "Ideographic"},
    36792: {"Unified_Ideograph", "Ideographic"},
    36793: {"Unified_Ideograph", "Ideographic"},
    36794: {"Unified_Ideograph", "Ideographic"},
    36795: {"Unified_Ideograph", "Ideographic"},
    36796: {"Unified_Ideograph", "Ideographic"},
    36797: {"Unified_Ideograph", "Ideographic"},
    36798: {"Unified_Ideograph", "Ideographic"},
    36799: {"Unified_Ideograph", "Ideographic"},
    36800: {"Unified_Ideograph", "Ideographic"},
    36801: {"Unified_Ideograph", "Ideographic"},
    36802: {"Unified_Ideograph", "Ideographic"},
    36803: {"Unified_Ideograph", "Ideographic"},
    36804: {"Unified_Ideograph", "Ideographic"},
    36805: {"Unified_Ideograph", "Ideographic"},
    36806: {"Unified_Ideograph", "Ideographic"},
    36807: {"Unified_Ideograph", "Ideographic"},
    36808: {"Unified_Ideograph", "Ideographic"},
    36809: {"Unified_Ideograph", "Ideographic"},
    36810: {"Unified_Ideograph", "Ideographic"},
    36811: {"Unified_Ideograph", "Ideographic"},
    36812: {"Unified_Ideograph", "Ideographic"},
    36813: {"Unified_Ideograph", "Ideographic"},
    36814: {"Unified_Ideograph", "Ideographic"},
    36815: {"Unified_Ideograph", "Ideographic"},
    36816: {"Unified_Ideograph", "Ideographic"},
    36817: {"Unified_Ideograph", "Ideographic"},
    36818: {"Unified_Ideograph", "Ideographic"},
    36819: {"Unified_Ideograph", "Ideographic"},
    36820: {"Unified_Ideograph", "Ideographic"},
    36821: {"Unified_Ideograph", "Ideographic"},
    36822: {"Unified_Ideograph", "Ideographic"},
    36823: {"Unified_Ideograph", "Ideographic"},
    36824: {"Unified_Ideograph", "Ideographic"},
    36825: {"Unified_Ideograph", "Ideographic"},
    36826: {"Unified_Ideograph", "Ideographic"},
    36827: {"Unified_Ideograph", "Ideographic"},
    36828: {"Unified_Ideograph", "Ideographic"},
    36829: {"Unified_Ideograph", "Ideographic"},
    36830: {"Unified_Ideograph", "Ideographic"},
    36831: {"Unified_Ideograph", "Ideographic"},
    36832: {"Unified_Ideograph", "Ideographic"},
    36833: {"Unified_Ideograph", "Ideographic"},
    36834: {"Unified_Ideograph", "Ideographic"},
    36835: {"Unified_Ideograph", "Ideographic"},
    36836: {"Unified_Ideograph", "Ideographic"},
    36837: {"Unified_Ideograph", "Ideographic"},
    36838: {"Unified_Ideograph", "Ideographic"},
    36839: {"Unified_Ideograph", "Ideographic"},
    36840: {"Unified_Ideograph", "Ideographic"},
    36841: {"Unified_Ideograph", "Ideographic"},
    36842: {"Unified_Ideograph", "Ideographic"},
    36843: {"Unified_Ideograph", "Ideographic"},
    36844: {"Unified_Ideograph", "Ideographic"},
    36845: {"Unified_Ideograph", "Ideographic"},
    36846: {"Unified_Ideograph", "Ideographic"},
    36847: {"Unified_Ideograph", "Ideographic"},
    36848: {"Unified_Ideograph", "Ideographic"},
    36849: {"Unified_Ideograph", "Ideographic"},
    36850: {"Unified_Ideograph", "Ideographic"},
    36851: {"Unified_Ideograph", "Ideographic"},
    36852: {"Unified_Ideograph", "Ideographic"},
    36853: {"Unified_Ideograph", "Ideographic"},
    36854: {"Unified_Ideograph", "Ideographic"},
    36855: {"Unified_Ideograph", "Ideographic"},
    36856: {"Unified_Ideograph", "Ideographic"},
    36857: {"Unified_Ideograph", "Ideographic"},
    36858: {"Unified_Ideograph", "Ideographic"},
    36859: {"Unified_Ideograph", "Ideographic"},
    36860: {"Unified_Ideograph", "Ideographic"},
    36861: {"Unified_Ideograph", "Ideographic"},
    36862: {"Unified_Ideograph", "Ideographic"},
    36863: {"Unified_Ideograph", "Ideographic"},
    36864: {"Unified_Ideograph", "Ideographic"},
    36865: {"Unified_Ideograph", "Ideographic"},
    36866: {"Unified_Ideograph", "Ideographic"},
    36867: {"Unified_Ideograph", "Ideographic"},
    36868: {"Unified_Ideograph", "Ideographic"},
    36869: {"Unified_Ideograph", "Ideographic"},
    36870: {"Unified_Ideograph", "Ideographic"},
    36871: {"Unified_Ideograph", "Ideographic"},
    36872: {"Unified_Ideograph", "Ideographic"},
    36873: {"Unified_Ideograph", "Ideographic"},
    36874: {"Unified_Ideograph", "Ideographic"},
    36875: {"Unified_Ideograph", "Ideographic"},
    36876: {"Unified_Ideograph", "Ideographic"},
    36877: {"Unified_Ideograph", "Ideographic"},
    36878: {"Unified_Ideograph", "Ideographic"},
    36879: {"Unified_Ideograph", "Ideographic"},
    36880: {"Unified_Ideograph", "Ideographic"},
    36881: {"Unified_Ideograph", "Ideographic"},
    36882: {"Unified_Ideograph", "Ideographic"},
    36883: {"Unified_Ideograph", "Ideographic"},
    36884: {"Unified_Ideograph", "Ideographic"},
    36885: {"Unified_Ideograph", "Ideographic"},
    36886: {"Unified_Ideograph", "Ideographic"},
    36887: {"Unified_Ideograph", "Ideographic"},
    36888: {"Unified_Ideograph", "Ideographic"},
    36889: {"Unified_Ideograph", "Ideographic"},
    36890: {"Unified_Ideograph", "Ideographic"},
    36891: {"Unified_Ideograph", "Ideographic"},
    36892: {"Unified_Ideograph", "Ideographic"},
    36893: {"Unified_Ideograph", "Ideographic"},
    36894: {"Unified_Ideograph", "Ideographic"},
    36895: {"Unified_Ideograph", "Ideographic"},
    36896: {"Unified_Ideograph", "Ideographic"},
    36897: {"Unified_Ideograph", "Ideographic"},
    36898: {"Unified_Ideograph", "Ideographic"},
    36899: {"Unified_Ideograph", "Ideographic"},
    36900: {"Unified_Ideograph", "Ideographic"},
    36901: {"Unified_Ideograph", "Ideographic"},
    36902: {"Unified_Ideograph", "Ideographic"},
    36903: {"Unified_Ideograph", "Ideographic"},
    36904: {"Unified_Ideograph", "Ideographic"},
    36905: {"Unified_Ideograph", "Ideographic"},
    36906: {"Unified_Ideograph", "Ideographic"},
    36907: {"Unified_Ideograph", "Ideographic"},
    36908: {"Unified_Ideograph", "Ideographic"},
    36909: {"Unified_Ideograph", "Ideographic"},
    36910: {"Unified_Ideograph", "Ideographic"},
    36911: {"Unified_Ideograph", "Ideographic"},
    36912: {"Unified_Ideograph", "Ideographic"},
    36913: {"Unified_Ideograph", "Ideographic"},
    36914: {"Unified_Ideograph", "Ideographic"},
    36915: {"Unified_Ideograph", "Ideographic"},
    36916: {"Unified_Ideograph", "Ideographic"},
    36917: {"Unified_Ideograph", "Ideographic"},
    36918: {"Unified_Ideograph", "Ideographic"},
    36919: {"Unified_Ideograph", "Ideographic"},
    36920: {"Unified_Ideograph", "Ideographic"},
    36921: {"Unified_Ideograph", "Ideographic"},
    36922: {"Unified_Ideograph", "Ideographic"},
    36923: {"Unified_Ideograph", "Ideographic"},
    36924: {"Unified_Ideograph", "Ideographic"},
    36925: {"Unified_Ideograph", "Ideographic"},
    36926: {"Unified_Ideograph", "Ideographic"},
    36927: {"Unified_Ideograph", "Ideographic"},
    36928: {"Unified_Ideograph", "Ideographic"},
    36929: {"Unified_Ideograph", "Ideographic"},
    36930: {"Unified_Ideograph", "Ideographic"},
    36931: {"Unified_Ideograph", "Ideographic"},
    36932: {"Unified_Ideograph", "Ideographic"},
    36933: {"Unified_Ideograph", "Ideographic"},
    36934: {"Unified_Ideograph", "Ideographic"},
    36935: {"Unified_Ideograph", "Ideographic"},
    36936: {"Unified_Ideograph", "Ideographic"},
    36937: {"Unified_Ideograph", "Ideographic"},
    36938: {"Unified_Ideograph", "Ideographic"},
    36939: {"Unified_Ideograph", "Ideographic"},
    36940: {"Unified_Ideograph", "Ideographic"},
    36941: {"Unified_Ideograph", "Ideographic"},
    36942: {"Unified_Ideograph", "Ideographic"},
    36943: {"Unified_Ideograph", "Ideographic"},
    36944: {"Unified_Ideograph", "Ideographic"},
    36945: {"Unified_Ideograph", "Ideographic"},
    36946: {"Unified_Ideograph", "Ideographic"},
    36947: {"Unified_Ideograph", "Ideographic"},
    36948: {"Unified_Ideograph", "Ideographic"},
    36949: {"Unified_Ideograph", "Ideographic"},
    36950: {"Unified_Ideograph", "Ideographic"},
    36951: {"Unified_Ideograph", "Ideographic"},
    36952: {"Unified_Ideograph", "Ideographic"},
    36953: {"Unified_Ideograph", "Ideographic"},
    36954: {"Unified_Ideograph", "Ideographic"},
    36955: {"Unified_Ideograph", "Ideographic"},
    36956: {"Unified_Ideograph", "Ideographic"},
    36957: {"Unified_Ideograph", "Ideographic"},
    36958: {"Unified_Ideograph", "Ideographic"},
    36959: {"Unified_Ideograph", "Ideographic"},
    36960: {"Unified_Ideograph", "Ideographic"},
    36961: {"Unified_Ideograph", "Ideographic"},
    36962: {"Unified_Ideograph", "Ideographic"},
    36963: {"Unified_Ideograph", "Ideographic"},
    36964: {"Unified_Ideograph", "Ideographic"},
    36965: {"Unified_Ideograph", "Ideographic"},
    36966: {"Unified_Ideograph", "Ideographic"},
    36967: {"Unified_Ideograph", "Ideographic"},
    36968: {"Unified_Ideograph", "Ideographic"},
    36969: {"Unified_Ideograph", "Ideographic"},
    36970: {"Unified_Ideograph", "Ideographic"},
    36971: {"Unified_Ideograph", "Ideographic"},
    36972: {"Unified_Ideograph", "Ideographic"},
    36973: {"Unified_Ideograph", "Ideographic"},
    36974: {"Unified_Ideograph", "Ideographic"},
    36975: {"Unified_Ideograph", "Ideographic"},
    36976: {"Unified_Ideograph", "Ideographic"},
    36977: {"Unified_Ideograph", "Ideographic"},
    36978: {"Unified_Ideograph", "Ideographic"},
    36979: {"Unified_Ideograph", "Ideographic"},
    36980: {"Unified_Ideograph", "Ideographic"},
    36981: {"Unified_Ideograph", "Ideographic"},
    36982: {"Unified_Ideograph", "Ideographic"},
    36983: {"Unified_Ideograph", "Ideographic"},
    36984: {"Unified_Ideograph", "Ideographic"},
    36985: {"Unified_Ideograph", "Ideographic"},
    36986: {"Unified_Ideograph", "Ideographic"},
    36987: {"Unified_Ideograph", "Ideographic"},
    36988: {"Unified_Ideograph", "Ideographic"},
    36989: {"Unified_Ideograph", "Ideographic"},
    36990: {"Unified_Ideograph", "Ideographic"},
    36991: {"Unified_Ideograph", "Ideographic"},
    36992: {"Unified_Ideograph", "Ideographic"},
    36993: {"Unified_Ideograph", "Ideographic"},
    36994: {"Unified_Ideograph", "Ideographic"},
    36995: {"Unified_Ideograph", "Ideographic"},
    36996: {"Unified_Ideograph", "Ideographic"},
    36997: {"Unified_Ideograph", "Ideographic"},
    36998: {"Unified_Ideograph", "Ideographic"},
    36999: {"Unified_Ideograph", "Ideographic"},
    37000: {"Unified_Ideograph", "Ideographic"},
    37001: {"Unified_Ideograph", "Ideographic"},
    37002: {"Unified_Ideograph", "Ideographic"},
    37003: {"Unified_Ideograph", "Ideographic"},
    37004: {"Unified_Ideograph", "Ideographic"},
    37005: {"Unified_Ideograph", "Ideographic"},
    37006: {"Unified_Ideograph", "Ideographic"},
    37007: {"Unified_Ideograph", "Ideographic"},
    37008: {"Unified_Ideograph", "Ideographic"},
    37009: {"Unified_Ideograph", "Ideographic"},
    37010: {"Unified_Ideograph", "Ideographic"},
    37011: {"Unified_Ideograph", "Ideographic"},
    37012: {"Unified_Ideograph", "Ideographic"},
    37013: {"Unified_Ideograph", "Ideographic"},
    37014: {"Unified_Ideograph", "Ideographic"},
    37015: {"Unified_Ideograph", "Ideographic"},
    37016: {"Unified_Ideograph", "Ideographic"},
    37017: {"Unified_Ideograph", "Ideographic"},
    37018: {"Unified_Ideograph", "Ideographic"},
    37019: {"Unified_Ideograph", "Ideographic"},
    37020: {"Unified_Ideograph", "Ideographic"},
    37021: {"Unified_Ideograph", "Ideographic"},
    37022: {"Unified_Ideograph", "Ideographic"},
    37023: {"Unified_Ideograph", "Ideographic"},
    37024: {"Unified_Ideograph", "Ideographic"},
    37025: {"Unified_Ideograph", "Ideographic"},
    37026: {"Unified_Ideograph", "Ideographic"},
    37027: {"Unified_Ideograph", "Ideographic"},
    37028: {"Unified_Ideograph", "Ideographic"},
    37029: {"Unified_Ideograph", "Ideographic"},
    37030: {"Unified_Ideograph", "Ideographic"},
    37031: {"Unified_Ideograph", "Ideographic"},
    37032: {"Unified_Ideograph", "Ideographic"},
    37033: {"Unified_Ideograph", "Ideographic"},
    37034: {"Unified_Ideograph", "Ideographic"},
    37035: {"Unified_Ideograph", "Ideographic"},
    37036: {"Unified_Ideograph", "Ideographic"},
    37037: {"Unified_Ideograph", "Ideographic"},
    37038: {"Unified_Ideograph", "Ideographic"},
    37039: {"Unified_Ideograph", "Ideographic"},
    37040: {"Unified_Ideograph", "Ideographic"},
    37041: {"Unified_Ideograph", "Ideographic"},
    37042: {"Unified_Ideograph", "Ideographic"},
    37043: {"Unified_Ideograph", "Ideographic"},
    37044: {"Unified_Ideograph", "Ideographic"},
    37045: {"Unified_Ideograph", "Ideographic"},
    37046: {"Unified_Ideograph", "Ideographic"},
    37047: {"Unified_Ideograph", "Ideographic"},
    37048: {"Unified_Ideograph", "Ideographic"},
    37049: {"Unified_Ideograph", "Ideographic"},
    37050: {"Unified_Ideograph", "Ideographic"},
    37051: {"Unified_Ideograph", "Ideographic"},
    37052: {"Unified_Ideograph", "Ideographic"},
    37053: {"Unified_Ideograph", "Ideographic"},
    37054: {"Unified_Ideograph", "Ideographic"},
    37055: {"Unified_Ideograph", "Ideographic"},
    37056: {"Unified_Ideograph", "Ideographic"},
    37057: {"Unified_Ideograph", "Ideographic"},
    37058: {"Unified_Ideograph", "Ideographic"},
    37059: {"Unified_Ideograph", "Ideographic"},
    37060: {"Unified_Ideograph", "Ideographic"},
    37061: {"Unified_Ideograph", "Ideographic"},
    37062: {"Unified_Ideograph", "Ideographic"},
    37063: {"Unified_Ideograph", "Ideographic"},
    37064: {"Unified_Ideograph", "Ideographic"},
    37065: {"Unified_Ideograph", "Ideographic"},
    37066: {"Unified_Ideograph", "Ideographic"},
    37067: {"Unified_Ideograph", "Ideographic"},
    37068: {"Unified_Ideograph", "Ideographic"},
    37069: {"Unified_Ideograph", "Ideographic"},
    37070: {"Unified_Ideograph", "Ideographic"},
    37071: {"Unified_Ideograph", "Ideographic"},
    37072: {"Unified_Ideograph", "Ideographic"},
    37073: {"Unified_Ideograph", "Ideographic"},
    37074: {"Unified_Ideograph", "Ideographic"},
    37075: {"Unified_Ideograph", "Ideographic"},
    37076: {"Unified_Ideograph", "Ideographic"},
    37077: {"Unified_Ideograph", "Ideographic"},
    37078: {"Unified_Ideograph", "Ideographic"},
    37079: {"Unified_Ideograph", "Ideographic"},
    37080: {"Unified_Ideograph", "Ideographic"},
    37081: {"Unified_Ideograph", "Ideographic"},
    37082: {"Unified_Ideograph", "Ideographic"},
    37083: {"Unified_Ideograph", "Ideographic"},
    37084: {"Unified_Ideograph", "Ideographic"},
    37085: {"Unified_Ideograph", "Ideographic"},
    37086: {"Unified_Ideograph", "Ideographic"},
    37087: {"Unified_Ideograph", "Ideographic"},
    37088: {"Unified_Ideograph", "Ideographic"},
    37089: {"Unified_Ideograph", "Ideographic"},
    37090: {"Unified_Ideograph", "Ideographic"},
    37091: {"Unified_Ideograph", "Ideographic"},
    37092: {"Unified_Ideograph", "Ideographic"},
    37093: {"Unified_Ideograph", "Ideographic"},
    37094: {"Unified_Ideograph", "Ideographic"},
    37095: {"Unified_Ideograph", "Ideographic"},
    37096: {"Unified_Ideograph", "Ideographic"},
    37097: {"Unified_Ideograph", "Ideographic"},
    37098: {"Unified_Ideograph", "Ideographic"},
    37099: {"Unified_Ideograph", "Ideographic"},
    37100: {"Unified_Ideograph", "Ideographic"},
    37101: {"Unified_Ideograph", "Ideographic"},
    37102: {"Unified_Ideograph", "Ideographic"},
    37103: {"Unified_Ideograph", "Ideographic"},
    37104: {"Unified_Ideograph", "Ideographic"},
    37105: {"Unified_Ideograph", "Ideographic"},
    37106: {"Unified_Ideograph", "Ideographic"},
    37107: {"Unified_Ideograph", "Ideographic"},
    37108: {"Unified_Ideograph", "Ideographic"},
    37109: {"Unified_Ideograph", "Ideographic"},
    37110: {"Unified_Ideograph", "Ideographic"},
    37111: {"Unified_Ideograph", "Ideographic"},
    37112: {"Unified_Ideograph", "Ideographic"},
    37113: {"Unified_Ideograph", "Ideographic"},
    37114: {"Unified_Ideograph", "Ideographic"},
    37115: {"Unified_Ideograph", "Ideographic"},
    37116: {"Unified_Ideograph", "Ideographic"},
    37117: {"Unified_Ideograph", "Ideographic"},
    37118: {"Unified_Ideograph", "Ideographic"},
    37119: {"Unified_Ideograph", "Ideographic"},
    37120: {"Unified_Ideograph", "Ideographic"},
    37121: {"Unified_Ideograph", "Ideographic"},
    37122: {"Unified_Ideograph", "Ideographic"},
    37123: {"Unified_Ideograph", "Ideographic"},
    37124: {"Unified_Ideograph", "Ideographic"},
    37125: {"Unified_Ideograph", "Ideographic"},
    37126: {"Unified_Ideograph", "Ideographic"},
    37127: {"Unified_Ideograph", "Ideographic"},
    37128: {"Unified_Ideograph", "Ideographic"},
    37129: {"Unified_Ideograph", "Ideographic"},
    37130: {"Unified_Ideograph", "Ideographic"},
    37131: {"Unified_Ideograph", "Ideographic"},
    37132: {"Unified_Ideograph", "Ideographic"},
    37133: {"Unified_Ideograph", "Ideographic"},
    37134: {"Unified_Ideograph", "Ideographic"},
    37135: {"Unified_Ideograph", "Ideographic"},
    37136: {"Unified_Ideograph", "Ideographic"},
    37137: {"Unified_Ideograph", "Ideographic"},
    37138: {"Unified_Ideograph", "Ideographic"},
    37139: {"Unified_Ideograph", "Ideographic"},
    37140: {"Unified_Ideograph", "Ideographic"},
    37141: {"Unified_Ideograph", "Ideographic"},
    37142: {"Unified_Ideograph", "Ideographic"},
    37143: {"Unified_Ideograph", "Ideographic"},
    37144: {"Unified_Ideograph", "Ideographic"},
    37145: {"Unified_Ideograph", "Ideographic"},
    37146: {"Unified_Ideograph", "Ideographic"},
    37147: {"Unified_Ideograph", "Ideographic"},
    37148: {"Unified_Ideograph", "Ideographic"},
    37149: {"Unified_Ideograph", "Ideographic"},
    37150: {"Unified_Ideograph", "Ideographic"},
    37151: {"Unified_Ideograph", "Ideographic"},
    37152: {"Unified_Ideograph", "Ideographic"},
    37153: {"Unified_Ideograph", "Ideographic"},
    37154: {"Unified_Ideograph", "Ideographic"},
    37155: {"Unified_Ideograph", "Ideographic"},
    37156: {"Unified_Ideograph", "Ideographic"},
    37157: {"Unified_Ideograph", "Ideographic"},
    37158: {"Unified_Ideograph", "Ideographic"},
    37159: {"Unified_Ideograph", "Ideographic"},
    37160: {"Unified_Ideograph", "Ideographic"},
    37161: {"Unified_Ideograph", "Ideographic"},
    37162: {"Unified_Ideograph", "Ideographic"},
    37163: {"Unified_Ideograph", "Ideographic"},
    37164: {"Unified_Ideograph", "Ideographic"},
    37165: {"Unified_Ideograph", "Ideographic"},
    37166: {"Unified_Ideograph", "Ideographic"},
    37167: {"Unified_Ideograph", "Ideographic"},
    37168: {"Unified_Ideograph", "Ideographic"},
    37169: {"Unified_Ideograph", "Ideographic"},
    37170: {"Unified_Ideograph", "Ideographic"},
    37171: {"Unified_Ideograph", "Ideographic"},
    37172: {"Unified_Ideograph", "Ideographic"},
    37173: {"Unified_Ideograph", "Ideographic"},
    37174: {"Unified_Ideograph", "Ideographic"},
    37175: {"Unified_Ideograph", "Ideographic"},
    37176: {"Unified_Ideograph", "Ideographic"},
    37177: {"Unified_Ideograph", "Ideographic"},
    37178: {"Unified_Ideograph", "Ideographic"},
    37179: {"Unified_Ideograph", "Ideographic"},
    37180: {"Unified_Ideograph", "Ideographic"},
    37181: {"Unified_Ideograph", "Ideographic"},
    37182: {"Unified_Ideograph", "Ideographic"},
    37183: {"Unified_Ideograph", "Ideographic"},
    37184: {"Unified_Ideograph", "Ideographic"},
    37185: {"Unified_Ideograph", "Ideographic"},
    37186: {"Unified_Ideograph", "Ideographic"},
    37187: {"Unified_Ideograph", "Ideographic"},
    37188: {"Unified_Ideograph", "Ideographic"},
    37189: {"Unified_Ideograph", "Ideographic"},
    37190: {"Unified_Ideograph", "Ideographic"},
    37191: {"Unified_Ideograph", "Ideographic"},
    37192: {"Unified_Ideograph", "Ideographic"},
    37193: {"Unified_Ideograph", "Ideographic"},
    37194: {"Unified_Ideograph", "Ideographic"},
    37195: {"Unified_Ideograph", "Ideographic"},
    37196: {"Unified_Ideograph", "Ideographic"},
    37197: {"Unified_Ideograph", "Ideographic"},
    37198: {"Unified_Ideograph", "Ideographic"},
    37199: {"Unified_Ideograph", "Ideographic"},
    37200: {"Unified_Ideograph", "Ideographic"},
    37201: {"Unified_Ideograph", "Ideographic"},
    37202: {"Unified_Ideograph", "Ideographic"},
    37203: {"Unified_Ideograph", "Ideographic"},
    37204: {"Unified_Ideograph", "Ideographic"},
    37205: {"Unified_Ideograph", "Ideographic"},
    37206: {"Unified_Ideograph", "Ideographic"},
    37207: {"Unified_Ideograph", "Ideographic"},
    37208: {"Unified_Ideograph", "Ideographic"},
    37209: {"Unified_Ideograph", "Ideographic"},
    37210: {"Unified_Ideograph", "Ideographic"},
    37211: {"Unified_Ideograph", "Ideographic"},
    37212: {"Unified_Ideograph", "Ideographic"},
    37213: {"Unified_Ideograph", "Ideographic"},
    37214: {"Unified_Ideograph", "Ideographic"},
    37215: {"Unified_Ideograph", "Ideographic"},
    37216: {"Unified_Ideograph", "Ideographic"},
    37217: {"Unified_Ideograph", "Ideographic"},
    37218: {"Unified_Ideograph", "Ideographic"},
    37219: {"Unified_Ideograph", "Ideographic"},
    37220: {"Unified_Ideograph", "Ideographic"},
    37221: {"Unified_Ideograph", "Ideographic"},
    37222: {"Unified_Ideograph", "Ideographic"},
    37223: {"Unified_Ideograph", "Ideographic"},
    37224: {"Unified_Ideograph", "Ideographic"},
    37225: {"Unified_Ideograph", "Ideographic"},
    37226: {"Unified_Ideograph", "Ideographic"},
    37227: {"Unified_Ideograph", "Ideographic"},
    37228: {"Unified_Ideograph", "Ideographic"},
    37229: {"Unified_Ideograph", "Ideographic"},
    37230: {"Unified_Ideograph", "Ideographic"},
    37231: {"Unified_Ideograph", "Ideographic"},
    37232: {"Unified_Ideograph", "Ideographic"},
    37233: {"Unified_Ideograph", "Ideographic"},
    37234: {"Unified_Ideograph", "Ideographic"},
    37235: {"Unified_Ideograph", "Ideographic"},
    37236: {"Unified_Ideograph", "Ideographic"},
    37237: {"Unified_Ideograph", "Ideographic"},
    37238: {"Unified_Ideograph", "Ideographic"},
    37239: {"Unified_Ideograph", "Ideographic"},
    37240: {"Unified_Ideograph", "Ideographic"},
    37241: {"Unified_Ideograph", "Ideographic"},
    37242: {"Unified_Ideograph", "Ideographic"},
    37243: {"Unified_Ideograph", "Ideographic"},
    37244: {"Unified_Ideograph", "Ideographic"},
    37245: {"Unified_Ideograph", "Ideographic"},
    37246: {"Unified_Ideograph", "Ideographic"},
    37247: {"Unified_Ideograph", "Ideographic"},
    37248: {"Unified_Ideograph", "Ideographic"},
    37249: {"Unified_Ideograph", "Ideographic"},
    37250: {"Unified_Ideograph", "Ideographic"},
    37251: {"Unified_Ideograph", "Ideographic"},
    37252: {"Unified_Ideograph", "Ideographic"},
    37253: {"Unified_Ideograph", "Ideographic"},
    37254: {"Unified_Ideograph", "Ideographic"},
    37255: {"Unified_Ideograph", "Ideographic"},
    37256: {"Unified_Ideograph", "Ideographic"},
    37257: {"Unified_Ideograph", "Ideographic"},
    37258: {"Unified_Ideograph", "Ideographic"},
    37259: {"Unified_Ideograph", "Ideographic"},
    37260: {"Unified_Ideograph", "Ideographic"},
    37261: {"Unified_Ideograph", "Ideographic"},
    37262: {"Unified_Ideograph", "Ideographic"},
    37263: {"Unified_Ideograph", "Ideographic"},
    37264: {"Unified_Ideograph", "Ideographic"},
    37265: {"Unified_Ideograph", "Ideographic"},
    37266: {"Unified_Ideograph", "Ideographic"},
    37267: {"Unified_Ideograph", "Ideographic"},
    37268: {"Unified_Ideograph", "Ideographic"},
    37269: {"Unified_Ideograph", "Ideographic"},
    37270: {"Unified_Ideograph", "Ideographic"},
    37271: {"Unified_Ideograph", "Ideographic"},
    37272: {"Unified_Ideograph", "Ideographic"},
    37273: {"Unified_Ideograph", "Ideographic"},
    37274: {"Unified_Ideograph", "Ideographic"},
    37275: {"Unified_Ideograph", "Ideographic"},
    37276: {"Unified_Ideograph", "Ideographic"},
    37277: {"Unified_Ideograph", "Ideographic"},
    37278: {"Unified_Ideograph", "Ideographic"},
    37279: {"Unified_Ideograph", "Ideographic"},
    37280: {"Unified_Ideograph", "Ideographic"},
    37281: {"Unified_Ideograph", "Ideographic"},
    37282: {"Unified_Ideograph", "Ideographic"},
    37283: {"Unified_Ideograph", "Ideographic"},
    37284: {"Unified_Ideograph", "Ideographic"},
    37285: {"Unified_Ideograph", "Ideographic"},
    37286: {"Unified_Ideograph", "Ideographic"},
    37287: {"Unified_Ideograph", "Ideographic"},
    37288: {"Unified_Ideograph", "Ideographic"},
    37289: {"Unified_Ideograph", "Ideographic"},
    37290: {"Unified_Ideograph", "Ideographic"},
    37291: {"Unified_Ideograph", "Ideographic"},
    37292: {"Unified_Ideograph", "Ideographic"},
    37293: {"Unified_Ideograph", "Ideographic"},
    37294: {"Unified_Ideograph", "Ideographic"},
    37295: {"Unified_Ideograph", "Ideographic"},
    37296: {"Unified_Ideograph", "Ideographic"},
    37297: {"Unified_Ideograph", "Ideographic"},
    37298: {"Unified_Ideograph", "Ideographic"},
    37299: {"Unified_Ideograph", "Ideographic"},
    37300: {"Unified_Ideograph", "Ideographic"},
    37301: {"Unified_Ideograph", "Ideographic"},
    37302: {"Unified_Ideograph", "Ideographic"},
    37303: {"Unified_Ideograph", "Ideographic"},
    37304: {"Unified_Ideograph", "Ideographic"},
    37305: {"Unified_Ideograph", "Ideographic"},
    37306: {"Unified_Ideograph", "Ideographic"},
    37307: {"Unified_Ideograph", "Ideographic"},
    37308: {"Unified_Ideograph", "Ideographic"},
    37309: {"Unified_Ideograph", "Ideographic"},
    37310: {"Unified_Ideograph", "Ideographic"},
    37311: {"Unified_Ideograph", "Ideographic"},
    37312: {"Unified_Ideograph", "Ideographic"},
    37313: {"Unified_Ideograph", "Ideographic"},
    37314: {"Unified_Ideograph", "Ideographic"},
    37315: {"Unified_Ideograph", "Ideographic"},
    37316: {"Unified_Ideograph", "Ideographic"},
    37317: {"Unified_Ideograph", "Ideographic"},
    37318: {"Unified_Ideograph", "Ideographic"},
    37319: {"Unified_Ideograph", "Ideographic"},
    37320: {"Unified_Ideograph", "Ideographic"},
    37321: {"Unified_Ideograph", "Ideographic"},
    37322: {"Unified_Ideograph", "Ideographic"},
    37323: {"Unified_Ideograph", "Ideographic"},
    37324: {"Unified_Ideograph", "Ideographic"},
    37325: {"Unified_Ideograph", "Ideographic"},
    37326: {"Unified_Ideograph", "Ideographic"},
    37327: {"Unified_Ideograph", "Ideographic"},
    37328: {"Unified_Ideograph", "Ideographic"},
    37329: {"Unified_Ideograph", "Ideographic"},
    37330: {"Unified_Ideograph", "Ideographic"},
    37331: {"Unified_Ideograph", "Ideographic"},
    37332: {"Unified_Ideograph", "Ideographic"},
    37333: {"Unified_Ideograph", "Ideographic"},
    37334: {"Unified_Ideograph", "Ideographic"},
    37335: {"Unified_Ideograph", "Ideographic"},
    37336: {"Unified_Ideograph", "Ideographic"},
    37337: {"Unified_Ideograph", "Ideographic"},
    37338: {"Unified_Ideograph", "Ideographic"},
    37339: {"Unified_Ideograph", "Ideographic"},
    37340: {"Unified_Ideograph", "Ideographic"},
    37341: {"Unified_Ideograph", "Ideographic"},
    37342: {"Unified_Ideograph", "Ideographic"},
    37343: {"Unified_Ideograph", "Ideographic"},
    37344: {"Unified_Ideograph", "Ideographic"},
    37345: {"Unified_Ideograph", "Ideographic"},
    37346: {"Unified_Ideograph", "Ideographic"},
    37347: {"Unified_Ideograph", "Ideographic"},
    37348: {"Unified_Ideograph", "Ideographic"},
    37349: {"Unified_Ideograph", "Ideographic"},
    37350: {"Unified_Ideograph", "Ideographic"},
    37351: {"Unified_Ideograph", "Ideographic"},
    37352: {"Unified_Ideograph", "Ideographic"},
    37353: {"Unified_Ideograph", "Ideographic"},
    37354: {"Unified_Ideograph", "Ideographic"},
    37355: {"Unified_Ideograph", "Ideographic"},
    37356: {"Unified_Ideograph", "Ideographic"},
    37357: {"Unified_Ideograph", "Ideographic"},
    37358: {"Unified_Ideograph", "Ideographic"},
    37359: {"Unified_Ideograph", "Ideographic"},
    37360: {"Unified_Ideograph", "Ideographic"},
    37361: {"Unified_Ideograph", "Ideographic"},
    37362: {"Unified_Ideograph", "Ideographic"},
    37363: {"Unified_Ideograph", "Ideographic"},
    37364: {"Unified_Ideograph", "Ideographic"},
    37365: {"Unified_Ideograph", "Ideographic"},
    37366: {"Unified_Ideograph", "Ideographic"},
    37367: {"Unified_Ideograph", "Ideographic"},
    37368: {"Unified_Ideograph", "Ideographic"},
    37369: {"Unified_Ideograph", "Ideographic"},
    37370: {"Unified_Ideograph", "Ideographic"},
    37371: {"Unified_Ideograph", "Ideographic"},
    37372: {"Unified_Ideograph", "Ideographic"},
    37373: {"Unified_Ideograph", "Ideographic"},
    37374: {"Unified_Ideograph", "Ideographic"},
    37375: {"Unified_Ideograph", "Ideographic"},
    37376: {"Unified_Ideograph", "Ideographic"},
    37377: {"Unified_Ideograph", "Ideographic"},
    37378: {"Unified_Ideograph", "Ideographic"},
    37379: {"Unified_Ideograph", "Ideographic"},
    37380: {"Unified_Ideograph", "Ideographic"},
    37381: {"Unified_Ideograph", "Ideographic"},
    37382: {"Unified_Ideograph", "Ideographic"},
    37383: {"Unified_Ideograph", "Ideographic"},
    37384: {"Unified_Ideograph", "Ideographic"},
    37385: {"Unified_Ideograph", "Ideographic"},
    37386: {"Unified_Ideograph", "Ideographic"},
    37387: {"Unified_Ideograph", "Ideographic"},
    37388: {"Unified_Ideograph", "Ideographic"},
    37389: {"Unified_Ideograph", "Ideographic"},
    37390: {"Unified_Ideograph", "Ideographic"},
    37391: {"Unified_Ideograph", "Ideographic"},
    37392: {"Unified_Ideograph", "Ideographic"},
    37393: {"Unified_Ideograph", "Ideographic"},
    37394: {"Unified_Ideograph", "Ideographic"},
    37395: {"Unified_Ideograph", "Ideographic"},
    37396: {"Unified_Ideograph", "Ideographic"},
    37397: {"Unified_Ideograph", "Ideographic"},
    37398: {"Unified_Ideograph", "Ideographic"},
    37399: {"Unified_Ideograph", "Ideographic"},
    37400: {"Unified_Ideograph", "Ideographic"},
    37401: {"Unified_Ideograph", "Ideographic"},
    37402: {"Unified_Ideograph", "Ideographic"},
    37403: {"Unified_Ideograph", "Ideographic"},
    37404: {"Unified_Ideograph", "Ideographic"},
    37405: {"Unified_Ideograph", "Ideographic"},
    37406: {"Unified_Ideograph", "Ideographic"},
    37407: {"Unified_Ideograph", "Ideographic"},
    37408: {"Unified_Ideograph", "Ideographic"},
    37409: {"Unified_Ideograph", "Ideographic"},
    37410: {"Unified_Ideograph", "Ideographic"},
    37411: {"Unified_Ideograph", "Ideographic"},
    37412: {"Unified_Ideograph", "Ideographic"},
    37413: {"Unified_Ideograph", "Ideographic"},
    37414: {"Unified_Ideograph", "Ideographic"},
    37415: {"Unified_Ideograph", "Ideographic"},
    37416: {"Unified_Ideograph", "Ideographic"},
    37417: {"Unified_Ideograph", "Ideographic"},
    37418: {"Unified_Ideograph", "Ideographic"},
    37419: {"Unified_Ideograph", "Ideographic"},
    37420: {"Unified_Ideograph", "Ideographic"},
    37421: {"Unified_Ideograph", "Ideographic"},
    37422: {"Unified_Ideograph", "Ideographic"},
    37423: {"Unified_Ideograph", "Ideographic"},
    37424: {"Unified_Ideograph", "Ideographic"},
    37425: {"Unified_Ideograph", "Ideographic"},
    37426: {"Unified_Ideograph", "Ideographic"},
    37427: {"Unified_Ideograph", "Ideographic"},
    37428: {"Unified_Ideograph", "Ideographic"},
    37429: {"Unified_Ideograph", "Ideographic"},
    37430: {"Unified_Ideograph", "Ideographic"},
    37431: {"Unified_Ideograph", "Ideographic"},
    37432: {"Unified_Ideograph", "Ideographic"},
    37433: {"Unified_Ideograph", "Ideographic"},
    37434: {"Unified_Ideograph", "Ideographic"},
    37435: {"Unified_Ideograph", "Ideographic"},
    37436: {"Unified_Ideograph", "Ideographic"},
    37437: {"Unified_Ideograph", "Ideographic"},
    37438: {"Unified_Ideograph", "Ideographic"},
    37439: {"Unified_Ideograph", "Ideographic"},
    37440: {"Unified_Ideograph", "Ideographic"},
    37441: {"Unified_Ideograph", "Ideographic"},
    37442: {"Unified_Ideograph", "Ideographic"},
    37443: {"Unified_Ideograph", "Ideographic"},
    37444: {"Unified_Ideograph", "Ideographic"},
    37445: {"Unified_Ideograph", "Ideographic"},
    37446: {"Unified_Ideograph", "Ideographic"},
    37447: {"Unified_Ideograph", "Ideographic"},
    37448: {"Unified_Ideograph", "Ideographic"},
    37449: {"Unified_Ideograph", "Ideographic"},
    37450: {"Unified_Ideograph", "Ideographic"},
    37451: {"Unified_Ideograph", "Ideographic"},
    37452: {"Unified_Ideograph", "Ideographic"},
    37453: {"Unified_Ideograph", "Ideographic"},
    37454: {"Unified_Ideograph", "Ideographic"},
    37455: {"Unified_Ideograph", "Ideographic"},
    37456: {"Unified_Ideograph", "Ideographic"},
    37457: {"Unified_Ideograph", "Ideographic"},
    37458: {"Unified_Ideograph", "Ideographic"},
    37459: {"Unified_Ideograph", "Ideographic"},
    37460: {"Unified_Ideograph", "Ideographic"},
    37461: {"Unified_Ideograph", "Ideographic"},
    37462: {"Unified_Ideograph", "Ideographic"},
    37463: {"Unified_Ideograph", "Ideographic"},
    37464: {"Unified_Ideograph", "Ideographic"},
    37465: {"Unified_Ideograph", "Ideographic"},
    37466: {"Unified_Ideograph", "Ideographic"},
    37467: {"Unified_Ideograph", "Ideographic"},
    37468: {"Unified_Ideograph", "Ideographic"},
    37469: {"Unified_Ideograph", "Ideographic"},
    37470: {"Unified_Ideograph", "Ideographic"},
    37471: {"Unified_Ideograph", "Ideographic"},
    37472: {"Unified_Ideograph", "Ideographic"},
    37473: {"Unified_Ideograph", "Ideographic"},
    37474: {"Unified_Ideograph", "Ideographic"},
    37475: {"Unified_Ideograph", "Ideographic"},
    37476: {"Unified_Ideograph", "Ideographic"},
    37477: {"Unified_Ideograph", "Ideographic"},
    37478: {"Unified_Ideograph", "Ideographic"},
    37479: {"Unified_Ideograph", "Ideographic"},
    37480: {"Unified_Ideograph", "Ideographic"},
    37481: {"Unified_Ideograph", "Ideographic"},
    37482: {"Unified_Ideograph", "Ideographic"},
    37483: {"Unified_Ideograph", "Ideographic"},
    37484: {"Unified_Ideograph", "Ideographic"},
    37485: {"Unified_Ideograph", "Ideographic"},
    37486: {"Unified_Ideograph", "Ideographic"},
    37487: {"Unified_Ideograph", "Ideographic"},
    37488: {"Unified_Ideograph", "Ideographic"},
    37489: {"Unified_Ideograph", "Ideographic"},
    37490: {"Unified_Ideograph", "Ideographic"},
    37491: {"Unified_Ideograph", "Ideographic"},
    37492: {"Unified_Ideograph", "Ideographic"},
    37493: {"Unified_Ideograph", "Ideographic"},
    37494: {"Unified_Ideograph", "Ideographic"},
    37495: {"Unified_Ideograph", "Ideographic"},
    37496: {"Unified_Ideograph", "Ideographic"},
    37497: {"Unified_Ideograph", "Ideographic"},
    37498: {"Unified_Ideograph", "Ideographic"},
    37499: {"Unified_Ideograph", "Ideographic"},
    37500: {"Unified_Ideograph", "Ideographic"},
    37501: {"Unified_Ideograph", "Ideographic"},
    37502: {"Unified_Ideograph", "Ideographic"},
    37503: {"Unified_Ideograph", "Ideographic"},
    37504: {"Unified_Ideograph", "Ideographic"},
    37505: {"Unified_Ideograph", "Ideographic"},
    37506: {"Unified_Ideograph", "Ideographic"},
    37507: {"Unified_Ideograph", "Ideographic"},
    37508: {"Unified_Ideograph", "Ideographic"},
    37509: {"Unified_Ideograph", "Ideographic"},
    37510: {"Unified_Ideograph", "Ideographic"},
    37511: {"Unified_Ideograph", "Ideographic"},
    37512: {"Unified_Ideograph", "Ideographic"},
    37513: {"Unified_Ideograph", "Ideographic"},
    37514: {"Unified_Ideograph", "Ideographic"},
    37515: {"Unified_Ideograph", "Ideographic"},
    37516: {"Unified_Ideograph", "Ideographic"},
    37517: {"Unified_Ideograph", "Ideographic"},
    37518: {"Unified_Ideograph", "Ideographic"},
    37519: {"Unified_Ideograph", "Ideographic"},
    37520: {"Unified_Ideograph", "Ideographic"},
    37521: {"Unified_Ideograph", "Ideographic"},
    37522: {"Unified_Ideograph", "Ideographic"},
    37523: {"Unified_Ideograph", "Ideographic"},
    37524: {"Unified_Ideograph", "Ideographic"},
    37525: {"Unified_Ideograph", "Ideographic"},
    37526: {"Unified_Ideograph", "Ideographic"},
    37527: {"Unified_Ideograph", "Ideographic"},
    37528: {"Unified_Ideograph", "Ideographic"},
    37529: {"Unified_Ideograph", "Ideographic"},
    37530: {"Unified_Ideograph", "Ideographic"},
    37531: {"Unified_Ideograph", "Ideographic"},
    37532: {"Unified_Ideograph", "Ideographic"},
    37533: {"Unified_Ideograph", "Ideographic"},
    37534: {"Unified_Ideograph", "Ideographic"},
    37535: {"Unified_Ideograph", "Ideographic"},
    37536: {"Unified_Ideograph", "Ideographic"},
    37537: {"Unified_Ideograph", "Ideographic"},
    37538: {"Unified_Ideograph", "Ideographic"},
    37539: {"Unified_Ideograph", "Ideographic"},
    37540: {"Unified_Ideograph", "Ideographic"},
    37541: {"Unified_Ideograph", "Ideographic"},
    37542: {"Unified_Ideograph", "Ideographic"},
    37543: {"Unified_Ideograph", "Ideographic"},
    37544: {"Unified_Ideograph", "Ideographic"},
    37545: {"Unified_Ideograph", "Ideographic"},
    37546: {"Unified_Ideograph", "Ideographic"},
    37547: {"Unified_Ideograph", "Ideographic"},
    37548: {"Unified_Ideograph", "Ideographic"},
    37549: {"Unified_Ideograph", "Ideographic"},
    37550: {"Unified_Ideograph", "Ideographic"},
    37551: {"Unified_Ideograph", "Ideographic"},
    37552: {"Unified_Ideograph", "Ideographic"},
    37553: {"Unified_Ideograph", "Ideographic"},
    37554: {"Unified_Ideograph", "Ideographic"},
    37555: {"Unified_Ideograph", "Ideographic"},
    37556: {"Unified_Ideograph", "Ideographic"},
    37557: {"Unified_Ideograph", "Ideographic"},
    37558: {"Unified_Ideograph", "Ideographic"},
    37559: {"Unified_Ideograph", "Ideographic"},
    37560: {"Unified_Ideograph", "Ideographic"},
    37561: {"Unified_Ideograph", "Ideographic"},
    37562: {"Unified_Ideograph", "Ideographic"},
    37563: {"Unified_Ideograph", "Ideographic"},
    37564: {"Unified_Ideograph", "Ideographic"},
    37565: {"Unified_Ideograph", "Ideographic"},
    37566: {"Unified_Ideograph", "Ideographic"},
    37567: {"Unified_Ideograph", "Ideographic"},
    37568: {"Unified_Ideograph", "Ideographic"},
    37569: {"Unified_Ideograph", "Ideographic"},
    37570: {"Unified_Ideograph", "Ideographic"},
    37571: {"Unified_Ideograph", "Ideographic"},
    37572: {"Unified_Ideograph", "Ideographic"},
    37573: {"Unified_Ideograph", "Ideographic"},
    37574: {"Unified_Ideograph", "Ideographic"},
    37575: {"Unified_Ideograph", "Ideographic"},
    37576: {"Unified_Ideograph", "Ideographic"},
    37577: {"Unified_Ideograph", "Ideographic"},
    37578: {"Unified_Ideograph", "Ideographic"},
    37579: {"Unified_Ideograph", "Ideographic"},
    37580: {"Unified_Ideograph", "Ideographic"},
    37581: {"Unified_Ideograph", "Ideographic"},
    37582: {"Unified_Ideograph", "Ideographic"},
    37583: {"Unified_Ideograph", "Ideographic"},
    37584: {"Unified_Ideograph", "Ideographic"},
    37585: {"Unified_Ideograph", "Ideographic"},
    37586: {"Unified_Ideograph", "Ideographic"},
    37587: {"Unified_Ideograph", "Ideographic"},
    37588: {"Unified_Ideograph", "Ideographic"},
    37589: {"Unified_Ideograph", "Ideographic"},
    37590: {"Unified_Ideograph", "Ideographic"},
    37591: {"Unified_Ideograph", "Ideographic"},
    37592: {"Unified_Ideograph", "Ideographic"},
    37593: {"Unified_Ideograph", "Ideographic"},
    37594: {"Unified_Ideograph", "Ideographic"},
    37595: {"Unified_Ideograph", "Ideographic"},
    37596: {"Unified_Ideograph", "Ideographic"},
    37597: {"Unified_Ideograph", "Ideographic"},
    37598: {"Unified_Ideograph", "Ideographic"},
    37599: {"Unified_Ideograph", "Ideographic"},
    37600: {"Unified_Ideograph", "Ideographic"},
    37601: {"Unified_Ideograph", "Ideographic"},
    37602: {"Unified_Ideograph", "Ideographic"},
    37603: {"Unified_Ideograph", "Ideographic"},
    37604: {"Unified_Ideograph", "Ideographic"},
    37605: {"Unified_Ideograph", "Ideographic"},
    37606: {"Unified_Ideograph", "Ideographic"},
    37607: {"Unified_Ideograph", "Ideographic"},
    37608: {"Unified_Ideograph", "Ideographic"},
    37609: {"Unified_Ideograph", "Ideographic"},
    37610: {"Unified_Ideograph", "Ideographic"},
    37611: {"Unified_Ideograph", "Ideographic"},
    37612: {"Unified_Ideograph", "Ideographic"},
    37613: {"Unified_Ideograph", "Ideographic"},
    37614: {"Unified_Ideograph", "Ideographic"},
    37615: {"Unified_Ideograph", "Ideographic"},
    37616: {"Unified_Ideograph", "Ideographic"},
    37617: {"Unified_Ideograph", "Ideographic"},
    37618: {"Unified_Ideograph", "Ideographic"},
    37619: {"Unified_Ideograph", "Ideographic"},
    37620: {"Unified_Ideograph", "Ideographic"},
    37621: {"Unified_Ideograph", "Ideographic"},
    37622: {"Unified_Ideograph", "Ideographic"},
    37623: {"Unified_Ideograph", "Ideographic"},
    37624: {"Unified_Ideograph", "Ideographic"},
    37625: {"Unified_Ideograph", "Ideographic"},
    37626: {"Unified_Ideograph", "Ideographic"},
    37627: {"Unified_Ideograph", "Ideographic"},
    37628: {"Unified_Ideograph", "Ideographic"},
    37629: {"Unified_Ideograph", "Ideographic"},
    37630: {"Unified_Ideograph", "Ideographic"},
    37631: {"Unified_Ideograph", "Ideographic"},
    37632: {"Unified_Ideograph", "Ideographic"},
    37633: {"Unified_Ideograph", "Ideographic"},
    37634: {"Unified_Ideograph", "Ideographic"},
    37635: {"Unified_Ideograph", "Ideographic"},
    37636: {"Unified_Ideograph", "Ideographic"},
    37637: {"Unified_Ideograph", "Ideographic"},
    37638: {"Unified_Ideograph", "Ideographic"},
    37639: {"Unified_Ideograph", "Ideographic"},
    37640: {"Unified_Ideograph", "Ideographic"},
    37641: {"Unified_Ideograph", "Ideographic"},
    37642: {"Unified_Ideograph", "Ideographic"},
    37643: {"Unified_Ideograph", "Ideographic"},
    37644: {"Unified_Ideograph", "Ideographic"},
    37645: {"Unified_Ideograph", "Ideographic"},
    37646: {"Unified_Ideograph", "Ideographic"},
    37647: {"Unified_Ideograph", "Ideographic"},
    37648: {"Unified_Ideograph", "Ideographic"},
    37649: {"Unified_Ideograph", "Ideographic"},
    37650: {"Unified_Ideograph", "Ideographic"},
    37651: {"Unified_Ideograph", "Ideographic"},
    37652: {"Unified_Ideograph", "Ideographic"},
    37653: {"Unified_Ideograph", "Ideographic"},
    37654: {"Unified_Ideograph", "Ideographic"},
    37655: {"Unified_Ideograph", "Ideographic"},
    37656: {"Unified_Ideograph", "Ideographic"},
    37657: {"Unified_Ideograph", "Ideographic"},
    37658: {"Unified_Ideograph", "Ideographic"},
    37659: {"Unified_Ideograph", "Ideographic"},
    37660: {"Unified_Ideograph", "Ideographic"},
    37661: {"Unified_Ideograph", "Ideographic"},
    37662: {"Unified_Ideograph", "Ideographic"},
    37663: {"Unified_Ideograph", "Ideographic"},
    37664: {"Unified_Ideograph", "Ideographic"},
    37665: {"Unified_Ideograph", "Ideographic"},
    37666: {"Unified_Ideograph", "Ideographic"},
    37667: {"Unified_Ideograph", "Ideographic"},
    37668: {"Unified_Ideograph", "Ideographic"},
    37669: {"Unified_Ideograph", "Ideographic"},
    37670: {"Unified_Ideograph", "Ideographic"},
    37671: {"Unified_Ideograph", "Ideographic"},
    37672: {"Unified_Ideograph", "Ideographic"},
    37673: {"Unified_Ideograph", "Ideographic"},
    37674: {"Unified_Ideograph", "Ideographic"},
    37675: {"Unified_Ideograph", "Ideographic"},
    37676: {"Unified_Ideograph", "Ideographic"},
    37677: {"Unified_Ideograph", "Ideographic"},
    37678: {"Unified_Ideograph", "Ideographic"},
    37679: {"Unified_Ideograph", "Ideographic"},
    37680: {"Unified_Ideograph", "Ideographic"},
    37681: {"Unified_Ideograph", "Ideographic"},
    37682: {"Unified_Ideograph", "Ideographic"},
    37683: {"Unified_Ideograph", "Ideographic"},
    37684: {"Unified_Ideograph", "Ideographic"},
    37685: {"Unified_Ideograph", "Ideographic"},
    37686: {"Unified_Ideograph", "Ideographic"},
    37687: {"Unified_Ideograph", "Ideographic"},
    37688: {"Unified_Ideograph", "Ideographic"},
    37689: {"Unified_Ideograph", "Ideographic"},
    37690: {"Unified_Ideograph", "Ideographic"},
    37691: {"Unified_Ideograph", "Ideographic"},
    37692: {"Unified_Ideograph", "Ideographic"},
    37693: {"Unified_Ideograph", "Ideographic"},
    37694: {"Unified_Ideograph", "Ideographic"},
    37695: {"Unified_Ideograph", "Ideographic"},
    37696: {"Unified_Ideograph", "Ideographic"},
    37697: {"Unified_Ideograph", "Ideographic"},
    37698: {"Unified_Ideograph", "Ideographic"},
    37699: {"Unified_Ideograph", "Ideographic"},
    37700: {"Unified_Ideograph", "Ideographic"},
    37701: {"Unified_Ideograph", "Ideographic"},
    37702: {"Unified_Ideograph", "Ideographic"},
    37703: {"Unified_Ideograph", "Ideographic"},
    37704: {"Unified_Ideograph", "Ideographic"},
    37705: {"Unified_Ideograph", "Ideographic"},
    37706: {"Unified_Ideograph", "Ideographic"},
    37707: {"Unified_Ideograph", "Ideographic"},
    37708: {"Unified_Ideograph", "Ideographic"},
    37709: {"Unified_Ideograph", "Ideographic"},
    37710: {"Unified_Ideograph", "Ideographic"},
    37711: {"Unified_Ideograph", "Ideographic"},
    37712: {"Unified_Ideograph", "Ideographic"},
    37713: {"Unified_Ideograph", "Ideographic"},
    37714: {"Unified_Ideograph", "Ideographic"},
    37715: {"Unified_Ideograph", "Ideographic"},
    37716: {"Unified_Ideograph", "Ideographic"},
    37717: {"Unified_Ideograph", "Ideographic"},
    37718: {"Unified_Ideograph", "Ideographic"},
    37719: {"Unified_Ideograph", "Ideographic"},
    37720: {"Unified_Ideograph", "Ideographic"},
    37721: {"Unified_Ideograph", "Ideographic"},
    37722: {"Unified_Ideograph", "Ideographic"},
    37723: {"Unified_Ideograph", "Ideographic"},
    37724: {"Unified_Ideograph", "Ideographic"},
    37725: {"Unified_Ideograph", "Ideographic"},
    37726: {"Unified_Ideograph", "Ideographic"},
    37727: {"Unified_Ideograph", "Ideographic"},
    37728: {"Unified_Ideograph", "Ideographic"},
    37729: {"Unified_Ideograph", "Ideographic"},
    37730: {"Unified_Ideograph", "Ideographic"},
    37731: {"Unified_Ideograph", "Ideographic"},
    37732: {"Unified_Ideograph", "Ideographic"},
    37733: {"Unified_Ideograph", "Ideographic"},
    37734: {"Unified_Ideograph", "Ideographic"},
    37735: {"Unified_Ideograph", "Ideographic"},
    37736: {"Unified_Ideograph", "Ideographic"},
    37737: {"Unified_Ideograph", "Ideographic"},
    37738: {"Unified_Ideograph", "Ideographic"},
    37739: {"Unified_Ideograph", "Ideographic"},
    37740: {"Unified_Ideograph", "Ideographic"},
    37741: {"Unified_Ideograph", "Ideographic"},
    37742: {"Unified_Ideograph", "Ideographic"},
    37743: {"Unified_Ideograph", "Ideographic"},
    37744: {"Unified_Ideograph", "Ideographic"},
    37745: {"Unified_Ideograph", "Ideographic"},
    37746: {"Unified_Ideograph", "Ideographic"},
    37747: {"Unified_Ideograph", "Ideographic"},
    37748: {"Unified_Ideograph", "Ideographic"},
    37749: {"Unified_Ideograph", "Ideographic"},
    37750: {"Unified_Ideograph", "Ideographic"},
    37751: {"Unified_Ideograph", "Ideographic"},
    37752: {"Unified_Ideograph", "Ideographic"},
    37753: {"Unified_Ideograph", "Ideographic"},
    37754: {"Unified_Ideograph", "Ideographic"},
    37755: {"Unified_Ideograph", "Ideographic"},
    37756: {"Unified_Ideograph", "Ideographic"},
    37757: {"Unified_Ideograph", "Ideographic"},
    37758: {"Unified_Ideograph", "Ideographic"},
    37759: {"Unified_Ideograph", "Ideographic"},
    37760: {"Unified_Ideograph", "Ideographic"},
    37761: {"Unified_Ideograph", "Ideographic"},
    37762: {"Unified_Ideograph", "Ideographic"},
    37763: {"Unified_Ideograph", "Ideographic"},
    37764: {"Unified_Ideograph", "Ideographic"},
    37765: {"Unified_Ideograph", "Ideographic"},
    37766: {"Unified_Ideograph", "Ideographic"},
    37767: {"Unified_Ideograph", "Ideographic"},
    37768: {"Unified_Ideograph", "Ideographic"},
    37769: {"Unified_Ideograph", "Ideographic"},
    37770: {"Unified_Ideograph", "Ideographic"},
    37771: {"Unified_Ideograph", "Ideographic"},
    37772: {"Unified_Ideograph", "Ideographic"},
    37773: {"Unified_Ideograph", "Ideographic"},
    37774: {"Unified_Ideograph", "Ideographic"},
    37775: {"Unified_Ideograph", "Ideographic"},
    37776: {"Unified_Ideograph", "Ideographic"},
    37777: {"Unified_Ideograph", "Ideographic"},
    37778: {"Unified_Ideograph", "Ideographic"},
    37779: {"Unified_Ideograph", "Ideographic"},
    37780: {"Unified_Ideograph", "Ideographic"},
    37781: {"Unified_Ideograph", "Ideographic"},
    37782: {"Unified_Ideograph", "Ideographic"},
    37783: {"Unified_Ideograph", "Ideographic"},
    37784: {"Unified_Ideograph", "Ideographic"},
    37785: {"Unified_Ideograph", "Ideographic"},
    37786: {"Unified_Ideograph", "Ideographic"},
    37787: {"Unified_Ideograph", "Ideographic"},
    37788: {"Unified_Ideograph", "Ideographic"},
    37789: {"Unified_Ideograph", "Ideographic"},
    37790: {"Unified_Ideograph", "Ideographic"},
    37791: {"Unified_Ideograph", "Ideographic"},
    37792: {"Unified_Ideograph", "Ideographic"},
    37793: {"Unified_Ideograph", "Ideographic"},
    37794: {"Unified_Ideograph", "Ideographic"},
    37795: {"Unified_Ideograph", "Ideographic"},
    37796: {"Unified_Ideograph", "Ideographic"},
    37797: {"Unified_Ideograph", "Ideographic"},
    37798: {"Unified_Ideograph", "Ideographic"},
    37799: {"Unified_Ideograph", "Ideographic"},
    37800: {"Unified_Ideograph", "Ideographic"},
    37801: {"Unified_Ideograph", "Ideographic"},
    37802: {"Unified_Ideograph", "Ideographic"},
    37803: {"Unified_Ideograph", "Ideographic"},
    37804: {"Unified_Ideograph", "Ideographic"},
    37805: {"Unified_Ideograph", "Ideographic"},
    37806: {"Unified_Ideograph", "Ideographic"},
    37807: {"Unified_Ideograph", "Ideographic"},
    37808: {"Unified_Ideograph", "Ideographic"},
    37809: {"Unified_Ideograph", "Ideographic"},
    37810: {"Unified_Ideograph", "Ideographic"},
    37811: {"Unified_Ideograph", "Ideographic"},
    37812: {"Unified_Ideograph", "Ideographic"},
    37813: {"Unified_Ideograph", "Ideographic"},
    37814: {"Unified_Ideograph", "Ideographic"},
    37815: {"Unified_Ideograph", "Ideographic"},
    37816: {"Unified_Ideograph", "Ideographic"},
    37817: {"Unified_Ideograph", "Ideographic"},
    37818: {"Unified_Ideograph", "Ideographic"},
    37819: {"Unified_Ideograph", "Ideographic"},
    37820: {"Unified_Ideograph", "Ideographic"},
    37821: {"Unified_Ideograph", "Ideographic"},
    37822: {"Unified_Ideograph", "Ideographic"},
    37823: {"Unified_Ideograph", "Ideographic"},
    37824: {"Unified_Ideograph", "Ideographic"},
    37825: {"Unified_Ideograph", "Ideographic"},
    37826: {"Unified_Ideograph", "Ideographic"},
    37827: {"Unified_Ideograph", "Ideographic"},
    37828: {"Unified_Ideograph", "Ideographic"},
    37829: {"Unified_Ideograph", "Ideographic"},
    37830: {"Unified_Ideograph", "Ideographic"},
    37831: {"Unified_Ideograph", "Ideographic"},
    37832: {"Unified_Ideograph", "Ideographic"},
    37833: {"Unified_Ideograph", "Ideographic"},
    37834: {"Unified_Ideograph", "Ideographic"},
    37835: {"Unified_Ideograph", "Ideographic"},
    37836: {"Unified_Ideograph", "Ideographic"},
    37837: {"Unified_Ideograph", "Ideographic"},
    37838: {"Unified_Ideograph", "Ideographic"},
    37839: {"Unified_Ideograph", "Ideographic"},
    37840: {"Unified_Ideograph", "Ideographic"},
    37841: {"Unified_Ideograph", "Ideographic"},
    37842: {"Unified_Ideograph", "Ideographic"},
    37843: {"Unified_Ideograph", "Ideographic"},
    37844: {"Unified_Ideograph", "Ideographic"},
    37845: {"Unified_Ideograph", "Ideographic"},
    37846: {"Unified_Ideograph", "Ideographic"},
    37847: {"Unified_Ideograph", "Ideographic"},
    37848: {"Unified_Ideograph", "Ideographic"},
    37849: {"Unified_Ideograph", "Ideographic"},
    37850: {"Unified_Ideograph", "Ideographic"},
    37851: {"Unified_Ideograph", "Ideographic"},
    37852: {"Unified_Ideograph", "Ideographic"},
    37853: {"Unified_Ideograph", "Ideographic"},
    37854: {"Unified_Ideograph", "Ideographic"},
    37855: {"Unified_Ideograph", "Ideographic"},
    37856: {"Unified_Ideograph", "Ideographic"},
    37857: {"Unified_Ideograph", "Ideographic"},
    37858: {"Unified_Ideograph", "Ideographic"},
    37859: {"Unified_Ideograph", "Ideographic"},
    37860: {"Unified_Ideograph", "Ideographic"},
    37861: {"Unified_Ideograph", "Ideographic"},
    37862: {"Unified_Ideograph", "Ideographic"},
    37863: {"Unified_Ideograph", "Ideographic"},
    37864: {"Unified_Ideograph", "Ideographic"},
    37865: {"Unified_Ideograph", "Ideographic"},
    37866: {"Unified_Ideograph", "Ideographic"},
    37867: {"Unified_Ideograph", "Ideographic"},
    37868: {"Unified_Ideograph", "Ideographic"},
    37869: {"Unified_Ideograph", "Ideographic"},
    37870: {"Unified_Ideograph", "Ideographic"},
    37871: {"Unified_Ideograph", "Ideographic"},
    37872: {"Unified_Ideograph", "Ideographic"},
    37873: {"Unified_Ideograph", "Ideographic"},
    37874: {"Unified_Ideograph", "Ideographic"},
    37875: {"Unified_Ideograph", "Ideographic"},
    37876: {"Unified_Ideograph", "Ideographic"},
    37877: {"Unified_Ideograph", "Ideographic"},
    37878: {"Unified_Ideograph", "Ideographic"},
    37879: {"Unified_Ideograph", "Ideographic"},
    37880: {"Unified_Ideograph", "Ideographic"},
    37881: {"Unified_Ideograph", "Ideographic"},
    37882: {"Unified_Ideograph", "Ideographic"},
    37883: {"Unified_Ideograph", "Ideographic"},
    37884: {"Unified_Ideograph", "Ideographic"},
    37885: {"Unified_Ideograph", "Ideographic"},
    37886: {"Unified_Ideograph", "Ideographic"},
    37887: {"Unified_Ideograph", "Ideographic"},
    37888: {"Unified_Ideograph", "Ideographic"},
    37889: {"Unified_Ideograph", "Ideographic"},
    37890: {"Unified_Ideograph", "Ideographic"},
    37891: {"Unified_Ideograph", "Ideographic"},
    37892: {"Unified_Ideograph", "Ideographic"},
    37893: {"Unified_Ideograph", "Ideographic"},
    37894: {"Unified_Ideograph", "Ideographic"},
    37895: {"Unified_Ideograph", "Ideographic"},
    37896: {"Unified_Ideograph", "Ideographic"},
    37897: {"Unified_Ideograph", "Ideographic"},
    37898: {"Unified_Ideograph", "Ideographic"},
    37899: {"Unified_Ideograph", "Ideographic"},
    37900: {"Unified_Ideograph", "Ideographic"},
    37901: {"Unified_Ideograph", "Ideographic"},
    37902: {"Unified_Ideograph", "Ideographic"},
    37903: {"Unified_Ideograph", "Ideographic"},
    37904: {"Unified_Ideograph", "Ideographic"},
    37905: {"Unified_Ideograph", "Ideographic"},
    37906: {"Unified_Ideograph", "Ideographic"},
    37907: {"Unified_Ideograph", "Ideographic"},
    37908: {"Unified_Ideograph", "Ideographic"},
    37909: {"Unified_Ideograph", "Ideographic"},
    37910: {"Unified_Ideograph", "Ideographic"},
    37911: {"Unified_Ideograph", "Ideographic"},
    37912: {"Unified_Ideograph", "Ideographic"},
    37913: {"Unified_Ideograph", "Ideographic"},
    37914: {"Unified_Ideograph", "Ideographic"},
    37915: {"Unified_Ideograph", "Ideographic"},
    37916: {"Unified_Ideograph", "Ideographic"},
    37917: {"Unified_Ideograph", "Ideographic"},
    37918: {"Unified_Ideograph", "Ideographic"},
    37919: {"Unified_Ideograph", "Ideographic"},
    37920: {"Unified_Ideograph", "Ideographic"},
    37921: {"Unified_Ideograph", "Ideographic"},
    37922: {"Unified_Ideograph", "Ideographic"},
    37923: {"Unified_Ideograph", "Ideographic"},
    37924: {"Unified_Ideograph", "Ideographic"},
    37925: {"Unified_Ideograph", "Ideographic"},
    37926: {"Unified_Ideograph", "Ideographic"},
    37927: {"Unified_Ideograph", "Ideographic"},
    37928: {"Unified_Ideograph", "Ideographic"},
    37929: {"Unified_Ideograph", "Ideographic"},
    37930: {"Unified_Ideograph", "Ideographic"},
    37931: {"Unified_Ideograph", "Ideographic"},
    37932: {"Unified_Ideograph", "Ideographic"},
    37933: {"Unified_Ideograph", "Ideographic"},
    37934: {"Unified_Ideograph", "Ideographic"},
    37935: {"Unified_Ideograph", "Ideographic"},
    37936: {"Unified_Ideograph", "Ideographic"},
    37937: {"Unified_Ideograph", "Ideographic"},
    37938: {"Unified_Ideograph", "Ideographic"},
    37939: {"Unified_Ideograph", "Ideographic"},
    37940: {"Unified_Ideograph", "Ideographic"},
    37941: {"Unified_Ideograph", "Ideographic"},
    37942: {"Unified_Ideograph", "Ideographic"},
    37943: {"Unified_Ideograph", "Ideographic"},
    37944: {"Unified_Ideograph", "Ideographic"},
    37945: {"Unified_Ideograph", "Ideographic"},
    37946: {"Unified_Ideograph", "Ideographic"},
    37947: {"Unified_Ideograph", "Ideographic"},
    37948: {"Unified_Ideograph", "Ideographic"},
    37949: {"Unified_Ideograph", "Ideographic"},
    37950: {"Unified_Ideograph", "Ideographic"},
    37951: {"Unified_Ideograph", "Ideographic"},
    37952: {"Unified_Ideograph", "Ideographic"},
    37953: {"Unified_Ideograph", "Ideographic"},
    37954: {"Unified_Ideograph", "Ideographic"},
    37955: {"Unified_Ideograph", "Ideographic"},
    37956: {"Unified_Ideograph", "Ideographic"},
    37957: {"Unified_Ideograph", "Ideographic"},
    37958: {"Unified_Ideograph", "Ideographic"},
    37959: {"Unified_Ideograph", "Ideographic"},
    37960: {"Unified_Ideograph", "Ideographic"},
    37961: {"Unified_Ideograph", "Ideographic"},
    37962: {"Unified_Ideograph", "Ideographic"},
    37963: {"Unified_Ideograph", "Ideographic"},
    37964: {"Unified_Ideograph", "Ideographic"},
    37965: {"Unified_Ideograph", "Ideographic"},
    37966: {"Unified_Ideograph", "Ideographic"},
    37967: {"Unified_Ideograph", "Ideographic"},
    37968: {"Unified_Ideograph", "Ideographic"},
    37969: {"Unified_Ideograph", "Ideographic"},
    37970: {"Unified_Ideograph", "Ideographic"},
    37971: {"Unified_Ideograph", "Ideographic"},
    37972: {"Unified_Ideograph", "Ideographic"},
    37973: {"Unified_Ideograph", "Ideographic"},
    37974: {"Unified_Ideograph", "Ideographic"},
    37975: {"Unified_Ideograph", "Ideographic"},
    37976: {"Unified_Ideograph", "Ideographic"},
    37977: {"Unified_Ideograph", "Ideographic"},
    37978: {"Unified_Ideograph", "Ideographic"},
    37979: {"Unified_Ideograph", "Ideographic"},
    37980: {"Unified_Ideograph", "Ideographic"},
    37981: {"Unified_Ideograph", "Ideographic"},
    37982: {"Unified_Ideograph", "Ideographic"},
    37983: {"Unified_Ideograph", "Ideographic"},
    37984: {"Unified_Ideograph", "Ideographic"},
    37985: {"Unified_Ideograph", "Ideographic"},
    37986: {"Unified_Ideograph", "Ideographic"},
    37987: {"Unified_Ideograph", "Ideographic"},
    37988: {"Unified_Ideograph", "Ideographic"},
    37989: {"Unified_Ideograph", "Ideographic"},
    37990: {"Unified_Ideograph", "Ideographic"},
    37991: {"Unified_Ideograph", "Ideographic"},
    37992: {"Unified_Ideograph", "Ideographic"},
    37993: {"Unified_Ideograph", "Ideographic"},
    37994: {"Unified_Ideograph", "Ideographic"},
    37995: {"Unified_Ideograph", "Ideographic"},
    37996: {"Unified_Ideograph", "Ideographic"},
    37997: {"Unified_Ideograph", "Ideographic"},
    37998: {"Unified_Ideograph", "Ideographic"},
    37999: {"Unified_Ideograph", "Ideographic"},
    38000: {"Unified_Ideograph", "Ideographic"},
    38001: {"Unified_Ideograph", "Ideographic"},
    38002: {"Unified_Ideograph", "Ideographic"},
    38003: {"Unified_Ideograph", "Ideographic"},
    38004: {"Unified_Ideograph", "Ideographic"},
    38005: {"Unified_Ideograph", "Ideographic"},
    38006: {"Unified_Ideograph", "Ideographic"},
    38007: {"Unified_Ideograph", "Ideographic"},
    38008: {"Unified_Ideograph", "Ideographic"},
    38009: {"Unified_Ideograph", "Ideographic"},
    38010: {"Unified_Ideograph", "Ideographic"},
    38011: {"Unified_Ideograph", "Ideographic"},
    38012: {"Unified_Ideograph", "Ideographic"},
    38013: {"Unified_Ideograph", "Ideographic"},
    38014: {"Unified_Ideograph", "Ideographic"},
    38015: {"Unified_Ideograph", "Ideographic"},
    38016: {"Unified_Ideograph", "Ideographic"},
    38017: {"Unified_Ideograph", "Ideographic"},
    38018: {"Unified_Ideograph", "Ideographic"},
    38019: {"Unified_Ideograph", "Ideographic"},
    38020: {"Unified_Ideograph", "Ideographic"},
    38021: {"Unified_Ideograph", "Ideographic"},
    38022: {"Unified_Ideograph", "Ideographic"},
    38023: {"Unified_Ideograph", "Ideographic"},
    38024: {"Unified_Ideograph", "Ideographic"},
    38025: {"Unified_Ideograph", "Ideographic"},
    38026: {"Unified_Ideograph", "Ideographic"},
    38027: {"Unified_Ideograph", "Ideographic"},
    38028: {"Unified_Ideograph", "Ideographic"},
    38029: {"Unified_Ideograph", "Ideographic"},
    38030: {"Unified_Ideograph", "Ideographic"},
    38031: {"Unified_Ideograph", "Ideographic"},
    38032: {"Unified_Ideograph", "Ideographic"},
    38033: {"Unified_Ideograph", "Ideographic"},
    38034: {"Unified_Ideograph", "Ideographic"},
    38035: {"Unified_Ideograph", "Ideographic"},
    38036: {"Unified_Ideograph", "Ideographic"},
    38037: {"Unified_Ideograph", "Ideographic"},
    38038: {"Unified_Ideograph", "Ideographic"},
    38039: {"Unified_Ideograph", "Ideographic"},
    38040: {"Unified_Ideograph", "Ideographic"},
    38041: {"Unified_Ideograph", "Ideographic"},
    38042: {"Unified_Ideograph", "Ideographic"},
    38043: {"Unified_Ideograph", "Ideographic"},
    38044: {"Unified_Ideograph", "Ideographic"},
    38045: {"Unified_Ideograph", "Ideographic"},
    38046: {"Unified_Ideograph", "Ideographic"},
    38047: {"Unified_Ideograph", "Ideographic"},
    38048: {"Unified_Ideograph", "Ideographic"},
    38049: {"Unified_Ideograph", "Ideographic"},
    38050: {"Unified_Ideograph", "Ideographic"},
    38051: {"Unified_Ideograph", "Ideographic"},
    38052: {"Unified_Ideograph", "Ideographic"},
    38053: {"Unified_Ideograph", "Ideographic"},
    38054: {"Unified_Ideograph", "Ideographic"},
    38055: {"Unified_Ideograph", "Ideographic"},
    38056: {"Unified_Ideograph", "Ideographic"},
    38057: {"Unified_Ideograph", "Ideographic"},
    38058: {"Unified_Ideograph", "Ideographic"},
    38059: {"Unified_Ideograph", "Ideographic"},
    38060: {"Unified_Ideograph", "Ideographic"},
    38061: {"Unified_Ideograph", "Ideographic"},
    38062: {"Unified_Ideograph", "Ideographic"},
    38063: {"Unified_Ideograph", "Ideographic"},
    38064: {"Unified_Ideograph", "Ideographic"},
    38065: {"Unified_Ideograph", "Ideographic"},
    38066: {"Unified_Ideograph", "Ideographic"},
    38067: {"Unified_Ideograph", "Ideographic"},
    38068: {"Unified_Ideograph", "Ideographic"},
    38069: {"Unified_Ideograph", "Ideographic"},
    38070: {"Unified_Ideograph", "Ideographic"},
    38071: {"Unified_Ideograph", "Ideographic"},
    38072: {"Unified_Ideograph", "Ideographic"},
    38073: {"Unified_Ideograph", "Ideographic"},
    38074: {"Unified_Ideograph", "Ideographic"},
    38075: {"Unified_Ideograph", "Ideographic"},
    38076: {"Unified_Ideograph", "Ideographic"},
    38077: {"Unified_Ideograph", "Ideographic"},
    38078: {"Unified_Ideograph", "Ideographic"},
    38079: {"Unified_Ideograph", "Ideographic"},
    38080: {"Unified_Ideograph", "Ideographic"},
    38081: {"Unified_Ideograph", "Ideographic"},
    38082: {"Unified_Ideograph", "Ideographic"},
    38083: {"Unified_Ideograph", "Ideographic"},
    38084: {"Unified_Ideograph", "Ideographic"},
    38085: {"Unified_Ideograph", "Ideographic"},
    38086: {"Unified_Ideograph", "Ideographic"},
    38087: {"Unified_Ideograph", "Ideographic"},
    38088: {"Unified_Ideograph", "Ideographic"},
    38089: {"Unified_Ideograph", "Ideographic"},
    38090: {"Unified_Ideograph", "Ideographic"},
    38091: {"Unified_Ideograph", "Ideographic"},
    38092: {"Unified_Ideograph", "Ideographic"},
    38093: {"Unified_Ideograph", "Ideographic"},
    38094: {"Unified_Ideograph", "Ideographic"},
    38095: {"Unified_Ideograph", "Ideographic"},
    38096: {"Unified_Ideograph", "Ideographic"},
    38097: {"Unified_Ideograph", "Ideographic"},
    38098: {"Unified_Ideograph", "Ideographic"},
    38099: {"Unified_Ideograph", "Ideographic"},
    38100: {"Unified_Ideograph", "Ideographic"},
    38101: {"Unified_Ideograph", "Ideographic"},
    38102: {"Unified_Ideograph", "Ideographic"},
    38103: {"Unified_Ideograph", "Ideographic"},
    38104: {"Unified_Ideograph", "Ideographic"},
    38105: {"Unified_Ideograph", "Ideographic"},
    38106: {"Unified_Ideograph", "Ideographic"},
    38107: {"Unified_Ideograph", "Ideographic"},
    38108: {"Unified_Ideograph", "Ideographic"},
    38109: {"Unified_Ideograph", "Ideographic"},
    38110: {"Unified_Ideograph", "Ideographic"},
    38111: {"Unified_Ideograph", "Ideographic"},
    38112: {"Unified_Ideograph", "Ideographic"},
    38113: {"Unified_Ideograph", "Ideographic"},
    38114: {"Unified_Ideograph", "Ideographic"},
    38115: {"Unified_Ideograph", "Ideographic"},
    38116: {"Unified_Ideograph", "Ideographic"},
    38117: {"Unified_Ideograph", "Ideographic"},
    38118: {"Unified_Ideograph", "Ideographic"},
    38119: {"Unified_Ideograph", "Ideographic"},
    38120: {"Unified_Ideograph", "Ideographic"},
    38121: {"Unified_Ideograph", "Ideographic"},
    38122: {"Unified_Ideograph", "Ideographic"},
    38123: {"Unified_Ideograph", "Ideographic"},
    38124: {"Unified_Ideograph", "Ideographic"},
    38125: {"Unified_Ideograph", "Ideographic"},
    38126: {"Unified_Ideograph", "Ideographic"},
    38127: {"Unified_Ideograph", "Ideographic"},
    38128: {"Unified_Ideograph", "Ideographic"},
    38129: {"Unified_Ideograph", "Ideographic"},
    38130: {"Unified_Ideograph", "Ideographic"},
    38131: {"Unified_Ideograph", "Ideographic"},
    38132: {"Unified_Ideograph", "Ideographic"},
    38133: {"Unified_Ideograph", "Ideographic"},
    38134: {"Unified_Ideograph", "Ideographic"},
    38135: {"Unified_Ideograph", "Ideographic"},
    38136: {"Unified_Ideograph", "Ideographic"},
    38137: {"Unified_Ideograph", "Ideographic"},
    38138: {"Unified_Ideograph", "Ideographic"},
    38139: {"Unified_Ideograph", "Ideographic"},
    38140: {"Unified_Ideograph", "Ideographic"},
    38141: {"Unified_Ideograph", "Ideographic"},
    38142: {"Unified_Ideograph", "Ideographic"},
    38143: {"Unified_Ideograph", "Ideographic"},
    38144: {"Unified_Ideograph", "Ideographic"},
    38145: {"Unified_Ideograph", "Ideographic"},
    38146: {"Unified_Ideograph", "Ideographic"},
    38147: {"Unified_Ideograph", "Ideographic"},
    38148: {"Unified_Ideograph", "Ideographic"},
    38149: {"Unified_Ideograph", "Ideographic"},
    38150: {"Unified_Ideograph", "Ideographic"},
    38151: {"Unified_Ideograph", "Ideographic"},
    38152: {"Unified_Ideograph", "Ideographic"},
    38153: {"Unified_Ideograph", "Ideographic"},
    38154: {"Unified_Ideograph", "Ideographic"},
    38155: {"Unified_Ideograph", "Ideographic"},
    38156: {"Unified_Ideograph", "Ideographic"},
    38157: {"Unified_Ideograph", "Ideographic"},
    38158: {"Unified_Ideograph", "Ideographic"},
    38159: {"Unified_Ideograph", "Ideographic"},
    38160: {"Unified_Ideograph", "Ideographic"},
    38161: {"Unified_Ideograph", "Ideographic"},
    38162: {"Unified_Ideograph", "Ideographic"},
    38163: {"Unified_Ideograph", "Ideographic"},
    38164: {"Unified_Ideograph", "Ideographic"},
    38165: {"Unified_Ideograph", "Ideographic"},
    38166: {"Unified_Ideograph", "Ideographic"},
    38167: {"Unified_Ideograph", "Ideographic"},
    38168: {"Unified_Ideograph", "Ideographic"},
    38169: {"Unified_Ideograph", "Ideographic"},
    38170: {"Unified_Ideograph", "Ideographic"},
    38171: {"Unified_Ideograph", "Ideographic"},
    38172: {"Unified_Ideograph", "Ideographic"},
    38173: {"Unified_Ideograph", "Ideographic"},
    38174: {"Unified_Ideograph", "Ideographic"},
    38175: {"Unified_Ideograph", "Ideographic"},
    38176: {"Unified_Ideograph", "Ideographic"},
    38177: {"Unified_Ideograph", "Ideographic"},
    38178: {"Unified_Ideograph", "Ideographic"},
    38179: {"Unified_Ideograph", "Ideographic"},
    38180: {"Unified_Ideograph", "Ideographic"},
    38181: {"Unified_Ideograph", "Ideographic"},
    38182: {"Unified_Ideograph", "Ideographic"},
    38183: {"Unified_Ideograph", "Ideographic"},
    38184: {"Unified_Ideograph", "Ideographic"},
    38185: {"Unified_Ideograph", "Ideographic"},
    38186: {"Unified_Ideograph", "Ideographic"},
    38187: {"Unified_Ideograph", "Ideographic"},
    38188: {"Unified_Ideograph", "Ideographic"},
    38189: {"Unified_Ideograph", "Ideographic"},
    38190: {"Unified_Ideograph", "Ideographic"},
    38191: {"Unified_Ideograph", "Ideographic"},
    38192: {"Unified_Ideograph", "Ideographic"},
    38193: {"Unified_Ideograph", "Ideographic"},
    38194: {"Unified_Ideograph", "Ideographic"},
    38195: {"Unified_Ideograph", "Ideographic"},
    38196: {"Unified_Ideograph", "Ideographic"},
    38197: {"Unified_Ideograph", "Ideographic"},
    38198: {"Unified_Ideograph", "Ideographic"},
    38199: {"Unified_Ideograph", "Ideographic"},
    38200: {"Unified_Ideograph", "Ideographic"},
    38201: {"Unified_Ideograph", "Ideographic"},
    38202: {"Unified_Ideograph", "Ideographic"},
    38203: {"Unified_Ideograph", "Ideographic"},
    38204: {"Unified_Ideograph", "Ideographic"},
    38205: {"Unified_Ideograph", "Ideographic"},
    38206: {"Unified_Ideograph", "Ideographic"},
    38207: {"Unified_Ideograph", "Ideographic"},
    38208: {"Unified_Ideograph", "Ideographic"},
    38209: {"Unified_Ideograph", "Ideographic"},
    38210: {"Unified_Ideograph", "Ideographic"},
    38211: {"Unified_Ideograph", "Ideographic"},
    38212: {"Unified_Ideograph", "Ideographic"},
    38213: {"Unified_Ideograph", "Ideographic"},
    38214: {"Unified_Ideograph", "Ideographic"},
    38215: {"Unified_Ideograph", "Ideographic"},
    38216: {"Unified_Ideograph", "Ideographic"},
    38217: {"Unified_Ideograph", "Ideographic"},
    38218: {"Unified_Ideograph", "Ideographic"},
    38219: {"Unified_Ideograph", "Ideographic"},
    38220: {"Unified_Ideograph", "Ideographic"},
    38221: {"Unified_Ideograph", "Ideographic"},
    38222: {"Unified_Ideograph", "Ideographic"},
    38223: {"Unified_Ideograph", "Ideographic"},
    38224: {"Unified_Ideograph", "Ideographic"},
    38225: {"Unified_Ideograph", "Ideographic"},
    38226: {"Unified_Ideograph", "Ideographic"},
    38227: {"Unified_Ideograph", "Ideographic"},
    38228: {"Unified_Ideograph", "Ideographic"},
    38229: {"Unified_Ideograph", "Ideographic"},
    38230: {"Unified_Ideograph", "Ideographic"},
    38231: {"Unified_Ideograph", "Ideographic"},
    38232: {"Unified_Ideograph", "Ideographic"},
    38233: {"Unified_Ideograph", "Ideographic"},
    38234: {"Unified_Ideograph", "Ideographic"},
    38235: {"Unified_Ideograph", "Ideographic"},
    38236: {"Unified_Ideograph", "Ideographic"},
    38237: {"Unified_Ideograph", "Ideographic"},
    38238: {"Unified_Ideograph", "Ideographic"},
    38239: {"Unified_Ideograph", "Ideographic"},
    38240: {"Unified_Ideograph", "Ideographic"},
    38241: {"Unified_Ideograph", "Ideographic"},
    38242: {"Unified_Ideograph", "Ideographic"},
    38243: {"Unified_Ideograph", "Ideographic"},
    38244: {"Unified_Ideograph", "Ideographic"},
    38245: {"Unified_Ideograph", "Ideographic"},
    38246: {"Unified_Ideograph", "Ideographic"},
    38247: {"Unified_Ideograph", "Ideographic"},
    38248: {"Unified_Ideograph", "Ideographic"},
    38249: {"Unified_Ideograph", "Ideographic"},
    38250: {"Unified_Ideograph", "Ideographic"},
    38251: {"Unified_Ideograph", "Ideographic"},
    38252: {"Unified_Ideograph", "Ideographic"},
    38253: {"Unified_Ideograph", "Ideographic"},
    38254: {"Unified_Ideograph", "Ideographic"},
    38255: {"Unified_Ideograph", "Ideographic"},
    38256: {"Unified_Ideograph", "Ideographic"},
    38257: {"Unified_Ideograph", "Ideographic"},
    38258: {"Unified_Ideograph", "Ideographic"},
    38259: {"Unified_Ideograph", "Ideographic"},
    38260: {"Unified_Ideograph", "Ideographic"},
    38261: {"Unified_Ideograph", "Ideographic"},
    38262: {"Unified_Ideograph", "Ideographic"},
    38263: {"Unified_Ideograph", "Ideographic"},
    38264: {"Unified_Ideograph", "Ideographic"},
    38265: {"Unified_Ideograph", "Ideographic"},
    38266: {"Unified_Ideograph", "Ideographic"},
    38267: {"Unified_Ideograph", "Ideographic"},
    38268: {"Unified_Ideograph", "Ideographic"},
    38269: {"Unified_Ideograph", "Ideographic"},
    38270: {"Unified_Ideograph", "Ideographic"},
    38271: {"Unified_Ideograph", "Ideographic"},
    38272: {"Unified_Ideograph", "Ideographic"},
    38273: {"Unified_Ideograph", "Ideographic"},
    38274: {"Unified_Ideograph", "Ideographic"},
    38275: {"Unified_Ideograph", "Ideographic"},
    38276: {"Unified_Ideograph", "Ideographic"},
    38277: {"Unified_Ideograph", "Ideographic"},
    38278: {"Unified_Ideograph", "Ideographic"},
    38279: {"Unified_Ideograph", "Ideographic"},
    38280: {"Unified_Ideograph", "Ideographic"},
    38281: {"Unified_Ideograph", "Ideographic"},
    38282: {"Unified_Ideograph", "Ideographic"},
    38283: {"Unified_Ideograph", "Ideographic"},
    38284: {"Unified_Ideograph", "Ideographic"},
    38285: {"Unified_Ideograph", "Ideographic"},
    38286: {"Unified_Ideograph", "Ideographic"},
    38287: {"Unified_Ideograph", "Ideographic"},
    38288: {"Unified_Ideograph", "Ideographic"},
    38289: {"Unified_Ideograph", "Ideographic"},
    38290: {"Unified_Ideograph", "Ideographic"},
    38291: {"Unified_Ideograph", "Ideographic"},
    38292: {"Unified_Ideograph", "Ideographic"},
    38293: {"Unified_Ideograph", "Ideographic"},
    38294: {"Unified_Ideograph", "Ideographic"},
    38295: {"Unified_Ideograph", "Ideographic"},
    38296: {"Unified_Ideograph", "Ideographic"},
    38297: {"Unified_Ideograph", "Ideographic"},
    38298: {"Unified_Ideograph", "Ideographic"},
    38299: {"Unified_Ideograph", "Ideographic"},
    38300: {"Unified_Ideograph", "Ideographic"},
    38301: {"Unified_Ideograph", "Ideographic"},
    38302: {"Unified_Ideograph", "Ideographic"},
    38303: {"Unified_Ideograph", "Ideographic"},
    38304: {"Unified_Ideograph", "Ideographic"},
    38305: {"Unified_Ideograph", "Ideographic"},
    38306: {"Unified_Ideograph", "Ideographic"},
    38307: {"Unified_Ideograph", "Ideographic"},
    38308: {"Unified_Ideograph", "Ideographic"},
    38309: {"Unified_Ideograph", "Ideographic"},
    38310: {"Unified_Ideograph", "Ideographic"},
    38311: {"Unified_Ideograph", "Ideographic"},
    38312: {"Unified_Ideograph", "Ideographic"},
    38313: {"Unified_Ideograph", "Ideographic"},
    38314: {"Unified_Ideograph", "Ideographic"},
    38315: {"Unified_Ideograph", "Ideographic"},
    38316: {"Unified_Ideograph", "Ideographic"},
    38317: {"Unified_Ideograph", "Ideographic"},
    38318: {"Unified_Ideograph", "Ideographic"},
    38319: {"Unified_Ideograph", "Ideographic"},
    38320: {"Unified_Ideograph", "Ideographic"},
    38321: {"Unified_Ideograph", "Ideographic"},
    38322: {"Unified_Ideograph", "Ideographic"},
    38323: {"Unified_Ideograph", "Ideographic"},
    38324: {"Unified_Ideograph", "Ideographic"},
    38325: {"Unified_Ideograph", "Ideographic"},
    38326: {"Unified_Ideograph", "Ideographic"},
    38327: {"Unified_Ideograph", "Ideographic"},
    38328: {"Unified_Ideograph", "Ideographic"},
    38329: {"Unified_Ideograph", "Ideographic"},
    38330: {"Unified_Ideograph", "Ideographic"},
    38331: {"Unified_Ideograph", "Ideographic"},
    38332: {"Unified_Ideograph", "Ideographic"},
    38333: {"Unified_Ideograph", "Ideographic"},
    38334: {"Unified_Ideograph", "Ideographic"},
    38335: {"Unified_Ideograph", "Ideographic"},
    38336: {"Unified_Ideograph", "Ideographic"},
    38337: {"Unified_Ideograph", "Ideographic"},
    38338: {"Unified_Ideograph", "Ideographic"},
    38339: {"Unified_Ideograph", "Ideographic"},
    38340: {"Unified_Ideograph", "Ideographic"},
    38341: {"Unified_Ideograph", "Ideographic"},
    38342: {"Unified_Ideograph", "Ideographic"},
    38343: {"Unified_Ideograph", "Ideographic"},
    38344: {"Unified_Ideograph", "Ideographic"},
    38345: {"Unified_Ideograph", "Ideographic"},
    38346: {"Unified_Ideograph", "Ideographic"},
    38347: {"Unified_Ideograph", "Ideographic"},
    38348: {"Unified_Ideograph", "Ideographic"},
    38349: {"Unified_Ideograph", "Ideographic"},
    38350: {"Unified_Ideograph", "Ideographic"},
    38351: {"Unified_Ideograph", "Ideographic"},
    38352: {"Unified_Ideograph", "Ideographic"},
    38353: {"Unified_Ideograph", "Ideographic"},
    38354: {"Unified_Ideograph", "Ideographic"},
    38355: {"Unified_Ideograph", "Ideographic"},
    38356: {"Unified_Ideograph", "Ideographic"},
    38357: {"Unified_Ideograph", "Ideographic"},
    38358: {"Unified_Ideograph", "Ideographic"},
    38359: {"Unified_Ideograph", "Ideographic"},
    38360: {"Unified_Ideograph", "Ideographic"},
    38361: {"Unified_Ideograph", "Ideographic"},
    38362: {"Unified_Ideograph", "Ideographic"},
    38363: {"Unified_Ideograph", "Ideographic"},
    38364: {"Unified_Ideograph", "Ideographic"},
    38365: {"Unified_Ideograph", "Ideographic"},
    38366: {"Unified_Ideograph", "Ideographic"},
    38367: {"Unified_Ideograph", "Ideographic"},
    38368: {"Unified_Ideograph", "Ideographic"},
    38369: {"Unified_Ideograph", "Ideographic"},
    38370: {"Unified_Ideograph", "Ideographic"},
    38371: {"Unified_Ideograph", "Ideographic"},
    38372: {"Unified_Ideograph", "Ideographic"},
    38373: {"Unified_Ideograph", "Ideographic"},
    38374: {"Unified_Ideograph", "Ideographic"},
    38375: {"Unified_Ideograph", "Ideographic"},
    38376: {"Unified_Ideograph", "Ideographic"},
    38377: {"Unified_Ideograph", "Ideographic"},
    38378: {"Unified_Ideograph", "Ideographic"},
    38379: {"Unified_Ideograph", "Ideographic"},
    38380: {"Unified_Ideograph", "Ideographic"},
    38381: {"Unified_Ideograph", "Ideographic"},
    38382: {"Unified_Ideograph", "Ideographic"},
    38383: {"Unified_Ideograph", "Ideographic"},
    38384: {"Unified_Ideograph", "Ideographic"},
    38385: {"Unified_Ideograph", "Ideographic"},
    38386: {"Unified_Ideograph", "Ideographic"},
    38387: {"Unified_Ideograph", "Ideographic"},
    38388: {"Unified_Ideograph", "Ideographic"},
    38389: {"Unified_Ideograph", "Ideographic"},
    38390: {"Unified_Ideograph", "Ideographic"},
    38391: {"Unified_Ideograph", "Ideographic"},
    38392: {"Unified_Ideograph", "Ideographic"},
    38393: {"Unified_Ideograph", "Ideographic"},
    38394: {"Unified_Ideograph", "Ideographic"},
    38395: {"Unified_Ideograph", "Ideographic"},
    38396: {"Unified_Ideograph", "Ideographic"},
    38397: {"Unified_Ideograph", "Ideographic"},
    38398: {"Unified_Ideograph", "Ideographic"},
    38399: {"Unified_Ideograph", "Ideographic"},
    38400: {"Unified_Ideograph", "Ideographic"},
    38401: {"Unified_Ideograph", "Ideographic"},
    38402: {"Unified_Ideograph", "Ideographic"},
    38403: {"Unified_Ideograph", "Ideographic"},
    38404: {"Unified_Ideograph", "Ideographic"},
    38405: {"Unified_Ideograph", "Ideographic"},
    38406: {"Unified_Ideograph", "Ideographic"},
    38407: {"Unified_Ideograph", "Ideographic"},
    38408: {"Unified_Ideograph", "Ideographic"},
    38409: {"Unified_Ideograph", "Ideographic"},
    38410: {"Unified_Ideograph", "Ideographic"},
    38411: {"Unified_Ideograph", "Ideographic"},
    38412: {"Unified_Ideograph", "Ideographic"},
    38413: {"Unified_Ideograph", "Ideographic"},
    38414: {"Unified_Ideograph", "Ideographic"},
    38415: {"Unified_Ideograph", "Ideographic"},
    38416: {"Unified_Ideograph", "Ideographic"},
    38417: {"Unified_Ideograph", "Ideographic"},
    38418: {"Unified_Ideograph", "Ideographic"},
    38419: {"Unified_Ideograph", "Ideographic"},
    38420: {"Unified_Ideograph", "Ideographic"},
    38421: {"Unified_Ideograph", "Ideographic"},
    38422: {"Unified_Ideograph", "Ideographic"},
    38423: {"Unified_Ideograph", "Ideographic"},
    38424: {"Unified_Ideograph", "Ideographic"},
    38425: {"Unified_Ideograph", "Ideographic"},
    38426: {"Unified_Ideograph", "Ideographic"},
    38427: {"Unified_Ideograph", "Ideographic"},
    38428: {"Unified_Ideograph", "Ideographic"},
    38429: {"Unified_Ideograph", "Ideographic"},
    38430: {"Unified_Ideograph", "Ideographic"},
    38431: {"Unified_Ideograph", "Ideographic"},
    38432: {"Unified_Ideograph", "Ideographic"},
    38433: {"Unified_Ideograph", "Ideographic"},
    38434: {"Unified_Ideograph", "Ideographic"},
    38435: {"Unified_Ideograph", "Ideographic"},
    38436: {"Unified_Ideograph", "Ideographic"},
    38437: {"Unified_Ideograph", "Ideographic"},
    38438: {"Unified_Ideograph", "Ideographic"},
    38439: {"Unified_Ideograph", "Ideographic"},
    38440: {"Unified_Ideograph", "Ideographic"},
    38441: {"Unified_Ideograph", "Ideographic"},
    38442: {"Unified_Ideograph", "Ideographic"},
    38443: {"Unified_Ideograph", "Ideographic"},
    38444: {"Unified_Ideograph", "Ideographic"},
    38445: {"Unified_Ideograph", "Ideographic"},
    38446: {"Unified_Ideograph", "Ideographic"},
    38447: {"Unified_Ideograph", "Ideographic"},
    38448: {"Unified_Ideograph", "Ideographic"},
    38449: {"Unified_Ideograph", "Ideographic"},
    38450: {"Unified_Ideograph", "Ideographic"},
    38451: {"Unified_Ideograph", "Ideographic"},
    38452: {"Unified_Ideograph", "Ideographic"},
    38453: {"Unified_Ideograph", "Ideographic"},
    38454: {"Unified_Ideograph", "Ideographic"},
    38455: {"Unified_Ideograph", "Ideographic"},
    38456: {"Unified_Ideograph", "Ideographic"},
    38457: {"Unified_Ideograph", "Ideographic"},
    38458: {"Unified_Ideograph", "Ideographic"},
    38459: {"Unified_Ideograph", "Ideographic"},
    38460: {"Unified_Ideograph", "Ideographic"},
    38461: {"Unified_Ideograph", "Ideographic"},
    38462: {"Unified_Ideograph", "Ideographic"},
    38463: {"Unified_Ideograph", "Ideographic"},
    38464: {"Unified_Ideograph", "Ideographic"},
    38465: {"Unified_Ideograph", "Ideographic"},
    38466: {"Unified_Ideograph", "Ideographic"},
    38467: {"Unified_Ideograph", "Ideographic"},
    38468: {"Unified_Ideograph", "Ideographic"},
    38469: {"Unified_Ideograph", "Ideographic"},
    38470: {"Unified_Ideograph", "Ideographic"},
    38471: {"Unified_Ideograph", "Ideographic"},
    38472: {"Unified_Ideograph", "Ideographic"},
    38473: {"Unified_Ideograph", "Ideographic"},
    38474: {"Unified_Ideograph", "Ideographic"},
    38475: {"Unified_Ideograph", "Ideographic"},
    38476: {"Unified_Ideograph", "Ideographic"},
    38477: {"Unified_Ideograph", "Ideographic"},
    38478: {"Unified_Ideograph", "Ideographic"},
    38479: {"Unified_Ideograph", "Ideographic"},
    38480: {"Unified_Ideograph", "Ideographic"},
    38481: {"Unified_Ideograph", "Ideographic"},
    38482: {"Unified_Ideograph", "Ideographic"},
    38483: {"Unified_Ideograph", "Ideographic"},
    38484: {"Unified_Ideograph", "Ideographic"},
    38485: {"Unified_Ideograph", "Ideographic"},
    38486: {"Unified_Ideograph", "Ideographic"},
    38487: {"Unified_Ideograph", "Ideographic"},
    38488: {"Unified_Ideograph", "Ideographic"},
    38489: {"Unified_Ideograph", "Ideographic"},
    38490: {"Unified_Ideograph", "Ideographic"},
    38491: {"Unified_Ideograph", "Ideographic"},
    38492: {"Unified_Ideograph", "Ideographic"},
    38493: {"Unified_Ideograph", "Ideographic"},
    38494: {"Unified_Ideograph", "Ideographic"},
    38495: {"Unified_Ideograph", "Ideographic"},
    38496: {"Unified_Ideograph", "Ideographic"},
    38497: {"Unified_Ideograph", "Ideographic"},
    38498: {"Unified_Ideograph", "Ideographic"},
    38499: {"Unified_Ideograph", "Ideographic"},
    38500: {"Unified_Ideograph", "Ideographic"},
    38501: {"Unified_Ideograph", "Ideographic"},
    38502: {"Unified_Ideograph", "Ideographic"},
    38503: {"Unified_Ideograph", "Ideographic"},
    38504: {"Unified_Ideograph", "Ideographic"},
    38505: {"Unified_Ideograph", "Ideographic"},
    38506: {"Unified_Ideograph", "Ideographic"},
    38507: {"Unified_Ideograph", "Ideographic"},
    38508: {"Unified_Ideograph", "Ideographic"},
    38509: {"Unified_Ideograph", "Ideographic"},
    38510: {"Unified_Ideograph", "Ideographic"},
    38511: {"Unified_Ideograph", "Ideographic"},
    38512: {"Unified_Ideograph", "Ideographic"},
    38513: {"Unified_Ideograph", "Ideographic"},
    38514: {"Unified_Ideograph", "Ideographic"},
    38515: {"Unified_Ideograph", "Ideographic"},
    38516: {"Unified_Ideograph", "Ideographic"},
    38517: {"Unified_Ideograph", "Ideographic"},
    38518: {"Unified_Ideograph", "Ideographic"},
    38519: {"Unified_Ideograph", "Ideographic"},
    38520: {"Unified_Ideograph", "Ideographic"},
    38521: {"Unified_Ideograph", "Ideographic"},
    38522: {"Unified_Ideograph", "Ideographic"},
    38523: {"Unified_Ideograph", "Ideographic"},
    38524: {"Unified_Ideograph", "Ideographic"},
    38525: {"Unified_Ideograph", "Ideographic"},
    38526: {"Unified_Ideograph", "Ideographic"},
    38527: {"Unified_Ideograph", "Ideographic"},
    38528: {"Unified_Ideograph", "Ideographic"},
    38529: {"Unified_Ideograph", "Ideographic"},
    38530: {"Unified_Ideograph", "Ideographic"},
    38531: {"Unified_Ideograph", "Ideographic"},
    38532: {"Unified_Ideograph", "Ideographic"},
    38533: {"Unified_Ideograph", "Ideographic"},
    38534: {"Unified_Ideograph", "Ideographic"},
    38535: {"Unified_Ideograph", "Ideographic"},
    38536: {"Unified_Ideograph", "Ideographic"},
    38537: {"Unified_Ideograph", "Ideographic"},
    38538: {"Unified_Ideograph", "Ideographic"},
    38539: {"Unified_Ideograph", "Ideographic"},
    38540: {"Unified_Ideograph", "Ideographic"},
    38541: {"Unified_Ideograph", "Ideographic"},
    38542: {"Unified_Ideograph", "Ideographic"},
    38543: {"Unified_Ideograph", "Ideographic"},
    38544: {"Unified_Ideograph", "Ideographic"},
    38545: {"Unified_Ideograph", "Ideographic"},
    38546: {"Unified_Ideograph", "Ideographic"},
    38547: {"Unified_Ideograph", "Ideographic"},
    38548: {"Unified_Ideograph", "Ideographic"},
    38549: {"Unified_Ideograph", "Ideographic"},
    38550: {"Unified_Ideograph", "Ideographic"},
    38551: {"Unified_Ideograph", "Ideographic"},
    38552: {"Unified_Ideograph", "Ideographic"},
    38553: {"Unified_Ideograph", "Ideographic"},
    38554: {"Unified_Ideograph", "Ideographic"},
    38555: {"Unified_Ideograph", "Ideographic"},
    38556: {"Unified_Ideograph", "Ideographic"},
    38557: {"Unified_Ideograph", "Ideographic"},
    38558: {"Unified_Ideograph", "Ideographic"},
    38559: {"Unified_Ideograph", "Ideographic"},
    38560: {"Unified_Ideograph", "Ideographic"},
    38561: {"Unified_Ideograph", "Ideographic"},
    38562: {"Unified_Ideograph", "Ideographic"},
    38563: {"Unified_Ideograph", "Ideographic"},
    38564: {"Unified_Ideograph", "Ideographic"},
    38565: {"Unified_Ideograph", "Ideographic"},
    38566: {"Unified_Ideograph", "Ideographic"},
    38567: {"Unified_Ideograph", "Ideographic"},
    38568: {"Unified_Ideograph", "Ideographic"},
    38569: {"Unified_Ideograph", "Ideographic"},
    38570: {"Unified_Ideograph", "Ideographic"},
    38571: {"Unified_Ideograph", "Ideographic"},
    38572: {"Unified_Ideograph", "Ideographic"},
    38573: {"Unified_Ideograph", "Ideographic"},
    38574: {"Unified_Ideograph", "Ideographic"},
    38575: {"Unified_Ideograph", "Ideographic"},
    38576: {"Unified_Ideograph", "Ideographic"},
    38577: {"Unified_Ideograph", "Ideographic"},
    38578: {"Unified_Ideograph", "Ideographic"},
    38579: {"Unified_Ideograph", "Ideographic"},
    38580: {"Unified_Ideograph", "Ideographic"},
    38581: {"Unified_Ideograph", "Ideographic"},
    38582: {"Unified_Ideograph", "Ideographic"},
    38583: {"Unified_Ideograph", "Ideographic"},
    38584: {"Unified_Ideograph", "Ideographic"},
    38585: {"Unified_Ideograph", "Ideographic"},
    38586: {"Unified_Ideograph", "Ideographic"},
    38587: {"Unified_Ideograph", "Ideographic"},
    38588: {"Unified_Ideograph", "Ideographic"},
    38589: {"Unified_Ideograph", "Ideographic"},
    38590: {"Unified_Ideograph", "Ideographic"},
    38591: {"Unified_Ideograph", "Ideographic"},
    38592: {"Unified_Ideograph", "Ideographic"},
    38593: {"Unified_Ideograph", "Ideographic"},
    38594: {"Unified_Ideograph", "Ideographic"},
    38595: {"Unified_Ideograph", "Ideographic"},
    38596: {"Unified_Ideograph", "Ideographic"},
    38597: {"Unified_Ideograph", "Ideographic"},
    38598: {"Unified_Ideograph", "Ideographic"},
    38599: {"Unified_Ideograph", "Ideographic"},
    38600: {"Unified_Ideograph", "Ideographic"},
    38601: {"Unified_Ideograph", "Ideographic"},
    38602: {"Unified_Ideograph", "Ideographic"},
    38603: {"Unified_Ideograph", "Ideographic"},
    38604: {"Unified_Ideograph", "Ideographic"},
    38605: {"Unified_Ideograph", "Ideographic"},
    38606: {"Unified_Ideograph", "Ideographic"},
    38607: {"Unified_Ideograph", "Ideographic"},
    38608: {"Unified_Ideograph", "Ideographic"},
    38609: {"Unified_Ideograph", "Ideographic"},
    38610: {"Unified_Ideograph", "Ideographic"},
    38611: {"Unified_Ideograph", "Ideographic"},
    38612: {"Unified_Ideograph", "Ideographic"},
    38613: {"Unified_Ideograph", "Ideographic"},
    38614: {"Unified_Ideograph", "Ideographic"},
    38615: {"Unified_Ideograph", "Ideographic"},
    38616: {"Unified_Ideograph", "Ideographic"},
    38617: {"Unified_Ideograph", "Ideographic"},
    38618: {"Unified_Ideograph", "Ideographic"},
    38619: {"Unified_Ideograph", "Ideographic"},
    38620: {"Unified_Ideograph", "Ideographic"},
    38621: {"Unified_Ideograph", "Ideographic"},
    38622: {"Unified_Ideograph", "Ideographic"},
    38623: {"Unified_Ideograph", "Ideographic"},
    38624: {"Unified_Ideograph", "Ideographic"},
    38625: {"Unified_Ideograph", "Ideographic"},
    38626: {"Unified_Ideograph", "Ideographic"},
    38627: {"Unified_Ideograph", "Ideographic"},
    38628: {"Unified_Ideograph", "Ideographic"},
    38629: {"Unified_Ideograph", "Ideographic"},
    38630: {"Unified_Ideograph", "Ideographic"},
    38631: {"Unified_Ideograph", "Ideographic"},
    38632: {"Unified_Ideograph", "Ideographic"},
    38633: {"Unified_Ideograph", "Ideographic"},
    38634: {"Unified_Ideograph", "Ideographic"},
    38635: {"Unified_Ideograph", "Ideographic"},
    38636: {"Unified_Ideograph", "Ideographic"},
    38637: {"Unified_Ideograph", "Ideographic"},
    38638: {"Unified_Ideograph", "Ideographic"},
    38639: {"Unified_Ideograph", "Ideographic"},
    38640: {"Unified_Ideograph", "Ideographic"},
    38641: {"Unified_Ideograph", "Ideographic"},
    38642: {"Unified_Ideograph", "Ideographic"},
    38643: {"Unified_Ideograph", "Ideographic"},
    38644: {"Unified_Ideograph", "Ideographic"},
    38645: {"Unified_Ideograph", "Ideographic"},
    38646: {"Unified_Ideograph", "Ideographic"},
    38647: {"Unified_Ideograph", "Ideographic"},
    38648: {"Unified_Ideograph", "Ideographic"},
    38649: {"Unified_Ideograph", "Ideographic"},
    38650: {"Unified_Ideograph", "Ideographic"},
    38651: {"Unified_Ideograph", "Ideographic"},
    38652: {"Unified_Ideograph", "Ideographic"},
    38653: {"Unified_Ideograph", "Ideographic"},
    38654: {"Unified_Ideograph", "Ideographic"},
    38655: {"Unified_Ideograph", "Ideographic"},
    38656: {"Unified_Ideograph", "Ideographic"},
    38657: {"Unified_Ideograph", "Ideographic"},
    38658: {"Unified_Ideograph", "Ideographic"},
    38659: {"Unified_Ideograph", "Ideographic"},
    38660: {"Unified_Ideograph", "Ideographic"},
    38661: {"Unified_Ideograph", "Ideographic"},
    38662: {"Unified_Ideograph", "Ideographic"},
    38663: {"Unified_Ideograph", "Ideographic"},
    38664: {"Unified_Ideograph", "Ideographic"},
    38665: {"Unified_Ideograph", "Ideographic"},
    38666: {"Unified_Ideograph", "Ideographic"},
    38667: {"Unified_Ideograph", "Ideographic"},
    38668: {"Unified_Ideograph", "Ideographic"},
    38669: {"Unified_Ideograph", "Ideographic"},
    38670: {"Unified_Ideograph", "Ideographic"},
    38671: {"Unified_Ideograph", "Ideographic"},
    38672: {"Unified_Ideograph", "Ideographic"},
    38673: {"Unified_Ideograph", "Ideographic"},
    38674: {"Unified_Ideograph", "Ideographic"},
    38675: {"Unified_Ideograph", "Ideographic"},
    38676: {"Unified_Ideograph", "Ideographic"},
    38677: {"Unified_Ideograph", "Ideographic"},
    38678: {"Unified_Ideograph", "Ideographic"},
    38679: {"Unified_Ideograph", "Ideographic"},
    38680: {"Unified_Ideograph", "Ideographic"},
    38681: {"Unified_Ideograph", "Ideographic"},
    38682: {"Unified_Ideograph", "Ideographic"},
    38683: {"Unified_Ideograph", "Ideographic"},
    38684: {"Unified_Ideograph", "Ideographic"},
    38685: {"Unified_Ideograph", "Ideographic"},
    38686: {"Unified_Ideograph", "Ideographic"},
    38687: {"Unified_Ideograph", "Ideographic"},
    38688: {"Unified_Ideograph", "Ideographic"},
    38689: {"Unified_Ideograph", "Ideographic"},
    38690: {"Unified_Ideograph", "Ideographic"},
    38691: {"Unified_Ideograph", "Ideographic"},
    38692: {"Unified_Ideograph", "Ideographic"},
    38693: {"Unified_Ideograph", "Ideographic"},
    38694: {"Unified_Ideograph", "Ideographic"},
    38695: {"Unified_Ideograph", "Ideographic"},
    38696: {"Unified_Ideograph", "Ideographic"},
    38697: {"Unified_Ideograph", "Ideographic"},
    38698: {"Unified_Ideograph", "Ideographic"},
    38699: {"Unified_Ideograph", "Ideographic"},
    38700: {"Unified_Ideograph", "Ideographic"},
    38701: {"Unified_Ideograph", "Ideographic"},
    38702: {"Unified_Ideograph", "Ideographic"},
    38703: {"Unified_Ideograph", "Ideographic"},
    38704: {"Unified_Ideograph", "Ideographic"},
    38705: {"Unified_Ideograph", "Ideographic"},
    38706: {"Unified_Ideograph", "Ideographic"},
    38707: {"Unified_Ideograph", "Ideographic"},
    38708: {"Unified_Ideograph", "Ideographic"},
    38709: {"Unified_Ideograph", "Ideographic"},
    38710: {"Unified_Ideograph", "Ideographic"},
    38711: {"Unified_Ideograph", "Ideographic"},
    38712: {"Unified_Ideograph", "Ideographic"},
    38713: {"Unified_Ideograph", "Ideographic"},
    38714: {"Unified_Ideograph", "Ideographic"},
    38715: {"Unified_Ideograph", "Ideographic"},
    38716: {"Unified_Ideograph", "Ideographic"},
    38717: {"Unified_Ideograph", "Ideographic"},
    38718: {"Unified_Ideograph", "Ideographic"},
    38719: {"Unified_Ideograph", "Ideographic"},
    38720: {"Unified_Ideograph", "Ideographic"},
    38721: {"Unified_Ideograph", "Ideographic"},
    38722: {"Unified_Ideograph", "Ideographic"},
    38723: {"Unified_Ideograph", "Ideographic"},
    38724: {"Unified_Ideograph", "Ideographic"},
    38725: {"Unified_Ideograph", "Ideographic"},
    38726: {"Unified_Ideograph", "Ideographic"},
    38727: {"Unified_Ideograph", "Ideographic"},
    38728: {"Unified_Ideograph", "Ideographic"},
    38729: {"Unified_Ideograph", "Ideographic"},
    38730: {"Unified_Ideograph", "Ideographic"},
    38731: {"Unified_Ideograph", "Ideographic"},
    38732: {"Unified_Ideograph", "Ideographic"},
    38733: {"Unified_Ideograph", "Ideographic"},
    38734: {"Unified_Ideograph", "Ideographic"},
    38735: {"Unified_Ideograph", "Ideographic"},
    38736: {"Unified_Ideograph", "Ideographic"},
    38737: {"Unified_Ideograph", "Ideographic"},
    38738: {"Unified_Ideograph", "Ideographic"},
    38739: {"Unified_Ideograph", "Ideographic"},
    38740: {"Unified_Ideograph", "Ideographic"},
    38741: {"Unified_Ideograph", "Ideographic"},
    38742: {"Unified_Ideograph", "Ideographic"},
    38743: {"Unified_Ideograph", "Ideographic"},
    38744: {"Unified_Ideograph", "Ideographic"},
    38745: {"Unified_Ideograph", "Ideographic"},
    38746: {"Unified_Ideograph", "Ideographic"},
    38747: {"Unified_Ideograph", "Ideographic"},
    38748: {"Unified_Ideograph", "Ideographic"},
    38749: {"Unified_Ideograph", "Ideographic"},
    38750: {"Unified_Ideograph", "Ideographic"},
    38751: {"Unified_Ideograph", "Ideographic"},
    38752: {"Unified_Ideograph", "Ideographic"},
    38753: {"Unified_Ideograph", "Ideographic"},
    38754: {"Unified_Ideograph", "Ideographic"},
    38755: {"Unified_Ideograph", "Ideographic"},
    38756: {"Unified_Ideograph", "Ideographic"},
    38757: {"Unified_Ideograph", "Ideographic"},
    38758: {"Unified_Ideograph", "Ideographic"},
    38759: {"Unified_Ideograph", "Ideographic"},
    38760: {"Unified_Ideograph", "Ideographic"},
    38761: {"Unified_Ideograph", "Ideographic"},
    38762: {"Unified_Ideograph", "Ideographic"},
    38763: {"Unified_Ideograph", "Ideographic"},
    38764: {"Unified_Ideograph", "Ideographic"},
    38765: {"Unified_Ideograph", "Ideographic"},
    38766: {"Unified_Ideograph", "Ideographic"},
    38767: {"Unified_Ideograph", "Ideographic"},
    38768: {"Unified_Ideograph", "Ideographic"},
    38769: {"Unified_Ideograph", "Ideographic"},
    38770: {"Unified_Ideograph", "Ideographic"},
    38771: {"Unified_Ideograph", "Ideographic"},
    38772: {"Unified_Ideograph", "Ideographic"},
    38773: {"Unified_Ideograph", "Ideographic"},
    38774: {"Unified_Ideograph", "Ideographic"},
    38775: {"Unified_Ideograph", "Ideographic"},
    38776: {"Unified_Ideograph", "Ideographic"},
    38777: {"Unified_Ideograph", "Ideographic"},
    38778: {"Unified_Ideograph", "Ideographic"},
    38779: {"Unified_Ideograph", "Ideographic"},
    38780: {"Unified_Ideograph", "Ideographic"},
    38781: {"Unified_Ideograph", "Ideographic"},
    38782: {"Unified_Ideograph", "Ideographic"},
    38783: {"Unified_Ideograph", "Ideographic"},
    38784: {"Unified_Ideograph", "Ideographic"},
    38785: {"Unified_Ideograph", "Ideographic"},
    38786: {"Unified_Ideograph", "Ideographic"},
    38787: {"Unified_Ideograph", "Ideographic"},
    38788: {"Unified_Ideograph", "Ideographic"},
    38789: {"Unified_Ideograph", "Ideographic"},
    38790: {"Unified_Ideograph", "Ideographic"},
    38791: {"Unified_Ideograph", "Ideographic"},
    38792: {"Unified_Ideograph", "Ideographic"},
    38793: {"Unified_Ideograph", "Ideographic"},
    38794: {"Unified_Ideograph", "Ideographic"},
    38795: {"Unified_Ideograph", "Ideographic"},
    38796: {"Unified_Ideograph", "Ideographic"},
    38797: {"Unified_Ideograph", "Ideographic"},
    38798: {"Unified_Ideograph", "Ideographic"},
    38799: {"Unified_Ideograph", "Ideographic"},
    38800: {"Unified_Ideograph", "Ideographic"},
    38801: {"Unified_Ideograph", "Ideographic"},
    38802: {"Unified_Ideograph", "Ideographic"},
    38803: {"Unified_Ideograph", "Ideographic"},
    38804: {"Unified_Ideograph", "Ideographic"},
    38805: {"Unified_Ideograph", "Ideographic"},
    38806: {"Unified_Ideograph", "Ideographic"},
    38807: {"Unified_Ideograph", "Ideographic"},
    38808: {"Unified_Ideograph", "Ideographic"},
    38809: {"Unified_Ideograph", "Ideographic"},
    38810: {"Unified_Ideograph", "Ideographic"},
    38811: {"Unified_Ideograph", "Ideographic"},
    38812: {"Unified_Ideograph", "Ideographic"},
    38813: {"Unified_Ideograph", "Ideographic"},
    38814: {"Unified_Ideograph", "Ideographic"},
    38815: {"Unified_Ideograph", "Ideographic"},
    38816: {"Unified_Ideograph", "Ideographic"},
    38817: {"Unified_Ideograph", "Ideographic"},
    38818: {"Unified_Ideograph", "Ideographic"},
    38819: {"Unified_Ideograph", "Ideographic"},
    38820: {"Unified_Ideograph", "Ideographic"},
    38821: {"Unified_Ideograph", "Ideographic"},
    38822: {"Unified_Ideograph", "Ideographic"},
    38823: {"Unified_Ideograph", "Ideographic"},
    38824: {"Unified_Ideograph", "Ideographic"},
    38825: {"Unified_Ideograph", "Ideographic"},
    38826: {"Unified_Ideograph", "Ideographic"},
    38827: {"Unified_Ideograph", "Ideographic"},
    38828: {"Unified_Ideograph", "Ideographic"},
    38829: {"Unified_Ideograph", "Ideographic"},
    38830: {"Unified_Ideograph", "Ideographic"},
    38831: {"Unified_Ideograph", "Ideographic"},
    38832: {"Unified_Ideograph", "Ideographic"},
    38833: {"Unified_Ideograph", "Ideographic"},
    38834: {"Unified_Ideograph", "Ideographic"},
    38835: {"Unified_Ideograph", "Ideographic"},
    38836: {"Unified_Ideograph", "Ideographic"},
    38837: {"Unified_Ideograph", "Ideographic"},
    38838: {"Unified_Ideograph", "Ideographic"},
    38839: {"Unified_Ideograph", "Ideographic"},
    38840: {"Unified_Ideograph", "Ideographic"},
    38841: {"Unified_Ideograph", "Ideographic"},
    38842: {"Unified_Ideograph", "Ideographic"},
    38843: {"Unified_Ideograph", "Ideographic"},
    38844: {"Unified_Ideograph", "Ideographic"},
    38845: {"Unified_Ideograph", "Ideographic"},
    38846: {"Unified_Ideograph", "Ideographic"},
    38847: {"Unified_Ideograph", "Ideographic"},
    38848: {"Unified_Ideograph", "Ideographic"},
    38849: {"Unified_Ideograph", "Ideographic"},
    38850: {"Unified_Ideograph", "Ideographic"},
    38851: {"Unified_Ideograph", "Ideographic"},
    38852: {"Unified_Ideograph", "Ideographic"},
    38853: {"Unified_Ideograph", "Ideographic"},
    38854: {"Unified_Ideograph", "Ideographic"},
    38855: {"Unified_Ideograph", "Ideographic"},
    38856: {"Unified_Ideograph", "Ideographic"},
    38857: {"Unified_Ideograph", "Ideographic"},
    38858: {"Unified_Ideograph", "Ideographic"},
    38859: {"Unified_Ideograph", "Ideographic"},
    38860: {"Unified_Ideograph", "Ideographic"},
    38861: {"Unified_Ideograph", "Ideographic"},
    38862: {"Unified_Ideograph", "Ideographic"},
    38863: {"Unified_Ideograph", "Ideographic"},
    38864: {"Unified_Ideograph", "Ideographic"},
    38865: {"Unified_Ideograph", "Ideographic"},
    38866: {"Unified_Ideograph", "Ideographic"},
    38867: {"Unified_Ideograph", "Ideographic"},
    38868: {"Unified_Ideograph", "Ideographic"},
    38869: {"Unified_Ideograph", "Ideographic"},
    38870: {"Unified_Ideograph", "Ideographic"},
    38871: {"Unified_Ideograph", "Ideographic"},
    38872: {"Unified_Ideograph", "Ideographic"},
    38873: {"Unified_Ideograph", "Ideographic"},
    38874: {"Unified_Ideograph", "Ideographic"},
    38875: {"Unified_Ideograph", "Ideographic"},
    38876: {"Unified_Ideograph", "Ideographic"},
    38877: {"Unified_Ideograph", "Ideographic"},
    38878: {"Unified_Ideograph", "Ideographic"},
    38879: {"Unified_Ideograph", "Ideographic"},
    38880: {"Unified_Ideograph", "Ideographic"},
    38881: {"Unified_Ideograph", "Ideographic"},
    38882: {"Unified_Ideograph", "Ideographic"},
    38883: {"Unified_Ideograph", "Ideographic"},
    38884: {"Unified_Ideograph", "Ideographic"},
    38885: {"Unified_Ideograph", "Ideographic"},
    38886: {"Unified_Ideograph", "Ideographic"},
    38887: {"Unified_Ideograph", "Ideographic"},
    38888: {"Unified_Ideograph", "Ideographic"},
    38889: {"Unified_Ideograph", "Ideographic"},
    38890: {"Unified_Ideograph", "Ideographic"},
    38891: {"Unified_Ideograph", "Ideographic"},
    38892: {"Unified_Ideograph", "Ideographic"},
    38893: {"Unified_Ideograph", "Ideographic"},
    38894: {"Unified_Ideograph", "Ideographic"},
    38895: {"Unified_Ideograph", "Ideographic"},
    38896: {"Unified_Ideograph", "Ideographic"},
    38897: {"Unified_Ideograph", "Ideographic"},
    38898: {"Unified_Ideograph", "Ideographic"},
    38899: {"Unified_Ideograph", "Ideographic"},
    38900: {"Unified_Ideograph", "Ideographic"},
    38901: {"Unified_Ideograph", "Ideographic"},
    38902: {"Unified_Ideograph", "Ideographic"},
    38903: {"Unified_Ideograph", "Ideographic"},
    38904: {"Unified_Ideograph", "Ideographic"},
    38905: {"Unified_Ideograph", "Ideographic"},
    38906: {"Unified_Ideograph", "Ideographic"},
    38907: {"Unified_Ideograph", "Ideographic"},
    38908: {"Unified_Ideograph", "Ideographic"},
    38909: {"Unified_Ideograph", "Ideographic"},
    38910: {"Unified_Ideograph", "Ideographic"},
    38911: {"Unified_Ideograph", "Ideographic"},
    38912: {"Unified_Ideograph", "Ideographic"},
    38913: {"Unified_Ideograph", "Ideographic"},
    38914: {"Unified_Ideograph", "Ideographic"},
    38915: {"Unified_Ideograph", "Ideographic"},
    38916: {"Unified_Ideograph", "Ideographic"},
    38917: {"Unified_Ideograph", "Ideographic"},
    38918: {"Unified_Ideograph", "Ideographic"},
    38919: {"Unified_Ideograph", "Ideographic"},
    38920: {"Unified_Ideograph", "Ideographic"},
    38921: {"Unified_Ideograph", "Ideographic"},
    38922: {"Unified_Ideograph", "Ideographic"},
    38923: {"Unified_Ideograph", "Ideographic"},
    38924: {"Unified_Ideograph", "Ideographic"},
    38925: {"Unified_Ideograph", "Ideographic"},
    38926: {"Unified_Ideograph", "Ideographic"},
    38927: {"Unified_Ideograph", "Ideographic"},
    38928: {"Unified_Ideograph", "Ideographic"},
    38929: {"Unified_Ideograph", "Ideographic"},
    38930: {"Unified_Ideograph", "Ideographic"},
    38931: {"Unified_Ideograph", "Ideographic"},
    38932: {"Unified_Ideograph", "Ideographic"},
    38933: {"Unified_Ideograph", "Ideographic"},
    38934: {"Unified_Ideograph", "Ideographic"},
    38935: {"Unified_Ideograph", "Ideographic"},
    38936: {"Unified_Ideograph", "Ideographic"},
    38937: {"Unified_Ideograph", "Ideographic"},
    38938: {"Unified_Ideograph", "Ideographic"},
    38939: {"Unified_Ideograph", "Ideographic"},
    38940: {"Unified_Ideograph", "Ideographic"},
    38941: {"Unified_Ideograph", "Ideographic"},
    38942: {"Unified_Ideograph", "Ideographic"},
    38943: {"Unified_Ideograph", "Ideographic"},
    38944: {"Unified_Ideograph", "Ideographic"},
    38945: {"Unified_Ideograph", "Ideographic"},
    38946: {"Unified_Ideograph", "Ideographic"},
    38947: {"Unified_Ideograph", "Ideographic"},
    38948: {"Unified_Ideograph", "Ideographic"},
    38949: {"Unified_Ideograph", "Ideographic"},
    38950: {"Unified_Ideograph", "Ideographic"},
    38951: {"Unified_Ideograph", "Ideographic"},
    38952: {"Unified_Ideograph", "Ideographic"},
    38953: {"Unified_Ideograph", "Ideographic"},
    38954: {"Unified_Ideograph", "Ideographic"},
    38955: {"Unified_Ideograph", "Ideographic"},
    38956: {"Unified_Ideograph", "Ideographic"},
    38957: {"Unified_Ideograph", "Ideographic"},
    38958: {"Unified_Ideograph", "Ideographic"},
    38959: {"Unified_Ideograph", "Ideographic"},
    38960: {"Unified_Ideograph", "Ideographic"},
    38961: {"Unified_Ideograph", "Ideographic"},
    38962: {"Unified_Ideograph", "Ideographic"},
    38963: {"Unified_Ideograph", "Ideographic"},
    38964: {"Unified_Ideograph", "Ideographic"},
    38965: {"Unified_Ideograph", "Ideographic"},
    38966: {"Unified_Ideograph", "Ideographic"},
    38967: {"Unified_Ideograph", "Ideographic"},
    38968: {"Unified_Ideograph", "Ideographic"},
    38969: {"Unified_Ideograph", "Ideographic"},
    38970: {"Unified_Ideograph", "Ideographic"},
    38971: {"Unified_Ideograph", "Ideographic"},
    38972: {"Unified_Ideograph", "Ideographic"},
    38973: {"Unified_Ideograph", "Ideographic"},
    38974: {"Unified_Ideograph", "Ideographic"},
    38975: {"Unified_Ideograph", "Ideographic"},
    38976: {"Unified_Ideograph", "Ideographic"},
    38977: {"Unified_Ideograph", "Ideographic"},
    38978: {"Unified_Ideograph", "Ideographic"},
    38979: {"Unified_Ideograph", "Ideographic"},
    38980: {"Unified_Ideograph", "Ideographic"},
    38981: {"Unified_Ideograph", "Ideographic"},
    38982: {"Unified_Ideograph", "Ideographic"},
    38983: {"Unified_Ideograph", "Ideographic"},
    38984: {"Unified_Ideograph", "Ideographic"},
    38985: {"Unified_Ideograph", "Ideographic"},
    38986: {"Unified_Ideograph", "Ideographic"},
    38987: {"Unified_Ideograph", "Ideographic"},
    38988: {"Unified_Ideograph", "Ideographic"},
    38989: {"Unified_Ideograph", "Ideographic"},
    38990: {"Unified_Ideograph", "Ideographic"},
    38991: {"Unified_Ideograph", "Ideographic"},
    38992: {"Unified_Ideograph", "Ideographic"},
    38993: {"Unified_Ideograph", "Ideographic"},
    38994: {"Unified_Ideograph", "Ideographic"},
    38995: {"Unified_Ideograph", "Ideographic"},
    38996: {"Unified_Ideograph", "Ideographic"},
    38997: {"Unified_Ideograph", "Ideographic"},
    38998: {"Unified_Ideograph", "Ideographic"},
    38999: {"Unified_Ideograph", "Ideographic"},
    39000: {"Unified_Ideograph", "Ideographic"},
    39001: {"Unified_Ideograph", "Ideographic"},
    39002: {"Unified_Ideograph", "Ideographic"},
    39003: {"Unified_Ideograph", "Ideographic"},
    39004: {"Unified_Ideograph", "Ideographic"},
    39005: {"Unified_Ideograph", "Ideographic"},
    39006: {"Unified_Ideograph", "Ideographic"},
    39007: {"Unified_Ideograph", "Ideographic"},
    39008: {"Unified_Ideograph", "Ideographic"},
    39009: {"Unified_Ideograph", "Ideographic"},
    39010: {"Unified_Ideograph", "Ideographic"},
    39011: {"Unified_Ideograph", "Ideographic"},
    39012: {"Unified_Ideograph", "Ideographic"},
    39013: {"Unified_Ideograph", "Ideographic"},
    39014: {"Unified_Ideograph", "Ideographic"},
    39015: {"Unified_Ideograph", "Ideographic"},
    39016: {"Unified_Ideograph", "Ideographic"},
    39017: {"Unified_Ideograph", "Ideographic"},
    39018: {"Unified_Ideograph", "Ideographic"},
    39019: {"Unified_Ideograph", "Ideographic"},
    39020: {"Unified_Ideograph", "Ideographic"},
    39021: {"Unified_Ideograph", "Ideographic"},
    39022: {"Unified_Ideograph", "Ideographic"},
    39023: {"Unified_Ideograph", "Ideographic"},
    39024: {"Unified_Ideograph", "Ideographic"},
    39025: {"Unified_Ideograph", "Ideographic"},
    39026: {"Unified_Ideograph", "Ideographic"},
    39027: {"Unified_Ideograph", "Ideographic"},
    39028: {"Unified_Ideograph", "Ideographic"},
    39029: {"Unified_Ideograph", "Ideographic"},
    39030: {"Unified_Ideograph", "Ideographic"},
    39031: {"Unified_Ideograph", "Ideographic"},
    39032: {"Unified_Ideograph", "Ideographic"},
    39033: {"Unified_Ideograph", "Ideographic"},
    39034: {"Unified_Ideograph", "Ideographic"},
    39035: {"Unified_Ideograph", "Ideographic"},
    39036: {"Unified_Ideograph", "Ideographic"},
    39037: {"Unified_Ideograph", "Ideographic"},
    39038: {"Unified_Ideograph", "Ideographic"},
    39039: {"Unified_Ideograph", "Ideographic"},
    39040: {"Unified_Ideograph", "Ideographic"},
    39041: {"Unified_Ideograph", "Ideographic"},
    39042: {"Unified_Ideograph", "Ideographic"},
    39043: {"Unified_Ideograph", "Ideographic"},
    39044: {"Unified_Ideograph", "Ideographic"},
    39045: {"Unified_Ideograph", "Ideographic"},
    39046: {"Unified_Ideograph", "Ideographic"},
    39047: {"Unified_Ideograph", "Ideographic"},
    39048: {"Unified_Ideograph", "Ideographic"},
    39049: {"Unified_Ideograph", "Ideographic"},
    39050: {"Unified_Ideograph", "Ideographic"},
    39051: {"Unified_Ideograph", "Ideographic"},
    39052: {"Unified_Ideograph", "Ideographic"},
    39053: {"Unified_Ideograph", "Ideographic"},
    39054: {"Unified_Ideograph", "Ideographic"},
    39055: {"Unified_Ideograph", "Ideographic"},
    39056: {"Unified_Ideograph", "Ideographic"},
    39057: {"Unified_Ideograph", "Ideographic"},
    39058: {"Unified_Ideograph", "Ideographic"},
    39059: {"Unified_Ideograph", "Ideographic"},
    39060: {"Unified_Ideograph", "Ideographic"},
    39061: {"Unified_Ideograph", "Ideographic"},
    39062: {"Unified_Ideograph", "Ideographic"},
    39063: {"Unified_Ideograph", "Ideographic"},
    39064: {"Unified_Ideograph", "Ideographic"},
    39065: {"Unified_Ideograph", "Ideographic"},
    39066: {"Unified_Ideograph", "Ideographic"},
    39067: {"Unified_Ideograph", "Ideographic"},
    39068: {"Unified_Ideograph", "Ideographic"},
    39069: {"Unified_Ideograph", "Ideographic"},
    39070: {"Unified_Ideograph", "Ideographic"},
    39071: {"Unified_Ideograph", "Ideographic"},
    39072: {"Unified_Ideograph", "Ideographic"},
    39073: {"Unified_Ideograph", "Ideographic"},
    39074: {"Unified_Ideograph", "Ideographic"},
    39075: {"Unified_Ideograph", "Ideographic"},
    39076: {"Unified_Ideograph", "Ideographic"},
    39077: {"Unified_Ideograph", "Ideographic"},
    39078: {"Unified_Ideograph", "Ideographic"},
    39079: {"Unified_Ideograph", "Ideographic"},
    39080: {"Unified_Ideograph", "Ideographic"},
    39081: {"Unified_Ideograph", "Ideographic"},
    39082: {"Unified_Ideograph", "Ideographic"},
    39083: {"Unified_Ideograph", "Ideographic"},
    39084: {"Unified_Ideograph", "Ideographic"},
    39085: {"Unified_Ideograph", "Ideographic"},
    39086: {"Unified_Ideograph", "Ideographic"},
    39087: {"Unified_Ideograph", "Ideographic"},
    39088: {"Unified_Ideograph", "Ideographic"},
    39089: {"Unified_Ideograph", "Ideographic"},
    39090: {"Unified_Ideograph", "Ideographic"},
    39091: {"Unified_Ideograph", "Ideographic"},
    39092: {"Unified_Ideograph", "Ideographic"},
    39093: {"Unified_Ideograph", "Ideographic"},
    39094: {"Unified_Ideograph", "Ideographic"},
    39095: {"Unified_Ideograph", "Ideographic"},
    39096: {"Unified_Ideograph", "Ideographic"},
    39097: {"Unified_Ideograph", "Ideographic"},
    39098: {"Unified_Ideograph", "Ideographic"},
    39099: {"Unified_Ideograph", "Ideographic"},
    39100: {"Unified_Ideograph", "Ideographic"},
    39101: {"Unified_Ideograph", "Ideographic"},
    39102: {"Unified_Ideograph", "Ideographic"},
    39103: {"Unified_Ideograph", "Ideographic"},
    39104: {"Unified_Ideograph", "Ideographic"},
    39105: {"Unified_Ideograph", "Ideographic"},
    39106: {"Unified_Ideograph", "Ideographic"},
    39107: {"Unified_Ideograph", "Ideographic"},
    39108: {"Unified_Ideograph", "Ideographic"},
    39109: {"Unified_Ideograph", "Ideographic"},
    39110: {"Unified_Ideograph", "Ideographic"},
    39111: {"Unified_Ideograph", "Ideographic"},
    39112: {"Unified_Ideograph", "Ideographic"},
    39113: {"Unified_Ideograph", "Ideographic"},
    39114: {"Unified_Ideograph", "Ideographic"},
    39115: {"Unified_Ideograph", "Ideographic"},
    39116: {"Unified_Ideograph", "Ideographic"},
    39117: {"Unified_Ideograph", "Ideographic"},
    39118: {"Unified_Ideograph", "Ideographic"},
    39119: {"Unified_Ideograph", "Ideographic"},
    39120: {"Unified_Ideograph", "Ideographic"},
    39121: {"Unified_Ideograph", "Ideographic"},
    39122: {"Unified_Ideograph", "Ideographic"},
    39123: {"Unified_Ideograph", "Ideographic"},
    39124: {"Unified_Ideograph", "Ideographic"},
    39125: {"Unified_Ideograph", "Ideographic"},
    39126: {"Unified_Ideograph", "Ideographic"},
    39127: {"Unified_Ideograph", "Ideographic"},
    39128: {"Unified_Ideograph", "Ideographic"},
    39129: {"Unified_Ideograph", "Ideographic"},
    39130: {"Unified_Ideograph", "Ideographic"},
    39131: {"Unified_Ideograph", "Ideographic"},
    39132: {"Unified_Ideograph", "Ideographic"},
    39133: {"Unified_Ideograph", "Ideographic"},
    39134: {"Unified_Ideograph", "Ideographic"},
    39135: {"Unified_Ideograph", "Ideographic"},
    39136: {"Unified_Ideograph", "Ideographic"},
    39137: {"Unified_Ideograph", "Ideographic"},
    39138: {"Unified_Ideograph", "Ideographic"},
    39139: {"Unified_Ideograph", "Ideographic"},
    39140: {"Unified_Ideograph", "Ideographic"},
    39141: {"Unified_Ideograph", "Ideographic"},
    39142: {"Unified_Ideograph", "Ideographic"},
    39143: {"Unified_Ideograph", "Ideographic"},
    39144: {"Unified_Ideograph", "Ideographic"},
    39145: {"Unified_Ideograph", "Ideographic"},
    39146: {"Unified_Ideograph", "Ideographic"},
    39147: {"Unified_Ideograph", "Ideographic"},
    39148: {"Unified_Ideograph", "Ideographic"},
    39149: {"Unified_Ideograph", "Ideographic"},
    39150: {"Unified_Ideograph", "Ideographic"},
    39151: {"Unified_Ideograph", "Ideographic"},
    39152: {"Unified_Ideograph", "Ideographic"},
    39153: {"Unified_Ideograph", "Ideographic"},
    39154: {"Unified_Ideograph", "Ideographic"},
    39155: {"Unified_Ideograph", "Ideographic"},
    39156: {"Unified_Ideograph", "Ideographic"},
    39157: {"Unified_Ideograph", "Ideographic"},
    39158: {"Unified_Ideograph", "Ideographic"},
    39159: {"Unified_Ideograph", "Ideographic"},
    39160: {"Unified_Ideograph", "Ideographic"},
    39161: {"Unified_Ideograph", "Ideographic"},
    39162: {"Unified_Ideograph", "Ideographic"},
    39163: {"Unified_Ideograph", "Ideographic"},
    39164: {"Unified_Ideograph", "Ideographic"},
    39165: {"Unified_Ideograph", "Ideographic"},
    39166: {"Unified_Ideograph", "Ideographic"},
    39167: {"Unified_Ideograph", "Ideographic"},
    39168: {"Unified_Ideograph", "Ideographic"},
    39169: {"Unified_Ideograph", "Ideographic"},
    39170: {"Unified_Ideograph", "Ideographic"},
    39171: {"Unified_Ideograph", "Ideographic"},
    39172: {"Unified_Ideograph", "Ideographic"},
    39173: {"Unified_Ideograph", "Ideographic"},
    39174: {"Unified_Ideograph", "Ideographic"},
    39175: {"Unified_Ideograph", "Ideographic"},
    39176: {"Unified_Ideograph", "Ideographic"},
    39177: {"Unified_Ideograph", "Ideographic"},
    39178: {"Unified_Ideograph", "Ideographic"},
    39179: {"Unified_Ideograph", "Ideographic"},
    39180: {"Unified_Ideograph", "Ideographic"},
    39181: {"Unified_Ideograph", "Ideographic"},
    39182: {"Unified_Ideograph", "Ideographic"},
    39183: {"Unified_Ideograph", "Ideographic"},
    39184: {"Unified_Ideograph", "Ideographic"},
    39185: {"Unified_Ideograph", "Ideographic"},
    39186: {"Unified_Ideograph", "Ideographic"},
    39187: {"Unified_Ideograph", "Ideographic"},
    39188: {"Unified_Ideograph", "Ideographic"},
    39189: {"Unified_Ideograph", "Ideographic"},
    39190: {"Unified_Ideograph", "Ideographic"},
    39191: {"Unified_Ideograph", "Ideographic"},
    39192: {"Unified_Ideograph", "Ideographic"},
    39193: {"Unified_Ideograph", "Ideographic"},
    39194: {"Unified_Ideograph", "Ideographic"},
    39195: {"Unified_Ideograph", "Ideographic"},
    39196: {"Unified_Ideograph", "Ideographic"},
    39197: {"Unified_Ideograph", "Ideographic"},
    39198: {"Unified_Ideograph", "Ideographic"},
    39199: {"Unified_Ideograph", "Ideographic"},
    39200: {"Unified_Ideograph", "Ideographic"},
    39201: {"Unified_Ideograph", "Ideographic"},
    39202: {"Unified_Ideograph", "Ideographic"},
    39203: {"Unified_Ideograph", "Ideographic"},
    39204: {"Unified_Ideograph", "Ideographic"},
    39205: {"Unified_Ideograph", "Ideographic"},
    39206: {"Unified_Ideograph", "Ideographic"},
    39207: {"Unified_Ideograph", "Ideographic"},
    39208: {"Unified_Ideograph", "Ideographic"},
    39209: {"Unified_Ideograph", "Ideographic"},
    39210: {"Unified_Ideograph", "Ideographic"},
    39211: {"Unified_Ideograph", "Ideographic"},
    39212: {"Unified_Ideograph", "Ideographic"},
    39213: {"Unified_Ideograph", "Ideographic"},
    39214: {"Unified_Ideograph", "Ideographic"},
    39215: {"Unified_Ideograph", "Ideographic"},
    39216: {"Unified_Ideograph", "Ideographic"},
    39217: {"Unified_Ideograph", "Ideographic"},
    39218: {"Unified_Ideograph", "Ideographic"},
    39219: {"Unified_Ideograph", "Ideographic"},
    39220: {"Unified_Ideograph", "Ideographic"},
    39221: {"Unified_Ideograph", "Ideographic"},
    39222: {"Unified_Ideograph", "Ideographic"},
    39223: {"Unified_Ideograph", "Ideographic"},
    39224: {"Unified_Ideograph", "Ideographic"},
    39225: {"Unified_Ideograph", "Ideographic"},
    39226: {"Unified_Ideograph", "Ideographic"},
    39227: {"Unified_Ideograph", "Ideographic"},
    39228: {"Unified_Ideograph", "Ideographic"},
    39229: {"Unified_Ideograph", "Ideographic"},
    39230: {"Unified_Ideograph", "Ideographic"},
    39231: {"Unified_Ideograph", "Ideographic"},
    39232: {"Unified_Ideograph", "Ideographic"},
    39233: {"Unified_Ideograph", "Ideographic"},
    39234: {"Unified_Ideograph", "Ideographic"},
    39235: {"Unified_Ideograph", "Ideographic"},
    39236: {"Unified_Ideograph", "Ideographic"},
    39237: {"Unified_Ideograph", "Ideographic"},
    39238: {"Unified_Ideograph", "Ideographic"},
    39239: {"Unified_Ideograph", "Ideographic"},
    39240: {"Unified_Ideograph", "Ideographic"},
    39241: {"Unified_Ideograph", "Ideographic"},
    39242: {"Unified_Ideograph", "Ideographic"},
    39243: {"Unified_Ideograph", "Ideographic"},
    39244: {"Unified_Ideograph", "Ideographic"},
    39245: {"Unified_Ideograph", "Ideographic"},
    39246: {"Unified_Ideograph", "Ideographic"},
    39247: {"Unified_Ideograph", "Ideographic"},
    39248: {"Unified_Ideograph", "Ideographic"},
    39249: {"Unified_Ideograph", "Ideographic"},
    39250: {"Unified_Ideograph", "Ideographic"},
    39251: {"Unified_Ideograph", "Ideographic"},
    39252: {"Unified_Ideograph", "Ideographic"},
    39253: {"Unified_Ideograph", "Ideographic"},
    39254: {"Unified_Ideograph", "Ideographic"},
    39255: {"Unified_Ideograph", "Ideographic"},
    39256: {"Unified_Ideograph", "Ideographic"},
    39257: {"Unified_Ideograph", "Ideographic"},
    39258: {"Unified_Ideograph", "Ideographic"},
    39259: {"Unified_Ideograph", "Ideographic"},
    39260: {"Unified_Ideograph", "Ideographic"},
    39261: {"Unified_Ideograph", "Ideographic"},
    39262: {"Unified_Ideograph", "Ideographic"},
    39263: {"Unified_Ideograph", "Ideographic"},
    39264: {"Unified_Ideograph", "Ideographic"},
    39265: {"Unified_Ideograph", "Ideographic"},
    39266: {"Unified_Ideograph", "Ideographic"},
    39267: {"Unified_Ideograph", "Ideographic"},
    39268: {"Unified_Ideograph", "Ideographic"},
    39269: {"Unified_Ideograph", "Ideographic"},
    39270: {"Unified_Ideograph", "Ideographic"},
    39271: {"Unified_Ideograph", "Ideographic"},
    39272: {"Unified_Ideograph", "Ideographic"},
    39273: {"Unified_Ideograph", "Ideographic"},
    39274: {"Unified_Ideograph", "Ideographic"},
    39275: {"Unified_Ideograph", "Ideographic"},
    39276: {"Unified_Ideograph", "Ideographic"},
    39277: {"Unified_Ideograph", "Ideographic"},
    39278: {"Unified_Ideograph", "Ideographic"},
    39279: {"Unified_Ideograph", "Ideographic"},
    39280: {"Unified_Ideograph", "Ideographic"},
    39281: {"Unified_Ideograph", "Ideographic"},
    39282: {"Unified_Ideograph", "Ideographic"},
    39283: {"Unified_Ideograph", "Ideographic"},
    39284: {"Unified_Ideograph", "Ideographic"},
    39285: {"Unified_Ideograph", "Ideographic"},
    39286: {"Unified_Ideograph", "Ideographic"},
    39287: {"Unified_Ideograph", "Ideographic"},
    39288: {"Unified_Ideograph", "Ideographic"},
    39289: {"Unified_Ideograph", "Ideographic"},
    39290: {"Unified_Ideograph", "Ideographic"},
    39291: {"Unified_Ideograph", "Ideographic"},
    39292: {"Unified_Ideograph", "Ideographic"},
    39293: {"Unified_Ideograph", "Ideographic"},
    39294: {"Unified_Ideograph", "Ideographic"},
    39295: {"Unified_Ideograph", "Ideographic"},
    39296: {"Unified_Ideograph", "Ideographic"},
    39297: {"Unified_Ideograph", "Ideographic"},
    39298: {"Unified_Ideograph", "Ideographic"},
    39299: {"Unified_Ideograph", "Ideographic"},
    39300: {"Unified_Ideograph", "Ideographic"},
    39301: {"Unified_Ideograph", "Ideographic"},
    39302: {"Unified_Ideograph", "Ideographic"},
    39303: {"Unified_Ideograph", "Ideographic"},
    39304: {"Unified_Ideograph", "Ideographic"},
    39305: {"Unified_Ideograph", "Ideographic"},
    39306: {"Unified_Ideograph", "Ideographic"},
    39307: {"Unified_Ideograph", "Ideographic"},
    39308: {"Unified_Ideograph", "Ideographic"},
    39309: {"Unified_Ideograph", "Ideographic"},
    39310: {"Unified_Ideograph", "Ideographic"},
    39311: {"Unified_Ideograph", "Ideographic"},
    39312: {"Unified_Ideograph", "Ideographic"},
    39313: {"Unified_Ideograph", "Ideographic"},
    39314: {"Unified_Ideograph", "Ideographic"},
    39315: {"Unified_Ideograph", "Ideographic"},
    39316: {"Unified_Ideograph", "Ideographic"},
    39317: {"Unified_Ideograph", "Ideographic"},
    39318: {"Unified_Ideograph", "Ideographic"},
    39319: {"Unified_Ideograph", "Ideographic"},
    39320: {"Unified_Ideograph", "Ideographic"},
    39321: {"Unified_Ideograph", "Ideographic"},
    39322: {"Unified_Ideograph", "Ideographic"},
    39323: {"Unified_Ideograph", "Ideographic"},
    39324: {"Unified_Ideograph", "Ideographic"},
    39325: {"Unified_Ideograph", "Ideographic"},
    39326: {"Unified_Ideograph", "Ideographic"},
    39327: {"Unified_Ideograph", "Ideographic"},
    39328: {"Unified_Ideograph", "Ideographic"},
    39329: {"Unified_Ideograph", "Ideographic"},
    39330: {"Unified_Ideograph", "Ideographic"},
    39331: {"Unified_Ideograph", "Ideographic"},
    39332: {"Unified_Ideograph", "Ideographic"},
    39333: {"Unified_Ideograph", "Ideographic"},
    39334: {"Unified_Ideograph", "Ideographic"},
    39335: {"Unified_Ideograph", "Ideographic"},
    39336: {"Unified_Ideograph", "Ideographic"},
    39337: {"Unified_Ideograph", "Ideographic"},
    39338: {"Unified_Ideograph", "Ideographic"},
    39339: {"Unified_Ideograph", "Ideographic"},
    39340: {"Unified_Ideograph", "Ideographic"},
    39341: {"Unified_Ideograph", "Ideographic"},
    39342: {"Unified_Ideograph", "Ideographic"},
    39343: {"Unified_Ideograph", "Ideographic"},
    39344: {"Unified_Ideograph", "Ideographic"},
    39345: {"Unified_Ideograph", "Ideographic"},
    39346: {"Unified_Ideograph", "Ideographic"},
    39347: {"Unified_Ideograph", "Ideographic"},
    39348: {"Unified_Ideograph", "Ideographic"},
    39349: {"Unified_Ideograph", "Ideographic"},
    39350: {"Unified_Ideograph", "Ideographic"},
    39351: {"Unified_Ideograph", "Ideographic"},
    39352: {"Unified_Ideograph", "Ideographic"},
    39353: {"Unified_Ideograph", "Ideographic"},
    39354: {"Unified_Ideograph", "Ideographic"},
    39355: {"Unified_Ideograph", "Ideographic"},
    39356: {"Unified_Ideograph", "Ideographic"},
    39357: {"Unified_Ideograph", "Ideographic"},
    39358: {"Unified_Ideograph", "Ideographic"},
    39359: {"Unified_Ideograph", "Ideographic"},
    39360: {"Unified_Ideograph", "Ideographic"},
    39361: {"Unified_Ideograph", "Ideographic"},
    39362: {"Unified_Ideograph", "Ideographic"},
    39363: {"Unified_Ideograph", "Ideographic"},
    39364: {"Unified_Ideograph", "Ideographic"},
    39365: {"Unified_Ideograph", "Ideographic"},
    39366: {"Unified_Ideograph", "Ideographic"},
    39367: {"Unified_Ideograph", "Ideographic"},
    39368: {"Unified_Ideograph", "Ideographic"},
    39369: {"Unified_Ideograph", "Ideographic"},
    39370: {"Unified_Ideograph", "Ideographic"},
    39371: {"Unified_Ideograph", "Ideographic"},
    39372: {"Unified_Ideograph", "Ideographic"},
    39373: {"Unified_Ideograph", "Ideographic"},
    39374: {"Unified_Ideograph", "Ideographic"},
    39375: {"Unified_Ideograph", "Ideographic"},
    39376: {"Unified_Ideograph", "Ideographic"},
    39377: {"Unified_Ideograph", "Ideographic"},
    39378: {"Unified_Ideograph", "Ideographic"},
    39379: {"Unified_Ideograph", "Ideographic"},
    39380: {"Unified_Ideograph", "Ideographic"},
    39381: {"Unified_Ideograph", "Ideographic"},
    39382: {"Unified_Ideograph", "Ideographic"},
    39383: {"Unified_Ideograph", "Ideographic"},
    39384: {"Unified_Ideograph", "Ideographic"},
    39385: {"Unified_Ideograph", "Ideographic"},
    39386: {"Unified_Ideograph", "Ideographic"},
    39387: {"Unified_Ideograph", "Ideographic"},
    39388: {"Unified_Ideograph", "Ideographic"},
    39389: {"Unified_Ideograph", "Ideographic"},
    39390: {"Unified_Ideograph", "Ideographic"},
    39391: {"Unified_Ideograph", "Ideographic"},
    39392: {"Unified_Ideograph", "Ideographic"},
    39393: {"Unified_Ideograph", "Ideographic"},
    39394: {"Unified_Ideograph", "Ideographic"},
    39395: {"Unified_Ideograph", "Ideographic"},
    39396: {"Unified_Ideograph", "Ideographic"},
    39397: {"Unified_Ideograph", "Ideographic"},
    39398: {"Unified_Ideograph", "Ideographic"},
    39399: {"Unified_Ideograph", "Ideographic"},
    39400: {"Unified_Ideograph", "Ideographic"},
    39401: {"Unified_Ideograph", "Ideographic"},
    39402: {"Unified_Ideograph", "Ideographic"},
    39403: {"Unified_Ideograph", "Ideographic"},
    39404: {"Unified_Ideograph", "Ideographic"},
    39405: {"Unified_Ideograph", "Ideographic"},
    39406: {"Unified_Ideograph", "Ideographic"},
    39407: {"Unified_Ideograph", "Ideographic"},
    39408: {"Unified_Ideograph", "Ideographic"},
    39409: {"Unified_Ideograph", "Ideographic"},
    39410: {"Unified_Ideograph", "Ideographic"},
    39411: {"Unified_Ideograph", "Ideographic"},
    39412: {"Unified_Ideograph", "Ideographic"},
    39413: {"Unified_Ideograph", "Ideographic"},
    39414: {"Unified_Ideograph", "Ideographic"},
    39415: {"Unified_Ideograph", "Ideographic"},
    39416: {"Unified_Ideograph", "Ideographic"},
    39417: {"Unified_Ideograph", "Ideographic"},
    39418: {"Unified_Ideograph", "Ideographic"},
    39419: {"Unified_Ideograph", "Ideographic"},
    39420: {"Unified_Ideograph", "Ideographic"},
    39421: {"Unified_Ideograph", "Ideographic"},
    39422: {"Unified_Ideograph", "Ideographic"},
    39423: {"Unified_Ideograph", "Ideographic"},
    39424: {"Unified_Ideograph", "Ideographic"},
    39425: {"Unified_Ideograph", "Ideographic"},
    39426: {"Unified_Ideograph", "Ideographic"},
    39427: {"Unified_Ideograph", "Ideographic"},
    39428: {"Unified_Ideograph", "Ideographic"},
    39429: {"Unified_Ideograph", "Ideographic"},
    39430: {"Unified_Ideograph", "Ideographic"},
    39431: {"Unified_Ideograph", "Ideographic"},
    39432: {"Unified_Ideograph", "Ideographic"},
    39433: {"Unified_Ideograph", "Ideographic"},
    39434: {"Unified_Ideograph", "Ideographic"},
    39435: {"Unified_Ideograph", "Ideographic"},
    39436: {"Unified_Ideograph", "Ideographic"},
    39437: {"Unified_Ideograph", "Ideographic"},
    39438: {"Unified_Ideograph", "Ideographic"},
    39439: {"Unified_Ideograph", "Ideographic"},
    39440: {"Unified_Ideograph", "Ideographic"},
    39441: {"Unified_Ideograph", "Ideographic"},
    39442: {"Unified_Ideograph", "Ideographic"},
    39443: {"Unified_Ideograph", "Ideographic"},
    39444: {"Unified_Ideograph", "Ideographic"},
    39445: {"Unified_Ideograph", "Ideographic"},
    39446: {"Unified_Ideograph", "Ideographic"},
    39447: {"Unified_Ideograph", "Ideographic"},
    39448: {"Unified_Ideograph", "Ideographic"},
    39449: {"Unified_Ideograph", "Ideographic"},
    39450: {"Unified_Ideograph", "Ideographic"},
    39451: {"Unified_Ideograph", "Ideographic"},
    39452: {"Unified_Ideograph", "Ideographic"},
    39453: {"Unified_Ideograph", "Ideographic"},
    39454: {"Unified_Ideograph", "Ideographic"},
    39455: {"Unified_Ideograph", "Ideographic"},
    39456: {"Unified_Ideograph", "Ideographic"},
    39457: {"Unified_Ideograph", "Ideographic"},
    39458: {"Unified_Ideograph", "Ideographic"},
    39459: {"Unified_Ideograph", "Ideographic"},
    39460: {"Unified_Ideograph", "Ideographic"},
    39461: {"Unified_Ideograph", "Ideographic"},
    39462: {"Unified_Ideograph", "Ideographic"},
    39463: {"Unified_Ideograph", "Ideographic"},
    39464: {"Unified_Ideograph", "Ideographic"},
    39465: {"Unified_Ideograph", "Ideographic"},
    39466: {"Unified_Ideograph", "Ideographic"},
    39467: {"Unified_Ideograph", "Ideographic"},
    39468: {"Unified_Ideograph", "Ideographic"},
    39469: {"Unified_Ideograph", "Ideographic"},
    39470: {"Unified_Ideograph", "Ideographic"},
    39471: {"Unified_Ideograph", "Ideographic"},
    39472: {"Unified_Ideograph", "Ideographic"},
    39473: {"Unified_Ideograph", "Ideographic"},
    39474: {"Unified_Ideograph", "Ideographic"},
    39475: {"Unified_Ideograph", "Ideographic"},
    39476: {"Unified_Ideograph", "Ideographic"},
    39477: {"Unified_Ideograph", "Ideographic"},
    39478: {"Unified_Ideograph", "Ideographic"},
    39479: {"Unified_Ideograph", "Ideographic"},
    39480: {"Unified_Ideograph", "Ideographic"},
    39481: {"Unified_Ideograph", "Ideographic"},
    39482: {"Unified_Ideograph", "Ideographic"},
    39483: {"Unified_Ideograph", "Ideographic"},
    39484: {"Unified_Ideograph", "Ideographic"},
    39485: {"Unified_Ideograph", "Ideographic"},
    39486: {"Unified_Ideograph", "Ideographic"},
    39487: {"Unified_Ideograph", "Ideographic"},
    39488: {"Unified_Ideograph", "Ideographic"},
    39489: {"Unified_Ideograph", "Ideographic"},
    39490: {"Unified_Ideograph", "Ideographic"},
    39491: {"Unified_Ideograph", "Ideographic"},
    39492: {"Unified_Ideograph", "Ideographic"},
    39493: {"Unified_Ideograph", "Ideographic"},
    39494: {"Unified_Ideograph", "Ideographic"},
    39495: {"Unified_Ideograph", "Ideographic"},
    39496: {"Unified_Ideograph", "Ideographic"},
    39497: {"Unified_Ideograph", "Ideographic"},
    39498: {"Unified_Ideograph", "Ideographic"},
    39499: {"Unified_Ideograph", "Ideographic"},
    39500: {"Unified_Ideograph", "Ideographic"},
    39501: {"Unified_Ideograph", "Ideographic"},
    39502: {"Unified_Ideograph", "Ideographic"},
    39503: {"Unified_Ideograph", "Ideographic"},
    39504: {"Unified_Ideograph", "Ideographic"},
    39505: {"Unified_Ideograph", "Ideographic"},
    39506: {"Unified_Ideograph", "Ideographic"},
    39507: {"Unified_Ideograph", "Ideographic"},
    39508: {"Unified_Ideograph", "Ideographic"},
    39509: {"Unified_Ideograph", "Ideographic"},
    39510: {"Unified_Ideograph", "Ideographic"},
    39511: {"Unified_Ideograph", "Ideographic"},
    39512: {"Unified_Ideograph", "Ideographic"},
    39513: {"Unified_Ideograph", "Ideographic"},
    39514: {"Unified_Ideograph", "Ideographic"},
    39515: {"Unified_Ideograph", "Ideographic"},
    39516: {"Unified_Ideograph", "Ideographic"},
    39517: {"Unified_Ideograph", "Ideographic"},
    39518: {"Unified_Ideograph", "Ideographic"},
    39519: {"Unified_Ideograph", "Ideographic"},
    39520: {"Unified_Ideograph", "Ideographic"},
    39521: {"Unified_Ideograph", "Ideographic"},
    39522: {"Unified_Ideograph", "Ideographic"},
    39523: {"Unified_Ideograph", "Ideographic"},
    39524: {"Unified_Ideograph", "Ideographic"},
    39525: {"Unified_Ideograph", "Ideographic"},
    39526: {"Unified_Ideograph", "Ideographic"},
    39527: {"Unified_Ideograph", "Ideographic"},
    39528: {"Unified_Ideograph", "Ideographic"},
    39529: {"Unified_Ideograph", "Ideographic"},
    39530: {"Unified_Ideograph", "Ideographic"},
    39531: {"Unified_Ideograph", "Ideographic"},
    39532: {"Unified_Ideograph", "Ideographic"},
    39533: {"Unified_Ideograph", "Ideographic"},
    39534: {"Unified_Ideograph", "Ideographic"},
    39535: {"Unified_Ideograph", "Ideographic"},
    39536: {"Unified_Ideograph", "Ideographic"},
    39537: {"Unified_Ideograph", "Ideographic"},
    39538: {"Unified_Ideograph", "Ideographic"},
    39539: {"Unified_Ideograph", "Ideographic"},
    39540: {"Unified_Ideograph", "Ideographic"},
    39541: {"Unified_Ideograph", "Ideographic"},
    39542: {"Unified_Ideograph", "Ideographic"},
    39543: {"Unified_Ideograph", "Ideographic"},
    39544: {"Unified_Ideograph", "Ideographic"},
    39545: {"Unified_Ideograph", "Ideographic"},
    39546: {"Unified_Ideograph", "Ideographic"},
    39547: {"Unified_Ideograph", "Ideographic"},
    39548: {"Unified_Ideograph", "Ideographic"},
    39549: {"Unified_Ideograph", "Ideographic"},
    39550: {"Unified_Ideograph", "Ideographic"},
    39551: {"Unified_Ideograph", "Ideographic"},
    39552: {"Unified_Ideograph", "Ideographic"},
    39553: {"Unified_Ideograph", "Ideographic"},
    39554: {"Unified_Ideograph", "Ideographic"},
    39555: {"Unified_Ideograph", "Ideographic"},
    39556: {"Unified_Ideograph", "Ideographic"},
    39557: {"Unified_Ideograph", "Ideographic"},
    39558: {"Unified_Ideograph", "Ideographic"},
    39559: {"Unified_Ideograph", "Ideographic"},
    39560: {"Unified_Ideograph", "Ideographic"},
    39561: {"Unified_Ideograph", "Ideographic"},
    39562: {"Unified_Ideograph", "Ideographic"},
    39563: {"Unified_Ideograph", "Ideographic"},
    39564: {"Unified_Ideograph", "Ideographic"},
    39565: {"Unified_Ideograph", "Ideographic"},
    39566: {"Unified_Ideograph", "Ideographic"},
    39567: {"Unified_Ideograph", "Ideographic"},
    39568: {"Unified_Ideograph", "Ideographic"},
    39569: {"Unified_Ideograph", "Ideographic"},
    39570: {"Unified_Ideograph", "Ideographic"},
    39571: {"Unified_Ideograph", "Ideographic"},
    39572: {"Unified_Ideograph", "Ideographic"},
    39573: {"Unified_Ideograph", "Ideographic"},
    39574: {"Unified_Ideograph", "Ideographic"},
    39575: {"Unified_Ideograph", "Ideographic"},
    39576: {"Unified_Ideograph", "Ideographic"},
    39577: {"Unified_Ideograph", "Ideographic"},
    39578: {"Unified_Ideograph", "Ideographic"},
    39579: {"Unified_Ideograph", "Ideographic"},
    39580: {"Unified_Ideograph", "Ideographic"},
    39581: {"Unified_Ideograph", "Ideographic"},
    39582: {"Unified_Ideograph", "Ideographic"},
    39583: {"Unified_Ideograph", "Ideographic"},
    39584: {"Unified_Ideograph", "Ideographic"},
    39585: {"Unified_Ideograph", "Ideographic"},
    39586: {"Unified_Ideograph", "Ideographic"},
    39587: {"Unified_Ideograph", "Ideographic"},
    39588: {"Unified_Ideograph", "Ideographic"},
    39589: {"Unified_Ideograph", "Ideographic"},
    39590: {"Unified_Ideograph", "Ideographic"},
    39591: {"Unified_Ideograph", "Ideographic"},
    39592: {"Unified_Ideograph", "Ideographic"},
    39593: {"Unified_Ideograph", "Ideographic"},
    39594: {"Unified_Ideograph", "Ideographic"},
    39595: {"Unified_Ideograph", "Ideographic"},
    39596: {"Unified_Ideograph", "Ideographic"},
    39597: {"Unified_Ideograph", "Ideographic"},
    39598: {"Unified_Ideograph", "Ideographic"},
    39599: {"Unified_Ideograph", "Ideographic"},
    39600: {"Unified_Ideograph", "Ideographic"},
    39601: {"Unified_Ideograph", "Ideographic"},
    39602: {"Unified_Ideograph", "Ideographic"},
    39603: {"Unified_Ideograph", "Ideographic"},
    39604: {"Unified_Ideograph", "Ideographic"},
    39605: {"Unified_Ideograph", "Ideographic"},
    39606: {"Unified_Ideograph", "Ideographic"},
    39607: {"Unified_Ideograph", "Ideographic"},
    39608: {"Unified_Ideograph", "Ideographic"},
    39609: {"Unified_Ideograph", "Ideographic"},
    39610: {"Unified_Ideograph", "Ideographic"},
    39611: {"Unified_Ideograph", "Ideographic"},
    39612: {"Unified_Ideograph", "Ideographic"},
    39613: {"Unified_Ideograph", "Ideographic"},
    39614: {"Unified_Ideograph", "Ideographic"},
    39615: {"Unified_Ideograph", "Ideographic"},
    39616: {"Unified_Ideograph", "Ideographic"},
    39617: {"Unified_Ideograph", "Ideographic"},
    39618: {"Unified_Ideograph", "Ideographic"},
    39619: {"Unified_Ideograph", "Ideographic"},
    39620: {"Unified_Ideograph", "Ideographic"},
    39621: {"Unified_Ideograph", "Ideographic"},
    39622: {"Unified_Ideograph", "Ideographic"},
    39623: {"Unified_Ideograph", "Ideographic"},
    39624: {"Unified_Ideograph", "Ideographic"},
    39625: {"Unified_Ideograph", "Ideographic"},
    39626: {"Unified_Ideograph", "Ideographic"},
    39627: {"Unified_Ideograph", "Ideographic"},
    39628: {"Unified_Ideograph", "Ideographic"},
    39629: {"Unified_Ideograph", "Ideographic"},
    39630: {"Unified_Ideograph", "Ideographic"},
    39631: {"Unified_Ideograph", "Ideographic"},
    39632: {"Unified_Ideograph", "Ideographic"},
    39633: {"Unified_Ideograph", "Ideographic"},
    39634: {"Unified_Ideograph", "Ideographic"},
    39635: {"Unified_Ideograph", "Ideographic"},
    39636: {"Unified_Ideograph", "Ideographic"},
    39637: {"Unified_Ideograph", "Ideographic"},
    39638: {"Unified_Ideograph", "Ideographic"},
    39639: {"Unified_Ideograph", "Ideographic"},
    39640: {"Unified_Ideograph", "Ideographic"},
    39641: {"Unified_Ideograph", "Ideographic"},
    39642: {"Unified_Ideograph", "Ideographic"},
    39643: {"Unified_Ideograph", "Ideographic"},
    39644: {"Unified_Ideograph", "Ideographic"},
    39645: {"Unified_Ideograph", "Ideographic"},
    39646: {"Unified_Ideograph", "Ideographic"},
    39647: {"Unified_Ideograph", "Ideographic"},
    39648: {"Unified_Ideograph", "Ideographic"},
    39649: {"Unified_Ideograph", "Ideographic"},
    39650: {"Unified_Ideograph", "Ideographic"},
    39651: {"Unified_Ideograph", "Ideographic"},
    39652: {"Unified_Ideograph", "Ideographic"},
    39653: {"Unified_Ideograph", "Ideographic"},
    39654: {"Unified_Ideograph", "Ideographic"},
    39655: {"Unified_Ideograph", "Ideographic"},
    39656: {"Unified_Ideograph", "Ideographic"},
    39657: {"Unified_Ideograph", "Ideographic"},
    39658: {"Unified_Ideograph", "Ideographic"},
    39659: {"Unified_Ideograph", "Ideographic"},
    39660: {"Unified_Ideograph", "Ideographic"},
    39661: {"Unified_Ideograph", "Ideographic"},
    39662: {"Unified_Ideograph", "Ideographic"},
    39663: {"Unified_Ideograph", "Ideographic"},
    39664: {"Unified_Ideograph", "Ideographic"},
    39665: {"Unified_Ideograph", "Ideographic"},
    39666: {"Unified_Ideograph", "Ideographic"},
    39667: {"Unified_Ideograph", "Ideographic"},
    39668: {"Unified_Ideograph", "Ideographic"},
    39669: {"Unified_Ideograph", "Ideographic"},
    39670: {"Unified_Ideograph", "Ideographic"},
    39671: {"Unified_Ideograph", "Ideographic"},
    39672: {"Unified_Ideograph", "Ideographic"},
    39673: {"Unified_Ideograph", "Ideographic"},
    39674: {"Unified_Ideograph", "Ideographic"},
    39675: {"Unified_Ideograph", "Ideographic"},
    39676: {"Unified_Ideograph", "Ideographic"},
    39677: {"Unified_Ideograph", "Ideographic"},
    39678: {"Unified_Ideograph", "Ideographic"},
    39679: {"Unified_Ideograph", "Ideographic"},
    39680: {"Unified_Ideograph", "Ideographic"},
    39681: {"Unified_Ideograph", "Ideographic"},
    39682: {"Unified_Ideograph", "Ideographic"},
    39683: {"Unified_Ideograph", "Ideographic"},
    39684: {"Unified_Ideograph", "Ideographic"},
    39685: {"Unified_Ideograph", "Ideographic"},
    39686: {"Unified_Ideograph", "Ideographic"},
    39687: {"Unified_Ideograph", "Ideographic"},
    39688: {"Unified_Ideograph", "Ideographic"},
    39689: {"Unified_Ideograph", "Ideographic"},
    39690: {"Unified_Ideograph", "Ideographic"},
    39691: {"Unified_Ideograph", "Ideographic"},
    39692: {"Unified_Ideograph", "Ideographic"},
    39693: {"Unified_Ideograph", "Ideographic"},
    39694: {"Unified_Ideograph", "Ideographic"},
    39695: {"Unified_Ideograph", "Ideographic"},
    39696: {"Unified_Ideograph", "Ideographic"},
    39697: {"Unified_Ideograph", "Ideographic"},
    39698: {"Unified_Ideograph", "Ideographic"},
    39699: {"Unified_Ideograph", "Ideographic"},
    39700: {"Unified_Ideograph", "Ideographic"},
    39701: {"Unified_Ideograph", "Ideographic"},
    39702: {"Unified_Ideograph", "Ideographic"},
    39703: {"Unified_Ideograph", "Ideographic"},
    39704: {"Unified_Ideograph", "Ideographic"},
    39705: {"Unified_Ideograph", "Ideographic"},
    39706: {"Unified_Ideograph", "Ideographic"},
    39707: {"Unified_Ideograph", "Ideographic"},
    39708: {"Unified_Ideograph", "Ideographic"},
    39709: {"Unified_Ideograph", "Ideographic"},
    39710: {"Unified_Ideograph", "Ideographic"},
    39711: {"Unified_Ideograph", "Ideographic"},
    39712: {"Unified_Ideograph", "Ideographic"},
    39713: {"Unified_Ideograph", "Ideographic"},
    39714: {"Unified_Ideograph", "Ideographic"},
    39715: {"Unified_Ideograph", "Ideographic"},
    39716: {"Unified_Ideograph", "Ideographic"},
    39717: {"Unified_Ideograph", "Ideographic"},
    39718: {"Unified_Ideograph", "Ideographic"},
    39719: {"Unified_Ideograph", "Ideographic"},
    39720: {"Unified_Ideograph", "Ideographic"},
    39721: {"Unified_Ideograph", "Ideographic"},
    39722: {"Unified_Ideograph", "Ideographic"},
    39723: {"Unified_Ideograph", "Ideographic"},
    39724: {"Unified_Ideograph", "Ideographic"},
    39725: {"Unified_Ideograph", "Ideographic"},
    39726: {"Unified_Ideograph", "Ideographic"},
    39727: {"Unified_Ideograph", "Ideographic"},
    39728: {"Unified_Ideograph", "Ideographic"},
    39729: {"Unified_Ideograph", "Ideographic"},
    39730: {"Unified_Ideograph", "Ideographic"},
    39731: {"Unified_Ideograph", "Ideographic"},
    39732: {"Unified_Ideograph", "Ideographic"},
    39733: {"Unified_Ideograph", "Ideographic"},
    39734: {"Unified_Ideograph", "Ideographic"},
    39735: {"Unified_Ideograph", "Ideographic"},
    39736: {"Unified_Ideograph", "Ideographic"},
    39737: {"Unified_Ideograph", "Ideographic"},
    39738: {"Unified_Ideograph", "Ideographic"},
    39739: {"Unified_Ideograph", "Ideographic"},
    39740: {"Unified_Ideograph", "Ideographic"},
    39741: {"Unified_Ideograph", "Ideographic"},
    39742: {"Unified_Ideograph", "Ideographic"},
    39743: {"Unified_Ideograph", "Ideographic"},
    39744: {"Unified_Ideograph", "Ideographic"},
    39745: {"Unified_Ideograph", "Ideographic"},
    39746: {"Unified_Ideograph", "Ideographic"},
    39747: {"Unified_Ideograph", "Ideographic"},
    39748: {"Unified_Ideograph", "Ideographic"},
    39749: {"Unified_Ideograph", "Ideographic"},
    39750: {"Unified_Ideograph", "Ideographic"},
    39751: {"Unified_Ideograph", "Ideographic"},
    39752: {"Unified_Ideograph", "Ideographic"},
    39753: {"Unified_Ideograph", "Ideographic"},
    39754: {"Unified_Ideograph", "Ideographic"},
    39755: {"Unified_Ideograph", "Ideographic"},
    39756: {"Unified_Ideograph", "Ideographic"},
    39757: {"Unified_Ideograph", "Ideographic"},
    39758: {"Unified_Ideograph", "Ideographic"},
    39759: {"Unified_Ideograph", "Ideographic"},
    39760: {"Unified_Ideograph", "Ideographic"},
    39761: {"Unified_Ideograph", "Ideographic"},
    39762: {"Unified_Ideograph", "Ideographic"},
    39763: {"Unified_Ideograph", "Ideographic"},
    39764: {"Unified_Ideograph", "Ideographic"},
    39765: {"Unified_Ideograph", "Ideographic"},
    39766: {"Unified_Ideograph", "Ideographic"},
    39767: {"Unified_Ideograph", "Ideographic"},
    39768: {"Unified_Ideograph", "Ideographic"},
    39769: {"Unified_Ideograph", "Ideographic"},
    39770: {"Unified_Ideograph", "Ideographic"},
    39771: {"Unified_Ideograph", "Ideographic"},
    39772: {"Unified_Ideograph", "Ideographic"},
    39773: {"Unified_Ideograph", "Ideographic"},
    39774: {"Unified_Ideograph", "Ideographic"},
    39775: {"Unified_Ideograph", "Ideographic"},
    39776: {"Unified_Ideograph", "Ideographic"},
    39777: {"Unified_Ideograph", "Ideographic"},
    39778: {"Unified_Ideograph", "Ideographic"},
    39779: {"Unified_Ideograph", "Ideographic"},
    39780: {"Unified_Ideograph", "Ideographic"},
    39781: {"Unified_Ideograph", "Ideographic"},
    39782: {"Unified_Ideograph", "Ideographic"},
    39783: {"Unified_Ideograph", "Ideographic"},
    39784: {"Unified_Ideograph", "Ideographic"},
    39785: {"Unified_Ideograph", "Ideographic"},
    39786: {"Unified_Ideograph", "Ideographic"},
    39787: {"Unified_Ideograph", "Ideographic"},
    39788: {"Unified_Ideograph", "Ideographic"},
    39789: {"Unified_Ideograph", "Ideographic"},
    39790: {"Unified_Ideograph", "Ideographic"},
    39791: {"Unified_Ideograph", "Ideographic"},
    39792: {"Unified_Ideograph", "Ideographic"},
    39793: {"Unified_Ideograph", "Ideographic"},
    39794: {"Unified_Ideograph", "Ideographic"},
    39795: {"Unified_Ideograph", "Ideographic"},
    39796: {"Unified_Ideograph", "Ideographic"},
    39797: {"Unified_Ideograph", "Ideographic"},
    39798: {"Unified_Ideograph", "Ideographic"},
    39799: {"Unified_Ideograph", "Ideographic"},
    39800: {"Unified_Ideograph", "Ideographic"},
    39801: {"Unified_Ideograph", "Ideographic"},
    39802: {"Unified_Ideograph", "Ideographic"},
    39803: {"Unified_Ideograph", "Ideographic"},
    39804: {"Unified_Ideograph", "Ideographic"},
    39805: {"Unified_Ideograph", "Ideographic"},
    39806: {"Unified_Ideograph", "Ideographic"},
    39807: {"Unified_Ideograph", "Ideographic"},
    39808: {"Unified_Ideograph", "Ideographic"},
    39809: {"Unified_Ideograph", "Ideographic"},
    39810: {"Unified_Ideograph", "Ideographic"},
    39811: {"Unified_Ideograph", "Ideographic"},
    39812: {"Unified_Ideograph", "Ideographic"},
    39813: {"Unified_Ideograph", "Ideographic"},
    39814: {"Unified_Ideograph", "Ideographic"},
    39815: {"Unified_Ideograph", "Ideographic"},
    39816: {"Unified_Ideograph", "Ideographic"},
    39817: {"Unified_Ideograph", "Ideographic"},
    39818: {"Unified_Ideograph", "Ideographic"},
    39819: {"Unified_Ideograph", "Ideographic"},
    39820: {"Unified_Ideograph", "Ideographic"},
    39821: {"Unified_Ideograph", "Ideographic"},
    39822: {"Unified_Ideograph", "Ideographic"},
    39823: {"Unified_Ideograph", "Ideographic"},
    39824: {"Unified_Ideograph", "Ideographic"},
    39825: {"Unified_Ideograph", "Ideographic"},
    39826: {"Unified_Ideograph", "Ideographic"},
    39827: {"Unified_Ideograph", "Ideographic"},
    39828: {"Unified_Ideograph", "Ideographic"},
    39829: {"Unified_Ideograph", "Ideographic"},
    39830: {"Unified_Ideograph", "Ideographic"},
    39831: {"Unified_Ideograph", "Ideographic"},
    39832: {"Unified_Ideograph", "Ideographic"},
    39833: {"Unified_Ideograph", "Ideographic"},
    39834: {"Unified_Ideograph", "Ideographic"},
    39835: {"Unified_Ideograph", "Ideographic"},
    39836: {"Unified_Ideograph", "Ideographic"},
    39837: {"Unified_Ideograph", "Ideographic"},
    39838: {"Unified_Ideograph", "Ideographic"},
    39839: {"Unified_Ideograph", "Ideographic"},
    39840: {"Unified_Ideograph", "Ideographic"},
    39841: {"Unified_Ideograph", "Ideographic"},
    39842: {"Unified_Ideograph", "Ideographic"},
    39843: {"Unified_Ideograph", "Ideographic"},
    39844: {"Unified_Ideograph", "Ideographic"},
    39845: {"Unified_Ideograph", "Ideographic"},
    39846: {"Unified_Ideograph", "Ideographic"},
    39847: {"Unified_Ideograph", "Ideographic"},
    39848: {"Unified_Ideograph", "Ideographic"},
    39849: {"Unified_Ideograph", "Ideographic"},
    39850: {"Unified_Ideograph", "Ideographic"},
    39851: {"Unified_Ideograph", "Ideographic"},
    39852: {"Unified_Ideograph", "Ideographic"},
    39853: {"Unified_Ideograph", "Ideographic"},
    39854: {"Unified_Ideograph", "Ideographic"},
    39855: {"Unified_Ideograph", "Ideographic"},
    39856: {"Unified_Ideograph", "Ideographic"},
    39857: {"Unified_Ideograph", "Ideographic"},
    39858: {"Unified_Ideograph", "Ideographic"},
    39859: {"Unified_Ideograph", "Ideographic"},
    39860: {"Unified_Ideograph", "Ideographic"},
    39861: {"Unified_Ideograph", "Ideographic"},
    39862: {"Unified_Ideograph", "Ideographic"},
    39863: {"Unified_Ideograph", "Ideographic"},
    39864: {"Unified_Ideograph", "Ideographic"},
    39865: {"Unified_Ideograph", "Ideographic"},
    39866: {"Unified_Ideograph", "Ideographic"},
    39867: {"Unified_Ideograph", "Ideographic"},
    39868: {"Unified_Ideograph", "Ideographic"},
    39869: {"Unified_Ideograph", "Ideographic"},
    39870: {"Unified_Ideograph", "Ideographic"},
    39871: {"Unified_Ideograph", "Ideographic"},
    39872: {"Unified_Ideograph", "Ideographic"},
    39873: {"Unified_Ideograph", "Ideographic"},
    39874: {"Unified_Ideograph", "Ideographic"},
    39875: {"Unified_Ideograph", "Ideographic"},
    39876: {"Unified_Ideograph", "Ideographic"},
    39877: {"Unified_Ideograph", "Ideographic"},
    39878: {"Unified_Ideograph", "Ideographic"},
    39879: {"Unified_Ideograph", "Ideographic"},
    39880: {"Unified_Ideograph", "Ideographic"},
    39881: {"Unified_Ideograph", "Ideographic"},
    39882: {"Unified_Ideograph", "Ideographic"},
    39883: {"Unified_Ideograph", "Ideographic"},
    39884: {"Unified_Ideograph", "Ideographic"},
    39885: {"Unified_Ideograph", "Ideographic"},
    39886: {"Unified_Ideograph", "Ideographic"},
    39887: {"Unified_Ideograph", "Ideographic"},
    39888: {"Unified_Ideograph", "Ideographic"},
    39889: {"Unified_Ideograph", "Ideographic"},
    39890: {"Unified_Ideograph", "Ideographic"},
    39891: {"Unified_Ideograph", "Ideographic"},
    39892: {"Unified_Ideograph", "Ideographic"},
    39893: {"Unified_Ideograph", "Ideographic"},
    39894: {"Unified_Ideograph", "Ideographic"},
    39895: {"Unified_Ideograph", "Ideographic"},
    39896: {"Unified_Ideograph", "Ideographic"},
    39897: {"Unified_Ideograph", "Ideographic"},
    39898: {"Unified_Ideograph", "Ideographic"},
    39899: {"Unified_Ideograph", "Ideographic"},
    39900: {"Unified_Ideograph", "Ideographic"},
    39901: {"Unified_Ideograph", "Ideographic"},
    39902: {"Unified_Ideograph", "Ideographic"},
    39903: {"Unified_Ideograph", "Ideographic"},
    39904: {"Unified_Ideograph", "Ideographic"},
    39905: {"Unified_Ideograph", "Ideographic"},
    39906: {"Unified_Ideograph", "Ideographic"},
    39907: {"Unified_Ideograph", "Ideographic"},
    39908: {"Unified_Ideograph", "Ideographic"},
    39909: {"Unified_Ideograph", "Ideographic"},
    39910: {"Unified_Ideograph", "Ideographic"},
    39911: {"Unified_Ideograph", "Ideographic"},
    39912: {"Unified_Ideograph", "Ideographic"},
    39913: {"Unified_Ideograph", "Ideographic"},
    39914: {"Unified_Ideograph", "Ideographic"},
    39915: {"Unified_Ideograph", "Ideographic"},
    39916: {"Unified_Ideograph", "Ideographic"},
    39917: {"Unified_Ideograph", "Ideographic"},
    39918: {"Unified_Ideograph", "Ideographic"},
    39919: {"Unified_Ideograph", "Ideographic"},
    39920: {"Unified_Ideograph", "Ideographic"},
    39921: {"Unified_Ideograph", "Ideographic"},
    39922: {"Unified_Ideograph", "Ideographic"},
    39923: {"Unified_Ideograph", "Ideographic"},
    39924: {"Unified_Ideograph", "Ideographic"},
    39925: {"Unified_Ideograph", "Ideographic"},
    39926: {"Unified_Ideograph", "Ideographic"},
    39927: {"Unified_Ideograph", "Ideographic"},
    39928: {"Unified_Ideograph", "Ideographic"},
    39929: {"Unified_Ideograph", "Ideographic"},
    39930: {"Unified_Ideograph", "Ideographic"},
    39931: {"Unified_Ideograph", "Ideographic"},
    39932: {"Unified_Ideograph", "Ideographic"},
    39933: {"Unified_Ideograph", "Ideographic"},
    39934: {"Unified_Ideograph", "Ideographic"},
    39935: {"Unified_Ideograph", "Ideographic"},
    39936: {"Unified_Ideograph", "Ideographic"},
    39937: {"Unified_Ideograph", "Ideographic"},
    39938: {"Unified_Ideograph", "Ideographic"},
    39939: {"Unified_Ideograph", "Ideographic"},
    39940: {"Unified_Ideograph", "Ideographic"},
    39941: {"Unified_Ideograph", "Ideographic"},
    39942: {"Unified_Ideograph", "Ideographic"},
    39943: {"Unified_Ideograph", "Ideographic"},
    39944: {"Unified_Ideograph", "Ideographic"},
    39945: {"Unified_Ideograph", "Ideographic"},
    39946: {"Unified_Ideograph", "Ideographic"},
    39947: {"Unified_Ideograph", "Ideographic"},
    39948: {"Unified_Ideograph", "Ideographic"},
    39949: {"Unified_Ideograph", "Ideographic"},
    39950: {"Unified_Ideograph", "Ideographic"},
    39951: {"Unified_Ideograph", "Ideographic"},
    39952: {"Unified_Ideograph", "Ideographic"},
    39953: {"Unified_Ideograph", "Ideographic"},
    39954: {"Unified_Ideograph", "Ideographic"},
    39955: {"Unified_Ideograph", "Ideographic"},
    39956: {"Unified_Ideograph", "Ideographic"},
    39957: {"Unified_Ideograph", "Ideographic"},
    39958: {"Unified_Ideograph", "Ideographic"},
    39959: {"Unified_Ideograph", "Ideographic"},
    39960: {"Unified_Ideograph", "Ideographic"},
    39961: {"Unified_Ideograph", "Ideographic"},
    39962: {"Unified_Ideograph", "Ideographic"},
    39963: {"Unified_Ideograph", "Ideographic"},
    39964: {"Unified_Ideograph", "Ideographic"},
    39965: {"Unified_Ideograph", "Ideographic"},
    39966: {"Unified_Ideograph", "Ideographic"},
    39967: {"Unified_Ideograph", "Ideographic"},
    39968: {"Unified_Ideograph", "Ideographic"},
    39969: {"Unified_Ideograph", "Ideographic"},
    39970: {"Unified_Ideograph", "Ideographic"},
    39971: {"Unified_Ideograph", "Ideographic"},
    39972: {"Unified_Ideograph", "Ideographic"},
    39973: {"Unified_Ideograph", "Ideographic"},
    39974: {"Unified_Ideograph", "Ideographic"},
    39975: {"Unified_Ideograph", "Ideographic"},
    39976: {"Unified_Ideograph", "Ideographic"},
    39977: {"Unified_Ideograph", "Ideographic"},
    39978: {"Unified_Ideograph", "Ideographic"},
    39979: {"Unified_Ideograph", "Ideographic"},
    39980: {"Unified_Ideograph", "Ideographic"},
    39981: {"Unified_Ideograph", "Ideographic"},
    39982: {"Unified_Ideograph", "Ideographic"},
    39983: {"Unified_Ideograph", "Ideographic"},
    39984: {"Unified_Ideograph", "Ideographic"},
    39985: {"Unified_Ideograph", "Ideographic"},
    39986: {"Unified_Ideograph", "Ideographic"},
    39987: {"Unified_Ideograph", "Ideographic"},
    39988: {"Unified_Ideograph", "Ideographic"},
    39989: {"Unified_Ideograph", "Ideographic"},
    39990: {"Unified_Ideograph", "Ideographic"},
    39991: {"Unified_Ideograph", "Ideographic"},
    39992: {"Unified_Ideograph", "Ideographic"},
    39993: {"Unified_Ideograph", "Ideographic"},
    39994: {"Unified_Ideograph", "Ideographic"},
    39995: {"Unified_Ideograph", "Ideographic"},
    39996: {"Unified_Ideograph", "Ideographic"},
    39997: {"Unified_Ideograph", "Ideographic"},
    39998: {"Unified_Ideograph", "Ideographic"},
    39999: {"Unified_Ideograph", "Ideographic"},
    40000: {"Unified_Ideograph", "Ideographic"},
    40001: {"Unified_Ideograph", "Ideographic"},
    40002: {"Unified_Ideograph", "Ideographic"},
    40003: {"Unified_Ideograph", "Ideographic"},
    40004: {"Unified_Ideograph", "Ideographic"},
    40005: {"Unified_Ideograph", "Ideographic"},
    40006: {"Unified_Ideograph", "Ideographic"},
    40007: {"Unified_Ideograph", "Ideographic"},
    40008: {"Unified_Ideograph", "Ideographic"},
    40009: {"Unified_Ideograph", "Ideographic"},
    40010: {"Unified_Ideograph", "Ideographic"},
    40011: {"Unified_Ideograph", "Ideographic"},
    40012: {"Unified_Ideograph", "Ideographic"},
    40013: {"Unified_Ideograph", "Ideographic"},
    40014: {"Unified_Ideograph", "Ideographic"},
    40015: {"Unified_Ideograph", "Ideographic"},
    40016: {"Unified_Ideograph", "Ideographic"},
    40017: {"Unified_Ideograph", "Ideographic"},
    40018: {"Unified_Ideograph", "Ideographic"},
    40019: {"Unified_Ideograph", "Ideographic"},
    40020: {"Unified_Ideograph", "Ideographic"},
    40021: {"Unified_Ideograph", "Ideographic"},
    40022: {"Unified_Ideograph", "Ideographic"},
    40023: {"Unified_Ideograph", "Ideographic"},
    40024: {"Unified_Ideograph", "Ideographic"},
    40025: {"Unified_Ideograph", "Ideographic"},
    40026: {"Unified_Ideograph", "Ideographic"},
    40027: {"Unified_Ideograph", "Ideographic"},
    40028: {"Unified_Ideograph", "Ideographic"},
    40029: {"Unified_Ideograph", "Ideographic"},
    40030: {"Unified_Ideograph", "Ideographic"},
    40031: {"Unified_Ideograph", "Ideographic"},
    40032: {"Unified_Ideograph", "Ideographic"},
    40033: {"Unified_Ideograph", "Ideographic"},
    40034: {"Unified_Ideograph", "Ideographic"},
    40035: {"Unified_Ideograph", "Ideographic"},
    40036: {"Unified_Ideograph", "Ideographic"},
    40037: {"Unified_Ideograph", "Ideographic"},
    40038: {"Unified_Ideograph", "Ideographic"},
    40039: {"Unified_Ideograph", "Ideographic"},
    40040: {"Unified_Ideograph", "Ideographic"},
    40041: {"Unified_Ideograph", "Ideographic"},
    40042: {"Unified_Ideograph", "Ideographic"},
    40043: {"Unified_Ideograph", "Ideographic"},
    40044: {"Unified_Ideograph", "Ideographic"},
    40045: {"Unified_Ideograph", "Ideographic"},
    40046: {"Unified_Ideograph", "Ideographic"},
    40047: {"Unified_Ideograph", "Ideographic"},
    40048: {"Unified_Ideograph", "Ideographic"},
    40049: {"Unified_Ideograph", "Ideographic"},
    40050: {"Unified_Ideograph", "Ideographic"},
    40051: {"Unified_Ideograph", "Ideographic"},
    40052: {"Unified_Ideograph", "Ideographic"},
    40053: {"Unified_Ideograph", "Ideographic"},
    40054: {"Unified_Ideograph", "Ideographic"},
    40055: {"Unified_Ideograph", "Ideographic"},
    40056: {"Unified_Ideograph", "Ideographic"},
    40057: {"Unified_Ideograph", "Ideographic"},
    40058: {"Unified_Ideograph", "Ideographic"},
    40059: {"Unified_Ideograph", "Ideographic"},
    40060: {"Unified_Ideograph", "Ideographic"},
    40061: {"Unified_Ideograph", "Ideographic"},
    40062: {"Unified_Ideograph", "Ideographic"},
    40063: {"Unified_Ideograph", "Ideographic"},
    40064: {"Unified_Ideograph", "Ideographic"},
    40065: {"Unified_Ideograph", "Ideographic"},
    40066: {"Unified_Ideograph", "Ideographic"},
    40067: {"Unified_Ideograph", "Ideographic"},
    40068: {"Unified_Ideograph", "Ideographic"},
    40069: {"Unified_Ideograph", "Ideographic"},
    40070: {"Unified_Ideograph", "Ideographic"},
    40071: {"Unified_Ideograph", "Ideographic"},
    40072: {"Unified_Ideograph", "Ideographic"},
    40073: {"Unified_Ideograph", "Ideographic"},
    40074: {"Unified_Ideograph", "Ideographic"},
    40075: {"Unified_Ideograph", "Ideographic"},
    40076: {"Unified_Ideograph", "Ideographic"},
    40077: {"Unified_Ideograph", "Ideographic"},
    40078: {"Unified_Ideograph", "Ideographic"},
    40079: {"Unified_Ideograph", "Ideographic"},
    40080: {"Unified_Ideograph", "Ideographic"},
    40081: {"Unified_Ideograph", "Ideographic"},
    40082: {"Unified_Ideograph", "Ideographic"},
    40083: {"Unified_Ideograph", "Ideographic"},
    40084: {"Unified_Ideograph", "Ideographic"},
    40085: {"Unified_Ideograph", "Ideographic"},
    40086: {"Unified_Ideograph", "Ideographic"},
    40087: {"Unified_Ideograph", "Ideographic"},
    40088: {"Unified_Ideograph", "Ideographic"},
    40089: {"Unified_Ideograph", "Ideographic"},
    40090: {"Unified_Ideograph", "Ideographic"},
    40091: {"Unified_Ideograph", "Ideographic"},
    40092: {"Unified_Ideograph", "Ideographic"},
    40093: {"Unified_Ideograph", "Ideographic"},
    40094: {"Unified_Ideograph", "Ideographic"},
    40095: {"Unified_Ideograph", "Ideographic"},
    40096: {"Unified_Ideograph", "Ideographic"},
    40097: {"Unified_Ideograph", "Ideographic"},
    40098: {"Unified_Ideograph", "Ideographic"},
    40099: {"Unified_Ideograph", "Ideographic"},
    40100: {"Unified_Ideograph", "Ideographic"},
    40101: {"Unified_Ideograph", "Ideographic"},
    40102: {"Unified_Ideograph", "Ideographic"},
    40103: {"Unified_Ideograph", "Ideographic"},
    40104: {"Unified_Ideograph", "Ideographic"},
    40105: {"Unified_Ideograph", "Ideographic"},
    40106: {"Unified_Ideograph", "Ideographic"},
    40107: {"Unified_Ideograph", "Ideographic"},
    40108: {"Unified_Ideograph", "Ideographic"},
    40109: {"Unified_Ideograph", "Ideographic"},
    40110: {"Unified_Ideograph", "Ideographic"},
    40111: {"Unified_Ideograph", "Ideographic"},
    40112: {"Unified_Ideograph", "Ideographic"},
    40113: {"Unified_Ideograph", "Ideographic"},
    40114: {"Unified_Ideograph", "Ideographic"},
    40115: {"Unified_Ideograph", "Ideographic"},
    40116: {"Unified_Ideograph", "Ideographic"},
    40117: {"Unified_Ideograph", "Ideographic"},
    40118: {"Unified_Ideograph", "Ideographic"},
    40119: {"Unified_Ideograph", "Ideographic"},
    40120: {"Unified_Ideograph", "Ideographic"},
    40121: {"Unified_Ideograph", "Ideographic"},
    40122: {"Unified_Ideograph", "Ideographic"},
    40123: {"Unified_Ideograph", "Ideographic"},
    40124: {"Unified_Ideograph", "Ideographic"},
    40125: {"Unified_Ideograph", "Ideographic"},
    40126: {"Unified_Ideograph", "Ideographic"},
    40127: {"Unified_Ideograph", "Ideographic"},
    40128: {"Unified_Ideograph", "Ideographic"},
    40129: {"Unified_Ideograph", "Ideographic"},
    40130: {"Unified_Ideograph", "Ideographic"},
    40131: {"Unified_Ideograph", "Ideographic"},
    40132: {"Unified_Ideograph", "Ideographic"},
    40133: {"Unified_Ideograph", "Ideographic"},
    40134: {"Unified_Ideograph", "Ideographic"},
    40135: {"Unified_Ideograph", "Ideographic"},
    40136: {"Unified_Ideograph", "Ideographic"},
    40137: {"Unified_Ideograph", "Ideographic"},
    40138: {"Unified_Ideograph", "Ideographic"},
    40139: {"Unified_Ideograph", "Ideographic"},
    40140: {"Unified_Ideograph", "Ideographic"},
    40141: {"Unified_Ideograph", "Ideographic"},
    40142: {"Unified_Ideograph", "Ideographic"},
    40143: {"Unified_Ideograph", "Ideographic"},
    40144: {"Unified_Ideograph", "Ideographic"},
    40145: {"Unified_Ideograph", "Ideographic"},
    40146: {"Unified_Ideograph", "Ideographic"},
    40147: {"Unified_Ideograph", "Ideographic"},
    40148: {"Unified_Ideograph", "Ideographic"},
    40149: {"Unified_Ideograph", "Ideographic"},
    40150: {"Unified_Ideograph", "Ideographic"},
    40151: {"Unified_Ideograph", "Ideographic"},
    40152: {"Unified_Ideograph", "Ideographic"},
    40153: {"Unified_Ideograph", "Ideographic"},
    40154: {"Unified_Ideograph", "Ideographic"},
    40155: {"Unified_Ideograph", "Ideographic"},
    40156: {"Unified_Ideograph", "Ideographic"},
    40157: {"Unified_Ideograph", "Ideographic"},
    40158: {"Unified_Ideograph", "Ideographic"},
    40159: {"Unified_Ideograph", "Ideographic"},
    40160: {"Unified_Ideograph", "Ideographic"},
    40161: {"Unified_Ideograph", "Ideographic"},
    40162: {"Unified_Ideograph", "Ideographic"},
    40163: {"Unified_Ideograph", "Ideographic"},
    40164: {"Unified_Ideograph", "Ideographic"},
    40165: {"Unified_Ideograph", "Ideographic"},
    40166: {"Unified_Ideograph", "Ideographic"},
    40167: {"Unified_Ideograph", "Ideographic"},
    40168: {"Unified_Ideograph", "Ideographic"},
    40169: {"Unified_Ideograph", "Ideographic"},
    40170: {"Unified_Ideograph", "Ideographic"},
    40171: {"Unified_Ideograph", "Ideographic"},
    40172: {"Unified_Ideograph", "Ideographic"},
    40173: {"Unified_Ideograph", "Ideographic"},
    40174: {"Unified_Ideograph", "Ideographic"},
    40175: {"Unified_Ideograph", "Ideographic"},
    40176: {"Unified_Ideograph", "Ideographic"},
    40177: {"Unified_Ideograph", "Ideographic"},
    40178: {"Unified_Ideograph", "Ideographic"},
    40179: {"Unified_Ideograph", "Ideographic"},
    40180: {"Unified_Ideograph", "Ideographic"},
    40181: {"Unified_Ideograph", "Ideographic"},
    40182: {"Unified_Ideograph", "Ideographic"},
    40183: {"Unified_Ideograph", "Ideographic"},
    40184: {"Unified_Ideograph", "Ideographic"},
    40185: {"Unified_Ideograph", "Ideographic"},
    40186: {"Unified_Ideograph", "Ideographic"},
    40187: {"Unified_Ideograph", "Ideographic"},
    40188: {"Unified_Ideograph", "Ideographic"},
    40189: {"Unified_Ideograph", "Ideographic"},
    40190: {"Unified_Ideograph", "Ideographic"},
    40191: {"Unified_Ideograph", "Ideographic"},
    40192: {"Unified_Ideograph", "Ideographic"},
    40193: {"Unified_Ideograph", "Ideographic"},
    40194: {"Unified_Ideograph", "Ideographic"},
    40195: {"Unified_Ideograph", "Ideographic"},
    40196: {"Unified_Ideograph", "Ideographic"},
    40197: {"Unified_Ideograph", "Ideographic"},
    40198: {"Unified_Ideograph", "Ideographic"},
    40199: {"Unified_Ideograph", "Ideographic"},
    40200: {"Unified_Ideograph", "Ideographic"},
    40201: {"Unified_Ideograph", "Ideographic"},
    40202: {"Unified_Ideograph", "Ideographic"},
    40203: {"Unified_Ideograph", "Ideographic"},
    40204: {"Unified_Ideograph", "Ideographic"},
    40205: {"Unified_Ideograph", "Ideographic"},
    40206: {"Unified_Ideograph", "Ideographic"},
    40207: {"Unified_Ideograph", "Ideographic"},
    40208: {"Unified_Ideograph", "Ideographic"},
    40209: {"Unified_Ideograph", "Ideographic"},
    40210: {"Unified_Ideograph", "Ideographic"},
    40211: {"Unified_Ideograph", "Ideographic"},
    40212: {"Unified_Ideograph", "Ideographic"},
    40213: {"Unified_Ideograph", "Ideographic"},
    40214: {"Unified_Ideograph", "Ideographic"},
    40215: {"Unified_Ideograph", "Ideographic"},
    40216: {"Unified_Ideograph", "Ideographic"},
    40217: {"Unified_Ideograph", "Ideographic"},
    40218: {"Unified_Ideograph", "Ideographic"},
    40219: {"Unified_Ideograph", "Ideographic"},
    40220: {"Unified_Ideograph", "Ideographic"},
    40221: {"Unified_Ideograph", "Ideographic"},
    40222: {"Unified_Ideograph", "Ideographic"},
    40223: {"Unified_Ideograph", "Ideographic"},
    40224: {"Unified_Ideograph", "Ideographic"},
    40225: {"Unified_Ideograph", "Ideographic"},
    40226: {"Unified_Ideograph", "Ideographic"},
    40227: {"Unified_Ideograph", "Ideographic"},
    40228: {"Unified_Ideograph", "Ideographic"},
    40229: {"Unified_Ideograph", "Ideographic"},
    40230: {"Unified_Ideograph", "Ideographic"},
    40231: {"Unified_Ideograph", "Ideographic"},
    40232: {"Unified_Ideograph", "Ideographic"},
    40233: {"Unified_Ideograph", "Ideographic"},
    40234: {"Unified_Ideograph", "Ideographic"},
    40235: {"Unified_Ideograph", "Ideographic"},
    40236: {"Unified_Ideograph", "Ideographic"},
    40237: {"Unified_Ideograph", "Ideographic"},
    40238: {"Unified_Ideograph", "Ideographic"},
    40239: {"Unified_Ideograph", "Ideographic"},
    40240: {"Unified_Ideograph", "Ideographic"},
    40241: {"Unified_Ideograph", "Ideographic"},
    40242: {"Unified_Ideograph", "Ideographic"},
    40243: {"Unified_Ideograph", "Ideographic"},
    40244: {"Unified_Ideograph", "Ideographic"},
    40245: {"Unified_Ideograph", "Ideographic"},
    40246: {"Unified_Ideograph", "Ideographic"},
    40247: {"Unified_Ideograph", "Ideographic"},
    40248: {"Unified_Ideograph", "Ideographic"},
    40249: {"Unified_Ideograph", "Ideographic"},
    40250: {"Unified_Ideograph", "Ideographic"},
    40251: {"Unified_Ideograph", "Ideographic"},
    40252: {"Unified_Ideograph", "Ideographic"},
    40253: {"Unified_Ideograph", "Ideographic"},
    40254: {"Unified_Ideograph", "Ideographic"},
    40255: {"Unified_Ideograph", "Ideographic"},
    40256: {"Unified_Ideograph", "Ideographic"},
    40257: {"Unified_Ideograph", "Ideographic"},
    40258: {"Unified_Ideograph", "Ideographic"},
    40259: {"Unified_Ideograph", "Ideographic"},
    40260: {"Unified_Ideograph", "Ideographic"},
    40261: {"Unified_Ideograph", "Ideographic"},
    40262: {"Unified_Ideograph", "Ideographic"},
    40263: {"Unified_Ideograph", "Ideographic"},
    40264: {"Unified_Ideograph", "Ideographic"},
    40265: {"Unified_Ideograph", "Ideographic"},
    40266: {"Unified_Ideograph", "Ideographic"},
    40267: {"Unified_Ideograph", "Ideographic"},
    40268: {"Unified_Ideograph", "Ideographic"},
    40269: {"Unified_Ideograph", "Ideographic"},
    40270: {"Unified_Ideograph", "Ideographic"},
    40271: {"Unified_Ideograph", "Ideographic"},
    40272: {"Unified_Ideograph", "Ideographic"},
    40273: {"Unified_Ideograph", "Ideographic"},
    40274: {"Unified_Ideograph", "Ideographic"},
    40275: {"Unified_Ideograph", "Ideographic"},
    40276: {"Unified_Ideograph", "Ideographic"},
    40277: {"Unified_Ideograph", "Ideographic"},
    40278: {"Unified_Ideograph", "Ideographic"},
    40279: {"Unified_Ideograph", "Ideographic"},
    40280: {"Unified_Ideograph", "Ideographic"},
    40281: {"Unified_Ideograph", "Ideographic"},
    40282: {"Unified_Ideograph", "Ideographic"},
    40283: {"Unified_Ideograph", "Ideographic"},
    40284: {"Unified_Ideograph", "Ideographic"},
    40285: {"Unified_Ideograph", "Ideographic"},
    40286: {"Unified_Ideograph", "Ideographic"},
    40287: {"Unified_Ideograph", "Ideographic"},
    40288: {"Unified_Ideograph", "Ideographic"},
    40289: {"Unified_Ideograph", "Ideographic"},
    40290: {"Unified_Ideograph", "Ideographic"},
    40291: {"Unified_Ideograph", "Ideographic"},
    40292: {"Unified_Ideograph", "Ideographic"},
    40293: {"Unified_Ideograph", "Ideographic"},
    40294: {"Unified_Ideograph", "Ideographic"},
    40295: {"Unified_Ideograph", "Ideographic"},
    40296: {"Unified_Ideograph", "Ideographic"},
    40297: {"Unified_Ideograph", "Ideographic"},
    40298: {"Unified_Ideograph", "Ideographic"},
    40299: {"Unified_Ideograph", "Ideographic"},
    40300: {"Unified_Ideograph", "Ideographic"},
    40301: {"Unified_Ideograph", "Ideographic"},
    40302: {"Unified_Ideograph", "Ideographic"},
    40303: {"Unified_Ideograph", "Ideographic"},
    40304: {"Unified_Ideograph", "Ideographic"},
    40305: {"Unified_Ideograph", "Ideographic"},
    40306: {"Unified_Ideograph", "Ideographic"},
    40307: {"Unified_Ideograph", "Ideographic"},
    40308: {"Unified_Ideograph", "Ideographic"},
    40309: {"Unified_Ideograph", "Ideographic"},
    40310: {"Unified_Ideograph", "Ideographic"},
    40311: {"Unified_Ideograph", "Ideographic"},
    40312: {"Unified_Ideograph", "Ideographic"},
    40313: {"Unified_Ideograph", "Ideographic"},
    40314: {"Unified_Ideograph", "Ideographic"},
    40315: {"Unified_Ideograph", "Ideographic"},
    40316: {"Unified_Ideograph", "Ideographic"},
    40317: {"Unified_Ideograph", "Ideographic"},
    40318: {"Unified_Ideograph", "Ideographic"},
    40319: {"Unified_Ideograph", "Ideographic"},
    40320: {"Unified_Ideograph", "Ideographic"},
    40321: {"Unified_Ideograph", "Ideographic"},
    40322: {"Unified_Ideograph", "Ideographic"},
    40323: {"Unified_Ideograph", "Ideographic"},
    40324: {"Unified_Ideograph", "Ideographic"},
    40325: {"Unified_Ideograph", "Ideographic"},
    40326: {"Unified_Ideograph", "Ideographic"},
    40327: {"Unified_Ideograph", "Ideographic"},
    40328: {"Unified_Ideograph", "Ideographic"},
    40329: {"Unified_Ideograph", "Ideographic"},
    40330: {"Unified_Ideograph", "Ideographic"},
    40331: {"Unified_Ideograph", "Ideographic"},
    40332: {"Unified_Ideograph", "Ideographic"},
    40333: {"Unified_Ideograph", "Ideographic"},
    40334: {"Unified_Ideograph", "Ideographic"},
    40335: {"Unified_Ideograph", "Ideographic"},
    40336: {"Unified_Ideograph", "Ideographic"},
    40337: {"Unified_Ideograph", "Ideographic"},
    40338: {"Unified_Ideograph", "Ideographic"},
    40339: {"Unified_Ideograph", "Ideographic"},
    40340: {"Unified_Ideograph", "Ideographic"},
    40341: {"Unified_Ideograph", "Ideographic"},
    40342: {"Unified_Ideograph", "Ideographic"},
    40343: {"Unified_Ideograph", "Ideographic"},
    40344: {"Unified_Ideograph", "Ideographic"},
    40345: {"Unified_Ideograph", "Ideographic"},
    40346: {"Unified_Ideograph", "Ideographic"},
    40347: {"Unified_Ideograph", "Ideographic"},
    40348: {"Unified_Ideograph", "Ideographic"},
    40349: {"Unified_Ideograph", "Ideographic"},
    40350: {"Unified_Ideograph", "Ideographic"},
    40351: {"Unified_Ideograph", "Ideographic"},
    40352: {"Unified_Ideograph", "Ideographic"},
    40353: {"Unified_Ideograph", "Ideographic"},
    40354: {"Unified_Ideograph", "Ideographic"},
    40355: {"Unified_Ideograph", "Ideographic"},
    40356: {"Unified_Ideograph", "Ideographic"},
    40357: {"Unified_Ideograph", "Ideographic"},
    40358: {"Unified_Ideograph", "Ideographic"},
    40359: {"Unified_Ideograph", "Ideographic"},
    40360: {"Unified_Ideograph", "Ideographic"},
    40361: {"Unified_Ideograph", "Ideographic"},
    40362: {"Unified_Ideograph", "Ideographic"},
    40363: {"Unified_Ideograph", "Ideographic"},
    40364: {"Unified_Ideograph", "Ideographic"},
    40365: {"Unified_Ideograph", "Ideographic"},
    40366: {"Unified_Ideograph", "Ideographic"},
    40367: {"Unified_Ideograph", "Ideographic"},
    40368: {"Unified_Ideograph", "Ideographic"},
    40369: {"Unified_Ideograph", "Ideographic"},
    40370: {"Unified_Ideograph", "Ideographic"},
    40371: {"Unified_Ideograph", "Ideographic"},
    40372: {"Unified_Ideograph", "Ideographic"},
    40373: {"Unified_Ideograph", "Ideographic"},
    40374: {"Unified_Ideograph", "Ideographic"},
    40375: {"Unified_Ideograph", "Ideographic"},
    40376: {"Unified_Ideograph", "Ideographic"},
    40377: {"Unified_Ideograph", "Ideographic"},
    40378: {"Unified_Ideograph", "Ideographic"},
    40379: {"Unified_Ideograph", "Ideographic"},
    40380: {"Unified_Ideograph", "Ideographic"},
    40381: {"Unified_Ideograph", "Ideographic"},
    40382: {"Unified_Ideograph", "Ideographic"},
    40383: {"Unified_Ideograph", "Ideographic"},
    40384: {"Unified_Ideograph", "Ideographic"},
    40385: {"Unified_Ideograph", "Ideographic"},
    40386: {"Unified_Ideograph", "Ideographic"},
    40387: {"Unified_Ideograph", "Ideographic"},
    40388: {"Unified_Ideograph", "Ideographic"},
    40389: {"Unified_Ideograph", "Ideographic"},
    40390: {"Unified_Ideograph", "Ideographic"},
    40391: {"Unified_Ideograph", "Ideographic"},
    40392: {"Unified_Ideograph", "Ideographic"},
    40393: {"Unified_Ideograph", "Ideographic"},
    40394: {"Unified_Ideograph", "Ideographic"},
    40395: {"Unified_Ideograph", "Ideographic"},
    40396: {"Unified_Ideograph", "Ideographic"},
    40397: {"Unified_Ideograph", "Ideographic"},
    40398: {"Unified_Ideograph", "Ideographic"},
    40399: {"Unified_Ideograph", "Ideographic"},
    40400: {"Unified_Ideograph", "Ideographic"},
    40401: {"Unified_Ideograph", "Ideographic"},
    40402: {"Unified_Ideograph", "Ideographic"},
    40403: {"Unified_Ideograph", "Ideographic"},
    40404: {"Unified_Ideograph", "Ideographic"},
    40405: {"Unified_Ideograph", "Ideographic"},
    40406: {"Unified_Ideograph", "Ideographic"},
    40407: {"Unified_Ideograph", "Ideographic"},
    40408: {"Unified_Ideograph", "Ideographic"},
    40409: {"Unified_Ideograph", "Ideographic"},
    40410: {"Unified_Ideograph", "Ideographic"},
    40411: {"Unified_Ideograph", "Ideographic"},
    40412: {"Unified_Ideograph", "Ideographic"},
    40413: {"Unified_Ideograph", "Ideographic"},
    40414: {"Unified_Ideograph", "Ideographic"},
    40415: {"Unified_Ideograph", "Ideographic"},
    40416: {"Unified_Ideograph", "Ideographic"},
    40417: {"Unified_Ideograph", "Ideographic"},
    40418: {"Unified_Ideograph", "Ideographic"},
    40419: {"Unified_Ideograph", "Ideographic"},
    40420: {"Unified_Ideograph", "Ideographic"},
    40421: {"Unified_Ideograph", "Ideographic"},
    40422: {"Unified_Ideograph", "Ideographic"},
    40423: {"Unified_Ideograph", "Ideographic"},
    40424: {"Unified_Ideograph", "Ideographic"},
    40425: {"Unified_Ideograph", "Ideographic"},
    40426: {"Unified_Ideograph", "Ideographic"},
    40427: {"Unified_Ideograph", "Ideographic"},
    40428: {"Unified_Ideograph", "Ideographic"},
    40429: {"Unified_Ideograph", "Ideographic"},
    40430: {"Unified_Ideograph", "Ideographic"},
    40431: {"Unified_Ideograph", "Ideographic"},
    40432: {"Unified_Ideograph", "Ideographic"},
    40433: {"Unified_Ideograph", "Ideographic"},
    40434: {"Unified_Ideograph", "Ideographic"},
    40435: {"Unified_Ideograph", "Ideographic"},
    40436: {"Unified_Ideograph", "Ideographic"},
    40437: {"Unified_Ideograph", "Ideographic"},
    40438: {"Unified_Ideograph", "Ideographic"},
    40439: {"Unified_Ideograph", "Ideographic"},
    40440: {"Unified_Ideograph", "Ideographic"},
    40441: {"Unified_Ideograph", "Ideographic"},
    40442: {"Unified_Ideograph", "Ideographic"},
    40443: {"Unified_Ideograph", "Ideographic"},
    40444: {"Unified_Ideograph", "Ideographic"},
    40445: {"Unified_Ideograph", "Ideographic"},
    40446: {"Unified_Ideograph", "Ideographic"},
    40447: {"Unified_Ideograph", "Ideographic"},
    40448: {"Unified_Ideograph", "Ideographic"},
    40449: {"Unified_Ideograph", "Ideographic"},
    40450: {"Unified_Ideograph", "Ideographic"},
    40451: {"Unified_Ideograph", "Ideographic"},
    40452: {"Unified_Ideograph", "Ideographic"},
    40453: {"Unified_Ideograph", "Ideographic"},
    40454: {"Unified_Ideograph", "Ideographic"},
    40455: {"Unified_Ideograph", "Ideographic"},
    40456: {"Unified_Ideograph", "Ideographic"},
    40457: {"Unified_Ideograph", "Ideographic"},
    40458: {"Unified_Ideograph", "Ideographic"},
    40459: {"Unified_Ideograph", "Ideographic"},
    40460: {"Unified_Ideograph", "Ideographic"},
    40461: {"Unified_Ideograph", "Ideographic"},
    40462: {"Unified_Ideograph", "Ideographic"},
    40463: {"Unified_Ideograph", "Ideographic"},
    40464: {"Unified_Ideograph", "Ideographic"},
    40465: {"Unified_Ideograph", "Ideographic"},
    40466: {"Unified_Ideograph", "Ideographic"},
    40467: {"Unified_Ideograph", "Ideographic"},
    40468: {"Unified_Ideograph", "Ideographic"},
    40469: {"Unified_Ideograph", "Ideographic"},
    40470: {"Unified_Ideograph", "Ideographic"},
    40471: {"Unified_Ideograph", "Ideographic"},
    40472: {"Unified_Ideograph", "Ideographic"},
    40473: {"Unified_Ideograph", "Ideographic"},
    40474: {"Unified_Ideograph", "Ideographic"},
    40475: {"Unified_Ideograph", "Ideographic"},
    40476: {"Unified_Ideograph", "Ideographic"},
    40477: {"Unified_Ideograph", "Ideographic"},
    40478: {"Unified_Ideograph", "Ideographic"},
    40479: {"Unified_Ideograph", "Ideographic"},
    40480: {"Unified_Ideograph", "Ideographic"},
    40481: {"Unified_Ideograph", "Ideographic"},
    40482: {"Unified_Ideograph", "Ideographic"},
    40483: {"Unified_Ideograph", "Ideographic"},
    40484: {"Unified_Ideograph", "Ideographic"},
    40485: {"Unified_Ideograph", "Ideographic"},
    40486: {"Unified_Ideograph", "Ideographic"},
    40487: {"Unified_Ideograph", "Ideographic"},
    40488: {"Unified_Ideograph", "Ideographic"},
    40489: {"Unified_Ideograph", "Ideographic"},
    40490: {"Unified_Ideograph", "Ideographic"},
    40491: {"Unified_Ideograph", "Ideographic"},
    40492: {"Unified_Ideograph", "Ideographic"},
    40493: {"Unified_Ideograph", "Ideographic"},
    40494: {"Unified_Ideograph", "Ideographic"},
    40495: {"Unified_Ideograph", "Ideographic"},
    40496: {"Unified_Ideograph", "Ideographic"},
    40497: {"Unified_Ideograph", "Ideographic"},
    40498: {"Unified_Ideograph", "Ideographic"},
    40499: {"Unified_Ideograph", "Ideographic"},
    40500: {"Unified_Ideograph", "Ideographic"},
    40501: {"Unified_Ideograph", "Ideographic"},
    40502: {"Unified_Ideograph", "Ideographic"},
    40503: {"Unified_Ideograph", "Ideographic"},
    40504: {"Unified_Ideograph", "Ideographic"},
    40505: {"Unified_Ideograph", "Ideographic"},
    40506: {"Unified_Ideograph", "Ideographic"},
    40507: {"Unified_Ideograph", "Ideographic"},
    40508: {"Unified_Ideograph", "Ideographic"},
    40509: {"Unified_Ideograph", "Ideographic"},
    40510: {"Unified_Ideograph", "Ideographic"},
    40511: {"Unified_Ideograph", "Ideographic"},
    40512: {"Unified_Ideograph", "Ideographic"},
    40513: {"Unified_Ideograph", "Ideographic"},
    40514: {"Unified_Ideograph", "Ideographic"},
    40515: {"Unified_Ideograph", "Ideographic"},
    40516: {"Unified_Ideograph", "Ideographic"},
    40517: {"Unified_Ideograph", "Ideographic"},
    40518: {"Unified_Ideograph", "Ideographic"},
    40519: {"Unified_Ideograph", "Ideographic"},
    40520: {"Unified_Ideograph", "Ideographic"},
    40521: {"Unified_Ideograph", "Ideographic"},
    40522: {"Unified_Ideograph", "Ideographic"},
    40523: {"Unified_Ideograph", "Ideographic"},
    40524: {"Unified_Ideograph", "Ideographic"},
    40525: {"Unified_Ideograph", "Ideographic"},
    40526: {"Unified_Ideograph", "Ideographic"},
    40527: {"Unified_Ideograph", "Ideographic"},
    40528: {"Unified_Ideograph", "Ideographic"},
    40529: {"Unified_Ideograph", "Ideographic"},
    40530: {"Unified_Ideograph", "Ideographic"},
    40531: {"Unified_Ideograph", "Ideographic"},
    40532: {"Unified_Ideograph", "Ideographic"},
    40533: {"Unified_Ideograph", "Ideographic"},
    40534: {"Unified_Ideograph", "Ideographic"},
    40535: {"Unified_Ideograph", "Ideographic"},
    40536: {"Unified_Ideograph", "Ideographic"},
    40537: {"Unified_Ideograph", "Ideographic"},
    40538: {"Unified_Ideograph", "Ideographic"},
    40539: {"Unified_Ideograph", "Ideographic"},
    40540: {"Unified_Ideograph", "Ideographic"},
    40541: {"Unified_Ideograph", "Ideographic"},
    40542: {"Unified_Ideograph", "Ideographic"},
    40543: {"Unified_Ideograph", "Ideographic"},
    40544: {"Unified_Ideograph", "Ideographic"},
    40545: {"Unified_Ideograph", "Ideographic"},
    40546: {"Unified_Ideograph", "Ideographic"},
    40547: {"Unified_Ideograph", "Ideographic"},
    40548: {"Unified_Ideograph", "Ideographic"},
    40549: {"Unified_Ideograph", "Ideographic"},
    40550: {"Unified_Ideograph", "Ideographic"},
    40551: {"Unified_Ideograph", "Ideographic"},
    40552: {"Unified_Ideograph", "Ideographic"},
    40553: {"Unified_Ideograph", "Ideographic"},
    40554: {"Unified_Ideograph", "Ideographic"},
    40555: {"Unified_Ideograph", "Ideographic"},
    40556: {"Unified_Ideograph", "Ideographic"},
    40557: {"Unified_Ideograph", "Ideographic"},
    40558: {"Unified_Ideograph", "Ideographic"},
    40559: {"Unified_Ideograph", "Ideographic"},
    40560: {"Unified_Ideograph", "Ideographic"},
    40561: {"Unified_Ideograph", "Ideographic"},
    40562: {"Unified_Ideograph", "Ideographic"},
    40563: {"Unified_Ideograph", "Ideographic"},
    40564: {"Unified_Ideograph", "Ideographic"},
    40565: {"Unified_Ideograph", "Ideographic"},
    40566: {"Unified_Ideograph", "Ideographic"},
    40567: {"Unified_Ideograph", "Ideographic"},
    40568: {"Unified_Ideograph", "Ideographic"},
    40569: {"Unified_Ideograph", "Ideographic"},
    40570: {"Unified_Ideograph", "Ideographic"},
    40571: {"Unified_Ideograph", "Ideographic"},
    40572: {"Unified_Ideograph", "Ideographic"},
    40573: {"Unified_Ideograph", "Ideographic"},
    40574: {"Unified_Ideograph", "Ideographic"},
    40575: {"Unified_Ideograph", "Ideographic"},
    40576: {"Unified_Ideograph", "Ideographic"},
    40577: {"Unified_Ideograph", "Ideographic"},
    40578: {"Unified_Ideograph", "Ideographic"},
    40579: {"Unified_Ideograph", "Ideographic"},
    40580: {"Unified_Ideograph", "Ideographic"},
    40581: {"Unified_Ideograph", "Ideographic"},
    40582: {"Unified_Ideograph", "Ideographic"},
    40583: {"Unified_Ideograph", "Ideographic"},
    40584: {"Unified_Ideograph", "Ideographic"},
    40585: {"Unified_Ideograph", "Ideographic"},
    40586: {"Unified_Ideograph", "Ideographic"},
    40587: {"Unified_Ideograph", "Ideographic"},
    40588: {"Unified_Ideograph", "Ideographic"},
    40589: {"Unified_Ideograph", "Ideographic"},
    40590: {"Unified_Ideograph", "Ideographic"},
    40591: {"Unified_Ideograph", "Ideographic"},
    40592: {"Unified_Ideograph", "Ideographic"},
    40593: {"Unified_Ideograph", "Ideographic"},
    40594: {"Unified_Ideograph", "Ideographic"},
    40595: {"Unified_Ideograph", "Ideographic"},
    40596: {"Unified_Ideograph", "Ideographic"},
    40597: {"Unified_Ideograph", "Ideographic"},
    40598: {"Unified_Ideograph", "Ideographic"},
    40599: {"Unified_Ideograph", "Ideographic"},
    40600: {"Unified_Ideograph", "Ideographic"},
    40601: {"Unified_Ideograph", "Ideographic"},
    40602: {"Unified_Ideograph", "Ideographic"},
    40603: {"Unified_Ideograph", "Ideographic"},
    40604: {"Unified_Ideograph", "Ideographic"},
    40605: {"Unified_Ideograph", "Ideographic"},
    40606: {"Unified_Ideograph", "Ideographic"},
    40607: {"Unified_Ideograph", "Ideographic"},
    40608: {"Unified_Ideograph", "Ideographic"},
    40609: {"Unified_Ideograph", "Ideographic"},
    40610: {"Unified_Ideograph", "Ideographic"},
    40611: {"Unified_Ideograph", "Ideographic"},
    40612: {"Unified_Ideograph", "Ideographic"},
    40613: {"Unified_Ideograph", "Ideographic"},
    40614: {"Unified_Ideograph", "Ideographic"},
    40615: {"Unified_Ideograph", "Ideographic"},
    40616: {"Unified_Ideograph", "Ideographic"},
    40617: {"Unified_Ideograph", "Ideographic"},
    40618: {"Unified_Ideograph", "Ideographic"},
    40619: {"Unified_Ideograph", "Ideographic"},
    40620: {"Unified_Ideograph", "Ideographic"},
    40621: {"Unified_Ideograph", "Ideographic"},
    40622: {"Unified_Ideograph", "Ideographic"},
    40623: {"Unified_Ideograph", "Ideographic"},
    40624: {"Unified_Ideograph", "Ideographic"},
    40625: {"Unified_Ideograph", "Ideographic"},
    40626: {"Unified_Ideograph", "Ideographic"},
    40627: {"Unified_Ideograph", "Ideographic"},
    40628: {"Unified_Ideograph", "Ideographic"},
    40629: {"Unified_Ideograph", "Ideographic"},
    40630: {"Unified_Ideograph", "Ideographic"},
    40631: {"Unified_Ideograph", "Ideographic"},
    40632: {"Unified_Ideograph", "Ideographic"},
    40633: {"Unified_Ideograph", "Ideographic"},
    40634: {"Unified_Ideograph", "Ideographic"},
    40635: {"Unified_Ideograph", "Ideographic"},
    40636: {"Unified_Ideograph", "Ideographic"},
    40637: {"Unified_Ideograph", "Ideographic"},
    40638: {"Unified_Ideograph", "Ideographic"},
    40639: {"Unified_Ideograph", "Ideographic"},
    40640: {"Unified_Ideograph", "Ideographic"},
    40641: {"Unified_Ideograph", "Ideographic"},
    40642: {"Unified_Ideograph", "Ideographic"},
    40643: {"Unified_Ideograph", "Ideographic"},
    40644: {"Unified_Ideograph", "Ideographic"},
    40645: {"Unified_Ideograph", "Ideographic"},
    40646: {"Unified_Ideograph", "Ideographic"},
    40647: {"Unified_Ideograph", "Ideographic"},
    40648: {"Unified_Ideograph", "Ideographic"},
    40649: {"Unified_Ideograph", "Ideographic"},
    40650: {"Unified_Ideograph", "Ideographic"},
    40651: {"Unified_Ideograph", "Ideographic"},
    40652: {"Unified_Ideograph", "Ideographic"},
    40653: {"Unified_Ideograph", "Ideographic"},
    40654: {"Unified_Ideograph", "Ideographic"},
    40655: {"Unified_Ideograph", "Ideographic"},
    40656: {"Unified_Ideograph", "Ideographic"},
    40657: {"Unified_Ideograph", "Ideographic"},
    40658: {"Unified_Ideograph", "Ideographic"},
    40659: {"Unified_Ideograph", "Ideographic"},
    40660: {"Unified_Ideograph", "Ideographic"},
    40661: {"Unified_Ideograph", "Ideographic"},
    40662: {"Unified_Ideograph", "Ideographic"},
    40663: {"Unified_Ideograph", "Ideographic"},
    40664: {"Unified_Ideograph", "Ideographic"},
    40665: {"Unified_Ideograph", "Ideographic"},
    40666: {"Unified_Ideograph", "Ideographic"},
    40667: {"Unified_Ideograph", "Ideographic"},
    40668: {"Unified_Ideograph", "Ideographic"},
    40669: {"Unified_Ideograph", "Ideographic"},
    40670: {"Unified_Ideograph", "Ideographic"},
    40671: {"Unified_Ideograph", "Ideographic"},
    40672: {"Unified_Ideograph", "Ideographic"},
    40673: {"Unified_Ideograph", "Ideographic"},
    40674: {"Unified_Ideograph", "Ideographic"},
    40675: {"Unified_Ideograph", "Ideographic"},
    40676: {"Unified_Ideograph", "Ideographic"},
    40677: {"Unified_Ideograph", "Ideographic"},
    40678: {"Unified_Ideograph", "Ideographic"},
    40679: {"Unified_Ideograph", "Ideographic"},
    40680: {"Unified_Ideograph", "Ideographic"},
    40681: {"Unified_Ideograph", "Ideographic"},
    40682: {"Unified_Ideograph", "Ideographic"},
    40683: {"Unified_Ideograph", "Ideographic"},
    40684: {"Unified_Ideograph", "Ideographic"},
    40685: {"Unified_Ideograph", "Ideographic"},
    40686: {"Unified_Ideograph", "Ideographic"},
    40687: {"Unified_Ideograph", "Ideographic"},
    40688: {"Unified_Ideograph", "Ideographic"},
    40689: {"Unified_Ideograph", "Ideographic"},
    40690: {"Unified_Ideograph", "Ideographic"},
    40691: {"Unified_Ideograph", "Ideographic"},
    40692: {"Unified_Ideograph", "Ideographic"},
    40693: {"Unified_Ideograph", "Ideographic"},
    40694: {"Unified_Ideograph", "Ideographic"},
    40695: {"Unified_Ideograph", "Ideographic"},
    40696: {"Unified_Ideograph", "Ideographic"},
    40697: {"Unified_Ideograph", "Ideographic"},
    40698: {"Unified_Ideograph", "Ideographic"},
    40699: {"Unified_Ideograph", "Ideographic"},
    40700: {"Unified_Ideograph", "Ideographic"},
    40701: {"Unified_Ideograph", "Ideographic"},
    40702: {"Unified_Ideograph", "Ideographic"},
    40703: {"Unified_Ideograph", "Ideographic"},
    40704: {"Unified_Ideograph", "Ideographic"},
    40705: {"Unified_Ideograph", "Ideographic"},
    40706: {"Unified_Ideograph", "Ideographic"},
    40707: {"Unified_Ideograph", "Ideographic"},
    40708: {"Unified_Ideograph", "Ideographic"},
    40709: {"Unified_Ideograph", "Ideographic"},
    40710: {"Unified_Ideograph", "Ideographic"},
    40711: {"Unified_Ideograph", "Ideographic"},
    40712: {"Unified_Ideograph", "Ideographic"},
    40713: {"Unified_Ideograph", "Ideographic"},
    40714: {"Unified_Ideograph", "Ideographic"},
    40715: {"Unified_Ideograph", "Ideographic"},
    40716: {"Unified_Ideograph", "Ideographic"},
    40717: {"Unified_Ideograph", "Ideographic"},
    40718: {"Unified_Ideograph", "Ideographic"},
    40719: {"Unified_Ideograph", "Ideographic"},
    40720: {"Unified_Ideograph", "Ideographic"},
    40721: {"Unified_Ideograph", "Ideographic"},
    40722: {"Unified_Ideograph", "Ideographic"},
    40723: {"Unified_Ideograph", "Ideographic"},
    40724: {"Unified_Ideograph", "Ideographic"},
    40725: {"Unified_Ideograph", "Ideographic"},
    40726: {"Unified_Ideograph", "Ideographic"},
    40727: {"Unified_Ideograph", "Ideographic"},
    40728: {"Unified_Ideograph", "Ideographic"},
    40729: {"Unified_Ideograph", "Ideographic"},
    40730: {"Unified_Ideograph", "Ideographic"},
    40731: {"Unified_Ideograph", "Ideographic"},
    40732: {"Unified_Ideograph", "Ideographic"},
    40733: {"Unified_Ideograph", "Ideographic"},
    40734: {"Unified_Ideograph", "Ideographic"},
    40735: {"Unified_Ideograph", "Ideographic"},
    40736: {"Unified_Ideograph", "Ideographic"},
    40737: {"Unified_Ideograph", "Ideographic"},
    40738: {"Unified_Ideograph", "Ideographic"},
    40739: {"Unified_Ideograph", "Ideographic"},
    40740: {"Unified_Ideograph", "Ideographic"},
    40741: {"Unified_Ideograph", "Ideographic"},
    40742: {"Unified_Ideograph", "Ideographic"},
    40743: {"Unified_Ideograph", "Ideographic"},
    40744: {"Unified_Ideograph", "Ideographic"},
    40745: {"Unified_Ideograph", "Ideographic"},
    40746: {"Unified_Ideograph", "Ideographic"},
    40747: {"Unified_Ideograph", "Ideographic"},
    40748: {"Unified_Ideograph", "Ideographic"},
    40749: {"Unified_Ideograph", "Ideographic"},
    40750: {"Unified_Ideograph", "Ideographic"},
    40751: {"Unified_Ideograph", "Ideographic"},
    40752: {"Unified_Ideograph", "Ideographic"},
    40753: {"Unified_Ideograph", "Ideographic"},
    40754: {"Unified_Ideograph", "Ideographic"},
    40755: {"Unified_Ideograph", "Ideographic"},
    40756: {"Unified_Ideograph", "Ideographic"},
    40757: {"Unified_Ideograph", "Ideographic"},
    40758: {"Unified_Ideograph", "Ideographic"},
    40759: {"Unified_Ideograph", "Ideographic"},
    40760: {"Unified_Ideograph", "Ideographic"},
    40761: {"Unified_Ideograph", "Ideographic"},
    40762: {"Unified_Ideograph", "Ideographic"},
    40763: {"Unified_Ideograph", "Ideographic"},
    40764: {"Unified_Ideograph", "Ideographic"},
    40765: {"Unified_Ideograph", "Ideographic"},
    40766: {"Unified_Ideograph", "Ideographic"},
    40767: {"Unified_Ideograph", "Ideographic"},
    40768: {"Unified_Ideograph", "Ideographic"},
    40769: {"Unified_Ideograph", "Ideographic"},
    40770: {"Unified_Ideograph", "Ideographic"},
    40771: {"Unified_Ideograph", "Ideographic"},
    40772: {"Unified_Ideograph", "Ideographic"},
    40773: {"Unified_Ideograph", "Ideographic"},
    40774: {"Unified_Ideograph", "Ideographic"},
    40775: {"Unified_Ideograph", "Ideographic"},
    40776: {"Unified_Ideograph", "Ideographic"},
    40777: {"Unified_Ideograph", "Ideographic"},
    40778: {"Unified_Ideograph", "Ideographic"},
    40779: {"Unified_Ideograph", "Ideographic"},
    40780: {"Unified_Ideograph", "Ideographic"},
    40781: {"Unified_Ideograph", "Ideographic"},
    40782: {"Unified_Ideograph", "Ideographic"},
    40783: {"Unified_Ideograph", "Ideographic"},
    40784: {"Unified_Ideograph", "Ideographic"},
    40785: {"Unified_Ideograph", "Ideographic"},
    40786: {"Unified_Ideograph", "Ideographic"},
    40787: {"Unified_Ideograph", "Ideographic"},
    40788: {"Unified_Ideograph", "Ideographic"},
    40789: {"Unified_Ideograph", "Ideographic"},
    40790: {"Unified_Ideograph", "Ideographic"},
    40791: {"Unified_Ideograph", "Ideographic"},
    40792: {"Unified_Ideograph", "Ideographic"},
    40793: {"Unified_Ideograph", "Ideographic"},
    40794: {"Unified_Ideograph", "Ideographic"},
    40795: {"Unified_Ideograph", "Ideographic"},
    40796: {"Unified_Ideograph", "Ideographic"},
    40797: {"Unified_Ideograph", "Ideographic"},
    40798: {"Unified_Ideograph", "Ideographic"},
    40799: {"Unified_Ideograph", "Ideographic"},
    40800: {"Unified_Ideograph", "Ideographic"},
    40801: {"Unified_Ideograph", "Ideographic"},
    40802: {"Unified_Ideograph", "Ideographic"},
    40803: {"Unified_Ideograph", "Ideographic"},
    40804: {"Unified_Ideograph", "Ideographic"},
    40805: {"Unified_Ideograph", "Ideographic"},
    40806: {"Unified_Ideograph", "Ideographic"},
    40807: {"Unified_Ideograph", "Ideographic"},
    40808: {"Unified_Ideograph", "Ideographic"},
    40809: {"Unified_Ideograph", "Ideographic"},
    40810: {"Unified_Ideograph", "Ideographic"},
    40811: {"Unified_Ideograph", "Ideographic"},
    40812: {"Unified_Ideograph", "Ideographic"},
    40813: {"Unified_Ideograph", "Ideographic"},
    40814: {"Unified_Ideograph", "Ideographic"},
    40815: {"Unified_Ideograph", "Ideographic"},
    40816: {"Unified_Ideograph", "Ideographic"},
    40817: {"Unified_Ideograph", "Ideographic"},
    40818: {"Unified_Ideograph", "Ideographic"},
    40819: {"Unified_Ideograph", "Ideographic"},
    40820: {"Unified_Ideograph", "Ideographic"},
    40821: {"Unified_Ideograph", "Ideographic"},
    40822: {"Unified_Ideograph", "Ideographic"},
    40823: {"Unified_Ideograph", "Ideographic"},
    40824: {"Unified_Ideograph", "Ideographic"},
    40825: {"Unified_Ideograph", "Ideographic"},
    40826: {"Unified_Ideograph", "Ideographic"},
    40827: {"Unified_Ideograph", "Ideographic"},
    40828: {"Unified_Ideograph", "Ideographic"},
    40829: {"Unified_Ideograph", "Ideographic"},
    40830: {"Unified_Ideograph", "Ideographic"},
    40831: {"Unified_Ideograph", "Ideographic"},
    40832: {"Unified_Ideograph", "Ideographic"},
    40833: {"Unified_Ideograph", "Ideographic"},
    40834: {"Unified_Ideograph", "Ideographic"},
    40835: {"Unified_Ideograph", "Ideographic"},
    40836: {"Unified_Ideograph", "Ideographic"},
    40837: {"Unified_Ideograph", "Ideographic"},
    40838: {"Unified_Ideograph", "Ideographic"},
    40839: {"Unified_Ideograph", "Ideographic"},
    40840: {"Unified_Ideograph", "Ideographic"},
    40841: {"Unified_Ideograph", "Ideographic"},
    40842: {"Unified_Ideograph", "Ideographic"},
    40843: {"Unified_Ideograph", "Ideographic"},
    40844: {"Unified_Ideograph", "Ideographic"},
    40845: {"Unified_Ideograph", "Ideographic"},
    40846: {"Unified_Ideograph", "Ideographic"},
    40847: {"Unified_Ideograph", "Ideographic"},
    40848: {"Unified_Ideograph", "Ideographic"},
    40849: {"Unified_Ideograph", "Ideographic"},
    40850: {"Unified_Ideograph", "Ideographic"},
    40851: {"Unified_Ideograph", "Ideographic"},
    40852: {"Unified_Ideograph", "Ideographic"},
    40853: {"Unified_Ideograph", "Ideographic"},
    40854: {"Unified_Ideograph", "Ideographic"},
    40855: {"Unified_Ideograph", "Ideographic"},
    40856: {"Unified_Ideograph", "Ideographic"},
    40857: {"Unified_Ideograph", "Ideographic"},
    40858: {"Unified_Ideograph", "Ideographic"},
    40859: {"Unified_Ideograph", "Ideographic"},
    40860: {"Unified_Ideograph", "Ideographic"},
    40861: {"Unified_Ideograph", "Ideographic"},
    40862: {"Unified_Ideograph", "Ideographic"},
    40863: {"Unified_Ideograph", "Ideographic"},
    40864: {"Unified_Ideograph", "Ideographic"},
    40865: {"Unified_Ideograph", "Ideographic"},
    40866: {"Unified_Ideograph", "Ideographic"},
    40867: {"Unified_Ideograph", "Ideographic"},
    40868: {"Unified_Ideograph", "Ideographic"},
    40869: {"Unified_Ideograph", "Ideographic"},
    40870: {"Unified_Ideograph", "Ideographic"},
    40871: {"Unified_Ideograph", "Ideographic"},
    40872: {"Unified_Ideograph", "Ideographic"},
    40873: {"Unified_Ideograph", "Ideographic"},
    40874: {"Unified_Ideograph", "Ideographic"},
    40875: {"Unified_Ideograph", "Ideographic"},
    40876: {"Unified_Ideograph", "Ideographic"},
    40877: {"Unified_Ideograph", "Ideographic"},
    40878: {"Unified_Ideograph", "Ideographic"},
    40879: {"Unified_Ideograph", "Ideographic"},
    40880: {"Unified_Ideograph", "Ideographic"},
    40881: {"Unified_Ideograph", "Ideographic"},
    40882: {"Unified_Ideograph", "Ideographic"},
    40883: {"Unified_Ideograph", "Ideographic"},
    40884: {"Unified_Ideograph", "Ideographic"},
    40885: {"Unified_Ideograph", "Ideographic"},
    40886: {"Unified_Ideograph", "Ideographic"},
    40887: {"Unified_Ideograph", "Ideographic"},
    40888: {"Unified_Ideograph", "Ideographic"},
    40889: {"Unified_Ideograph", "Ideographic"},
    40890: {"Unified_Ideograph", "Ideographic"},
    40891: {"Unified_Ideograph", "Ideographic"},
    40892: {"Unified_Ideograph", "Ideographic"},
    40893: {"Unified_Ideograph", "Ideographic"},
    40894: {"Unified_Ideograph", "Ideographic"},
    40895: {"Unified_Ideograph", "Ideographic"},
    40896: {"Unified_Ideograph", "Ideographic"},
    40897: {"Unified_Ideograph", "Ideographic"},
    40898: {"Unified_Ideograph", "Ideographic"},
    40899: {"Unified_Ideograph", "Ideographic"},
    40900: {"Unified_Ideograph", "Ideographic"},
    40901: {"Unified_Ideograph", "Ideographic"},
    40902: {"Unified_Ideograph", "Ideographic"},
    40903: {"Unified_Ideograph", "Ideographic"},
    40904: {"Unified_Ideograph", "Ideographic"},
    40905: {"Unified_Ideograph", "Ideographic"},
    40906: {"Unified_Ideograph", "Ideographic"},
    40907: {"Unified_Ideograph", "Ideographic"},
    40908: {"Unified_Ideograph", "Ideographic"},
    40909: {"Unified_Ideograph", "Ideographic"},
    40910: {"Unified_Ideograph", "Ideographic"},
    40911: {"Unified_Ideograph", "Ideographic"},
    40912: {"Unified_Ideograph", "Ideographic"},
    40913: {"Unified_Ideograph", "Ideographic"},
    40914: {"Unified_Ideograph", "Ideographic"},
    40915: {"Unified_Ideograph", "Ideographic"},
    40916: {"Unified_Ideograph", "Ideographic"},
    40917: {"Unified_Ideograph", "Ideographic"},
    40918: {"Unified_Ideograph", "Ideographic"},
    40919: {"Unified_Ideograph", "Ideographic"},
    40920: {"Unified_Ideograph", "Ideographic"},
    40921: {"Unified_Ideograph", "Ideographic"},
    40922: {"Unified_Ideograph", "Ideographic"},
    40923: {"Unified_Ideograph", "Ideographic"},
    40924: {"Unified_Ideograph", "Ideographic"},
    40925: {"Unified_Ideograph", "Ideographic"},
    40926: {"Unified_Ideograph", "Ideographic"},
    40927: {"Unified_Ideograph", "Ideographic"},
    40928: {"Unified_Ideograph", "Ideographic"},
    40929: {"Unified_Ideograph", "Ideographic"},
    40930: {"Unified_Ideograph", "Ideographic"},
    40931: {"Unified_Ideograph", "Ideographic"},
    40932: {"Unified_Ideograph", "Ideographic"},
    40933: {"Unified_Ideograph", "Ideographic"},
    40934: {"Unified_Ideograph", "Ideographic"},
    40935: {"Unified_Ideograph", "Ideographic"},
    40936: {"Unified_Ideograph", "Ideographic"},
    40937: {"Unified_Ideograph", "Ideographic"},
    40938: {"Unified_Ideograph", "Ideographic"},
    40939: {"Unified_Ideograph", "Ideographic"},
    40940: {"Unified_Ideograph", "Ideographic"},
    40941: {"Unified_Ideograph", "Ideographic"},
    40942: {"Unified_Ideograph", "Ideographic"},
    40943: {"Unified_Ideograph", "Ideographic"},
    40944: {"Unified_Ideograph", "Ideographic"},
    40945: {"Unified_Ideograph", "Ideographic"},
    40946: {"Unified_Ideograph", "Ideographic"},
    40947: {"Unified_Ideograph", "Ideographic"},
    40948: {"Unified_Ideograph", "Ideographic"},
    40949: {"Unified_Ideograph", "Ideographic"},
    40950: {"Unified_Ideograph", "Ideographic"},
    40951: {"Unified_Ideograph", "Ideographic"},
    40952: {"Unified_Ideograph", "Ideographic"},
    40953: {"Unified_Ideograph", "Ideographic"},
    40954: {"Unified_Ideograph", "Ideographic"},
    40955: {"Unified_Ideograph", "Ideographic"},
    40956: {"Unified_Ideograph", "Ideographic"},
    40981: {"Extender"},
    42238: {"Terminal_Punctuation"},
    42239: {"Terminal_Punctuation", "Sentence_Terminal"},
    42508: {"Extender"},
    42509: {"Terminal_Punctuation"},
    42510: {"Terminal_Punctuation", "Sentence_Terminal"},
    42511: {"Terminal_Punctuation", "Sentence_Terminal"},
    42607: {"Diacritic"},
    42612: {"Other_Alphabetic"},
    42613: {"Other_Alphabetic"},
    42614: {"Other_Alphabetic"},
    42615: {"Other_Alphabetic"},
    42616: {"Other_Alphabetic"},
    42617: {"Other_Alphabetic"},
    42618: {"Other_Alphabetic"},
    42619: {"Other_Alphabetic"},
    42620: {"Diacritic"},
    42621: {"Diacritic"},
    42623: {"Diacritic"},
    42652: {"Other_Lowercase", "Diacritic"},
    42653: {"Other_Lowercase", "Diacritic"},
    42654: {"Other_Alphabetic"},
    42655: {"Other_Alphabetic"},
    42736: {"Diacritic"},
    42737: {"Diacritic"},
    42739: {"Terminal_Punctuation", "Sentence_Terminal"},
    42740: {"Terminal_Punctuation"},
    42741: {"Terminal_Punctuation"},
    42742: {"Terminal_Punctuation"},
    42743: {"Terminal_Punctuation", "Sentence_Terminal"},
    42752: {"Diacritic"},
    42753: {"Diacritic"},
    42754: {"Diacritic"},
    42755: {"Diacritic"},
    42756: {"Diacritic"},
    42757: {"Diacritic"},
    42758: {"Diacritic"},
    42759: {"Diacritic"},
    42760: {"Diacritic"},
    42761: {"Diacritic"},
    42762: {"Diacritic"},
    42763: {"Diacritic"},
    42764: {"Diacritic"},
    42765: {"Diacritic"},
    42766: {"Diacritic"},
    42767: {"Diacritic"},
    42768: {"Diacritic"},
    42769: {"Diacritic"},
    42770: {"Diacritic"},
    42771: {"Diacritic"},
    42772: {"Diacritic"},
    42773: {"Diacritic"},
    42774: {"Diacritic"},
    42775: {"Diacritic"},
    42776: {"Diacritic"},
    42777: {"Diacritic"},
    42778: {"Diacritic"},
    42779: {"Diacritic"},
    42780: {"Diacritic"},
    42781: {"Diacritic"},
    42782: {"Diacritic"},
    42783: {"Diacritic"},
    42784: {"Diacritic"},
    42785: {"Diacritic"},
    42864: {"Other_Lowercase"},
    42888: {"Diacritic"},
    42889: {"Diacritic"},
    42890: {"Diacritic"},
    43000: {"Other_Lowercase", "Diacritic"},
    43001: {"Other_Lowercase", "Diacritic"},
    43010: {"Other_Alphabetic"},
    43019: {"Other_Alphabetic"},
    43043: {"Other_Alphabetic"},
    43044: {"Other_Alphabetic"},
    43045: {"Other_Alphabetic"},
    43046: {"Other_Alphabetic"},
    43047: {"Other_Alphabetic"},
    43126: {"Terminal_Punctuation", "Sentence_Terminal"},
    43127: {"Terminal_Punctuation", "Sentence_Terminal"},
    43136: {"Other_Alphabetic"},
    43137: {"Other_Alphabetic"},
    43188: {"Other_Alphabetic"},
    43189: {"Other_Alphabetic"},
    43190: {"Other_Alphabetic"},
    43191: {"Other_Alphabetic"},
    43192: {"Other_Alphabetic"},
    43193: {"Other_Alphabetic"},
    43194: {"Other_Alphabetic"},
    43195: {"Other_Alphabetic"},
    43196: {"Other_Alphabetic"},
    43197: {"Other_Alphabetic"},
    43198: {"Other_Alphabetic"},
    43199: {"Other_Alphabetic"},
    43200: {"Other_Alphabetic"},
    43201: {"Other_Alphabetic"},
    43202: {"Other_Alphabetic"},
    43203: {"Other_Alphabetic"},
    43204: {"Diacritic"},
    43205: {"Other_Alphabetic"},
    43214: {"Terminal_Punctuation", "Sentence_Terminal"},
    43215: {"Terminal_Punctuation", "Sentence_Terminal"},
    43232: {"Diacritic"},
    43233: {"Diacritic"},
    43234: {"Diacritic"},
    43235: {"Diacritic"},
    43236: {"Diacritic"},
    43237: {"Diacritic"},
    43238: {"Diacritic"},
    43239: {"Diacritic"},
    43240: {"Diacritic"},
    43241: {"Diacritic"},
    43242: {"Diacritic"},
    43243: {"Diacritic"},
    43244: {"Diacritic"},
    43245: {"Diacritic"},
    43246: {"Diacritic"},
    43247: {"Diacritic"},
    43248: {"Diacritic"},
    43249: {"Diacritic"},
    43263: {"Other_Alphabetic"},
    43302: {"Other_Alphabetic"},
    43303: {"Other_Alphabetic"},
    43304: {"Other_Alphabetic"},
    43305: {"Other_Alphabetic"},
    43306: {"Other_Alphabetic"},
    43307: {"Diacritic"},
    43308: {"Diacritic"},
    43309: {"Diacritic"},
    43310: {"Diacritic"},
    43311: {"Terminal_Punctuation", "Sentence_Terminal"},
    43335: {"Other_Alphabetic"},
    43336: {"Other_Alphabetic"},
    43337: {"Other_Alphabetic"},
    43338: {"Other_Alphabetic"},
    43339: {"Other_Alphabetic"},
    43340: {"Other_Alphabetic"},
    43341: {"Other_Alphabetic"},
    43342: {"Other_Alphabetic"},
    43343: {"Other_Alphabetic"},
    43344: {"Other_Alphabetic"},
    43345: {"Other_Alphabetic"},
    43346: {"Other_Alphabetic"},
    43347: {"Diacritic"},
    43392: {"Other_Alphabetic"},
    43393: {"Other_Alphabetic"},
    43394: {"Other_Alphabetic"},
    43395: {"Other_Alphabetic"},
    43443: {"Diacritic"},
    43444: {"Other_Alphabetic"},
    43445: {"Other_Alphabetic"},
    43446: {"Other_Alphabetic"},
    43447: {"Other_Alphabetic"},
    43448: {"Other_Alphabetic"},
    43449: {"Other_Alphabetic"},
    43450: {"Other_Alphabetic"},
    43451: {"Other_Alphabetic"},
    43452: {"Other_Alphabetic"},
    43453: {"Other_Alphabetic"},
    43454: {"Other_Alphabetic"},
    43455: {"Other_Alphabetic"},
    43456: {"Diacritic"},
    43463: {"Terminal_Punctuation"},
    43464: {"Terminal_Punctuation", "Sentence_Terminal"},
    43465: {"Terminal_Punctuation", "Sentence_Terminal"},
    43471: {"Extender"},
    43493: {"Diacritic", "Other_Alphabetic"},
    43494: {"Extender"},
    43561: {"Other_Alphabetic"},
    43562: {"Other_Alphabetic"},
    43563: {"Other_Alphabetic"},
    43564: {"Other_Alphabetic"},
    43565: {"Other_Alphabetic"},
    43566: {"Other_Alphabetic"},
    43567: {"Other_Alphabetic"},
    43568: {"Other_Alphabetic"},
    43569: {"Other_Alphabetic"},
    43570: {"Other_Alphabetic"},
    43571: {"Other_Alphabetic"},
    43572: {"Other_Alphabetic"},
    43573: {"Other_Alphabetic"},
    43574: {"Other_Alphabetic"},
    43587: {"Other_Alphabetic"},
    43596: {"Other_Alphabetic"},
    43597: {"Other_Alphabetic"},
    43613: {"Terminal_Punctuation", "Sentence_Terminal"},
    43614: {"Terminal_Punctuation", "Sentence_Terminal"},
    43615: {"Terminal_Punctuation", "Sentence_Terminal"},
    43632: {"Extender"},
    43643: {"Diacritic", "Other_Alphabetic"},
    43644: {"Diacritic", "Other_Alphabetic"},
    43645: {"Diacritic", "Other_Alphabetic"},
    43696: {"Other_Alphabetic"},
    43698: {"Other_Alphabetic"},
    43699: {"Other_Alphabetic"},
    43700: {"Other_Alphabetic"},
    43701: {"Logical_Order_Exception"},
    43702: {"Logical_Order_Exception"},
    43703: {"Other_Alphabetic"},
    43704: {"Other_Alphabetic"},
    43705: {"Logical_Order_Exception"},
    43707: {"Logical_Order_Exception"},
    43708: {"Logical_Order_Exception"},
    43710: {"Other_Alphabetic"},
    43711: {"Diacritic"},
    43712: {"Diacritic"},
    43713: {"Diacritic"},
    43714: {"Diacritic"},
    43741: {"Extender"},
    43743: {"Terminal_Punctuation"},
    43755: {"Other_Alphabetic"},
    43756: {"Other_Alphabetic"},
    43757: {"Other_Alphabetic"},
    43758: {"Other_Alphabetic"},
    43759: {"Other_Alphabetic"},
    43760: {"Terminal_Punctuation", "Sentence_Terminal"},
    43761: {"Terminal_Punctuation", "Sentence_Terminal"},
    43763: {"Extender"},
    43764: {"Extender"},
    43765: {"Other_Alphabetic"},
    43766: {"Diacritic"},
    43867: {"Diacritic"},
    43868: {"Other_Lowercase", "Diacritic"},
    43869: {"Other_Lowercase", "Diacritic"},
    43870: {"Other_Lowercase", "Diacritic"},
    43871: {"Other_Lowercase", "Diacritic"},
    43881: {"Diacritic"},
    43882: {"Diacritic"},
    43883: {"Diacritic"},
    44003: {"Other_Alphabetic"},
    44004: {"Other_Alphabetic"},
    44005: {"Other_Alphabetic"},
    44006: {"Other_Alphabetic"},
    44007: {"Other_Alphabetic"},
    44008: {"Other_Alphabetic"},
    44009: {"Other_Alphabetic"},
    44010: {"Other_Alphabetic"},
    44011: {"Terminal_Punctuation", "Sentence_Terminal"},
    44012: {"Diacritic"},
    44013: {"Diacritic"},
    63744: {"Ideographic"},
    63745: {"Ideographic"},
    63746: {"Ideographic"},
    63747: {"Ideographic"},
    63748: {"Ideographic"},
    63749: {"Ideographic"},
    63750: {"Ideographic"},
    63751: {"Ideographic"},
    63752: {"Ideographic"},
    63753: {"Ideographic"},
    63754: {"Ideographic"},
    63755: {"Ideographic"},
    63756: {"Ideographic"},
    63757: {"Ideographic"},
    63758: {"Ideographic"},
    63759: {"Ideographic"},
    63760: {"Ideographic"},
    63761: {"Ideographic"},
    63762: {"Ideographic"},
    63763: {"Ideographic"},
    63764: {"Ideographic"},
    63765: {"Ideographic"},
    63766: {"Ideographic"},
    63767: {"Ideographic"},
    63768: {"Ideographic"},
    63769: {"Ideographic"},
    63770: {"Ideographic"},
    63771: {"Ideographic"},
    63772: {"Ideographic"},
    63773: {"Ideographic"},
    63774: {"Ideographic"},
    63775: {"Ideographic"},
    63776: {"Ideographic"},
    63777: {"Ideographic"},
    63778: {"Ideographic"},
    63779: {"Ideographic"},
    63780: {"Ideographic"},
    63781: {"Ideographic"},
    63782: {"Ideographic"},
    63783: {"Ideographic"},
    63784: {"Ideographic"},
    63785: {"Ideographic"},
    63786: {"Ideographic"},
    63787: {"Ideographic"},
    63788: {"Ideographic"},
    63789: {"Ideographic"},
    63790: {"Ideographic"},
    63791: {"Ideographic"},
    63792: {"Ideographic"},
    63793: {"Ideographic"},
    63794: {"Ideographic"},
    63795: {"Ideographic"},
    63796: {"Ideographic"},
    63797: {"Ideographic"},
    63798: {"Ideographic"},
    63799: {"Ideographic"},
    63800: {"Ideographic"},
    63801: {"Ideographic"},
    63802: {"Ideographic"},
    63803: {"Ideographic"},
    63804: {"Ideographic"},
    63805: {"Ideographic"},
    63806: {"Ideographic"},
    63807: {"Ideographic"},
    63808: {"Ideographic"},
    63809: {"Ideographic"},
    63810: {"Ideographic"},
    63811: {"Ideographic"},
    63812: {"Ideographic"},
    63813: {"Ideographic"},
    63814: {"Ideographic"},
    63815: {"Ideographic"},
    63816: {"Ideographic"},
    63817: {"Ideographic"},
    63818: {"Ideographic"},
    63819: {"Ideographic"},
    63820: {"Ideographic"},
    63821: {"Ideographic"},
    63822: {"Ideographic"},
    63823: {"Ideographic"},
    63824: {"Ideographic"},
    63825: {"Ideographic"},
    63826: {"Ideographic"},
    63827: {"Ideographic"},
    63828: {"Ideographic"},
    63829: {"Ideographic"},
    63830: {"Ideographic"},
    63831: {"Ideographic"},
    63832: {"Ideographic"},
    63833: {"Ideographic"},
    63834: {"Ideographic"},
    63835: {"Ideographic"},
    63836: {"Ideographic"},
    63837: {"Ideographic"},
    63838: {"Ideographic"},
    63839: {"Ideographic"},
    63840: {"Ideographic"},
    63841: {"Ideographic"},
    63842: {"Ideographic"},
    63843: {"Ideographic"},
    63844: {"Ideographic"},
    63845: {"Ideographic"},
    63846: {"Ideographic"},
    63847: {"Ideographic"},
    63848: {"Ideographic"},
    63849: {"Ideographic"},
    63850: {"Ideographic"},
    63851: {"Ideographic"},
    63852: {"Ideographic"},
    63853: {"Ideographic"},
    63854: {"Ideographic"},
    63855: {"Ideographic"},
    63856: {"Ideographic"},
    63857: {"Ideographic"},
    63858: {"Ideographic"},
    63859: {"Ideographic"},
    63860: {"Ideographic"},
    63861: {"Ideographic"},
    63862: {"Ideographic"},
    63863: {"Ideographic"},
    63864: {"Ideographic"},
    63865: {"Ideographic"},
    63866: {"Ideographic"},
    63867: {"Ideographic"},
    63868: {"Ideographic"},
    63869: {"Ideographic"},
    63870: {"Ideographic"},
    63871: {"Ideographic"},
    63872: {"Ideographic"},
    63873: {"Ideographic"},
    63874: {"Ideographic"},
    63875: {"Ideographic"},
    63876: {"Ideographic"},
    63877: {"Ideographic"},
    63878: {"Ideographic"},
    63879: {"Ideographic"},
    63880: {"Ideographic"},
    63881: {"Ideographic"},
    63882: {"Ideographic"},
    63883: {"Ideographic"},
    63884: {"Ideographic"},
    63885: {"Ideographic"},
    63886: {"Ideographic"},
    63887: {"Ideographic"},
    63888: {"Ideographic"},
    63889: {"Ideographic"},
    63890: {"Ideographic"},
    63891: {"Ideographic"},
    63892: {"Ideographic"},
    63893: {"Ideographic"},
    63894: {"Ideographic"},
    63895: {"Ideographic"},
    63896: {"Ideographic"},
    63897: {"Ideographic"},
    63898: {"Ideographic"},
    63899: {"Ideographic"},
    63900: {"Ideographic"},
    63901: {"Ideographic"},
    63902: {"Ideographic"},
    63903: {"Ideographic"},
    63904: {"Ideographic"},
    63905: {"Ideographic"},
    63906: {"Ideographic"},
    63907: {"Ideographic"},
    63908: {"Ideographic"},
    63909: {"Ideographic"},
    63910: {"Ideographic"},
    63911: {"Ideographic"},
    63912: {"Ideographic"},
    63913: {"Ideographic"},
    63914: {"Ideographic"},
    63915: {"Ideographic"},
    63916: {"Ideographic"},
    63917: {"Ideographic"},
    63918: {"Ideographic"},
    63919: {"Ideographic"},
    63920: {"Ideographic"},
    63921: {"Ideographic"},
    63922: {"Ideographic"},
    63923: {"Ideographic"},
    63924: {"Ideographic"},
    63925: {"Ideographic"},
    63926: {"Ideographic"},
    63927: {"Ideographic"},
    63928: {"Ideographic"},
    63929: {"Ideographic"},
    63930: {"Ideographic"},
    63931: {"Ideographic"},
    63932: {"Ideographic"},
    63933: {"Ideographic"},
    63934: {"Ideographic"},
    63935: {"Ideographic"},
    63936: {"Ideographic"},
    63937: {"Ideographic"},
    63938: {"Ideographic"},
    63939: {"Ideographic"},
    63940: {"Ideographic"},
    63941: {"Ideographic"},
    63942: {"Ideographic"},
    63943: {"Ideographic"},
    63944: {"Ideographic"},
    63945: {"Ideographic"},
    63946: {"Ideographic"},
    63947: {"Ideographic"},
    63948: {"Ideographic"},
    63949: {"Ideographic"},
    63950: {"Ideographic"},
    63951: {"Ideographic"},
    63952: {"Ideographic"},
    63953: {"Ideographic"},
    63954: {"Ideographic"},
    63955: {"Ideographic"},
    63956: {"Ideographic"},
    63957: {"Ideographic"},
    63958: {"Ideographic"},
    63959: {"Ideographic"},
    63960: {"Ideographic"},
    63961: {"Ideographic"},
    63962: {"Ideographic"},
    63963: {"Ideographic"},
    63964: {"Ideographic"},
    63965: {"Ideographic"},
    63966: {"Ideographic"},
    63967: {"Ideographic"},
    63968: {"Ideographic"},
    63969: {"Ideographic"},
    63970: {"Ideographic"},
    63971: {"Ideographic"},
    63972: {"Ideographic"},
    63973: {"Ideographic"},
    63974: {"Ideographic"},
    63975: {"Ideographic"},
    63976: {"Ideographic"},
    63977: {"Ideographic"},
    63978: {"Ideographic"},
    63979: {"Ideographic"},
    63980: {"Ideographic"},
    63981: {"Ideographic"},
    63982: {"Ideographic"},
    63983: {"Ideographic"},
    63984: {"Ideographic"},
    63985: {"Ideographic"},
    63986: {"Ideographic"},
    63987: {"Ideographic"},
    63988: {"Ideographic"},
    63989: {"Ideographic"},
    63990: {"Ideographic"},
    63991: {"Ideographic"},
    63992: {"Ideographic"},
    63993: {"Ideographic"},
    63994: {"Ideographic"},
    63995: {"Ideographic"},
    63996: {"Ideographic"},
    63997: {"Ideographic"},
    63998: {"Ideographic"},
    63999: {"Ideographic"},
    64000: {"Ideographic"},
    64001: {"Ideographic"},
    64002: {"Ideographic"},
    64003: {"Ideographic"},
    64004: {"Ideographic"},
    64005: {"Ideographic"},
    64006: {"Ideographic"},
    64007: {"Ideographic"},
    64008: {"Ideographic"},
    64009: {"Ideographic"},
    64010: {"Ideographic"},
    64011: {"Ideographic"},
    64012: {"Ideographic"},
    64013: {"Ideographic"},
    64014: {"Unified_Ideograph", "Ideographic"},
    64015: {"Unified_Ideograph", "Ideographic"},
    64016: {"Ideographic"},
    64017: {"Unified_Ideograph", "Ideographic"},
    64018: {"Ideographic"},
    64019: {"Unified_Ideograph", "Ideographic"},
    64020: {"Unified_Ideograph", "Ideographic"},
    64021: {"Ideographic"},
    64022: {"Ideographic"},
    64023: {"Ideographic"},
    64024: {"Ideographic"},
    64025: {"Ideographic"},
    64026: {"Ideographic"},
    64027: {"Ideographic"},
    64028: {"Ideographic"},
    64029: {"Ideographic"},
    64030: {"Ideographic"},
    64031: {"Unified_Ideograph", "Ideographic"},
    64032: {"Ideographic"},
    64033: {"Unified_Ideograph", "Ideographic"},
    64034: {"Ideographic"},
    64035: {"Unified_Ideograph", "Ideographic"},
    64036: {"Unified_Ideograph", "Ideographic"},
    64037: {"Ideographic"},
    64038: {"Ideographic"},
    64039: {"Unified_Ideograph", "Ideographic"},
    64040: {"Unified_Ideograph", "Ideographic"},
    64041: {"Unified_Ideograph", "Ideographic"},
    64042: {"Ideographic"},
    64043: {"Ideographic"},
    64044: {"Ideographic"},
    64045: {"Ideographic"},
    64046: {"Ideographic"},
    64047: {"Ideographic"},
    64048: {"Ideographic"},
    64049: {"Ideographic"},
    64050: {"Ideographic"},
    64051: {"Ideographic"},
    64052: {"Ideographic"},
    64053: {"Ideographic"},
    64054: {"Ideographic"},
    64055: {"Ideographic"},
    64056: {"Ideographic"},
    64057: {"Ideographic"},
    64058: {"Ideographic"},
    64059: {"Ideographic"},
    64060: {"Ideographic"},
    64061: {"Ideographic"},
    64062: {"Ideographic"},
    64063: {"Ideographic"},
    64064: {"Ideographic"},
    64065: {"Ideographic"},
    64066: {"Ideographic"},
    64067: {"Ideographic"},
    64068: {"Ideographic"},
    64069: {"Ideographic"},
    64070: {"Ideographic"},
    64071: {"Ideographic"},
    64072: {"Ideographic"},
    64073: {"Ideographic"},
    64074: {"Ideographic"},
    64075: {"Ideographic"},
    64076: {"Ideographic"},
    64077: {"Ideographic"},
    64078: {"Ideographic"},
    64079: {"Ideographic"},
    64080: {"Ideographic"},
    64081: {"Ideographic"},
    64082: {"Ideographic"},
    64083: {"Ideographic"},
    64084: {"Ideographic"},
    64085: {"Ideographic"},
    64086: {"Ideographic"},
    64087: {"Ideographic"},
    64088: {"Ideographic"},
    64089: {"Ideographic"},
    64090: {"Ideographic"},
    64091: {"Ideographic"},
    64092: {"Ideographic"},
    64093: {"Ideographic"},
    64094: {"Ideographic"},
    64095: {"Ideographic"},
    64096: {"Ideographic"},
    64097: {"Ideographic"},
    64098: {"Ideographic"},
    64099: {"Ideographic"},
    64100: {"Ideographic"},
    64101: {"Ideographic"},
    64102: {"Ideographic"},
    64103: {"Ideographic"},
    64104: {"Ideographic"},
    64105: {"Ideographic"},
    64106: {"Ideographic"},
    64107: {"Ideographic"},
    64108: {"Ideographic"},
    64109: {"Ideographic"},
    64112: {"Ideographic"},
    64113: {"Ideographic"},
    64114: {"Ideographic"},
    64115: {"Ideographic"},
    64116: {"Ideographic"},
    64117: {"Ideographic"},
    64118: {"Ideographic"},
    64119: {"Ideographic"},
    64120: {"Ideographic"},
    64121: {"Ideographic"},
    64122: {"Ideographic"},
    64123: {"Ideographic"},
    64124: {"Ideographic"},
    64125: {"Ideographic"},
    64126: {"Ideographic"},
    64127: {"Ideographic"},
    64128: {"Ideographic"},
    64129: {"Ideographic"},
    64130: {"Ideographic"},
    64131: {"Ideographic"},
    64132: {"Ideographic"},
    64133: {"Ideographic"},
    64134: {"Ideographic"},
    64135: {"Ideographic"},
    64136: {"Ideographic"},
    64137: {"Ideographic"},
    64138: {"Ideographic"},
    64139: {"Ideographic"},
    64140: {"Ideographic"},
    64141: {"Ideographic"},
    64142: {"Ideographic"},
    64143: {"Ideographic"},
    64144: {"Ideographic"},
    64145: {"Ideographic"},
    64146: {"Ideographic"},
    64147: {"Ideographic"},
    64148: {"Ideographic"},
    64149: {"Ideographic"},
    64150: {"Ideographic"},
    64151: {"Ideographic"},
    64152: {"Ideographic"},
    64153: {"Ideographic"},
    64154: {"Ideographic"},
    64155: {"Ideographic"},
    64156: {"Ideographic"},
    64157: {"Ideographic"},
    64158: {"Ideographic"},
    64159: {"Ideographic"},
    64160: {"Ideographic"},
    64161: {"Ideographic"},
    64162: {"Ideographic"},
    64163: {"Ideographic"},
    64164: {"Ideographic"},
    64165: {"Ideographic"},
    64166: {"Ideographic"},
    64167: {"Ideographic"},
    64168: {"Ideographic"},
    64169: {"Ideographic"},
    64170: {"Ideographic"},
    64171: {"Ideographic"},
    64172: {"Ideographic"},
    64173: {"Ideographic"},
    64174: {"Ideographic"},
    64175: {"Ideographic"},
    64176: {"Ideographic"},
    64177: {"Ideographic"},
    64178: {"Ideographic"},
    64179: {"Ideographic"},
    64180: {"Ideographic"},
    64181: {"Ideographic"},
    64182: {"Ideographic"},
    64183: {"Ideographic"},
    64184: {"Ideographic"},
    64185: {"Ideographic"},
    64186: {"Ideographic"},
    64187: {"Ideographic"},
    64188: {"Ideographic"},
    64189: {"Ideographic"},
    64190: {"Ideographic"},
    64191: {"Ideographic"},
    64192: {"Ideographic"},
    64193: {"Ideographic"},
    64194: {"Ideographic"},
    64195: {"Ideographic"},
    64196: {"Ideographic"},
    64197: {"Ideographic"},
    64198: {"Ideographic"},
    64199: {"Ideographic"},
    64200: {"Ideographic"},
    64201: {"Ideographic"},
    64202: {"Ideographic"},
    64203: {"Ideographic"},
    64204: {"Ideographic"},
    64205: {"Ideographic"},
    64206: {"Ideographic"},
    64207: {"Ideographic"},
    64208: {"Ideographic"},
    64209: {"Ideographic"},
    64210: {"Ideographic"},
    64211: {"Ideographic"},
    64212: {"Ideographic"},
    64213: {"Ideographic"},
    64214: {"Ideographic"},
    64215: {"Ideographic"},
    64216: {"Ideographic"},
    64217: {"Ideographic"},
    64286: {"Diacritic", "Other_Alphabetic"},
    64830: {"Pattern_Syntax"},
    64831: {"Pattern_Syntax"},
    64976: {"Noncharacter_Code_Point"},
    64977: {"Noncharacter_Code_Point"},
    64978: {"Noncharacter_Code_Point"},
    64979: {"Noncharacter_Code_Point"},
    64980: {"Noncharacter_Code_Point"},
    64981: {"Noncharacter_Code_Point"},
    64982: {"Noncharacter_Code_Point"},
    64983: {"Noncharacter_Code_Point"},
    64984: {"Noncharacter_Code_Point"},
    64985: {"Noncharacter_Code_Point"},
    64986: {"Noncharacter_Code_Point"},
    64987: {"Noncharacter_Code_Point"},
    64988: {"Noncharacter_Code_Point"},
    64989: {"Noncharacter_Code_Point"},
    64990: {"Noncharacter_Code_Point"},
    64991: {"Noncharacter_Code_Point"},
    64992: {"Noncharacter_Code_Point"},
    64993: {"Noncharacter_Code_Point"},
    64994: {"Noncharacter_Code_Point"},
    64995: {"Noncharacter_Code_Point"},
    64996: {"Noncharacter_Code_Point"},
    64997: {"Noncharacter_Code_Point"},
    64998: {"Noncharacter_Code_Point"},
    64999: {"Noncharacter_Code_Point"},
    65000: {"Noncharacter_Code_Point"},
    65001: {"Noncharacter_Code_Point"},
    65002: {"Noncharacter_Code_Point"},
    65003: {"Noncharacter_Code_Point"},
    65004: {"Noncharacter_Code_Point"},
    65005: {"Noncharacter_Code_Point"},
    65006: {"Noncharacter_Code_Point"},
    65007: {"Noncharacter_Code_Point"},
    65024: {"Variation_Selector"},
    65025: {"Variation_Selector"},
    65026: {"Variation_Selector"},
    65027: {"Variation_Selector"},
    65028: {"Variation_Selector"},
    65029: {"Variation_Selector"},
    65030: {"Variation_Selector"},
    65031: {"Variation_Selector"},
    65032: {"Variation_Selector"},
    65033: {"Variation_Selector"},
    65034: {"Variation_Selector"},
    65035: {"Variation_Selector"},
    65036: {"Variation_Selector"},
    65037: {"Variation_Selector"},
    65038: {"Variation_Selector"},
    65039: {"Variation_Selector"},
    65056: {"Diacritic"},
    65057: {"Diacritic"},
    65058: {"Diacritic"},
    65059: {"Diacritic"},
    65060: {"Diacritic"},
    65061: {"Diacritic"},
    65062: {"Diacritic"},
    65063: {"Diacritic"},
    65064: {"Diacritic"},
    65065: {"Diacritic"},
    65066: {"Diacritic"},
    65067: {"Diacritic"},
    65068: {"Diacritic"},
    65069: {"Diacritic"},
    65070: {"Diacritic"},
    65071: {"Diacritic"},
    65073: {"Dash"},
    65074: {"Dash"},
    65089: {"Quotation_Mark"},
    65090: {"Quotation_Mark"},
    65091: {"Quotation_Mark"},
    65092: {"Quotation_Mark"},
    65093: {"Pattern_Syntax"},
    65094: {"Pattern_Syntax"},
    65104: {"Terminal_Punctuation"},
    65105: {"Terminal_Punctuation"},
    65106: {"Terminal_Punctuation", "Sentence_Terminal"},
    65108: {"Terminal_Punctuation"},
    65109: {"Terminal_Punctuation"},
    65110: {"Terminal_Punctuation", "Sentence_Terminal"},
    65111: {"Terminal_Punctuation", "Sentence_Terminal"},
    65112: {"Dash"},
    65121: {"Other_Math"},
    65123: {"Dash", "Other_Math", "Hyphen"},
    65128: {"Other_Math"},
    65281: {"Terminal_Punctuation", "Sentence_Terminal"},
    65282: {"Quotation_Mark"},
    65287: {"Quotation_Mark"},
    65292: {"Terminal_Punctuation"},
    65293: {"Dash", "Hyphen"},
    65294: {"Terminal_Punctuation", "Sentence_Terminal"},
    65296: {"Hex_Digit"},
    65297: {"Hex_Digit"},
    65298: {"Hex_Digit"},
    65299: {"Hex_Digit"},
    65300: {"Hex_Digit"},
    65301: {"Hex_Digit"},
    65302: {"Hex_Digit"},
    65303: {"Hex_Digit"},
    65304: {"Hex_Digit"},
    65305: {"Hex_Digit"},
    65306: {"Terminal_Punctuation"},
    65307: {"Terminal_Punctuation"},
    65311: {"Terminal_Punctuation", "Sentence_Terminal"},
    65313: {"Hex_Digit"},
    65314: {"Hex_Digit"},
    65315: {"Hex_Digit"},
    65316: {"Hex_Digit"},
    65317: {"Hex_Digit"},
    65318: {"Hex_Digit"},
    65340: {"Other_Math"},
    65342: {"Diacritic", "Other_Math"},
    65344: {"Diacritic"},
    65345: {"Hex_Digit"},
    65346: {"Hex_Digit"},
    65347: {"Hex_Digit"},
    65348: {"Hex_Digit"},
    65349: {"Hex_Digit"},
    65350: {"Hex_Digit"},
    65377: {"Terminal_Punctuation", "Sentence_Terminal"},
    65378: {"Quotation_Mark"},
    65379: {"Quotation_Mark"},
    65380: {"Terminal_Punctuation"},
    65381: {"Hyphen"},
    65392: {"Diacritic", "Extender"},
    65438: {"Diacritic", "Other_Grapheme_Extend"},
    65439: {"Diacritic", "Other_Grapheme_Extend"},
    65440: {"Other_Default_Ignorable_Code_Point"},
    65507: {"Diacritic"},
    65520: {"Other_Default_Ignorable_Code_Point"},
    65521: {"Other_Default_Ignorable_Code_Point"},
    65522: {"Other_Default_Ignorable_Code_Point"},
    65523: {"Other_Default_Ignorable_Code_Point"},
    65524: {"Other_Default_Ignorable_Code_Point"},
    65525: {"Other_Default_Ignorable_Code_Point"},
    65526: {"Other_Default_Ignorable_Code_Point"},
    65527: {"Other_Default_Ignorable_Code_Point"},
    65528: {"Other_Default_Ignorable_Code_Point"},
    65534: {"Noncharacter_Code_Point"},
    65535: {"Noncharacter_Code_Point"},
    66272: {"Diacritic"},
    66422: {"Other_Alphabetic"},
    66423: {"Other_Alphabetic"},
    66424: {"Other_Alphabetic"},
    66425: {"Other_Alphabetic"},
    66426: {"Other_Alphabetic"},
    66463: {"Terminal_Punctuation"},
    66512: {"Terminal_Punctuation"},
    67671: {"Terminal_Punctuation"},
    67871: {"Terminal_Punctuation"},
    68097: {"Other_Alphabetic"},
    68098: {"Other_Alphabetic"},
    68099: {"Other_Alphabetic"},
    68101: {"Other_Alphabetic"},
    68102: {"Other_Alphabetic"},
    68108: {"Other_Alphabetic"},
    68109: {"Other_Alphabetic"},
    68110: {"Other_Alphabetic"},
    68111: {"Other_Alphabetic"},
    68182: {"Terminal_Punctuation", "Sentence_Terminal"},
    68183: {"Terminal_Punctuation", "Sentence_Terminal"},
    68325: {"Diacritic"},
    68326: {"Diacritic"},
    68336: {"Terminal_Punctuation"},
    68337: {"Terminal_Punctuation"},
    68338: {"Terminal_Punctuation"},
    68339: {"Terminal_Punctuation"},
    68340: {"Terminal_Punctuation"},
    68341: {"Terminal_Punctuation"},
    68410: {"Terminal_Punctuation"},
    68411: {"Terminal_Punctuation"},
    68412: {"Terminal_Punctuation"},
    68413: {"Terminal_Punctuation"},
    68414: {"Terminal_Punctuation"},
    68415: {"Terminal_Punctuation"},
    68505: {"Terminal_Punctuation"},
    68506: {"Terminal_Punctuation"},
    68507: {"Terminal_Punctuation"},
    68508: {"Terminal_Punctuation"},
    68898: {"Diacritic"},
    68899: {"Diacritic"},
    68900: {"Diacritic", "Other_Alphabetic"},
    68901: {"Diacritic", "Other_Alphabetic"},
    68902: {"Diacritic", "Other_Alphabetic"},
    68903: {"Diacritic", "Other_Alphabetic"},
    69291: {"Other_Alphabetic"},
    69292: {"Other_Alphabetic"},
    69293: {"Dash"},
    69446: {"Diacritic"},
    69447: {"Diacritic"},
    69448: {"Diacritic"},
    69449: {"Diacritic"},
    69450: {"Diacritic"},
    69451: {"Diacritic"},
    69452: {"Diacritic"},
    69453: {"Diacritic"},
    69454: {"Diacritic"},
    69455: {"Diacritic"},
    69456: {"Diacritic"},
    69461: {"Terminal_Punctuation", "Sentence_Terminal"},
    69462: {"Terminal_Punctuation", "Sentence_Terminal"},
    69463: {"Terminal_Punctuation", "Sentence_Terminal"},
    69464: {"Terminal_Punctuation", "Sentence_Terminal"},
    69465: {"Terminal_Punctuation", "Sentence_Terminal"},
    69632: {"Other_Alphabetic"},
    69633: {"Other_Alphabetic"},
    69634: {"Other_Alphabetic"},
    69688: {"Other_Alphabetic"},
    69689: {"Other_Alphabetic"},
    69690: {"Other_Alphabetic"},
    69691: {"Other_Alphabetic"},
    69692: {"Other_Alphabetic"},
    69693: {"Other_Alphabetic"},
    69694: {"Other_Alphabetic"},
    69695: {"Other_Alphabetic"},
    69696: {"Other_Alphabetic"},
    69697: {"Other_Alphabetic"},
    69698: {"Other_Alphabetic"},
    69699: {"Other_Alphabetic"},
    69700: {"Other_Alphabetic"},
    69701: {"Other_Alphabetic"},
    69703: {"Terminal_Punctuation", "Sentence_Terminal"},
    69704: {"Terminal_Punctuation", "Sentence_Terminal"},
    69705: {"Terminal_Punctuation"},
    69706: {"Terminal_Punctuation"},
    69707: {"Terminal_Punctuation"},
    69708: {"Terminal_Punctuation"},
    69709: {"Terminal_Punctuation"},
    69762: {"Other_Alphabetic"},
    69808: {"Other_Alphabetic"},
    69809: {"Other_Alphabetic"},
    69810: {"Other_Alphabetic"},
    69811: {"Other_Alphabetic"},
    69812: {"Other_Alphabetic"},
    69813: {"Other_Alphabetic"},
    69814: {"Other_Alphabetic"},
    69815: {"Other_Alphabetic"},
    69816: {"Other_Alphabetic"},
    69817: {"Diacritic"},
    69818: {"Diacritic"},
    69821: {"Prepended_Concatenation_Mark"},
    69822: {"Terminal_Punctuation", "Sentence_Terminal"},
    69823: {"Terminal_Punctuation", "Sentence_Terminal"},
    69824: {"Terminal_Punctuation", "Sentence_Terminal"},
    69825: {"Terminal_Punctuation", "Sentence_Terminal"},
    69837: {"Prepended_Concatenation_Mark"},
    69888: {"Other_Alphabetic"},
    69889: {"Other_Alphabetic"},
    69890: {"Other_Alphabetic"},
    69927: {"Other_Alphabetic"},
    69928: {"Other_Alphabetic"},
    69929: {"Other_Alphabetic"},
    69930: {"Other_Alphabetic"},
    69931: {"Other_Alphabetic"},
    69932: {"Other_Alphabetic"},
    69933: {"Other_Alphabetic"},
    69934: {"Other_Alphabetic"},
    69935: {"Other_Alphabetic"},
    69936: {"Other_Alphabetic"},
    69937: {"Other_Alphabetic"},
    69938: {"Other_Alphabetic"},
    69939: {"Diacritic"},
    69940: {"Diacritic"},
    69953: {"Terminal_Punctuation", "Sentence_Terminal"},
    69954: {"Terminal_Punctuation", "Sentence_Terminal"},
    69955: {"Terminal_Punctuation", "Sentence_Terminal"},
    69957: {"Other_Alphabetic"},
    69958: {"Other_Alphabetic"},
    70003: {"Diacritic"},
    70016: {"Other_Alphabetic"},
    70017: {"Other_Alphabetic"},
    70018: {"Other_Alphabetic"},
    70067: {"Other_Alphabetic"},
    70068: {"Other_Alphabetic"},
    70069: {"Other_Alphabetic"},
    70070: {"Other_Alphabetic"},
    70071: {"Other_Alphabetic"},
    70072: {"Other_Alphabetic"},
    70073: {"Other_Alphabetic"},
    70074: {"Other_Alphabetic"},
    70075: {"Other_Alphabetic"},
    70076: {"Other_Alphabetic"},
    70077: {"Other_Alphabetic"},
    70078: {"Other_Alphabetic"},
    70079: {"Other_Alphabetic"},
    70080: {"Diacritic"},
    70085: {"Terminal_Punctuation", "Sentence_Terminal"},
    70086: {"Terminal_Punctuation", "Sentence_Terminal"},
    70090: {"Diacritic"},
    70091: {"Diacritic"},
    70092: {"Diacritic"},
    70093: {"Terminal_Punctuation", "Sentence_Terminal"},
    70094: {"Other_Alphabetic"},
    70095: {"Other_Alphabetic"},
    70110: {"Terminal_Punctuation", "Sentence_Terminal"},
    70111: {"Terminal_Punctuation", "Sentence_Terminal"},
    70188: {"Other_Alphabetic"},
    70189: {"Other_Alphabetic"},
    70190: {"Other_Alphabetic"},
    70191: {"Other_Alphabetic"},
    70192: {"Other_Alphabetic"},
    70193: {"Other_Alphabetic"},
    70194: {"Other_Alphabetic"},
    70195: {"Other_Alphabetic"},
    70196: {"Other_Alphabetic"},
    70197: {"Diacritic"},
    70198: {"Diacritic"},
    70199: {"Other_Alphabetic"},
    70200: {"Terminal_Punctuation", "Sentence_Terminal"},
    70201: {"Terminal_Punctuation", "Sentence_Terminal"},
    70202: {"Terminal_Punctuation"},
    70203: {"Terminal_Punctuation", "Sentence_Terminal"},
    70204: {"Terminal_Punctuation", "Sentence_Terminal"},
    70206: {"Other_Alphabetic"},
    70313: {"Terminal_Punctuation", "Sentence_Terminal"},
    70367: {"Other_Alphabetic"},
    70368: {"Other_Alphabetic"},
    70369: {"Other_Alphabetic"},
    70370: {"Other_Alphabetic"},
    70371: {"Other_Alphabetic"},
    70372: {"Other_Alphabetic"},
    70373: {"Other_Alphabetic"},
    70374: {"Other_Alphabetic"},
    70375: {"Other_Alphabetic"},
    70376: {"Other_Alphabetic"},
    70377: {"Diacritic"},
    70378: {"Diacritic"},
    70400: {"Other_Alphabetic"},
    70401: {"Other_Alphabetic"},
    70402: {"Other_Alphabetic"},
    70403: {"Other_Alphabetic"},
    70460: {"Diacritic"},
    70462: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    70463: {"Other_Alphabetic"},
    70464: {"Other_Alphabetic"},
    70465: {"Other_Alphabetic"},
    70466: {"Other_Alphabetic"},
    70467: {"Other_Alphabetic"},
    70468: {"Other_Alphabetic"},
    70471: {"Other_Alphabetic"},
    70472: {"Other_Alphabetic"},
    70475: {"Other_Alphabetic"},
    70476: {"Other_Alphabetic"},
    70477: {"Diacritic"},
    70487: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    70493: {"Extender"},
    70498: {"Other_Alphabetic"},
    70499: {"Other_Alphabetic"},
    70502: {"Diacritic"},
    70503: {"Diacritic"},
    70504: {"Diacritic"},
    70505: {"Diacritic"},
    70506: {"Diacritic"},
    70507: {"Diacritic"},
    70508: {"Diacritic"},
    70512: {"Diacritic"},
    70513: {"Diacritic"},
    70514: {"Diacritic"},
    70515: {"Diacritic"},
    70516: {"Diacritic"},
    70709: {"Other_Alphabetic"},
    70710: {"Other_Alphabetic"},
    70711: {"Other_Alphabetic"},
    70712: {"Other_Alphabetic"},
    70713: {"Other_Alphabetic"},
    70714: {"Other_Alphabetic"},
    70715: {"Other_Alphabetic"},
    70716: {"Other_Alphabetic"},
    70717: {"Other_Alphabetic"},
    70718: {"Other_Alphabetic"},
    70719: {"Other_Alphabetic"},
    70720: {"Other_Alphabetic"},
    70721: {"Other_Alphabetic"},
    70722: {"Diacritic"},
    70723: {"Other_Alphabetic"},
    70724: {"Other_Alphabetic"},
    70725: {"Other_Alphabetic"},
    70726: {"Diacritic"},
    70731: {"Terminal_Punctuation", "Sentence_Terminal"},
    70732: {"Terminal_Punctuation", "Sentence_Terminal"},
    70733: {"Terminal_Punctuation"},
    70746: {"Terminal_Punctuation"},
    70747: {"Terminal_Punctuation"},
    70832: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    70833: {"Other_Alphabetic"},
    70834: {"Other_Alphabetic"},
    70835: {"Other_Alphabetic"},
    70836: {"Other_Alphabetic"},
    70837: {"Other_Alphabetic"},
    70838: {"Other_Alphabetic"},
    70839: {"Other_Alphabetic"},
    70840: {"Other_Alphabetic"},
    70841: {"Other_Alphabetic"},
    70842: {"Other_Alphabetic"},
    70843: {"Other_Alphabetic"},
    70844: {"Other_Alphabetic"},
    70845: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    70846: {"Other_Alphabetic"},
    70847: {"Other_Alphabetic"},
    70848: {"Other_Alphabetic"},
    70849: {"Other_Alphabetic"},
    70850: {"Diacritic"},
    70851: {"Diacritic"},
    71087: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    71088: {"Other_Alphabetic"},
    71089: {"Other_Alphabetic"},
    71090: {"Other_Alphabetic"},
    71091: {"Other_Alphabetic"},
    71092: {"Other_Alphabetic"},
    71093: {"Other_Alphabetic"},
    71096: {"Other_Alphabetic"},
    71097: {"Other_Alphabetic"},
    71098: {"Other_Alphabetic"},
    71099: {"Other_Alphabetic"},
    71100: {"Other_Alphabetic"},
    71101: {"Other_Alphabetic"},
    71102: {"Other_Alphabetic"},
    71103: {"Diacritic"},
    71104: {"Diacritic"},
    71106: {"Terminal_Punctuation", "Sentence_Terminal"},
    71107: {"Terminal_Punctuation", "Sentence_Terminal"},
    71108: {"Terminal_Punctuation"},
    71109: {"Terminal_Punctuation"},
    71110: {"Extender"},
    71111: {"Extender"},
    71112: {"Extender"},
    71113: {"Terminal_Punctuation", "Sentence_Terminal"},
    71114: {"Terminal_Punctuation", "Sentence_Terminal"},
    71115: {"Terminal_Punctuation", "Sentence_Terminal"},
    71116: {"Terminal_Punctuation", "Sentence_Terminal"},
    71117: {"Terminal_Punctuation", "Sentence_Terminal"},
    71118: {"Terminal_Punctuation", "Sentence_Terminal"},
    71119: {"Terminal_Punctuation", "Sentence_Terminal"},
    71120: {"Terminal_Punctuation", "Sentence_Terminal"},
    71121: {"Terminal_Punctuation", "Sentence_Terminal"},
    71122: {"Terminal_Punctuation", "Sentence_Terminal"},
    71123: {"Terminal_Punctuation", "Sentence_Terminal"},
    71124: {"Terminal_Punctuation", "Sentence_Terminal"},
    71125: {"Terminal_Punctuation", "Sentence_Terminal"},
    71126: {"Terminal_Punctuation", "Sentence_Terminal"},
    71127: {"Terminal_Punctuation", "Sentence_Terminal"},
    71132: {"Other_Alphabetic"},
    71133: {"Other_Alphabetic"},
    71216: {"Other_Alphabetic"},
    71217: {"Other_Alphabetic"},
    71218: {"Other_Alphabetic"},
    71219: {"Other_Alphabetic"},
    71220: {"Other_Alphabetic"},
    71221: {"Other_Alphabetic"},
    71222: {"Other_Alphabetic"},
    71223: {"Other_Alphabetic"},
    71224: {"Other_Alphabetic"},
    71225: {"Other_Alphabetic"},
    71226: {"Other_Alphabetic"},
    71227: {"Other_Alphabetic"},
    71228: {"Other_Alphabetic"},
    71229: {"Other_Alphabetic"},
    71230: {"Other_Alphabetic"},
    71231: {"Diacritic"},
    71232: {"Other_Alphabetic"},
    71233: {"Terminal_Punctuation", "Sentence_Terminal"},
    71234: {"Terminal_Punctuation", "Sentence_Terminal"},
    71339: {"Other_Alphabetic"},
    71340: {"Other_Alphabetic"},
    71341: {"Other_Alphabetic"},
    71342: {"Other_Alphabetic"},
    71343: {"Other_Alphabetic"},
    71344: {"Other_Alphabetic"},
    71345: {"Other_Alphabetic"},
    71346: {"Other_Alphabetic"},
    71347: {"Other_Alphabetic"},
    71348: {"Other_Alphabetic"},
    71349: {"Other_Alphabetic"},
    71350: {"Diacritic"},
    71351: {"Diacritic"},
    71453: {"Other_Alphabetic"},
    71454: {"Other_Alphabetic"},
    71455: {"Other_Alphabetic"},
    71456: {"Other_Alphabetic"},
    71457: {"Other_Alphabetic"},
    71458: {"Other_Alphabetic"},
    71459: {"Other_Alphabetic"},
    71460: {"Other_Alphabetic"},
    71461: {"Other_Alphabetic"},
    71462: {"Other_Alphabetic"},
    71463: {"Other_Alphabetic"},
    71464: {"Other_Alphabetic"},
    71465: {"Other_Alphabetic"},
    71466: {"Other_Alphabetic"},
    71467: {"Diacritic"},
    71484: {"Terminal_Punctuation", "Sentence_Terminal"},
    71485: {"Terminal_Punctuation", "Sentence_Terminal"},
    71486: {"Terminal_Punctuation", "Sentence_Terminal"},
    71724: {"Other_Alphabetic"},
    71725: {"Other_Alphabetic"},
    71726: {"Other_Alphabetic"},
    71727: {"Other_Alphabetic"},
    71728: {"Other_Alphabetic"},
    71729: {"Other_Alphabetic"},
    71730: {"Other_Alphabetic"},
    71731: {"Other_Alphabetic"},
    71732: {"Other_Alphabetic"},
    71733: {"Other_Alphabetic"},
    71734: {"Other_Alphabetic"},
    71735: {"Other_Alphabetic"},
    71736: {"Other_Alphabetic"},
    71737: {"Diacritic"},
    71738: {"Diacritic"},
    71984: {"Other_Alphabetic", "Other_Grapheme_Extend"},
    71985: {"Other_Alphabetic"},
    71986: {"Other_Alphabetic"},
    71987: {"Other_Alphabetic"},
    71988: {"Other_Alphabetic"},
    71989: {"Other_Alphabetic"},
    71991: {"Other_Alphabetic"},
    71992: {"Other_Alphabetic"},
    71995: {"Other_Alphabetic"},
    71996: {"Other_Alphabetic"},
    71997: {"Diacritic"},
    71998: {"Diacritic"},
    72000: {"Other_Alphabetic"},
    72002: {"Other_Alphabetic"},
    72003: {"Diacritic"},
    72004: {"Terminal_Punctuation", "Sentence_Terminal"},
    72006: {"Terminal_Punctuation", "Sentence_Terminal"},
    72145: {"Other_Alphabetic"},
    72146: {"Other_Alphabetic"},
    72147: {"Other_Alphabetic"},
    72148: {"Other_Alphabetic"},
    72149: {"Other_Alphabetic"},
    72150: {"Other_Alphabetic"},
    72151: {"Other_Alphabetic"},
    72154: {"Other_Alphabetic"},
    72155: {"Other_Alphabetic"},
    72156: {"Other_Alphabetic"},
    72157: {"Other_Alphabetic"},
    72158: {"Other_Alphabetic"},
    72159: {"Other_Alphabetic"},
    72160: {"Diacritic"},
    72164: {"Other_Alphabetic"},
    72193: {"Other_Alphabetic"},
    72194: {"Other_Alphabetic"},
    72195: {"Other_Alphabetic"},
    72196: {"Other_Alphabetic"},
    72197: {"Other_Alphabetic"},
    72198: {"Other_Alphabetic"},
    72199: {"Other_Alphabetic"},
    72200: {"Other_Alphabetic"},
    72201: {"Other_Alphabetic"},
    72202: {"Other_Alphabetic"},
    72244: {"Diacritic"},
    72245: {"Other_Alphabetic"},
    72246: {"Other_Alphabetic"},
    72247: {"Other_Alphabetic"},
    72248: {"Other_Alphabetic"},
    72249: {"Other_Alphabetic"},
    72251: {"Other_Alphabetic"},
    72252: {"Other_Alphabetic"},
    72253: {"Other_Alphabetic"},
    72254: {"Other_Alphabetic"},
    72258: {"Terminal_Punctuation", "Sentence_Terminal"},
    72259: {"Terminal_Punctuation", "Sentence_Terminal"},
    72263: {"Diacritic"},
    72273: {"Other_Alphabetic"},
    72274: {"Other_Alphabetic"},
    72275: {"Other_Alphabetic"},
    72276: {"Other_Alphabetic"},
    72277: {"Other_Alphabetic"},
    72278: {"Other_Alphabetic"},
    72279: {"Other_Alphabetic"},
    72280: {"Other_Alphabetic"},
    72281: {"Other_Alphabetic"},
    72282: {"Other_Alphabetic"},
    72283: {"Other_Alphabetic"},
    72330: {"Other_Alphabetic"},
    72331: {"Other_Alphabetic"},
    72332: {"Other_Alphabetic"},
    72333: {"Other_Alphabetic"},
    72334: {"Other_Alphabetic"},
    72335: {"Other_Alphabetic"},
    72336: {"Other_Alphabetic"},
    72337: {"Other_Alphabetic"},
    72338: {"Other_Alphabetic"},
    72339: {"Other_Alphabetic"},
    72340: {"Other_Alphabetic"},
    72341: {"Other_Alphabetic"},
    72342: {"Other_Alphabetic"},
    72343: {"Other_Alphabetic"},
    72344: {"Extender"},
    72345: {"Diacritic"},
    72347: {"Terminal_Punctuation", "Sentence_Terminal"},
    72348: {"Terminal_Punctuation", "Sentence_Terminal"},
    72353: {"Terminal_Punctuation"},
    72354: {"Terminal_Punctuation"},
    72751: {"Other_Alphabetic"},
    72752: {"Other_Alphabetic"},
    72753: {"Other_Alphabetic"},
    72754: {"Other_Alphabetic"},
    72755: {"Other_Alphabetic"},
    72756: {"Other_Alphabetic"},
    72757: {"Other_Alphabetic"},
    72758: {"Other_Alphabetic"},
    72760: {"Other_Alphabetic"},
    72761: {"Other_Alphabetic"},
    72762: {"Other_Alphabetic"},
    72763: {"Other_Alphabetic"},
    72764: {"Other_Alphabetic"},
    72765: {"Other_Alphabetic"},
    72766: {"Other_Alphabetic"},
    72767: {"Diacritic"},
    72769: {"Terminal_Punctuation", "Sentence_Terminal"},
    72770: {"Terminal_Punctuation", "Sentence_Terminal"},
    72771: {"Terminal_Punctuation"},
    72817: {"Terminal_Punctuation"},
    72850: {"Other_Alphabetic"},
    72851: {"Other_Alphabetic"},
    72852: {"Other_Alphabetic"},
    72853: {"Other_Alphabetic"},
    72854: {"Other_Alphabetic"},
    72855: {"Other_Alphabetic"},
    72856: {"Other_Alphabetic"},
    72857: {"Other_Alphabetic"},
    72858: {"Other_Alphabetic"},
    72859: {"Other_Alphabetic"},
    72860: {"Other_Alphabetic"},
    72861: {"Other_Alphabetic"},
    72862: {"Other_Alphabetic"},
    72863: {"Other_Alphabetic"},
    72864: {"Other_Alphabetic"},
    72865: {"Other_Alphabetic"},
    72866: {"Other_Alphabetic"},
    72867: {"Other_Alphabetic"},
    72868: {"Other_Alphabetic"},
    72869: {"Other_Alphabetic"},
    72870: {"Other_Alphabetic"},
    72871: {"Other_Alphabetic"},
    72873: {"Other_Alphabetic"},
    72874: {"Other_Alphabetic"},
    72875: {"Other_Alphabetic"},
    72876: {"Other_Alphabetic"},
    72877: {"Other_Alphabetic"},
    72878: {"Other_Alphabetic"},
    72879: {"Other_Alphabetic"},
    72880: {"Other_Alphabetic"},
    72881: {"Other_Alphabetic"},
    72882: {"Other_Alphabetic"},
    72883: {"Other_Alphabetic"},
    72884: {"Other_Alphabetic"},
    72885: {"Other_Alphabetic"},
    72886: {"Other_Alphabetic"},
    73009: {"Other_Alphabetic"},
    73010: {"Other_Alphabetic"},
    73011: {"Other_Alphabetic"},
    73012: {"Other_Alphabetic"},
    73013: {"Other_Alphabetic"},
    73014: {"Other_Alphabetic"},
    73018: {"Other_Alphabetic"},
    73020: {"Other_Alphabetic"},
    73021: {"Other_Alphabetic"},
    73023: {"Other_Alphabetic"},
    73024: {"Other_Alphabetic"},
    73025: {"Other_Alphabetic"},
    73026: {"Diacritic"},
    73027: {"Other_Alphabetic"},
    73028: {"Diacritic"},
    73029: {"Diacritic"},
    73031: {"Other_Alphabetic"},
    73098: {"Other_Alphabetic"},
    73099: {"Other_Alphabetic"},
    73100: {"Other_Alphabetic"},
    73101: {"Other_Alphabetic"},
    73102: {"Other_Alphabetic"},
    73104: {"Other_Alphabetic"},
    73105: {"Other_Alphabetic"},
    73107: {"Other_Alphabetic"},
    73108: {"Other_Alphabetic"},
    73109: {"Other_Alphabetic"},
    73110: {"Other_Alphabetic"},
    73111: {"Diacritic"},
    73459: {"Other_Alphabetic"},
    73460: {"Other_Alphabetic"},
    73461: {"Other_Alphabetic"},
    73462: {"Other_Alphabetic"},
    73463: {"Terminal_Punctuation", "Sentence_Terminal"},
    73464: {"Terminal_Punctuation", "Sentence_Terminal"},
    74864: {"Terminal_Punctuation"},
    74865: {"Terminal_Punctuation"},
    74866: {"Terminal_Punctuation"},
    74867: {"Terminal_Punctuation"},
    74868: {"Terminal_Punctuation"},
    92782: {"Terminal_Punctuation", "Sentence_Terminal"},
    92783: {"Terminal_Punctuation", "Sentence_Terminal"},
    92912: {"Diacritic"},
    92913: {"Diacritic"},
    92914: {"Diacritic"},
    92915: {"Diacritic"},
    92916: {"Diacritic"},
    92917: {"Terminal_Punctuation", "Sentence_Terminal"},
    92976: {"Diacritic"},
    92977: {"Diacritic"},
    92978: {"Diacritic"},
    92979: {"Diacritic"},
    92980: {"Diacritic"},
    92981: {"Diacritic"},
    92982: {"Diacritic"},
    92983: {"Terminal_Punctuation", "Sentence_Terminal"},
    92984: {"Terminal_Punctuation", "Sentence_Terminal"},
    92985: {"Terminal_Punctuation"},
    92994: {"Extender"},
    92995: {"Extender"},
    92996: {"Terminal_Punctuation", "Sentence_Terminal"},
    93847: {"Terminal_Punctuation"},
    93848: {"Terminal_Punctuation", "Sentence_Terminal"},
    94031: {"Other_Alphabetic"},
    94033: {"Other_Alphabetic"},
    94034: {"Other_Alphabetic"},
    94035: {"Other_Alphabetic"},
    94036: {"Other_Alphabetic"},
    94037: {"Other_Alphabetic"},
    94038: {"Other_Alphabetic"},
    94039: {"Other_Alphabetic"},
    94040: {"Other_Alphabetic"},
    94041: {"Other_Alphabetic"},
    94042: {"Other_Alphabetic"},
    94043: {"Other_Alphabetic"},
    94044: {"Other_Alphabetic"},
    94045: {"Other_Alphabetic"},
    94046: {"Other_Alphabetic"},
    94047: {"Other_Alphabetic"},
    94048: {"Other_Alphabetic"},
    94049: {"Other_Alphabetic"},
    94050: {"Other_Alphabetic"},
    94051: {"Other_Alphabetic"},
    94052: {"Other_Alphabetic"},
    94053: {"Other_Alphabetic"},
    94054: {"Other_Alphabetic"},
    94055: {"Other_Alphabetic"},
    94056: {"Other_Alphabetic"},
    94057: {"Other_Alphabetic"},
    94058: {"Other_Alphabetic"},
    94059: {"Other_Alphabetic"},
    94060: {"Other_Alphabetic"},
    94061: {"Other_Alphabetic"},
    94062: {"Other_Alphabetic"},
    94063: {"Other_Alphabetic"},
    94064: {"Other_Alphabetic"},
    94065: {"Other_Alphabetic"},
    94066: {"Other_Alphabetic"},
    94067: {"Other_Alphabetic"},
    94068: {"Other_Alphabetic"},
    94069: {"Other_Alphabetic"},
    94070: {"Other_Alphabetic"},
    94071: {"Other_Alphabetic"},
    94072: {"Other_Alphabetic"},
    94073: {"Other_Alphabetic"},
    94074: {"Other_Alphabetic"},
    94075: {"Other_Alphabetic"},
    94076: {"Other_Alphabetic"},
    94077: {"Other_Alphabetic"},
    94078: {"Other_Alphabetic"},
    94079: {"Other_Alphabetic"},
    94080: {"Other_Alphabetic"},
    94081: {"Other_Alphabetic"},
    94082: {"Other_Alphabetic"},
    94083: {"Other_Alphabetic"},
    94084: {"Other_Alphabetic"},
    94085: {"Other_Alphabetic"},
    94086: {"Other_Alphabetic"},
    94087: {"Other_Alphabetic"},
    94095: {"Diacritic", "Other_Alphabetic"},
    94096: {"Diacritic", "Other_Alphabetic"},
    94097: {"Diacritic", "Other_Alphabetic"},
    94098: {"Diacritic", "Other_Alphabetic"},
    94099: {"Diacritic"},
    94100: {"Diacritic"},
    94101: {"Diacritic"},
    94102: {"Diacritic"},
    94103: {"Diacritic"},
    94104: {"Diacritic"},
    94105: {"Diacritic"},
    94106: {"Diacritic"},
    94107: {"Diacritic"},
    94108: {"Diacritic"},
    94109: {"Diacritic"},
    94110: {"Diacritic"},
    94111: {"Diacritic"},
    94176: {"Extender"},
    94177: {"Extender"},
    94179: {"Extender"},
    94180: {"Ideographic"},
    94192: {"Diacritic", "Other_Alphabetic"},
    94193: {"Diacritic", "Other_Alphabetic"},
    94208: {"Ideographic"},
    94209: {"Ideographic"},
    94210: {"Ideographic"},
    94211: {"Ideographic"},
    94212: {"Ideographic"},
    94213: {"Ideographic"},
    94214: {"Ideographic"},
    94215: {"Ideographic"},
    94216: {"Ideographic"},
    94217: {"Ideographic"},
    94218: {"Ideographic"},
    94219: {"Ideographic"},
    94220: {"Ideographic"},
    94221: {"Ideographic"},
    94222: {"Ideographic"},
    94223: {"Ideographic"},
    94224: {"Ideographic"},
    94225: {"Ideographic"},
    94226: {"Ideographic"},
    94227: {"Ideographic"},
    94228: {"Ideographic"},
    94229: {"Ideographic"},
    94230: {"Ideographic"},
    94231: {"Ideographic"},
    94232: {"Ideographic"},
    94233: {"Ideographic"},
    94234: {"Ideographic"},
    94235: {"Ideographic"},
    94236: {"Ideographic"},
    94237: {"Ideographic"},
    94238: {"Ideographic"},
    94239: {"Ideographic"},
    94240: {"Ideographic"},
    94241: {"Ideographic"},
    94242: {"Ideographic"},
    94243: {"Ideographic"},
    94244: {"Ideographic"},
    94245: {"Ideographic"},
    94246: {"Ideographic"},
    94247: {"Ideographic"},
    94248: {"Ideographic"},
    94249: {"Ideographic"},
    94250: {"Ideographic"},
    94251: {"Ideographic"},
    94252: {"Ideographic"},
    94253: {"Ideographic"},
    94254: {"Ideographic"},
    94255: {"Ideographic"},
    94256: {"Ideographic"},
    94257: {"Ideographic"},
    94258: {"Ideographic"},
    94259: {"Ideographic"},
    94260: {"Ideographic"},
    94261: {"Ideographic"},
    94262: {"Ideographic"},
    94263: {"Ideographic"},
    94264: {"Ideographic"},
    94265: {"Ideographic"},
    94266: {"Ideographic"},
    94267: {"Ideographic"},
    94268: {"Ideographic"},
    94269: {"Ideographic"},
    94270: {"Ideographic"},
    94271: {"Ideographic"},
    94272: {"Ideographic"},
    94273: {"Ideographic"},
    94274: {"Ideographic"},
    94275: {"Ideographic"},
    94276: {"Ideographic"},
    94277: {"Ideographic"},
    94278: {"Ideographic"},
    94279: {"Ideographic"},
    94280: {"Ideographic"},
    94281: {"Ideographic"},
    94282: {"Ideographic"},
    94283: {"Ideographic"},
    94284: {"Ideographic"},
    94285: {"Ideographic"},
    94286: {"Ideographic"},
    94287: {"Ideographic"},
    94288: {"Ideographic"},
    94289: {"Ideographic"},
    94290: {"Ideographic"},
    94291: {"Ideographic"},
    94292: {"Ideographic"},
    94293: {"Ideographic"},
    94294: {"Ideographic"},
    94295: {"Ideographic"},
    94296: {"Ideographic"},
    94297: {"Ideographic"},
    94298: {"Ideographic"},
    94299: {"Ideographic"},
    94300: {"Ideographic"},
    94301: {"Ideographic"},
    94302: {"Ideographic"},
    94303: {"Ideographic"},
    94304: {"Ideographic"},
    94305: {"Ideographic"},
    94306: {"Ideographic"},
    94307: {"Ideographic"},
    94308: {"Ideographic"},
    94309: {"Ideographic"},
    94310: {"Ideographic"},
    94311: {"Ideographic"},
    94312: {"Ideographic"},
    94313: {"Ideographic"},
    94314: {"Ideographic"},
    94315: {"Ideographic"},
    94316: {"Ideographic"},
    94317: {"Ideographic"},
    94318: {"Ideographic"},
    94319: {"Ideographic"},
    94320: {"Ideographic"},
    94321: {"Ideographic"},
    94322: {"Ideographic"},
    94323: {"Ideographic"},
    94324: {"Ideographic"},
    94325: {"Ideographic"},
    94326: {"Ideographic"},
    94327: {"Ideographic"},
    94328: {"Ideographic"},
    94329: {"Ideographic"},
    94330: {"Ideographic"},
    94331: {"Ideographic"},
    94332: {"Ideographic"},
    94333: {"Ideographic"},
    94334: {"Ideographic"},
    94335: {"Ideographic"},
    94336: {"Ideographic"},
    94337: {"Ideographic"},
    94338: {"Ideographic"},
    94339: {"Ideographic"},
    94340: {"Ideographic"},
    94341: {"Ideographic"},
    94342: {"Ideographic"},
    94343: {"Ideographic"},
    94344: {"Ideographic"},
    94345: {"Ideographic"},
    94346: {"Ideographic"},
    94347: {"Ideographic"},
    94348: {"Ideographic"},
    94349: {"Ideographic"},
    94350: {"Ideographic"},
    94351: {"Ideographic"},
    94352: {"Ideographic"},
    94353: {"Ideographic"},
    94354: {"Ideographic"},
    94355: {"Ideographic"},
    94356: {"Ideographic"},
    94357: {"Ideographic"},
    94358: {"Ideographic"},
    94359: {"Ideographic"},
    94360: {"Ideographic"},
    94361: {"Ideographic"},
    94362: {"Ideographic"},
    94363: {"Ideographic"},
    94364: {"Ideographic"},
    94365: {"Ideographic"},
    94366: {"Ideographic"},
    94367: {"Ideographic"},
    94368: {"Ideographic"},
    94369: {"Ideographic"},
    94370: {"Ideographic"},
    94371: {"Ideographic"},
    94372: {"Ideographic"},
    94373: {"Ideographic"},
    94374: {"Ideographic"},
    94375: {"Ideographic"},
    94376: {"Ideographic"},
    94377: {"Ideographic"},
    94378: {"Ideographic"},
    94379: {"Ideographic"},
    94380: {"Ideographic"},
    94381: {"Ideographic"},
    94382: {"Ideographic"},
    94383: {"Ideographic"},
    94384: {"Ideographic"},
    94385: {"Ideographic"},
    94386: {"Ideographic"},
    94387: {"Ideographic"},
    94388: {"Ideographic"},
    94389: {"Ideographic"},
    94390: {"Ideographic"},
    94391: {"Ideographic"},
    94392: {"Ideographic"},
    94393: {"Ideographic"},
    94394: {"Ideographic"},
    94395: {"Ideographic"},
    94396: {"Ideographic"},
    94397: {"Ideographic"},
    94398: {"Ideographic"},
    94399: {"Ideographic"},
    94400: {"Ideographic"},
    94401: {"Ideographic"},
    94402: {"Ideographic"},
    94403: {"Ideographic"},
    94404: {"Ideographic"},
    94405: {"Ideographic"},
    94406: {"Ideographic"},
    94407: {"Ideographic"},
    94408: {"Ideographic"},
    94409: {"Ideographic"},
    94410: {"Ideographic"},
    94411: {"Ideographic"},
    94412: {"Ideographic"},
    94413: {"Ideographic"},
    94414: {"Ideographic"},
    94415: {"Ideographic"},
    94416: {"Ideographic"},
    94417: {"Ideographic"},
    94418: {"Ideographic"},
    94419: {"Ideographic"},
    94420: {"Ideographic"},
    94421: {"Ideographic"},
    94422: {"Ideographic"},
    94423: {"Ideographic"},
    94424: {"Ideographic"},
    94425: {"Ideographic"},
    94426: {"Ideographic"},
    94427: {"Ideographic"},
    94428: {"Ideographic"},
    94429: {"Ideographic"},
    94430: {"Ideographic"},
    94431: {"Ideographic"},
    94432: {"Ideographic"},
    94433: {"Ideographic"},
    94434: {"Ideographic"},
    94435: {"Ideographic"},
    94436: {"Ideographic"},
    94437: {"Ideographic"},
    94438: {"Ideographic"},
    94439: {"Ideographic"},
    94440: {"Ideographic"},
    94441: {"Ideographic"},
    94442: {"Ideographic"},
    94443: {"Ideographic"},
    94444: {"Ideographic"},
    94445: {"Ideographic"},
    94446: {"Ideographic"},
    94447: {"Ideographic"},
    94448: {"Ideographic"},
    94449: {"Ideographic"},
    94450: {"Ideographic"},
    94451: {"Ideographic"},
    94452: {"Ideographic"},
    94453: {"Ideographic"},
    94454: {"Ideographic"},
    94455: {"Ideographic"},
    94456: {"Ideographic"},
    94457: {"Ideographic"},
    94458: {"Ideographic"},
    94459: {"Ideographic"},
    94460: {"Ideographic"},
    94461: {"Ideographic"},
    94462: {"Ideographic"},
    94463: {"Ideographic"},
    94464: {"Ideographic"},
    94465: {"Ideographic"},
    94466: {"Ideographic"},
    94467: {"Ideographic"},
    94468: {"Ideographic"},
    94469: {"Ideographic"},
    94470: {"Ideographic"},
    94471: {"Ideographic"},
    94472: {"Ideographic"},
    94473: {"Ideographic"},
    94474: {"Ideographic"},
    94475: {"Ideographic"},
    94476: {"Ideographic"},
    94477: {"Ideographic"},
    94478: {"Ideographic"},
    94479: {"Ideographic"},
    94480: {"Ideographic"},
    94481: {"Ideographic"},
    94482: {"Ideographic"},
    94483: {"Ideographic"},
    94484: {"Ideographic"},
    94485: {"Ideographic"},
    94486: {"Ideographic"},
    94487: {"Ideographic"},
    94488: {"Ideographic"},
    94489: {"Ideographic"},
    94490: {"Ideographic"},
    94491: {"Ideographic"},
    94492: {"Ideographic"},
    94493: {"Ideographic"},
    94494: {"Ideographic"},
    94495: {"Ideographic"},
    94496: {"Ideographic"},
    94497: {"Ideographic"},
    94498: {"Ideographic"},
    94499: {"Ideographic"},
    94500: {"Ideographic"},
    94501: {"Ideographic"},
    94502: {"Ideographic"},
    94503: {"Ideographic"},
    94504: {"Ideographic"},
    94505: {"Ideographic"},
    94506: {"Ideographic"},
    94507: {"Ideographic"},
    94508: {"Ideographic"},
    94509: {"Ideographic"},
    94510: {"Ideographic"},
    94511: {"Ideographic"},
    94512: {"Ideographic"},
    94513: {"Ideographic"},
    94514: {"Ideographic"},
    94515: {"Ideographic"},
    94516: {"Ideographic"},
    94517: {"Ideographic"},
    94518: {"Ideographic"},
    94519: {"Ideographic"},
    94520: {"Ideographic"},
    94521: {"Ideographic"},
    94522: {"Ideographic"},
    94523: {"Ideographic"},
    94524: {"Ideographic"},
    94525: {"Ideographic"},
    94526: {"Ideographic"},
    94527: {"Ideographic"},
    94528: {"Ideographic"},
    94529: {"Ideographic"},
    94530: {"Ideographic"},
    94531: {"Ideographic"},
    94532: {"Ideographic"},
    94533: {"Ideographic"},
    94534: {"Ideographic"},
    94535: {"Ideographic"},
    94536: {"Ideographic"},
    94537: {"Ideographic"},
    94538: {"Ideographic"},
    94539: {"Ideographic"},
    94540: {"Ideographic"},
    94541: {"Ideographic"},
    94542: {"Ideographic"},
    94543: {"Ideographic"},
    94544: {"Ideographic"},
    94545: {"Ideographic"},
    94546: {"Ideographic"},
    94547: {"Ideographic"},
    94548: {"Ideographic"},
    94549: {"Ideographic"},
    94550: {"Ideographic"},
    94551: {"Ideographic"},
    94552: {"Ideographic"},
    94553: {"Ideographic"},
    94554: {"Ideographic"},
    94555: {"Ideographic"},
    94556: {"Ideographic"},
    94557: {"Ideographic"},
    94558: {"Ideographic"},
    94559: {"Ideographic"},
    94560: {"Ideographic"},
    94561: {"Ideographic"},
    94562: {"Ideographic"},
    94563: {"Ideographic"},
    94564: {"Ideographic"},
    94565: {"Ideographic"},
    94566: {"Ideographic"},
    94567: {"Ideographic"},
    94568: {"Ideographic"},
    94569: {"Ideographic"},
    94570: {"Ideographic"},
    94571: {"Ideographic"},
    94572: {"Ideographic"},
    94573: {"Ideographic"},
    94574: {"Ideographic"},
    94575: {"Ideographic"},
    94576: {"Ideographic"},
    94577: {"Ideographic"},
    94578: {"Ideographic"},
    94579: {"Ideographic"},
    94580: {"Ideographic"},
    94581: {"Ideographic"},
    94582: {"Ideographic"},
    94583: {"Ideographic"},
    94584: {"Ideographic"},
    94585: {"Ideographic"},
    94586: {"Ideographic"},
    94587: {"Ideographic"},
    94588: {"Ideographic"},
    94589: {"Ideographic"},
    94590: {"Ideographic"},
    94591: {"Ideographic"},
    94592: {"Ideographic"},
    94593: {"Ideographic"},
    94594: {"Ideographic"},
    94595: {"Ideographic"},
    94596: {"Ideographic"},
    94597: {"Ideographic"},
    94598: {"Ideographic"},
    94599: {"Ideographic"},
    94600: {"Ideographic"},
    94601: {"Ideographic"},
    94602: {"Ideographic"},
    94603: {"Ideographic"},
    94604: {"Ideographic"},
    94605: {"Ideographic"},
    94606: {"Ideographic"},
    94607: {"Ideographic"},
    94608: {"Ideographic"},
    94609: {"Ideographic"},
    94610: {"Ideographic"},
    94611: {"Ideographic"},
    94612: {"Ideographic"},
    94613: {"Ideographic"},
    94614: {"Ideographic"},
    94615: {"Ideographic"},
    94616: {"Ideographic"},
    94617: {"Ideographic"},
    94618: {"Ideographic"},
    94619: {"Ideographic"},
    94620: {"Ideographic"},
    94621: {"Ideographic"},
    94622: {"Ideographic"},
    94623: {"Ideographic"},
    94624: {"Ideographic"},
    94625: {"Ideographic"},
    94626: {"Ideographic"},
    94627: {"Ideographic"},
    94628: {"Ideographic"},
    94629: {"Ideographic"},
    94630: {"Ideographic"},
    94631: {"Ideographic"},
    94632: {"Ideographic"},
    94633: {"Ideographic"},
    94634: {"Ideographic"},
    94635: {"Ideographic"},
    94636: {"Ideographic"},
    94637: {"Ideographic"},
    94638: {"Ideographic"},
    94639: {"Ideographic"},
    94640: {"Ideographic"},
    94641: {"Ideographic"},
    94642: {"Ideographic"},
    94643: {"Ideographic"},
    94644: {"Ideographic"},
    94645: {"Ideographic"},
    94646: {"Ideographic"},
    94647: {"Ideographic"},
    94648: {"Ideographic"},
    94649: {"Ideographic"},
    94650: {"Ideographic"},
    94651: {"Ideographic"},
    94652: {"Ideographic"},
    94653: {"Ideographic"},
    94654: {"Ideographic"},
    94655: {"Ideographic"},
    94656: {"Ideographic"},
    94657: {"Ideographic"},
    94658: {"Ideographic"},
    94659: {"Ideographic"},
    94660: {"Ideographic"},
    94661: {"Ideographic"},
    94662: {"Ideographic"},
    94663: {"Ideographic"},
    94664: {"Ideographic"},
    94665: {"Ideographic"},
    94666: {"Ideographic"},
    94667: {"Ideographic"},
    94668: {"Ideographic"},
    94669: {"Ideographic"},
    94670: {"Ideographic"},
    94671: {"Ideographic"},
    94672: {"Ideographic"},
    94673: {"Ideographic"},
    94674: {"Ideographic"},
    94675: {"Ideographic"},
    94676: {"Ideographic"},
    94677: {"Ideographic"},
    94678: {"Ideographic"},
    94679: {"Ideographic"},
    94680: {"Ideographic"},
    94681: {"Ideographic"},
    94682: {"Ideographic"},
    94683: {"Ideographic"},
    94684: {"Ideographic"},
    94685: {"Ideographic"},
    94686: {"Ideographic"},
    94687: {"Ideographic"},
    94688: {"Ideographic"},
    94689: {"Ideographic"},
    94690: {"Ideographic"},
    94691: {"Ideographic"},
    94692: {"Ideographic"},
    94693: {"Ideographic"},
    94694: {"Ideographic"},
    94695: {"Ideographic"},
    94696: {"Ideographic"},
    94697: {"Ideographic"},
    94698: {"Ideographic"},
    94699: {"Ideographic"},
    94700: {"Ideographic"},
    94701: {"Ideographic"},
    94702: {"Ideographic"},
    94703: {"Ideographic"},
    94704: {"Ideographic"},
    94705: {"Ideographic"},
    94706: {"Ideographic"},
    94707: {"Ideographic"},
    94708: {"Ideographic"},
    94709: {"Ideographic"},
    94710: {"Ideographic"},
    94711: {"Ideographic"},
    94712: {"Ideographic"},
    94713: {"Ideographic"},
    94714: {"Ideographic"},
    94715: {"Ideographic"},
    94716: {"Ideographic"},
    94717: {"Ideographic"},
    94718: {"Ideographic"},
    94719: {"Ideographic"},
    94720: {"Ideographic"},
    94721: {"Ideographic"},
    94722: {"Ideographic"},
    94723: {"Ideographic"},
    94724: {"Ideographic"},
    94725: {"Ideographic"},
    94726: {"Ideographic"},
    94727: {"Ideographic"},
    94728: {"Ideographic"},
    94729: {"Ideographic"},
    94730: {"Ideographic"},
    94731: {"Ideographic"},
    94732: {"Ideographic"},
    94733: {"Ideographic"},
    94734: {"Ideographic"},
    94735: {"Ideographic"},
    94736: {"Ideographic"},
    94737: {"Ideographic"},
    94738: {"Ideographic"},
    94739: {"Ideographic"},
    94740: {"Ideographic"},
    94741: {"Ideographic"},
    94742: {"Ideographic"},
    94743: {"Ideographic"},
    94744: {"Ideographic"},
    94745: {"Ideographic"},
    94746: {"Ideographic"},
    94747: {"Ideographic"},
    94748: {"Ideographic"},
    94749: {"Ideographic"},
    94750: {"Ideographic"},
    94751: {"Ideographic"},
    94752: {"Ideographic"},
    94753: {"Ideographic"},
    94754: {"Ideographic"},
    94755: {"Ideographic"},
    94756: {"Ideographic"},
    94757: {"Ideographic"},
    94758: {"Ideographic"},
    94759: {"Ideographic"},
    94760: {"Ideographic"},
    94761: {"Ideographic"},
    94762: {"Ideographic"},
    94763: {"Ideographic"},
    94764: {"Ideographic"},
    94765: {"Ideographic"},
    94766: {"Ideographic"},
    94767: {"Ideographic"},
    94768: {"Ideographic"},
    94769: {"Ideographic"},
    94770: {"Ideographic"},
    94771: {"Ideographic"},
    94772: {"Ideographic"},
    94773: {"Ideographic"},
    94774: {"Ideographic"},
    94775: {"Ideographic"},
    94776: {"Ideographic"},
    94777: {"Ideographic"},
    94778: {"Ideographic"},
    94779: {"Ideographic"},
    94780: {"Ideographic"},
    94781: {"Ideographic"},
    94782: {"Ideographic"},
    94783: {"Ideographic"},
    94784: {"Ideographic"},
    94785: {"Ideographic"},
    94786: {"Ideographic"},
    94787: {"Ideographic"},
    94788: {"Ideographic"},
    94789: {"Ideographic"},
    94790: {"Ideographic"},
    94791: {"Ideographic"},
    94792: {"Ideographic"},
    94793: {"Ideographic"},
    94794: {"Ideographic"},
    94795: {"Ideographic"},
    94796: {"Ideographic"},
    94797: {"Ideographic"},
    94798: {"Ideographic"},
    94799: {"Ideographic"},
    94800: {"Ideographic"},
    94801: {"Ideographic"},
    94802: {"Ideographic"},
    94803: {"Ideographic"},
    94804: {"Ideographic"},
    94805: {"Ideographic"},
    94806: {"Ideographic"},
    94807: {"Ideographic"},
    94808: {"Ideographic"},
    94809: {"Ideographic"},
    94810: {"Ideographic"},
    94811: {"Ideographic"},
    94812: {"Ideographic"},
    94813: {"Ideographic"},
    94814: {"Ideographic"},
    94815: {"Ideographic"},
    94816: {"Ideographic"},
    94817: {"Ideographic"},
    94818: {"Ideographic"},
    94819: {"Ideographic"},
    94820: {"Ideographic"},
    94821: {"Ideographic"},
    94822: {"Ideographic"},
    94823: {"Ideographic"},
    94824: {"Ideographic"},
    94825: {"Ideographic"},
    94826: {"Ideographic"},
    94827: {"Ideographic"},
    94828: {"Ideographic"},
    94829: {"Ideographic"},
    94830: {"Ideographic"},
    94831: {"Ideographic"},
    94832: {"Ideographic"},
    94833: {"Ideographic"},
    94834: {"Ideographic"},
    94835: {"Ideographic"},
    94836: {"Ideographic"},
    94837: {"Ideographic"},
    94838: {"Ideographic"},
    94839: {"Ideographic"},
    94840: {"Ideographic"},
    94841: {"Ideographic"},
    94842: {"Ideographic"},
    94843: {"Ideographic"},
    94844: {"Ideographic"},
    94845: {"Ideographic"},
    94846: {"Ideographic"},
    94847: {"Ideographic"},
    94848: {"Ideographic"},
    94849: {"Ideographic"},
    94850: {"Ideographic"},
    94851: {"Ideographic"},
    94852: {"Ideographic"},
    94853: {"Ideographic"},
    94854: {"Ideographic"},
    94855: {"Ideographic"},
    94856: {"Ideographic"},
    94857: {"Ideographic"},
    94858: {"Ideographic"},
    94859: {"Ideographic"},
    94860: {"Ideographic"},
    94861: {"Ideographic"},
    94862: {"Ideographic"},
    94863: {"Ideographic"},
    94864: {"Ideographic"},
    94865: {"Ideographic"},
    94866: {"Ideographic"},
    94867: {"Ideographic"},
    94868: {"Ideographic"},
    94869: {"Ideographic"},
    94870: {"Ideographic"},
    94871: {"Ideographic"},
    94872: {"Ideographic"},
    94873: {"Ideographic"},
    94874: {"Ideographic"},
    94875: {"Ideographic"},
    94876: {"Ideographic"},
    94877: {"Ideographic"},
    94878: {"Ideographic"},
    94879: {"Ideographic"},
    94880: {"Ideographic"},
    94881: {"Ideographic"},
    94882: {"Ideographic"},
    94883: {"Ideographic"},
    94884: {"Ideographic"},
    94885: {"Ideographic"},
    94886: {"Ideographic"},
    94887: {"Ideographic"},
    94888: {"Ideographic"},
    94889: {"Ideographic"},
    94890: {"Ideographic"},
    94891: {"Ideographic"},
    94892: {"Ideographic"},
    94893: {"Ideographic"},
    94894: {"Ideographic"},
    94895: {"Ideographic"},
    94896: {"Ideographic"},
    94897: {"Ideographic"},
    94898: {"Ideographic"},
    94899: {"Ideographic"},
    94900: {"Ideographic"},
    94901: {"Ideographic"},
    94902: {"Ideographic"},
    94903: {"Ideographic"},
    94904: {"Ideographic"},
    94905: {"Ideographic"},
    94906: {"Ideographic"},
    94907: {"Ideographic"},
    94908: {"Ideographic"},
    94909: {"Ideographic"},
    94910: {"Ideographic"},
    94911: {"Ideographic"},
    94912: {"Ideographic"},
    94913: {"Ideographic"},
    94914: {"Ideographic"},
    94915: {"Ideographic"},
    94916: {"Ideographic"},
    94917: {"Ideographic"},
    94918: {"Ideographic"},
    94919: {"Ideographic"},
    94920: {"Ideographic"},
    94921: {"Ideographic"},
    94922: {"Ideographic"},
    94923: {"Ideographic"},
    94924: {"Ideographic"},
    94925: {"Ideographic"},
    94926: {"Ideographic"},
    94927: {"Ideographic"},
    94928: {"Ideographic"},
    94929: {"Ideographic"},
    94930: {"Ideographic"},
    94931: {"Ideographic"},
    94932: {"Ideographic"},
    94933: {"Ideographic"},
    94934: {"Ideographic"},
    94935: {"Ideographic"},
    94936: {"Ideographic"},
    94937: {"Ideographic"},
    94938: {"Ideographic"},
    94939: {"Ideographic"},
    94940: {"Ideographic"},
    94941: {"Ideographic"},
    94942: {"Ideographic"},
    94943: {"Ideographic"},
    94944: {"Ideographic"},
    94945: {"Ideographic"},
    94946: {"Ideographic"},
    94947: {"Ideographic"},
    94948: {"Ideographic"},
    94949: {"Ideographic"},
    94950: {"Ideographic"},
    94951: {"Ideographic"},
    94952: {"Ideographic"},
    94953: {"Ideographic"},
    94954: {"Ideographic"},
    94955: {"Ideographic"},
    94956: {"Ideographic"},
    94957: {"Ideographic"},
    94958: {"Ideographic"},
    94959: {"Ideographic"},
    94960: {"Ideographic"},
    94961: {"Ideographic"},
    94962: {"Ideographic"},
    94963: {"Ideographic"},
    94964: {"Ideographic"},
    94965: {"Ideographic"},
    94966: {"Ideographic"},
    94967: {"Ideographic"},
    94968: {"Ideographic"},
    94969: {"Ideographic"},
    94970: {"Ideographic"},
    94971: {"Ideographic"},
    94972: {"Ideographic"},
    94973: {"Ideographic"},
    94974: {"Ideographic"},
    94975: {"Ideographic"},
    94976: {"Ideographic"},
    94977: {"Ideographic"},
    94978: {"Ideographic"},
    94979: {"Ideographic"},
    94980: {"Ideographic"},
    94981: {"Ideographic"},
    94982: {"Ideographic"},
    94983: {"Ideographic"},
    94984: {"Ideographic"},
    94985: {"Ideographic"},
    94986: {"Ideographic"},
    94987: {"Ideographic"},
    94988: {"Ideographic"},
    94989: {"Ideographic"},
    94990: {"Ideographic"},
    94991: {"Ideographic"},
    94992: {"Ideographic"},
    94993: {"Ideographic"},
    94994: {"Ideographic"},
    94995: {"Ideographic"},
    94996: {"Ideographic"},
    94997: {"Ideographic"},
    94998: {"Ideographic"},
    94999: {"Ideographic"},
    95000: {"Ideographic"},
    95001: {"Ideographic"},
    95002: {"Ideographic"},
    95003: {"Ideographic"},
    95004: {"Ideographic"},
    95005: {"Ideographic"},
    95006: {"Ideographic"},
    95007: {"Ideographic"},
    95008: {"Ideographic"},
    95009: {"Ideographic"},
    95010: {"Ideographic"},
    95011: {"Ideographic"},
    95012: {"Ideographic"},
    95013: {"Ideographic"},
    95014: {"Ideographic"},
    95015: {"Ideographic"},
    95016: {"Ideographic"},
    95017: {"Ideographic"},
    95018: {"Ideographic"},
    95019: {"Ideographic"},
    95020: {"Ideographic"},
    95021: {"Ideographic"},
    95022: {"Ideographic"},
    95023: {"Ideographic"},
    95024: {"Ideographic"},
    95025: {"Ideographic"},
    95026: {"Ideographic"},
    95027: {"Ideographic"},
    95028: {"Ideographic"},
    95029: {"Ideographic"},
    95030: {"Ideographic"},
    95031: {"Ideographic"},
    95032: {"Ideographic"},
    95033: {"Ideographic"},
    95034: {"Ideographic"},
    95035: {"Ideographic"},
    95036: {"Ideographic"},
    95037: {"Ideographic"},
    95038: {"Ideographic"},
    95039: {"Ideographic"},
    95040: {"Ideographic"},
    95041: {"Ideographic"},
    95042: {"Ideographic"},
    95043: {"Ideographic"},
    95044: {"Ideographic"},
    95045: {"Ideographic"},
    95046: {"Ideographic"},
    95047: {"Ideographic"},
    95048: {"Ideographic"},
    95049: {"Ideographic"},
    95050: {"Ideographic"},
    95051: {"Ideographic"},
    95052: {"Ideographic"},
    95053: {"Ideographic"},
    95054: {"Ideographic"},
    95055: {"Ideographic"},
    95056: {"Ideographic"},
    95057: {"Ideographic"},
    95058: {"Ideographic"},
    95059: {"Ideographic"},
    95060: {"Ideographic"},
    95061: {"Ideographic"},
    95062: {"Ideographic"},
    95063: {"Ideographic"},
    95064: {"Ideographic"},
    95065: {"Ideographic"},
    95066: {"Ideographic"},
    95067: {"Ideographic"},
    95068: {"Ideographic"},
    95069: {"Ideographic"},
    95070: {"Ideographic"},
    95071: {"Ideographic"},
    95072: {"Ideographic"},
    95073: {"Ideographic"},
    95074: {"Ideographic"},
    95075: {"Ideographic"},
    95076: {"Ideographic"},
    95077: {"Ideographic"},
    95078: {"Ideographic"},
    95079: {"Ideographic"},
    95080: {"Ideographic"},
    95081: {"Ideographic"},
    95082: {"Ideographic"},
    95083: {"Ideographic"},
    95084: {"Ideographic"},
    95085: {"Ideographic"},
    95086: {"Ideographic"},
    95087: {"Ideographic"},
    95088: {"Ideographic"},
    95089: {"Ideographic"},
    95090: {"Ideographic"},
    95091: {"Ideographic"},
    95092: {"Ideographic"},
    95093: {"Ideographic"},
    95094: {"Ideographic"},
    95095: {"Ideographic"},
    95096: {"Ideographic"},
    95097: {"Ideographic"},
    95098: {"Ideographic"},
    95099: {"Ideographic"},
    95100: {"Ideographic"},
    95101: {"Ideographic"},
    95102: {"Ideographic"},
    95103: {"Ideographic"},
    95104: {"Ideographic"},
    95105: {"Ideographic"},
    95106: {"Ideographic"},
    95107: {"Ideographic"},
    95108: {"Ideographic"},
    95109: {"Ideographic"},
    95110: {"Ideographic"},
    95111: {"Ideographic"},
    95112: {"Ideographic"},
    95113: {"Ideographic"},
    95114: {"Ideographic"},
    95115: {"Ideographic"},
    95116: {"Ideographic"},
    95117: {"Ideographic"},
    95118: {"Ideographic"},
    95119: {"Ideographic"},
    95120: {"Ideographic"},
    95121: {"Ideographic"},
    95122: {"Ideographic"},
    95123: {"Ideographic"},
    95124: {"Ideographic"},
    95125: {"Ideographic"},
    95126: {"Ideographic"},
    95127: {"Ideographic"},
    95128: {"Ideographic"},
    95129: {"Ideographic"},
    95130: {"Ideographic"},
    95131: {"Ideographic"},
    95132: {"Ideographic"},
    95133: {"Ideographic"},
    95134: {"Ideographic"},
    95135: {"Ideographic"},
    95136: {"Ideographic"},
    95137: {"Ideographic"},
    95138: {"Ideographic"},
    95139: {"Ideographic"},
    95140: {"Ideographic"},
    95141: {"Ideographic"},
    95142: {"Ideographic"},
    95143: {"Ideographic"},
    95144: {"Ideographic"},
    95145: {"Ideographic"},
    95146: {"Ideographic"},
    95147: {"Ideographic"},
    95148: {"Ideographic"},
    95149: {"Ideographic"},
    95150: {"Ideographic"},
    95151: {"Ideographic"},
    95152: {"Ideographic"},
    95153: {"Ideographic"},
    95154: {"Ideographic"},
    95155: {"Ideographic"},
    95156: {"Ideographic"},
    95157: {"Ideographic"},
    95158: {"Ideographic"},
    95159: {"Ideographic"},
    95160: {"Ideographic"},
    95161: {"Ideographic"},
    95162: {"Ideographic"},
    95163: {"Ideographic"},
    95164: {"Ideographic"},
    95165: {"Ideographic"},
    95166: {"Ideographic"},
    95167: {"Ideographic"},
    95168: {"Ideographic"},
    95169: {"Ideographic"},
    95170: {"Ideographic"},
    95171: {"Ideographic"},
    95172: {"Ideographic"},
    95173: {"Ideographic"},
    95174: {"Ideographic"},
    95175: {"Ideographic"},
    95176: {"Ideographic"},
    95177: {"Ideographic"},
    95178: {"Ideographic"},
    95179: {"Ideographic"},
    95180: {"Ideographic"},
    95181: {"Ideographic"},
    95182: {"Ideographic"},
    95183: {"Ideographic"},
    95184: {"Ideographic"},
    95185: {"Ideographic"},
    95186: {"Ideographic"},
    95187: {"Ideographic"},
    95188: {"Ideographic"},
    95189: {"Ideographic"},
    95190: {"Ideographic"},
    95191: {"Ideographic"},
    95192: {"Ideographic"},
    95193: {"Ideographic"},
    95194: {"Ideographic"},
    95195: {"Ideographic"},
    95196: {"Ideographic"},
    95197: {"Ideographic"},
    95198: {"Ideographic"},
    95199: {"Ideographic"},
    95200: {"Ideographic"},
    95201: {"Ideographic"},
    95202: {"Ideographic"},
    95203: {"Ideographic"},
    95204: {"Ideographic"},
    95205: {"Ideographic"},
    95206: {"Ideographic"},
    95207: {"Ideographic"},
    95208: {"Ideographic"},
    95209: {"Ideographic"},
    95210: {"Ideographic"},
    95211: {"Ideographic"},
    95212: {"Ideographic"},
    95213: {"Ideographic"},
    95214: {"Ideographic"},
    95215: {"Ideographic"},
    95216: {"Ideographic"},
    95217: {"Ideographic"},
    95218: {"Ideographic"},
    95219: {"Ideographic"},
    95220: {"Ideographic"},
    95221: {"Ideographic"},
    95222: {"Ideographic"},
    95223: {"Ideographic"},
    95224: {"Ideographic"},
    95225: {"Ideographic"},
    95226: {"Ideographic"},
    95227: {"Ideographic"},
    95228: {"Ideographic"},
    95229: {"Ideographic"},
    95230: {"Ideographic"},
    95231: {"Ideographic"},
    95232: {"Ideographic"},
    95233: {"Ideographic"},
    95234: {"Ideographic"},
    95235: {"Ideographic"},
    95236: {"Ideographic"},
    95237: {"Ideographic"},
    95238: {"Ideographic"},
    95239: {"Ideographic"},
    95240: {"Ideographic"},
    95241: {"Ideographic"},
    95242: {"Ideographic"},
    95243: {"Ideographic"},
    95244: {"Ideographic"},
    95245: {"Ideographic"},
    95246: {"Ideographic"},
    95247: {"Ideographic"},
    95248: {"Ideographic"},
    95249: {"Ideographic"},
    95250: {"Ideographic"},
    95251: {"Ideographic"},
    95252: {"Ideographic"},
    95253: {"Ideographic"},
    95254: {"Ideographic"},
    95255: {"Ideographic"},
    95256: {"Ideographic"},
    95257: {"Ideographic"},
    95258: {"Ideographic"},
    95259: {"Ideographic"},
    95260: {"Ideographic"},
    95261: {"Ideographic"},
    95262: {"Ideographic"},
    95263: {"Ideographic"},
    95264: {"Ideographic"},
    95265: {"Ideographic"},
    95266: {"Ideographic"},
    95267: {"Ideographic"},
    95268: {"Ideographic"},
    95269: {"Ideographic"},
    95270: {"Ideographic"},
    95271: {"Ideographic"},
    95272: {"Ideographic"},
    95273: {"Ideographic"},
    95274: {"Ideographic"},
    95275: {"Ideographic"},
    95276: {"Ideographic"},
    95277: {"Ideographic"},
    95278: {"Ideographic"},
    95279: {"Ideographic"},
    95280: {"Ideographic"},
    95281: {"Ideographic"},
    95282: {"Ideographic"},
    95283: {"Ideographic"},
    95284: {"Ideographic"},
    95285: {"Ideographic"},
    95286: {"Ideographic"},
    95287: {"Ideographic"},
    95288: {"Ideographic"},
    95289: {"Ideographic"},
    95290: {"Ideographic"},
    95291: {"Ideographic"},
    95292: {"Ideographic"},
    95293: {"Ideographic"},
    95294: {"Ideographic"},
    95295: {"Ideographic"},
    95296: {"Ideographic"},
    95297: {"Ideographic"},
    95298: {"Ideographic"},
    95299: {"Ideographic"},
    95300: {"Ideographic"},
    95301: {"Ideographic"},
    95302: {"Ideographic"},
    95303: {"Ideographic"},
    95304: {"Ideographic"},
    95305: {"Ideographic"},
    95306: {"Ideographic"},
    95307: {"Ideographic"},
    95308: {"Ideographic"},
    95309: {"Ideographic"},
    95310: {"Ideographic"},
    95311: {"Ideographic"},
    95312: {"Ideographic"},
    95313: {"Ideographic"},
    95314: {"Ideographic"},
    95315: {"Ideographic"},
    95316: {"Ideographic"},
    95317: {"Ideographic"},
    95318: {"Ideographic"},
    95319: {"Ideographic"},
    95320: {"Ideographic"},
    95321: {"Ideographic"},
    95322: {"Ideographic"},
    95323: {"Ideographic"},
    95324: {"Ideographic"},
    95325: {"Ideographic"},
    95326: {"Ideographic"},
    95327: {"Ideographic"},
    95328: {"Ideographic"},
    95329: {"Ideographic"},
    95330: {"Ideographic"},
    95331: {"Ideographic"},
    95332: {"Ideographic"},
    95333: {"Ideographic"},
    95334: {"Ideographic"},
    95335: {"Ideographic"},
    95336: {"Ideographic"},
    95337: {"Ideographic"},
    95338: {"Ideographic"},
    95339: {"Ideographic"},
    95340: {"Ideographic"},
    95341: {"Ideographic"},
    95342: {"Ideographic"},
    95343: {"Ideographic"},
    95344: {"Ideographic"},
    95345: {"Ideographic"},
    95346: {"Ideographic"},
    95347: {"Ideographic"},
    95348: {"Ideographic"},
    95349: {"Ideographic"},
    95350: {"Ideographic"},
    95351: {"Ideographic"},
    95352: {"Ideographic"},
    95353: {"Ideographic"},
    95354: {"Ideographic"},
    95355: {"Ideographic"},
    95356: {"Ideographic"},
    95357: {"Ideographic"},
    95358: {"Ideographic"},
    95359: {"Ideographic"},
    95360: {"Ideographic"},
    95361: {"Ideographic"},
    95362: {"Ideographic"},
    95363: {"Ideographic"},
    95364: {"Ideographic"},
    95365: {"Ideographic"},
    95366: {"Ideographic"},
    95367: {"Ideographic"},
    95368: {"Ideographic"},
    95369: {"Ideographic"},
    95370: {"Ideographic"},
    95371: {"Ideographic"},
    95372: {"Ideographic"},
    95373: {"Ideographic"},
    95374: {"Ideographic"},
    95375: {"Ideographic"},
    95376: {"Ideographic"},
    95377: {"Ideographic"},
    95378: {"Ideographic"},
    95379: {"Ideographic"},
    95380: {"Ideographic"},
    95381: {"Ideographic"},
    95382: {"Ideographic"},
    95383: {"Ideographic"},
    95384: {"Ideographic"},
    95385: {"Ideographic"},
    95386: {"Ideographic"},
    95387: {"Ideographic"},
    95388: {"Ideographic"},
    95389: {"Ideographic"},
    95390: {"Ideographic"},
    95391: {"Ideographic"},
    95392: {"Ideographic"},
    95393: {"Ideographic"},
    95394: {"Ideographic"},
    95395: {"Ideographic"},
    95396: {"Ideographic"},
    95397: {"Ideographic"},
    95398: {"Ideographic"},
    95399: {"Ideographic"},
    95400: {"Ideographic"},
    95401: {"Ideographic"},
    95402: {"Ideographic"},
    95403: {"Ideographic"},
    95404: {"Ideographic"},
    95405: {"Ideographic"},
    95406: {"Ideographic"},
    95407: {"Ideographic"},
    95408: {"Ideographic"},
    95409: {"Ideographic"},
    95410: {"Ideographic"},
    95411: {"Ideographic"},
    95412: {"Ideographic"},
    95413: {"Ideographic"},
    95414: {"Ideographic"},
    95415: {"Ideographic"},
    95416: {"Ideographic"},
    95417: {"Ideographic"},
    95418: {"Ideographic"},
    95419: {"Ideographic"},
    95420: {"Ideographic"},
    95421: {"Ideographic"},
    95422: {"Ideographic"},
    95423: {"Ideographic"},
    95424: {"Ideographic"},
    95425: {"Ideographic"},
    95426: {"Ideographic"},
    95427: {"Ideographic"},
    95428: {"Ideographic"},
    95429: {"Ideographic"},
    95430: {"Ideographic"},
    95431: {"Ideographic"},
    95432: {"Ideographic"},
    95433: {"Ideographic"},
    95434: {"Ideographic"},
    95435: {"Ideographic"},
    95436: {"Ideographic"},
    95437: {"Ideographic"},
    95438: {"Ideographic"},
    95439: {"Ideographic"},
    95440: {"Ideographic"},
    95441: {"Ideographic"},
    95442: {"Ideographic"},
    95443: {"Ideographic"},
    95444: {"Ideographic"},
    95445: {"Ideographic"},
    95446: {"Ideographic"},
    95447: {"Ideographic"},
    95448: {"Ideographic"},
    95449: {"Ideographic"},
    95450: {"Ideographic"},
    95451: {"Ideographic"},
    95452: {"Ideographic"},
    95453: {"Ideographic"},
    95454: {"Ideographic"},
    95455: {"Ideographic"},
    95456: {"Ideographic"},
    95457: {"Ideographic"},
    95458: {"Ideographic"},
    95459: {"Ideographic"},
    95460: {"Ideographic"},
    95461: {"Ideographic"},
    95462: {"Ideographic"},
    95463: {"Ideographic"},
    95464: {"Ideographic"},
    95465: {"Ideographic"},
    95466: {"Ideographic"},
    95467: {"Ideographic"},
    95468: {"Ideographic"},
    95469: {"Ideographic"},
    95470: {"Ideographic"},
    95471: {"Ideographic"},
    95472: {"Ideographic"},
    95473: {"Ideographic"},
    95474: {"Ideographic"},
    95475: {"Ideographic"},
    95476: {"Ideographic"},
    95477: {"Ideographic"},
    95478: {"Ideographic"},
    95479: {"Ideographic"},
    95480: {"Ideographic"},
    95481: {"Ideographic"},
    95482: {"Ideographic"},
    95483: {"Ideographic"},
    95484: {"Ideographic"},
    95485: {"Ideographic"},
    95486: {"Ideographic"},
    95487: {"Ideographic"},
    95488: {"Ideographic"},
    95489: {"Ideographic"},
    95490: {"Ideographic"},
    95491: {"Ideographic"},
    95492: {"Ideographic"},
    95493: {"Ideographic"},
    95494: {"Ideographic"},
    95495: {"Ideographic"},
    95496: {"Ideographic"},
    95497: {"Ideographic"},
    95498: {"Ideographic"},
    95499: {"Ideographic"},
    95500: {"Ideographic"},
    95501: {"Ideographic"},
    95502: {"Ideographic"},
    95503: {"Ideographic"},
    95504: {"Ideographic"},
    95505: {"Ideographic"},
    95506: {"Ideographic"},
    95507: {"Ideographic"},
    95508: {"Ideographic"},
    95509: {"Ideographic"},
    95510: {"Ideographic"},
    95511: {"Ideographic"},
    95512: {"Ideographic"},
    95513: {"Ideographic"},
    95514: {"Ideographic"},
    95515: {"Ideographic"},
    95516: {"Ideographic"},
    95517: {"Ideographic"},
    95518: {"Ideographic"},
    95519: {"Ideographic"},
    95520: {"Ideographic"},
    95521: {"Ideographic"},
    95522: {"Ideographic"},
    95523: {"Ideographic"},
    95524: {"Ideographic"},
    95525: {"Ideographic"},
    95526: {"Ideographic"},
    95527: {"Ideographic"},
    95528: {"Ideographic"},
    95529: {"Ideographic"},
    95530: {"Ideographic"},
    95531: {"Ideographic"},
    95532: {"Ideographic"},
    95533: {"Ideographic"},
    95534: {"Ideographic"},
    95535: {"Ideographic"},
    95536: {"Ideographic"},
    95537: {"Ideographic"},
    95538: {"Ideographic"},
    95539: {"Ideographic"},
    95540: {"Ideographic"},
    95541: {"Ideographic"},
    95542: {"Ideographic"},
    95543: {"Ideographic"},
    95544: {"Ideographic"},
    95545: {"Ideographic"},
    95546: {"Ideographic"},
    95547: {"Ideographic"},
    95548: {"Ideographic"},
    95549: {"Ideographic"},
    95550: {"Ideographic"},
    95551: {"Ideographic"},
    95552: {"Ideographic"},
    95553: {"Ideographic"},
    95554: {"Ideographic"},
    95555: {"Ideographic"},
    95556: {"Ideographic"},
    95557: {"Ideographic"},
    95558: {"Ideographic"},
    95559: {"Ideographic"},
    95560: {"Ideographic"},
    95561: {"Ideographic"},
    95562: {"Ideographic"},
    95563: {"Ideographic"},
    95564: {"Ideographic"},
    95565: {"Ideographic"},
    95566: {"Ideographic"},
    95567: {"Ideographic"},
    95568: {"Ideographic"},
    95569: {"Ideographic"},
    95570: {"Ideographic"},
    95571: {"Ideographic"},
    95572: {"Ideographic"},
    95573: {"Ideographic"},
    95574: {"Ideographic"},
    95575: {"Ideographic"},
    95576: {"Ideographic"},
    95577: {"Ideographic"},
    95578: {"Ideographic"},
    95579: {"Ideographic"},
    95580: {"Ideographic"},
    95581: {"Ideographic"},
    95582: {"Ideographic"},
    95583: {"Ideographic"},
    95584: {"Ideographic"},
    95585: {"Ideographic"},
    95586: {"Ideographic"},
    95587: {"Ideographic"},
    95588: {"Ideographic"},
    95589: {"Ideographic"},
    95590: {"Ideographic"},
    95591: {"Ideographic"},
    95592: {"Ideographic"},
    95593: {"Ideographic"},
    95594: {"Ideographic"},
    95595: {"Ideographic"},
    95596: {"Ideographic"},
    95597: {"Ideographic"},
    95598: {"Ideographic"},
    95599: {"Ideographic"},
    95600: {"Ideographic"},
    95601: {"Ideographic"},
    95602: {"Ideographic"},
    95603: {"Ideographic"},
    95604: {"Ideographic"},
    95605: {"Ideographic"},
    95606: {"Ideographic"},
    95607: {"Ideographic"},
    95608: {"Ideographic"},
    95609: {"Ideographic"},
    95610: {"Ideographic"},
    95611: {"Ideographic"},
    95612: {"Ideographic"},
    95613: {"Ideographic"},
    95614: {"Ideographic"},
    95615: {"Ideographic"},
    95616: {"Ideographic"},
    95617: {"Ideographic"},
    95618: {"Ideographic"},
    95619: {"Ideographic"},
    95620: {"Ideographic"},
    95621: {"Ideographic"},
    95622: {"Ideographic"},
    95623: {"Ideographic"},
    95624: {"Ideographic"},
    95625: {"Ideographic"},
    95626: {"Ideographic"},
    95627: {"Ideographic"},
    95628: {"Ideographic"},
    95629: {"Ideographic"},
    95630: {"Ideographic"},
    95631: {"Ideographic"},
    95632: {"Ideographic"},
    95633: {"Ideographic"},
    95634: {"Ideographic"},
    95635: {"Ideographic"},
    95636: {"Ideographic"},
    95637: {"Ideographic"},
    95638: {"Ideographic"},
    95639: {"Ideographic"},
    95640: {"Ideographic"},
    95641: {"Ideographic"},
    95642: {"Ideographic"},
    95643: {"Ideographic"},
    95644: {"Ideographic"},
    95645: {"Ideographic"},
    95646: {"Ideographic"},
    95647: {"Ideographic"},
    95648: {"Ideographic"},
    95649: {"Ideographic"},
    95650: {"Ideographic"},
    95651: {"Ideographic"},
    95652: {"Ideographic"},
    95653: {"Ideographic"},
    95654: {"Ideographic"},
    95655: {"Ideographic"},
    95656: {"Ideographic"},
    95657: {"Ideographic"},
    95658: {"Ideographic"},
    95659: {"Ideographic"},
    95660: {"Ideographic"},
    95661: {"Ideographic"},
    95662: {"Ideographic"},
    95663: {"Ideographic"},
    95664: {"Ideographic"},
    95665: {"Ideographic"},
    95666: {"Ideographic"},
    95667: {"Ideographic"},
    95668: {"Ideographic"},
    95669: {"Ideographic"},
    95670: {"Ideographic"},
    95671: {"Ideographic"},
    95672: {"Ideographic"},
    95673: {"Ideographic"},
    95674: {"Ideographic"},
    95675: {"Ideographic"},
    95676: {"Ideographic"},
    95677: {"Ideographic"},
    95678: {"Ideographic"},
    95679: {"Ideographic"},
    95680: {"Ideographic"},
    95681: {"Ideographic"},
    95682: {"Ideographic"},
    95683: {"Ideographic"},
    95684: {"Ideographic"},
    95685: {"Ideographic"},
    95686: {"Ideographic"},
    95687: {"Ideographic"},
    95688: {"Ideographic"},
    95689: {"Ideographic"},
    95690: {"Ideographic"},
    95691: {"Ideographic"},
    95692: {"Ideographic"},
    95693: {"Ideographic"},
    95694: {"Ideographic"},
    95695: {"Ideographic"},
    95696: {"Ideographic"},
    95697: {"Ideographic"},
    95698: {"Ideographic"},
    95699: {"Ideographic"},
    95700: {"Ideographic"},
    95701: {"Ideographic"},
    95702: {"Ideographic"},
    95703: {"Ideographic"},
    95704: {"Ideographic"},
    95705: {"Ideographic"},
    95706: {"Ideographic"},
    95707: {"Ideographic"},
    95708: {"Ideographic"},
    95709: {"Ideographic"},
    95710: {"Ideographic"},
    95711: {"Ideographic"},
    95712: {"Ideographic"},
    95713: {"Ideographic"},
    95714: {"Ideographic"},
    95715: {"Ideographic"},
    95716: {"Ideographic"},
    95717: {"Ideographic"},
    95718: {"Ideographic"},
    95719: {"Ideographic"},
    95720: {"Ideographic"},
    95721: {"Ideographic"},
    95722: {"Ideographic"},
    95723: {"Ideographic"},
    95724: {"Ideographic"},
    95725: {"Ideographic"},
    95726: {"Ideographic"},
    95727: {"Ideographic"},
    95728: {"Ideographic"},
    95729: {"Ideographic"},
    95730: {"Ideographic"},
    95731: {"Ideographic"},
    95732: {"Ideographic"},
    95733: {"Ideographic"},
    95734: {"Ideographic"},
    95735: {"Ideographic"},
    95736: {"Ideographic"},
    95737: {"Ideographic"},
    95738: {"Ideographic"},
    95739: {"Ideographic"},
    95740: {"Ideographic"},
    95741: {"Ideographic"},
    95742: {"Ideographic"},
    95743: {"Ideographic"},
    95744: {"Ideographic"},
    95745: {"Ideographic"},
    95746: {"Ideographic"},
    95747: {"Ideographic"},
    95748: {"Ideographic"},
    95749: {"Ideographic"},
    95750: {"Ideographic"},
    95751: {"Ideographic"},
    95752: {"Ideographic"},
    95753: {"Ideographic"},
    95754: {"Ideographic"},
    95755: {"Ideographic"},
    95756: {"Ideographic"},
    95757: {"Ideographic"},
    95758: {"Ideographic"},
    95759: {"Ideographic"},
    95760: {"Ideographic"},
    95761: {"Ideographic"},
    95762: {"Ideographic"},
    95763: {"Ideographic"},
    95764: {"Ideographic"},
    95765: {"Ideographic"},
    95766: {"Ideographic"},
    95767: {"Ideographic"},
    95768: {"Ideographic"},
    95769: {"Ideographic"},
    95770: {"Ideographic"},
    95771: {"Ideographic"},
    95772: {"Ideographic"},
    95773: {"Ideographic"},
    95774: {"Ideographic"},
    95775: {"Ideographic"},
    95776: {"Ideographic"},
    95777: {"Ideographic"},
    95778: {"Ideographic"},
    95779: {"Ideographic"},
    95780: {"Ideographic"},
    95781: {"Ideographic"},
    95782: {"Ideographic"},
    95783: {"Ideographic"},
    95784: {"Ideographic"},
    95785: {"Ideographic"},
    95786: {"Ideographic"},
    95787: {"Ideographic"},
    95788: {"Ideographic"},
    95789: {"Ideographic"},
    95790: {"Ideographic"},
    95791: {"Ideographic"},
    95792: {"Ideographic"},
    95793: {"Ideographic"},
    95794: {"Ideographic"},
    95795: {"Ideographic"},
    95796: {"Ideographic"},
    95797: {"Ideographic"},
    95798: {"Ideographic"},
    95799: {"Ideographic"},
    95800: {"Ideographic"},
    95801: {"Ideographic"},
    95802: {"Ideographic"},
    95803: {"Ideographic"},
    95804: {"Ideographic"},
    95805: {"Ideographic"},
    95806: {"Ideographic"},
    95807: {"Ideographic"},
    95808: {"Ideographic"},
    95809: {"Ideographic"},
    95810: {"Ideographic"},
    95811: {"Ideographic"},
    95812: {"Ideographic"},
    95813: {"Ideographic"},
    95814: {"Ideographic"},
    95815: {"Ideographic"},
    95816: {"Ideographic"},
    95817: {"Ideographic"},
    95818: {"Ideographic"},
    95819: {"Ideographic"},
    95820: {"Ideographic"},
    95821: {"Ideographic"},
    95822: {"Ideographic"},
    95823: {"Ideographic"},
    95824: {"Ideographic"},
    95825: {"Ideographic"},
    95826: {"Ideographic"},
    95827: {"Ideographic"},
    95828: {"Ideographic"},
    95829: {"Ideographic"},
    95830: {"Ideographic"},
    95831: {"Ideographic"},
    95832: {"Ideographic"},
    95833: {"Ideographic"},
    95834: {"Ideographic"},
    95835: {"Ideographic"},
    95836: {"Ideographic"},
    95837: {"Ideographic"},
    95838: {"Ideographic"},
    95839: {"Ideographic"},
    95840: {"Ideographic"},
    95841: {"Ideographic"},
    95842: {"Ideographic"},
    95843: {"Ideographic"},
    95844: {"Ideographic"},
    95845: {"Ideographic"},
    95846: {"Ideographic"},
    95847: {"Ideographic"},
    95848: {"Ideographic"},
    95849: {"Ideographic"},
    95850: {"Ideographic"},
    95851: {"Ideographic"},
    95852: {"Ideographic"},
    95853: {"Ideographic"},
    95854: {"Ideographic"},
    95855: {"Ideographic"},
    95856: {"Ideographic"},
    95857: {"Ideographic"},
    95858: {"Ideographic"},
    95859: {"Ideographic"},
    95860: {"Ideographic"},
    95861: {"Ideographic"},
    95862: {"Ideographic"},
    95863: {"Ideographic"},
    95864: {"Ideographic"},
    95865: {"Ideographic"},
    95866: {"Ideographic"},
    95867: {"Ideographic"},
    95868: {"Ideographic"},
    95869: {"Ideographic"},
    95870: {"Ideographic"},
    95871: {"Ideographic"},
    95872: {"Ideographic"},
    95873: {"Ideographic"},
    95874: {"Ideographic"},
    95875: {"Ideographic"},
    95876: {"Ideographic"},
    95877: {"Ideographic"},
    95878: {"Ideographic"},
    95879: {"Ideographic"},
    95880: {"Ideographic"},
    95881: {"Ideographic"},
    95882: {"Ideographic"},
    95883: {"Ideographic"},
    95884: {"Ideographic"},
    95885: {"Ideographic"},
    95886: {"Ideographic"},
    95887: {"Ideographic"},
    95888: {"Ideographic"},
    95889: {"Ideographic"},
    95890: {"Ideographic"},
    95891: {"Ideographic"},
    95892: {"Ideographic"},
    95893: {"Ideographic"},
    95894: {"Ideographic"},
    95895: {"Ideographic"},
    95896: {"Ideographic"},
    95897: {"Ideographic"},
    95898: {"Ideographic"},
    95899: {"Ideographic"},
    95900: {"Ideographic"},
    95901: {"Ideographic"},
    95902: {"Ideographic"},
    95903: {"Ideographic"},
    95904: {"Ideographic"},
    95905: {"Ideographic"},
    95906: {"Ideographic"},
    95907: {"Ideographic"},
    95908: {"Ideographic"},
    95909: {"Ideographic"},
    95910: {"Ideographic"},
    95911: {"Ideographic"},
    95912: {"Ideographic"},
    95913: {"Ideographic"},
    95914: {"Ideographic"},
    95915: {"Ideographic"},
    95916: {"Ideographic"},
    95917: {"Ideographic"},
    95918: {"Ideographic"},
    95919: {"Ideographic"},
    95920: {"Ideographic"},
    95921: {"Ideographic"},
    95922: {"Ideographic"},
    95923: {"Ideographic"},
    95924: {"Ideographic"},
    95925: {"Ideographic"},
    95926: {"Ideographic"},
    95927: {"Ideographic"},
    95928: {"Ideographic"},
    95929: {"Ideographic"},
    95930: {"Ideographic"},
    95931: {"Ideographic"},
    95932: {"Ideographic"},
    95933: {"Ideographic"},
    95934: {"Ideographic"},
    95935: {"Ideographic"},
    95936: {"Ideographic"},
    95937: {"Ideographic"},
    95938: {"Ideographic"},
    95939: {"Ideographic"},
    95940: {"Ideographic"},
    95941: {"Ideographic"},
    95942: {"Ideographic"},
    95943: {"Ideographic"},
    95944: {"Ideographic"},
    95945: {"Ideographic"},
    95946: {"Ideographic"},
    95947: {"Ideographic"},
    95948: {"Ideographic"},
    95949: {"Ideographic"},
    95950: {"Ideographic"},
    95951: {"Ideographic"},
    95952: {"Ideographic"},
    95953: {"Ideographic"},
    95954: {"Ideographic"},
    95955: {"Ideographic"},
    95956: {"Ideographic"},
    95957: {"Ideographic"},
    95958: {"Ideographic"},
    95959: {"Ideographic"},
    95960: {"Ideographic"},
    95961: {"Ideographic"},
    95962: {"Ideographic"},
    95963: {"Ideographic"},
    95964: {"Ideographic"},
    95965: {"Ideographic"},
    95966: {"Ideographic"},
    95967: {"Ideographic"},
    95968: {"Ideographic"},
    95969: {"Ideographic"},
    95970: {"Ideographic"},
    95971: {"Ideographic"},
    95972: {"Ideographic"},
    95973: {"Ideographic"},
    95974: {"Ideographic"},
    95975: {"Ideographic"},
    95976: {"Ideographic"},
    95977: {"Ideographic"},
    95978: {"Ideographic"},
    95979: {"Ideographic"},
    95980: {"Ideographic"},
    95981: {"Ideographic"},
    95982: {"Ideographic"},
    95983: {"Ideographic"},
    95984: {"Ideographic"},
    95985: {"Ideographic"},
    95986: {"Ideographic"},
    95987: {"Ideographic"},
    95988: {"Ideographic"},
    95989: {"Ideographic"},
    95990: {"Ideographic"},
    95991: {"Ideographic"},
    95992: {"Ideographic"},
    95993: {"Ideographic"},
    95994: {"Ideographic"},
    95995: {"Ideographic"},
    95996: {"Ideographic"},
    95997: {"Ideographic"},
    95998: {"Ideographic"},
    95999: {"Ideographic"},
    96000: {"Ideographic"},
    96001: {"Ideographic"},
    96002: {"Ideographic"},
    96003: {"Ideographic"},
    96004: {"Ideographic"},
    96005: {"Ideographic"},
    96006: {"Ideographic"},
    96007: {"Ideographic"},
    96008: {"Ideographic"},
    96009: {"Ideographic"},
    96010: {"Ideographic"},
    96011: {"Ideographic"},
    96012: {"Ideographic"},
    96013: {"Ideographic"},
    96014: {"Ideographic"},
    96015: {"Ideographic"},
    96016: {"Ideographic"},
    96017: {"Ideographic"},
    96018: {"Ideographic"},
    96019: {"Ideographic"},
    96020: {"Ideographic"},
    96021: {"Ideographic"},
    96022: {"Ideographic"},
    96023: {"Ideographic"},
    96024: {"Ideographic"},
    96025: {"Ideographic"},
    96026: {"Ideographic"},
    96027: {"Ideographic"},
    96028: {"Ideographic"},
    96029: {"Ideographic"},
    96030: {"Ideographic"},
    96031: {"Ideographic"},
    96032: {"Ideographic"},
    96033: {"Ideographic"},
    96034: {"Ideographic"},
    96035: {"Ideographic"},
    96036: {"Ideographic"},
    96037: {"Ideographic"},
    96038: {"Ideographic"},
    96039: {"Ideographic"},
    96040: {"Ideographic"},
    96041: {"Ideographic"},
    96042: {"Ideographic"},
    96043: {"Ideographic"},
    96044: {"Ideographic"},
    96045: {"Ideographic"},
    96046: {"Ideographic"},
    96047: {"Ideographic"},
    96048: {"Ideographic"},
    96049: {"Ideographic"},
    96050: {"Ideographic"},
    96051: {"Ideographic"},
    96052: {"Ideographic"},
    96053: {"Ideographic"},
    96054: {"Ideographic"},
    96055: {"Ideographic"},
    96056: {"Ideographic"},
    96057: {"Ideographic"},
    96058: {"Ideographic"},
    96059: {"Ideographic"},
    96060: {"Ideographic"},
    96061: {"Ideographic"},
    96062: {"Ideographic"},
    96063: {"Ideographic"},
    96064: {"Ideographic"},
    96065: {"Ideographic"},
    96066: {"Ideographic"},
    96067: {"Ideographic"},
    96068: {"Ideographic"},
    96069: {"Ideographic"},
    96070: {"Ideographic"},
    96071: {"Ideographic"},
    96072: {"Ideographic"},
    96073: {"Ideographic"},
    96074: {"Ideographic"},
    96075: {"Ideographic"},
    96076: {"Ideographic"},
    96077: {"Ideographic"},
    96078: {"Ideographic"},
    96079: {"Ideographic"},
    96080: {"Ideographic"},
    96081: {"Ideographic"},
    96082: {"Ideographic"},
    96083: {"Ideographic"},
    96084: {"Ideographic"},
    96085: {"Ideographic"},
    96086: {"Ideographic"},
    96087: {"Ideographic"},
    96088: {"Ideographic"},
    96089: {"Ideographic"},
    96090: {"Ideographic"},
    96091: {"Ideographic"},
    96092: {"Ideographic"},
    96093: {"Ideographic"},
    96094: {"Ideographic"},
    96095: {"Ideographic"},
    96096: {"Ideographic"},
    96097: {"Ideographic"},
    96098: {"Ideographic"},
    96099: {"Ideographic"},
    96100: {"Ideographic"},
    96101: {"Ideographic"},
    96102: {"Ideographic"},
    96103: {"Ideographic"},
    96104: {"Ideographic"},
    96105: {"Ideographic"},
    96106: {"Ideographic"},
    96107: {"Ideographic"},
    96108: {"Ideographic"},
    96109: {"Ideographic"},
    96110: {"Ideographic"},
    96111: {"Ideographic"},
    96112: {"Ideographic"},
    96113: {"Ideographic"},
    96114: {"Ideographic"},
    96115: {"Ideographic"},
    96116: {"Ideographic"},
    96117: {"Ideographic"},
    96118: {"Ideographic"},
    96119: {"Ideographic"},
    96120: {"Ideographic"},
    96121: {"Ideographic"},
    96122: {"Ideographic"},
    96123: {"Ideographic"},
    96124: {"Ideographic"},
    96125: {"Ideographic"},
    96126: {"Ideographic"},
    96127: {"Ideographic"},
    96128: {"Ideographic"},
    96129: {"Ideographic"},
    96130: {"Ideographic"},
    96131: {"Ideographic"},
    96132: {"Ideographic"},
    96133: {"Ideographic"},
    96134: {"Ideographic"},
    96135: {"Ideographic"},
    96136: {"Ideographic"},
    96137: {"Ideographic"},
    96138: {"Ideographic"},
    96139: {"Ideographic"},
    96140: {"Ideographic"},
    96141: {"Ideographic"},
    96142: {"Ideographic"},
    96143: {"Ideographic"},
    96144: {"Ideographic"},
    96145: {"Ideographic"},
    96146: {"Ideographic"},
    96147: {"Ideographic"},
    96148: {"Ideographic"},
    96149: {"Ideographic"},
    96150: {"Ideographic"},
    96151: {"Ideographic"},
    96152: {"Ideographic"},
    96153: {"Ideographic"},
    96154: {"Ideographic"},
    96155: {"Ideographic"},
    96156: {"Ideographic"},
    96157: {"Ideographic"},
    96158: {"Ideographic"},
    96159: {"Ideographic"},
    96160: {"Ideographic"},
    96161: {"Ideographic"},
    96162: {"Ideographic"},
    96163: {"Ideographic"},
    96164: {"Ideographic"},
    96165: {"Ideographic"},
    96166: {"Ideographic"},
    96167: {"Ideographic"},
    96168: {"Ideographic"},
    96169: {"Ideographic"},
    96170: {"Ideographic"},
    96171: {"Ideographic"},
    96172: {"Ideographic"},
    96173: {"Ideographic"},
    96174: {"Ideographic"},
    96175: {"Ideographic"},
    96176: {"Ideographic"},
    96177: {"Ideographic"},
    96178: {"Ideographic"},
    96179: {"Ideographic"},
    96180: {"Ideographic"},
    96181: {"Ideographic"},
    96182: {"Ideographic"},
    96183: {"Ideographic"},
    96184: {"Ideographic"},
    96185: {"Ideographic"},
    96186: {"Ideographic"},
    96187: {"Ideographic"},
    96188: {"Ideographic"},
    96189: {"Ideographic"},
    96190: {"Ideographic"},
    96191: {"Ideographic"},
    96192: {"Ideographic"},
    96193: {"Ideographic"},
    96194: {"Ideographic"},
    96195: {"Ideographic"},
    96196: {"Ideographic"},
    96197: {"Ideographic"},
    96198: {"Ideographic"},
    96199: {"Ideographic"},
    96200: {"Ideographic"},
    96201: {"Ideographic"},
    96202: {"Ideographic"},
    96203: {"Ideographic"},
    96204: {"Ideographic"},
    96205: {"Ideographic"},
    96206: {"Ideographic"},
    96207: {"Ideographic"},
    96208: {"Ideographic"},
    96209: {"Ideographic"},
    96210: {"Ideographic"},
    96211: {"Ideographic"},
    96212: {"Ideographic"},
    96213: {"Ideographic"},
    96214: {"Ideographic"},
    96215: {"Ideographic"},
    96216: {"Ideographic"},
    96217: {"Ideographic"},
    96218: {"Ideographic"},
    96219: {"Ideographic"},
    96220: {"Ideographic"},
    96221: {"Ideographic"},
    96222: {"Ideographic"},
    96223: {"Ideographic"},
    96224: {"Ideographic"},
    96225: {"Ideographic"},
    96226: {"Ideographic"},
    96227: {"Ideographic"},
    96228: {"Ideographic"},
    96229: {"Ideographic"},
    96230: {"Ideographic"},
    96231: {"Ideographic"},
    96232: {"Ideographic"},
    96233: {"Ideographic"},
    96234: {"Ideographic"},
    96235: {"Ideographic"},
    96236: {"Ideographic"},
    96237: {"Ideographic"},
    96238: {"Ideographic"},
    96239: {"Ideographic"},
    96240: {"Ideographic"},
    96241: {"Ideographic"},
    96242: {"Ideographic"},
    96243: {"Ideographic"},
    96244: {"Ideographic"},
    96245: {"Ideographic"},
    96246: {"Ideographic"},
    96247: {"Ideographic"},
    96248: {"Ideographic"},
    96249: {"Ideographic"},
    96250: {"Ideographic"},
    96251: {"Ideographic"},
    96252: {"Ideographic"},
    96253: {"Ideographic"},
    96254: {"Ideographic"},
    96255: {"Ideographic"},
    96256: {"Ideographic"},
    96257: {"Ideographic"},
    96258: {"Ideographic"},
    96259: {"Ideographic"},
    96260: {"Ideographic"},
    96261: {"Ideographic"},
    96262: {"Ideographic"},
    96263: {"Ideographic"},
    96264: {"Ideographic"},
    96265: {"Ideographic"},
    96266: {"Ideographic"},
    96267: {"Ideographic"},
    96268: {"Ideographic"},
    96269: {"Ideographic"},
    96270: {"Ideographic"},
    96271: {"Ideographic"},
    96272: {"Ideographic"},
    96273: {"Ideographic"},
    96274: {"Ideographic"},
    96275: {"Ideographic"},
    96276: {"Ideographic"},
    96277: {"Ideographic"},
    96278: {"Ideographic"},
    96279: {"Ideographic"},
    96280: {"Ideographic"},
    96281: {"Ideographic"},
    96282: {"Ideographic"},
    96283: {"Ideographic"},
    96284: {"Ideographic"},
    96285: {"Ideographic"},
    96286: {"Ideographic"},
    96287: {"Ideographic"},
    96288: {"Ideographic"},
    96289: {"Ideographic"},
    96290: {"Ideographic"},
    96291: {"Ideographic"},
    96292: {"Ideographic"},
    96293: {"Ideographic"},
    96294: {"Ideographic"},
    96295: {"Ideographic"},
    96296: {"Ideographic"},
    96297: {"Ideographic"},
    96298: {"Ideographic"},
    96299: {"Ideographic"},
    96300: {"Ideographic"},
    96301: {"Ideographic"},
    96302: {"Ideographic"},
    96303: {"Ideographic"},
    96304: {"Ideographic"},
    96305: {"Ideographic"},
    96306: {"Ideographic"},
    96307: {"Ideographic"},
    96308: {"Ideographic"},
    96309: {"Ideographic"},
    96310: {"Ideographic"},
    96311: {"Ideographic"},
    96312: {"Ideographic"},
    96313: {"Ideographic"},
    96314: {"Ideographic"},
    96315: {"Ideographic"},
    96316: {"Ideographic"},
    96317: {"Ideographic"},
    96318: {"Ideographic"},
    96319: {"Ideographic"},
    96320: {"Ideographic"},
    96321: {"Ideographic"},
    96322: {"Ideographic"},
    96323: {"Ideographic"},
    96324: {"Ideographic"},
    96325: {"Ideographic"},
    96326: {"Ideographic"},
    96327: {"Ideographic"},
    96328: {"Ideographic"},
    96329: {"Ideographic"},
    96330: {"Ideographic"},
    96331: {"Ideographic"},
    96332: {"Ideographic"},
    96333: {"Ideographic"},
    96334: {"Ideographic"},
    96335: {"Ideographic"},
    96336: {"Ideographic"},
    96337: {"Ideographic"},
    96338: {"Ideographic"},
    96339: {"Ideographic"},
    96340: {"Ideographic"},
    96341: {"Ideographic"},
    96342: {"Ideographic"},
    96343: {"Ideographic"},
    96344: {"Ideographic"},
    96345: {"Ideographic"},
    96346: {"Ideographic"},
    96347: {"Ideographic"},
    96348: {"Ideographic"},
    96349: {"Ideographic"},
    96350: {"Ideographic"},
    96351: {"Ideographic"},
    96352: {"Ideographic"},
    96353: {"Ideographic"},
    96354: {"Ideographic"},
    96355: {"Ideographic"},
    96356: {"Ideographic"},
    96357: {"Ideographic"},
    96358: {"Ideographic"},
    96359: {"Ideographic"},
    96360: {"Ideographic"},
    96361: {"Ideographic"},
    96362: {"Ideographic"},
    96363: {"Ideographic"},
    96364: {"Ideographic"},
    96365: {"Ideographic"},
    96366: {"Ideographic"},
    96367: {"Ideographic"},
    96368: {"Ideographic"},
    96369: {"Ideographic"},
    96370: {"Ideographic"},
    96371: {"Ideographic"},
    96372: {"Ideographic"},
    96373: {"Ideographic"},
    96374: {"Ideographic"},
    96375: {"Ideographic"},
    96376: {"Ideographic"},
    96377: {"Ideographic"},
    96378: {"Ideographic"},
    96379: {"Ideographic"},
    96380: {"Ideographic"},
    96381: {"Ideographic"},
    96382: {"Ideographic"},
    96383: {"Ideographic"},
    96384: {"Ideographic"},
    96385: {"Ideographic"},
    96386: {"Ideographic"},
    96387: {"Ideographic"},
    96388: {"Ideographic"},
    96389: {"Ideographic"},
    96390: {"Ideographic"},
    96391: {"Ideographic"},
    96392: {"Ideographic"},
    96393: {"Ideographic"},
    96394: {"Ideographic"},
    96395: {"Ideographic"},
    96396: {"Ideographic"},
    96397: {"Ideographic"},
    96398: {"Ideographic"},
    96399: {"Ideographic"},
    96400: {"Ideographic"},
    96401: {"Ideographic"},
    96402: {"Ideographic"},
    96403: {"Ideographic"},
    96404: {"Ideographic"},
    96405: {"Ideographic"},
    96406: {"Ideographic"},
    96407: {"Ideographic"},
    96408: {"Ideographic"},
    96409: {"Ideographic"},
    96410: {"Ideographic"},
    96411: {"Ideographic"},
    96412: {"Ideographic"},
    96413: {"Ideographic"},
    96414: {"Ideographic"},
    96415: {"Ideographic"},
    96416: {"Ideographic"},
    96417: {"Ideographic"},
    96418: {"Ideographic"},
    96419: {"Ideographic"},
    96420: {"Ideographic"},
    96421: {"Ideographic"},
    96422: {"Ideographic"},
    96423: {"Ideographic"},
    96424: {"Ideographic"},
    96425: {"Ideographic"},
    96426: {"Ideographic"},
    96427: {"Ideographic"},
    96428: {"Ideographic"},
    96429: {"Ideographic"},
    96430: {"Ideographic"},
    96431: {"Ideographic"},
    96432: {"Ideographic"},
    96433: {"Ideographic"},
    96434: {"Ideographic"},
    96435: {"Ideographic"},
    96436: {"Ideographic"},
    96437: {"Ideographic"},
    96438: {"Ideographic"},
    96439: {"Ideographic"},
    96440: {"Ideographic"},
    96441: {"Ideographic"},
    96442: {"Ideographic"},
    96443: {"Ideographic"},
    96444: {"Ideographic"},
    96445: {"Ideographic"},
    96446: {"Ideographic"},
    96447: {"Ideographic"},
    96448: {"Ideographic"},
    96449: {"Ideographic"},
    96450: {"Ideographic"},
    96451: {"Ideographic"},
    96452: {"Ideographic"},
    96453: {"Ideographic"},
    96454: {"Ideographic"},
    96455: {"Ideographic"},
    96456: {"Ideographic"},
    96457: {"Ideographic"},
    96458: {"Ideographic"},
    96459: {"Ideographic"},
    96460: {"Ideographic"},
    96461: {"Ideographic"},
    96462: {"Ideographic"},
    96463: {"Ideographic"},
    96464: {"Ideographic"},
    96465: {"Ideographic"},
    96466: {"Ideographic"},
    96467: {"Ideographic"},
    96468: {"Ideographic"},
    96469: {"Ideographic"},
    96470: {"Ideographic"},
    96471: {"Ideographic"},
    96472: {"Ideographic"},
    96473: {"Ideographic"},
    96474: {"Ideographic"},
    96475: {"Ideographic"},
    96476: {"Ideographic"},
    96477: {"Ideographic"},
    96478: {"Ideographic"},
    96479: {"Ideographic"},
    96480: {"Ideographic"},
    96481: {"Ideographic"},
    96482: {"Ideographic"},
    96483: {"Ideographic"},
    96484: {"Ideographic"},
    96485: {"Ideographic"},
    96486: {"Ideographic"},
    96487: {"Ideographic"},
    96488: {"Ideographic"},
    96489: {"Ideographic"},
    96490: {"Ideographic"},
    96491: {"Ideographic"},
    96492: {"Ideographic"},
    96493: {"Ideographic"},
    96494: {"Ideographic"},
    96495: {"Ideographic"},
    96496: {"Ideographic"},
    96497: {"Ideographic"},
    96498: {"Ideographic"},
    96499: {"Ideographic"},
    96500: {"Ideographic"},
    96501: {"Ideographic"},
    96502: {"Ideographic"},
    96503: {"Ideographic"},
    96504: {"Ideographic"},
    96505: {"Ideographic"},
    96506: {"Ideographic"},
    96507: {"Ideographic"},
    96508: {"Ideographic"},
    96509: {"Ideographic"},
    96510: {"Ideographic"},
    96511: {"Ideographic"},
    96512: {"Ideographic"},
    96513: {"Ideographic"},
    96514: {"Ideographic"},
    96515: {"Ideographic"},
    96516: {"Ideographic"},
    96517: {"Ideographic"},
    96518: {"Ideographic"},
    96519: {"Ideographic"},
    96520: {"Ideographic"},
    96521: {"Ideographic"},
    96522: {"Ideographic"},
    96523: {"Ideographic"},
    96524: {"Ideographic"},
    96525: {"Ideographic"},
    96526: {"Ideographic"},
    96527: {"Ideographic"},
    96528: {"Ideographic"},
    96529: {"Ideographic"},
    96530: {"Ideographic"},
    96531: {"Ideographic"},
    96532: {"Ideographic"},
    96533: {"Ideographic"},
    96534: {"Ideographic"},
    96535: {"Ideographic"},
    96536: {"Ideographic"},
    96537: {"Ideographic"},
    96538: {"Ideographic"},
    96539: {"Ideographic"},
    96540: {"Ideographic"},
    96541: {"Ideographic"},
    96542: {"Ideographic"},
    96543: {"Ideographic"},
    96544: {"Ideographic"},
    96545: {"Ideographic"},
    96546: {"Ideographic"},
    96547: {"Ideographic"},
    96548: {"Ideographic"},
    96549: {"Ideographic"},
    96550: {"Ideographic"},
    96551: {"Ideographic"},
    96552: {"Ideographic"},
    96553: {"Ideographic"},
    96554: {"Ideographic"},
    96555: {"Ideographic"},
    96556: {"Ideographic"},
    96557: {"Ideographic"},
    96558: {"Ideographic"},
    96559: {"Ideographic"},
    96560: {"Ideographic"},
    96561: {"Ideographic"},
    96562: {"Ideographic"},
    96563: {"Ideographic"},
    96564: {"Ideographic"},
    96565: {"Ideographic"},
    96566: {"Ideographic"},
    96567: {"Ideographic"},
    96568: {"Ideographic"},
    96569: {"Ideographic"},
    96570: {"Ideographic"},
    96571: {"Ideographic"},
    96572: {"Ideographic"},
    96573: {"Ideographic"},
    96574: {"Ideographic"},
    96575: {"Ideographic"},
    96576: {"Ideographic"},
    96577: {"Ideographic"},
    96578: {"Ideographic"},
    96579: {"Ideographic"},
    96580: {"Ideographic"},
    96581: {"Ideographic"},
    96582: {"Ideographic"},
    96583: {"Ideographic"},
    96584: {"Ideographic"},
    96585: {"Ideographic"},
    96586: {"Ideographic"},
    96587: {"Ideographic"},
    96588: {"Ideographic"},
    96589: {"Ideographic"},
    96590: {"Ideographic"},
    96591: {"Ideographic"},
    96592: {"Ideographic"},
    96593: {"Ideographic"},
    96594: {"Ideographic"},
    96595: {"Ideographic"},
    96596: {"Ideographic"},
    96597: {"Ideographic"},
    96598: {"Ideographic"},
    96599: {"Ideographic"},
    96600: {"Ideographic"},
    96601: {"Ideographic"},
    96602: {"Ideographic"},
    96603: {"Ideographic"},
    96604: {"Ideographic"},
    96605: {"Ideographic"},
    96606: {"Ideographic"},
    96607: {"Ideographic"},
    96608: {"Ideographic"},
    96609: {"Ideographic"},
    96610: {"Ideographic"},
    96611: {"Ideographic"},
    96612: {"Ideographic"},
    96613: {"Ideographic"},
    96614: {"Ideographic"},
    96615: {"Ideographic"},
    96616: {"Ideographic"},
    96617: {"Ideographic"},
    96618: {"Ideographic"},
    96619: {"Ideographic"},
    96620: {"Ideographic"},
    96621: {"Ideographic"},
    96622: {"Ideographic"},
    96623: {"Ideographic"},
    96624: {"Ideographic"},
    96625: {"Ideographic"},
    96626: {"Ideographic"},
    96627: {"Ideographic"},
    96628: {"Ideographic"},
    96629: {"Ideographic"},
    96630: {"Ideographic"},
    96631: {"Ideographic"},
    96632: {"Ideographic"},
    96633: {"Ideographic"},
    96634: {"Ideographic"},
    96635: {"Ideographic"},
    96636: {"Ideographic"},
    96637: {"Ideographic"},
    96638: {"Ideographic"},
    96639: {"Ideographic"},
    96640: {"Ideographic"},
    96641: {"Ideographic"},
    96642: {"Ideographic"},
    96643: {"Ideographic"},
    96644: {"Ideographic"},
    96645: {"Ideographic"},
    96646: {"Ideographic"},
    96647: {"Ideographic"},
    96648: {"Ideographic"},
    96649: {"Ideographic"},
    96650: {"Ideographic"},
    96651: {"Ideographic"},
    96652: {"Ideographic"},
    96653: {"Ideographic"},
    96654: {"Ideographic"},
    96655: {"Ideographic"},
    96656: {"Ideographic"},
    96657: {"Ideographic"},
    96658: {"Ideographic"},
    96659: {"Ideographic"},
    96660: {"Ideographic"},
    96661: {"Ideographic"},
    96662: {"Ideographic"},
    96663: {"Ideographic"},
    96664: {"Ideographic"},
    96665: {"Ideographic"},
    96666: {"Ideographic"},
    96667: {"Ideographic"},
    96668: {"Ideographic"},
    96669: {"Ideographic"},
    96670: {"Ideographic"},
    96671: {"Ideographic"},
    96672: {"Ideographic"},
    96673: {"Ideographic"},
    96674: {"Ideographic"},
    96675: {"Ideographic"},
    96676: {"Ideographic"},
    96677: {"Ideographic"},
    96678: {"Ideographic"},
    96679: {"Ideographic"},
    96680: {"Ideographic"},
    96681: {"Ideographic"},
    96682: {"Ideographic"},
    96683: {"Ideographic"},
    96684: {"Ideographic"},
    96685: {"Ideographic"},
    96686: {"Ideographic"},
    96687: {"Ideographic"},
    96688: {"Ideographic"},
    96689: {"Ideographic"},
    96690: {"Ideographic"},
    96691: {"Ideographic"},
    96692: {"Ideographic"},
    96693: {"Ideographic"},
    96694: {"Ideographic"},
    96695: {"Ideographic"},
    96696: {"Ideographic"},
    96697: {"Ideographic"},
    96698: {"Ideographic"},
    96699: {"Ideographic"},
    96700: {"Ideographic"},
    96701: {"Ideographic"},
    96702: {"Ideographic"},
    96703: {"Ideographic"},
    96704: {"Ideographic"},
    96705: {"Ideographic"},
    96706: {"Ideographic"},
    96707: {"Ideographic"},
    96708: {"Ideographic"},
    96709: {"Ideographic"},
    96710: {"Ideographic"},
    96711: {"Ideographic"},
    96712: {"Ideographic"},
    96713: {"Ideographic"},
    96714: {"Ideographic"},
    96715: {"Ideographic"},
    96716: {"Ideographic"},
    96717: {"Ideographic"},
    96718: {"Ideographic"},
    96719: {"Ideographic"},
    96720: {"Ideographic"},
    96721: {"Ideographic"},
    96722: {"Ideographic"},
    96723: {"Ideographic"},
    96724: {"Ideographic"},
    96725: {"Ideographic"},
    96726: {"Ideographic"},
    96727: {"Ideographic"},
    96728: {"Ideographic"},
    96729: {"Ideographic"},
    96730: {"Ideographic"},
    96731: {"Ideographic"},
    96732: {"Ideographic"},
    96733: {"Ideographic"},
    96734: {"Ideographic"},
    96735: {"Ideographic"},
    96736: {"Ideographic"},
    96737: {"Ideographic"},
    96738: {"Ideographic"},
    96739: {"Ideographic"},
    96740: {"Ideographic"},
    96741: {"Ideographic"},
    96742: {"Ideographic"},
    96743: {"Ideographic"},
    96744: {"Ideographic"},
    96745: {"Ideographic"},
    96746: {"Ideographic"},
    96747: {"Ideographic"},
    96748: {"Ideographic"},
    96749: {"Ideographic"},
    96750: {"Ideographic"},
    96751: {"Ideographic"},
    96752: {"Ideographic"},
    96753: {"Ideographic"},
    96754: {"Ideographic"},
    96755: {"Ideographic"},
    96756: {"Ideographic"},
    96757: {"Ideographic"},
    96758: {"Ideographic"},
    96759: {"Ideographic"},
    96760: {"Ideographic"},
    96761: {"Ideographic"},
    96762: {"Ideographic"},
    96763: {"Ideographic"},
    96764: {"Ideographic"},
    96765: {"Ideographic"},
    96766: {"Ideographic"},
    96767: {"Ideographic"},
    96768: {"Ideographic"},
    96769: {"Ideographic"},
    96770: {"Ideographic"},
    96771: {"Ideographic"},
    96772: {"Ideographic"},
    96773: {"Ideographic"},
    96774: {"Ideographic"},
    96775: {"Ideographic"},
    96776: {"Ideographic"},
    96777: {"Ideographic"},
    96778: {"Ideographic"},
    96779: {"Ideographic"},
    96780: {"Ideographic"},
    96781: {"Ideographic"},
    96782: {"Ideographic"},
    96783: {"Ideographic"},
    96784: {"Ideographic"},
    96785: {"Ideographic"},
    96786: {"Ideographic"},
    96787: {"Ideographic"},
    96788: {"Ideographic"},
    96789: {"Ideographic"},
    96790: {"Ideographic"},
    96791: {"Ideographic"},
    96792: {"Ideographic"},
    96793: {"Ideographic"},
    96794: {"Ideographic"},
    96795: {"Ideographic"},
    96796: {"Ideographic"},
    96797: {"Ideographic"},
    96798: {"Ideographic"},
    96799: {"Ideographic"},
    96800: {"Ideographic"},
    96801: {"Ideographic"},
    96802: {"Ideographic"},
    96803: {"Ideographic"},
    96804: {"Ideographic"},
    96805: {"Ideographic"},
    96806: {"Ideographic"},
    96807: {"Ideographic"},
    96808: {"Ideographic"},
    96809: {"Ideographic"},
    96810: {"Ideographic"},
    96811: {"Ideographic"},
    96812: {"Ideographic"},
    96813: {"Ideographic"},
    96814: {"Ideographic"},
    96815: {"Ideographic"},
    96816: {"Ideographic"},
    96817: {"Ideographic"},
    96818: {"Ideographic"},
    96819: {"Ideographic"},
    96820: {"Ideographic"},
    96821: {"Ideographic"},
    96822: {"Ideographic"},
    96823: {"Ideographic"},
    96824: {"Ideographic"},
    96825: {"Ideographic"},
    96826: {"Ideographic"},
    96827: {"Ideographic"},
    96828: {"Ideographic"},
    96829: {"Ideographic"},
    96830: {"Ideographic"},
    96831: {"Ideographic"},
    96832: {"Ideographic"},
    96833: {"Ideographic"},
    96834: {"Ideographic"},
    96835: {"Ideographic"},
    96836: {"Ideographic"},
    96837: {"Ideographic"},
    96838: {"Ideographic"},
    96839: {"Ideographic"},
    96840: {"Ideographic"},
    96841: {"Ideographic"},
    96842: {"Ideographic"},
    96843: {"Ideographic"},
    96844: {"Ideographic"},
    96845: {"Ideographic"},
    96846: {"Ideographic"},
    96847: {"Ideographic"},
    96848: {"Ideographic"},
    96849: {"Ideographic"},
    96850: {"Ideographic"},
    96851: {"Ideographic"},
    96852: {"Ideographic"},
    96853: {"Ideographic"},
    96854: {"Ideographic"},
    96855: {"Ideographic"},
    96856: {"Ideographic"},
    96857: {"Ideographic"},
    96858: {"Ideographic"},
    96859: {"Ideographic"},
    96860: {"Ideographic"},
    96861: {"Ideographic"},
    96862: {"Ideographic"},
    96863: {"Ideographic"},
    96864: {"Ideographic"},
    96865: {"Ideographic"},
    96866: {"Ideographic"},
    96867: {"Ideographic"},
    96868: {"Ideographic"},
    96869: {"Ideographic"},
    96870: {"Ideographic"},
    96871: {"Ideographic"},
    96872: {"Ideographic"},
    96873: {"Ideographic"},
    96874: {"Ideographic"},
    96875: {"Ideographic"},
    96876: {"Ideographic"},
    96877: {"Ideographic"},
    96878: {"Ideographic"},
    96879: {"Ideographic"},
    96880: {"Ideographic"},
    96881: {"Ideographic"},
    96882: {"Ideographic"},
    96883: {"Ideographic"},
    96884: {"Ideographic"},
    96885: {"Ideographic"},
    96886: {"Ideographic"},
    96887: {"Ideographic"},
    96888: {"Ideographic"},
    96889: {"Ideographic"},
    96890: {"Ideographic"},
    96891: {"Ideographic"},
    96892: {"Ideographic"},
    96893: {"Ideographic"},
    96894: {"Ideographic"},
    96895: {"Ideographic"},
    96896: {"Ideographic"},
    96897: {"Ideographic"},
    96898: {"Ideographic"},
    96899: {"Ideographic"},
    96900: {"Ideographic"},
    96901: {"Ideographic"},
    96902: {"Ideographic"},
    96903: {"Ideographic"},
    96904: {"Ideographic"},
    96905: {"Ideographic"},
    96906: {"Ideographic"},
    96907: {"Ideographic"},
    96908: {"Ideographic"},
    96909: {"Ideographic"},
    96910: {"Ideographic"},
    96911: {"Ideographic"},
    96912: {"Ideographic"},
    96913: {"Ideographic"},
    96914: {"Ideographic"},
    96915: {"Ideographic"},
    96916: {"Ideographic"},
    96917: {"Ideographic"},
    96918: {"Ideographic"},
    96919: {"Ideographic"},
    96920: {"Ideographic"},
    96921: {"Ideographic"},
    96922: {"Ideographic"},
    96923: {"Ideographic"},
    96924: {"Ideographic"},
    96925: {"Ideographic"},
    96926: {"Ideographic"},
    96927: {"Ideographic"},
    96928: {"Ideographic"},
    96929: {"Ideographic"},
    96930: {"Ideographic"},
    96931: {"Ideographic"},
    96932: {"Ideographic"},
    96933: {"Ideographic"},
    96934: {"Ideographic"},
    96935: {"Ideographic"},
    96936: {"Ideographic"},
    96937: {"Ideographic"},
    96938: {"Ideographic"},
    96939: {"Ideographic"},
    96940: {"Ideographic"},
    96941: {"Ideographic"},
    96942: {"Ideographic"},
    96943: {"Ideographic"},
    96944: {"Ideographic"},
    96945: {"Ideographic"},
    96946: {"Ideographic"},
    96947: {"Ideographic"},
    96948: {"Ideographic"},
    96949: {"Ideographic"},
    96950: {"Ideographic"},
    96951: {"Ideographic"},
    96952: {"Ideographic"},
    96953: {"Ideographic"},
    96954: {"Ideographic"},
    96955: {"Ideographic"},
    96956: {"Ideographic"},
    96957: {"Ideographic"},
    96958: {"Ideographic"},
    96959: {"Ideographic"},
    96960: {"Ideographic"},
    96961: {"Ideographic"},
    96962: {"Ideographic"},
    96963: {"Ideographic"},
    96964: {"Ideographic"},
    96965: {"Ideographic"},
    96966: {"Ideographic"},
    96967: {"Ideographic"},
    96968: {"Ideographic"},
    96969: {"Ideographic"},
    96970: {"Ideographic"},
    96971: {"Ideographic"},
    96972: {"Ideographic"},
    96973: {"Ideographic"},
    96974: {"Ideographic"},
    96975: {"Ideographic"},
    96976: {"Ideographic"},
    96977: {"Ideographic"},
    96978: {"Ideographic"},
    96979: {"Ideographic"},
    96980: {"Ideographic"},
    96981: {"Ideographic"},
    96982: {"Ideographic"},
    96983: {"Ideographic"},
    96984: {"Ideographic"},
    96985: {"Ideographic"},
    96986: {"Ideographic"},
    96987: {"Ideographic"},
    96988: {"Ideographic"},
    96989: {"Ideographic"},
    96990: {"Ideographic"},
    96991: {"Ideographic"},
    96992: {"Ideographic"},
    96993: {"Ideographic"},
    96994: {"Ideographic"},
    96995: {"Ideographic"},
    96996: {"Ideographic"},
    96997: {"Ideographic"},
    96998: {"Ideographic"},
    96999: {"Ideographic"},
    97000: {"Ideographic"},
    97001: {"Ideographic"},
    97002: {"Ideographic"},
    97003: {"Ideographic"},
    97004: {"Ideographic"},
    97005: {"Ideographic"},
    97006: {"Ideographic"},
    97007: {"Ideographic"},
    97008: {"Ideographic"},
    97009: {"Ideographic"},
    97010: {"Ideographic"},
    97011: {"Ideographic"},
    97012: {"Ideographic"},
    97013: {"Ideographic"},
    97014: {"Ideographic"},
    97015: {"Ideographic"},
    97016: {"Ideographic"},
    97017: {"Ideographic"},
    97018: {"Ideographic"},
    97019: {"Ideographic"},
    97020: {"Ideographic"},
    97021: {"Ideographic"},
    97022: {"Ideographic"},
    97023: {"Ideographic"},
    97024: {"Ideographic"},
    97025: {"Ideographic"},
    97026: {"Ideographic"},
    97027: {"Ideographic"},
    97028: {"Ideographic"},
    97029: {"Ideographic"},
    97030: {"Ideographic"},
    97031: {"Ideographic"},
    97032: {"Ideographic"},
    97033: {"Ideographic"},
    97034: {"Ideographic"},
    97035: {"Ideographic"},
    97036: {"Ideographic"},
    97037: {"Ideographic"},
    97038: {"Ideographic"},
    97039: {"Ideographic"},
    97040: {"Ideographic"},
    97041: {"Ideographic"},
    97042: {"Ideographic"},
    97043: {"Ideographic"},
    97044: {"Ideographic"},
    97045: {"Ideographic"},
    97046: {"Ideographic"},
    97047: {"Ideographic"},
    97048: {"Ideographic"},
    97049: {"Ideographic"},
    97050: {"Ideographic"},
    97051: {"Ideographic"},
    97052: {"Ideographic"},
    97053: {"Ideographic"},
    97054: {"Ideographic"},
    97055: {"Ideographic"},
    97056: {"Ideographic"},
    97057: {"Ideographic"},
    97058: {"Ideographic"},
    97059: {"Ideographic"},
    97060: {"Ideographic"},
    97061: {"Ideographic"},
    97062: {"Ideographic"},
    97063: {"Ideographic"},
    97064: {"Ideographic"},
    97065: {"Ideographic"},
    97066: {"Ideographic"},
    97067: {"Ideographic"},
    97068: {"Ideographic"},
    97069: {"Ideographic"},
    97070: {"Ideographic"},
    97071: {"Ideographic"},
    97072: {"Ideographic"},
    97073: {"Ideographic"},
    97074: {"Ideographic"},
    97075: {"Ideographic"},
    97076: {"Ideographic"},
    97077: {"Ideographic"},
    97078: {"Ideographic"},
    97079: {"Ideographic"},
    97080: {"Ideographic"},
    97081: {"Ideographic"},
    97082: {"Ideographic"},
    97083: {"Ideographic"},
    97084: {"Ideographic"},
    97085: {"Ideographic"},
    97086: {"Ideographic"},
    97087: {"Ideographic"},
    97088: {"Ideographic"},
    97089: {"Ideographic"},
    97090: {"Ideographic"},
    97091: {"Ideographic"},
    97092: {"Ideographic"},
    97093: {"Ideographic"},
    97094: {"Ideographic"},
    97095: {"Ideographic"},
    97096: {"Ideographic"},
    97097: {"Ideographic"},
    97098: {"Ideographic"},
    97099: {"Ideographic"},
    97100: {"Ideographic"},
    97101: {"Ideographic"},
    97102: {"Ideographic"},
    97103: {"Ideographic"},
    97104: {"Ideographic"},
    97105: {"Ideographic"},
    97106: {"Ideographic"},
    97107: {"Ideographic"},
    97108: {"Ideographic"},
    97109: {"Ideographic"},
    97110: {"Ideographic"},
    97111: {"Ideographic"},
    97112: {"Ideographic"},
    97113: {"Ideographic"},
    97114: {"Ideographic"},
    97115: {"Ideographic"},
    97116: {"Ideographic"},
    97117: {"Ideographic"},
    97118: {"Ideographic"},
    97119: {"Ideographic"},
    97120: {"Ideographic"},
    97121: {"Ideographic"},
    97122: {"Ideographic"},
    97123: {"Ideographic"},
    97124: {"Ideographic"},
    97125: {"Ideographic"},
    97126: {"Ideographic"},
    97127: {"Ideographic"},
    97128: {"Ideographic"},
    97129: {"Ideographic"},
    97130: {"Ideographic"},
    97131: {"Ideographic"},
    97132: {"Ideographic"},
    97133: {"Ideographic"},
    97134: {"Ideographic"},
    97135: {"Ideographic"},
    97136: {"Ideographic"},
    97137: {"Ideographic"},
    97138: {"Ideographic"},
    97139: {"Ideographic"},
    97140: {"Ideographic"},
    97141: {"Ideographic"},
    97142: {"Ideographic"},
    97143: {"Ideographic"},
    97144: {"Ideographic"},
    97145: {"Ideographic"},
    97146: {"Ideographic"},
    97147: {"Ideographic"},
    97148: {"Ideographic"},
    97149: {"Ideographic"},
    97150: {"Ideographic"},
    97151: {"Ideographic"},
    97152: {"Ideographic"},
    97153: {"Ideographic"},
    97154: {"Ideographic"},
    97155: {"Ideographic"},
    97156: {"Ideographic"},
    97157: {"Ideographic"},
    97158: {"Ideographic"},
    97159: {"Ideographic"},
    97160: {"Ideographic"},
    97161: {"Ideographic"},
    97162: {"Ideographic"},
    97163: {"Ideographic"},
    97164: {"Ideographic"},
    97165: {"Ideographic"},
    97166: {"Ideographic"},
    97167: {"Ideographic"},
    97168: {"Ideographic"},
    97169: {"Ideographic"},
    97170: {"Ideographic"},
    97171: {"Ideographic"},
    97172: {"Ideographic"},
    97173: {"Ideographic"},
    97174: {"Ideographic"},
    97175: {"Ideographic"},
    97176: {"Ideographic"},
    97177: {"Ideographic"},
    97178: {"Ideographic"},
    97179: {"Ideographic"},
    97180: {"Ideographic"},
    97181: {"Ideographic"},
    97182: {"Ideographic"},
    97183: {"Ideographic"},
    97184: {"Ideographic"},
    97185: {"Ideographic"},
    97186: {"Ideographic"},
    97187: {"Ideographic"},
    97188: {"Ideographic"},
    97189: {"Ideographic"},
    97190: {"Ideographic"},
    97191: {"Ideographic"},
    97192: {"Ideographic"},
    97193: {"Ideographic"},
    97194: {"Ideographic"},
    97195: {"Ideographic"},
    97196: {"Ideographic"},
    97197: {"Ideographic"},
    97198: {"Ideographic"},
    97199: {"Ideographic"},
    97200: {"Ideographic"},
    97201: {"Ideographic"},
    97202: {"Ideographic"},
    97203: {"Ideographic"},
    97204: {"Ideographic"},
    97205: {"Ideographic"},
    97206: {"Ideographic"},
    97207: {"Ideographic"},
    97208: {"Ideographic"},
    97209: {"Ideographic"},
    97210: {"Ideographic"},
    97211: {"Ideographic"},
    97212: {"Ideographic"},
    97213: {"Ideographic"},
    97214: {"Ideographic"},
    97215: {"Ideographic"},
    97216: {"Ideographic"},
    97217: {"Ideographic"},
    97218: {"Ideographic"},
    97219: {"Ideographic"},
    97220: {"Ideographic"},
    97221: {"Ideographic"},
    97222: {"Ideographic"},
    97223: {"Ideographic"},
    97224: {"Ideographic"},
    97225: {"Ideographic"},
    97226: {"Ideographic"},
    97227: {"Ideographic"},
    97228: {"Ideographic"},
    97229: {"Ideographic"},
    97230: {"Ideographic"},
    97231: {"Ideographic"},
    97232: {"Ideographic"},
    97233: {"Ideographic"},
    97234: {"Ideographic"},
    97235: {"Ideographic"},
    97236: {"Ideographic"},
    97237: {"Ideographic"},
    97238: {"Ideographic"},
    97239: {"Ideographic"},
    97240: {"Ideographic"},
    97241: {"Ideographic"},
    97242: {"Ideographic"},
    97243: {"Ideographic"},
    97244: {"Ideographic"},
    97245: {"Ideographic"},
    97246: {"Ideographic"},
    97247: {"Ideographic"},
    97248: {"Ideographic"},
    97249: {"Ideographic"},
    97250: {"Ideographic"},
    97251: {"Ideographic"},
    97252: {"Ideographic"},
    97253: {"Ideographic"},
    97254: {"Ideographic"},
    97255: {"Ideographic"},
    97256: {"Ideographic"},
    97257: {"Ideographic"},
    97258: {"Ideographic"},
    97259: {"Ideographic"},
    97260: {"Ideographic"},
    97261: {"Ideographic"},
    97262: {"Ideographic"},
    97263: {"Ideographic"},
    97264: {"Ideographic"},
    97265: {"Ideographic"},
    97266: {"Ideographic"},
    97267: {"Ideographic"},
    97268: {"Ideographic"},
    97269: {"Ideographic"},
    97270: {"Ideographic"},
    97271: {"Ideographic"},
    97272: {"Ideographic"},
    97273: {"Ideographic"},
    97274: {"Ideographic"},
    97275: {"Ideographic"},
    97276: {"Ideographic"},
    97277: {"Ideographic"},
    97278: {"Ideographic"},
    97279: {"Ideographic"},
    97280: {"Ideographic"},
    97281: {"Ideographic"},
    97282: {"Ideographic"},
    97283: {"Ideographic"},
    97284: {"Ideographic"},
    97285: {"Ideographic"},
    97286: {"Ideographic"},
    97287: {"Ideographic"},
    97288: {"Ideographic"},
    97289: {"Ideographic"},
    97290: {"Ideographic"},
    97291: {"Ideographic"},
    97292: {"Ideographic"},
    97293: {"Ideographic"},
    97294: {"Ideographic"},
    97295: {"Ideographic"},
    97296: {"Ideographic"},
    97297: {"Ideographic"},
    97298: {"Ideographic"},
    97299: {"Ideographic"},
    97300: {"Ideographic"},
    97301: {"Ideographic"},
    97302: {"Ideographic"},
    97303: {"Ideographic"},
    97304: {"Ideographic"},
    97305: {"Ideographic"},
    97306: {"Ideographic"},
    97307: {"Ideographic"},
    97308: {"Ideographic"},
    97309: {"Ideographic"},
    97310: {"Ideographic"},
    97311: {"Ideographic"},
    97312: {"Ideographic"},
    97313: {"Ideographic"},
    97314: {"Ideographic"},
    97315: {"Ideographic"},
    97316: {"Ideographic"},
    97317: {"Ideographic"},
    97318: {"Ideographic"},
    97319: {"Ideographic"},
    97320: {"Ideographic"},
    97321: {"Ideographic"},
    97322: {"Ideographic"},
    97323: {"Ideographic"},
    97324: {"Ideographic"},
    97325: {"Ideographic"},
    97326: {"Ideographic"},
    97327: {"Ideographic"},
    97328: {"Ideographic"},
    97329: {"Ideographic"},
    97330: {"Ideographic"},
    97331: {"Ideographic"},
    97332: {"Ideographic"},
    97333: {"Ideographic"},
    97334: {"Ideographic"},
    97335: {"Ideographic"},
    97336: {"Ideographic"},
    97337: {"Ideographic"},
    97338: {"Ideographic"},
    97339: {"Ideographic"},
    97340: {"Ideographic"},
    97341: {"Ideographic"},
    97342: {"Ideographic"},
    97343: {"Ideographic"},
    97344: {"Ideographic"},
    97345: {"Ideographic"},
    97346: {"Ideographic"},
    97347: {"Ideographic"},
    97348: {"Ideographic"},
    97349: {"Ideographic"},
    97350: {"Ideographic"},
    97351: {"Ideographic"},
    97352: {"Ideographic"},
    97353: {"Ideographic"},
    97354: {"Ideographic"},
    97355: {"Ideographic"},
    97356: {"Ideographic"},
    97357: {"Ideographic"},
    97358: {"Ideographic"},
    97359: {"Ideographic"},
    97360: {"Ideographic"},
    97361: {"Ideographic"},
    97362: {"Ideographic"},
    97363: {"Ideographic"},
    97364: {"Ideographic"},
    97365: {"Ideographic"},
    97366: {"Ideographic"},
    97367: {"Ideographic"},
    97368: {"Ideographic"},
    97369: {"Ideographic"},
    97370: {"Ideographic"},
    97371: {"Ideographic"},
    97372: {"Ideographic"},
    97373: {"Ideographic"},
    97374: {"Ideographic"},
    97375: {"Ideographic"},
    97376: {"Ideographic"},
    97377: {"Ideographic"},
    97378: {"Ideographic"},
    97379: {"Ideographic"},
    97380: {"Ideographic"},
    97381: {"Ideographic"},
    97382: {"Ideographic"},
    97383: {"Ideographic"},
    97384: {"Ideographic"},
    97385: {"Ideographic"},
    97386: {"Ideographic"},
    97387: {"Ideographic"},
    97388: {"Ideographic"},
    97389: {"Ideographic"},
    97390: {"Ideographic"},
    97391: {"Ideographic"},
    97392: {"Ideographic"},
    97393: {"Ideographic"},
    97394: {"Ideographic"},
    97395: {"Ideographic"},
    97396: {"Ideographic"},
    97397: {"Ideographic"},
    97398: {"Ideographic"},
    97399: {"Ideographic"},
    97400: {"Ideographic"},
    97401: {"Ideographic"},
    97402: {"Ideographic"},
    97403: {"Ideographic"},
    97404: {"Ideographic"},
    97405: {"Ideographic"},
    97406: {"Ideographic"},
    97407: {"Ideographic"},
    97408: {"Ideographic"},
    97409: {"Ideographic"},
    97410: {"Ideographic"},
    97411: {"Ideographic"},
    97412: {"Ideographic"},
    97413: {"Ideographic"},
    97414: {"Ideographic"},
    97415: {"Ideographic"},
    97416: {"Ideographic"},
    97417: {"Ideographic"},
    97418: {"Ideographic"},
    97419: {"Ideographic"},
    97420: {"Ideographic"},
    97421: {"Ideographic"},
    97422: {"Ideographic"},
    97423: {"Ideographic"},
    97424: {"Ideographic"},
    97425: {"Ideographic"},
    97426: {"Ideographic"},
    97427: {"Ideographic"},
    97428: {"Ideographic"},
    97429: {"Ideographic"},
    97430: {"Ideographic"},
    97431: {"Ideographic"},
    97432: {"Ideographic"},
    97433: {"Ideographic"},
    97434: {"Ideographic"},
    97435: {"Ideographic"},
    97436: {"Ideographic"},
    97437: {"Ideographic"},
    97438: {"Ideographic"},
    97439: {"Ideographic"},
    97440: {"Ideographic"},
    97441: {"Ideographic"},
    97442: {"Ideographic"},
    97443: {"Ideographic"},
    97444: {"Ideographic"},
    97445: {"Ideographic"},
    97446: {"Ideographic"},
    97447: {"Ideographic"},
    97448: {"Ideographic"},
    97449: {"Ideographic"},
    97450: {"Ideographic"},
    97451: {"Ideographic"},
    97452: {"Ideographic"},
    97453: {"Ideographic"},
    97454: {"Ideographic"},
    97455: {"Ideographic"},
    97456: {"Ideographic"},
    97457: {"Ideographic"},
    97458: {"Ideographic"},
    97459: {"Ideographic"},
    97460: {"Ideographic"},
    97461: {"Ideographic"},
    97462: {"Ideographic"},
    97463: {"Ideographic"},
    97464: {"Ideographic"},
    97465: {"Ideographic"},
    97466: {"Ideographic"},
    97467: {"Ideographic"},
    97468: {"Ideographic"},
    97469: {"Ideographic"},
    97470: {"Ideographic"},
    97471: {"Ideographic"},
    97472: {"Ideographic"},
    97473: {"Ideographic"},
    97474: {"Ideographic"},
    97475: {"Ideographic"},
    97476: {"Ideographic"},
    97477: {"Ideographic"},
    97478: {"Ideographic"},
    97479: {"Ideographic"},
    97480: {"Ideographic"},
    97481: {"Ideographic"},
    97482: {"Ideographic"},
    97483: {"Ideographic"},
    97484: {"Ideographic"},
    97485: {"Ideographic"},
    97486: {"Ideographic"},
    97487: {"Ideographic"},
    97488: {"Ideographic"},
    97489: {"Ideographic"},
    97490: {"Ideographic"},
    97491: {"Ideographic"},
    97492: {"Ideographic"},
    97493: {"Ideographic"},
    97494: {"Ideographic"},
    97495: {"Ideographic"},
    97496: {"Ideographic"},
    97497: {"Ideographic"},
    97498: {"Ideographic"},
    97499: {"Ideographic"},
    97500: {"Ideographic"},
    97501: {"Ideographic"},
    97502: {"Ideographic"},
    97503: {"Ideographic"},
    97504: {"Ideographic"},
    97505: {"Ideographic"},
    97506: {"Ideographic"},
    97507: {"Ideographic"},
    97508: {"Ideographic"},
    97509: {"Ideographic"},
    97510: {"Ideographic"},
    97511: {"Ideographic"},
    97512: {"Ideographic"},
    97513: {"Ideographic"},
    97514: {"Ideographic"},
    97515: {"Ideographic"},
    97516: {"Ideographic"},
    97517: {"Ideographic"},
    97518: {"Ideographic"},
    97519: {"Ideographic"},
    97520: {"Ideographic"},
    97521: {"Ideographic"},
    97522: {"Ideographic"},
    97523: {"Ideographic"},
    97524: {"Ideographic"},
    97525: {"Ideographic"},
    97526: {"Ideographic"},
    97527: {"Ideographic"},
    97528: {"Ideographic"},
    97529: {"Ideographic"},
    97530: {"Ideographic"},
    97531: {"Ideographic"},
    97532: {"Ideographic"},
    97533: {"Ideographic"},
    97534: {"Ideographic"},
    97535: {"Ideographic"},
    97536: {"Ideographic"},
    97537: {"Ideographic"},
    97538: {"Ideographic"},
    97539: {"Ideographic"},
    97540: {"Ideographic"},
    97541: {"Ideographic"},
    97542: {"Ideographic"},
    97543: {"Ideographic"},
    97544: {"Ideographic"},
    97545: {"Ideographic"},
    97546: {"Ideographic"},
    97547: {"Ideographic"},
    97548: {"Ideographic"},
    97549: {"Ideographic"},
    97550: {"Ideographic"},
    97551: {"Ideographic"},
    97552: {"Ideographic"},
    97553: {"Ideographic"},
    97554: {"Ideographic"},
    97555: {"Ideographic"},
    97556: {"Ideographic"},
    97557: {"Ideographic"},
    97558: {"Ideographic"},
    97559: {"Ideographic"},
    97560: {"Ideographic"},
    97561: {"Ideographic"},
    97562: {"Ideographic"},
    97563: {"Ideographic"},
    97564: {"Ideographic"},
    97565: {"Ideographic"},
    97566: {"Ideographic"},
    97567: {"Ideographic"},
    97568: {"Ideographic"},
    97569: {"Ideographic"},
    97570: {"Ideographic"},
    97571: {"Ideographic"},
    97572: {"Ideographic"},
    97573: {"Ideographic"},
    97574: {"Ideographic"},
    97575: {"Ideographic"},
    97576: {"Ideographic"},
    97577: {"Ideographic"},
    97578: {"Ideographic"},
    97579: {"Ideographic"},
    97580: {"Ideographic"},
    97581: {"Ideographic"},
    97582: {"Ideographic"},
    97583: {"Ideographic"},
    97584: {"Ideographic"},
    97585: {"Ideographic"},
    97586: {"Ideographic"},
    97587: {"Ideographic"},
    97588: {"Ideographic"},
    97589: {"Ideographic"},
    97590: {"Ideographic"},
    97591: {"Ideographic"},
    97592: {"Ideographic"},
    97593: {"Ideographic"},
    97594: {"Ideographic"},
    97595: {"Ideographic"},
    97596: {"Ideographic"},
    97597: {"Ideographic"},
    97598: {"Ideographic"},
    97599: {"Ideographic"},
    97600: {"Ideographic"},
    97601: {"Ideographic"},
    97602: {"Ideographic"},
    97603: {"Ideographic"},
    97604: {"Ideographic"},
    97605: {"Ideographic"},
    97606: {"Ideographic"},
    97607: {"Ideographic"},
    97608: {"Ideographic"},
    97609: {"Ideographic"},
    97610: {"Ideographic"},
    97611: {"Ideographic"},
    97612: {"Ideographic"},
    97613: {"Ideographic"},
    97614: {"Ideographic"},
    97615: {"Ideographic"},
    97616: {"Ideographic"},
    97617: {"Ideographic"},
    97618: {"Ideographic"},
    97619: {"Ideographic"},
    97620: {"Ideographic"},
    97621: {"Ideographic"},
    97622: {"Ideographic"},
    97623: {"Ideographic"},
    97624: {"Ideographic"},
    97625: {"Ideographic"},
    97626: {"Ideographic"},
    97627: {"Ideographic"},
    97628: {"Ideographic"},
    97629: {"Ideographic"},
    97630: {"Ideographic"},
    97631: {"Ideographic"},
    97632: {"Ideographic"},
    97633: {"Ideographic"},
    97634: {"Ideographic"},
    97635: {"Ideographic"},
    97636: {"Ideographic"},
    97637: {"Ideographic"},
    97638: {"Ideographic"},
    97639: {"Ideographic"},
    97640: {"Ideographic"},
    97641: {"Ideographic"},
    97642: {"Ideographic"},
    97643: {"Ideographic"},
    97644: {"Ideographic"},
    97645: {"Ideographic"},
    97646: {"Ideographic"},
    97647: {"Ideographic"},
    97648: {"Ideographic"},
    97649: {"Ideographic"},
    97650: {"Ideographic"},
    97651: {"Ideographic"},
    97652: {"Ideographic"},
    97653: {"Ideographic"},
    97654: {"Ideographic"},
    97655: {"Ideographic"},
    97656: {"Ideographic"},
    97657: {"Ideographic"},
    97658: {"Ideographic"},
    97659: {"Ideographic"},
    97660: {"Ideographic"},
    97661: {"Ideographic"},
    97662: {"Ideographic"},
    97663: {"Ideographic"},
    97664: {"Ideographic"},
    97665: {"Ideographic"},
    97666: {"Ideographic"},
    97667: {"Ideographic"},
    97668: {"Ideographic"},
    97669: {"Ideographic"},
    97670: {"Ideographic"},
    97671: {"Ideographic"},
    97672: {"Ideographic"},
    97673: {"Ideographic"},
    97674: {"Ideographic"},
    97675: {"Ideographic"},
    97676: {"Ideographic"},
    97677: {"Ideographic"},
    97678: {"Ideographic"},
    97679: {"Ideographic"},
    97680: {"Ideographic"},
    97681: {"Ideographic"},
    97682: {"Ideographic"},
    97683: {"Ideographic"},
    97684: {"Ideographic"},
    97685: {"Ideographic"},
    97686: {"Ideographic"},
    97687: {"Ideographic"},
    97688: {"Ideographic"},
    97689: {"Ideographic"},
    97690: {"Ideographic"},
    97691: {"Ideographic"},
    97692: {"Ideographic"},
    97693: {"Ideographic"},
    97694: {"Ideographic"},
    97695: {"Ideographic"},
    97696: {"Ideographic"},
    97697: {"Ideographic"},
    97698: {"Ideographic"},
    97699: {"Ideographic"},
    97700: {"Ideographic"},
    97701: {"Ideographic"},
    97702: {"Ideographic"},
    97703: {"Ideographic"},
    97704: {"Ideographic"},
    97705: {"Ideographic"},
    97706: {"Ideographic"},
    97707: {"Ideographic"},
    97708: {"Ideographic"},
    97709: {"Ideographic"},
    97710: {"Ideographic"},
    97711: {"Ideographic"},
    97712: {"Ideographic"},
    97713: {"Ideographic"},
    97714: {"Ideographic"},
    97715: {"Ideographic"},
    97716: {"Ideographic"},
    97717: {"Ideographic"},
    97718: {"Ideographic"},
    97719: {"Ideographic"},
    97720: {"Ideographic"},
    97721: {"Ideographic"},
    97722: {"Ideographic"},
    97723: {"Ideographic"},
    97724: {"Ideographic"},
    97725: {"Ideographic"},
    97726: {"Ideographic"},
    97727: {"Ideographic"},
    97728: {"Ideographic"},
    97729: {"Ideographic"},
    97730: {"Ideographic"},
    97731: {"Ideographic"},
    97732: {"Ideographic"},
    97733: {"Ideographic"},
    97734: {"Ideographic"},
    97735: {"Ideographic"},
    97736: {"Ideographic"},
    97737: {"Ideographic"},
    97738: {"Ideographic"},
    97739: {"Ideographic"},
    97740: {"Ideographic"},
    97741: {"Ideographic"},
    97742: {"Ideographic"},
    97743: {"Ideographic"},
    97744: {"Ideographic"},
    97745: {"Ideographic"},
    97746: {"Ideographic"},
    97747: {"Ideographic"},
    97748: {"Ideographic"},
    97749: {"Ideographic"},
    97750: {"Ideographic"},
    97751: {"Ideographic"},
    97752: {"Ideographic"},
    97753: {"Ideographic"},
    97754: {"Ideographic"},
    97755: {"Ideographic"},
    97756: {"Ideographic"},
    97757: {"Ideographic"},
    97758: {"Ideographic"},
    97759: {"Ideographic"},
    97760: {"Ideographic"},
    97761: {"Ideographic"},
    97762: {"Ideographic"},
    97763: {"Ideographic"},
    97764: {"Ideographic"},
    97765: {"Ideographic"},
    97766: {"Ideographic"},
    97767: {"Ideographic"},
    97768: {"Ideographic"},
    97769: {"Ideographic"},
    97770: {"Ideographic"},
    97771: {"Ideographic"},
    97772: {"Ideographic"},
    97773: {"Ideographic"},
    97774: {"Ideographic"},
    97775: {"Ideographic"},
    97776: {"Ideographic"},
    97777: {"Ideographic"},
    97778: {"Ideographic"},
    97779: {"Ideographic"},
    97780: {"Ideographic"},
    97781: {"Ideographic"},
    97782: {"Ideographic"},
    97783: {"Ideographic"},
    97784: {"Ideographic"},
    97785: {"Ideographic"},
    97786: {"Ideographic"},
    97787: {"Ideographic"},
    97788: {"Ideographic"},
    97789: {"Ideographic"},
    97790: {"Ideographic"},
    97791: {"Ideographic"},
    97792: {"Ideographic"},
    97793: {"Ideographic"},
    97794: {"Ideographic"},
    97795: {"Ideographic"},
    97796: {"Ideographic"},
    97797: {"Ideographic"},
    97798: {"Ideographic"},
    97799: {"Ideographic"},
    97800: {"Ideographic"},
    97801: {"Ideographic"},
    97802: {"Ideographic"},
    97803: {"Ideographic"},
    97804: {"Ideographic"},
    97805: {"Ideographic"},
    97806: {"Ideographic"},
    97807: {"Ideographic"},
    97808: {"Ideographic"},
    97809: {"Ideographic"},
    97810: {"Ideographic"},
    97811: {"Ideographic"},
    97812: {"Ideographic"},
    97813: {"Ideographic"},
    97814: {"Ideographic"},
    97815: {"Ideographic"},
    97816: {"Ideographic"},
    97817: {"Ideographic"},
    97818: {"Ideographic"},
    97819: {"Ideographic"},
    97820: {"Ideographic"},
    97821: {"Ideographic"},
    97822: {"Ideographic"},
    97823: {"Ideographic"},
    97824: {"Ideographic"},
    97825: {"Ideographic"},
    97826: {"Ideographic"},
    97827: {"Ideographic"},
    97828: {"Ideographic"},
    97829: {"Ideographic"},
    97830: {"Ideographic"},
    97831: {"Ideographic"},
    97832: {"Ideographic"},
    97833: {"Ideographic"},
    97834: {"Ideographic"},
    97835: {"Ideographic"},
    97836: {"Ideographic"},
    97837: {"Ideographic"},
    97838: {"Ideographic"},
    97839: {"Ideographic"},
    97840: {"Ideographic"},
    97841: {"Ideographic"},
    97842: {"Ideographic"},
    97843: {"Ideographic"},
    97844: {"Ideographic"},
    97845: {"Ideographic"},
    97846: {"Ideographic"},
    97847: {"Ideographic"},
    97848: {"Ideographic"},
    97849: {"Ideographic"},
    97850: {"Ideographic"},
    97851: {"Ideographic"},
    97852: {"Ideographic"},
    97853: {"Ideographic"},
    97854: {"Ideographic"},
    97855: {"Ideographic"},
    97856: {"Ideographic"},
    97857: {"Ideographic"},
    97858: {"Ideographic"},
    97859: {"Ideographic"},
    97860: {"Ideographic"},
    97861: {"Ideographic"},
    97862: {"Ideographic"},
    97863: {"Ideographic"},
    97864: {"Ideographic"},
    97865: {"Ideographic"},
    97866: {"Ideographic"},
    97867: {"Ideographic"},
    97868: {"Ideographic"},
    97869: {"Ideographic"},
    97870: {"Ideographic"},
    97871: {"Ideographic"},
    97872: {"Ideographic"},
    97873: {"Ideographic"},
    97874: {"Ideographic"},
    97875: {"Ideographic"},
    97876: {"Ideographic"},
    97877: {"Ideographic"},
    97878: {"Ideographic"},
    97879: {"Ideographic"},
    97880: {"Ideographic"},
    97881: {"Ideographic"},
    97882: {"Ideographic"},
    97883: {"Ideographic"},
    97884: {"Ideographic"},
    97885: {"Ideographic"},
    97886: {"Ideographic"},
    97887: {"Ideographic"},
    97888: {"Ideographic"},
    97889: {"Ideographic"},
    97890: {"Ideographic"},
    97891: {"Ideographic"},
    97892: {"Ideographic"},
    97893: {"Ideographic"},
    97894: {"Ideographic"},
    97895: {"Ideographic"},
    97896: {"Ideographic"},
    97897: {"Ideographic"},
    97898: {"Ideographic"},
    97899: {"Ideographic"},
    97900: {"Ideographic"},
    97901: {"Ideographic"},
    97902: {"Ideographic"},
    97903: {"Ideographic"},
    97904: {"Ideographic"},
    97905: {"Ideographic"},
    97906: {"Ideographic"},
    97907: {"Ideographic"},
    97908: {"Ideographic"},
    97909: {"Ideographic"},
    97910: {"Ideographic"},
    97911: {"Ideographic"},
    97912: {"Ideographic"},
    97913: {"Ideographic"},
    97914: {"Ideographic"},
    97915: {"Ideographic"},
    97916: {"Ideographic"},
    97917: {"Ideographic"},
    97918: {"Ideographic"},
    97919: {"Ideographic"},
    97920: {"Ideographic"},
    97921: {"Ideographic"},
    97922: {"Ideographic"},
    97923: {"Ideographic"},
    97924: {"Ideographic"},
    97925: {"Ideographic"},
    97926: {"Ideographic"},
    97927: {"Ideographic"},
    97928: {"Ideographic"},
    97929: {"Ideographic"},
    97930: {"Ideographic"},
    97931: {"Ideographic"},
    97932: {"Ideographic"},
    97933: {"Ideographic"},
    97934: {"Ideographic"},
    97935: {"Ideographic"},
    97936: {"Ideographic"},
    97937: {"Ideographic"},
    97938: {"Ideographic"},
    97939: {"Ideographic"},
    97940: {"Ideographic"},
    97941: {"Ideographic"},
    97942: {"Ideographic"},
    97943: {"Ideographic"},
    97944: {"Ideographic"},
    97945: {"Ideographic"},
    97946: {"Ideographic"},
    97947: {"Ideographic"},
    97948: {"Ideographic"},
    97949: {"Ideographic"},
    97950: {"Ideographic"},
    97951: {"Ideographic"},
    97952: {"Ideographic"},
    97953: {"Ideographic"},
    97954: {"Ideographic"},
    97955: {"Ideographic"},
    97956: {"Ideographic"},
    97957: {"Ideographic"},
    97958: {"Ideographic"},
    97959: {"Ideographic"},
    97960: {"Ideographic"},
    97961: {"Ideographic"},
    97962: {"Ideographic"},
    97963: {"Ideographic"},
    97964: {"Ideographic"},
    97965: {"Ideographic"},
    97966: {"Ideographic"},
    97967: {"Ideographic"},
    97968: {"Ideographic"},
    97969: {"Ideographic"},
    97970: {"Ideographic"},
    97971: {"Ideographic"},
    97972: {"Ideographic"},
    97973: {"Ideographic"},
    97974: {"Ideographic"},
    97975: {"Ideographic"},
    97976: {"Ideographic"},
    97977: {"Ideographic"},
    97978: {"Ideographic"},
    97979: {"Ideographic"},
    97980: {"Ideographic"},
    97981: {"Ideographic"},
    97982: {"Ideographic"},
    97983: {"Ideographic"},
    97984: {"Ideographic"},
    97985: {"Ideographic"},
    97986: {"Ideographic"},
    97987: {"Ideographic"},
    97988: {"Ideographic"},
    97989: {"Ideographic"},
    97990: {"Ideographic"},
    97991: {"Ideographic"},
    97992: {"Ideographic"},
    97993: {"Ideographic"},
    97994: {"Ideographic"},
    97995: {"Ideographic"},
    97996: {"Ideographic"},
    97997: {"Ideographic"},
    97998: {"Ideographic"},
    97999: {"Ideographic"},
    98000: {"Ideographic"},
    98001: {"Ideographic"},
    98002: {"Ideographic"},
    98003: {"Ideographic"},
    98004: {"Ideographic"},
    98005: {"Ideographic"},
    98006: {"Ideographic"},
    98007: {"Ideographic"},
    98008: {"Ideographic"},
    98009: {"Ideographic"},
    98010: {"Ideographic"},
    98011: {"Ideographic"},
    98012: {"Ideographic"},
    98013: {"Ideographic"},
    98014: {"Ideographic"},
    98015: {"Ideographic"},
    98016: {"Ideographic"},
    98017: {"Ideographic"},
    98018: {"Ideographic"},
    98019: {"Ideographic"},
    98020: {"Ideographic"},
    98021: {"Ideographic"},
    98022: {"Ideographic"},
    98023: {"Ideographic"},
    98024: {"Ideographic"},
    98025: {"Ideographic"},
    98026: {"Ideographic"},
    98027: {"Ideographic"},
    98028: {"Ideographic"},
    98029: {"Ideographic"},
    98030: {"Ideographic"},
    98031: {"Ideographic"},
    98032: {"Ideographic"},
    98033: {"Ideographic"},
    98034: {"Ideographic"},
    98035: {"Ideographic"},
    98036: {"Ideographic"},
    98037: {"Ideographic"},
    98038: {"Ideographic"},
    98039: {"Ideographic"},
    98040: {"Ideographic"},
    98041: {"Ideographic"},
    98042: {"Ideographic"},
    98043: {"Ideographic"},
    98044: {"Ideographic"},
    98045: {"Ideographic"},
    98046: {"Ideographic"},
    98047: {"Ideographic"},
    98048: {"Ideographic"},
    98049: {"Ideographic"},
    98050: {"Ideographic"},
    98051: {"Ideographic"},
    98052: {"Ideographic"},
    98053: {"Ideographic"},
    98054: {"Ideographic"},
    98055: {"Ideographic"},
    98056: {"Ideographic"},
    98057: {"Ideographic"},
    98058: {"Ideographic"},
    98059: {"Ideographic"},
    98060: {"Ideographic"},
    98061: {"Ideographic"},
    98062: {"Ideographic"},
    98063: {"Ideographic"},
    98064: {"Ideographic"},
    98065: {"Ideographic"},
    98066: {"Ideographic"},
    98067: {"Ideographic"},
    98068: {"Ideographic"},
    98069: {"Ideographic"},
    98070: {"Ideographic"},
    98071: {"Ideographic"},
    98072: {"Ideographic"},
    98073: {"Ideographic"},
    98074: {"Ideographic"},
    98075: {"Ideographic"},
    98076: {"Ideographic"},
    98077: {"Ideographic"},
    98078: {"Ideographic"},
    98079: {"Ideographic"},
    98080: {"Ideographic"},
    98081: {"Ideographic"},
    98082: {"Ideographic"},
    98083: {"Ideographic"},
    98084: {"Ideographic"},
    98085: {"Ideographic"},
    98086: {"Ideographic"},
    98087: {"Ideographic"},
    98088: {"Ideographic"},
    98089: {"Ideographic"},
    98090: {"Ideographic"},
    98091: {"Ideographic"},
    98092: {"Ideographic"},
    98093: {"Ideographic"},
    98094: {"Ideographic"},
    98095: {"Ideographic"},
    98096: {"Ideographic"},
    98097: {"Ideographic"},
    98098: {"Ideographic"},
    98099: {"Ideographic"},
    98100: {"Ideographic"},
    98101: {"Ideographic"},
    98102: {"Ideographic"},
    98103: {"Ideographic"},
    98104: {"Ideographic"},
    98105: {"Ideographic"},
    98106: {"Ideographic"},
    98107: {"Ideographic"},
    98108: {"Ideographic"},
    98109: {"Ideographic"},
    98110: {"Ideographic"},
    98111: {"Ideographic"},
    98112: {"Ideographic"},
    98113: {"Ideographic"},
    98114: {"Ideographic"},
    98115: {"Ideographic"},
    98116: {"Ideographic"},
    98117: {"Ideographic"},
    98118: {"Ideographic"},
    98119: {"Ideographic"},
    98120: {"Ideographic"},
    98121: {"Ideographic"},
    98122: {"Ideographic"},
    98123: {"Ideographic"},
    98124: {"Ideographic"},
    98125: {"Ideographic"},
    98126: {"Ideographic"},
    98127: {"Ideographic"},
    98128: {"Ideographic"},
    98129: {"Ideographic"},
    98130: {"Ideographic"},
    98131: {"Ideographic"},
    98132: {"Ideographic"},
    98133: {"Ideographic"},
    98134: {"Ideographic"},
    98135: {"Ideographic"},
    98136: {"Ideographic"},
    98137: {"Ideographic"},
    98138: {"Ideographic"},
    98139: {"Ideographic"},
    98140: {"Ideographic"},
    98141: {"Ideographic"},
    98142: {"Ideographic"},
    98143: {"Ideographic"},
    98144: {"Ideographic"},
    98145: {"Ideographic"},
    98146: {"Ideographic"},
    98147: {"Ideographic"},
    98148: {"Ideographic"},
    98149: {"Ideographic"},
    98150: {"Ideographic"},
    98151: {"Ideographic"},
    98152: {"Ideographic"},
    98153: {"Ideographic"},
    98154: {"Ideographic"},
    98155: {"Ideographic"},
    98156: {"Ideographic"},
    98157: {"Ideographic"},
    98158: {"Ideographic"},
    98159: {"Ideographic"},
    98160: {"Ideographic"},
    98161: {"Ideographic"},
    98162: {"Ideographic"},
    98163: {"Ideographic"},
    98164: {"Ideographic"},
    98165: {"Ideographic"},
    98166: {"Ideographic"},
    98167: {"Ideographic"},
    98168: {"Ideographic"},
    98169: {"Ideographic"},
    98170: {"Ideographic"},
    98171: {"Ideographic"},
    98172: {"Ideographic"},
    98173: {"Ideographic"},
    98174: {"Ideographic"},
    98175: {"Ideographic"},
    98176: {"Ideographic"},
    98177: {"Ideographic"},
    98178: {"Ideographic"},
    98179: {"Ideographic"},
    98180: {"Ideographic"},
    98181: {"Ideographic"},
    98182: {"Ideographic"},
    98183: {"Ideographic"},
    98184: {"Ideographic"},
    98185: {"Ideographic"},
    98186: {"Ideographic"},
    98187: {"Ideographic"},
    98188: {"Ideographic"},
    98189: {"Ideographic"},
    98190: {"Ideographic"},
    98191: {"Ideographic"},
    98192: {"Ideographic"},
    98193: {"Ideographic"},
    98194: {"Ideographic"},
    98195: {"Ideographic"},
    98196: {"Ideographic"},
    98197: {"Ideographic"},
    98198: {"Ideographic"},
    98199: {"Ideographic"},
    98200: {"Ideographic"},
    98201: {"Ideographic"},
    98202: {"Ideographic"},
    98203: {"Ideographic"},
    98204: {"Ideographic"},
    98205: {"Ideographic"},
    98206: {"Ideographic"},
    98207: {"Ideographic"},
    98208: {"Ideographic"},
    98209: {"Ideographic"},
    98210: {"Ideographic"},
    98211: {"Ideographic"},
    98212: {"Ideographic"},
    98213: {"Ideographic"},
    98214: {"Ideographic"},
    98215: {"Ideographic"},
    98216: {"Ideographic"},
    98217: {"Ideographic"},
    98218: {"Ideographic"},
    98219: {"Ideographic"},
    98220: {"Ideographic"},
    98221: {"Ideographic"},
    98222: {"Ideographic"},
    98223: {"Ideographic"},
    98224: {"Ideographic"},
    98225: {"Ideographic"},
    98226: {"Ideographic"},
    98227: {"Ideographic"},
    98228: {"Ideographic"},
    98229: {"Ideographic"},
    98230: {"Ideographic"},
    98231: {"Ideographic"},
    98232: {"Ideographic"},
    98233: {"Ideographic"},
    98234: {"Ideographic"},
    98235: {"Ideographic"},
    98236: {"Ideographic"},
    98237: {"Ideographic"},
    98238: {"Ideographic"},
    98239: {"Ideographic"},
    98240: {"Ideographic"},
    98241: {"Ideographic"},
    98242: {"Ideographic"},
    98243: {"Ideographic"},
    98244: {"Ideographic"},
    98245: {"Ideographic"},
    98246: {"Ideographic"},
    98247: {"Ideographic"},
    98248: {"Ideographic"},
    98249: {"Ideographic"},
    98250: {"Ideographic"},
    98251: {"Ideographic"},
    98252: {"Ideographic"},
    98253: {"Ideographic"},
    98254: {"Ideographic"},
    98255: {"Ideographic"},
    98256: {"Ideographic"},
    98257: {"Ideographic"},
    98258: {"Ideographic"},
    98259: {"Ideographic"},
    98260: {"Ideographic"},
    98261: {"Ideographic"},
    98262: {"Ideographic"},
    98263: {"Ideographic"},
    98264: {"Ideographic"},
    98265: {"Ideographic"},
    98266: {"Ideographic"},
    98267: {"Ideographic"},
    98268: {"Ideographic"},
    98269: {"Ideographic"},
    98270: {"Ideographic"},
    98271: {"Ideographic"},
    98272: {"Ideographic"},
    98273: {"Ideographic"},
    98274: {"Ideographic"},
    98275: {"Ideographic"},
    98276: {"Ideographic"},
    98277: {"Ideographic"},
    98278: {"Ideographic"},
    98279: {"Ideographic"},
    98280: {"Ideographic"},
    98281: {"Ideographic"},
    98282: {"Ideographic"},
    98283: {"Ideographic"},
    98284: {"Ideographic"},
    98285: {"Ideographic"},
    98286: {"Ideographic"},
    98287: {"Ideographic"},
    98288: {"Ideographic"},
    98289: {"Ideographic"},
    98290: {"Ideographic"},
    98291: {"Ideographic"},
    98292: {"Ideographic"},
    98293: {"Ideographic"},
    98294: {"Ideographic"},
    98295: {"Ideographic"},
    98296: {"Ideographic"},
    98297: {"Ideographic"},
    98298: {"Ideographic"},
    98299: {"Ideographic"},
    98300: {"Ideographic"},
    98301: {"Ideographic"},
    98302: {"Ideographic"},
    98303: {"Ideographic"},
    98304: {"Ideographic"},
    98305: {"Ideographic"},
    98306: {"Ideographic"},
    98307: {"Ideographic"},
    98308: {"Ideographic"},
    98309: {"Ideographic"},
    98310: {"Ideographic"},
    98311: {"Ideographic"},
    98312: {"Ideographic"},
    98313: {"Ideographic"},
    98314: {"Ideographic"},
    98315: {"Ideographic"},
    98316: {"Ideographic"},
    98317: {"Ideographic"},
    98318: {"Ideographic"},
    98319: {"Ideographic"},
    98320: {"Ideographic"},
    98321: {"Ideographic"},
    98322: {"Ideographic"},
    98323: {"Ideographic"},
    98324: {"Ideographic"},
    98325: {"Ideographic"},
    98326: {"Ideographic"},
    98327: {"Ideographic"},
    98328: {"Ideographic"},
    98329: {"Ideographic"},
    98330: {"Ideographic"},
    98331: {"Ideographic"},
    98332: {"Ideographic"},
    98333: {"Ideographic"},
    98334: {"Ideographic"},
    98335: {"Ideographic"},
    98336: {"Ideographic"},
    98337: {"Ideographic"},
    98338: {"Ideographic"},
    98339: {"Ideographic"},
    98340: {"Ideographic"},
    98341: {"Ideographic"},
    98342: {"Ideographic"},
    98343: {"Ideographic"},
    98344: {"Ideographic"},
    98345: {"Ideographic"},
    98346: {"Ideographic"},
    98347: {"Ideographic"},
    98348: {"Ideographic"},
    98349: {"Ideographic"},
    98350: {"Ideographic"},
    98351: {"Ideographic"},
    98352: {"Ideographic"},
    98353: {"Ideographic"},
    98354: {"Ideographic"},
    98355: {"Ideographic"},
    98356: {"Ideographic"},
    98357: {"Ideographic"},
    98358: {"Ideographic"},
    98359: {"Ideographic"},
    98360: {"Ideographic"},
    98361: {"Ideographic"},
    98362: {"Ideographic"},
    98363: {"Ideographic"},
    98364: {"Ideographic"},
    98365: {"Ideographic"},
    98366: {"Ideographic"},
    98367: {"Ideographic"},
    98368: {"Ideographic"},
    98369: {"Ideographic"},
    98370: {"Ideographic"},
    98371: {"Ideographic"},
    98372: {"Ideographic"},
    98373: {"Ideographic"},
    98374: {"Ideographic"},
    98375: {"Ideographic"},
    98376: {"Ideographic"},
    98377: {"Ideographic"},
    98378: {"Ideographic"},
    98379: {"Ideographic"},
    98380: {"Ideographic"},
    98381: {"Ideographic"},
    98382: {"Ideographic"},
    98383: {"Ideographic"},
    98384: {"Ideographic"},
    98385: {"Ideographic"},
    98386: {"Ideographic"},
    98387: {"Ideographic"},
    98388: {"Ideographic"},
    98389: {"Ideographic"},
    98390: {"Ideographic"},
    98391: {"Ideographic"},
    98392: {"Ideographic"},
    98393: {"Ideographic"},
    98394: {"Ideographic"},
    98395: {"Ideographic"},
    98396: {"Ideographic"},
    98397: {"Ideographic"},
    98398: {"Ideographic"},
    98399: {"Ideographic"},
    98400: {"Ideographic"},
    98401: {"Ideographic"},
    98402: {"Ideographic"},
    98403: {"Ideographic"},
    98404: {"Ideographic"},
    98405: {"Ideographic"},
    98406: {"Ideographic"},
    98407: {"Ideographic"},
    98408: {"Ideographic"},
    98409: {"Ideographic"},
    98410: {"Ideographic"},
    98411: {"Ideographic"},
    98412: {"Ideographic"},
    98413: {"Ideographic"},
    98414: {"Ideographic"},
    98415: {"Ideographic"},
    98416: {"Ideographic"},
    98417: {"Ideographic"},
    98418: {"Ideographic"},
    98419: {"Ideographic"},
    98420: {"Ideographic"},
    98421: {"Ideographic"},
    98422: {"Ideographic"},
    98423: {"Ideographic"},
    98424: {"Ideographic"},
    98425: {"Ideographic"},
    98426: {"Ideographic"},
    98427: {"Ideographic"},
    98428: {"Ideographic"},
    98429: {"Ideographic"},
    98430: {"Ideographic"},
    98431: {"Ideographic"},
    98432: {"Ideographic"},
    98433: {"Ideographic"},
    98434: {"Ideographic"},
    98435: {"Ideographic"},
    98436: {"Ideographic"},
    98437: {"Ideographic"},
    98438: {"Ideographic"},
    98439: {"Ideographic"},
    98440: {"Ideographic"},
    98441: {"Ideographic"},
    98442: {"Ideographic"},
    98443: {"Ideographic"},
    98444: {"Ideographic"},
    98445: {"Ideographic"},
    98446: {"Ideographic"},
    98447: {"Ideographic"},
    98448: {"Ideographic"},
    98449: {"Ideographic"},
    98450: {"Ideographic"},
    98451: {"Ideographic"},
    98452: {"Ideographic"},
    98453: {"Ideographic"},
    98454: {"Ideographic"},
    98455: {"Ideographic"},
    98456: {"Ideographic"},
    98457: {"Ideographic"},
    98458: {"Ideographic"},
    98459: {"Ideographic"},
    98460: {"Ideographic"},
    98461: {"Ideographic"},
    98462: {"Ideographic"},
    98463: {"Ideographic"},
    98464: {"Ideographic"},
    98465: {"Ideographic"},
    98466: {"Ideographic"},
    98467: {"Ideographic"},
    98468: {"Ideographic"},
    98469: {"Ideographic"},
    98470: {"Ideographic"},
    98471: {"Ideographic"},
    98472: {"Ideographic"},
    98473: {"Ideographic"},
    98474: {"Ideographic"},
    98475: {"Ideographic"},
    98476: {"Ideographic"},
    98477: {"Ideographic"},
    98478: {"Ideographic"},
    98479: {"Ideographic"},
    98480: {"Ideographic"},
    98481: {"Ideographic"},
    98482: {"Ideographic"},
    98483: {"Ideographic"},
    98484: {"Ideographic"},
    98485: {"Ideographic"},
    98486: {"Ideographic"},
    98487: {"Ideographic"},
    98488: {"Ideographic"},
    98489: {"Ideographic"},
    98490: {"Ideographic"},
    98491: {"Ideographic"},
    98492: {"Ideographic"},
    98493: {"Ideographic"},
    98494: {"Ideographic"},
    98495: {"Ideographic"},
    98496: {"Ideographic"},
    98497: {"Ideographic"},
    98498: {"Ideographic"},
    98499: {"Ideographic"},
    98500: {"Ideographic"},
    98501: {"Ideographic"},
    98502: {"Ideographic"},
    98503: {"Ideographic"},
    98504: {"Ideographic"},
    98505: {"Ideographic"},
    98506: {"Ideographic"},
    98507: {"Ideographic"},
    98508: {"Ideographic"},
    98509: {"Ideographic"},
    98510: {"Ideographic"},
    98511: {"Ideographic"},
    98512: {"Ideographic"},
    98513: {"Ideographic"},
    98514: {"Ideographic"},
    98515: {"Ideographic"},
    98516: {"Ideographic"},
    98517: {"Ideographic"},
    98518: {"Ideographic"},
    98519: {"Ideographic"},
    98520: {"Ideographic"},
    98521: {"Ideographic"},
    98522: {"Ideographic"},
    98523: {"Ideographic"},
    98524: {"Ideographic"},
    98525: {"Ideographic"},
    98526: {"Ideographic"},
    98527: {"Ideographic"},
    98528: {"Ideographic"},
    98529: {"Ideographic"},
    98530: {"Ideographic"},
    98531: {"Ideographic"},
    98532: {"Ideographic"},
    98533: {"Ideographic"},
    98534: {"Ideographic"},
    98535: {"Ideographic"},
    98536: {"Ideographic"},
    98537: {"Ideographic"},
    98538: {"Ideographic"},
    98539: {"Ideographic"},
    98540: {"Ideographic"},
    98541: {"Ideographic"},
    98542: {"Ideographic"},
    98543: {"Ideographic"},
    98544: {"Ideographic"},
    98545: {"Ideographic"},
    98546: {"Ideographic"},
    98547: {"Ideographic"},
    98548: {"Ideographic"},
    98549: {"Ideographic"},
    98550: {"Ideographic"},
    98551: {"Ideographic"},
    98552: {"Ideographic"},
    98553: {"Ideographic"},
    98554: {"Ideographic"},
    98555: {"Ideographic"},
    98556: {"Ideographic"},
    98557: {"Ideographic"},
    98558: {"Ideographic"},
    98559: {"Ideographic"},
    98560: {"Ideographic"},
    98561: {"Ideographic"},
    98562: {"Ideographic"},
    98563: {"Ideographic"},
    98564: {"Ideographic"},
    98565: {"Ideographic"},
    98566: {"Ideographic"},
    98567: {"Ideographic"},
    98568: {"Ideographic"},
    98569: {"Ideographic"},
    98570: {"Ideographic"},
    98571: {"Ideographic"},
    98572: {"Ideographic"},
    98573: {"Ideographic"},
    98574: {"Ideographic"},
    98575: {"Ideographic"},
    98576: {"Ideographic"},
    98577: {"Ideographic"},
    98578: {"Ideographic"},
    98579: {"Ideographic"},
    98580: {"Ideographic"},
    98581: {"Ideographic"},
    98582: {"Ideographic"},
    98583: {"Ideographic"},
    98584: {"Ideographic"},
    98585: {"Ideographic"},
    98586: {"Ideographic"},
    98587: {"Ideographic"},
    98588: {"Ideographic"},
    98589: {"Ideographic"},
    98590: {"Ideographic"},
    98591: {"Ideographic"},
    98592: {"Ideographic"},
    98593: {"Ideographic"},
    98594: {"Ideographic"},
    98595: {"Ideographic"},
    98596: {"Ideographic"},
    98597: {"Ideographic"},
    98598: {"Ideographic"},
    98599: {"Ideographic"},
    98600: {"Ideographic"},
    98601: {"Ideographic"},
    98602: {"Ideographic"},
    98603: {"Ideographic"},
    98604: {"Ideographic"},
    98605: {"Ideographic"},
    98606: {"Ideographic"},
    98607: {"Ideographic"},
    98608: {"Ideographic"},
    98609: {"Ideographic"},
    98610: {"Ideographic"},
    98611: {"Ideographic"},
    98612: {"Ideographic"},
    98613: {"Ideographic"},
    98614: {"Ideographic"},
    98615: {"Ideographic"},
    98616: {"Ideographic"},
    98617: {"Ideographic"},
    98618: {"Ideographic"},
    98619: {"Ideographic"},
    98620: {"Ideographic"},
    98621: {"Ideographic"},
    98622: {"Ideographic"},
    98623: {"Ideographic"},
    98624: {"Ideographic"},
    98625: {"Ideographic"},
    98626: {"Ideographic"},
    98627: {"Ideographic"},
    98628: {"Ideographic"},
    98629: {"Ideographic"},
    98630: {"Ideographic"},
    98631: {"Ideographic"},
    98632: {"Ideographic"},
    98633: {"Ideographic"},
    98634: {"Ideographic"},
    98635: {"Ideographic"},
    98636: {"Ideographic"},
    98637: {"Ideographic"},
    98638: {"Ideographic"},
    98639: {"Ideographic"},
    98640: {"Ideographic"},
    98641: {"Ideographic"},
    98642: {"Ideographic"},
    98643: {"Ideographic"},
    98644: {"Ideographic"},
    98645: {"Ideographic"},
    98646: {"Ideographic"},
    98647: {"Ideographic"},
    98648: {"Ideographic"},
    98649: {"Ideographic"},
    98650: {"Ideographic"},
    98651: {"Ideographic"},
    98652: {"Ideographic"},
    98653: {"Ideographic"},
    98654: {"Ideographic"},
    98655: {"Ideographic"},
    98656: {"Ideographic"},
    98657: {"Ideographic"},
    98658: {"Ideographic"},
    98659: {"Ideographic"},
    98660: {"Ideographic"},
    98661: {"Ideographic"},
    98662: {"Ideographic"},
    98663: {"Ideographic"},
    98664: {"Ideographic"},
    98665: {"Ideographic"},
    98666: {"Ideographic"},
    98667: {"Ideographic"},
    98668: {"Ideographic"},
    98669: {"Ideographic"},
    98670: {"Ideographic"},
    98671: {"Ideographic"},
    98672: {"Ideographic"},
    98673: {"Ideographic"},
    98674: {"Ideographic"},
    98675: {"Ideographic"},
    98676: {"Ideographic"},
    98677: {"Ideographic"},
    98678: {"Ideographic"},
    98679: {"Ideographic"},
    98680: {"Ideographic"},
    98681: {"Ideographic"},
    98682: {"Ideographic"},
    98683: {"Ideographic"},
    98684: {"Ideographic"},
    98685: {"Ideographic"},
    98686: {"Ideographic"},
    98687: {"Ideographic"},
    98688: {"Ideographic"},
    98689: {"Ideographic"},
    98690: {"Ideographic"},
    98691: {"Ideographic"},
    98692: {"Ideographic"},
    98693: {"Ideographic"},
    98694: {"Ideographic"},
    98695: {"Ideographic"},
    98696: {"Ideographic"},
    98697: {"Ideographic"},
    98698: {"Ideographic"},
    98699: {"Ideographic"},
    98700: {"Ideographic"},
    98701: {"Ideographic"},
    98702: {"Ideographic"},
    98703: {"Ideographic"},
    98704: {"Ideographic"},
    98705: {"Ideographic"},
    98706: {"Ideographic"},
    98707: {"Ideographic"},
    98708: {"Ideographic"},
    98709: {"Ideographic"},
    98710: {"Ideographic"},
    98711: {"Ideographic"},
    98712: {"Ideographic"},
    98713: {"Ideographic"},
    98714: {"Ideographic"},
    98715: {"Ideographic"},
    98716: {"Ideographic"},
    98717: {"Ideographic"},
    98718: {"Ideographic"},
    98719: {"Ideographic"},
    98720: {"Ideographic"},
    98721: {"Ideographic"},
    98722: {"Ideographic"},
    98723: {"Ideographic"},
    98724: {"Ideographic"},
    98725: {"Ideographic"},
    98726: {"Ideographic"},
    98727: {"Ideographic"},
    98728: {"Ideographic"},
    98729: {"Ideographic"},
    98730: {"Ideographic"},
    98731: {"Ideographic"},
    98732: {"Ideographic"},
    98733: {"Ideographic"},
    98734: {"Ideographic"},
    98735: {"Ideographic"},
    98736: {"Ideographic"},
    98737: {"Ideographic"},
    98738: {"Ideographic"},
    98739: {"Ideographic"},
    98740: {"Ideographic"},
    98741: {"Ideographic"},
    98742: {"Ideographic"},
    98743: {"Ideographic"},
    98744: {"Ideographic"},
    98745: {"Ideographic"},
    98746: {"Ideographic"},
    98747: {"Ideographic"},
    98748: {"Ideographic"},
    98749: {"Ideographic"},
    98750: {"Ideographic"},
    98751: {"Ideographic"},
    98752: {"Ideographic"},
    98753: {"Ideographic"},
    98754: {"Ideographic"},
    98755: {"Ideographic"},
    98756: {"Ideographic"},
    98757: {"Ideographic"},
    98758: {"Ideographic"},
    98759: {"Ideographic"},
    98760: {"Ideographic"},
    98761: {"Ideographic"},
    98762: {"Ideographic"},
    98763: {"Ideographic"},
    98764: {"Ideographic"},
    98765: {"Ideographic"},
    98766: {"Ideographic"},
    98767: {"Ideographic"},
    98768: {"Ideographic"},
    98769: {"Ideographic"},
    98770: {"Ideographic"},
    98771: {"Ideographic"},
    98772: {"Ideographic"},
    98773: {"Ideographic"},
    98774: {"Ideographic"},
    98775: {"Ideographic"},
    98776: {"Ideographic"},
    98777: {"Ideographic"},
    98778: {"Ideographic"},
    98779: {"Ideographic"},
    98780: {"Ideographic"},
    98781: {"Ideographic"},
    98782: {"Ideographic"},
    98783: {"Ideographic"},
    98784: {"Ideographic"},
    98785: {"Ideographic"},
    98786: {"Ideographic"},
    98787: {"Ideographic"},
    98788: {"Ideographic"},
    98789: {"Ideographic"},
    98790: {"Ideographic"},
    98791: {"Ideographic"},
    98792: {"Ideographic"},
    98793: {"Ideographic"},
    98794: {"Ideographic"},
    98795: {"Ideographic"},
    98796: {"Ideographic"},
    98797: {"Ideographic"},
    98798: {"Ideographic"},
    98799: {"Ideographic"},
    98800: {"Ideographic"},
    98801: {"Ideographic"},
    98802: {"Ideographic"},
    98803: {"Ideographic"},
    98804: {"Ideographic"},
    98805: {"Ideographic"},
    98806: {"Ideographic"},
    98807: {"Ideographic"},
    98808: {"Ideographic"},
    98809: {"Ideographic"},
    98810: {"Ideographic"},
    98811: {"Ideographic"},
    98812: {"Ideographic"},
    98813: {"Ideographic"},
    98814: {"Ideographic"},
    98815: {"Ideographic"},
    98816: {"Ideographic"},
    98817: {"Ideographic"},
    98818: {"Ideographic"},
    98819: {"Ideographic"},
    98820: {"Ideographic"},
    98821: {"Ideographic"},
    98822: {"Ideographic"},
    98823: {"Ideographic"},
    98824: {"Ideographic"},
    98825: {"Ideographic"},
    98826: {"Ideographic"},
    98827: {"Ideographic"},
    98828: {"Ideographic"},
    98829: {"Ideographic"},
    98830: {"Ideographic"},
    98831: {"Ideographic"},
    98832: {"Ideographic"},
    98833: {"Ideographic"},
    98834: {"Ideographic"},
    98835: {"Ideographic"},
    98836: {"Ideographic"},
    98837: {"Ideographic"},
    98838: {"Ideographic"},
    98839: {"Ideographic"},
    98840: {"Ideographic"},
    98841: {"Ideographic"},
    98842: {"Ideographic"},
    98843: {"Ideographic"},
    98844: {"Ideographic"},
    98845: {"Ideographic"},
    98846: {"Ideographic"},
    98847: {"Ideographic"},
    98848: {"Ideographic"},
    98849: {"Ideographic"},
    98850: {"Ideographic"},
    98851: {"Ideographic"},
    98852: {"Ideographic"},
    98853: {"Ideographic"},
    98854: {"Ideographic"},
    98855: {"Ideographic"},
    98856: {"Ideographic"},
    98857: {"Ideographic"},
    98858: {"Ideographic"},
    98859: {"Ideographic"},
    98860: {"Ideographic"},
    98861: {"Ideographic"},
    98862: {"Ideographic"},
    98863: {"Ideographic"},
    98864: {"Ideographic"},
    98865: {"Ideographic"},
    98866: {"Ideographic"},
    98867: {"Ideographic"},
    98868: {"Ideographic"},
    98869: {"Ideographic"},
    98870: {"Ideographic"},
    98871: {"Ideographic"},
    98872: {"Ideographic"},
    98873: {"Ideographic"},
    98874: {"Ideographic"},
    98875: {"Ideographic"},
    98876: {"Ideographic"},
    98877: {"Ideographic"},
    98878: {"Ideographic"},
    98879: {"Ideographic"},
    98880: {"Ideographic"},
    98881: {"Ideographic"},
    98882: {"Ideographic"},
    98883: {"Ideographic"},
    98884: {"Ideographic"},
    98885: {"Ideographic"},
    98886: {"Ideographic"},
    98887: {"Ideographic"},
    98888: {"Ideographic"},
    98889: {"Ideographic"},
    98890: {"Ideographic"},
    98891: {"Ideographic"},
    98892: {"Ideographic"},
    98893: {"Ideographic"},
    98894: {"Ideographic"},
    98895: {"Ideographic"},
    98896: {"Ideographic"},
    98897: {"Ideographic"},
    98898: {"Ideographic"},
    98899: {"Ideographic"},
    98900: {"Ideographic"},
    98901: {"Ideographic"},
    98902: {"Ideographic"},
    98903: {"Ideographic"},
    98904: {"Ideographic"},
    98905: {"Ideographic"},
    98906: {"Ideographic"},
    98907: {"Ideographic"},
    98908: {"Ideographic"},
    98909: {"Ideographic"},
    98910: {"Ideographic"},
    98911: {"Ideographic"},
    98912: {"Ideographic"},
    98913: {"Ideographic"},
    98914: {"Ideographic"},
    98915: {"Ideographic"},
    98916: {"Ideographic"},
    98917: {"Ideographic"},
    98918: {"Ideographic"},
    98919: {"Ideographic"},
    98920: {"Ideographic"},
    98921: {"Ideographic"},
    98922: {"Ideographic"},
    98923: {"Ideographic"},
    98924: {"Ideographic"},
    98925: {"Ideographic"},
    98926: {"Ideographic"},
    98927: {"Ideographic"},
    98928: {"Ideographic"},
    98929: {"Ideographic"},
    98930: {"Ideographic"},
    98931: {"Ideographic"},
    98932: {"Ideographic"},
    98933: {"Ideographic"},
    98934: {"Ideographic"},
    98935: {"Ideographic"},
    98936: {"Ideographic"},
    98937: {"Ideographic"},
    98938: {"Ideographic"},
    98939: {"Ideographic"},
    98940: {"Ideographic"},
    98941: {"Ideographic"},
    98942: {"Ideographic"},
    98943: {"Ideographic"},
    98944: {"Ideographic"},
    98945: {"Ideographic"},
    98946: {"Ideographic"},
    98947: {"Ideographic"},
    98948: {"Ideographic"},
    98949: {"Ideographic"},
    98950: {"Ideographic"},
    98951: {"Ideographic"},
    98952: {"Ideographic"},
    98953: {"Ideographic"},
    98954: {"Ideographic"},
    98955: {"Ideographic"},
    98956: {"Ideographic"},
    98957: {"Ideographic"},
    98958: {"Ideographic"},
    98959: {"Ideographic"},
    98960: {"Ideographic"},
    98961: {"Ideographic"},
    98962: {"Ideographic"},
    98963: {"Ideographic"},
    98964: {"Ideographic"},
    98965: {"Ideographic"},
    98966: {"Ideographic"},
    98967: {"Ideographic"},
    98968: {"Ideographic"},
    98969: {"Ideographic"},
    98970: {"Ideographic"},
    98971: {"Ideographic"},
    98972: {"Ideographic"},
    98973: {"Ideographic"},
    98974: {"Ideographic"},
    98975: {"Ideographic"},
    98976: {"Ideographic"},
    98977: {"Ideographic"},
    98978: {"Ideographic"},
    98979: {"Ideographic"},
    98980: {"Ideographic"},
    98981: {"Ideographic"},
    98982: {"Ideographic"},
    98983: {"Ideographic"},
    98984: {"Ideographic"},
    98985: {"Ideographic"},
    98986: {"Ideographic"},
    98987: {"Ideographic"},
    98988: {"Ideographic"},
    98989: {"Ideographic"},
    98990: {"Ideographic"},
    98991: {"Ideographic"},
    98992: {"Ideographic"},
    98993: {"Ideographic"},
    98994: {"Ideographic"},
    98995: {"Ideographic"},
    98996: {"Ideographic"},
    98997: {"Ideographic"},
    98998: {"Ideographic"},
    98999: {"Ideographic"},
    99000: {"Ideographic"},
    99001: {"Ideographic"},
    99002: {"Ideographic"},
    99003: {"Ideographic"},
    99004: {"Ideographic"},
    99005: {"Ideographic"},
    99006: {"Ideographic"},
    99007: {"Ideographic"},
    99008: {"Ideographic"},
    99009: {"Ideographic"},
    99010: {"Ideographic"},
    99011: {"Ideographic"},
    99012: {"Ideographic"},
    99013: {"Ideographic"},
    99014: {"Ideographic"},
    99015: {"Ideographic"},
    99016: {"Ideographic"},
    99017: {"Ideographic"},
    99018: {"Ideographic"},
    99019: {"Ideographic"},
    99020: {"Ideographic"},
    99021: {"Ideographic"},
    99022: {"Ideographic"},
    99023: {"Ideographic"},
    99024: {"Ideographic"},
    99025: {"Ideographic"},
    99026: {"Ideographic"},
    99027: {"Ideographic"},
    99028: {"Ideographic"},
    99029: {"Ideographic"},
    99030: {"Ideographic"},
    99031: {"Ideographic"},
    99032: {"Ideographic"},
    99033: {"Ideographic"},
    99034: {"Ideographic"},
    99035: {"Ideographic"},
    99036: {"Ideographic"},
    99037: {"Ideographic"},
    99038: {"Ideographic"},
    99039: {"Ideographic"},
    99040: {"Ideographic"},
    99041: {"Ideographic"},
    99042: {"Ideographic"},
    99043: {"Ideographic"},
    99044: {"Ideographic"},
    99045: {"Ideographic"},
    99046: {"Ideographic"},
    99047: {"Ideographic"},
    99048: {"Ideographic"},
    99049: {"Ideographic"},
    99050: {"Ideographic"},
    99051: {"Ideographic"},
    99052: {"Ideographic"},
    99053: {"Ideographic"},
    99054: {"Ideographic"},
    99055: {"Ideographic"},
    99056: {"Ideographic"},
    99057: {"Ideographic"},
    99058: {"Ideographic"},
    99059: {"Ideographic"},
    99060: {"Ideographic"},
    99061: {"Ideographic"},
    99062: {"Ideographic"},
    99063: {"Ideographic"},
    99064: {"Ideographic"},
    99065: {"Ideographic"},
    99066: {"Ideographic"},
    99067: {"Ideographic"},
    99068: {"Ideographic"},
    99069: {"Ideographic"},
    99070: {"Ideographic"},
    99071: {"Ideographic"},
    99072: {"Ideographic"},
    99073: {"Ideographic"},
    99074: {"Ideographic"},
    99075: {"Ideographic"},
    99076: {"Ideographic"},
    99077: {"Ideographic"},
    99078: {"Ideographic"},
    99079: {"Ideographic"},
    99080: {"Ideographic"},
    99081: {"Ideographic"},
    99082: {"Ideographic"},
    99083: {"Ideographic"},
    99084: {"Ideographic"},
    99085: {"Ideographic"},
    99086: {"Ideographic"},
    99087: {"Ideographic"},
    99088: {"Ideographic"},
    99089: {"Ideographic"},
    99090: {"Ideographic"},
    99091: {"Ideographic"},
    99092: {"Ideographic"},
    99093: {"Ideographic"},
    99094: {"Ideographic"},
    99095: {"Ideographic"},
    99096: {"Ideographic"},
    99097: {"Ideographic"},
    99098: {"Ideographic"},
    99099: {"Ideographic"},
    99100: {"Ideographic"},
    99101: {"Ideographic"},
    99102: {"Ideographic"},
    99103: {"Ideographic"},
    99104: {"Ideographic"},
    99105: {"Ideographic"},
    99106: {"Ideographic"},
    99107: {"Ideographic"},
    99108: {"Ideographic"},
    99109: {"Ideographic"},
    99110: {"Ideographic"},
    99111: {"Ideographic"},
    99112: {"Ideographic"},
    99113: {"Ideographic"},
    99114: {"Ideographic"},
    99115: {"Ideographic"},
    99116: {"Ideographic"},
    99117: {"Ideographic"},
    99118: {"Ideographic"},
    99119: {"Ideographic"},
    99120: {"Ideographic"},
    99121: {"Ideographic"},
    99122: {"Ideographic"},
    99123: {"Ideographic"},
    99124: {"Ideographic"},
    99125: {"Ideographic"},
    99126: {"Ideographic"},
    99127: {"Ideographic"},
    99128: {"Ideographic"},
    99129: {"Ideographic"},
    99130: {"Ideographic"},
    99131: {"Ideographic"},
    99132: {"Ideographic"},
    99133: {"Ideographic"},
    99134: {"Ideographic"},
    99135: {"Ideographic"},
    99136: {"Ideographic"},
    99137: {"Ideographic"},
    99138: {"Ideographic"},
    99139: {"Ideographic"},
    99140: {"Ideographic"},
    99141: {"Ideographic"},
    99142: {"Ideographic"},
    99143: {"Ideographic"},
    99144: {"Ideographic"},
    99145: {"Ideographic"},
    99146: {"Ideographic"},
    99147: {"Ideographic"},
    99148: {"Ideographic"},
    99149: {"Ideographic"},
    99150: {"Ideographic"},
    99151: {"Ideographic"},
    99152: {"Ideographic"},
    99153: {"Ideographic"},
    99154: {"Ideographic"},
    99155: {"Ideographic"},
    99156: {"Ideographic"},
    99157: {"Ideographic"},
    99158: {"Ideographic"},
    99159: {"Ideographic"},
    99160: {"Ideographic"},
    99161: {"Ideographic"},
    99162: {"Ideographic"},
    99163: {"Ideographic"},
    99164: {"Ideographic"},
    99165: {"Ideographic"},
    99166: {"Ideographic"},
    99167: {"Ideographic"},
    99168: {"Ideographic"},
    99169: {"Ideographic"},
    99170: {"Ideographic"},
    99171: {"Ideographic"},
    99172: {"Ideographic"},
    99173: {"Ideographic"},
    99174: {"Ideographic"},
    99175: {"Ideographic"},
    99176: {"Ideographic"},
    99177: {"Ideographic"},
    99178: {"Ideographic"},
    99179: {"Ideographic"},
    99180: {"Ideographic"},
    99181: {"Ideographic"},
    99182: {"Ideographic"},
    99183: {"Ideographic"},
    99184: {"Ideographic"},
    99185: {"Ideographic"},
    99186: {"Ideographic"},
    99187: {"Ideographic"},
    99188: {"Ideographic"},
    99189: {"Ideographic"},
    99190: {"Ideographic"},
    99191: {"Ideographic"},
    99192: {"Ideographic"},
    99193: {"Ideographic"},
    99194: {"Ideographic"},
    99195: {"Ideographic"},
    99196: {"Ideographic"},
    99197: {"Ideographic"},
    99198: {"Ideographic"},
    99199: {"Ideographic"},
    99200: {"Ideographic"},
    99201: {"Ideographic"},
    99202: {"Ideographic"},
    99203: {"Ideographic"},
    99204: {"Ideographic"},
    99205: {"Ideographic"},
    99206: {"Ideographic"},
    99207: {"Ideographic"},
    99208: {"Ideographic"},
    99209: {"Ideographic"},
    99210: {"Ideographic"},
    99211: {"Ideographic"},
    99212: {"Ideographic"},
    99213: {"Ideographic"},
    99214: {"Ideographic"},
    99215: {"Ideographic"},
    99216: {"Ideographic"},
    99217: {"Ideographic"},
    99218: {"Ideographic"},
    99219: {"Ideographic"},
    99220: {"Ideographic"},
    99221: {"Ideographic"},
    99222: {"Ideographic"},
    99223: {"Ideographic"},
    99224: {"Ideographic"},
    99225: {"Ideographic"},
    99226: {"Ideographic"},
    99227: {"Ideographic"},
    99228: {"Ideographic"},
    99229: {"Ideographic"},
    99230: {"Ideographic"},
    99231: {"Ideographic"},
    99232: {"Ideographic"},
    99233: {"Ideographic"},
    99234: {"Ideographic"},
    99235: {"Ideographic"},
    99236: {"Ideographic"},
    99237: {"Ideographic"},
    99238: {"Ideographic"},
    99239: {"Ideographic"},
    99240: {"Ideographic"},
    99241: {"Ideographic"},
    99242: {"Ideographic"},
    99243: {"Ideographic"},
    99244: {"Ideographic"},
    99245: {"Ideographic"},
    99246: {"Ideographic"},
    99247: {"Ideographic"},
    99248: {"Ideographic"},
    99249: {"Ideographic"},
    99250: {"Ideographic"},
    99251: {"Ideographic"},
    99252: {"Ideographic"},
    99253: {"Ideographic"},
    99254: {"Ideographic"},
    99255: {"Ideographic"},
    99256: {"Ideographic"},
    99257: {"Ideographic"},
    99258: {"Ideographic"},
    99259: {"Ideographic"},
    99260: {"Ideographic"},
    99261: {"Ideographic"},
    99262: {"Ideographic"},
    99263: {"Ideographic"},
    99264: {"Ideographic"},
    99265: {"Ideographic"},
    99266: {"Ideographic"},
    99267: {"Ideographic"},
    99268: {"Ideographic"},
    99269: {"Ideographic"},
    99270: {"Ideographic"},
    99271: {"Ideographic"},
    99272: {"Ideographic"},
    99273: {"Ideographic"},
    99274: {"Ideographic"},
    99275: {"Ideographic"},
    99276: {"Ideographic"},
    99277: {"Ideographic"},
    99278: {"Ideographic"},
    99279: {"Ideographic"},
    99280: {"Ideographic"},
    99281: {"Ideographic"},
    99282: {"Ideographic"},
    99283: {"Ideographic"},
    99284: {"Ideographic"},
    99285: {"Ideographic"},
    99286: {"Ideographic"},
    99287: {"Ideographic"},
    99288: {"Ideographic"},
    99289: {"Ideographic"},
    99290: {"Ideographic"},
    99291: {"Ideographic"},
    99292: {"Ideographic"},
    99293: {"Ideographic"},
    99294: {"Ideographic"},
    99295: {"Ideographic"},
    99296: {"Ideographic"},
    99297: {"Ideographic"},
    99298: {"Ideographic"},
    99299: {"Ideographic"},
    99300: {"Ideographic"},
    99301: {"Ideographic"},
    99302: {"Ideographic"},
    99303: {"Ideographic"},
    99304: {"Ideographic"},
    99305: {"Ideographic"},
    99306: {"Ideographic"},
    99307: {"Ideographic"},
    99308: {"Ideographic"},
    99309: {"Ideographic"},
    99310: {"Ideographic"},
    99311: {"Ideographic"},
    99312: {"Ideographic"},
    99313: {"Ideographic"},
    99314: {"Ideographic"},
    99315: {"Ideographic"},
    99316: {"Ideographic"},
    99317: {"Ideographic"},
    99318: {"Ideographic"},
    99319: {"Ideographic"},
    99320: {"Ideographic"},
    99321: {"Ideographic"},
    99322: {"Ideographic"},
    99323: {"Ideographic"},
    99324: {"Ideographic"},
    99325: {"Ideographic"},
    99326: {"Ideographic"},
    99327: {"Ideographic"},
    99328: {"Ideographic"},
    99329: {"Ideographic"},
    99330: {"Ideographic"},
    99331: {"Ideographic"},
    99332: {"Ideographic"},
    99333: {"Ideographic"},
    99334: {"Ideographic"},
    99335: {"Ideographic"},
    99336: {"Ideographic"},
    99337: {"Ideographic"},
    99338: {"Ideographic"},
    99339: {"Ideographic"},
    99340: {"Ideographic"},
    99341: {"Ideographic"},
    99342: {"Ideographic"},
    99343: {"Ideographic"},
    99344: {"Ideographic"},
    99345: {"Ideographic"},
    99346: {"Ideographic"},
    99347: {"Ideographic"},
    99348: {"Ideographic"},
    99349: {"Ideographic"},
    99350: {"Ideographic"},
    99351: {"Ideographic"},
    99352: {"Ideographic"},
    99353: {"Ideographic"},
    99354: {"Ideographic"},
    99355: {"Ideographic"},
    99356: {"Ideographic"},
    99357: {"Ideographic"},
    99358: {"Ideographic"},
    99359: {"Ideographic"},
    99360: {"Ideographic"},
    99361: {"Ideographic"},
    99362: {"Ideographic"},
    99363: {"Ideographic"},
    99364: {"Ideographic"},
    99365: {"Ideographic"},
    99366: {"Ideographic"},
    99367: {"Ideographic"},
    99368: {"Ideographic"},
    99369: {"Ideographic"},
    99370: {"Ideographic"},
    99371: {"Ideographic"},
    99372: {"Ideographic"},
    99373: {"Ideographic"},
    99374: {"Ideographic"},
    99375: {"Ideographic"},
    99376: {"Ideographic"},
    99377: {"Ideographic"},
    99378: {"Ideographic"},
    99379: {"Ideographic"},
    99380: {"Ideographic"},
    99381: {"Ideographic"},
    99382: {"Ideographic"},
    99383: {"Ideographic"},
    99384: {"Ideographic"},
    99385: {"Ideographic"},
    99386: {"Ideographic"},
    99387: {"Ideographic"},
    99388: {"Ideographic"},
    99389: {"Ideographic"},
    99390: {"Ideographic"},
    99391: {"Ideographic"},
    99392: {"Ideographic"},
    99393: {"Ideographic"},
    99394: {"Ideographic"},
    99395: {"Ideographic"},
    99396: {"Ideographic"},
    99397: {"Ideographic"},
    99398: {"Ideographic"},
    99399: {"Ideographic"},
    99400: {"Ideographic"},
    99401: {"Ideographic"},
    99402: {"Ideographic"},
    99403: {"Ideographic"},
    99404: {"Ideographic"},
    99405: {"Ideographic"},
    99406: {"Ideographic"},
    99407: {"Ideographic"},
    99408: {"Ideographic"},
    99409: {"Ideographic"},
    99410: {"Ideographic"},
    99411: {"Ideographic"},
    99412: {"Ideographic"},
    99413: {"Ideographic"},
    99414: {"Ideographic"},
    99415: {"Ideographic"},
    99416: {"Ideographic"},
    99417: {"Ideographic"},
    99418: {"Ideographic"},
    99419: {"Ideographic"},
    99420: {"Ideographic"},
    99421: {"Ideographic"},
    99422: {"Ideographic"},
    99423: {"Ideographic"},
    99424: {"Ideographic"},
    99425: {"Ideographic"},
    99426: {"Ideographic"},
    99427: {"Ideographic"},
    99428: {"Ideographic"},
    99429: {"Ideographic"},
    99430: {"Ideographic"},
    99431: {"Ideographic"},
    99432: {"Ideographic"},
    99433: {"Ideographic"},
    99434: {"Ideographic"},
    99435: {"Ideographic"},
    99436: {"Ideographic"},
    99437: {"Ideographic"},
    99438: {"Ideographic"},
    99439: {"Ideographic"},
    99440: {"Ideographic"},
    99441: {"Ideographic"},
    99442: {"Ideographic"},
    99443: {"Ideographic"},
    99444: {"Ideographic"},
    99445: {"Ideographic"},
    99446: {"Ideographic"},
    99447: {"Ideographic"},
    99448: {"Ideographic"},
    99449: {"Ideographic"},
    99450: {"Ideographic"},
    99451: {"Ideographic"},
    99452: {"Ideographic"},
    99453: {"Ideographic"},
    99454: {"Ideographic"},
    99455: {"Ideographic"},
    99456: {"Ideographic"},
    99457: {"Ideographic"},
    99458: {"Ideographic"},
    99459: {"Ideographic"},
    99460: {"Ideographic"},
    99461: {"Ideographic"},
    99462: {"Ideographic"},
    99463: {"Ideographic"},
    99464: {"Ideographic"},
    99465: {"Ideographic"},
    99466: {"Ideographic"},
    99467: {"Ideographic"},
    99468: {"Ideographic"},
    99469: {"Ideographic"},
    99470: {"Ideographic"},
    99471: {"Ideographic"},
    99472: {"Ideographic"},
    99473: {"Ideographic"},
    99474: {"Ideographic"},
    99475: {"Ideographic"},
    99476: {"Ideographic"},
    99477: {"Ideographic"},
    99478: {"Ideographic"},
    99479: {"Ideographic"},
    99480: {"Ideographic"},
    99481: {"Ideographic"},
    99482: {"Ideographic"},
    99483: {"Ideographic"},
    99484: {"Ideographic"},
    99485: {"Ideographic"},
    99486: {"Ideographic"},
    99487: {"Ideographic"},
    99488: {"Ideographic"},
    99489: {"Ideographic"},
    99490: {"Ideographic"},
    99491: {"Ideographic"},
    99492: {"Ideographic"},
    99493: {"Ideographic"},
    99494: {"Ideographic"},
    99495: {"Ideographic"},
    99496: {"Ideographic"},
    99497: {"Ideographic"},
    99498: {"Ideographic"},
    99499: {"Ideographic"},
    99500: {"Ideographic"},
    99501: {"Ideographic"},
    99502: {"Ideographic"},
    99503: {"Ideographic"},
    99504: {"Ideographic"},
    99505: {"Ideographic"},
    99506: {"Ideographic"},
    99507: {"Ideographic"},
    99508: {"Ideographic"},
    99509: {"Ideographic"},
    99510: {"Ideographic"},
    99511: {"Ideographic"},
    99512: {"Ideographic"},
    99513: {"Ideographic"},
    99514: {"Ideographic"},
    99515: {"Ideographic"},
    99516: {"Ideographic"},
    99517: {"Ideographic"},
    99518: {"Ideographic"},
    99519: {"Ideographic"},
    99520: {"Ideographic"},
    99521: {"Ideographic"},
    99522: {"Ideographic"},
    99523: {"Ideographic"},
    99524: {"Ideographic"},
    99525: {"Ideographic"},
    99526: {"Ideographic"},
    99527: {"Ideographic"},
    99528: {"Ideographic"},
    99529: {"Ideographic"},
    99530: {"Ideographic"},
    99531: {"Ideographic"},
    99532: {"Ideographic"},
    99533: {"Ideographic"},
    99534: {"Ideographic"},
    99535: {"Ideographic"},
    99536: {"Ideographic"},
    99537: {"Ideographic"},
    99538: {"Ideographic"},
    99539: {"Ideographic"},
    99540: {"Ideographic"},
    99541: {"Ideographic"},
    99542: {"Ideographic"},
    99543: {"Ideographic"},
    99544: {"Ideographic"},
    99545: {"Ideographic"},
    99546: {"Ideographic"},
    99547: {"Ideographic"},
    99548: {"Ideographic"},
    99549: {"Ideographic"},
    99550: {"Ideographic"},
    99551: {"Ideographic"},
    99552: {"Ideographic"},
    99553: {"Ideographic"},
    99554: {"Ideographic"},
    99555: {"Ideographic"},
    99556: {"Ideographic"},
    99557: {"Ideographic"},
    99558: {"Ideographic"},
    99559: {"Ideographic"},
    99560: {"Ideographic"},
    99561: {"Ideographic"},
    99562: {"Ideographic"},
    99563: {"Ideographic"},
    99564: {"Ideographic"},
    99565: {"Ideographic"},
    99566: {"Ideographic"},
    99567: {"Ideographic"},
    99568: {"Ideographic"},
    99569: {"Ideographic"},
    99570: {"Ideographic"},
    99571: {"Ideographic"},
    99572: {"Ideographic"},
    99573: {"Ideographic"},
    99574: {"Ideographic"},
    99575: {"Ideographic"},
    99576: {"Ideographic"},
    99577: {"Ideographic"},
    99578: {"Ideographic"},
    99579: {"Ideographic"},
    99580: {"Ideographic"},
    99581: {"Ideographic"},
    99582: {"Ideographic"},
    99583: {"Ideographic"},
    99584: {"Ideographic"},
    99585: {"Ideographic"},
    99586: {"Ideographic"},
    99587: {"Ideographic"},
    99588: {"Ideographic"},
    99589: {"Ideographic"},
    99590: {"Ideographic"},
    99591: {"Ideographic"},
    99592: {"Ideographic"},
    99593: {"Ideographic"},
    99594: {"Ideographic"},
    99595: {"Ideographic"},
    99596: {"Ideographic"},
    99597: {"Ideographic"},
    99598: {"Ideographic"},
    99599: {"Ideographic"},
    99600: {"Ideographic"},
    99601: {"Ideographic"},
    99602: {"Ideographic"},
    99603: {"Ideographic"},
    99604: {"Ideographic"},
    99605: {"Ideographic"},
    99606: {"Ideographic"},
    99607: {"Ideographic"},
    99608: {"Ideographic"},
    99609: {"Ideographic"},
    99610: {"Ideographic"},
    99611: {"Ideographic"},
    99612: {"Ideographic"},
    99613: {"Ideographic"},
    99614: {"Ideographic"},
    99615: {"Ideographic"},
    99616: {"Ideographic"},
    99617: {"Ideographic"},
    99618: {"Ideographic"},
    99619: {"Ideographic"},
    99620: {"Ideographic"},
    99621: {"Ideographic"},
    99622: {"Ideographic"},
    99623: {"Ideographic"},
    99624: {"Ideographic"},
    99625: {"Ideographic"},
    99626: {"Ideographic"},
    99627: {"Ideographic"},
    99628: {"Ideographic"},
    99629: {"Ideographic"},
    99630: {"Ideographic"},
    99631: {"Ideographic"},
    99632: {"Ideographic"},
    99633: {"Ideographic"},
    99634: {"Ideographic"},
    99635: {"Ideographic"},
    99636: {"Ideographic"},
    99637: {"Ideographic"},
    99638: {"Ideographic"},
    99639: {"Ideographic"},
    99640: {"Ideographic"},
    99641: {"Ideographic"},
    99642: {"Ideographic"},
    99643: {"Ideographic"},
    99644: {"Ideographic"},
    99645: {"Ideographic"},
    99646: {"Ideographic"},
    99647: {"Ideographic"},
    99648: {"Ideographic"},
    99649: {"Ideographic"},
    99650: {"Ideographic"},
    99651: {"Ideographic"},
    99652: {"Ideographic"},
    99653: {"Ideographic"},
    99654: {"Ideographic"},
    99655: {"Ideographic"},
    99656: {"Ideographic"},
    99657: {"Ideographic"},
    99658: {"Ideographic"},
    99659: {"Ideographic"},
    99660: {"Ideographic"},
    99661: {"Ideographic"},
    99662: {"Ideographic"},
    99663: {"Ideographic"},
    99664: {"Ideographic"},
    99665: {"Ideographic"},
    99666: {"Ideographic"},
    99667: {"Ideographic"},
    99668: {"Ideographic"},
    99669: {"Ideographic"},
    99670: {"Ideographic"},
    99671: {"Ideographic"},
    99672: {"Ideographic"},
    99673: {"Ideographic"},
    99674: {"Ideographic"},
    99675: {"Ideographic"},
    99676: {"Ideographic"},
    99677: {"Ideographic"},
    99678: {"Ideographic"},
    99679: {"Ideographic"},
    99680: {"Ideographic"},
    99681: {"Ideographic"},
    99682: {"Ideographic"},
    99683: {"Ideographic"},
    99684: {"Ideographic"},
    99685: {"Ideographic"},
    99686: {"Ideographic"},
    99687: {"Ideographic"},
    99688: {"Ideographic"},
    99689: {"Ideographic"},
    99690: {"Ideographic"},
    99691: {"Ideographic"},
    99692: {"Ideographic"},
    99693: {"Ideographic"},
    99694: {"Ideographic"},
    99695: {"Ideographic"},
    99696: {"Ideographic"},
    99697: {"Ideographic"},
    99698: {"Ideographic"},
    99699: {"Ideographic"},
    99700: {"Ideographic"},
    99701: {"Ideographic"},
    99702: {"Ideographic"},
    99703: {"Ideographic"},
    99704: {"Ideographic"},
    99705: {"Ideographic"},
    99706: {"Ideographic"},
    99707: {"Ideographic"},
    99708: {"Ideographic"},
    99709: {"Ideographic"},
    99710: {"Ideographic"},
    99711: {"Ideographic"},
    99712: {"Ideographic"},
    99713: {"Ideographic"},
    99714: {"Ideographic"},
    99715: {"Ideographic"},
    99716: {"Ideographic"},
    99717: {"Ideographic"},
    99718: {"Ideographic"},
    99719: {"Ideographic"},
    99720: {"Ideographic"},
    99721: {"Ideographic"},
    99722: {"Ideographic"},
    99723: {"Ideographic"},
    99724: {"Ideographic"},
    99725: {"Ideographic"},
    99726: {"Ideographic"},
    99727: {"Ideographic"},
    99728: {"Ideographic"},
    99729: {"Ideographic"},
    99730: {"Ideographic"},
    99731: {"Ideographic"},
    99732: {"Ideographic"},
    99733: {"Ideographic"},
    99734: {"Ideographic"},
    99735: {"Ideographic"},
    99736: {"Ideographic"},
    99737: {"Ideographic"},
    99738: {"Ideographic"},
    99739: {"Ideographic"},
    99740: {"Ideographic"},
    99741: {"Ideographic"},
    99742: {"Ideographic"},
    99743: {"Ideographic"},
    99744: {"Ideographic"},
    99745: {"Ideographic"},
    99746: {"Ideographic"},
    99747: {"Ideographic"},
    99748: {"Ideographic"},
    99749: {"Ideographic"},
    99750: {"Ideographic"},
    99751: {"Ideographic"},
    99752: {"Ideographic"},
    99753: {"Ideographic"},
    99754: {"Ideographic"},
    99755: {"Ideographic"},
    99756: {"Ideographic"},
    99757: {"Ideographic"},
    99758: {"Ideographic"},
    99759: {"Ideographic"},
    99760: {"Ideographic"},
    99761: {"Ideographic"},
    99762: {"Ideographic"},
    99763: {"Ideographic"},
    99764: {"Ideographic"},
    99765: {"Ideographic"},
    99766: {"Ideographic"},
    99767: {"Ideographic"},
    99768: {"Ideographic"},
    99769: {"Ideographic"},
    99770: {"Ideographic"},
    99771: {"Ideographic"},
    99772: {"Ideographic"},
    99773: {"Ideographic"},
    99774: {"Ideographic"},
    99775: {"Ideographic"},
    99776: {"Ideographic"},
    99777: {"Ideographic"},
    99778: {"Ideographic"},
    99779: {"Ideographic"},
    99780: {"Ideographic"},
    99781: {"Ideographic"},
    99782: {"Ideographic"},
    99783: {"Ideographic"},
    99784: {"Ideographic"},
    99785: {"Ideographic"},
    99786: {"Ideographic"},
    99787: {"Ideographic"},
    99788: {"Ideographic"},
    99789: {"Ideographic"},
    99790: {"Ideographic"},
    99791: {"Ideographic"},
    99792: {"Ideographic"},
    99793: {"Ideographic"},
    99794: {"Ideographic"},
    99795: {"Ideographic"},
    99796: {"Ideographic"},
    99797: {"Ideographic"},
    99798: {"Ideographic"},
    99799: {"Ideographic"},
    99800: {"Ideographic"},
    99801: {"Ideographic"},
    99802: {"Ideographic"},
    99803: {"Ideographic"},
    99804: {"Ideographic"},
    99805: {"Ideographic"},
    99806: {"Ideographic"},
    99807: {"Ideographic"},
    99808: {"Ideographic"},
    99809: {"Ideographic"},
    99810: {"Ideographic"},
    99811: {"Ideographic"},
    99812: {"Ideographic"},
    99813: {"Ideographic"},
    99814: {"Ideographic"},
    99815: {"Ideographic"},
    99816: {"Ideographic"},
    99817: {"Ideographic"},
    99818: {"Ideographic"},
    99819: {"Ideographic"},
    99820: {"Ideographic"},
    99821: {"Ideographic"},
    99822: {"Ideographic"},
    99823: {"Ideographic"},
    99824: {"Ideographic"},
    99825: {"Ideographic"},
    99826: {"Ideographic"},
    99827: {"Ideographic"},
    99828: {"Ideographic"},
    99829: {"Ideographic"},
    99830: {"Ideographic"},
    99831: {"Ideographic"},
    99832: {"Ideographic"},
    99833: {"Ideographic"},
    99834: {"Ideographic"},
    99835: {"Ideographic"},
    99836: {"Ideographic"},
    99837: {"Ideographic"},
    99838: {"Ideographic"},
    99839: {"Ideographic"},
    99840: {"Ideographic"},
    99841: {"Ideographic"},
    99842: {"Ideographic"},
    99843: {"Ideographic"},
    99844: {"Ideographic"},
    99845: {"Ideographic"},
    99846: {"Ideographic"},
    99847: {"Ideographic"},
    99848: {"Ideographic"},
    99849: {"Ideographic"},
    99850: {"Ideographic"},
    99851: {"Ideographic"},
    99852: {"Ideographic"},
    99853: {"Ideographic"},
    99854: {"Ideographic"},
    99855: {"Ideographic"},
    99856: {"Ideographic"},
    99857: {"Ideographic"},
    99858: {"Ideographic"},
    99859: {"Ideographic"},
    99860: {"Ideographic"},
    99861: {"Ideographic"},
    99862: {"Ideographic"},
    99863: {"Ideographic"},
    99864: {"Ideographic"},
    99865: {"Ideographic"},
    99866: {"Ideographic"},
    99867: {"Ideographic"},
    99868: {"Ideographic"},
    99869: {"Ideographic"},
    99870: {"Ideographic"},
    99871: {"Ideographic"},
    99872: {"Ideographic"},
    99873: {"Ideographic"},
    99874: {"Ideographic"},
    99875: {"Ideographic"},
    99876: {"Ideographic"},
    99877: {"Ideographic"},
    99878: {"Ideographic"},
    99879: {"Ideographic"},
    99880: {"Ideographic"},
    99881: {"Ideographic"},
    99882: {"Ideographic"},
    99883: {"Ideographic"},
    99884: {"Ideographic"},
    99885: {"Ideographic"},
    99886: {"Ideographic"},
    99887: {"Ideographic"},
    99888: {"Ideographic"},
    99889: {"Ideographic"},
    99890: {"Ideographic"},
    99891: {"Ideographic"},
    99892: {"Ideographic"},
    99893: {"Ideographic"},
    99894: {"Ideographic"},
    99895: {"Ideographic"},
    99896: {"Ideographic"},
    99897: {"Ideographic"},
    99898: {"Ideographic"},
    99899: {"Ideographic"},
    99900: {"Ideographic"},
    99901: {"Ideographic"},
    99902: {"Ideographic"},
    99903: {"Ideographic"},
    99904: {"Ideographic"},
    99905: {"Ideographic"},
    99906: {"Ideographic"},
    99907: {"Ideographic"},
    99908: {"Ideographic"},
    99909: {"Ideographic"},
    99910: {"Ideographic"},
    99911: {"Ideographic"},
    99912: {"Ideographic"},
    99913: {"Ideographic"},
    99914: {"Ideographic"},
    99915: {"Ideographic"},
    99916: {"Ideographic"},
    99917: {"Ideographic"},
    99918: {"Ideographic"},
    99919: {"Ideographic"},
    99920: {"Ideographic"},
    99921: {"Ideographic"},
    99922: {"Ideographic"},
    99923: {"Ideographic"},
    99924: {"Ideographic"},
    99925: {"Ideographic"},
    99926: {"Ideographic"},
    99927: {"Ideographic"},
    99928: {"Ideographic"},
    99929: {"Ideographic"},
    99930: {"Ideographic"},
    99931: {"Ideographic"},
    99932: {"Ideographic"},
    99933: {"Ideographic"},
    99934: {"Ideographic"},
    99935: {"Ideographic"},
    99936: {"Ideographic"},
    99937: {"Ideographic"},
    99938: {"Ideographic"},
    99939: {"Ideographic"},
    99940: {"Ideographic"},
    99941: {"Ideographic"},
    99942: {"Ideographic"},
    99943: {"Ideographic"},
    99944: {"Ideographic"},
    99945: {"Ideographic"},
    99946: {"Ideographic"},
    99947: {"Ideographic"},
    99948: {"Ideographic"},
    99949: {"Ideographic"},
    99950: {"Ideographic"},
    99951: {"Ideographic"},
    99952: {"Ideographic"},
    99953: {"Ideographic"},
    99954: {"Ideographic"},
    99955: {"Ideographic"},
    99956: {"Ideographic"},
    99957: {"Ideographic"},
    99958: {"Ideographic"},
    99959: {"Ideographic"},
    99960: {"Ideographic"},
    99961: {"Ideographic"},
    99962: {"Ideographic"},
    99963: {"Ideographic"},
    99964: {"Ideographic"},
    99965: {"Ideographic"},
    99966: {"Ideographic"},
    99967: {"Ideographic"},
    99968: {"Ideographic"},
    99969: {"Ideographic"},
    99970: {"Ideographic"},
    99971: {"Ideographic"},
    99972: {"Ideographic"},
    99973: {"Ideographic"},
    99974: {"Ideographic"},
    99975: {"Ideographic"},
    99976: {"Ideographic"},
    99977: {"Ideographic"},
    99978: {"Ideographic"},
    99979: {"Ideographic"},
    99980: {"Ideographic"},
    99981: {"Ideographic"},
    99982: {"Ideographic"},
    99983: {"Ideographic"},
    99984: {"Ideographic"},
    99985: {"Ideographic"},
    99986: {"Ideographic"},
    99987: {"Ideographic"},
    99988: {"Ideographic"},
    99989: {"Ideographic"},
    99990: {"Ideographic"},
    99991: {"Ideographic"},
    99992: {"Ideographic"},
    99993: {"Ideographic"},
    99994: {"Ideographic"},
    99995: {"Ideographic"},
    99996: {"Ideographic"},
    99997: {"Ideographic"},
    99998: {"Ideographic"},
    99999: {"Ideographic"},
    100000: {"Ideographic"},
    100001: {"Ideographic"},
    100002: {"Ideographic"},
    100003: {"Ideographic"},
    100004: {"Ideographic"},
    100005: {"Ideographic"},
    100006: {"Ideographic"},
    100007: {"Ideographic"},
    100008: {"Ideographic"},
    100009: {"Ideographic"},
    100010: {"Ideographic"},
    100011: {"Ideographic"},
    100012: {"Ideographic"},
    100013: {"Ideographic"},
    100014: {"Ideographic"},
    100015: {"Ideographic"},
    100016: {"Ideographic"},
    100017: {"Ideographic"},
    100018: {"Ideographic"},
    100019: {"Ideographic"},
    100020: {"Ideographic"},
    100021: {"Ideographic"},
    100022: {"Ideographic"},
    100023: {"Ideographic"},
    100024: {"Ideographic"},
    100025: {"Ideographic"},
    100026: {"Ideographic"},
    100027: {"Ideographic"},
    100028: {"Ideographic"},
    100029: {"Ideographic"},
    100030: {"Ideographic"},
    100031: {"Ideographic"},
    100032: {"Ideographic"},
    100033: {"Ideographic"},
    100034: {"Ideographic"},
    100035: {"Ideographic"},
    100036: {"Ideographic"},
    100037: {"Ideographic"},
    100038: {"Ideographic"},
    100039: {"Ideographic"},
    100040: {"Ideographic"},
    100041: {"Ideographic"},
    100042: {"Ideographic"},
    100043: {"Ideographic"},
    100044: {"Ideographic"},
    100045: {"Ideographic"},
    100046: {"Ideographic"},
    100047: {"Ideographic"},
    100048: {"Ideographic"},
    100049: {"Ideographic"},
    100050: {"Ideographic"},
    100051: {"Ideographic"},
    100052: {"Ideographic"},
    100053: {"Ideographic"},
    100054: {"Ideographic"},
    100055: {"Ideographic"},
    100056: {"Ideographic"},
    100057: {"Ideographic"},
    100058: {"Ideographic"},
    100059: {"Ideographic"},
    100060: {"Ideographic"},
    100061: {"Ideographic"},
    100062: {"Ideographic"},
    100063: {"Ideographic"},
    100064: {"Ideographic"},
    100065: {"Ideographic"},
    100066: {"Ideographic"},
    100067: {"Ideographic"},
    100068: {"Ideographic"},
    100069: {"Ideographic"},
    100070: {"Ideographic"},
    100071: {"Ideographic"},
    100072: {"Ideographic"},
    100073: {"Ideographic"},
    100074: {"Ideographic"},
    100075: {"Ideographic"},
    100076: {"Ideographic"},
    100077: {"Ideographic"},
    100078: {"Ideographic"},
    100079: {"Ideographic"},
    100080: {"Ideographic"},
    100081: {"Ideographic"},
    100082: {"Ideographic"},
    100083: {"Ideographic"},
    100084: {"Ideographic"},
    100085: {"Ideographic"},
    100086: {"Ideographic"},
    100087: {"Ideographic"},
    100088: {"Ideographic"},
    100089: {"Ideographic"},
    100090: {"Ideographic"},
    100091: {"Ideographic"},
    100092: {"Ideographic"},
    100093: {"Ideographic"},
    100094: {"Ideographic"},
    100095: {"Ideographic"},
    100096: {"Ideographic"},
    100097: {"Ideographic"},
    100098: {"Ideographic"},
    100099: {"Ideographic"},
    100100: {"Ideographic"},
    100101: {"Ideographic"},
    100102: {"Ideographic"},
    100103: {"Ideographic"},
    100104: {"Ideographic"},
    100105: {"Ideographic"},
    100106: {"Ideographic"},
    100107: {"Ideographic"},
    100108: {"Ideographic"},
    100109: {"Ideographic"},
    100110: {"Ideographic"},
    100111: {"Ideographic"},
    100112: {"Ideographic"},
    100113: {"Ideographic"},
    100114: {"Ideographic"},
    100115: {"Ideographic"},
    100116: {"Ideographic"},
    100117: {"Ideographic"},
    100118: {"Ideographic"},
    100119: {"Ideographic"},
    100120: {"Ideographic"},
    100121: {"Ideographic"},
    100122: {"Ideographic"},
    100123: {"Ideographic"},
    100124: {"Ideographic"},
    100125: {"Ideographic"},
    100126: {"Ideographic"},
    100127: {"Ideographic"},
    100128: {"Ideographic"},
    100129: {"Ideographic"},
    100130: {"Ideographic"},
    100131: {"Ideographic"},
    100132: {"Ideographic"},
    100133: {"Ideographic"},
    100134: {"Ideographic"},
    100135: {"Ideographic"},
    100136: {"Ideographic"},
    100137: {"Ideographic"},
    100138: {"Ideographic"},
    100139: {"Ideographic"},
    100140: {"Ideographic"},
    100141: {"Ideographic"},
    100142: {"Ideographic"},
    100143: {"Ideographic"},
    100144: {"Ideographic"},
    100145: {"Ideographic"},
    100146: {"Ideographic"},
    100147: {"Ideographic"},
    100148: {"Ideographic"},
    100149: {"Ideographic"},
    100150: {"Ideographic"},
    100151: {"Ideographic"},
    100152: {"Ideographic"},
    100153: {"Ideographic"},
    100154: {"Ideographic"},
    100155: {"Ideographic"},
    100156: {"Ideographic"},
    100157: {"Ideographic"},
    100158: {"Ideographic"},
    100159: {"Ideographic"},
    100160: {"Ideographic"},
    100161: {"Ideographic"},
    100162: {"Ideographic"},
    100163: {"Ideographic"},
    100164: {"Ideographic"},
    100165: {"Ideographic"},
    100166: {"Ideographic"},
    100167: {"Ideographic"},
    100168: {"Ideographic"},
    100169: {"Ideographic"},
    100170: {"Ideographic"},
    100171: {"Ideographic"},
    100172: {"Ideographic"},
    100173: {"Ideographic"},
    100174: {"Ideographic"},
    100175: {"Ideographic"},
    100176: {"Ideographic"},
    100177: {"Ideographic"},
    100178: {"Ideographic"},
    100179: {"Ideographic"},
    100180: {"Ideographic"},
    100181: {"Ideographic"},
    100182: {"Ideographic"},
    100183: {"Ideographic"},
    100184: {"Ideographic"},
    100185: {"Ideographic"},
    100186: {"Ideographic"},
    100187: {"Ideographic"},
    100188: {"Ideographic"},
    100189: {"Ideographic"},
    100190: {"Ideographic"},
    100191: {"Ideographic"},
    100192: {"Ideographic"},
    100193: {"Ideographic"},
    100194: {"Ideographic"},
    100195: {"Ideographic"},
    100196: {"Ideographic"},
    100197: {"Ideographic"},
    100198: {"Ideographic"},
    100199: {"Ideographic"},
    100200: {"Ideographic"},
    100201: {"Ideographic"},
    100202: {"Ideographic"},
    100203: {"Ideographic"},
    100204: {"Ideographic"},
    100205: {"Ideographic"},
    100206: {"Ideographic"},
    100207: {"Ideographic"},
    100208: {"Ideographic"},
    100209: {"Ideographic"},
    100210: {"Ideographic"},
    100211: {"Ideographic"},
    100212: {"Ideographic"},
    100213: {"Ideographic"},
    100214: {"Ideographic"},
    100215: {"Ideographic"},
    100216: {"Ideographic"},
    100217: {"Ideographic"},
    100218: {"Ideographic"},
    100219: {"Ideographic"},
    100220: {"Ideographic"},
    100221: {"Ideographic"},
    100222: {"Ideographic"},
    100223: {"Ideographic"},
    100224: {"Ideographic"},
    100225: {"Ideographic"},
    100226: {"Ideographic"},
    100227: {"Ideographic"},
    100228: {"Ideographic"},
    100229: {"Ideographic"},
    100230: {"Ideographic"},
    100231: {"Ideographic"},
    100232: {"Ideographic"},
    100233: {"Ideographic"},
    100234: {"Ideographic"},
    100235: {"Ideographic"},
    100236: {"Ideographic"},
    100237: {"Ideographic"},
    100238: {"Ideographic"},
    100239: {"Ideographic"},
    100240: {"Ideographic"},
    100241: {"Ideographic"},
    100242: {"Ideographic"},
    100243: {"Ideographic"},
    100244: {"Ideographic"},
    100245: {"Ideographic"},
    100246: {"Ideographic"},
    100247: {"Ideographic"},
    100248: {"Ideographic"},
    100249: {"Ideographic"},
    100250: {"Ideographic"},
    100251: {"Ideographic"},
    100252: {"Ideographic"},
    100253: {"Ideographic"},
    100254: {"Ideographic"},
    100255: {"Ideographic"},
    100256: {"Ideographic"},
    100257: {"Ideographic"},
    100258: {"Ideographic"},
    100259: {"Ideographic"},
    100260: {"Ideographic"},
    100261: {"Ideographic"},
    100262: {"Ideographic"},
    100263: {"Ideographic"},
    100264: {"Ideographic"},
    100265: {"Ideographic"},
    100266: {"Ideographic"},
    100267: {"Ideographic"},
    100268: {"Ideographic"},
    100269: {"Ideographic"},
    100270: {"Ideographic"},
    100271: {"Ideographic"},
    100272: {"Ideographic"},
    100273: {"Ideographic"},
    100274: {"Ideographic"},
    100275: {"Ideographic"},
    100276: {"Ideographic"},
    100277: {"Ideographic"},
    100278: {"Ideographic"},
    100279: {"Ideographic"},
    100280: {"Ideographic"},
    100281: {"Ideographic"},
    100282: {"Ideographic"},
    100283: {"Ideographic"},
    100284: {"Ideographic"},
    100285: {"Ideographic"},
    100286: {"Ideographic"},
    100287: {"Ideographic"},
    100288: {"Ideographic"},
    100289: {"Ideographic"},
    100290: {"Ideographic"},
    100291: {"Ideographic"},
    100292: {"Ideographic"},
    100293: {"Ideographic"},
    100294: {"Ideographic"},
    100295: {"Ideographic"},
    100296: {"Ideographic"},
    100297: {"Ideographic"},
    100298: {"Ideographic"},
    100299: {"Ideographic"},
    100300: {"Ideographic"},
    100301: {"Ideographic"},
    100302: {"Ideographic"},
    100303: {"Ideographic"},
    100304: {"Ideographic"},
    100305: {"Ideographic"},
    100306: {"Ideographic"},
    100307: {"Ideographic"},
    100308: {"Ideographic"},
    100309: {"Ideographic"},
    100310: {"Ideographic"},
    100311: {"Ideographic"},
    100312: {"Ideographic"},
    100313: {"Ideographic"},
    100314: {"Ideographic"},
    100315: {"Ideographic"},
    100316: {"Ideographic"},
    100317: {"Ideographic"},
    100318: {"Ideographic"},
    100319: {"Ideographic"},
    100320: {"Ideographic"},
    100321: {"Ideographic"},
    100322: {"Ideographic"},
    100323: {"Ideographic"},
    100324: {"Ideographic"},
    100325: {"Ideographic"},
    100326: {"Ideographic"},
    100327: {"Ideographic"},
    100328: {"Ideographic"},
    100329: {"Ideographic"},
    100330: {"Ideographic"},
    100331: {"Ideographic"},
    100332: {"Ideographic"},
    100333: {"Ideographic"},
    100334: {"Ideographic"},
    100335: {"Ideographic"},
    100336: {"Ideographic"},
    100337: {"Ideographic"},
    100338: {"Ideographic"},
    100339: {"Ideographic"},
    100340: {"Ideographic"},
    100341: {"Ideographic"},
    100342: {"Ideographic"},
    100343: {"Ideographic"},
    100352: {"Ideographic"},
    100353: {"Ideographic"},
    100354: {"Ideographic"},
    100355: {"Ideographic"},
    100356: {"Ideographic"},
    100357: {"Ideographic"},
    100358: {"Ideographic"},
    100359: {"Ideographic"},
    100360: {"Ideographic"},
    100361: {"Ideographic"},
    100362: {"Ideographic"},
    100363: {"Ideographic"},
    100364: {"Ideographic"},
    100365: {"Ideographic"},
    100366: {"Ideographic"},
    100367: {"Ideographic"},
    100368: {"Ideographic"},
    100369: {"Ideographic"},
    100370: {"Ideographic"},
    100371: {"Ideographic"},
    100372: {"Ideographic"},
    100373: {"Ideographic"},
    100374: {"Ideographic"},
    100375: {"Ideographic"},
    100376: {"Ideographic"},
    100377: {"Ideographic"},
    100378: {"Ideographic"},
    100379: {"Ideographic"},
    100380: {"Ideographic"},
    100381: {"Ideographic"},
    100382: {"Ideographic"},
    100383: {"Ideographic"},
    100384: {"Ideographic"},
    100385: {"Ideographic"},
    100386: {"Ideographic"},
    100387: {"Ideographic"},
    100388: {"Ideographic"},
    100389: {"Ideographic"},
    100390: {"Ideographic"},
    100391: {"Ideographic"},
    100392: {"Ideographic"},
    100393: {"Ideographic"},
    100394: {"Ideographic"},
    100395: {"Ideographic"},
    100396: {"Ideographic"},
    100397: {"Ideographic"},
    100398: {"Ideographic"},
    100399: {"Ideographic"},
    100400: {"Ideographic"},
    100401: {"Ideographic"},
    100402: {"Ideographic"},
    100403: {"Ideographic"},
    100404: {"Ideographic"},
    100405: {"Ideographic"},
    100406: {"Ideographic"},
    100407: {"Ideographic"},
    100408: {"Ideographic"},
    100409: {"Ideographic"},
    100410: {"Ideographic"},
    100411: {"Ideographic"},
    100412: {"Ideographic"},
    100413: {"Ideographic"},
    100414: {"Ideographic"},
    100415: {"Ideographic"},
    100416: {"Ideographic"},
    100417: {"Ideographic"},
    100418: {"Ideographic"},
    100419: {"Ideographic"},
    100420: {"Ideographic"},
    100421: {"Ideographic"},
    100422: {"Ideographic"},
    100423: {"Ideographic"},
    100424: {"Ideographic"},
    100425: {"Ideographic"},
    100426: {"Ideographic"},
    100427: {"Ideographic"},
    100428: {"Ideographic"},
    100429: {"Ideographic"},
    100430: {"Ideographic"},
    100431: {"Ideographic"},
    100432: {"Ideographic"},
    100433: {"Ideographic"},
    100434: {"Ideographic"},
    100435: {"Ideographic"},
    100436: {"Ideographic"},
    100437: {"Ideographic"},
    100438: {"Ideographic"},
    100439: {"Ideographic"},
    100440: {"Ideographic"},
    100441: {"Ideographic"},
    100442: {"Ideographic"},
    100443: {"Ideographic"},
    100444: {"Ideographic"},
    100445: {"Ideographic"},
    100446: {"Ideographic"},
    100447: {"Ideographic"},
    100448: {"Ideographic"},
    100449: {"Ideographic"},
    100450: {"Ideographic"},
    100451: {"Ideographic"},
    100452: {"Ideographic"},
    100453: {"Ideographic"},
    100454: {"Ideographic"},
    100455: {"Ideographic"},
    100456: {"Ideographic"},
    100457: {"Ideographic"},
    100458: {"Ideographic"},
    100459: {"Ideographic"},
    100460: {"Ideographic"},
    100461: {"Ideographic"},
    100462: {"Ideographic"},
    100463: {"Ideographic"},
    100464: {"Ideographic"},
    100465: {"Ideographic"},
    100466: {"Ideographic"},
    100467: {"Ideographic"},
    100468: {"Ideographic"},
    100469: {"Ideographic"},
    100470: {"Ideographic"},
    100471: {"Ideographic"},
    100472: {"Ideographic"},
    100473: {"Ideographic"},
    100474: {"Ideographic"},
    100475: {"Ideographic"},
    100476: {"Ideographic"},
    100477: {"Ideographic"},
    100478: {"Ideographic"},
    100479: {"Ideographic"},
    100480: {"Ideographic"},
    100481: {"Ideographic"},
    100482: {"Ideographic"},
    100483: {"Ideographic"},
    100484: {"Ideographic"},
    100485: {"Ideographic"},
    100486: {"Ideographic"},
    100487: {"Ideographic"},
    100488: {"Ideographic"},
    100489: {"Ideographic"},
    100490: {"Ideographic"},
    100491: {"Ideographic"},
    100492: {"Ideographic"},
    100493: {"Ideographic"},
    100494: {"Ideographic"},
    100495: {"Ideographic"},
    100496: {"Ideographic"},
    100497: {"Ideographic"},
    100498: {"Ideographic"},
    100499: {"Ideographic"},
    100500: {"Ideographic"},
    100501: {"Ideographic"},
    100502: {"Ideographic"},
    100503: {"Ideographic"},
    100504: {"Ideographic"},
    100505: {"Ideographic"},
    100506: {"Ideographic"},
    100507: {"Ideographic"},
    100508: {"Ideographic"},
    100509: {"Ideographic"},
    100510: {"Ideographic"},
    100511: {"Ideographic"},
    100512: {"Ideographic"},
    100513: {"Ideographic"},
    100514: {"Ideographic"},
    100515: {"Ideographic"},
    100516: {"Ideographic"},
    100517: {"Ideographic"},
    100518: {"Ideographic"},
    100519: {"Ideographic"},
    100520: {"Ideographic"},
    100521: {"Ideographic"},
    100522: {"Ideographic"},
    100523: {"Ideographic"},
    100524: {"Ideographic"},
    100525: {"Ideographic"},
    100526: {"Ideographic"},
    100527: {"Ideographic"},
    100528: {"Ideographic"},
    100529: {"Ideographic"},
    100530: {"Ideographic"},
    100531: {"Ideographic"},
    100532: {"Ideographic"},
    100533: {"Ideographic"},
    100534: {"Ideographic"},
    100535: {"Ideographic"},
    100536: {"Ideographic"},
    100537: {"Ideographic"},
    100538: {"Ideographic"},
    100539: {"Ideographic"},
    100540: {"Ideographic"},
    100541: {"Ideographic"},
    100542: {"Ideographic"},
    100543: {"Ideographic"},
    100544: {"Ideographic"},
    100545: {"Ideographic"},
    100546: {"Ideographic"},
    100547: {"Ideographic"},
    100548: {"Ideographic"},
    100549: {"Ideographic"},
    100550: {"Ideographic"},
    100551: {"Ideographic"},
    100552: {"Ideographic"},
    100553: {"Ideographic"},
    100554: {"Ideographic"},
    100555: {"Ideographic"},
    100556: {"Ideographic"},
    100557: {"Ideographic"},
    100558: {"Ideographic"},
    100559: {"Ideographic"},
    100560: {"Ideographic"},
    100561: {"Ideographic"},
    100562: {"Ideographic"},
    100563: {"Ideographic"},
    100564: {"Ideographic"},
    100565: {"Ideographic"},
    100566: {"Ideographic"},
    100567: {"Ideographic"},
    100568: {"Ideographic"},
    100569: {"Ideographic"},
    100570: {"Ideographic"},
    100571: {"Ideographic"},
    100572: {"Ideographic"},
    100573: {"Ideographic"},
    100574: {"Ideographic"},
    100575: {"Ideographic"},
    100576: {"Ideographic"},
    100577: {"Ideographic"},
    100578: {"Ideographic"},
    100579: {"Ideographic"},
    100580: {"Ideographic"},
    100581: {"Ideographic"},
    100582: {"Ideographic"},
    100583: {"Ideographic"},
    100584: {"Ideographic"},
    100585: {"Ideographic"},
    100586: {"Ideographic"},
    100587: {"Ideographic"},
    100588: {"Ideographic"},
    100589: {"Ideographic"},
    100590: {"Ideographic"},
    100591: {"Ideographic"},
    100592: {"Ideographic"},
    100593: {"Ideographic"},
    100594: {"Ideographic"},
    100595: {"Ideographic"},
    100596: {"Ideographic"},
    100597: {"Ideographic"},
    100598: {"Ideographic"},
    100599: {"Ideographic"},
    100600: {"Ideographic"},
    100601: {"Ideographic"},
    100602: {"Ideographic"},
    100603: {"Ideographic"},
    100604: {"Ideographic"},
    100605: {"Ideographic"},
    100606: {"Ideographic"},
    100607: {"Ideographic"},
    100608: {"Ideographic"},
    100609: {"Ideographic"},
    100610: {"Ideographic"},
    100611: {"Ideographic"},
    100612: {"Ideographic"},
    100613: {"Ideographic"},
    100614: {"Ideographic"},
    100615: {"Ideographic"},
    100616: {"Ideographic"},
    100617: {"Ideographic"},
    100618: {"Ideographic"},
    100619: {"Ideographic"},
    100620: {"Ideographic"},
    100621: {"Ideographic"},
    100622: {"Ideographic"},
    100623: {"Ideographic"},
    100624: {"Ideographic"},
    100625: {"Ideographic"},
    100626: {"Ideographic"},
    100627: {"Ideographic"},
    100628: {"Ideographic"},
    100629: {"Ideographic"},
    100630: {"Ideographic"},
    100631: {"Ideographic"},
    100632: {"Ideographic"},
    100633: {"Ideographic"},
    100634: {"Ideographic"},
    100635: {"Ideographic"},
    100636: {"Ideographic"},
    100637: {"Ideographic"},
    100638: {"Ideographic"},
    100639: {"Ideographic"},
    100640: {"Ideographic"},
    100641: {"Ideographic"},
    100642: {"Ideographic"},
    100643: {"Ideographic"},
    100644: {"Ideographic"},
    100645: {"Ideographic"},
    100646: {"Ideographic"},
    100647: {"Ideographic"},
    100648: {"Ideographic"},
    100649: {"Ideographic"},
    100650: {"Ideographic"},
    100651: {"Ideographic"},
    100652: {"Ideographic"},
    100653: {"Ideographic"},
    100654: {"Ideographic"},
    100655: {"Ideographic"},
    100656: {"Ideographic"},
    100657: {"Ideographic"},
    100658: {"Ideographic"},
    100659: {"Ideographic"},
    100660: {"Ideographic"},
    100661: {"Ideographic"},
    100662: {"Ideographic"},
    100663: {"Ideographic"},
    100664: {"Ideographic"},
    100665: {"Ideographic"},
    100666: {"Ideographic"},
    100667: {"Ideographic"},
    100668: {"Ideographic"},
    100669: {"Ideographic"},
    100670: {"Ideographic"},
    100671: {"Ideographic"},
    100672: {"Ideographic"},
    100673: {"Ideographic"},
    100674: {"Ideographic"},
    100675: {"Ideographic"},
    100676: {"Ideographic"},
    100677: {"Ideographic"},
    100678: {"Ideographic"},
    100679: {"Ideographic"},
    100680: {"Ideographic"},
    100681: {"Ideographic"},
    100682: {"Ideographic"},
    100683: {"Ideographic"},
    100684: {"Ideographic"},
    100685: {"Ideographic"},
    100686: {"Ideographic"},
    100687: {"Ideographic"},
    100688: {"Ideographic"},
    100689: {"Ideographic"},
    100690: {"Ideographic"},
    100691: {"Ideographic"},
    100692: {"Ideographic"},
    100693: {"Ideographic"},
    100694: {"Ideographic"},
    100695: {"Ideographic"},
    100696: {"Ideographic"},
    100697: {"Ideographic"},
    100698: {"Ideographic"},
    100699: {"Ideographic"},
    100700: {"Ideographic"},
    100701: {"Ideographic"},
    100702: {"Ideographic"},
    100703: {"Ideographic"},
    100704: {"Ideographic"},
    100705: {"Ideographic"},
    100706: {"Ideographic"},
    100707: {"Ideographic"},
    100708: {"Ideographic"},
    100709: {"Ideographic"},
    100710: {"Ideographic"},
    100711: {"Ideographic"},
    100712: {"Ideographic"},
    100713: {"Ideographic"},
    100714: {"Ideographic"},
    100715: {"Ideographic"},
    100716: {"Ideographic"},
    100717: {"Ideographic"},
    100718: {"Ideographic"},
    100719: {"Ideographic"},
    100720: {"Ideographic"},
    100721: {"Ideographic"},
    100722: {"Ideographic"},
    100723: {"Ideographic"},
    100724: {"Ideographic"},
    100725: {"Ideographic"},
    100726: {"Ideographic"},
    100727: {"Ideographic"},
    100728: {"Ideographic"},
    100729: {"Ideographic"},
    100730: {"Ideographic"},
    100731: {"Ideographic"},
    100732: {"Ideographic"},
    100733: {"Ideographic"},
    100734: {"Ideographic"},
    100735: {"Ideographic"},
    100736: {"Ideographic"},
    100737: {"Ideographic"},
    100738: {"Ideographic"},
    100739: {"Ideographic"},
    100740: {"Ideographic"},
    100741: {"Ideographic"},
    100742: {"Ideographic"},
    100743: {"Ideographic"},
    100744: {"Ideographic"},
    100745: {"Ideographic"},
    100746: {"Ideographic"},
    100747: {"Ideographic"},
    100748: {"Ideographic"},
    100749: {"Ideographic"},
    100750: {"Ideographic"},
    100751: {"Ideographic"},
    100752: {"Ideographic"},
    100753: {"Ideographic"},
    100754: {"Ideographic"},
    100755: {"Ideographic"},
    100756: {"Ideographic"},
    100757: {"Ideographic"},
    100758: {"Ideographic"},
    100759: {"Ideographic"},
    100760: {"Ideographic"},
    100761: {"Ideographic"},
    100762: {"Ideographic"},
    100763: {"Ideographic"},
    100764: {"Ideographic"},
    100765: {"Ideographic"},
    100766: {"Ideographic"},
    100767: {"Ideographic"},
    100768: {"Ideographic"},
    100769: {"Ideographic"},
    100770: {"Ideographic"},
    100771: {"Ideographic"},
    100772: {"Ideographic"},
    100773: {"Ideographic"},
    100774: {"Ideographic"},
    100775: {"Ideographic"},
    100776: {"Ideographic"},
    100777: {"Ideographic"},
    100778: {"Ideographic"},
    100779: {"Ideographic"},
    100780: {"Ideographic"},
    100781: {"Ideographic"},
    100782: {"Ideographic"},
    100783: {"Ideographic"},
    100784: {"Ideographic"},
    100785: {"Ideographic"},
    100786: {"Ideographic"},
    100787: {"Ideographic"},
    100788: {"Ideographic"},
    100789: {"Ideographic"},
    100790: {"Ideographic"},
    100791: {"Ideographic"},
    100792: {"Ideographic"},
    100793: {"Ideographic"},
    100794: {"Ideographic"},
    100795: {"Ideographic"},
    100796: {"Ideographic"},
    100797: {"Ideographic"},
    100798: {"Ideographic"},
    100799: {"Ideographic"},
    100800: {"Ideographic"},
    100801: {"Ideographic"},
    100802: {"Ideographic"},
    100803: {"Ideographic"},
    100804: {"Ideographic"},
    100805: {"Ideographic"},
    100806: {"Ideographic"},
    100807: {"Ideographic"},
    100808: {"Ideographic"},
    100809: {"Ideographic"},
    100810: {"Ideographic"},
    100811: {"Ideographic"},
    100812: {"Ideographic"},
    100813: {"Ideographic"},
    100814: {"Ideographic"},
    100815: {"Ideographic"},
    100816: {"Ideographic"},
    100817: {"Ideographic"},
    100818: {"Ideographic"},
    100819: {"Ideographic"},
    100820: {"Ideographic"},
    100821: {"Ideographic"},
    100822: {"Ideographic"},
    100823: {"Ideographic"},
    100824: {"Ideographic"},
    100825: {"Ideographic"},
    100826: {"Ideographic"},
    100827: {"Ideographic"},
    100828: {"Ideographic"},
    100829: {"Ideographic"},
    100830: {"Ideographic"},
    100831: {"Ideographic"},
    100832: {"Ideographic"},
    100833: {"Ideographic"},
    100834: {"Ideographic"},
    100835: {"Ideographic"},
    100836: {"Ideographic"},
    100837: {"Ideographic"},
    100838: {"Ideographic"},
    100839: {"Ideographic"},
    100840: {"Ideographic"},
    100841: {"Ideographic"},
    100842: {"Ideographic"},
    100843: {"Ideographic"},
    100844: {"Ideographic"},
    100845: {"Ideographic"},
    100846: {"Ideographic"},
    100847: {"Ideographic"},
    100848: {"Ideographic"},
    100849: {"Ideographic"},
    100850: {"Ideographic"},
    100851: {"Ideographic"},
    100852: {"Ideographic"},
    100853: {"Ideographic"},
    100854: {"Ideographic"},
    100855: {"Ideographic"},
    100856: {"Ideographic"},
    100857: {"Ideographic"},
    100858: {"Ideographic"},
    100859: {"Ideographic"},
    100860: {"Ideographic"},
    100861: {"Ideographic"},
    100862: {"Ideographic"},
    100863: {"Ideographic"},
    100864: {"Ideographic"},
    100865: {"Ideographic"},
    100866: {"Ideographic"},
    100867: {"Ideographic"},
    100868: {"Ideographic"},
    100869: {"Ideographic"},
    100870: {"Ideographic"},
    100871: {"Ideographic"},
    100872: {"Ideographic"},
    100873: {"Ideographic"},
    100874: {"Ideographic"},
    100875: {"Ideographic"},
    100876: {"Ideographic"},
    100877: {"Ideographic"},
    100878: {"Ideographic"},
    100879: {"Ideographic"},
    100880: {"Ideographic"},
    100881: {"Ideographic"},
    100882: {"Ideographic"},
    100883: {"Ideographic"},
    100884: {"Ideographic"},
    100885: {"Ideographic"},
    100886: {"Ideographic"},
    100887: {"Ideographic"},
    100888: {"Ideographic"},
    100889: {"Ideographic"},
    100890: {"Ideographic"},
    100891: {"Ideographic"},
    100892: {"Ideographic"},
    100893: {"Ideographic"},
    100894: {"Ideographic"},
    100895: {"Ideographic"},
    100896: {"Ideographic"},
    100897: {"Ideographic"},
    100898: {"Ideographic"},
    100899: {"Ideographic"},
    100900: {"Ideographic"},
    100901: {"Ideographic"},
    100902: {"Ideographic"},
    100903: {"Ideographic"},
    100904: {"Ideographic"},
    100905: {"Ideographic"},
    100906: {"Ideographic"},
    100907: {"Ideographic"},
    100908: {"Ideographic"},
    100909: {"Ideographic"},
    100910: {"Ideographic"},
    100911: {"Ideographic"},
    100912: {"Ideographic"},
    100913: {"Ideographic"},
    100914: {"Ideographic"},
    100915: {"Ideographic"},
    100916: {"Ideographic"},
    100917: {"Ideographic"},
    100918: {"Ideographic"},
    100919: {"Ideographic"},
    100920: {"Ideographic"},
    100921: {"Ideographic"},
    100922: {"Ideographic"},
    100923: {"Ideographic"},
    100924: {"Ideographic"},
    100925: {"Ideographic"},
    100926: {"Ideographic"},
    100927: {"Ideographic"},
    100928: {"Ideographic"},
    100929: {"Ideographic"},
    100930: {"Ideographic"},
    100931: {"Ideographic"},
    100932: {"Ideographic"},
    100933: {"Ideographic"},
    100934: {"Ideographic"},
    100935: {"Ideographic"},
    100936: {"Ideographic"},
    100937: {"Ideographic"},
    100938: {"Ideographic"},
    100939: {"Ideographic"},
    100940: {"Ideographic"},
    100941: {"Ideographic"},
    100942: {"Ideographic"},
    100943: {"Ideographic"},
    100944: {"Ideographic"},
    100945: {"Ideographic"},
    100946: {"Ideographic"},
    100947: {"Ideographic"},
    100948: {"Ideographic"},
    100949: {"Ideographic"},
    100950: {"Ideographic"},
    100951: {"Ideographic"},
    100952: {"Ideographic"},
    100953: {"Ideographic"},
    100954: {"Ideographic"},
    100955: {"Ideographic"},
    100956: {"Ideographic"},
    100957: {"Ideographic"},
    100958: {"Ideographic"},
    100959: {"Ideographic"},
    100960: {"Ideographic"},
    100961: {"Ideographic"},
    100962: {"Ideographic"},
    100963: {"Ideographic"},
    100964: {"Ideographic"},
    100965: {"Ideographic"},
    100966: {"Ideographic"},
    100967: {"Ideographic"},
    100968: {"Ideographic"},
    100969: {"Ideographic"},
    100970: {"Ideographic"},
    100971: {"Ideographic"},
    100972: {"Ideographic"},
    100973: {"Ideographic"},
    100974: {"Ideographic"},
    100975: {"Ideographic"},
    100976: {"Ideographic"},
    100977: {"Ideographic"},
    100978: {"Ideographic"},
    100979: {"Ideographic"},
    100980: {"Ideographic"},
    100981: {"Ideographic"},
    100982: {"Ideographic"},
    100983: {"Ideographic"},
    100984: {"Ideographic"},
    100985: {"Ideographic"},
    100986: {"Ideographic"},
    100987: {"Ideographic"},
    100988: {"Ideographic"},
    100989: {"Ideographic"},
    100990: {"Ideographic"},
    100991: {"Ideographic"},
    100992: {"Ideographic"},
    100993: {"Ideographic"},
    100994: {"Ideographic"},
    100995: {"Ideographic"},
    100996: {"Ideographic"},
    100997: {"Ideographic"},
    100998: {"Ideographic"},
    100999: {"Ideographic"},
    101000: {"Ideographic"},
    101001: {"Ideographic"},
    101002: {"Ideographic"},
    101003: {"Ideographic"},
    101004: {"Ideographic"},
    101005: {"Ideographic"},
    101006: {"Ideographic"},
    101007: {"Ideographic"},
    101008: {"Ideographic"},
    101009: {"Ideographic"},
    101010: {"Ideographic"},
    101011: {"Ideographic"},
    101012: {"Ideographic"},
    101013: {"Ideographic"},
    101014: {"Ideographic"},
    101015: {"Ideographic"},
    101016: {"Ideographic"},
    101017: {"Ideographic"},
    101018: {"Ideographic"},
    101019: {"Ideographic"},
    101020: {"Ideographic"},
    101021: {"Ideographic"},
    101022: {"Ideographic"},
    101023: {"Ideographic"},
    101024: {"Ideographic"},
    101025: {"Ideographic"},
    101026: {"Ideographic"},
    101027: {"Ideographic"},
    101028: {"Ideographic"},
    101029: {"Ideographic"},
    101030: {"Ideographic"},
    101031: {"Ideographic"},
    101032: {"Ideographic"},
    101033: {"Ideographic"},
    101034: {"Ideographic"},
    101035: {"Ideographic"},
    101036: {"Ideographic"},
    101037: {"Ideographic"},
    101038: {"Ideographic"},
    101039: {"Ideographic"},
    101040: {"Ideographic"},
    101041: {"Ideographic"},
    101042: {"Ideographic"},
    101043: {"Ideographic"},
    101044: {"Ideographic"},
    101045: {"Ideographic"},
    101046: {"Ideographic"},
    101047: {"Ideographic"},
    101048: {"Ideographic"},
    101049: {"Ideographic"},
    101050: {"Ideographic"},
    101051: {"Ideographic"},
    101052: {"Ideographic"},
    101053: {"Ideographic"},
    101054: {"Ideographic"},
    101055: {"Ideographic"},
    101056: {"Ideographic"},
    101057: {"Ideographic"},
    101058: {"Ideographic"},
    101059: {"Ideographic"},
    101060: {"Ideographic"},
    101061: {"Ideographic"},
    101062: {"Ideographic"},
    101063: {"Ideographic"},
    101064: {"Ideographic"},
    101065: {"Ideographic"},
    101066: {"Ideographic"},
    101067: {"Ideographic"},
    101068: {"Ideographic"},
    101069: {"Ideographic"},
    101070: {"Ideographic"},
    101071: {"Ideographic"},
    101072: {"Ideographic"},
    101073: {"Ideographic"},
    101074: {"Ideographic"},
    101075: {"Ideographic"},
    101076: {"Ideographic"},
    101077: {"Ideographic"},
    101078: {"Ideographic"},
    101079: {"Ideographic"},
    101080: {"Ideographic"},
    101081: {"Ideographic"},
    101082: {"Ideographic"},
    101083: {"Ideographic"},
    101084: {"Ideographic"},
    101085: {"Ideographic"},
    101086: {"Ideographic"},
    101087: {"Ideographic"},
    101088: {"Ideographic"},
    101089: {"Ideographic"},
    101090: {"Ideographic"},
    101091: {"Ideographic"},
    101092: {"Ideographic"},
    101093: {"Ideographic"},
    101094: {"Ideographic"},
    101095: {"Ideographic"},
    101096: {"Ideographic"},
    101097: {"Ideographic"},
    101098: {"Ideographic"},
    101099: {"Ideographic"},
    101100: {"Ideographic"},
    101101: {"Ideographic"},
    101102: {"Ideographic"},
    101103: {"Ideographic"},
    101104: {"Ideographic"},
    101105: {"Ideographic"},
    101106: {"Ideographic"},
    101107: {"Ideographic"},
    101108: {"Ideographic"},
    101109: {"Ideographic"},
    101110: {"Ideographic"},
    101111: {"Ideographic"},
    101112: {"Ideographic"},
    101113: {"Ideographic"},
    101114: {"Ideographic"},
    101115: {"Ideographic"},
    101116: {"Ideographic"},
    101117: {"Ideographic"},
    101118: {"Ideographic"},
    101119: {"Ideographic"},
    101120: {"Ideographic"},
    101121: {"Ideographic"},
    101122: {"Ideographic"},
    101123: {"Ideographic"},
    101124: {"Ideographic"},
    101125: {"Ideographic"},
    101126: {"Ideographic"},
    101127: {"Ideographic"},
    101128: {"Ideographic"},
    101129: {"Ideographic"},
    101130: {"Ideographic"},
    101131: {"Ideographic"},
    101132: {"Ideographic"},
    101133: {"Ideographic"},
    101134: {"Ideographic"},
    101135: {"Ideographic"},
    101136: {"Ideographic"},
    101137: {"Ideographic"},
    101138: {"Ideographic"},
    101139: {"Ideographic"},
    101140: {"Ideographic"},
    101141: {"Ideographic"},
    101142: {"Ideographic"},
    101143: {"Ideographic"},
    101144: {"Ideographic"},
    101145: {"Ideographic"},
    101146: {"Ideographic"},
    101147: {"Ideographic"},
    101148: {"Ideographic"},
    101149: {"Ideographic"},
    101150: {"Ideographic"},
    101151: {"Ideographic"},
    101152: {"Ideographic"},
    101153: {"Ideographic"},
    101154: {"Ideographic"},
    101155: {"Ideographic"},
    101156: {"Ideographic"},
    101157: {"Ideographic"},
    101158: {"Ideographic"},
    101159: {"Ideographic"},
    101160: {"Ideographic"},
    101161: {"Ideographic"},
    101162: {"Ideographic"},
    101163: {"Ideographic"},
    101164: {"Ideographic"},
    101165: {"Ideographic"},
    101166: {"Ideographic"},
    101167: {"Ideographic"},
    101168: {"Ideographic"},
    101169: {"Ideographic"},
    101170: {"Ideographic"},
    101171: {"Ideographic"},
    101172: {"Ideographic"},
    101173: {"Ideographic"},
    101174: {"Ideographic"},
    101175: {"Ideographic"},
    101176: {"Ideographic"},
    101177: {"Ideographic"},
    101178: {"Ideographic"},
    101179: {"Ideographic"},
    101180: {"Ideographic"},
    101181: {"Ideographic"},
    101182: {"Ideographic"},
    101183: {"Ideographic"},
    101184: {"Ideographic"},
    101185: {"Ideographic"},
    101186: {"Ideographic"},
    101187: {"Ideographic"},
    101188: {"Ideographic"},
    101189: {"Ideographic"},
    101190: {"Ideographic"},
    101191: {"Ideographic"},
    101192: {"Ideographic"},
    101193: {"Ideographic"},
    101194: {"Ideographic"},
    101195: {"Ideographic"},
    101196: {"Ideographic"},
    101197: {"Ideographic"},
    101198: {"Ideographic"},
    101199: {"Ideographic"},
    101200: {"Ideographic"},
    101201: {"Ideographic"},
    101202: {"Ideographic"},
    101203: {"Ideographic"},
    101204: {"Ideographic"},
    101205: {"Ideographic"},
    101206: {"Ideographic"},
    101207: {"Ideographic"},
    101208: {"Ideographic"},
    101209: {"Ideographic"},
    101210: {"Ideographic"},
    101211: {"Ideographic"},
    101212: {"Ideographic"},
    101213: {"Ideographic"},
    101214: {"Ideographic"},
    101215: {"Ideographic"},
    101216: {"Ideographic"},
    101217: {"Ideographic"},
    101218: {"Ideographic"},
    101219: {"Ideographic"},
    101220: {"Ideographic"},
    101221: {"Ideographic"},
    101222: {"Ideographic"},
    101223: {"Ideographic"},
    101224: {"Ideographic"},
    101225: {"Ideographic"},
    101226: {"Ideographic"},
    101227: {"Ideographic"},
    101228: {"Ideographic"},
    101229: {"Ideographic"},
    101230: {"Ideographic"},
    101231: {"Ideographic"},
    101232: {"Ideographic"},
    101233: {"Ideographic"},
    101234: {"Ideographic"},
    101235: {"Ideographic"},
    101236: {"Ideographic"},
    101237: {"Ideographic"},
    101238: {"Ideographic"},
    101239: {"Ideographic"},
    101240: {"Ideographic"},
    101241: {"Ideographic"},
    101242: {"Ideographic"},
    101243: {"Ideographic"},
    101244: {"Ideographic"},
    101245: {"Ideographic"},
    101246: {"Ideographic"},
    101247: {"Ideographic"},
    101248: {"Ideographic"},
    101249: {"Ideographic"},
    101250: {"Ideographic"},
    101251: {"Ideographic"},
    101252: {"Ideographic"},
    101253: {"Ideographic"},
    101254: {"Ideographic"},
    101255: {"Ideographic"},
    101256: {"Ideographic"},
    101257: {"Ideographic"},
    101258: {"Ideographic"},
    101259: {"Ideographic"},
    101260: {"Ideographic"},
    101261: {"Ideographic"},
    101262: {"Ideographic"},
    101263: {"Ideographic"},
    101264: {"Ideographic"},
    101265: {"Ideographic"},
    101266: {"Ideographic"},
    101267: {"Ideographic"},
    101268: {"Ideographic"},
    101269: {"Ideographic"},
    101270: {"Ideographic"},
    101271: {"Ideographic"},
    101272: {"Ideographic"},
    101273: {"Ideographic"},
    101274: {"Ideographic"},
    101275: {"Ideographic"},
    101276: {"Ideographic"},
    101277: {"Ideographic"},
    101278: {"Ideographic"},
    101279: {"Ideographic"},
    101280: {"Ideographic"},
    101281: {"Ideographic"},
    101282: {"Ideographic"},
    101283: {"Ideographic"},
    101284: {"Ideographic"},
    101285: {"Ideographic"},
    101286: {"Ideographic"},
    101287: {"Ideographic"},
    101288: {"Ideographic"},
    101289: {"Ideographic"},
    101290: {"Ideographic"},
    101291: {"Ideographic"},
    101292: {"Ideographic"},
    101293: {"Ideographic"},
    101294: {"Ideographic"},
    101295: {"Ideographic"},
    101296: {"Ideographic"},
    101297: {"Ideographic"},
    101298: {"Ideographic"},
    101299: {"Ideographic"},
    101300: {"Ideographic"},
    101301: {"Ideographic"},
    101302: {"Ideographic"},
    101303: {"Ideographic"},
    101304: {"Ideographic"},
    101305: {"Ideographic"},
    101306: {"Ideographic"},
    101307: {"Ideographic"},
    101308: {"Ideographic"},
    101309: {"Ideographic"},
    101310: {"Ideographic"},
    101311: {"Ideographic"},
    101312: {"Ideographic"},
    101313: {"Ideographic"},
    101314: {"Ideographic"},
    101315: {"Ideographic"},
    101316: {"Ideographic"},
    101317: {"Ideographic"},
    101318: {"Ideographic"},
    101319: {"Ideographic"},
    101320: {"Ideographic"},
    101321: {"Ideographic"},
    101322: {"Ideographic"},
    101323: {"Ideographic"},
    101324: {"Ideographic"},
    101325: {"Ideographic"},
    101326: {"Ideographic"},
    101327: {"Ideographic"},
    101328: {"Ideographic"},
    101329: {"Ideographic"},
    101330: {"Ideographic"},
    101331: {"Ideographic"},
    101332: {"Ideographic"},
    101333: {"Ideographic"},
    101334: {"Ideographic"},
    101335: {"Ideographic"},
    101336: {"Ideographic"},
    101337: {"Ideographic"},
    101338: {"Ideographic"},
    101339: {"Ideographic"},
    101340: {"Ideographic"},
    101341: {"Ideographic"},
    101342: {"Ideographic"},
    101343: {"Ideographic"},
    101344: {"Ideographic"},
    101345: {"Ideographic"},
    101346: {"Ideographic"},
    101347: {"Ideographic"},
    101348: {"Ideographic"},
    101349: {"Ideographic"},
    101350: {"Ideographic"},
    101351: {"Ideographic"},
    101352: {"Ideographic"},
    101353: {"Ideographic"},
    101354: {"Ideographic"},
    101355: {"Ideographic"},
    101356: {"Ideographic"},
    101357: {"Ideographic"},
    101358: {"Ideographic"},
    101359: {"Ideographic"},
    101360: {"Ideographic"},
    101361: {"Ideographic"},
    101362: {"Ideographic"},
    101363: {"Ideographic"},
    101364: {"Ideographic"},
    101365: {"Ideographic"},
    101366: {"Ideographic"},
    101367: {"Ideographic"},
    101368: {"Ideographic"},
    101369: {"Ideographic"},
    101370: {"Ideographic"},
    101371: {"Ideographic"},
    101372: {"Ideographic"},
    101373: {"Ideographic"},
    101374: {"Ideographic"},
    101375: {"Ideographic"},
    101376: {"Ideographic"},
    101377: {"Ideographic"},
    101378: {"Ideographic"},
    101379: {"Ideographic"},
    101380: {"Ideographic"},
    101381: {"Ideographic"},
    101382: {"Ideographic"},
    101383: {"Ideographic"},
    101384: {"Ideographic"},
    101385: {"Ideographic"},
    101386: {"Ideographic"},
    101387: {"Ideographic"},
    101388: {"Ideographic"},
    101389: {"Ideographic"},
    101390: {"Ideographic"},
    101391: {"Ideographic"},
    101392: {"Ideographic"},
    101393: {"Ideographic"},
    101394: {"Ideographic"},
    101395: {"Ideographic"},
    101396: {"Ideographic"},
    101397: {"Ideographic"},
    101398: {"Ideographic"},
    101399: {"Ideographic"},
    101400: {"Ideographic"},
    101401: {"Ideographic"},
    101402: {"Ideographic"},
    101403: {"Ideographic"},
    101404: {"Ideographic"},
    101405: {"Ideographic"},
    101406: {"Ideographic"},
    101407: {"Ideographic"},
    101408: {"Ideographic"},
    101409: {"Ideographic"},
    101410: {"Ideographic"},
    101411: {"Ideographic"},
    101412: {"Ideographic"},
    101413: {"Ideographic"},
    101414: {"Ideographic"},
    101415: {"Ideographic"},
    101416: {"Ideographic"},
    101417: {"Ideographic"},
    101418: {"Ideographic"},
    101419: {"Ideographic"},
    101420: {"Ideographic"},
    101421: {"Ideographic"},
    101422: {"Ideographic"},
    101423: {"Ideographic"},
    101424: {"Ideographic"},
    101425: {"Ideographic"},
    101426: {"Ideographic"},
    101427: {"Ideographic"},
    101428: {"Ideographic"},
    101429: {"Ideographic"},
    101430: {"Ideographic"},
    101431: {"Ideographic"},
    101432: {"Ideographic"},
    101433: {"Ideographic"},
    101434: {"Ideographic"},
    101435: {"Ideographic"},
    101436: {"Ideographic"},
    101437: {"Ideographic"},
    101438: {"Ideographic"},
    101439: {"Ideographic"},
    101440: {"Ideographic"},
    101441: {"Ideographic"},
    101442: {"Ideographic"},
    101443: {"Ideographic"},
    101444: {"Ideographic"},
    101445: {"Ideographic"},
    101446: {"Ideographic"},
    101447: {"Ideographic"},
    101448: {"Ideographic"},
    101449: {"Ideographic"},
    101450: {"Ideographic"},
    101451: {"Ideographic"},
    101452: {"Ideographic"},
    101453: {"Ideographic"},
    101454: {"Ideographic"},
    101455: {"Ideographic"},
    101456: {"Ideographic"},
    101457: {"Ideographic"},
    101458: {"Ideographic"},
    101459: {"Ideographic"},
    101460: {"Ideographic"},
    101461: {"Ideographic"},
    101462: {"Ideographic"},
    101463: {"Ideographic"},
    101464: {"Ideographic"},
    101465: {"Ideographic"},
    101466: {"Ideographic"},
    101467: {"Ideographic"},
    101468: {"Ideographic"},
    101469: {"Ideographic"},
    101470: {"Ideographic"},
    101471: {"Ideographic"},
    101472: {"Ideographic"},
    101473: {"Ideographic"},
    101474: {"Ideographic"},
    101475: {"Ideographic"},
    101476: {"Ideographic"},
    101477: {"Ideographic"},
    101478: {"Ideographic"},
    101479: {"Ideographic"},
    101480: {"Ideographic"},
    101481: {"Ideographic"},
    101482: {"Ideographic"},
    101483: {"Ideographic"},
    101484: {"Ideographic"},
    101485: {"Ideographic"},
    101486: {"Ideographic"},
    101487: {"Ideographic"},
    101488: {"Ideographic"},
    101489: {"Ideographic"},
    101490: {"Ideographic"},
    101491: {"Ideographic"},
    101492: {"Ideographic"},
    101493: {"Ideographic"},
    101494: {"Ideographic"},
    101495: {"Ideographic"},
    101496: {"Ideographic"},
    101497: {"Ideographic"},
    101498: {"Ideographic"},
    101499: {"Ideographic"},
    101500: {"Ideographic"},
    101501: {"Ideographic"},
    101502: {"Ideographic"},
    101503: {"Ideographic"},
    101504: {"Ideographic"},
    101505: {"Ideographic"},
    101506: {"Ideographic"},
    101507: {"Ideographic"},
    101508: {"Ideographic"},
    101509: {"Ideographic"},
    101510: {"Ideographic"},
    101511: {"Ideographic"},
    101512: {"Ideographic"},
    101513: {"Ideographic"},
    101514: {"Ideographic"},
    101515: {"Ideographic"},
    101516: {"Ideographic"},
    101517: {"Ideographic"},
    101518: {"Ideographic"},
    101519: {"Ideographic"},
    101520: {"Ideographic"},
    101521: {"Ideographic"},
    101522: {"Ideographic"},
    101523: {"Ideographic"},
    101524: {"Ideographic"},
    101525: {"Ideographic"},
    101526: {"Ideographic"},
    101527: {"Ideographic"},
    101528: {"Ideographic"},
    101529: {"Ideographic"},
    101530: {"Ideographic"},
    101531: {"Ideographic"},
    101532: {"Ideographic"},
    101533: {"Ideographic"},
    101534: {"Ideographic"},
    101535: {"Ideographic"},
    101536: {"Ideographic"},
    101537: {"Ideographic"},
    101538: {"Ideographic"},
    101539: {"Ideographic"},
    101540: {"Ideographic"},
    101541: {"Ideographic"},
    101542: {"Ideographic"},
    101543: {"Ideographic"},
    101544: {"Ideographic"},
    101545: {"Ideographic"},
    101546: {"Ideographic"},
    101547: {"Ideographic"},
    101548: {"Ideographic"},
    101549: {"Ideographic"},
    101550: {"Ideographic"},
    101551: {"Ideographic"},
    101552: {"Ideographic"},
    101553: {"Ideographic"},
    101554: {"Ideographic"},
    101555: {"Ideographic"},
    101556: {"Ideographic"},
    101557: {"Ideographic"},
    101558: {"Ideographic"},
    101559: {"Ideographic"},
    101560: {"Ideographic"},
    101561: {"Ideographic"},
    101562: {"Ideographic"},
    101563: {"Ideographic"},
    101564: {"Ideographic"},
    101565: {"Ideographic"},
    101566: {"Ideographic"},
    101567: {"Ideographic"},
    101568: {"Ideographic"},
    101569: {"Ideographic"},
    101570: {"Ideographic"},
    101571: {"Ideographic"},
    101572: {"Ideographic"},
    101573: {"Ideographic"},
    101574: {"Ideographic"},
    101575: {"Ideographic"},
    101576: {"Ideographic"},
    101577: {"Ideographic"},
    101578: {"Ideographic"},
    101579: {"Ideographic"},
    101580: {"Ideographic"},
    101581: {"Ideographic"},
    101582: {"Ideographic"},
    101583: {"Ideographic"},
    101584: {"Ideographic"},
    101585: {"Ideographic"},
    101586: {"Ideographic"},
    101587: {"Ideographic"},
    101588: {"Ideographic"},
    101589: {"Ideographic"},
    101632: {"Ideographic"},
    101633: {"Ideographic"},
    101634: {"Ideographic"},
    101635: {"Ideographic"},
    101636: {"Ideographic"},
    101637: {"Ideographic"},
    101638: {"Ideographic"},
    101639: {"Ideographic"},
    101640: {"Ideographic"},
    110960: {"Ideographic"},
    110961: {"Ideographic"},
    110962: {"Ideographic"},
    110963: {"Ideographic"},
    110964: {"Ideographic"},
    110965: {"Ideographic"},
    110966: {"Ideographic"},
    110967: {"Ideographic"},
    110968: {"Ideographic"},
    110969: {"Ideographic"},
    110970: {"Ideographic"},
    110971: {"Ideographic"},
    110972: {"Ideographic"},
    110973: {"Ideographic"},
    110974: {"Ideographic"},
    110975: {"Ideographic"},
    110976: {"Ideographic"},
    110977: {"Ideographic"},
    110978: {"Ideographic"},
    110979: {"Ideographic"},
    110980: {"Ideographic"},
    110981: {"Ideographic"},
    110982: {"Ideographic"},
    110983: {"Ideographic"},
    110984: {"Ideographic"},
    110985: {"Ideographic"},
    110986: {"Ideographic"},
    110987: {"Ideographic"},
    110988: {"Ideographic"},
    110989: {"Ideographic"},
    110990: {"Ideographic"},
    110991: {"Ideographic"},
    110992: {"Ideographic"},
    110993: {"Ideographic"},
    110994: {"Ideographic"},
    110995: {"Ideographic"},
    110996: {"Ideographic"},
    110997: {"Ideographic"},
    110998: {"Ideographic"},
    110999: {"Ideographic"},
    111000: {"Ideographic"},
    111001: {"Ideographic"},
    111002: {"Ideographic"},
    111003: {"Ideographic"},
    111004: {"Ideographic"},
    111005: {"Ideographic"},
    111006: {"Ideographic"},
    111007: {"Ideographic"},
    111008: {"Ideographic"},
    111009: {"Ideographic"},
    111010: {"Ideographic"},
    111011: {"Ideographic"},
    111012: {"Ideographic"},
    111013: {"Ideographic"},
    111014: {"Ideographic"},
    111015: {"Ideographic"},
    111016: {"Ideographic"},
    111017: {"Ideographic"},
    111018: {"Ideographic"},
    111019: {"Ideographic"},
    111020: {"Ideographic"},
    111021: {"Ideographic"},
    111022: {"Ideographic"},
    111023: {"Ideographic"},
    111024: {"Ideographic"},
    111025: {"Ideographic"},
    111026: {"Ideographic"},
    111027: {"Ideographic"},
    111028: {"Ideographic"},
    111029: {"Ideographic"},
    111030: {"Ideographic"},
    111031: {"Ideographic"},
    111032: {"Ideographic"},
    111033: {"Ideographic"},
    111034: {"Ideographic"},
    111035: {"Ideographic"},
    111036: {"Ideographic"},
    111037: {"Ideographic"},
    111038: {"Ideographic"},
    111039: {"Ideographic"},
    111040: {"Ideographic"},
    111041: {"Ideographic"},
    111042: {"Ideographic"},
    111043: {"Ideographic"},
    111044: {"Ideographic"},
    111045: {"Ideographic"},
    111046: {"Ideographic"},
    111047: {"Ideographic"},
    111048: {"Ideographic"},
    111049: {"Ideographic"},
    111050: {"Ideographic"},
    111051: {"Ideographic"},
    111052: {"Ideographic"},
    111053: {"Ideographic"},
    111054: {"Ideographic"},
    111055: {"Ideographic"},
    111056: {"Ideographic"},
    111057: {"Ideographic"},
    111058: {"Ideographic"},
    111059: {"Ideographic"},
    111060: {"Ideographic"},
    111061: {"Ideographic"},
    111062: {"Ideographic"},
    111063: {"Ideographic"},
    111064: {"Ideographic"},
    111065: {"Ideographic"},
    111066: {"Ideographic"},
    111067: {"Ideographic"},
    111068: {"Ideographic"},
    111069: {"Ideographic"},
    111070: {"Ideographic"},
    111071: {"Ideographic"},
    111072: {"Ideographic"},
    111073: {"Ideographic"},
    111074: {"Ideographic"},
    111075: {"Ideographic"},
    111076: {"Ideographic"},
    111077: {"Ideographic"},
    111078: {"Ideographic"},
    111079: {"Ideographic"},
    111080: {"Ideographic"},
    111081: {"Ideographic"},
    111082: {"Ideographic"},
    111083: {"Ideographic"},
    111084: {"Ideographic"},
    111085: {"Ideographic"},
    111086: {"Ideographic"},
    111087: {"Ideographic"},
    111088: {"Ideographic"},
    111089: {"Ideographic"},
    111090: {"Ideographic"},
    111091: {"Ideographic"},
    111092: {"Ideographic"},
    111093: {"Ideographic"},
    111094: {"Ideographic"},
    111095: {"Ideographic"},
    111096: {"Ideographic"},
    111097: {"Ideographic"},
    111098: {"Ideographic"},
    111099: {"Ideographic"},
    111100: {"Ideographic"},
    111101: {"Ideographic"},
    111102: {"Ideographic"},
    111103: {"Ideographic"},
    111104: {"Ideographic"},
    111105: {"Ideographic"},
    111106: {"Ideographic"},
    111107: {"Ideographic"},
    111108: {"Ideographic"},
    111109: {"Ideographic"},
    111110: {"Ideographic"},
    111111: {"Ideographic"},
    111112: {"Ideographic"},
    111113: {"Ideographic"},
    111114: {"Ideographic"},
    111115: {"Ideographic"},
    111116: {"Ideographic"},
    111117: {"Ideographic"},
    111118: {"Ideographic"},
    111119: {"Ideographic"},
    111120: {"Ideographic"},
    111121: {"Ideographic"},
    111122: {"Ideographic"},
    111123: {"Ideographic"},
    111124: {"Ideographic"},
    111125: {"Ideographic"},
    111126: {"Ideographic"},
    111127: {"Ideographic"},
    111128: {"Ideographic"},
    111129: {"Ideographic"},
    111130: {"Ideographic"},
    111131: {"Ideographic"},
    111132: {"Ideographic"},
    111133: {"Ideographic"},
    111134: {"Ideographic"},
    111135: {"Ideographic"},
    111136: {"Ideographic"},
    111137: {"Ideographic"},
    111138: {"Ideographic"},
    111139: {"Ideographic"},
    111140: {"Ideographic"},
    111141: {"Ideographic"},
    111142: {"Ideographic"},
    111143: {"Ideographic"},
    111144: {"Ideographic"},
    111145: {"Ideographic"},
    111146: {"Ideographic"},
    111147: {"Ideographic"},
    111148: {"Ideographic"},
    111149: {"Ideographic"},
    111150: {"Ideographic"},
    111151: {"Ideographic"},
    111152: {"Ideographic"},
    111153: {"Ideographic"},
    111154: {"Ideographic"},
    111155: {"Ideographic"},
    111156: {"Ideographic"},
    111157: {"Ideographic"},
    111158: {"Ideographic"},
    111159: {"Ideographic"},
    111160: {"Ideographic"},
    111161: {"Ideographic"},
    111162: {"Ideographic"},
    111163: {"Ideographic"},
    111164: {"Ideographic"},
    111165: {"Ideographic"},
    111166: {"Ideographic"},
    111167: {"Ideographic"},
    111168: {"Ideographic"},
    111169: {"Ideographic"},
    111170: {"Ideographic"},
    111171: {"Ideographic"},
    111172: {"Ideographic"},
    111173: {"Ideographic"},
    111174: {"Ideographic"},
    111175: {"Ideographic"},
    111176: {"Ideographic"},
    111177: {"Ideographic"},
    111178: {"Ideographic"},
    111179: {"Ideographic"},
    111180: {"Ideographic"},
    111181: {"Ideographic"},
    111182: {"Ideographic"},
    111183: {"Ideographic"},
    111184: {"Ideographic"},
    111185: {"Ideographic"},
    111186: {"Ideographic"},
    111187: {"Ideographic"},
    111188: {"Ideographic"},
    111189: {"Ideographic"},
    111190: {"Ideographic"},
    111191: {"Ideographic"},
    111192: {"Ideographic"},
    111193: {"Ideographic"},
    111194: {"Ideographic"},
    111195: {"Ideographic"},
    111196: {"Ideographic"},
    111197: {"Ideographic"},
    111198: {"Ideographic"},
    111199: {"Ideographic"},
    111200: {"Ideographic"},
    111201: {"Ideographic"},
    111202: {"Ideographic"},
    111203: {"Ideographic"},
    111204: {"Ideographic"},
    111205: {"Ideographic"},
    111206: {"Ideographic"},
    111207: {"Ideographic"},
    111208: {"Ideographic"},
    111209: {"Ideographic"},
    111210: {"Ideographic"},
    111211: {"Ideographic"},
    111212: {"Ideographic"},
    111213: {"Ideographic"},
    111214: {"Ideographic"},
    111215: {"Ideographic"},
    111216: {"Ideographic"},
    111217: {"Ideographic"},
    111218: {"Ideographic"},
    111219: {"Ideographic"},
    111220: {"Ideographic"},
    111221: {"Ideographic"},
    111222: {"Ideographic"},
    111223: {"Ideographic"},
    111224: {"Ideographic"},
    111225: {"Ideographic"},
    111226: {"Ideographic"},
    111227: {"Ideographic"},
    111228: {"Ideographic"},
    111229: {"Ideographic"},
    111230: {"Ideographic"},
    111231: {"Ideographic"},
    111232: {"Ideographic"},
    111233: {"Ideographic"},
    111234: {"Ideographic"},
    111235: {"Ideographic"},
    111236: {"Ideographic"},
    111237: {"Ideographic"},
    111238: {"Ideographic"},
    111239: {"Ideographic"},
    111240: {"Ideographic"},
    111241: {"Ideographic"},
    111242: {"Ideographic"},
    111243: {"Ideographic"},
    111244: {"Ideographic"},
    111245: {"Ideographic"},
    111246: {"Ideographic"},
    111247: {"Ideographic"},
    111248: {"Ideographic"},
    111249: {"Ideographic"},
    111250: {"Ideographic"},
    111251: {"Ideographic"},
    111252: {"Ideographic"},
    111253: {"Ideographic"},
    111254: {"Ideographic"},
    111255: {"Ideographic"},
    111256: {"Ideographic"},
    111257: {"Ideographic"},
    111258: {"Ideographic"},
    111259: {"Ideographic"},
    111260: {"Ideographic"},
    111261: {"Ideographic"},
    111262: {"Ideographic"},
    111263: {"Ideographic"},
    111264: {"Ideographic"},
    111265: {"Ideographic"},
    111266: {"Ideographic"},
    111267: {"Ideographic"},
    111268: {"Ideographic"},
    111269: {"Ideographic"},
    111270: {"Ideographic"},
    111271: {"Ideographic"},
    111272: {"Ideographic"},
    111273: {"Ideographic"},
    111274: {"Ideographic"},
    111275: {"Ideographic"},
    111276: {"Ideographic"},
    111277: {"Ideographic"},
    111278: {"Ideographic"},
    111279: {"Ideographic"},
    111280: {"Ideographic"},
    111281: {"Ideographic"},
    111282: {"Ideographic"},
    111283: {"Ideographic"},
    111284: {"Ideographic"},
    111285: {"Ideographic"},
    111286: {"Ideographic"},
    111287: {"Ideographic"},
    111288: {"Ideographic"},
    111289: {"Ideographic"},
    111290: {"Ideographic"},
    111291: {"Ideographic"},
    111292: {"Ideographic"},
    111293: {"Ideographic"},
    111294: {"Ideographic"},
    111295: {"Ideographic"},
    111296: {"Ideographic"},
    111297: {"Ideographic"},
    111298: {"Ideographic"},
    111299: {"Ideographic"},
    111300: {"Ideographic"},
    111301: {"Ideographic"},
    111302: {"Ideographic"},
    111303: {"Ideographic"},
    111304: {"Ideographic"},
    111305: {"Ideographic"},
    111306: {"Ideographic"},
    111307: {"Ideographic"},
    111308: {"Ideographic"},
    111309: {"Ideographic"},
    111310: {"Ideographic"},
    111311: {"Ideographic"},
    111312: {"Ideographic"},
    111313: {"Ideographic"},
    111314: {"Ideographic"},
    111315: {"Ideographic"},
    111316: {"Ideographic"},
    111317: {"Ideographic"},
    111318: {"Ideographic"},
    111319: {"Ideographic"},
    111320: {"Ideographic"},
    111321: {"Ideographic"},
    111322: {"Ideographic"},
    111323: {"Ideographic"},
    111324: {"Ideographic"},
    111325: {"Ideographic"},
    111326: {"Ideographic"},
    111327: {"Ideographic"},
    111328: {"Ideographic"},
    111329: {"Ideographic"},
    111330: {"Ideographic"},
    111331: {"Ideographic"},
    111332: {"Ideographic"},
    111333: {"Ideographic"},
    111334: {"Ideographic"},
    111335: {"Ideographic"},
    111336: {"Ideographic"},
    111337: {"Ideographic"},
    111338: {"Ideographic"},
    111339: {"Ideographic"},
    111340: {"Ideographic"},
    111341: {"Ideographic"},
    111342: {"Ideographic"},
    111343: {"Ideographic"},
    111344: {"Ideographic"},
    111345: {"Ideographic"},
    111346: {"Ideographic"},
    111347: {"Ideographic"},
    111348: {"Ideographic"},
    111349: {"Ideographic"},
    111350: {"Ideographic"},
    111351: {"Ideographic"},
    111352: {"Ideographic"},
    111353: {"Ideographic"},
    111354: {"Ideographic"},
    111355: {"Ideographic"},
    113822: {"Other_Alphabetic"},
    113823: {"Terminal_Punctuation", "Sentence_Terminal"},
    119141: {"Other_Grapheme_Extend"},
    119143: {"Diacritic"},
    119144: {"Diacritic"},
    119145: {"Diacritic"},
    119149: {"Diacritic"},
    119150: {"Diacritic", "Other_Grapheme_Extend"},
    119151: {"Diacritic", "Other_Grapheme_Extend"},
    119152: {"Diacritic", "Other_Grapheme_Extend"},
    119153: {"Diacritic", "Other_Grapheme_Extend"},
    119154: {"Diacritic", "Other_Grapheme_Extend"},
    119163: {"Diacritic"},
    119164: {"Diacritic"},
    119165: {"Diacritic"},
    119166: {"Diacritic"},
    119167: {"Diacritic"},
    119168: {"Diacritic"},
    119169: {"Diacritic"},
    119170: {"Diacritic"},
    119173: {"Diacritic"},
    119174: {"Diacritic"},
    119175: {"Diacritic"},
    119176: {"Diacritic"},
    119177: {"Diacritic"},
    119178: {"Diacritic"},
    119179: {"Diacritic"},
    119210: {"Diacritic"},
    119211: {"Diacritic"},
    119212: {"Diacritic"},
    119213: {"Diacritic"},
    119808: {"Other_Math"},
    119809: {"Other_Math"},
    119810: {"Other_Math"},
    119811: {"Other_Math"},
    119812: {"Other_Math"},
    119813: {"Other_Math"},
    119814: {"Other_Math"},
    119815: {"Other_Math"},
    119816: {"Other_Math"},
    119817: {"Other_Math"},
    119818: {"Other_Math"},
    119819: {"Other_Math"},
    119820: {"Other_Math"},
    119821: {"Other_Math"},
    119822: {"Other_Math"},
    119823: {"Other_Math"},
    119824: {"Other_Math"},
    119825: {"Other_Math"},
    119826: {"Other_Math"},
    119827: {"Other_Math"},
    119828: {"Other_Math"},
    119829: {"Other_Math"},
    119830: {"Other_Math"},
    119831: {"Other_Math"},
    119832: {"Other_Math"},
    119833: {"Other_Math"},
    119834: {"Other_Math"},
    119835: {"Other_Math"},
    119836: {"Other_Math"},
    119837: {"Other_Math"},
    119838: {"Other_Math"},
    119839: {"Other_Math"},
    119840: {"Other_Math"},
    119841: {"Other_Math"},
    119842: {"Soft_Dotted", "Other_Math"},
    119843: {"Soft_Dotted", "Other_Math"},
    119844: {"Other_Math"},
    119845: {"Other_Math"},
    119846: {"Other_Math"},
    119847: {"Other_Math"},
    119848: {"Other_Math"},
    119849: {"Other_Math"},
    119850: {"Other_Math"},
    119851: {"Other_Math"},
    119852: {"Other_Math"},
    119853: {"Other_Math"},
    119854: {"Other_Math"},
    119855: {"Other_Math"},
    119856: {"Other_Math"},
    119857: {"Other_Math"},
    119858: {"Other_Math"},
    119859: {"Other_Math"},
    119860: {"Other_Math"},
    119861: {"Other_Math"},
    119862: {"Other_Math"},
    119863: {"Other_Math"},
    119864: {"Other_Math"},
    119865: {"Other_Math"},
    119866: {"Other_Math"},
    119867: {"Other_Math"},
    119868: {"Other_Math"},
    119869: {"Other_Math"},
    119870: {"Other_Math"},
    119871: {"Other_Math"},
    119872: {"Other_Math"},
    119873: {"Other_Math"},
    119874: {"Other_Math"},
    119875: {"Other_Math"},
    119876: {"Other_Math"},
    119877: {"Other_Math"},
    119878: {"Other_Math"},
    119879: {"Other_Math"},
    119880: {"Other_Math"},
    119881: {"Other_Math"},
    119882: {"Other_Math"},
    119883: {"Other_Math"},
    119884: {"Other_Math"},
    119885: {"Other_Math"},
    119886: {"Other_Math"},
    119887: {"Other_Math"},
    119888: {"Other_Math"},
    119889: {"Other_Math"},
    119890: {"Other_Math"},
    119891: {"Other_Math"},
    119892: {"Other_Math"},
    119894: {"Soft_Dotted", "Other_Math"},
    119895: {"Soft_Dotted", "Other_Math"},
    119896: {"Other_Math"},
    119897: {"Other_Math"},
    119898: {"Other_Math"},
    119899: {"Other_Math"},
    119900: {"Other_Math"},
    119901: {"Other_Math"},
    119902: {"Other_Math"},
    119903: {"Other_Math"},
    119904: {"Other_Math"},
    119905: {"Other_Math"},
    119906: {"Other_Math"},
    119907: {"Other_Math"},
    119908: {"Other_Math"},
    119909: {"Other_Math"},
    119910: {"Other_Math"},
    119911: {"Other_Math"},
    119912: {"Other_Math"},
    119913: {"Other_Math"},
    119914: {"Other_Math"},
    119915: {"Other_Math"},
    119916: {"Other_Math"},
    119917: {"Other_Math"},
    119918: {"Other_Math"},
    119919: {"Other_Math"},
    119920: {"Other_Math"},
    119921: {"Other_Math"},
    119922: {"Other_Math"},
    119923: {"Other_Math"},
    119924: {"Other_Math"},
    119925: {"Other_Math"},
    119926: {"Other_Math"},
    119927: {"Other_Math"},
    119928: {"Other_Math"},
    119929: {"Other_Math"},
    119930: {"Other_Math"},
    119931: {"Other_Math"},
    119932: {"Other_Math"},
    119933: {"Other_Math"},
    119934: {"Other_Math"},
    119935: {"Other_Math"},
    119936: {"Other_Math"},
    119937: {"Other_Math"},
    119938: {"Other_Math"},
    119939: {"Other_Math"},
    119940: {"Other_Math"},
    119941: {"Other_Math"},
    119942: {"Other_Math"},
    119943: {"Other_Math"},
    119944: {"Other_Math"},
    119945: {"Other_Math"},
    119946: {"Soft_Dotted", "Other_Math"},
    119947: {"Soft_Dotted", "Other_Math"},
    119948: {"Other_Math"},
    119949: {"Other_Math"},
    119950: {"Other_Math"},
    119951: {"Other_Math"},
    119952: {"Other_Math"},
    119953: {"Other_Math"},
    119954: {"Other_Math"},
    119955: {"Other_Math"},
    119956: {"Other_Math"},
    119957: {"Other_Math"},
    119958: {"Other_Math"},
    119959: {"Other_Math"},
    119960: {"Other_Math"},
    119961: {"Other_Math"},
    119962: {"Other_Math"},
    119963: {"Other_Math"},
    119964: {"Other_Math"},
    119966: {"Other_Math"},
    119967: {"Other_Math"},
    119970: {"Other_Math"},
    119973: {"Other_Math"},
    119974: {"Other_Math"},
    119977: {"Other_Math"},
    119978: {"Other_Math"},
    119979: {"Other_Math"},
    119980: {"Other_Math"},
    119982: {"Other_Math"},
    119983: {"Other_Math"},
    119984: {"Other_Math"},
    119985: {"Other_Math"},
    119986: {"Other_Math"},
    119987: {"Other_Math"},
    119988: {"Other_Math"},
    119989: {"Other_Math"},
    119990: {"Other_Math"},
    119991: {"Other_Math"},
    119992: {"Other_Math"},
    119993: {"Other_Math"},
    119995: {"Other_Math"},
    119997: {"Other_Math"},
    119998: {"Soft_Dotted", "Other_Math"},
    119999: {"Soft_Dotted", "Other_Math"},
    120000: {"Other_Math"},
    120001: {"Other_Math"},
    120002: {"Other_Math"},
    120003: {"Other_Math"},
    120005: {"Other_Math"},
    120006: {"Other_Math"},
    120007: {"Other_Math"},
    120008: {"Other_Math"},
    120009: {"Other_Math"},
    120010: {"Other_Math"},
    120011: {"Other_Math"},
    120012: {"Other_Math"},
    120013: {"Other_Math"},
    120014: {"Other_Math"},
    120015: {"Other_Math"},
    120016: {"Other_Math"},
    120017: {"Other_Math"},
    120018: {"Other_Math"},
    120019: {"Other_Math"},
    120020: {"Other_Math"},
    120021: {"Other_Math"},
    120022: {"Other_Math"},
    120023: {"Other_Math"},
    120024: {"Other_Math"},
    120025: {"Other_Math"},
    120026: {"Other_Math"},
    120027: {"Other_Math"},
    120028: {"Other_Math"},
    120029: {"Other_Math"},
    120030: {"Other_Math"},
    120031: {"Other_Math"},
    120032: {"Other_Math"},
    120033: {"Other_Math"},
    120034: {"Other_Math"},
    120035: {"Other_Math"},
    120036: {"Other_Math"},
    120037: {"Other_Math"},
    120038: {"Other_Math"},
    120039: {"Other_Math"},
    120040: {"Other_Math"},
    120041: {"Other_Math"},
    120042: {"Other_Math"},
    120043: {"Other_Math"},
    120044: {"Other_Math"},
    120045: {"Other_Math"},
    120046: {"Other_Math"},
    120047: {"Other_Math"},
    120048: {"Other_Math"},
    120049: {"Other_Math"},
    120050: {"Soft_Dotted", "Other_Math"},
    120051: {"Soft_Dotted", "Other_Math"},
    120052: {"Other_Math"},
    120053: {"Other_Math"},
    120054: {"Other_Math"},
    120055: {"Other_Math"},
    120056: {"Other_Math"},
    120057: {"Other_Math"},
    120058: {"Other_Math"},
    120059: {"Other_Math"},
    120060: {"Other_Math"},
    120061: {"Other_Math"},
    120062: {"Other_Math"},
    120063: {"Other_Math"},
    120064: {"Other_Math"},
    120065: {"Other_Math"},
    120066: {"Other_Math"},
    120067: {"Other_Math"},
    120068: {"Other_Math"},
    120069: {"Other_Math"},
    120071: {"Other_Math"},
    120072: {"Other_Math"},
    120073: {"Other_Math"},
    120074: {"Other_Math"},
    120077: {"Other_Math"},
    120078: {"Other_Math"},
    120079: {"Other_Math"},
    120080: {"Other_Math"},
    120081: {"Other_Math"},
    120082: {"Other_Math"},
    120083: {"Other_Math"},
    120084: {"Other_Math"},
    120086: {"Other_Math"},
    120087: {"Other_Math"},
    120088: {"Other_Math"},
    120089: {"Other_Math"},
    120090: {"Other_Math"},
    120091: {"Other_Math"},
    120092: {"Other_Math"},
    120094: {"Other_Math"},
    120095: {"Other_Math"},
    120096: {"Other_Math"},
    120097: {"Other_Math"},
    120098: {"Other_Math"},
    120099: {"Other_Math"},
    120100: {"Other_Math"},
    120101: {"Other_Math"},
    120102: {"Soft_Dotted", "Other_Math"},
    120103: {"Soft_Dotted", "Other_Math"},
    120104: {"Other_Math"},
    120105: {"Other_Math"},
    120106: {"Other_Math"},
    120107: {"Other_Math"},
    120108: {"Other_Math"},
    120109: {"Other_Math"},
    120110: {"Other_Math"},
    120111: {"Other_Math"},
    120112: {"Other_Math"},
    120113: {"Other_Math"},
    120114: {"Other_Math"},
    120115: {"Other_Math"},
    120116: {"Other_Math"},
    120117: {"Other_Math"},
    120118: {"Other_Math"},
    120119: {"Other_Math"},
    120120: {"Other_Math"},
    120121: {"Other_Math"},
    120123: {"Other_Math"},
    120124: {"Other_Math"},
    120125: {"Other_Math"},
    120126: {"Other_Math"},
    120128: {"Other_Math"},
    120129: {"Other_Math"},
    120130: {"Other_Math"},
    120131: {"Other_Math"},
    120132: {"Other_Math"},
    120134: {"Other_Math"},
    120138: {"Other_Math"},
    120139: {"Other_Math"},
    120140: {"Other_Math"},
    120141: {"Other_Math"},
    120142: {"Other_Math"},
    120143: {"Other_Math"},
    120144: {"Other_Math"},
    120146: {"Other_Math"},
    120147: {"Other_Math"},
    120148: {"Other_Math"},
    120149: {"Other_Math"},
    120150: {"Other_Math"},
    120151: {"Other_Math"},
    120152: {"Other_Math"},
    120153: {"Other_Math"},
    120154: {"Soft_Dotted", "Other_Math"},
    120155: {"Soft_Dotted", "Other_Math"},
    120156: {"Other_Math"},
    120157: {"Other_Math"},
    120158: {"Other_Math"},
    120159: {"Other_Math"},
    120160: {"Other_Math"},
    120161: {"Other_Math"},
    120162: {"Other_Math"},
    120163: {"Other_Math"},
    120164: {"Other_Math"},
    120165: {"Other_Math"},
    120166: {"Other_Math"},
    120167: {"Other_Math"},
    120168: {"Other_Math"},
    120169: {"Other_Math"},
    120170: {"Other_Math"},
    120171: {"Other_Math"},
    120172: {"Other_Math"},
    120173: {"Other_Math"},
    120174: {"Other_Math"},
    120175: {"Other_Math"},
    120176: {"Other_Math"},
    120177: {"Other_Math"},
    120178: {"Other_Math"},
    120179: {"Other_Math"},
    120180: {"Other_Math"},
    120181: {"Other_Math"},
    120182: {"Other_Math"},
    120183: {"Other_Math"},
    120184: {"Other_Math"},
    120185: {"Other_Math"},
    120186: {"Other_Math"},
    120187: {"Other_Math"},
    120188: {"Other_Math"},
    120189: {"Other_Math"},
    120190: {"Other_Math"},
    120191: {"Other_Math"},
    120192: {"Other_Math"},
    120193: {"Other_Math"},
    120194: {"Other_Math"},
    120195: {"Other_Math"},
    120196: {"Other_Math"},
    120197: {"Other_Math"},
    120198: {"Other_Math"},
    120199: {"Other_Math"},
    120200: {"Other_Math"},
    120201: {"Other_Math"},
    120202: {"Other_Math"},
    120203: {"Other_Math"},
    120204: {"Other_Math"},
    120205: {"Other_Math"},
    120206: {"Soft_Dotted", "Other_Math"},
    120207: {"Soft_Dotted", "Other_Math"},
    120208: {"Other_Math"},
    120209: {"Other_Math"},
    120210: {"Other_Math"},
    120211: {"Other_Math"},
    120212: {"Other_Math"},
    120213: {"Other_Math"},
    120214: {"Other_Math"},
    120215: {"Other_Math"},
    120216: {"Other_Math"},
    120217: {"Other_Math"},
    120218: {"Other_Math"},
    120219: {"Other_Math"},
    120220: {"Other_Math"},
    120221: {"Other_Math"},
    120222: {"Other_Math"},
    120223: {"Other_Math"},
    120224: {"Other_Math"},
    120225: {"Other_Math"},
    120226: {"Other_Math"},
    120227: {"Other_Math"},
    120228: {"Other_Math"},
    120229: {"Other_Math"},
    120230: {"Other_Math"},
    120231: {"Other_Math"},
    120232: {"Other_Math"},
    120233: {"Other_Math"},
    120234: {"Other_Math"},
    120235: {"Other_Math"},
    120236: {"Other_Math"},
    120237: {"Other_Math"},
    120238: {"Other_Math"},
    120239: {"Other_Math"},
    120240: {"Other_Math"},
    120241: {"Other_Math"},
    120242: {"Other_Math"},
    120243: {"Other_Math"},
    120244: {"Other_Math"},
    120245: {"Other_Math"},
    120246: {"Other_Math"},
    120247: {"Other_Math"},
    120248: {"Other_Math"},
    120249: {"Other_Math"},
    120250: {"Other_Math"},
    120251: {"Other_Math"},
    120252: {"Other_Math"},
    120253: {"Other_Math"},
    120254: {"Other_Math"},
    120255: {"Other_Math"},
    120256: {"Other_Math"},
    120257: {"Other_Math"},
    120258: {"Soft_Dotted", "Other_Math"},
    120259: {"Soft_Dotted", "Other_Math"},
    120260: {"Other_Math"},
    120261: {"Other_Math"},
    120262: {"Other_Math"},
    120263: {"Other_Math"},
    120264: {"Other_Math"},
    120265: {"Other_Math"},
    120266: {"Other_Math"},
    120267: {"Other_Math"},
    120268: {"Other_Math"},
    120269: {"Other_Math"},
    120270: {"Other_Math"},
    120271: {"Other_Math"},
    120272: {"Other_Math"},
    120273: {"Other_Math"},
    120274: {"Other_Math"},
    120275: {"Other_Math"},
    120276: {"Other_Math"},
    120277: {"Other_Math"},
    120278: {"Other_Math"},
    120279: {"Other_Math"},
    120280: {"Other_Math"},
    120281: {"Other_Math"},
    120282: {"Other_Math"},
    120283: {"Other_Math"},
    120284: {"Other_Math"},
    120285: {"Other_Math"},
    120286: {"Other_Math"},
    120287: {"Other_Math"},
    120288: {"Other_Math"},
    120289: {"Other_Math"},
    120290: {"Other_Math"},
    120291: {"Other_Math"},
    120292: {"Other_Math"},
    120293: {"Other_Math"},
    120294: {"Other_Math"},
    120295: {"Other_Math"},
    120296: {"Other_Math"},
    120297: {"Other_Math"},
    120298: {"Other_Math"},
    120299: {"Other_Math"},
    120300: {"Other_Math"},
    120301: {"Other_Math"},
    120302: {"Other_Math"},
    120303: {"Other_Math"},
    120304: {"Other_Math"},
    120305: {"Other_Math"},
    120306: {"Other_Math"},
    120307: {"Other_Math"},
    120308: {"Other_Math"},
    120309: {"Other_Math"},
    120310: {"Soft_Dotted", "Other_Math"},
    120311: {"Soft_Dotted", "Other_Math"},
    120312: {"Other_Math"},
    120313: {"Other_Math"},
    120314: {"Other_Math"},
    120315: {"Other_Math"},
    120316: {"Other_Math"},
    120317: {"Other_Math"},
    120318: {"Other_Math"},
    120319: {"Other_Math"},
    120320: {"Other_Math"},
    120321: {"Other_Math"},
    120322: {"Other_Math"},
    120323: {"Other_Math"},
    120324: {"Other_Math"},
    120325: {"Other_Math"},
    120326: {"Other_Math"},
    120327: {"Other_Math"},
    120328: {"Other_Math"},
    120329: {"Other_Math"},
    120330: {"Other_Math"},
    120331: {"Other_Math"},
    120332: {"Other_Math"},
    120333: {"Other_Math"},
    120334: {"Other_Math"},
    120335: {"Other_Math"},
    120336: {"Other_Math"},
    120337: {"Other_Math"},
    120338: {"Other_Math"},
    120339: {"Other_Math"},
    120340: {"Other_Math"},
    120341: {"Other_Math"},
    120342: {"Other_Math"},
    120343: {"Other_Math"},
    120344: {"Other_Math"},
    120345: {"Other_Math"},
    120346: {"Other_Math"},
    120347: {"Other_Math"},
    120348: {"Other_Math"},
    120349: {"Other_Math"},
    120350: {"Other_Math"},
    120351: {"Other_Math"},
    120352: {"Other_Math"},
    120353: {"Other_Math"},
    120354: {"Other_Math"},
    120355: {"Other_Math"},
    120356: {"Other_Math"},
    120357: {"Other_Math"},
    120358: {"Other_Math"},
    120359: {"Other_Math"},
    120360: {"Other_Math"},
    120361: {"Other_Math"},
    120362: {"Soft_Dotted", "Other_Math"},
    120363: {"Soft_Dotted", "Other_Math"},
    120364: {"Other_Math"},
    120365: {"Other_Math"},
    120366: {"Other_Math"},
    120367: {"Other_Math"},
    120368: {"Other_Math"},
    120369: {"Other_Math"},
    120370: {"Other_Math"},
    120371: {"Other_Math"},
    120372: {"Other_Math"},
    120373: {"Other_Math"},
    120374: {"Other_Math"},
    120375: {"Other_Math"},
    120376: {"Other_Math"},
    120377: {"Other_Math"},
    120378: {"Other_Math"},
    120379: {"Other_Math"},
    120380: {"Other_Math"},
    120381: {"Other_Math"},
    120382: {"Other_Math"},
    120383: {"Other_Math"},
    120384: {"Other_Math"},
    120385: {"Other_Math"},
    120386: {"Other_Math"},
    120387: {"Other_Math"},
    120388: {"Other_Math"},
    120389: {"Other_Math"},
    120390: {"Other_Math"},
    120391: {"Other_Math"},
    120392: {"Other_Math"},
    120393: {"Other_Math"},
    120394: {"Other_Math"},
    120395: {"Other_Math"},
    120396: {"Other_Math"},
    120397: {"Other_Math"},
    120398: {"Other_Math"},
    120399: {"Other_Math"},
    120400: {"Other_Math"},
    120401: {"Other_Math"},
    120402: {"Other_Math"},
    120403: {"Other_Math"},
    120404: {"Other_Math"},
    120405: {"Other_Math"},
    120406: {"Other_Math"},
    120407: {"Other_Math"},
    120408: {"Other_Math"},
    120409: {"Other_Math"},
    120410: {"Other_Math"},
    120411: {"Other_Math"},
    120412: {"Other_Math"},
    120413: {"Other_Math"},
    120414: {"Soft_Dotted", "Other_Math"},
    120415: {"Soft_Dotted", "Other_Math"},
    120416: {"Other_Math"},
    120417: {"Other_Math"},
    120418: {"Other_Math"},
    120419: {"Other_Math"},
    120420: {"Other_Math"},
    120421: {"Other_Math"},
    120422: {"Other_Math"},
    120423: {"Other_Math"},
    120424: {"Other_Math"},
    120425: {"Other_Math"},
    120426: {"Other_Math"},
    120427: {"Other_Math"},
    120428: {"Other_Math"},
    120429: {"Other_Math"},
    120430: {"Other_Math"},
    120431: {"Other_Math"},
    120432: {"Other_Math"},
    120433: {"Other_Math"},
    120434: {"Other_Math"},
    120435: {"Other_Math"},
    120436: {"Other_Math"},
    120437: {"Other_Math"},
    120438: {"Other_Math"},
    120439: {"Other_Math"},
    120440: {"Other_Math"},
    120441: {"Other_Math"},
    120442: {"Other_Math"},
    120443: {"Other_Math"},
    120444: {"Other_Math"},
    120445: {"Other_Math"},
    120446: {"Other_Math"},
    120447: {"Other_Math"},
    120448: {"Other_Math"},
    120449: {"Other_Math"},
    120450: {"Other_Math"},
    120451: {"Other_Math"},
    120452: {"Other_Math"},
    120453: {"Other_Math"},
    120454: {"Other_Math"},
    120455: {"Other_Math"},
    120456: {"Other_Math"},
    120457: {"Other_Math"},
    120458: {"Other_Math"},
    120459: {"Other_Math"},
    120460: {"Other_Math"},
    120461: {"Other_Math"},
    120462: {"Other_Math"},
    120463: {"Other_Math"},
    120464: {"Other_Math"},
    120465: {"Other_Math"},
    120466: {"Soft_Dotted", "Other_Math"},
    120467: {"Soft_Dotted", "Other_Math"},
    120468: {"Other_Math"},
    120469: {"Other_Math"},
    120470: {"Other_Math"},
    120471: {"Other_Math"},
    120472: {"Other_Math"},
    120473: {"Other_Math"},
    120474: {"Other_Math"},
    120475: {"Other_Math"},
    120476: {"Other_Math"},
    120477: {"Other_Math"},
    120478: {"Other_Math"},
    120479: {"Other_Math"},
    120480: {"Other_Math"},
    120481: {"Other_Math"},
    120482: {"Other_Math"},
    120483: {"Other_Math"},
    120484: {"Other_Math"},
    120485: {"Other_Math"},
    120488: {"Other_Math"},
    120489: {"Other_Math"},
    120490: {"Other_Math"},
    120491: {"Other_Math"},
    120492: {"Other_Math"},
    120493: {"Other_Math"},
    120494: {"Other_Math"},
    120495: {"Other_Math"},
    120496: {"Other_Math"},
    120497: {"Other_Math"},
    120498: {"Other_Math"},
    120499: {"Other_Math"},
    120500: {"Other_Math"},
    120501: {"Other_Math"},
    120502: {"Other_Math"},
    120503: {"Other_Math"},
    120504: {"Other_Math"},
    120505: {"Other_Math"},
    120506: {"Other_Math"},
    120507: {"Other_Math"},
    120508: {"Other_Math"},
    120509: {"Other_Math"},
    120510: {"Other_Math"},
    120511: {"Other_Math"},
    120512: {"Other_Math"},
    120514: {"Other_Math"},
    120515: {"Other_Math"},
    120516: {"Other_Math"},
    120517: {"Other_Math"},
    120518: {"Other_Math"},
    120519: {"Other_Math"},
    120520: {"Other_Math"},
    120521: {"Other_Math"},
    120522: {"Other_Math"},
    120523: {"Other_Math"},
    120524: {"Other_Math"},
    120525: {"Other_Math"},
    120526: {"Other_Math"},
    120527: {"Other_Math"},
    120528: {"Other_Math"},
    120529: {"Other_Math"},
    120530: {"Other_Math"},
    120531: {"Other_Math"},
    120532: {"Other_Math"},
    120533: {"Other_Math"},
    120534: {"Other_Math"},
    120535: {"Other_Math"},
    120536: {"Other_Math"},
    120537: {"Other_Math"},
    120538: {"Other_Math"},
    120540: {"Other_Math"},
    120541: {"Other_Math"},
    120542: {"Other_Math"},
    120543: {"Other_Math"},
    120544: {"Other_Math"},
    120545: {"Other_Math"},
    120546: {"Other_Math"},
    120547: {"Other_Math"},
    120548: {"Other_Math"},
    120549: {"Other_Math"},
    120550: {"Other_Math"},
    120551: {"Other_Math"},
    120552: {"Other_Math"},
    120553: {"Other_Math"},
    120554: {"Other_Math"},
    120555: {"Other_Math"},
    120556: {"Other_Math"},
    120557: {"Other_Math"},
    120558: {"Other_Math"},
    120559: {"Other_Math"},
    120560: {"Other_Math"},
    120561: {"Other_Math"},
    120562: {"Other_Math"},
    120563: {"Other_Math"},
    120564: {"Other_Math"},
    120565: {"Other_Math"},
    120566: {"Other_Math"},
    120567: {"Other_Math"},
    120568: {"Other_Math"},
    120569: {"Other_Math"},
    120570: {"Other_Math"},
    120572: {"Other_Math"},
    120573: {"Other_Math"},
    120574: {"Other_Math"},
    120575: {"Other_Math"},
    120576: {"Other_Math"},
    120577: {"Other_Math"},
    120578: {"Other_Math"},
    120579: {"Other_Math"},
    120580: {"Other_Math"},
    120581: {"Other_Math"},
    120582: {"Other_Math"},
    120583: {"Other_Math"},
    120584: {"Other_Math"},
    120585: {"Other_Math"},
    120586: {"Other_Math"},
    120587: {"Other_Math"},
    120588: {"Other_Math"},
    120589: {"Other_Math"},
    120590: {"Other_Math"},
    120591: {"Other_Math"},
    120592: {"Other_Math"},
    120593: {"Other_Math"},
    120594: {"Other_Math"},
    120595: {"Other_Math"},
    120596: {"Other_Math"},
    120598: {"Other_Math"},
    120599: {"Other_Math"},
    120600: {"Other_Math"},
    120601: {"Other_Math"},
    120602: {"Other_Math"},
    120603: {"Other_Math"},
    120604: {"Other_Math"},
    120605: {"Other_Math"},
    120606: {"Other_Math"},
    120607: {"Other_Math"},
    120608: {"Other_Math"},
    120609: {"Other_Math"},
    120610: {"Other_Math"},
    120611: {"Other_Math"},
    120612: {"Other_Math"},
    120613: {"Other_Math"},
    120614: {"Other_Math"},
    120615: {"Other_Math"},
    120616: {"Other_Math"},
    120617: {"Other_Math"},
    120618: {"Other_Math"},
    120619: {"Other_Math"},
    120620: {"Other_Math"},
    120621: {"Other_Math"},
    120622: {"Other_Math"},
    120623: {"Other_Math"},
    120624: {"Other_Math"},
    120625: {"Other_Math"},
    120626: {"Other_Math"},
    120627: {"Other_Math"},
    120628: {"Other_Math"},
    120630: {"Other_Math"},
    120631: {"Other_Math"},
    120632: {"Other_Math"},
    120633: {"Other_Math"},
    120634: {"Other_Math"},
    120635: {"Other_Math"},
    120636: {"Other_Math"},
    120637: {"Other_Math"},
    120638: {"Other_Math"},
    120639: {"Other_Math"},
    120640: {"Other_Math"},
    120641: {"Other_Math"},
    120642: {"Other_Math"},
    120643: {"Other_Math"},
    120644: {"Other_Math"},
    120645: {"Other_Math"},
    120646: {"Other_Math"},
    120647: {"Other_Math"},
    120648: {"Other_Math"},
    120649: {"Other_Math"},
    120650: {"Other_Math"},
    120651: {"Other_Math"},
    120652: {"Other_Math"},
    120653: {"Other_Math"},
    120654: {"Other_Math"},
    120656: {"Other_Math"},
    120657: {"Other_Math"},
    120658: {"Other_Math"},
    120659: {"Other_Math"},
    120660: {"Other_Math"},
    120661: {"Other_Math"},
    120662: {"Other_Math"},
    120663: {"Other_Math"},
    120664: {"Other_Math"},
    120665: {"Other_Math"},
    120666: {"Other_Math"},
    120667: {"Other_Math"},
    120668: {"Other_Math"},
    120669: {"Other_Math"},
    120670: {"Other_Math"},
    120671: {"Other_Math"},
    120672: {"Other_Math"},
    120673: {"Other_Math"},
    120674: {"Other_Math"},
    120675: {"Other_Math"},
    120676: {"Other_Math"},
    120677: {"Other_Math"},
    120678: {"Other_Math"},
    120679: {"Other_Math"},
    120680: {"Other_Math"},
    120681: {"Other_Math"},
    120682: {"Other_Math"},
    120683: {"Other_Math"},
    120684: {"Other_Math"},
    120685: {"Other_Math"},
    120686: {"Other_Math"},
    120688: {"Other_Math"},
    120689: {"Other_Math"},
    120690: {"Other_Math"},
    120691: {"Other_Math"},
    120692: {"Other_Math"},
    120693: {"Other_Math"},
    120694: {"Other_Math"},
    120695: {"Other_Math"},
    120696: {"Other_Math"},
    120697: {"Other_Math"},
    120698: {"Other_Math"},
    120699: {"Other_Math"},
    120700: {"Other_Math"},
    120701: {"Other_Math"},
    120702: {"Other_Math"},
    120703: {"Other_Math"},
    120704: {"Other_Math"},
    120705: {"Other_Math"},
    120706: {"Other_Math"},
    120707: {"Other_Math"},
    120708: {"Other_Math"},
    120709: {"Other_Math"},
    120710: {"Other_Math"},
    120711: {"Other_Math"},
    120712: {"Other_Math"},
    120714: {"Other_Math"},
    120715: {"Other_Math"},
    120716: {"Other_Math"},
    120717: {"Other_Math"},
    120718: {"Other_Math"},
    120719: {"Other_Math"},
    120720: {"Other_Math"},
    120721: {"Other_Math"},
    120722: {"Other_Math"},
    120723: {"Other_Math"},
    120724: {"Other_Math"},
    120725: {"Other_Math"},
    120726: {"Other_Math"},
    120727: {"Other_Math"},
    120728: {"Other_Math"},
    120729: {"Other_Math"},
    120730: {"Other_Math"},
    120731: {"Other_Math"},
    120732: {"Other_Math"},
    120733: {"Other_Math"},
    120734: {"Other_Math"},
    120735: {"Other_Math"},
    120736: {"Other_Math"},
    120737: {"Other_Math"},
    120738: {"Other_Math"},
    120739: {"Other_Math"},
    120740: {"Other_Math"},
    120741: {"Other_Math"},
    120742: {"Other_Math"},
    120743: {"Other_Math"},
    120744: {"Other_Math"},
    120746: {"Other_Math"},
    120747: {"Other_Math"},
    120748: {"Other_Math"},
    120749: {"Other_Math"},
    120750: {"Other_Math"},
    120751: {"Other_Math"},
    120752: {"Other_Math"},
    120753: {"Other_Math"},
    120754: {"Other_Math"},
    120755: {"Other_Math"},
    120756: {"Other_Math"},
    120757: {"Other_Math"},
    120758: {"Other_Math"},
    120759: {"Other_Math"},
    120760: {"Other_Math"},
    120761: {"Other_Math"},
    120762: {"Other_Math"},
    120763: {"Other_Math"},
    120764: {"Other_Math"},
    120765: {"Other_Math"},
    120766: {"Other_Math"},
    120767: {"Other_Math"},
    120768: {"Other_Math"},
    120769: {"Other_Math"},
    120770: {"Other_Math"},
    120772: {"Other_Math"},
    120773: {"Other_Math"},
    120774: {"Other_Math"},
    120775: {"Other_Math"},
    120776: {"Other_Math"},
    120777: {"Other_Math"},
    120778: {"Other_Math"},
    120779: {"Other_Math"},
    120782: {"Other_Math"},
    120783: {"Other_Math"},
    120784: {"Other_Math"},
    120785: {"Other_Math"},
    120786: {"Other_Math"},
    120787: {"Other_Math"},
    120788: {"Other_Math"},
    120789: {"Other_Math"},
    120790: {"Other_Math"},
    120791: {"Other_Math"},
    120792: {"Other_Math"},
    120793: {"Other_Math"},
    120794: {"Other_Math"},
    120795: {"Other_Math"},
    120796: {"Other_Math"},
    120797: {"Other_Math"},
    120798: {"Other_Math"},
    120799: {"Other_Math"},
    120800: {"Other_Math"},
    120801: {"Other_Math"},
    120802: {"Other_Math"},
    120803: {"Other_Math"},
    120804: {"Other_Math"},
    120805: {"Other_Math"},
    120806: {"Other_Math"},
    120807: {"Other_Math"},
    120808: {"Other_Math"},
    120809: {"Other_Math"},
    120810: {"Other_Math"},
    120811: {"Other_Math"},
    120812: {"Other_Math"},
    120813: {"Other_Math"},
    120814: {"Other_Math"},
    120815: {"Other_Math"},
    120816: {"Other_Math"},
    120817: {"Other_Math"},
    120818: {"Other_Math"},
    120819: {"Other_Math"},
    120820: {"Other_Math"},
    120821: {"Other_Math"},
    120822: {"Other_Math"},
    120823: {"Other_Math"},
    120824: {"Other_Math"},
    120825: {"Other_Math"},
    120826: {"Other_Math"},
    120827: {"Other_Math"},
    120828: {"Other_Math"},
    120829: {"Other_Math"},
    120830: {"Other_Math"},
    120831: {"Other_Math"},
    121479: {"Terminal_Punctuation"},
    121480: {"Terminal_Punctuation", "Sentence_Terminal"},
    121481: {"Terminal_Punctuation"},
    121482: {"Terminal_Punctuation"},
    122880: {"Other_Alphabetic"},
    122881: {"Other_Alphabetic"},
    122882: {"Other_Alphabetic"},
    122883: {"Other_Alphabetic"},
    122884: {"Other_Alphabetic"},
    122885: {"Other_Alphabetic"},
    122886: {"Other_Alphabetic"},
    122888: {"Other_Alphabetic"},
    122889: {"Other_Alphabetic"},
    122890: {"Other_Alphabetic"},
    122891: {"Other_Alphabetic"},
    122892: {"Other_Alphabetic"},
    122893: {"Other_Alphabetic"},
    122894: {"Other_Alphabetic"},
    122895: {"Other_Alphabetic"},
    122896: {"Other_Alphabetic"},
    122897: {"Other_Alphabetic"},
    122898: {"Other_Alphabetic"},
    122899: {"Other_Alphabetic"},
    122900: {"Other_Alphabetic"},
    122901: {"Other_Alphabetic"},
    122902: {"Other_Alphabetic"},
    122903: {"Other_Alphabetic"},
    122904: {"Other_Alphabetic"},
    122907: {"Other_Alphabetic"},
    122908: {"Other_Alphabetic"},
    122909: {"Other_Alphabetic"},
    122910: {"Other_Alphabetic"},
    122911: {"Other_Alphabetic"},
    122912: {"Other_Alphabetic"},
    122913: {"Other_Alphabetic"},
    122915: {"Other_Alphabetic"},
    122916: {"Other_Alphabetic"},
    122918: {"Other_Alphabetic"},
    122919: {"Other_Alphabetic"},
    122920: {"Other_Alphabetic"},
    122921: {"Other_Alphabetic"},
    122922: {"Other_Alphabetic"},
    123184: {"Diacritic"},
    123185: {"Diacritic"},
    123186: {"Diacritic"},
    123187: {"Diacritic"},
    123188: {"Diacritic"},
    123189: {"Diacritic"},
    123190: {"Diacritic"},
    123196: {"Extender"},
    123197: {"Extender"},
    123628: {"Diacritic"},
    123629: {"Diacritic"},
    123630: {"Diacritic"},
    123631: {"Diacritic"},
    125136: {"Diacritic"},
    125137: {"Diacritic"},
    125138: {"Diacritic"},
    125139: {"Diacritic"},
    125140: {"Diacritic"},
    125141: {"Diacritic"},
    125142: {"Diacritic"},
    125252: {"Diacritic", "Extender"},
    125253: {"Diacritic", "Extender"},
    125254: {"Diacritic", "Extender"},
    125255: {"Other_Alphabetic"},
    125256: {"Diacritic"},
    125257: {"Diacritic"},
    125258: {"Diacritic"},
    126464: {"Other_Math"},
    126465: {"Other_Math"},
    126466: {"Other_Math"},
    126467: {"Other_Math"},
    126469: {"Other_Math"},
    126470: {"Other_Math"},
    126471: {"Other_Math"},
    126472: {"Other_Math"},
    126473: {"Other_Math"},
    126474: {"Other_Math"},
    126475: {"Other_Math"},
    126476: {"Other_Math"},
    126477: {"Other_Math"},
    126478: {"Other_Math"},
    126479: {"Other_Math"},
    126480: {"Other_Math"},
    126481: {"Other_Math"},
    126482: {"Other_Math"},
    126483: {"Other_Math"},
    126484: {"Other_Math"},
    126485: {"Other_Math"},
    126486: {"Other_Math"},
    126487: {"Other_Math"},
    126488: {"Other_Math"},
    126489: {"Other_Math"},
    126490: {"Other_Math"},
    126491: {"Other_Math"},
    126492: {"Other_Math"},
    126493: {"Other_Math"},
    126494: {"Other_Math"},
    126495: {"Other_Math"},
    126497: {"Other_Math"},
    126498: {"Other_Math"},
    126500: {"Other_Math"},
    126503: {"Other_Math"},
    126505: {"Other_Math"},
    126506: {"Other_Math"},
    126507: {"Other_Math"},
    126508: {"Other_Math"},
    126509: {"Other_Math"},
    126510: {"Other_Math"},
    126511: {"Other_Math"},
    126512: {"Other_Math"},
    126513: {"Other_Math"},
    126514: {"Other_Math"},
    126516: {"Other_Math"},
    126517: {"Other_Math"},
    126518: {"Other_Math"},
    126519: {"Other_Math"},
    126521: {"Other_Math"},
    126523: {"Other_Math"},
    126530: {"Other_Math"},
    126535: {"Other_Math"},
    126537: {"Other_Math"},
    126539: {"Other_Math"},
    126541: {"Other_Math"},
    126542: {"Other_Math"},
    126543: {"Other_Math"},
    126545: {"Other_Math"},
    126546: {"Other_Math"},
    126548: {"Other_Math"},
    126551: {"Other_Math"},
    126553: {"Other_Math"},
    126555: {"Other_Math"},
    126557: {"Other_Math"},
    126559: {"Other_Math"},
    126561: {"Other_Math"},
    126562: {"Other_Math"},
    126564: {"Other_Math"},
    126567: {"Other_Math"},
    126568: {"Other_Math"},
    126569: {"Other_Math"},
    126570: {"Other_Math"},
    126572: {"Other_Math"},
    126573: {"Other_Math"},
    126574: {"Other_Math"},
    126575: {"Other_Math"},
    126576: {"Other_Math"},
    126577: {"Other_Math"},
    126578: {"Other_Math"},
    126580: {"Other_Math"},
    126581: {"Other_Math"},
    126582: {"Other_Math"},
    126583: {"Other_Math"},
    126585: {"Other_Math"},
    126586: {"Other_Math"},
    126587: {"Other_Math"},
    126588: {"Other_Math"},
    126590: {"Other_Math"},
    126592: {"Other_Math"},
    126593: {"Other_Math"},
    126594: {"Other_Math"},
    126595: {"Other_Math"},
    126596: {"Other_Math"},
    126597: {"Other_Math"},
    126598: {"Other_Math"},
    126599: {"Other_Math"},
    126600: {"Other_Math"},
    126601: {"Other_Math"},
    126603: {"Other_Math"},
    126604: {"Other_Math"},
    126605: {"Other_Math"},
    126606: {"Other_Math"},
    126607: {"Other_Math"},
    126608: {"Other_Math"},
    126609: {"Other_Math"},
    126610: {"Other_Math"},
    126611: {"Other_Math"},
    126612: {"Other_Math"},
    126613: {"Other_Math"},
    126614: {"Other_Math"},
    126615: {"Other_Math"},
    126616: {"Other_Math"},
    126617: {"Other_Math"},
    126618: {"Other_Math"},
    126619: {"Other_Math"},
    126625: {"Other_Math"},
    126626: {"Other_Math"},
    126627: {"Other_Math"},
    126629: {"Other_Math"},
    126630: {"Other_Math"},
    126631: {"Other_Math"},
    126632: {"Other_Math"},
    126633: {"Other_Math"},
    126635: {"Other_Math"},
    126636: {"Other_Math"},
    126637: {"Other_Math"},
    126638: {"Other_Math"},
    126639: {"Other_Math"},
    126640: {"Other_Math"},
    126641: {"Other_Math"},
    126642: {"Other_Math"},
    126643: {"Other_Math"},
    126644: {"Other_Math"},
    126645: {"Other_Math"},
    126646: {"Other_Math"},
    126647: {"Other_Math"},
    126648: {"Other_Math"},
    126649: {"Other_Math"},
    126650: {"Other_Math"},
    126651: {"Other_Math"},
    127280: {"Other_Alphabetic", "Other_Uppercase"},
    127281: {"Other_Alphabetic", "Other_Uppercase"},
    127282: {"Other_Alphabetic", "Other_Uppercase"},
    127283: {"Other_Alphabetic", "Other_Uppercase"},
    127284: {"Other_Alphabetic", "Other_Uppercase"},
    127285: {"Other_Alphabetic", "Other_Uppercase"},
    127286: {"Other_Alphabetic", "Other_Uppercase"},
    127287: {"Other_Alphabetic", "Other_Uppercase"},
    127288: {"Other_Alphabetic", "Other_Uppercase"},
    127289: {"Other_Alphabetic", "Other_Uppercase"},
    127290: {"Other_Alphabetic", "Other_Uppercase"},
    127291: {"Other_Alphabetic", "Other_Uppercase"},
    127292: {"Other_Alphabetic", "Other_Uppercase"},
    127293: {"Other_Alphabetic", "Other_Uppercase"},
    127294: {"Other_Alphabetic", "Other_Uppercase"},
    127295: {"Other_Alphabetic", "Other_Uppercase"},
    127296: {"Other_Alphabetic", "Other_Uppercase"},
    127297: {"Other_Alphabetic", "Other_Uppercase"},
    127298: {"Other_Alphabetic", "Other_Uppercase"},
    127299: {"Other_Alphabetic", "Other_Uppercase"},
    127300: {"Other_Alphabetic", "Other_Uppercase"},
    127301: {"Other_Alphabetic", "Other_Uppercase"},
    127302: {"Other_Alphabetic", "Other_Uppercase"},
    127303: {"Other_Alphabetic", "Other_Uppercase"},
    127304: {"Other_Alphabetic", "Other_Uppercase"},
    127305: {"Other_Alphabetic", "Other_Uppercase"},
    127312: {"Other_Alphabetic", "Other_Uppercase"},
    127313: {"Other_Alphabetic", "Other_Uppercase"},
    127314: {"Other_Alphabetic", "Other_Uppercase"},
    127315: {"Other_Alphabetic", "Other_Uppercase"},
    127316: {"Other_Alphabetic", "Other_Uppercase"},
    127317: {"Other_Alphabetic", "Other_Uppercase"},
    127318: {"Other_Alphabetic", "Other_Uppercase"},
    127319: {"Other_Alphabetic", "Other_Uppercase"},
    127320: {"Other_Alphabetic", "Other_Uppercase"},
    127321: {"Other_Alphabetic", "Other_Uppercase"},
    127322: {"Other_Alphabetic", "Other_Uppercase"},
    127323: {"Other_Alphabetic", "Other_Uppercase"},
    127324: {"Other_Alphabetic", "Other_Uppercase"},
    127325: {"Other_Alphabetic", "Other_Uppercase"},
    127326: {"Other_Alphabetic", "Other_Uppercase"},
    127327: {"Other_Alphabetic", "Other_Uppercase"},
    127328: {"Other_Alphabetic", "Other_Uppercase"},
    127329: {"Other_Alphabetic", "Other_Uppercase"},
    127330: {"Other_Alphabetic", "Other_Uppercase"},
    127331: {"Other_Alphabetic", "Other_Uppercase"},
    127332: {"Other_Alphabetic", "Other_Uppercase"},
    127333: {"Other_Alphabetic", "Other_Uppercase"},
    127334: {"Other_Alphabetic", "Other_Uppercase"},
    127335: {"Other_Alphabetic", "Other_Uppercase"},
    127336: {"Other_Alphabetic", "Other_Uppercase"},
    127337: {"Other_Alphabetic", "Other_Uppercase"},
    127344: {"Other_Alphabetic", "Other_Uppercase"},
    127345: {"Other_Alphabetic", "Other_Uppercase"},
    127346: {"Other_Alphabetic", "Other_Uppercase"},
    127347: {"Other_Alphabetic", "Other_Uppercase"},
    127348: {"Other_Alphabetic", "Other_Uppercase"},
    127349: {"Other_Alphabetic", "Other_Uppercase"},
    127350: {"Other_Alphabetic", "Other_Uppercase"},
    127351: {"Other_Alphabetic", "Other_Uppercase"},
    127352: {"Other_Alphabetic", "Other_Uppercase"},
    127353: {"Other_Alphabetic", "Other_Uppercase"},
    127354: {"Other_Alphabetic", "Other_Uppercase"},
    127355: {"Other_Alphabetic", "Other_Uppercase"},
    127356: {"Other_Alphabetic", "Other_Uppercase"},
    127357: {"Other_Alphabetic", "Other_Uppercase"},
    127358: {"Other_Alphabetic", "Other_Uppercase"},
    127359: {"Other_Alphabetic", "Other_Uppercase"},
    127360: {"Other_Alphabetic", "Other_Uppercase"},
    127361: {"Other_Alphabetic", "Other_Uppercase"},
    127362: {"Other_Alphabetic", "Other_Uppercase"},
    127363: {"Other_Alphabetic", "Other_Uppercase"},
    127364: {"Other_Alphabetic", "Other_Uppercase"},
    127365: {"Other_Alphabetic", "Other_Uppercase"},
    127366: {"Other_Alphabetic", "Other_Uppercase"},
    127367: {"Other_Alphabetic", "Other_Uppercase"},
    127368: {"Other_Alphabetic", "Other_Uppercase"},
    127369: {"Other_Alphabetic", "Other_Uppercase"},
    127462: {"Regional_Indicator"},
    127463: {"Regional_Indicator"},
    127464: {"Regional_Indicator"},
    127465: {"Regional_Indicator"},
    127466: {"Regional_Indicator"},
    127467: {"Regional_Indicator"},
    127468: {"Regional_Indicator"},
    127469: {"Regional_Indicator"},
    127470: {"Regional_Indicator"},
    127471: {"Regional_Indicator"},
    127472: {"Regional_Indicator"},
    127473: {"Regional_Indicator"},
    127474: {"Regional_Indicator"},
    127475: {"Regional_Indicator"},
    127476: {"Regional_Indicator"},
    127477: {"Regional_Indicator"},
    127478: {"Regional_Indicator"},
    127479: {"Regional_Indicator"},
    127480: {"Regional_Indicator"},
    127481: {"Regional_Indicator"},
    127482: {"Regional_Indicator"},
    127483: {"Regional_Indicator"},
    127484: {"Regional_Indicator"},
    127485: {"Regional_Indicator"},
    127486: {"Regional_Indicator"},
    127487: {"Regional_Indicator"},
    131070: {"Noncharacter_Code_Point"},
    131071: {"Noncharacter_Code_Point"},
    131072: {"Unified_Ideograph", "Ideographic"},
    131073: {"Unified_Ideograph", "Ideographic"},
    131074: {"Unified_Ideograph", "Ideographic"},
    131075: {"Unified_Ideograph", "Ideographic"},
    131076: {"Unified_Ideograph", "Ideographic"},
    131077: {"Unified_Ideograph", "Ideographic"},
    131078: {"Unified_Ideograph", "Ideographic"},
    131079: {"Unified_Ideograph", "Ideographic"},
    131080: {"Unified_Ideograph", "Ideographic"},
    131081: {"Unified_Ideograph", "Ideographic"},
    131082: {"Unified_Ideograph", "Ideographic"},
    131083: {"Unified_Ideograph", "Ideographic"},
    131084: {"Unified_Ideograph", "Ideographic"},
    131085: {"Unified_Ideograph", "Ideographic"},
    131086: {"Unified_Ideograph", "Ideographic"},
    131087: {"Unified_Ideograph", "Ideographic"},
    131088: {"Unified_Ideograph", "Ideographic"},
    131089: {"Unified_Ideograph", "Ideographic"},
    131090: {"Unified_Ideograph", "Ideographic"},
    131091: {"Unified_Ideograph", "Ideographic"},
    131092: {"Unified_Ideograph", "Ideographic"},
    131093: {"Unified_Ideograph", "Ideographic"},
    131094: {"Unified_Ideograph", "Ideographic"},
    131095: {"Unified_Ideograph", "Ideographic"},
    131096: {"Unified_Ideograph", "Ideographic"},
    131097: {"Unified_Ideograph", "Ideographic"},
    131098: {"Unified_Ideograph", "Ideographic"},
    131099: {"Unified_Ideograph", "Ideographic"},
    131100: {"Unified_Ideograph", "Ideographic"},
    131101: {"Unified_Ideograph", "Ideographic"},
    131102: {"Unified_Ideograph", "Ideographic"},
    131103: {"Unified_Ideograph", "Ideographic"},
    131104: {"Unified_Ideograph", "Ideographic"},
    131105: {"Unified_Ideograph", "Ideographic"},
    131106: {"Unified_Ideograph", "Ideographic"},
    131107: {"Unified_Ideograph", "Ideographic"},
    131108: {"Unified_Ideograph", "Ideographic"},
    131109: {"Unified_Ideograph", "Ideographic"},
    131110: {"Unified_Ideograph", "Ideographic"},
    131111: {"Unified_Ideograph", "Ideographic"},
    131112: {"Unified_Ideograph", "Ideographic"},
    131113: {"Unified_Ideograph", "Ideographic"},
    131114: {"Unified_Ideograph", "Ideographic"},
    131115: {"Unified_Ideograph", "Ideographic"},
    131116: {"Unified_Ideograph", "Ideographic"},
    131117: {"Unified_Ideograph", "Ideographic"},
    131118: {"Unified_Ideograph", "Ideographic"},
    131119: {"Unified_Ideograph", "Ideographic"},
    131120: {"Unified_Ideograph", "Ideographic"},
    131121: {"Unified_Ideograph", "Ideographic"},
    131122: {"Unified_Ideograph", "Ideographic"},
    131123: {"Unified_Ideograph", "Ideographic"},
    131124: {"Unified_Ideograph", "Ideographic"},
    131125: {"Unified_Ideograph", "Ideographic"},
    131126: {"Unified_Ideograph", "Ideographic"},
    131127: {"Unified_Ideograph", "Ideographic"},
    131128: {"Unified_Ideograph", "Ideographic"},
    131129: {"Unified_Ideograph", "Ideographic"},
    131130: {"Unified_Ideograph", "Ideographic"},
    131131: {"Unified_Ideograph", "Ideographic"},
    131132: {"Unified_Ideograph", "Ideographic"},
    131133: {"Unified_Ideograph", "Ideographic"},
    131134: {"Unified_Ideograph", "Ideographic"},
    131135: {"Unified_Ideograph", "Ideographic"},
    131136: {"Unified_Ideograph", "Ideographic"},
    131137: {"Unified_Ideograph", "Ideographic"},
    131138: {"Unified_Ideograph", "Ideographic"},
    131139: {"Unified_Ideograph", "Ideographic"},
    131140: {"Unified_Ideograph", "Ideographic"},
    131141: {"Unified_Ideograph", "Ideographic"},
    131142: {"Unified_Ideograph", "Ideographic"},
    131143: {"Unified_Ideograph", "Ideographic"},
    131144: {"Unified_Ideograph", "Ideographic"},
    131145: {"Unified_Ideograph", "Ideographic"},
    131146: {"Unified_Ideograph", "Ideographic"},
    131147: {"Unified_Ideograph", "Ideographic"},
    131148: {"Unified_Ideograph", "Ideographic"},
    131149: {"Unified_Ideograph", "Ideographic"},
    131150: {"Unified_Ideograph", "Ideographic"},
    131151: {"Unified_Ideograph", "Ideographic"},
    131152: {"Unified_Ideograph", "Ideographic"},
    131153: {"Unified_Ideograph", "Ideographic"},
    131154: {"Unified_Ideograph", "Ideographic"},
    131155: {"Unified_Ideograph", "Ideographic"},
    131156: {"Unified_Ideograph", "Ideographic"},
    131157: {"Unified_Ideograph", "Ideographic"},
    131158: {"Unified_Ideograph", "Ideographic"},
    131159: {"Unified_Ideograph", "Ideographic"},
    131160: {"Unified_Ideograph", "Ideographic"},
    131161: {"Unified_Ideograph", "Ideographic"},
    131162: {"Unified_Ideograph", "Ideographic"},
    131163: {"Unified_Ideograph", "Ideographic"},
    131164: {"Unified_Ideograph", "Ideographic"},
    131165: {"Unified_Ideograph", "Ideographic"},
    131166: {"Unified_Ideograph", "Ideographic"},
    131167: {"Unified_Ideograph", "Ideographic"},
    131168: {"Unified_Ideograph", "Ideographic"},
    131169: {"Unified_Ideograph", "Ideographic"},
    131170: {"Unified_Ideograph", "Ideographic"},
    131171: {"Unified_Ideograph", "Ideographic"},
    131172: {"Unified_Ideograph", "Ideographic"},
    131173: {"Unified_Ideograph", "Ideographic"},
    131174: {"Unified_Ideograph", "Ideographic"},
    131175: {"Unified_Ideograph", "Ideographic"},
    131176: {"Unified_Ideograph", "Ideographic"},
    131177: {"Unified_Ideograph", "Ideographic"},
    131178: {"Unified_Ideograph", "Ideographic"},
    131179: {"Unified_Ideograph", "Ideographic"},
    131180: {"Unified_Ideograph", "Ideographic"},
    131181: {"Unified_Ideograph", "Ideographic"},
    131182: {"Unified_Ideograph", "Ideographic"},
    131183: {"Unified_Ideograph", "Ideographic"},
    131184: {"Unified_Ideograph", "Ideographic"},
    131185: {"Unified_Ideograph", "Ideographic"},
    131186: {"Unified_Ideograph", "Ideographic"},
    131187: {"Unified_Ideograph", "Ideographic"},
    131188: {"Unified_Ideograph", "Ideographic"},
    131189: {"Unified_Ideograph", "Ideographic"},
    131190: {"Unified_Ideograph", "Ideographic"},
    131191: {"Unified_Ideograph", "Ideographic"},
    131192: {"Unified_Ideograph", "Ideographic"},
    131193: {"Unified_Ideograph", "Ideographic"},
    131194: {"Unified_Ideograph", "Ideographic"},
    131195: {"Unified_Ideograph", "Ideographic"},
    131196: {"Unified_Ideograph", "Ideographic"},
    131197: {"Unified_Ideograph", "Ideographic"},
    131198: {"Unified_Ideograph", "Ideographic"},
    131199: {"Unified_Ideograph", "Ideographic"},
    131200: {"Unified_Ideograph", "Ideographic"},
    131201: {"Unified_Ideograph", "Ideographic"},
    131202: {"Unified_Ideograph", "Ideographic"},
    131203: {"Unified_Ideograph", "Ideographic"},
    131204: {"Unified_Ideograph", "Ideographic"},
    131205: {"Unified_Ideograph", "Ideographic"},
    131206: {"Unified_Ideograph", "Ideographic"},
    131207: {"Unified_Ideograph", "Ideographic"},
    131208: {"Unified_Ideograph", "Ideographic"},
    131209: {"Unified_Ideograph", "Ideographic"},
    131210: {"Unified_Ideograph", "Ideographic"},
    131211: {"Unified_Ideograph", "Ideographic"},
    131212: {"Unified_Ideograph", "Ideographic"},
    131213: {"Unified_Ideograph", "Ideographic"},
    131214: {"Unified_Ideograph", "Ideographic"},
    131215: {"Unified_Ideograph", "Ideographic"},
    131216: {"Unified_Ideograph", "Ideographic"},
    131217: {"Unified_Ideograph", "Ideographic"},
    131218: {"Unified_Ideograph", "Ideographic"},
    131219: {"Unified_Ideograph", "Ideographic"},
    131220: {"Unified_Ideograph", "Ideographic"},
    131221: {"Unified_Ideograph", "Ideographic"},
    131222: {"Unified_Ideograph", "Ideographic"},
    131223: {"Unified_Ideograph", "Ideographic"},
    131224: {"Unified_Ideograph", "Ideographic"},
    131225: {"Unified_Ideograph", "Ideographic"},
    131226: {"Unified_Ideograph", "Ideographic"},
    131227: {"Unified_Ideograph", "Ideographic"},
    131228: {"Unified_Ideograph", "Ideographic"},
    131229: {"Unified_Ideograph", "Ideographic"},
    131230: {"Unified_Ideograph", "Ideographic"},
    131231: {"Unified_Ideograph", "Ideographic"},
    131232: {"Unified_Ideograph", "Ideographic"},
    131233: {"Unified_Ideograph", "Ideographic"},
    131234: {"Unified_Ideograph", "Ideographic"},
    131235: {"Unified_Ideograph", "Ideographic"},
    131236: {"Unified_Ideograph", "Ideographic"},
    131237: {"Unified_Ideograph", "Ideographic"},
    131238: {"Unified_Ideograph", "Ideographic"},
    131239: {"Unified_Ideograph", "Ideographic"},
    131240: {"Unified_Ideograph", "Ideographic"},
    131241: {"Unified_Ideograph", "Ideographic"},
    131242: {"Unified_Ideograph", "Ideographic"},
    131243: {"Unified_Ideograph", "Ideographic"},
    131244: {"Unified_Ideograph", "Ideographic"},
    131245: {"Unified_Ideograph", "Ideographic"},
    131246: {"Unified_Ideograph", "Ideographic"},
    131247: {"Unified_Ideograph", "Ideographic"},
    131248: {"Unified_Ideograph", "Ideographic"},
    131249: {"Unified_Ideograph", "Ideographic"},
    131250: {"Unified_Ideograph", "Ideographic"},
    131251: {"Unified_Ideograph", "Ideographic"},
    131252: {"Unified_Ideograph", "Ideographic"},
    131253: {"Unified_Ideograph", "Ideographic"},
    131254: {"Unified_Ideograph", "Ideographic"},
    131255: {"Unified_Ideograph", "Ideographic"},
    131256: {"Unified_Ideograph", "Ideographic"},
    131257: {"Unified_Ideograph", "Ideographic"},
    131258: {"Unified_Ideograph", "Ideographic"},
    131259: {"Unified_Ideograph", "Ideographic"},
    131260: {"Unified_Ideograph", "Ideographic"},
    131261: {"Unified_Ideograph", "Ideographic"},
    131262: {"Unified_Ideograph", "Ideographic"},
    131263: {"Unified_Ideograph", "Ideographic"},
    131264: {"Unified_Ideograph", "Ideographic"},
    131265: {"Unified_Ideograph", "Ideographic"},
    131266: {"Unified_Ideograph", "Ideographic"},
    131267: {"Unified_Ideograph", "Ideographic"},
    131268: {"Unified_Ideograph", "Ideographic"},
    131269: {"Unified_Ideograph", "Ideographic"},
    131270: {"Unified_Ideograph", "Ideographic"},
    131271: {"Unified_Ideograph", "Ideographic"},
    131272: {"Unified_Ideograph", "Ideographic"},
    131273: {"Unified_Ideograph", "Ideographic"},
    131274: {"Unified_Ideograph", "Ideographic"},
    131275: {"Unified_Ideograph", "Ideographic"},
    131276: {"Unified_Ideograph", "Ideographic"},
    131277: {"Unified_Ideograph", "Ideographic"},
    131278: {"Unified_Ideograph", "Ideographic"},
    131279: {"Unified_Ideograph", "Ideographic"},
    131280: {"Unified_Ideograph", "Ideographic"},
    131281: {"Unified_Ideograph", "Ideographic"},
    131282: {"Unified_Ideograph", "Ideographic"},
    131283: {"Unified_Ideograph", "Ideographic"},
    131284: {"Unified_Ideograph", "Ideographic"},
    131285: {"Unified_Ideograph", "Ideographic"},
    131286: {"Unified_Ideograph", "Ideographic"},
    131287: {"Unified_Ideograph", "Ideographic"},
    131288: {"Unified_Ideograph", "Ideographic"},
    131289: {"Unified_Ideograph", "Ideographic"},
    131290: {"Unified_Ideograph", "Ideographic"},
    131291: {"Unified_Ideograph", "Ideographic"},
    131292: {"Unified_Ideograph", "Ideographic"},
    131293: {"Unified_Ideograph", "Ideographic"},
    131294: {"Unified_Ideograph", "Ideographic"},
    131295: {"Unified_Ideograph", "Ideographic"},
    131296: {"Unified_Ideograph", "Ideographic"},
    131297: {"Unified_Ideograph", "Ideographic"},
    131298: {"Unified_Ideograph", "Ideographic"},
    131299: {"Unified_Ideograph", "Ideographic"},
    131300: {"Unified_Ideograph", "Ideographic"},
    131301: {"Unified_Ideograph", "Ideographic"},
    131302: {"Unified_Ideograph", "Ideographic"},
    131303: {"Unified_Ideograph", "Ideographic"},
    131304: {"Unified_Ideograph", "Ideographic"},
    131305: {"Unified_Ideograph", "Ideographic"},
    131306: {"Unified_Ideograph", "Ideographic"},
    131307: {"Unified_Ideograph", "Ideographic"},
    131308: {"Unified_Ideograph", "Ideographic"},
    131309: {"Unified_Ideograph", "Ideographic"},
    131310: {"Unified_Ideograph", "Ideographic"},
    131311: {"Unified_Ideograph", "Ideographic"},
    131312: {"Unified_Ideograph", "Ideographic"},
    131313: {"Unified_Ideograph", "Ideographic"},
    131314: {"Unified_Ideograph", "Ideographic"},
    131315: {"Unified_Ideograph", "Ideographic"},
    131316: {"Unified_Ideograph", "Ideographic"},
    131317: {"Unified_Ideograph", "Ideographic"},
    131318: {"Unified_Ideograph", "Ideographic"},
    131319: {"Unified_Ideograph", "Ideographic"},
    131320: {"Unified_Ideograph", "Ideographic"},
    131321: {"Unified_Ideograph", "Ideographic"},
    131322: {"Unified_Ideograph", "Ideographic"},
    131323: {"Unified_Ideograph", "Ideographic"},
    131324: {"Unified_Ideograph", "Ideographic"},
    131325: {"Unified_Ideograph", "Ideographic"},
    131326: {"Unified_Ideograph", "Ideographic"},
    131327: {"Unified_Ideograph", "Ideographic"},
    131328: {"Unified_Ideograph", "Ideographic"},
    131329: {"Unified_Ideograph", "Ideographic"},
    131330: {"Unified_Ideograph", "Ideographic"},
    131331: {"Unified_Ideograph", "Ideographic"},
    131332: {"Unified_Ideograph", "Ideographic"},
    131333: {"Unified_Ideograph", "Ideographic"},
    131334: {"Unified_Ideograph", "Ideographic"},
    131335: {"Unified_Ideograph", "Ideographic"},
    131336: {"Unified_Ideograph", "Ideographic"},
    131337: {"Unified_Ideograph", "Ideographic"},
    131338: {"Unified_Ideograph", "Ideographic"},
    131339: {"Unified_Ideograph", "Ideographic"},
    131340: {"Unified_Ideograph", "Ideographic"},
    131341: {"Unified_Ideograph", "Ideographic"},
    131342: {"Unified_Ideograph", "Ideographic"},
    131343: {"Unified_Ideograph", "Ideographic"},
    131344: {"Unified_Ideograph", "Ideographic"},
    131345: {"Unified_Ideograph", "Ideographic"},
    131346: {"Unified_Ideograph", "Ideographic"},
    131347: {"Unified_Ideograph", "Ideographic"},
    131348: {"Unified_Ideograph", "Ideographic"},
    131349: {"Unified_Ideograph", "Ideographic"},
    131350: {"Unified_Ideograph", "Ideographic"},
    131351: {"Unified_Ideograph", "Ideographic"},
    131352: {"Unified_Ideograph", "Ideographic"},
    131353: {"Unified_Ideograph", "Ideographic"},
    131354: {"Unified_Ideograph", "Ideographic"},
    131355: {"Unified_Ideograph", "Ideographic"},
    131356: {"Unified_Ideograph", "Ideographic"},
    131357: {"Unified_Ideograph", "Ideographic"},
    131358: {"Unified_Ideograph", "Ideographic"},
    131359: {"Unified_Ideograph", "Ideographic"},
    131360: {"Unified_Ideograph", "Ideographic"},
    131361: {"Unified_Ideograph", "Ideographic"},
    131362: {"Unified_Ideograph", "Ideographic"},
    131363: {"Unified_Ideograph", "Ideographic"},
    131364: {"Unified_Ideograph", "Ideographic"},
    131365: {"Unified_Ideograph", "Ideographic"},
    131366: {"Unified_Ideograph", "Ideographic"},
    131367: {"Unified_Ideograph", "Ideographic"},
    131368: {"Unified_Ideograph", "Ideographic"},
    131369: {"Unified_Ideograph", "Ideographic"},
    131370: {"Unified_Ideograph", "Ideographic"},
    131371: {"Unified_Ideograph", "Ideographic"},
    131372: {"Unified_Ideograph", "Ideographic"},
    131373: {"Unified_Ideograph", "Ideographic"},
    131374: {"Unified_Ideograph", "Ideographic"},
    131375: {"Unified_Ideograph", "Ideographic"},
    131376: {"Unified_Ideograph", "Ideographic"},
    131377: {"Unified_Ideograph", "Ideographic"},
    131378: {"Unified_Ideograph", "Ideographic"},
    131379: {"Unified_Ideograph", "Ideographic"},
    131380: {"Unified_Ideograph", "Ideographic"},
    131381: {"Unified_Ideograph", "Ideographic"},
    131382: {"Unified_Ideograph", "Ideographic"},
    131383: {"Unified_Ideograph", "Ideographic"},
    131384: {"Unified_Ideograph", "Ideographic"},
    131385: {"Unified_Ideograph", "Ideographic"},
    131386: {"Unified_Ideograph", "Ideographic"},
    131387: {"Unified_Ideograph", "Ideographic"},
    131388: {"Unified_Ideograph", "Ideographic"},
    131389: {"Unified_Ideograph", "Ideographic"},
    131390: {"Unified_Ideograph", "Ideographic"},
    131391: {"Unified_Ideograph", "Ideographic"},
    131392: {"Unified_Ideograph", "Ideographic"},
    131393: {"Unified_Ideograph", "Ideographic"},
    131394: {"Unified_Ideograph", "Ideographic"},
    131395: {"Unified_Ideograph", "Ideographic"},
    131396: {"Unified_Ideograph", "Ideographic"},
    131397: {"Unified_Ideograph", "Ideographic"},
    131398: {"Unified_Ideograph", "Ideographic"},
    131399: {"Unified_Ideograph", "Ideographic"},
    131400: {"Unified_Ideograph", "Ideographic"},
    131401: {"Unified_Ideograph", "Ideographic"},
    131402: {"Unified_Ideograph", "Ideographic"},
    131403: {"Unified_Ideograph", "Ideographic"},
    131404: {"Unified_Ideograph", "Ideographic"},
    131405: {"Unified_Ideograph", "Ideographic"},
    131406: {"Unified_Ideograph", "Ideographic"},
    131407: {"Unified_Ideograph", "Ideographic"},
    131408: {"Unified_Ideograph", "Ideographic"},
    131409: {"Unified_Ideograph", "Ideographic"},
    131410: {"Unified_Ideograph", "Ideographic"},
    131411: {"Unified_Ideograph", "Ideographic"},
    131412: {"Unified_Ideograph", "Ideographic"},
    131413: {"Unified_Ideograph", "Ideographic"},
    131414: {"Unified_Ideograph", "Ideographic"},
    131415: {"Unified_Ideograph", "Ideographic"},
    131416: {"Unified_Ideograph", "Ideographic"},
    131417: {"Unified_Ideograph", "Ideographic"},
    131418: {"Unified_Ideograph", "Ideographic"},
    131419: {"Unified_Ideograph", "Ideographic"},
    131420: {"Unified_Ideograph", "Ideographic"},
    131421: {"Unified_Ideograph", "Ideographic"},
    131422: {"Unified_Ideograph", "Ideographic"},
    131423: {"Unified_Ideograph", "Ideographic"},
    131424: {"Unified_Ideograph", "Ideographic"},
    131425: {"Unified_Ideograph", "Ideographic"},
    131426: {"Unified_Ideograph", "Ideographic"},
    131427: {"Unified_Ideograph", "Ideographic"},
    131428: {"Unified_Ideograph", "Ideographic"},
    131429: {"Unified_Ideograph", "Ideographic"},
    131430: {"Unified_Ideograph", "Ideographic"},
    131431: {"Unified_Ideograph", "Ideographic"},
    131432: {"Unified_Ideograph", "Ideographic"},
    131433: {"Unified_Ideograph", "Ideographic"},
    131434: {"Unified_Ideograph", "Ideographic"},
    131435: {"Unified_Ideograph", "Ideographic"},
    131436: {"Unified_Ideograph", "Ideographic"},
    131437: {"Unified_Ideograph", "Ideographic"},
    131438: {"Unified_Ideograph", "Ideographic"},
    131439: {"Unified_Ideograph", "Ideographic"},
    131440: {"Unified_Ideograph", "Ideographic"},
    131441: {"Unified_Ideograph", "Ideographic"},
    131442: {"Unified_Ideograph", "Ideographic"},
    131443: {"Unified_Ideograph", "Ideographic"},
    131444: {"Unified_Ideograph", "Ideographic"},
    131445: {"Unified_Ideograph", "Ideographic"},
    131446: {"Unified_Ideograph", "Ideographic"},
    131447: {"Unified_Ideograph", "Ideographic"},
    131448: {"Unified_Ideograph", "Ideographic"},
    131449: {"Unified_Ideograph", "Ideographic"},
    131450: {"Unified_Ideograph", "Ideographic"},
    131451: {"Unified_Ideograph", "Ideographic"},
    131452: {"Unified_Ideograph", "Ideographic"},
    131453: {"Unified_Ideograph", "Ideographic"},
    131454: {"Unified_Ideograph", "Ideographic"},
    131455: {"Unified_Ideograph", "Ideographic"},
    131456: {"Unified_Ideograph", "Ideographic"},
    131457: {"Unified_Ideograph", "Ideographic"},
    131458: {"Unified_Ideograph", "Ideographic"},
    131459: {"Unified_Ideograph", "Ideographic"},
    131460: {"Unified_Ideograph", "Ideographic"},
    131461: {"Unified_Ideograph", "Ideographic"},
    131462: {"Unified_Ideograph", "Ideographic"},
    131463: {"Unified_Ideograph", "Ideographic"},
    131464: {"Unified_Ideograph", "Ideographic"},
    131465: {"Unified_Ideograph", "Ideographic"},
    131466: {"Unified_Ideograph", "Ideographic"},
    131467: {"Unified_Ideograph", "Ideographic"},
    131468: {"Unified_Ideograph", "Ideographic"},
    131469: {"Unified_Ideograph", "Ideographic"},
    131470: {"Unified_Ideograph", "Ideographic"},
    131471: {"Unified_Ideograph", "Ideographic"},
    131472: {"Unified_Ideograph", "Ideographic"},
    131473: {"Unified_Ideograph", "Ideographic"},
    131474: {"Unified_Ideograph", "Ideographic"},
    131475: {"Unified_Ideograph", "Ideographic"},
    131476: {"Unified_Ideograph", "Ideographic"},
    131477: {"Unified_Ideograph", "Ideographic"},
    131478: {"Unified_Ideograph", "Ideographic"},
    131479: {"Unified_Ideograph", "Ideographic"},
    131480: {"Unified_Ideograph", "Ideographic"},
    131481: {"Unified_Ideograph", "Ideographic"},
    131482: {"Unified_Ideograph", "Ideographic"},
    131483: {"Unified_Ideograph", "Ideographic"},
    131484: {"Unified_Ideograph", "Ideographic"},
    131485: {"Unified_Ideograph", "Ideographic"},
    131486: {"Unified_Ideograph", "Ideographic"},
    131487: {"Unified_Ideograph", "Ideographic"},
    131488: {"Unified_Ideograph", "Ideographic"},
    131489: {"Unified_Ideograph", "Ideographic"},
    131490: {"Unified_Ideograph", "Ideographic"},
    131491: {"Unified_Ideograph", "Ideographic"},
    131492: {"Unified_Ideograph", "Ideographic"},
    131493: {"Unified_Ideograph", "Ideographic"},
    131494: {"Unified_Ideograph", "Ideographic"},
    131495: {"Unified_Ideograph", "Ideographic"},
    131496: {"Unified_Ideograph", "Ideographic"},
    131497: {"Unified_Ideograph", "Ideographic"},
    131498: {"Unified_Ideograph", "Ideographic"},
    131499: {"Unified_Ideograph", "Ideographic"},
    131500: {"Unified_Ideograph", "Ideographic"},
    131501: {"Unified_Ideograph", "Ideographic"},
    131502: {"Unified_Ideograph", "Ideographic"},
    131503: {"Unified_Ideograph", "Ideographic"},
    131504: {"Unified_Ideograph", "Ideographic"},
    131505: {"Unified_Ideograph", "Ideographic"},
    131506: {"Unified_Ideograph", "Ideographic"},
    131507: {"Unified_Ideograph", "Ideographic"},
    131508: {"Unified_Ideograph", "Ideographic"},
    131509: {"Unified_Ideograph", "Ideographic"},
    131510: {"Unified_Ideograph", "Ideographic"},
    131511: {"Unified_Ideograph", "Ideographic"},
    131512: {"Unified_Ideograph", "Ideographic"},
    131513: {"Unified_Ideograph", "Ideographic"},
    131514: {"Unified_Ideograph", "Ideographic"},
    131515: {"Unified_Ideograph", "Ideographic"},
    131516: {"Unified_Ideograph", "Ideographic"},
    131517: {"Unified_Ideograph", "Ideographic"},
    131518: {"Unified_Ideograph", "Ideographic"},
    131519: {"Unified_Ideograph", "Ideographic"},
    131520: {"Unified_Ideograph", "Ideographic"},
    131521: {"Unified_Ideograph", "Ideographic"},
    131522: {"Unified_Ideograph", "Ideographic"},
    131523: {"Unified_Ideograph", "Ideographic"},
    131524: {"Unified_Ideograph", "Ideographic"},
    131525: {"Unified_Ideograph", "Ideographic"},
    131526: {"Unified_Ideograph", "Ideographic"},
    131527: {"Unified_Ideograph", "Ideographic"},
    131528: {"Unified_Ideograph", "Ideographic"},
    131529: {"Unified_Ideograph", "Ideographic"},
    131530: {"Unified_Ideograph", "Ideographic"},
    131531: {"Unified_Ideograph", "Ideographic"},
    131532: {"Unified_Ideograph", "Ideographic"},
    131533: {"Unified_Ideograph", "Ideographic"},
    131534: {"Unified_Ideograph", "Ideographic"},
    131535: {"Unified_Ideograph", "Ideographic"},
    131536: {"Unified_Ideograph", "Ideographic"},
    131537: {"Unified_Ideograph", "Ideographic"},
    131538: {"Unified_Ideograph", "Ideographic"},
    131539: {"Unified_Ideograph", "Ideographic"},
    131540: {"Unified_Ideograph", "Ideographic"},
    131541: {"Unified_Ideograph", "Ideographic"},
    131542: {"Unified_Ideograph", "Ideographic"},
    131543: {"Unified_Ideograph", "Ideographic"},
    131544: {"Unified_Ideograph", "Ideographic"},
    131545: {"Unified_Ideograph", "Ideographic"},
    131546: {"Unified_Ideograph", "Ideographic"},
    131547: {"Unified_Ideograph", "Ideographic"},
    131548: {"Unified_Ideograph", "Ideographic"},
    131549: {"Unified_Ideograph", "Ideographic"},
    131550: {"Unified_Ideograph", "Ideographic"},
    131551: {"Unified_Ideograph", "Ideographic"},
    131552: {"Unified_Ideograph", "Ideographic"},
    131553: {"Unified_Ideograph", "Ideographic"},
    131554: {"Unified_Ideograph", "Ideographic"},
    131555: {"Unified_Ideograph", "Ideographic"},
    131556: {"Unified_Ideograph", "Ideographic"},
    131557: {"Unified_Ideograph", "Ideographic"},
    131558: {"Unified_Ideograph", "Ideographic"},
    131559: {"Unified_Ideograph", "Ideographic"},
    131560: {"Unified_Ideograph", "Ideographic"},
    131561: {"Unified_Ideograph", "Ideographic"},
    131562: {"Unified_Ideograph", "Ideographic"},
    131563: {"Unified_Ideograph", "Ideographic"},
    131564: {"Unified_Ideograph", "Ideographic"},
    131565: {"Unified_Ideograph", "Ideographic"},
    131566: {"Unified_Ideograph", "Ideographic"},
    131567: {"Unified_Ideograph", "Ideographic"},
    131568: {"Unified_Ideograph", "Ideographic"},
    131569: {"Unified_Ideograph", "Ideographic"},
    131570: {"Unified_Ideograph", "Ideographic"},
    131571: {"Unified_Ideograph", "Ideographic"},
    131572: {"Unified_Ideograph", "Ideographic"},
    131573: {"Unified_Ideograph", "Ideographic"},
    131574: {"Unified_Ideograph", "Ideographic"},
    131575: {"Unified_Ideograph", "Ideographic"},
    131576: {"Unified_Ideograph", "Ideographic"},
    131577: {"Unified_Ideograph", "Ideographic"},
    131578: {"Unified_Ideograph", "Ideographic"},
    131579: {"Unified_Ideograph", "Ideographic"},
    131580: {"Unified_Ideograph", "Ideographic"},
    131581: {"Unified_Ideograph", "Ideographic"},
    131582: {"Unified_Ideograph", "Ideographic"},
    131583: {"Unified_Ideograph", "Ideographic"},
    131584: {"Unified_Ideograph", "Ideographic"},
    131585: {"Unified_Ideograph", "Ideographic"},
    131586: {"Unified_Ideograph", "Ideographic"},
    131587: {"Unified_Ideograph", "Ideographic"},
    131588: {"Unified_Ideograph", "Ideographic"},
    131589: {"Unified_Ideograph", "Ideographic"},
    131590: {"Unified_Ideograph", "Ideographic"},
    131591: {"Unified_Ideograph", "Ideographic"},
    131592: {"Unified_Ideograph", "Ideographic"},
    131593: {"Unified_Ideograph", "Ideographic"},
    131594: {"Unified_Ideograph", "Ideographic"},
    131595: {"Unified_Ideograph", "Ideographic"},
    131596: {"Unified_Ideograph", "Ideographic"},
    131597: {"Unified_Ideograph", "Ideographic"},
    131598: {"Unified_Ideograph", "Ideographic"},
    131599: {"Unified_Ideograph", "Ideographic"},
    131600: {"Unified_Ideograph", "Ideographic"},
    131601: {"Unified_Ideograph", "Ideographic"},
    131602: {"Unified_Ideograph", "Ideographic"},
    131603: {"Unified_Ideograph", "Ideographic"},
    131604: {"Unified_Ideograph", "Ideographic"},
    131605: {"Unified_Ideograph", "Ideographic"},
    131606: {"Unified_Ideograph", "Ideographic"},
    131607: {"Unified_Ideograph", "Ideographic"},
    131608: {"Unified_Ideograph", "Ideographic"},
    131609: {"Unified_Ideograph", "Ideographic"},
    131610: {"Unified_Ideograph", "Ideographic"},
    131611: {"Unified_Ideograph", "Ideographic"},
    131612: {"Unified_Ideograph", "Ideographic"},
    131613: {"Unified_Ideograph", "Ideographic"},
    131614: {"Unified_Ideograph", "Ideographic"},
    131615: {"Unified_Ideograph", "Ideographic"},
    131616: {"Unified_Ideograph", "Ideographic"},
    131617: {"Unified_Ideograph", "Ideographic"},
    131618: {"Unified_Ideograph", "Ideographic"},
    131619: {"Unified_Ideograph", "Ideographic"},
    131620: {"Unified_Ideograph", "Ideographic"},
    131621: {"Unified_Ideograph", "Ideographic"},
    131622: {"Unified_Ideograph", "Ideographic"},
    131623: {"Unified_Ideograph", "Ideographic"},
    131624: {"Unified_Ideograph", "Ideographic"},
    131625: {"Unified_Ideograph", "Ideographic"},
    131626: {"Unified_Ideograph", "Ideographic"},
    131627: {"Unified_Ideograph", "Ideographic"},
    131628: {"Unified_Ideograph", "Ideographic"},
    131629: {"Unified_Ideograph", "Ideographic"},
    131630: {"Unified_Ideograph", "Ideographic"},
    131631: {"Unified_Ideograph", "Ideographic"},
    131632: {"Unified_Ideograph", "Ideographic"},
    131633: {"Unified_Ideograph", "Ideographic"},
    131634: {"Unified_Ideograph", "Ideographic"},
    131635: {"Unified_Ideograph", "Ideographic"},
    131636: {"Unified_Ideograph", "Ideographic"},
    131637: {"Unified_Ideograph", "Ideographic"},
    131638: {"Unified_Ideograph", "Ideographic"},
    131639: {"Unified_Ideograph", "Ideographic"},
    131640: {"Unified_Ideograph", "Ideographic"},
    131641: {"Unified_Ideograph", "Ideographic"},
    131642: {"Unified_Ideograph", "Ideographic"},
    131643: {"Unified_Ideograph", "Ideographic"},
    131644: {"Unified_Ideograph", "Ideographic"},
    131645: {"Unified_Ideograph", "Ideographic"},
    131646: {"Unified_Ideograph", "Ideographic"},
    131647: {"Unified_Ideograph", "Ideographic"},
    131648: {"Unified_Ideograph", "Ideographic"},
    131649: {"Unified_Ideograph", "Ideographic"},
    131650: {"Unified_Ideograph", "Ideographic"},
    131651: {"Unified_Ideograph", "Ideographic"},
    131652: {"Unified_Ideograph", "Ideographic"},
    131653: {"Unified_Ideograph", "Ideographic"},
    131654: {"Unified_Ideograph", "Ideographic"},
    131655: {"Unified_Ideograph", "Ideographic"},
    131656: {"Unified_Ideograph", "Ideographic"},
    131657: {"Unified_Ideograph", "Ideographic"},
    131658: {"Unified_Ideograph", "Ideographic"},
    131659: {"Unified_Ideograph", "Ideographic"},
    131660: {"Unified_Ideograph", "Ideographic"},
    131661: {"Unified_Ideograph", "Ideographic"},
    131662: {"Unified_Ideograph", "Ideographic"},
    131663: {"Unified_Ideograph", "Ideographic"},
    131664: {"Unified_Ideograph", "Ideographic"},
    131665: {"Unified_Ideograph", "Ideographic"},
    131666: {"Unified_Ideograph", "Ideographic"},
    131667: {"Unified_Ideograph", "Ideographic"},
    131668: {"Unified_Ideograph", "Ideographic"},
    131669: {"Unified_Ideograph", "Ideographic"},
    131670: {"Unified_Ideograph", "Ideographic"},
    131671: {"Unified_Ideograph", "Ideographic"},
    131672: {"Unified_Ideograph", "Ideographic"},
    131673: {"Unified_Ideograph", "Ideographic"},
    131674: {"Unified_Ideograph", "Ideographic"},
    131675: {"Unified_Ideograph", "Ideographic"},
    131676: {"Unified_Ideograph", "Ideographic"},
    131677: {"Unified_Ideograph", "Ideographic"},
    131678: {"Unified_Ideograph", "Ideographic"},
    131679: {"Unified_Ideograph", "Ideographic"},
    131680: {"Unified_Ideograph", "Ideographic"},
    131681: {"Unified_Ideograph", "Ideographic"},
    131682: {"Unified_Ideograph", "Ideographic"},
    131683: {"Unified_Ideograph", "Ideographic"},
    131684: {"Unified_Ideograph", "Ideographic"},
    131685: {"Unified_Ideograph", "Ideographic"},
    131686: {"Unified_Ideograph", "Ideographic"},
    131687: {"Unified_Ideograph", "Ideographic"},
    131688: {"Unified_Ideograph", "Ideographic"},
    131689: {"Unified_Ideograph", "Ideographic"},
    131690: {"Unified_Ideograph", "Ideographic"},
    131691: {"Unified_Ideograph", "Ideographic"},
    131692: {"Unified_Ideograph", "Ideographic"},
    131693: {"Unified_Ideograph", "Ideographic"},
    131694: {"Unified_Ideograph", "Ideographic"},
    131695: {"Unified_Ideograph", "Ideographic"},
    131696: {"Unified_Ideograph", "Ideographic"},
    131697: {"Unified_Ideograph", "Ideographic"},
    131698: {"Unified_Ideograph", "Ideographic"},
    131699: {"Unified_Ideograph", "Ideographic"},
    131700: {"Unified_Ideograph", "Ideographic"},
    131701: {"Unified_Ideograph", "Ideographic"},
    131702: {"Unified_Ideograph", "Ideographic"},
    131703: {"Unified_Ideograph", "Ideographic"},
    131704: {"Unified_Ideograph", "Ideographic"},
    131705: {"Unified_Ideograph", "Ideographic"},
    131706: {"Unified_Ideograph", "Ideographic"},
    131707: {"Unified_Ideograph", "Ideographic"},
    131708: {"Unified_Ideograph", "Ideographic"},
    131709: {"Unified_Ideograph", "Ideographic"},
    131710: {"Unified_Ideograph", "Ideographic"},
    131711: {"Unified_Ideograph", "Ideographic"},
    131712: {"Unified_Ideograph", "Ideographic"},
    131713: {"Unified_Ideograph", "Ideographic"},
    131714: {"Unified_Ideograph", "Ideographic"},
    131715: {"Unified_Ideograph", "Ideographic"},
    131716: {"Unified_Ideograph", "Ideographic"},
    131717: {"Unified_Ideograph", "Ideographic"},
    131718: {"Unified_Ideograph", "Ideographic"},
    131719: {"Unified_Ideograph", "Ideographic"},
    131720: {"Unified_Ideograph", "Ideographic"},
    131721: {"Unified_Ideograph", "Ideographic"},
    131722: {"Unified_Ideograph", "Ideographic"},
    131723: {"Unified_Ideograph", "Ideographic"},
    131724: {"Unified_Ideograph", "Ideographic"},
    131725: {"Unified_Ideograph", "Ideographic"},
    131726: {"Unified_Ideograph", "Ideographic"},
    131727: {"Unified_Ideograph", "Ideographic"},
    131728: {"Unified_Ideograph", "Ideographic"},
    131729: {"Unified_Ideograph", "Ideographic"},
    131730: {"Unified_Ideograph", "Ideographic"},
    131731: {"Unified_Ideograph", "Ideographic"},
    131732: {"Unified_Ideograph", "Ideographic"},
    131733: {"Unified_Ideograph", "Ideographic"},
    131734: {"Unified_Ideograph", "Ideographic"},
    131735: {"Unified_Ideograph", "Ideographic"},
    131736: {"Unified_Ideograph", "Ideographic"},
    131737: {"Unified_Ideograph", "Ideographic"},
    131738: {"Unified_Ideograph", "Ideographic"},
    131739: {"Unified_Ideograph", "Ideographic"},
    131740: {"Unified_Ideograph", "Ideographic"},
    131741: {"Unified_Ideograph", "Ideographic"},
    131742: {"Unified_Ideograph", "Ideographic"},
    131743: {"Unified_Ideograph", "Ideographic"},
    131744: {"Unified_Ideograph", "Ideographic"},
    131745: {"Unified_Ideograph", "Ideographic"},
    131746: {"Unified_Ideograph", "Ideographic"},
    131747: {"Unified_Ideograph", "Ideographic"},
    131748: {"Unified_Ideograph", "Ideographic"},
    131749: {"Unified_Ideograph", "Ideographic"},
    131750: {"Unified_Ideograph", "Ideographic"},
    131751: {"Unified_Ideograph", "Ideographic"},
    131752: {"Unified_Ideograph", "Ideographic"},
    131753: {"Unified_Ideograph", "Ideographic"},
    131754: {"Unified_Ideograph", "Ideographic"},
    131755: {"Unified_Ideograph", "Ideographic"},
    131756: {"Unified_Ideograph", "Ideographic"},
    131757: {"Unified_Ideograph", "Ideographic"},
    131758: {"Unified_Ideograph", "Ideographic"},
    131759: {"Unified_Ideograph", "Ideographic"},
    131760: {"Unified_Ideograph", "Ideographic"},
    131761: {"Unified_Ideograph", "Ideographic"},
    131762: {"Unified_Ideograph", "Ideographic"},
    131763: {"Unified_Ideograph", "Ideographic"},
    131764: {"Unified_Ideograph", "Ideographic"},
    131765: {"Unified_Ideograph", "Ideographic"},
    131766: {"Unified_Ideograph", "Ideographic"},
    131767: {"Unified_Ideograph", "Ideographic"},
    131768: {"Unified_Ideograph", "Ideographic"},
    131769: {"Unified_Ideograph", "Ideographic"},
    131770: {"Unified_Ideograph", "Ideographic"},
    131771: {"Unified_Ideograph", "Ideographic"},
    131772: {"Unified_Ideograph", "Ideographic"},
    131773: {"Unified_Ideograph", "Ideographic"},
    131774: {"Unified_Ideograph", "Ideographic"},
    131775: {"Unified_Ideograph", "Ideographic"},
    131776: {"Unified_Ideograph", "Ideographic"},
    131777: {"Unified_Ideograph", "Ideographic"},
    131778: {"Unified_Ideograph", "Ideographic"},
    131779: {"Unified_Ideograph", "Ideographic"},
    131780: {"Unified_Ideograph", "Ideographic"},
    131781: {"Unified_Ideograph", "Ideographic"},
    131782: {"Unified_Ideograph", "Ideographic"},
    131783: {"Unified_Ideograph", "Ideographic"},
    131784: {"Unified_Ideograph", "Ideographic"},
    131785: {"Unified_Ideograph", "Ideographic"},
    131786: {"Unified_Ideograph", "Ideographic"},
    131787: {"Unified_Ideograph", "Ideographic"},
    131788: {"Unified_Ideograph", "Ideographic"},
    131789: {"Unified_Ideograph", "Ideographic"},
    131790: {"Unified_Ideograph", "Ideographic"},
    131791: {"Unified_Ideograph", "Ideographic"},
    131792: {"Unified_Ideograph", "Ideographic"},
    131793: {"Unified_Ideograph", "Ideographic"},
    131794: {"Unified_Ideograph", "Ideographic"},
    131795: {"Unified_Ideograph", "Ideographic"},
    131796: {"Unified_Ideograph", "Ideographic"},
    131797: {"Unified_Ideograph", "Ideographic"},
    131798: {"Unified_Ideograph", "Ideographic"},
    131799: {"Unified_Ideograph", "Ideographic"},
    131800: {"Unified_Ideograph", "Ideographic"},
    131801: {"Unified_Ideograph", "Ideographic"},
    131802: {"Unified_Ideograph", "Ideographic"},
    131803: {"Unified_Ideograph", "Ideographic"},
    131804: {"Unified_Ideograph", "Ideographic"},
    131805: {"Unified_Ideograph", "Ideographic"},
    131806: {"Unified_Ideograph", "Ideographic"},
    131807: {"Unified_Ideograph", "Ideographic"},
    131808: {"Unified_Ideograph", "Ideographic"},
    131809: {"Unified_Ideograph", "Ideographic"},
    131810: {"Unified_Ideograph", "Ideographic"},
    131811: {"Unified_Ideograph", "Ideographic"},
    131812: {"Unified_Ideograph", "Ideographic"},
    131813: {"Unified_Ideograph", "Ideographic"},
    131814: {"Unified_Ideograph", "Ideographic"},
    131815: {"Unified_Ideograph", "Ideographic"},
    131816: {"Unified_Ideograph", "Ideographic"},
    131817: {"Unified_Ideograph", "Ideographic"},
    131818: {"Unified_Ideograph", "Ideographic"},
    131819: {"Unified_Ideograph", "Ideographic"},
    131820: {"Unified_Ideograph", "Ideographic"},
    131821: {"Unified_Ideograph", "Ideographic"},
    131822: {"Unified_Ideograph", "Ideographic"},
    131823: {"Unified_Ideograph", "Ideographic"},
    131824: {"Unified_Ideograph", "Ideographic"},
    131825: {"Unified_Ideograph", "Ideographic"},
    131826: {"Unified_Ideograph", "Ideographic"},
    131827: {"Unified_Ideograph", "Ideographic"},
    131828: {"Unified_Ideograph", "Ideographic"},
    131829: {"Unified_Ideograph", "Ideographic"},
    131830: {"Unified_Ideograph", "Ideographic"},
    131831: {"Unified_Ideograph", "Ideographic"},
    131832: {"Unified_Ideograph", "Ideographic"},
    131833: {"Unified_Ideograph", "Ideographic"},
    131834: {"Unified_Ideograph", "Ideographic"},
    131835: {"Unified_Ideograph", "Ideographic"},
    131836: {"Unified_Ideograph", "Ideographic"},
    131837: {"Unified_Ideograph", "Ideographic"},
    131838: {"Unified_Ideograph", "Ideographic"},
    131839: {"Unified_Ideograph", "Ideographic"},
    131840: {"Unified_Ideograph", "Ideographic"},
    131841: {"Unified_Ideograph", "Ideographic"},
    131842: {"Unified_Ideograph", "Ideographic"},
    131843: {"Unified_Ideograph", "Ideographic"},
    131844: {"Unified_Ideograph", "Ideographic"},
    131845: {"Unified_Ideograph", "Ideographic"},
    131846: {"Unified_Ideograph", "Ideographic"},
    131847: {"Unified_Ideograph", "Ideographic"},
    131848: {"Unified_Ideograph", "Ideographic"},
    131849: {"Unified_Ideograph", "Ideographic"},
    131850: {"Unified_Ideograph", "Ideographic"},
    131851: {"Unified_Ideograph", "Ideographic"},
    131852: {"Unified_Ideograph", "Ideographic"},
    131853: {"Unified_Ideograph", "Ideographic"},
    131854: {"Unified_Ideograph", "Ideographic"},
    131855: {"Unified_Ideograph", "Ideographic"},
    131856: {"Unified_Ideograph", "Ideographic"},
    131857: {"Unified_Ideograph", "Ideographic"},
    131858: {"Unified_Ideograph", "Ideographic"},
    131859: {"Unified_Ideograph", "Ideographic"},
    131860: {"Unified_Ideograph", "Ideographic"},
    131861: {"Unified_Ideograph", "Ideographic"},
    131862: {"Unified_Ideograph", "Ideographic"},
    131863: {"Unified_Ideograph", "Ideographic"},
    131864: {"Unified_Ideograph", "Ideographic"},
    131865: {"Unified_Ideograph", "Ideographic"},
    131866: {"Unified_Ideograph", "Ideographic"},
    131867: {"Unified_Ideograph", "Ideographic"},
    131868: {"Unified_Ideograph", "Ideographic"},
    131869: {"Unified_Ideograph", "Ideographic"},
    131870: {"Unified_Ideograph", "Ideographic"},
    131871: {"Unified_Ideograph", "Ideographic"},
    131872: {"Unified_Ideograph", "Ideographic"},
    131873: {"Unified_Ideograph", "Ideographic"},
    131874: {"Unified_Ideograph", "Ideographic"},
    131875: {"Unified_Ideograph", "Ideographic"},
    131876: {"Unified_Ideograph", "Ideographic"},
    131877: {"Unified_Ideograph", "Ideographic"},
    131878: {"Unified_Ideograph", "Ideographic"},
    131879: {"Unified_Ideograph", "Ideographic"},
    131880: {"Unified_Ideograph", "Ideographic"},
    131881: {"Unified_Ideograph", "Ideographic"},
    131882: {"Unified_Ideograph", "Ideographic"},
    131883: {"Unified_Ideograph", "Ideographic"},
    131884: {"Unified_Ideograph", "Ideographic"},
    131885: {"Unified_Ideograph", "Ideographic"},
    131886: {"Unified_Ideograph", "Ideographic"},
    131887: {"Unified_Ideograph", "Ideographic"},
    131888: {"Unified_Ideograph", "Ideographic"},
    131889: {"Unified_Ideograph", "Ideographic"},
    131890: {"Unified_Ideograph", "Ideographic"},
    131891: {"Unified_Ideograph", "Ideographic"},
    131892: {"Unified_Ideograph", "Ideographic"},
    131893: {"Unified_Ideograph", "Ideographic"},
    131894: {"Unified_Ideograph", "Ideographic"},
    131895: {"Unified_Ideograph", "Ideographic"},
    131896: {"Unified_Ideograph", "Ideographic"},
    131897: {"Unified_Ideograph", "Ideographic"},
    131898: {"Unified_Ideograph", "Ideographic"},
    131899: {"Unified_Ideograph", "Ideographic"},
    131900: {"Unified_Ideograph", "Ideographic"},
    131901: {"Unified_Ideograph", "Ideographic"},
    131902: {"Unified_Ideograph", "Ideographic"},
    131903: {"Unified_Ideograph", "Ideographic"},
    131904: {"Unified_Ideograph", "Ideographic"},
    131905: {"Unified_Ideograph", "Ideographic"},
    131906: {"Unified_Ideograph", "Ideographic"},
    131907: {"Unified_Ideograph", "Ideographic"},
    131908: {"Unified_Ideograph", "Ideographic"},
    131909: {"Unified_Ideograph", "Ideographic"},
    131910: {"Unified_Ideograph", "Ideographic"},
    131911: {"Unified_Ideograph", "Ideographic"},
    131912: {"Unified_Ideograph", "Ideographic"},
    131913: {"Unified_Ideograph", "Ideographic"},
    131914: {"Unified_Ideograph", "Ideographic"},
    131915: {"Unified_Ideograph", "Ideographic"},
    131916: {"Unified_Ideograph", "Ideographic"},
    131917: {"Unified_Ideograph", "Ideographic"},
    131918: {"Unified_Ideograph", "Ideographic"},
    131919: {"Unified_Ideograph", "Ideographic"},
    131920: {"Unified_Ideograph", "Ideographic"},
    131921: {"Unified_Ideograph", "Ideographic"},
    131922: {"Unified_Ideograph", "Ideographic"},
    131923: {"Unified_Ideograph", "Ideographic"},
    131924: {"Unified_Ideograph", "Ideographic"},
    131925: {"Unified_Ideograph", "Ideographic"},
    131926: {"Unified_Ideograph", "Ideographic"},
    131927: {"Unified_Ideograph", "Ideographic"},
    131928: {"Unified_Ideograph", "Ideographic"},
    131929: {"Unified_Ideograph", "Ideographic"},
    131930: {"Unified_Ideograph", "Ideographic"},
    131931: {"Unified_Ideograph", "Ideographic"},
    131932: {"Unified_Ideograph", "Ideographic"},
    131933: {"Unified_Ideograph", "Ideographic"},
    131934: {"Unified_Ideograph", "Ideographic"},
    131935: {"Unified_Ideograph", "Ideographic"},
    131936: {"Unified_Ideograph", "Ideographic"},
    131937: {"Unified_Ideograph", "Ideographic"},
    131938: {"Unified_Ideograph", "Ideographic"},
    131939: {"Unified_Ideograph", "Ideographic"},
    131940: {"Unified_Ideograph", "Ideographic"},
    131941: {"Unified_Ideograph", "Ideographic"},
    131942: {"Unified_Ideograph", "Ideographic"},
    131943: {"Unified_Ideograph", "Ideographic"},
    131944: {"Unified_Ideograph", "Ideographic"},
    131945: {"Unified_Ideograph", "Ideographic"},
    131946: {"Unified_Ideograph", "Ideographic"},
    131947: {"Unified_Ideograph", "Ideographic"},
    131948: {"Unified_Ideograph", "Ideographic"},
    131949: {"Unified_Ideograph", "Ideographic"},
    131950: {"Unified_Ideograph", "Ideographic"},
    131951: {"Unified_Ideograph", "Ideographic"},
    131952: {"Unified_Ideograph", "Ideographic"},
    131953: {"Unified_Ideograph", "Ideographic"},
    131954: {"Unified_Ideograph", "Ideographic"},
    131955: {"Unified_Ideograph", "Ideographic"},
    131956: {"Unified_Ideograph", "Ideographic"},
    131957: {"Unified_Ideograph", "Ideographic"},
    131958: {"Unified_Ideograph", "Ideographic"},
    131959: {"Unified_Ideograph", "Ideographic"},
    131960: {"Unified_Ideograph", "Ideographic"},
    131961: {"Unified_Ideograph", "Ideographic"},
    131962: {"Unified_Ideograph", "Ideographic"},
    131963: {"Unified_Ideograph", "Ideographic"},
    131964: {"Unified_Ideograph", "Ideographic"},
    131965: {"Unified_Ideograph", "Ideographic"},
    131966: {"Unified_Ideograph", "Ideographic"},
    131967: {"Unified_Ideograph", "Ideographic"},
    131968: {"Unified_Ideograph", "Ideographic"},
    131969: {"Unified_Ideograph", "Ideographic"},
    131970: {"Unified_Ideograph", "Ideographic"},
    131971: {"Unified_Ideograph", "Ideographic"},
    131972: {"Unified_Ideograph", "Ideographic"},
    131973: {"Unified_Ideograph", "Ideographic"},
    131974: {"Unified_Ideograph", "Ideographic"},
    131975: {"Unified_Ideograph", "Ideographic"},
    131976: {"Unified_Ideograph", "Ideographic"},
    131977: {"Unified_Ideograph", "Ideographic"},
    131978: {"Unified_Ideograph", "Ideographic"},
    131979: {"Unified_Ideograph", "Ideographic"},
    131980: {"Unified_Ideograph", "Ideographic"},
    131981: {"Unified_Ideograph", "Ideographic"},
    131982: {"Unified_Ideograph", "Ideographic"},
    131983: {"Unified_Ideograph", "Ideographic"},
    131984: {"Unified_Ideograph", "Ideographic"},
    131985: {"Unified_Ideograph", "Ideographic"},
    131986: {"Unified_Ideograph", "Ideographic"},
    131987: {"Unified_Ideograph", "Ideographic"},
    131988: {"Unified_Ideograph", "Ideographic"},
    131989: {"Unified_Ideograph", "Ideographic"},
    131990: {"Unified_Ideograph", "Ideographic"},
    131991: {"Unified_Ideograph", "Ideographic"},
    131992: {"Unified_Ideograph", "Ideographic"},
    131993: {"Unified_Ideograph", "Ideographic"},
    131994: {"Unified_Ideograph", "Ideographic"},
    131995: {"Unified_Ideograph", "Ideographic"},
    131996: {"Unified_Ideograph", "Ideographic"},
    131997: {"Unified_Ideograph", "Ideographic"},
    131998: {"Unified_Ideograph", "Ideographic"},
    131999: {"Unified_Ideograph", "Ideographic"},
    132000: {"Unified_Ideograph", "Ideographic"},
    132001: {"Unified_Ideograph", "Ideographic"},
    132002: {"Unified_Ideograph", "Ideographic"},
    132003: {"Unified_Ideograph", "Ideographic"},
    132004: {"Unified_Ideograph", "Ideographic"},
    132005: {"Unified_Ideograph", "Ideographic"},
    132006: {"Unified_Ideograph", "Ideographic"},
    132007: {"Unified_Ideograph", "Ideographic"},
    132008: {"Unified_Ideograph", "Ideographic"},
    132009: {"Unified_Ideograph", "Ideographic"},
    132010: {"Unified_Ideograph", "Ideographic"},
    132011: {"Unified_Ideograph", "Ideographic"},
    132012: {"Unified_Ideograph", "Ideographic"},
    132013: {"Unified_Ideograph", "Ideographic"},
    132014: {"Unified_Ideograph", "Ideographic"},
    132015: {"Unified_Ideograph", "Ideographic"},
    132016: {"Unified_Ideograph", "Ideographic"},
    132017: {"Unified_Ideograph", "Ideographic"},
    132018: {"Unified_Ideograph", "Ideographic"},
    132019: {"Unified_Ideograph", "Ideographic"},
    132020: {"Unified_Ideograph", "Ideographic"},
    132021: {"Unified_Ideograph", "Ideographic"},
    132022: {"Unified_Ideograph", "Ideographic"},
    132023: {"Unified_Ideograph", "Ideographic"},
    132024: {"Unified_Ideograph", "Ideographic"},
    132025: {"Unified_Ideograph", "Ideographic"},
    132026: {"Unified_Ideograph", "Ideographic"},
    132027: {"Unified_Ideograph", "Ideographic"},
    132028: {"Unified_Ideograph", "Ideographic"},
    132029: {"Unified_Ideograph", "Ideographic"},
    132030: {"Unified_Ideograph", "Ideographic"},
    132031: {"Unified_Ideograph", "Ideographic"},
    132032: {"Unified_Ideograph", "Ideographic"},
    132033: {"Unified_Ideograph", "Ideographic"},
    132034: {"Unified_Ideograph", "Ideographic"},
    132035: {"Unified_Ideograph", "Ideographic"},
    132036: {"Unified_Ideograph", "Ideographic"},
    132037: {"Unified_Ideograph", "Ideographic"},
    132038: {"Unified_Ideograph", "Ideographic"},
    132039: {"Unified_Ideograph", "Ideographic"},
    132040: {"Unified_Ideograph", "Ideographic"},
    132041: {"Unified_Ideograph", "Ideographic"},
    132042: {"Unified_Ideograph", "Ideographic"},
    132043: {"Unified_Ideograph", "Ideographic"},
    132044: {"Unified_Ideograph", "Ideographic"},
    132045: {"Unified_Ideograph", "Ideographic"},
    132046: {"Unified_Ideograph", "Ideographic"},
    132047: {"Unified_Ideograph", "Ideographic"},
    132048: {"Unified_Ideograph", "Ideographic"},
    132049: {"Unified_Ideograph", "Ideographic"},
    132050: {"Unified_Ideograph", "Ideographic"},
    132051: {"Unified_Ideograph", "Ideographic"},
    132052: {"Unified_Ideograph", "Ideographic"},
    132053: {"Unified_Ideograph", "Ideographic"},
    132054: {"Unified_Ideograph", "Ideographic"},
    132055: {"Unified_Ideograph", "Ideographic"},
    132056: {"Unified_Ideograph", "Ideographic"},
    132057: {"Unified_Ideograph", "Ideographic"},
    132058: {"Unified_Ideograph", "Ideographic"},
    132059: {"Unified_Ideograph", "Ideographic"},
    132060: {"Unified_Ideograph", "Ideographic"},
    132061: {"Unified_Ideograph", "Ideographic"},
    132062: {"Unified_Ideograph", "Ideographic"},
    132063: {"Unified_Ideograph", "Ideographic"},
    132064: {"Unified_Ideograph", "Ideographic"},
    132065: {"Unified_Ideograph", "Ideographic"},
    132066: {"Unified_Ideograph", "Ideographic"},
    132067: {"Unified_Ideograph", "Ideographic"},
    132068: {"Unified_Ideograph", "Ideographic"},
    132069: {"Unified_Ideograph", "Ideographic"},
    132070: {"Unified_Ideograph", "Ideographic"},
    132071: {"Unified_Ideograph", "Ideographic"},
    132072: {"Unified_Ideograph", "Ideographic"},
    132073: {"Unified_Ideograph", "Ideographic"},
    132074: {"Unified_Ideograph", "Ideographic"},
    132075: {"Unified_Ideograph", "Ideographic"},
    132076: {"Unified_Ideograph", "Ideographic"},
    132077: {"Unified_Ideograph", "Ideographic"},
    132078: {"Unified_Ideograph", "Ideographic"},
    132079: {"Unified_Ideograph", "Ideographic"},
    132080: {"Unified_Ideograph", "Ideographic"},
    132081: {"Unified_Ideograph", "Ideographic"},
    132082: {"Unified_Ideograph", "Ideographic"},
    132083: {"Unified_Ideograph", "Ideographic"},
    132084: {"Unified_Ideograph", "Ideographic"},
    132085: {"Unified_Ideograph", "Ideographic"},
    132086: {"Unified_Ideograph", "Ideographic"},
    132087: {"Unified_Ideograph", "Ideographic"},
    132088: {"Unified_Ideograph", "Ideographic"},
    132089: {"Unified_Ideograph", "Ideographic"},
    132090: {"Unified_Ideograph", "Ideographic"},
    132091: {"Unified_Ideograph", "Ideographic"},
    132092: {"Unified_Ideograph", "Ideographic"},
    132093: {"Unified_Ideograph", "Ideographic"},
    132094: {"Unified_Ideograph", "Ideographic"},
    132095: {"Unified_Ideograph", "Ideographic"},
    132096: {"Unified_Ideograph", "Ideographic"},
    132097: {"Unified_Ideograph", "Ideographic"},
    132098: {"Unified_Ideograph", "Ideographic"},
    132099: {"Unified_Ideograph", "Ideographic"},
    132100: {"Unified_Ideograph", "Ideographic"},
    132101: {"Unified_Ideograph", "Ideographic"},
    132102: {"Unified_Ideograph", "Ideographic"},
    132103: {"Unified_Ideograph", "Ideographic"},
    132104: {"Unified_Ideograph", "Ideographic"},
    132105: {"Unified_Ideograph", "Ideographic"},
    132106: {"Unified_Ideograph", "Ideographic"},
    132107: {"Unified_Ideograph", "Ideographic"},
    132108: {"Unified_Ideograph", "Ideographic"},
    132109: {"Unified_Ideograph", "Ideographic"},
    132110: {"Unified_Ideograph", "Ideographic"},
    132111: {"Unified_Ideograph", "Ideographic"},
    132112: {"Unified_Ideograph", "Ideographic"},
    132113: {"Unified_Ideograph", "Ideographic"},
    132114: {"Unified_Ideograph", "Ideographic"},
    132115: {"Unified_Ideograph", "Ideographic"},
    132116: {"Unified_Ideograph", "Ideographic"},
    132117: {"Unified_Ideograph", "Ideographic"},
    132118: {"Unified_Ideograph", "Ideographic"},
    132119: {"Unified_Ideograph", "Ideographic"},
    132120: {"Unified_Ideograph", "Ideographic"},
    132121: {"Unified_Ideograph", "Ideographic"},
    132122: {"Unified_Ideograph", "Ideographic"},
    132123: {"Unified_Ideograph", "Ideographic"},
    132124: {"Unified_Ideograph", "Ideographic"},
    132125: {"Unified_Ideograph", "Ideographic"},
    132126: {"Unified_Ideograph", "Ideographic"},
    132127: {"Unified_Ideograph", "Ideographic"},
    132128: {"Unified_Ideograph", "Ideographic"},
    132129: {"Unified_Ideograph", "Ideographic"},
    132130: {"Unified_Ideograph", "Ideographic"},
    132131: {"Unified_Ideograph", "Ideographic"},
    132132: {"Unified_Ideograph", "Ideographic"},
    132133: {"Unified_Ideograph", "Ideographic"},
    132134: {"Unified_Ideograph", "Ideographic"},
    132135: {"Unified_Ideograph", "Ideographic"},
    132136: {"Unified_Ideograph", "Ideographic"},
    132137: {"Unified_Ideograph", "Ideographic"},
    132138: {"Unified_Ideograph", "Ideographic"},
    132139: {"Unified_Ideograph", "Ideographic"},
    132140: {"Unified_Ideograph", "Ideographic"},
    132141: {"Unified_Ideograph", "Ideographic"},
    132142: {"Unified_Ideograph", "Ideographic"},
    132143: {"Unified_Ideograph", "Ideographic"},
    132144: {"Unified_Ideograph", "Ideographic"},
    132145: {"Unified_Ideograph", "Ideographic"},
    132146: {"Unified_Ideograph", "Ideographic"},
    132147: {"Unified_Ideograph", "Ideographic"},
    132148: {"Unified_Ideograph", "Ideographic"},
    132149: {"Unified_Ideograph", "Ideographic"},
    132150: {"Unified_Ideograph", "Ideographic"},
    132151: {"Unified_Ideograph", "Ideographic"},
    132152: {"Unified_Ideograph", "Ideographic"},
    132153: {"Unified_Ideograph", "Ideographic"},
    132154: {"Unified_Ideograph", "Ideographic"},
    132155: {"Unified_Ideograph", "Ideographic"},
    132156: {"Unified_Ideograph", "Ideographic"},
    132157: {"Unified_Ideograph", "Ideographic"},
    132158: {"Unified_Ideograph", "Ideographic"},
    132159: {"Unified_Ideograph", "Ideographic"},
    132160: {"Unified_Ideograph", "Ideographic"},
    132161: {"Unified_Ideograph", "Ideographic"},
    132162: {"Unified_Ideograph", "Ideographic"},
    132163: {"Unified_Ideograph", "Ideographic"},
    132164: {"Unified_Ideograph", "Ideographic"},
    132165: {"Unified_Ideograph", "Ideographic"},
    132166: {"Unified_Ideograph", "Ideographic"},
    132167: {"Unified_Ideograph", "Ideographic"},
    132168: {"Unified_Ideograph", "Ideographic"},
    132169: {"Unified_Ideograph", "Ideographic"},
    132170: {"Unified_Ideograph", "Ideographic"},
    132171: {"Unified_Ideograph", "Ideographic"},
    132172: {"Unified_Ideograph", "Ideographic"},
    132173: {"Unified_Ideograph", "Ideographic"},
    132174: {"Unified_Ideograph", "Ideographic"},
    132175: {"Unified_Ideograph", "Ideographic"},
    132176: {"Unified_Ideograph", "Ideographic"},
    132177: {"Unified_Ideograph", "Ideographic"},
    132178: {"Unified_Ideograph", "Ideographic"},
    132179: {"Unified_Ideograph", "Ideographic"},
    132180: {"Unified_Ideograph", "Ideographic"},
    132181: {"Unified_Ideograph", "Ideographic"},
    132182: {"Unified_Ideograph", "Ideographic"},
    132183: {"Unified_Ideograph", "Ideographic"},
    132184: {"Unified_Ideograph", "Ideographic"},
    132185: {"Unified_Ideograph", "Ideographic"},
    132186: {"Unified_Ideograph", "Ideographic"},
    132187: {"Unified_Ideograph", "Ideographic"},
    132188: {"Unified_Ideograph", "Ideographic"},
    132189: {"Unified_Ideograph", "Ideographic"},
    132190: {"Unified_Ideograph", "Ideographic"},
    132191: {"Unified_Ideograph", "Ideographic"},
    132192: {"Unified_Ideograph", "Ideographic"},
    132193: {"Unified_Ideograph", "Ideographic"},
    132194: {"Unified_Ideograph", "Ideographic"},
    132195: {"Unified_Ideograph", "Ideographic"},
    132196: {"Unified_Ideograph", "Ideographic"},
    132197: {"Unified_Ideograph", "Ideographic"},
    132198: {"Unified_Ideograph", "Ideographic"},
    132199: {"Unified_Ideograph", "Ideographic"},
    132200: {"Unified_Ideograph", "Ideographic"},
    132201: {"Unified_Ideograph", "Ideographic"},
    132202: {"Unified_Ideograph", "Ideographic"},
    132203: {"Unified_Ideograph", "Ideographic"},
    132204: {"Unified_Ideograph", "Ideographic"},
    132205: {"Unified_Ideograph", "Ideographic"},
    132206: {"Unified_Ideograph", "Ideographic"},
    132207: {"Unified_Ideograph", "Ideographic"},
    132208: {"Unified_Ideograph", "Ideographic"},
    132209: {"Unified_Ideograph", "Ideographic"},
    132210: {"Unified_Ideograph", "Ideographic"},
    132211: {"Unified_Ideograph", "Ideographic"},
    132212: {"Unified_Ideograph", "Ideographic"},
    132213: {"Unified_Ideograph", "Ideographic"},
    132214: {"Unified_Ideograph", "Ideographic"},
    132215: {"Unified_Ideograph", "Ideographic"},
    132216: {"Unified_Ideograph", "Ideographic"},
    132217: {"Unified_Ideograph", "Ideographic"},
    132218: {"Unified_Ideograph", "Ideographic"},
    132219: {"Unified_Ideograph", "Ideographic"},
    132220: {"Unified_Ideograph", "Ideographic"},
    132221: {"Unified_Ideograph", "Ideographic"},
    132222: {"Unified_Ideograph", "Ideographic"},
    132223: {"Unified_Ideograph", "Ideographic"},
    132224: {"Unified_Ideograph", "Ideographic"},
    132225: {"Unified_Ideograph", "Ideographic"},
    132226: {"Unified_Ideograph", "Ideographic"},
    132227: {"Unified_Ideograph", "Ideographic"},
    132228: {"Unified_Ideograph", "Ideographic"},
    132229: {"Unified_Ideograph", "Ideographic"},
    132230: {"Unified_Ideograph", "Ideographic"},
    132231: {"Unified_Ideograph", "Ideographic"},
    132232: {"Unified_Ideograph", "Ideographic"},
    132233: {"Unified_Ideograph", "Ideographic"},
    132234: {"Unified_Ideograph", "Ideographic"},
    132235: {"Unified_Ideograph", "Ideographic"},
    132236: {"Unified_Ideograph", "Ideographic"},
    132237: {"Unified_Ideograph", "Ideographic"},
    132238: {"Unified_Ideograph", "Ideographic"},
    132239: {"Unified_Ideograph", "Ideographic"},
    132240: {"Unified_Ideograph", "Ideographic"},
    132241: {"Unified_Ideograph", "Ideographic"},
    132242: {"Unified_Ideograph", "Ideographic"},
    132243: {"Unified_Ideograph", "Ideographic"},
    132244: {"Unified_Ideograph", "Ideographic"},
    132245: {"Unified_Ideograph", "Ideographic"},
    132246: {"Unified_Ideograph", "Ideographic"},
    132247: {"Unified_Ideograph", "Ideographic"},
    132248: {"Unified_Ideograph", "Ideographic"},
    132249: {"Unified_Ideograph", "Ideographic"},
    132250: {"Unified_Ideograph", "Ideographic"},
    132251: {"Unified_Ideograph", "Ideographic"},
    132252: {"Unified_Ideograph", "Ideographic"},
    132253: {"Unified_Ideograph", "Ideographic"},
    132254: {"Unified_Ideograph", "Ideographic"},
    132255: {"Unified_Ideograph", "Ideographic"},
    132256: {"Unified_Ideograph", "Ideographic"},
    132257: {"Unified_Ideograph", "Ideographic"},
    132258: {"Unified_Ideograph", "Ideographic"},
    132259: {"Unified_Ideograph", "Ideographic"},
    132260: {"Unified_Ideograph", "Ideographic"},
    132261: {"Unified_Ideograph", "Ideographic"},
    132262: {"Unified_Ideograph", "Ideographic"},
    132263: {"Unified_Ideograph", "Ideographic"},
    132264: {"Unified_Ideograph", "Ideographic"},
    132265: {"Unified_Ideograph", "Ideographic"},
    132266: {"Unified_Ideograph", "Ideographic"},
    132267: {"Unified_Ideograph", "Ideographic"},
    132268: {"Unified_Ideograph", "Ideographic"},
    132269: {"Unified_Ideograph", "Ideographic"},
    132270: {"Unified_Ideograph", "Ideographic"},
    132271: {"Unified_Ideograph", "Ideographic"},
    132272: {"Unified_Ideograph", "Ideographic"},
    132273: {"Unified_Ideograph", "Ideographic"},
    132274: {"Unified_Ideograph", "Ideographic"},
    132275: {"Unified_Ideograph", "Ideographic"},
    132276: {"Unified_Ideograph", "Ideographic"},
    132277: {"Unified_Ideograph", "Ideographic"},
    132278: {"Unified_Ideograph", "Ideographic"},
    132279: {"Unified_Ideograph", "Ideographic"},
    132280: {"Unified_Ideograph", "Ideographic"},
    132281: {"Unified_Ideograph", "Ideographic"},
    132282: {"Unified_Ideograph", "Ideographic"},
    132283: {"Unified_Ideograph", "Ideographic"},
    132284: {"Unified_Ideograph", "Ideographic"},
    132285: {"Unified_Ideograph", "Ideographic"},
    132286: {"Unified_Ideograph", "Ideographic"},
    132287: {"Unified_Ideograph", "Ideographic"},
    132288: {"Unified_Ideograph", "Ideographic"},
    132289: {"Unified_Ideograph", "Ideographic"},
    132290: {"Unified_Ideograph", "Ideographic"},
    132291: {"Unified_Ideograph", "Ideographic"},
    132292: {"Unified_Ideograph", "Ideographic"},
    132293: {"Unified_Ideograph", "Ideographic"},
    132294: {"Unified_Ideograph", "Ideographic"},
    132295: {"Unified_Ideograph", "Ideographic"},
    132296: {"Unified_Ideograph", "Ideographic"},
    132297: {"Unified_Ideograph", "Ideographic"},
    132298: {"Unified_Ideograph", "Ideographic"},
    132299: {"Unified_Ideograph", "Ideographic"},
    132300: {"Unified_Ideograph", "Ideographic"},
    132301: {"Unified_Ideograph", "Ideographic"},
    132302: {"Unified_Ideograph", "Ideographic"},
    132303: {"Unified_Ideograph", "Ideographic"},
    132304: {"Unified_Ideograph", "Ideographic"},
    132305: {"Unified_Ideograph", "Ideographic"},
    132306: {"Unified_Ideograph", "Ideographic"},
    132307: {"Unified_Ideograph", "Ideographic"},
    132308: {"Unified_Ideograph", "Ideographic"},
    132309: {"Unified_Ideograph", "Ideographic"},
    132310: {"Unified_Ideograph", "Ideographic"},
    132311: {"Unified_Ideograph", "Ideographic"},
    132312: {"Unified_Ideograph", "Ideographic"},
    132313: {"Unified_Ideograph", "Ideographic"},
    132314: {"Unified_Ideograph", "Ideographic"},
    132315: {"Unified_Ideograph", "Ideographic"},
    132316: {"Unified_Ideograph", "Ideographic"},
    132317: {"Unified_Ideograph", "Ideographic"},
    132318: {"Unified_Ideograph", "Ideographic"},
    132319: {"Unified_Ideograph", "Ideographic"},
    132320: {"Unified_Ideograph", "Ideographic"},
    132321: {"Unified_Ideograph", "Ideographic"},
    132322: {"Unified_Ideograph", "Ideographic"},
    132323: {"Unified_Ideograph", "Ideographic"},
    132324: {"Unified_Ideograph", "Ideographic"},
    132325: {"Unified_Ideograph", "Ideographic"},
    132326: {"Unified_Ideograph", "Ideographic"},
    132327: {"Unified_Ideograph", "Ideographic"},
    132328: {"Unified_Ideograph", "Ideographic"},
    132329: {"Unified_Ideograph", "Ideographic"},
    132330: {"Unified_Ideograph", "Ideographic"},
    132331: {"Unified_Ideograph", "Ideographic"},
    132332: {"Unified_Ideograph", "Ideographic"},
    132333: {"Unified_Ideograph", "Ideographic"},
    132334: {"Unified_Ideograph", "Ideographic"},
    132335: {"Unified_Ideograph", "Ideographic"},
    132336: {"Unified_Ideograph", "Ideographic"},
    132337: {"Unified_Ideograph", "Ideographic"},
    132338: {"Unified_Ideograph", "Ideographic"},
    132339: {"Unified_Ideograph", "Ideographic"},
    132340: {"Unified_Ideograph", "Ideographic"},
    132341: {"Unified_Ideograph", "Ideographic"},
    132342: {"Unified_Ideograph", "Ideographic"},
    132343: {"Unified_Ideograph", "Ideographic"},
    132344: {"Unified_Ideograph", "Ideographic"},
    132345: {"Unified_Ideograph", "Ideographic"},
    132346: {"Unified_Ideograph", "Ideographic"},
    132347: {"Unified_Ideograph", "Ideographic"},
    132348: {"Unified_Ideograph", "Ideographic"},
    132349: {"Unified_Ideograph", "Ideographic"},
    132350: {"Unified_Ideograph", "Ideographic"},
    132351: {"Unified_Ideograph", "Ideographic"},
    132352: {"Unified_Ideograph", "Ideographic"},
    132353: {"Unified_Ideograph", "Ideographic"},
    132354: {"Unified_Ideograph", "Ideographic"},
    132355: {"Unified_Ideograph", "Ideographic"},
    132356: {"Unified_Ideograph", "Ideographic"},
    132357: {"Unified_Ideograph", "Ideographic"},
    132358: {"Unified_Ideograph", "Ideographic"},
    132359: {"Unified_Ideograph", "Ideographic"},
    132360: {"Unified_Ideograph", "Ideographic"},
    132361: {"Unified_Ideograph", "Ideographic"},
    132362: {"Unified_Ideograph", "Ideographic"},
    132363: {"Unified_Ideograph", "Ideographic"},
    132364: {"Unified_Ideograph", "Ideographic"},
    132365: {"Unified_Ideograph", "Ideographic"},
    132366: {"Unified_Ideograph", "Ideographic"},
    132367: {"Unified_Ideograph", "Ideographic"},
    132368: {"Unified_Ideograph", "Ideographic"},
    132369: {"Unified_Ideograph", "Ideographic"},
    132370: {"Unified_Ideograph", "Ideographic"},
    132371: {"Unified_Ideograph", "Ideographic"},
    132372: {"Unified_Ideograph", "Ideographic"},
    132373: {"Unified_Ideograph", "Ideographic"},
    132374: {"Unified_Ideograph", "Ideographic"},
    132375: {"Unified_Ideograph", "Ideographic"},
    132376: {"Unified_Ideograph", "Ideographic"},
    132377: {"Unified_Ideograph", "Ideographic"},
    132378: {"Unified_Ideograph", "Ideographic"},
    132379: {"Unified_Ideograph", "Ideographic"},
    132380: {"Unified_Ideograph", "Ideographic"},
    132381: {"Unified_Ideograph", "Ideographic"},
    132382: {"Unified_Ideograph", "Ideographic"},
    132383: {"Unified_Ideograph", "Ideographic"},
    132384: {"Unified_Ideograph", "Ideographic"},
    132385: {"Unified_Ideograph", "Ideographic"},
    132386: {"Unified_Ideograph", "Ideographic"},
    132387: {"Unified_Ideograph", "Ideographic"},
    132388: {"Unified_Ideograph", "Ideographic"},
    132389: {"Unified_Ideograph", "Ideographic"},
    132390: {"Unified_Ideograph", "Ideographic"},
    132391: {"Unified_Ideograph", "Ideographic"},
    132392: {"Unified_Ideograph", "Ideographic"},
    132393: {"Unified_Ideograph", "Ideographic"},
    132394: {"Unified_Ideograph", "Ideographic"},
    132395: {"Unified_Ideograph", "Ideographic"},
    132396: {"Unified_Ideograph", "Ideographic"},
    132397: {"Unified_Ideograph", "Ideographic"},
    132398: {"Unified_Ideograph", "Ideographic"},
    132399: {"Unified_Ideograph", "Ideographic"},
    132400: {"Unified_Ideograph", "Ideographic"},
    132401: {"Unified_Ideograph", "Ideographic"},
    132402: {"Unified_Ideograph", "Ideographic"},
    132403: {"Unified_Ideograph", "Ideographic"},
    132404: {"Unified_Ideograph", "Ideographic"},
    132405: {"Unified_Ideograph", "Ideographic"},
    132406: {"Unified_Ideograph", "Ideographic"},
    132407: {"Unified_Ideograph", "Ideographic"},
    132408: {"Unified_Ideograph", "Ideographic"},
    132409: {"Unified_Ideograph", "Ideographic"},
    132410: {"Unified_Ideograph", "Ideographic"},
    132411: {"Unified_Ideograph", "Ideographic"},
    132412: {"Unified_Ideograph", "Ideographic"},
    132413: {"Unified_Ideograph", "Ideographic"},
    132414: {"Unified_Ideograph", "Ideographic"},
    132415: {"Unified_Ideograph", "Ideographic"},
    132416: {"Unified_Ideograph", "Ideographic"},
    132417: {"Unified_Ideograph", "Ideographic"},
    132418: {"Unified_Ideograph", "Ideographic"},
    132419: {"Unified_Ideograph", "Ideographic"},
    132420: {"Unified_Ideograph", "Ideographic"},
    132421: {"Unified_Ideograph", "Ideographic"},
    132422: {"Unified_Ideograph", "Ideographic"},
    132423: {"Unified_Ideograph", "Ideographic"},
    132424: {"Unified_Ideograph", "Ideographic"},
    132425: {"Unified_Ideograph", "Ideographic"},
    132426: {"Unified_Ideograph", "Ideographic"},
    132427: {"Unified_Ideograph", "Ideographic"},
    132428: {"Unified_Ideograph", "Ideographic"},
    132429: {"Unified_Ideograph", "Ideographic"},
    132430: {"Unified_Ideograph", "Ideographic"},
    132431: {"Unified_Ideograph", "Ideographic"},
    132432: {"Unified_Ideograph", "Ideographic"},
    132433: {"Unified_Ideograph", "Ideographic"},
    132434: {"Unified_Ideograph", "Ideographic"},
    132435: {"Unified_Ideograph", "Ideographic"},
    132436: {"Unified_Ideograph", "Ideographic"},
    132437: {"Unified_Ideograph", "Ideographic"},
    132438: {"Unified_Ideograph", "Ideographic"},
    132439: {"Unified_Ideograph", "Ideographic"},
    132440: {"Unified_Ideograph", "Ideographic"},
    132441: {"Unified_Ideograph", "Ideographic"},
    132442: {"Unified_Ideograph", "Ideographic"},
    132443: {"Unified_Ideograph", "Ideographic"},
    132444: {"Unified_Ideograph", "Ideographic"},
    132445: {"Unified_Ideograph", "Ideographic"},
    132446: {"Unified_Ideograph", "Ideographic"},
    132447: {"Unified_Ideograph", "Ideographic"},
    132448: {"Unified_Ideograph", "Ideographic"},
    132449: {"Unified_Ideograph", "Ideographic"},
    132450: {"Unified_Ideograph", "Ideographic"},
    132451: {"Unified_Ideograph", "Ideographic"},
    132452: {"Unified_Ideograph", "Ideographic"},
    132453: {"Unified_Ideograph", "Ideographic"},
    132454: {"Unified_Ideograph", "Ideographic"},
    132455: {"Unified_Ideograph", "Ideographic"},
    132456: {"Unified_Ideograph", "Ideographic"},
    132457: {"Unified_Ideograph", "Ideographic"},
    132458: {"Unified_Ideograph", "Ideographic"},
    132459: {"Unified_Ideograph", "Ideographic"},
    132460: {"Unified_Ideograph", "Ideographic"},
    132461: {"Unified_Ideograph", "Ideographic"},
    132462: {"Unified_Ideograph", "Ideographic"},
    132463: {"Unified_Ideograph", "Ideographic"},
    132464: {"Unified_Ideograph", "Ideographic"},
    132465: {"Unified_Ideograph", "Ideographic"},
    132466: {"Unified_Ideograph", "Ideographic"},
    132467: {"Unified_Ideograph", "Ideographic"},
    132468: {"Unified_Ideograph", "Ideographic"},
    132469: {"Unified_Ideograph", "Ideographic"},
    132470: {"Unified_Ideograph", "Ideographic"},
    132471: {"Unified_Ideograph", "Ideographic"},
    132472: {"Unified_Ideograph", "Ideographic"},
    132473: {"Unified_Ideograph", "Ideographic"},
    132474: {"Unified_Ideograph", "Ideographic"},
    132475: {"Unified_Ideograph", "Ideographic"},
    132476: {"Unified_Ideograph", "Ideographic"},
    132477: {"Unified_Ideograph", "Ideographic"},
    132478: {"Unified_Ideograph", "Ideographic"},
    132479: {"Unified_Ideograph", "Ideographic"},
    132480: {"Unified_Ideograph", "Ideographic"},
    132481: {"Unified_Ideograph", "Ideographic"},
    132482: {"Unified_Ideograph", "Ideographic"},
    132483: {"Unified_Ideograph", "Ideographic"},
    132484: {"Unified_Ideograph", "Ideographic"},
    132485: {"Unified_Ideograph", "Ideographic"},
    132486: {"Unified_Ideograph", "Ideographic"},
    132487: {"Unified_Ideograph", "Ideographic"},
    132488: {"Unified_Ideograph", "Ideographic"},
    132489: {"Unified_Ideograph", "Ideographic"},
    132490: {"Unified_Ideograph", "Ideographic"},
    132491: {"Unified_Ideograph", "Ideographic"},
    132492: {"Unified_Ideograph", "Ideographic"},
    132493: {"Unified_Ideograph", "Ideographic"},
    132494: {"Unified_Ideograph", "Ideographic"},
    132495: {"Unified_Ideograph", "Ideographic"},
    132496: {"Unified_Ideograph", "Ideographic"},
    132497: {"Unified_Ideograph", "Ideographic"},
    132498: {"Unified_Ideograph", "Ideographic"},
    132499: {"Unified_Ideograph", "Ideographic"},
    132500: {"Unified_Ideograph", "Ideographic"},
    132501: {"Unified_Ideograph", "Ideographic"},
    132502: {"Unified_Ideograph", "Ideographic"},
    132503: {"Unified_Ideograph", "Ideographic"},
    132504: {"Unified_Ideograph", "Ideographic"},
    132505: {"Unified_Ideograph", "Ideographic"},
    132506: {"Unified_Ideograph", "Ideographic"},
    132507: {"Unified_Ideograph", "Ideographic"},
    132508: {"Unified_Ideograph", "Ideographic"},
    132509: {"Unified_Ideograph", "Ideographic"},
    132510: {"Unified_Ideograph", "Ideographic"},
    132511: {"Unified_Ideograph", "Ideographic"},
    132512: {"Unified_Ideograph", "Ideographic"},
    132513: {"Unified_Ideograph", "Ideographic"},
    132514: {"Unified_Ideograph", "Ideographic"},
    132515: {"Unified_Ideograph", "Ideographic"},
    132516: {"Unified_Ideograph", "Ideographic"},
    132517: {"Unified_Ideograph", "Ideographic"},
    132518: {"Unified_Ideograph", "Ideographic"},
    132519: {"Unified_Ideograph", "Ideographic"},
    132520: {"Unified_Ideograph", "Ideographic"},
    132521: {"Unified_Ideograph", "Ideographic"},
    132522: {"Unified_Ideograph", "Ideographic"},
    132523: {"Unified_Ideograph", "Ideographic"},
    132524: {"Unified_Ideograph", "Ideographic"},
    132525: {"Unified_Ideograph", "Ideographic"},
    132526: {"Unified_Ideograph", "Ideographic"},
    132527: {"Unified_Ideograph", "Ideographic"},
    132528: {"Unified_Ideograph", "Ideographic"},
    132529: {"Unified_Ideograph", "Ideographic"},
    132530: {"Unified_Ideograph", "Ideographic"},
    132531: {"Unified_Ideograph", "Ideographic"},
    132532: {"Unified_Ideograph", "Ideographic"},
    132533: {"Unified_Ideograph", "Ideographic"},
    132534: {"Unified_Ideograph", "Ideographic"},
    132535: {"Unified_Ideograph", "Ideographic"},
    132536: {"Unified_Ideograph", "Ideographic"},
    132537: {"Unified_Ideograph", "Ideographic"},
    132538: {"Unified_Ideograph", "Ideographic"},
    132539: {"Unified_Ideograph", "Ideographic"},
    132540: {"Unified_Ideograph", "Ideographic"},
    132541: {"Unified_Ideograph", "Ideographic"},
    132542: {"Unified_Ideograph", "Ideographic"},
    132543: {"Unified_Ideograph", "Ideographic"},
    132544: {"Unified_Ideograph", "Ideographic"},
    132545: {"Unified_Ideograph", "Ideographic"},
    132546: {"Unified_Ideograph", "Ideographic"},
    132547: {"Unified_Ideograph", "Ideographic"},
    132548: {"Unified_Ideograph", "Ideographic"},
    132549: {"Unified_Ideograph", "Ideographic"},
    132550: {"Unified_Ideograph", "Ideographic"},
    132551: {"Unified_Ideograph", "Ideographic"},
    132552: {"Unified_Ideograph", "Ideographic"},
    132553: {"Unified_Ideograph", "Ideographic"},
    132554: {"Unified_Ideograph", "Ideographic"},
    132555: {"Unified_Ideograph", "Ideographic"},
    132556: {"Unified_Ideograph", "Ideographic"},
    132557: {"Unified_Ideograph", "Ideographic"},
    132558: {"Unified_Ideograph", "Ideographic"},
    132559: {"Unified_Ideograph", "Ideographic"},
    132560: {"Unified_Ideograph", "Ideographic"},
    132561: {"Unified_Ideograph", "Ideographic"},
    132562: {"Unified_Ideograph", "Ideographic"},
    132563: {"Unified_Ideograph", "Ideographic"},
    132564: {"Unified_Ideograph", "Ideographic"},
    132565: {"Unified_Ideograph", "Ideographic"},
    132566: {"Unified_Ideograph", "Ideographic"},
    132567: {"Unified_Ideograph", "Ideographic"},
    132568: {"Unified_Ideograph", "Ideographic"},
    132569: {"Unified_Ideograph", "Ideographic"},
    132570: {"Unified_Ideograph", "Ideographic"},
    132571: {"Unified_Ideograph", "Ideographic"},
    132572: {"Unified_Ideograph", "Ideographic"},
    132573: {"Unified_Ideograph", "Ideographic"},
    132574: {"Unified_Ideograph", "Ideographic"},
    132575: {"Unified_Ideograph", "Ideographic"},
    132576: {"Unified_Ideograph", "Ideographic"},
    132577: {"Unified_Ideograph", "Ideographic"},
    132578: {"Unified_Ideograph", "Ideographic"},
    132579: {"Unified_Ideograph", "Ideographic"},
    132580: {"Unified_Ideograph", "Ideographic"},
    132581: {"Unified_Ideograph", "Ideographic"},
    132582: {"Unified_Ideograph", "Ideographic"},
    132583: {"Unified_Ideograph", "Ideographic"},
    132584: {"Unified_Ideograph", "Ideographic"},
    132585: {"Unified_Ideograph", "Ideographic"},
    132586: {"Unified_Ideograph", "Ideographic"},
    132587: {"Unified_Ideograph", "Ideographic"},
    132588: {"Unified_Ideograph", "Ideographic"},
    132589: {"Unified_Ideograph", "Ideographic"},
    132590: {"Unified_Ideograph", "Ideographic"},
    132591: {"Unified_Ideograph", "Ideographic"},
    132592: {"Unified_Ideograph", "Ideographic"},
    132593: {"Unified_Ideograph", "Ideographic"},
    132594: {"Unified_Ideograph", "Ideographic"},
    132595: {"Unified_Ideograph", "Ideographic"},
    132596: {"Unified_Ideograph", "Ideographic"},
    132597: {"Unified_Ideograph", "Ideographic"},
    132598: {"Unified_Ideograph", "Ideographic"},
    132599: {"Unified_Ideograph", "Ideographic"},
    132600: {"Unified_Ideograph", "Ideographic"},
    132601: {"Unified_Ideograph", "Ideographic"},
    132602: {"Unified_Ideograph", "Ideographic"},
    132603: {"Unified_Ideograph", "Ideographic"},
    132604: {"Unified_Ideograph", "Ideographic"},
    132605: {"Unified_Ideograph", "Ideographic"},
    132606: {"Unified_Ideograph", "Ideographic"},
    132607: {"Unified_Ideograph", "Ideographic"},
    132608: {"Unified_Ideograph", "Ideographic"},
    132609: {"Unified_Ideograph", "Ideographic"},
    132610: {"Unified_Ideograph", "Ideographic"},
    132611: {"Unified_Ideograph", "Ideographic"},
    132612: {"Unified_Ideograph", "Ideographic"},
    132613: {"Unified_Ideograph", "Ideographic"},
    132614: {"Unified_Ideograph", "Ideographic"},
    132615: {"Unified_Ideograph", "Ideographic"},
    132616: {"Unified_Ideograph", "Ideographic"},
    132617: {"Unified_Ideograph", "Ideographic"},
    132618: {"Unified_Ideograph", "Ideographic"},
    132619: {"Unified_Ideograph", "Ideographic"},
    132620: {"Unified_Ideograph", "Ideographic"},
    132621: {"Unified_Ideograph", "Ideographic"},
    132622: {"Unified_Ideograph", "Ideographic"},
    132623: {"Unified_Ideograph", "Ideographic"},
    132624: {"Unified_Ideograph", "Ideographic"},
    132625: {"Unified_Ideograph", "Ideographic"},
    132626: {"Unified_Ideograph", "Ideographic"},
    132627: {"Unified_Ideograph", "Ideographic"},
    132628: {"Unified_Ideograph", "Ideographic"},
    132629: {"Unified_Ideograph", "Ideographic"},
    132630: {"Unified_Ideograph", "Ideographic"},
    132631: {"Unified_Ideograph", "Ideographic"},
    132632: {"Unified_Ideograph", "Ideographic"},
    132633: {"Unified_Ideograph", "Ideographic"},
    132634: {"Unified_Ideograph", "Ideographic"},
    132635: {"Unified_Ideograph", "Ideographic"},
    132636: {"Unified_Ideograph", "Ideographic"},
    132637: {"Unified_Ideograph", "Ideographic"},
    132638: {"Unified_Ideograph", "Ideographic"},
    132639: {"Unified_Ideograph", "Ideographic"},
    132640: {"Unified_Ideograph", "Ideographic"},
    132641: {"Unified_Ideograph", "Ideographic"},
    132642: {"Unified_Ideograph", "Ideographic"},
    132643: {"Unified_Ideograph", "Ideographic"},
    132644: {"Unified_Ideograph", "Ideographic"},
    132645: {"Unified_Ideograph", "Ideographic"},
    132646: {"Unified_Ideograph", "Ideographic"},
    132647: {"Unified_Ideograph", "Ideographic"},
    132648: {"Unified_Ideograph", "Ideographic"},
    132649: {"Unified_Ideograph", "Ideographic"},
    132650: {"Unified_Ideograph", "Ideographic"},
    132651: {"Unified_Ideograph", "Ideographic"},
    132652: {"Unified_Ideograph", "Ideographic"},
    132653: {"Unified_Ideograph", "Ideographic"},
    132654: {"Unified_Ideograph", "Ideographic"},
    132655: {"Unified_Ideograph", "Ideographic"},
    132656: {"Unified_Ideograph", "Ideographic"},
    132657: {"Unified_Ideograph", "Ideographic"},
    132658: {"Unified_Ideograph", "Ideographic"},
    132659: {"Unified_Ideograph", "Ideographic"},
    132660: {"Unified_Ideograph", "Ideographic"},
    132661: {"Unified_Ideograph", "Ideographic"},
    132662: {"Unified_Ideograph", "Ideographic"},
    132663: {"Unified_Ideograph", "Ideographic"},
    132664: {"Unified_Ideograph", "Ideographic"},
    132665: {"Unified_Ideograph", "Ideographic"},
    132666: {"Unified_Ideograph", "Ideographic"},
    132667: {"Unified_Ideograph", "Ideographic"},
    132668: {"Unified_Ideograph", "Ideographic"},
    132669: {"Unified_Ideograph", "Ideographic"},
    132670: {"Unified_Ideograph", "Ideographic"},
    132671: {"Unified_Ideograph", "Ideographic"},
    132672: {"Unified_Ideograph", "Ideographic"},
    132673: {"Unified_Ideograph", "Ideographic"},
    132674: {"Unified_Ideograph", "Ideographic"},
    132675: {"Unified_Ideograph", "Ideographic"},
    132676: {"Unified_Ideograph", "Ideographic"},
    132677: {"Unified_Ideograph", "Ideographic"},
    132678: {"Unified_Ideograph", "Ideographic"},
    132679: {"Unified_Ideograph", "Ideographic"},
    132680: {"Unified_Ideograph", "Ideographic"},
    132681: {"Unified_Ideograph", "Ideographic"},
    132682: {"Unified_Ideograph", "Ideographic"},
    132683: {"Unified_Ideograph", "Ideographic"},
    132684: {"Unified_Ideograph", "Ideographic"},
    132685: {"Unified_Ideograph", "Ideographic"},
    132686: {"Unified_Ideograph", "Ideographic"},
    132687: {"Unified_Ideograph", "Ideographic"},
    132688: {"Unified_Ideograph", "Ideographic"},
    132689: {"Unified_Ideograph", "Ideographic"},
    132690: {"Unified_Ideograph", "Ideographic"},
    132691: {"Unified_Ideograph", "Ideographic"},
    132692: {"Unified_Ideograph", "Ideographic"},
    132693: {"Unified_Ideograph", "Ideographic"},
    132694: {"Unified_Ideograph", "Ideographic"},
    132695: {"Unified_Ideograph", "Ideographic"},
    132696: {"Unified_Ideograph", "Ideographic"},
    132697: {"Unified_Ideograph", "Ideographic"},
    132698: {"Unified_Ideograph", "Ideographic"},
    132699: {"Unified_Ideograph", "Ideographic"},
    132700: {"Unified_Ideograph", "Ideographic"},
    132701: {"Unified_Ideograph", "Ideographic"},
    132702: {"Unified_Ideograph", "Ideographic"},
    132703: {"Unified_Ideograph", "Ideographic"},
    132704: {"Unified_Ideograph", "Ideographic"},
    132705: {"Unified_Ideograph", "Ideographic"},
    132706: {"Unified_Ideograph", "Ideographic"},
    132707: {"Unified_Ideograph", "Ideographic"},
    132708: {"Unified_Ideograph", "Ideographic"},
    132709: {"Unified_Ideograph", "Ideographic"},
    132710: {"Unified_Ideograph", "Ideographic"},
    132711: {"Unified_Ideograph", "Ideographic"},
    132712: {"Unified_Ideograph", "Ideographic"},
    132713: {"Unified_Ideograph", "Ideographic"},
    132714: {"Unified_Ideograph", "Ideographic"},
    132715: {"Unified_Ideograph", "Ideographic"},
    132716: {"Unified_Ideograph", "Ideographic"},
    132717: {"Unified_Ideograph", "Ideographic"},
    132718: {"Unified_Ideograph", "Ideographic"},
    132719: {"Unified_Ideograph", "Ideographic"},
    132720: {"Unified_Ideograph", "Ideographic"},
    132721: {"Unified_Ideograph", "Ideographic"},
    132722: {"Unified_Ideograph", "Ideographic"},
    132723: {"Unified_Ideograph", "Ideographic"},
    132724: {"Unified_Ideograph", "Ideographic"},
    132725: {"Unified_Ideograph", "Ideographic"},
    132726: {"Unified_Ideograph", "Ideographic"},
    132727: {"Unified_Ideograph", "Ideographic"},
    132728: {"Unified_Ideograph", "Ideographic"},
    132729: {"Unified_Ideograph", "Ideographic"},
    132730: {"Unified_Ideograph", "Ideographic"},
    132731: {"Unified_Ideograph", "Ideographic"},
    132732: {"Unified_Ideograph", "Ideographic"},
    132733: {"Unified_Ideograph", "Ideographic"},
    132734: {"Unified_Ideograph", "Ideographic"},
    132735: {"Unified_Ideograph", "Ideographic"},
    132736: {"Unified_Ideograph", "Ideographic"},
    132737: {"Unified_Ideograph", "Ideographic"},
    132738: {"Unified_Ideograph", "Ideographic"},
    132739: {"Unified_Ideograph", "Ideographic"},
    132740: {"Unified_Ideograph", "Ideographic"},
    132741: {"Unified_Ideograph", "Ideographic"},
    132742: {"Unified_Ideograph", "Ideographic"},
    132743: {"Unified_Ideograph", "Ideographic"},
    132744: {"Unified_Ideograph", "Ideographic"},
    132745: {"Unified_Ideograph", "Ideographic"},
    132746: {"Unified_Ideograph", "Ideographic"},
    132747: {"Unified_Ideograph", "Ideographic"},
    132748: {"Unified_Ideograph", "Ideographic"},
    132749: {"Unified_Ideograph", "Ideographic"},
    132750: {"Unified_Ideograph", "Ideographic"},
    132751: {"Unified_Ideograph", "Ideographic"},
    132752: {"Unified_Ideograph", "Ideographic"},
    132753: {"Unified_Ideograph", "Ideographic"},
    132754: {"Unified_Ideograph", "Ideographic"},
    132755: {"Unified_Ideograph", "Ideographic"},
    132756: {"Unified_Ideograph", "Ideographic"},
    132757: {"Unified_Ideograph", "Ideographic"},
    132758: {"Unified_Ideograph", "Ideographic"},
    132759: {"Unified_Ideograph", "Ideographic"},
    132760: {"Unified_Ideograph", "Ideographic"},
    132761: {"Unified_Ideograph", "Ideographic"},
    132762: {"Unified_Ideograph", "Ideographic"},
    132763: {"Unified_Ideograph", "Ideographic"},
    132764: {"Unified_Ideograph", "Ideographic"},
    132765: {"Unified_Ideograph", "Ideographic"},
    132766: {"Unified_Ideograph", "Ideographic"},
    132767: {"Unified_Ideograph", "Ideographic"},
    132768: {"Unified_Ideograph", "Ideographic"},
    132769: {"Unified_Ideograph", "Ideographic"},
    132770: {"Unified_Ideograph", "Ideographic"},
    132771: {"Unified_Ideograph", "Ideographic"},
    132772: {"Unified_Ideograph", "Ideographic"},
    132773: {"Unified_Ideograph", "Ideographic"},
    132774: {"Unified_Ideograph", "Ideographic"},
    132775: {"Unified_Ideograph", "Ideographic"},
    132776: {"Unified_Ideograph", "Ideographic"},
    132777: {"Unified_Ideograph", "Ideographic"},
    132778: {"Unified_Ideograph", "Ideographic"},
    132779: {"Unified_Ideograph", "Ideographic"},
    132780: {"Unified_Ideograph", "Ideographic"},
    132781: {"Unified_Ideograph", "Ideographic"},
    132782: {"Unified_Ideograph", "Ideographic"},
    132783: {"Unified_Ideograph", "Ideographic"},
    132784: {"Unified_Ideograph", "Ideographic"},
    132785: {"Unified_Ideograph", "Ideographic"},
    132786: {"Unified_Ideograph", "Ideographic"},
    132787: {"Unified_Ideograph", "Ideographic"},
    132788: {"Unified_Ideograph", "Ideographic"},
    132789: {"Unified_Ideograph", "Ideographic"},
    132790: {"Unified_Ideograph", "Ideographic"},
    132791: {"Unified_Ideograph", "Ideographic"},
    132792: {"Unified_Ideograph", "Ideographic"},
    132793: {"Unified_Ideograph", "Ideographic"},
    132794: {"Unified_Ideograph", "Ideographic"},
    132795: {"Unified_Ideograph", "Ideographic"},
    132796: {"Unified_Ideograph", "Ideographic"},
    132797: {"Unified_Ideograph", "Ideographic"},
    132798: {"Unified_Ideograph", "Ideographic"},
    132799: {"Unified_Ideograph", "Ideographic"},
    132800: {"Unified_Ideograph", "Ideographic"},
    132801: {"Unified_Ideograph", "Ideographic"},
    132802: {"Unified_Ideograph", "Ideographic"},
    132803: {"Unified_Ideograph", "Ideographic"},
    132804: {"Unified_Ideograph", "Ideographic"},
    132805: {"Unified_Ideograph", "Ideographic"},
    132806: {"Unified_Ideograph", "Ideographic"},
    132807: {"Unified_Ideograph", "Ideographic"},
    132808: {"Unified_Ideograph", "Ideographic"},
    132809: {"Unified_Ideograph", "Ideographic"},
    132810: {"Unified_Ideograph", "Ideographic"},
    132811: {"Unified_Ideograph", "Ideographic"},
    132812: {"Unified_Ideograph", "Ideographic"},
    132813: {"Unified_Ideograph", "Ideographic"},
    132814: {"Unified_Ideograph", "Ideographic"},
    132815: {"Unified_Ideograph", "Ideographic"},
    132816: {"Unified_Ideograph", "Ideographic"},
    132817: {"Unified_Ideograph", "Ideographic"},
    132818: {"Unified_Ideograph", "Ideographic"},
    132819: {"Unified_Ideograph", "Ideographic"},
    132820: {"Unified_Ideograph", "Ideographic"},
    132821: {"Unified_Ideograph", "Ideographic"},
    132822: {"Unified_Ideograph", "Ideographic"},
    132823: {"Unified_Ideograph", "Ideographic"},
    132824: {"Unified_Ideograph", "Ideographic"},
    132825: {"Unified_Ideograph", "Ideographic"},
    132826: {"Unified_Ideograph", "Ideographic"},
    132827: {"Unified_Ideograph", "Ideographic"},
    132828: {"Unified_Ideograph", "Ideographic"},
    132829: {"Unified_Ideograph", "Ideographic"},
    132830: {"Unified_Ideograph", "Ideographic"},
    132831: {"Unified_Ideograph", "Ideographic"},
    132832: {"Unified_Ideograph", "Ideographic"},
    132833: {"Unified_Ideograph", "Ideographic"},
    132834: {"Unified_Ideograph", "Ideographic"},
    132835: {"Unified_Ideograph", "Ideographic"},
    132836: {"Unified_Ideograph", "Ideographic"},
    132837: {"Unified_Ideograph", "Ideographic"},
    132838: {"Unified_Ideograph", "Ideographic"},
    132839: {"Unified_Ideograph", "Ideographic"},
    132840: {"Unified_Ideograph", "Ideographic"},
    132841: {"Unified_Ideograph", "Ideographic"},
    132842: {"Unified_Ideograph", "Ideographic"},
    132843: {"Unified_Ideograph", "Ideographic"},
    132844: {"Unified_Ideograph", "Ideographic"},
    132845: {"Unified_Ideograph", "Ideographic"},
    132846: {"Unified_Ideograph", "Ideographic"},
    132847: {"Unified_Ideograph", "Ideographic"},
    132848: {"Unified_Ideograph", "Ideographic"},
    132849: {"Unified_Ideograph", "Ideographic"},
    132850: {"Unified_Ideograph", "Ideographic"},
    132851: {"Unified_Ideograph", "Ideographic"},
    132852: {"Unified_Ideograph", "Ideographic"},
    132853: {"Unified_Ideograph", "Ideographic"},
    132854: {"Unified_Ideograph", "Ideographic"},
    132855: {"Unified_Ideograph", "Ideographic"},
    132856: {"Unified_Ideograph", "Ideographic"},
    132857: {"Unified_Ideograph", "Ideographic"},
    132858: {"Unified_Ideograph", "Ideographic"},
    132859: {"Unified_Ideograph", "Ideographic"},
    132860: {"Unified_Ideograph", "Ideographic"},
    132861: {"Unified_Ideograph", "Ideographic"},
    132862: {"Unified_Ideograph", "Ideographic"},
    132863: {"Unified_Ideograph", "Ideographic"},
    132864: {"Unified_Ideograph", "Ideographic"},
    132865: {"Unified_Ideograph", "Ideographic"},
    132866: {"Unified_Ideograph", "Ideographic"},
    132867: {"Unified_Ideograph", "Ideographic"},
    132868: {"Unified_Ideograph", "Ideographic"},
    132869: {"Unified_Ideograph", "Ideographic"},
    132870: {"Unified_Ideograph", "Ideographic"},
    132871: {"Unified_Ideograph", "Ideographic"},
    132872: {"Unified_Ideograph", "Ideographic"},
    132873: {"Unified_Ideograph", "Ideographic"},
    132874: {"Unified_Ideograph", "Ideographic"},
    132875: {"Unified_Ideograph", "Ideographic"},
    132876: {"Unified_Ideograph", "Ideographic"},
    132877: {"Unified_Ideograph", "Ideographic"},
    132878: {"Unified_Ideograph", "Ideographic"},
    132879: {"Unified_Ideograph", "Ideographic"},
    132880: {"Unified_Ideograph", "Ideographic"},
    132881: {"Unified_Ideograph", "Ideographic"},
    132882: {"Unified_Ideograph", "Ideographic"},
    132883: {"Unified_Ideograph", "Ideographic"},
    132884: {"Unified_Ideograph", "Ideographic"},
    132885: {"Unified_Ideograph", "Ideographic"},
    132886: {"Unified_Ideograph", "Ideographic"},
    132887: {"Unified_Ideograph", "Ideographic"},
    132888: {"Unified_Ideograph", "Ideographic"},
    132889: {"Unified_Ideograph", "Ideographic"},
    132890: {"Unified_Ideograph", "Ideographic"},
    132891: {"Unified_Ideograph", "Ideographic"},
    132892: {"Unified_Ideograph", "Ideographic"},
    132893: {"Unified_Ideograph", "Ideographic"},
    132894: {"Unified_Ideograph", "Ideographic"},
    132895: {"Unified_Ideograph", "Ideographic"},
    132896: {"Unified_Ideograph", "Ideographic"},
    132897: {"Unified_Ideograph", "Ideographic"},
    132898: {"Unified_Ideograph", "Ideographic"},
    132899: {"Unified_Ideograph", "Ideographic"},
    132900: {"Unified_Ideograph", "Ideographic"},
    132901: {"Unified_Ideograph", "Ideographic"},
    132902: {"Unified_Ideograph", "Ideographic"},
    132903: {"Unified_Ideograph", "Ideographic"},
    132904: {"Unified_Ideograph", "Ideographic"},
    132905: {"Unified_Ideograph", "Ideographic"},
    132906: {"Unified_Ideograph", "Ideographic"},
    132907: {"Unified_Ideograph", "Ideographic"},
    132908: {"Unified_Ideograph", "Ideographic"},
    132909: {"Unified_Ideograph", "Ideographic"},
    132910: {"Unified_Ideograph", "Ideographic"},
    132911: {"Unified_Ideograph", "Ideographic"},
    132912: {"Unified_Ideograph", "Ideographic"},
    132913: {"Unified_Ideograph", "Ideographic"},
    132914: {"Unified_Ideograph", "Ideographic"},
    132915: {"Unified_Ideograph", "Ideographic"},
    132916: {"Unified_Ideograph", "Ideographic"},
    132917: {"Unified_Ideograph", "Ideographic"},
    132918: {"Unified_Ideograph", "Ideographic"},
    132919: {"Unified_Ideograph", "Ideographic"},
    132920: {"Unified_Ideograph", "Ideographic"},
    132921: {"Unified_Ideograph", "Ideographic"},
    132922: {"Unified_Ideograph", "Ideographic"},
    132923: {"Unified_Ideograph", "Ideographic"},
    132924: {"Unified_Ideograph", "Ideographic"},
    132925: {"Unified_Ideograph", "Ideographic"},
    132926: {"Unified_Ideograph", "Ideographic"},
    132927: {"Unified_Ideograph", "Ideographic"},
    132928: {"Unified_Ideograph", "Ideographic"},
    132929: {"Unified_Ideograph", "Ideographic"},
    132930: {"Unified_Ideograph", "Ideographic"},
    132931: {"Unified_Ideograph", "Ideographic"},
    132932: {"Unified_Ideograph", "Ideographic"},
    132933: {"Unified_Ideograph", "Ideographic"},
    132934: {"Unified_Ideograph", "Ideographic"},
    132935: {"Unified_Ideograph", "Ideographic"},
    132936: {"Unified_Ideograph", "Ideographic"},
    132937: {"Unified_Ideograph", "Ideographic"},
    132938: {"Unified_Ideograph", "Ideographic"},
    132939: {"Unified_Ideograph", "Ideographic"},
    132940: {"Unified_Ideograph", "Ideographic"},
    132941: {"Unified_Ideograph", "Ideographic"},
    132942: {"Unified_Ideograph", "Ideographic"},
    132943: {"Unified_Ideograph", "Ideographic"},
    132944: {"Unified_Ideograph", "Ideographic"},
    132945: {"Unified_Ideograph", "Ideographic"},
    132946: {"Unified_Ideograph", "Ideographic"},
    132947: {"Unified_Ideograph", "Ideographic"},
    132948: {"Unified_Ideograph", "Ideographic"},
    132949: {"Unified_Ideograph", "Ideographic"},
    132950: {"Unified_Ideograph", "Ideographic"},
    132951: {"Unified_Ideograph", "Ideographic"},
    132952: {"Unified_Ideograph", "Ideographic"},
    132953: {"Unified_Ideograph", "Ideographic"},
    132954: {"Unified_Ideograph", "Ideographic"},
    132955: {"Unified_Ideograph", "Ideographic"},
    132956: {"Unified_Ideograph", "Ideographic"},
    132957: {"Unified_Ideograph", "Ideographic"},
    132958: {"Unified_Ideograph", "Ideographic"},
    132959: {"Unified_Ideograph", "Ideographic"},
    132960: {"Unified_Ideograph", "Ideographic"},
    132961: {"Unified_Ideograph", "Ideographic"},
    132962: {"Unified_Ideograph", "Ideographic"},
    132963: {"Unified_Ideograph", "Ideographic"},
    132964: {"Unified_Ideograph", "Ideographic"},
    132965: {"Unified_Ideograph", "Ideographic"},
    132966: {"Unified_Ideograph", "Ideographic"},
    132967: {"Unified_Ideograph", "Ideographic"},
    132968: {"Unified_Ideograph", "Ideographic"},
    132969: {"Unified_Ideograph", "Ideographic"},
    132970: {"Unified_Ideograph", "Ideographic"},
    132971: {"Unified_Ideograph", "Ideographic"},
    132972: {"Unified_Ideograph", "Ideographic"},
    132973: {"Unified_Ideograph", "Ideographic"},
    132974: {"Unified_Ideograph", "Ideographic"},
    132975: {"Unified_Ideograph", "Ideographic"},
    132976: {"Unified_Ideograph", "Ideographic"},
    132977: {"Unified_Ideograph", "Ideographic"},
    132978: {"Unified_Ideograph", "Ideographic"},
    132979: {"Unified_Ideograph", "Ideographic"},
    132980: {"Unified_Ideograph", "Ideographic"},
    132981: {"Unified_Ideograph", "Ideographic"},
    132982: {"Unified_Ideograph", "Ideographic"},
    132983: {"Unified_Ideograph", "Ideographic"},
    132984: {"Unified_Ideograph", "Ideographic"},
    132985: {"Unified_Ideograph", "Ideographic"},
    132986: {"Unified_Ideograph", "Ideographic"},
    132987: {"Unified_Ideograph", "Ideographic"},
    132988: {"Unified_Ideograph", "Ideographic"},
    132989: {"Unified_Ideograph", "Ideographic"},
    132990: {"Unified_Ideograph", "Ideographic"},
    132991: {"Unified_Ideograph", "Ideographic"},
    132992: {"Unified_Ideograph", "Ideographic"},
    132993: {"Unified_Ideograph", "Ideographic"},
    132994: {"Unified_Ideograph", "Ideographic"},
    132995: {"Unified_Ideograph", "Ideographic"},
    132996: {"Unified_Ideograph", "Ideographic"},
    132997: {"Unified_Ideograph", "Ideographic"},
    132998: {"Unified_Ideograph", "Ideographic"},
    132999: {"Unified_Ideograph", "Ideographic"},
    133000: {"Unified_Ideograph", "Ideographic"},
    133001: {"Unified_Ideograph", "Ideographic"},
    133002: {"Unified_Ideograph", "Ideographic"},
    133003: {"Unified_Ideograph", "Ideographic"},
    133004: {"Unified_Ideograph", "Ideographic"},
    133005: {"Unified_Ideograph", "Ideographic"},
    133006: {"Unified_Ideograph", "Ideographic"},
    133007: {"Unified_Ideograph", "Ideographic"},
    133008: {"Unified_Ideograph", "Ideographic"},
    133009: {"Unified_Ideograph", "Ideographic"},
    133010: {"Unified_Ideograph", "Ideographic"},
    133011: {"Unified_Ideograph", "Ideographic"},
    133012: {"Unified_Ideograph", "Ideographic"},
    133013: {"Unified_Ideograph", "Ideographic"},
    133014: {"Unified_Ideograph", "Ideographic"},
    133015: {"Unified_Ideograph", "Ideographic"},
    133016: {"Unified_Ideograph", "Ideographic"},
    133017: {"Unified_Ideograph", "Ideographic"},
    133018: {"Unified_Ideograph", "Ideographic"},
    133019: {"Unified_Ideograph", "Ideographic"},
    133020: {"Unified_Ideograph", "Ideographic"},
    133021: {"Unified_Ideograph", "Ideographic"},
    133022: {"Unified_Ideograph", "Ideographic"},
    133023: {"Unified_Ideograph", "Ideographic"},
    133024: {"Unified_Ideograph", "Ideographic"},
    133025: {"Unified_Ideograph", "Ideographic"},
    133026: {"Unified_Ideograph", "Ideographic"},
    133027: {"Unified_Ideograph", "Ideographic"},
    133028: {"Unified_Ideograph", "Ideographic"},
    133029: {"Unified_Ideograph", "Ideographic"},
    133030: {"Unified_Ideograph", "Ideographic"},
    133031: {"Unified_Ideograph", "Ideographic"},
    133032: {"Unified_Ideograph", "Ideographic"},
    133033: {"Unified_Ideograph", "Ideographic"},
    133034: {"Unified_Ideograph", "Ideographic"},
    133035: {"Unified_Ideograph", "Ideographic"},
    133036: {"Unified_Ideograph", "Ideographic"},
    133037: {"Unified_Ideograph", "Ideographic"},
    133038: {"Unified_Ideograph", "Ideographic"},
    133039: {"Unified_Ideograph", "Ideographic"},
    133040: {"Unified_Ideograph", "Ideographic"},
    133041: {"Unified_Ideograph", "Ideographic"},
    133042: {"Unified_Ideograph", "Ideographic"},
    133043: {"Unified_Ideograph", "Ideographic"},
    133044: {"Unified_Ideograph", "Ideographic"},
    133045: {"Unified_Ideograph", "Ideographic"},
    133046: {"Unified_Ideograph", "Ideographic"},
    133047: {"Unified_Ideograph", "Ideographic"},
    133048: {"Unified_Ideograph", "Ideographic"},
    133049: {"Unified_Ideograph", "Ideographic"},
    133050: {"Unified_Ideograph", "Ideographic"},
    133051: {"Unified_Ideograph", "Ideographic"},
    133052: {"Unified_Ideograph", "Ideographic"},
    133053: {"Unified_Ideograph", "Ideographic"},
    133054: {"Unified_Ideograph", "Ideographic"},
    133055: {"Unified_Ideograph", "Ideographic"},
    133056: {"Unified_Ideograph", "Ideographic"},
    133057: {"Unified_Ideograph", "Ideographic"},
    133058: {"Unified_Ideograph", "Ideographic"},
    133059: {"Unified_Ideograph", "Ideographic"},
    133060: {"Unified_Ideograph", "Ideographic"},
    133061: {"Unified_Ideograph", "Ideographic"},
    133062: {"Unified_Ideograph", "Ideographic"},
    133063: {"Unified_Ideograph", "Ideographic"},
    133064: {"Unified_Ideograph", "Ideographic"},
    133065: {"Unified_Ideograph", "Ideographic"},
    133066: {"Unified_Ideograph", "Ideographic"},
    133067: {"Unified_Ideograph", "Ideographic"},
    133068: {"Unified_Ideograph", "Ideographic"},
    133069: {"Unified_Ideograph", "Ideographic"},
    133070: {"Unified_Ideograph", "Ideographic"},
    133071: {"Unified_Ideograph", "Ideographic"},
    133072: {"Unified_Ideograph", "Ideographic"},
    133073: {"Unified_Ideograph", "Ideographic"},
    133074: {"Unified_Ideograph", "Ideographic"},
    133075: {"Unified_Ideograph", "Ideographic"},
    133076: {"Unified_Ideograph", "Ideographic"},
    133077: {"Unified_Ideograph", "Ideographic"},
    133078: {"Unified_Ideograph", "Ideographic"},
    133079: {"Unified_Ideograph", "Ideographic"},
    133080: {"Unified_Ideograph", "Ideographic"},
    133081: {"Unified_Ideograph", "Ideographic"},
    133082: {"Unified_Ideograph", "Ideographic"},
    133083: {"Unified_Ideograph", "Ideographic"},
    133084: {"Unified_Ideograph", "Ideographic"},
    133085: {"Unified_Ideograph", "Ideographic"},
    133086: {"Unified_Ideograph", "Ideographic"},
    133087: {"Unified_Ideograph", "Ideographic"},
    133088: {"Unified_Ideograph", "Ideographic"},
    133089: {"Unified_Ideograph", "Ideographic"},
    133090: {"Unified_Ideograph", "Ideographic"},
    133091: {"Unified_Ideograph", "Ideographic"},
    133092: {"Unified_Ideograph", "Ideographic"},
    133093: {"Unified_Ideograph", "Ideographic"},
    133094: {"Unified_Ideograph", "Ideographic"},
    133095: {"Unified_Ideograph", "Ideographic"},
    133096: {"Unified_Ideograph", "Ideographic"},
    133097: {"Unified_Ideograph", "Ideographic"},
    133098: {"Unified_Ideograph", "Ideographic"},
    133099: {"Unified_Ideograph", "Ideographic"},
    133100: {"Unified_Ideograph", "Ideographic"},
    133101: {"Unified_Ideograph", "Ideographic"},
    133102: {"Unified_Ideograph", "Ideographic"},
    133103: {"Unified_Ideograph", "Ideographic"},
    133104: {"Unified_Ideograph", "Ideographic"},
    133105: {"Unified_Ideograph", "Ideographic"},
    133106: {"Unified_Ideograph", "Ideographic"},
    133107: {"Unified_Ideograph", "Ideographic"},
    133108: {"Unified_Ideograph", "Ideographic"},
    133109: {"Unified_Ideograph", "Ideographic"},
    133110: {"Unified_Ideograph", "Ideographic"},
    133111: {"Unified_Ideograph", "Ideographic"},
    133112: {"Unified_Ideograph", "Ideographic"},
    133113: {"Unified_Ideograph", "Ideographic"},
    133114: {"Unified_Ideograph", "Ideographic"},
    133115: {"Unified_Ideograph", "Ideographic"},
    133116: {"Unified_Ideograph", "Ideographic"},
    133117: {"Unified_Ideograph", "Ideographic"},
    133118: {"Unified_Ideograph", "Ideographic"},
    133119: {"Unified_Ideograph", "Ideographic"},
    133120: {"Unified_Ideograph", "Ideographic"},
    133121: {"Unified_Ideograph", "Ideographic"},
    133122: {"Unified_Ideograph", "Ideographic"},
    133123: {"Unified_Ideograph", "Ideographic"},
    133124: {"Unified_Ideograph", "Ideographic"},
    133125: {"Unified_Ideograph", "Ideographic"},
    133126: {"Unified_Ideograph", "Ideographic"},
    133127: {"Unified_Ideograph", "Ideographic"},
    133128: {"Unified_Ideograph", "Ideographic"},
    133129: {"Unified_Ideograph", "Ideographic"},
    133130: {"Unified_Ideograph", "Ideographic"},
    133131: {"Unified_Ideograph", "Ideographic"},
    133132: {"Unified_Ideograph", "Ideographic"},
    133133: {"Unified_Ideograph", "Ideographic"},
    133134: {"Unified_Ideograph", "Ideographic"},
    133135: {"Unified_Ideograph", "Ideographic"},
    133136: {"Unified_Ideograph", "Ideographic"},
    133137: {"Unified_Ideograph", "Ideographic"},
    133138: {"Unified_Ideograph", "Ideographic"},
    133139: {"Unified_Ideograph", "Ideographic"},
    133140: {"Unified_Ideograph", "Ideographic"},
    133141: {"Unified_Ideograph", "Ideographic"},
    133142: {"Unified_Ideograph", "Ideographic"},
    133143: {"Unified_Ideograph", "Ideographic"},
    133144: {"Unified_Ideograph", "Ideographic"},
    133145: {"Unified_Ideograph", "Ideographic"},
    133146: {"Unified_Ideograph", "Ideographic"},
    133147: {"Unified_Ideograph", "Ideographic"},
    133148: {"Unified_Ideograph", "Ideographic"},
    133149: {"Unified_Ideograph", "Ideographic"},
    133150: {"Unified_Ideograph", "Ideographic"},
    133151: {"Unified_Ideograph", "Ideographic"},
    133152: {"Unified_Ideograph", "Ideographic"},
    133153: {"Unified_Ideograph", "Ideographic"},
    133154: {"Unified_Ideograph", "Ideographic"},
    133155: {"Unified_Ideograph", "Ideographic"},
    133156: {"Unified_Ideograph", "Ideographic"},
    133157: {"Unified_Ideograph", "Ideographic"},
    133158: {"Unified_Ideograph", "Ideographic"},
    133159: {"Unified_Ideograph", "Ideographic"},
    133160: {"Unified_Ideograph", "Ideographic"},
    133161: {"Unified_Ideograph", "Ideographic"},
    133162: {"Unified_Ideograph", "Ideographic"},
    133163: {"Unified_Ideograph", "Ideographic"},
    133164: {"Unified_Ideograph", "Ideographic"},
    133165: {"Unified_Ideograph", "Ideographic"},
    133166: {"Unified_Ideograph", "Ideographic"},
    133167: {"Unified_Ideograph", "Ideographic"},
    133168: {"Unified_Ideograph", "Ideographic"},
    133169: {"Unified_Ideograph", "Ideographic"},
    133170: {"Unified_Ideograph", "Ideographic"},
    133171: {"Unified_Ideograph", "Ideographic"},
    133172: {"Unified_Ideograph", "Ideographic"},
    133173: {"Unified_Ideograph", "Ideographic"},
    133174: {"Unified_Ideograph", "Ideographic"},
    133175: {"Unified_Ideograph", "Ideographic"},
    133176: {"Unified_Ideograph", "Ideographic"},
    133177: {"Unified_Ideograph", "Ideographic"},
    133178: {"Unified_Ideograph", "Ideographic"},
    133179: {"Unified_Ideograph", "Ideographic"},
    133180: {"Unified_Ideograph", "Ideographic"},
    133181: {"Unified_Ideograph", "Ideographic"},
    133182: {"Unified_Ideograph", "Ideographic"},
    133183: {"Unified_Ideograph", "Ideographic"},
    133184: {"Unified_Ideograph", "Ideographic"},
    133185: {"Unified_Ideograph", "Ideographic"},
    133186: {"Unified_Ideograph", "Ideographic"},
    133187: {"Unified_Ideograph", "Ideographic"},
    133188: {"Unified_Ideograph", "Ideographic"},
    133189: {"Unified_Ideograph", "Ideographic"},
    133190: {"Unified_Ideograph", "Ideographic"},
    133191: {"Unified_Ideograph", "Ideographic"},
    133192: {"Unified_Ideograph", "Ideographic"},
    133193: {"Unified_Ideograph", "Ideographic"},
    133194: {"Unified_Ideograph", "Ideographic"},
    133195: {"Unified_Ideograph", "Ideographic"},
    133196: {"Unified_Ideograph", "Ideographic"},
    133197: {"Unified_Ideograph", "Ideographic"},
    133198: {"Unified_Ideograph", "Ideographic"},
    133199: {"Unified_Ideograph", "Ideographic"},
    133200: {"Unified_Ideograph", "Ideographic"},
    133201: {"Unified_Ideograph", "Ideographic"},
    133202: {"Unified_Ideograph", "Ideographic"},
    133203: {"Unified_Ideograph", "Ideographic"},
    133204: {"Unified_Ideograph", "Ideographic"},
    133205: {"Unified_Ideograph", "Ideographic"},
    133206: {"Unified_Ideograph", "Ideographic"},
    133207: {"Unified_Ideograph", "Ideographic"},
    133208: {"Unified_Ideograph", "Ideographic"},
    133209: {"Unified_Ideograph", "Ideographic"},
    133210: {"Unified_Ideograph", "Ideographic"},
    133211: {"Unified_Ideograph", "Ideographic"},
    133212: {"Unified_Ideograph", "Ideographic"},
    133213: {"Unified_Ideograph", "Ideographic"},
    133214: {"Unified_Ideograph", "Ideographic"},
    133215: {"Unified_Ideograph", "Ideographic"},
    133216: {"Unified_Ideograph", "Ideographic"},
    133217: {"Unified_Ideograph", "Ideographic"},
    133218: {"Unified_Ideograph", "Ideographic"},
    133219: {"Unified_Ideograph", "Ideographic"},
    133220: {"Unified_Ideograph", "Ideographic"},
    133221: {"Unified_Ideograph", "Ideographic"},
    133222: {"Unified_Ideograph", "Ideographic"},
    133223: {"Unified_Ideograph", "Ideographic"},
    133224: {"Unified_Ideograph", "Ideographic"},
    133225: {"Unified_Ideograph", "Ideographic"},
    133226: {"Unified_Ideograph", "Ideographic"},
    133227: {"Unified_Ideograph", "Ideographic"},
    133228: {"Unified_Ideograph", "Ideographic"},
    133229: {"Unified_Ideograph", "Ideographic"},
    133230: {"Unified_Ideograph", "Ideographic"},
    133231: {"Unified_Ideograph", "Ideographic"},
    133232: {"Unified_Ideograph", "Ideographic"},
    133233: {"Unified_Ideograph", "Ideographic"},
    133234: {"Unified_Ideograph", "Ideographic"},
    133235: {"Unified_Ideograph", "Ideographic"},
    133236: {"Unified_Ideograph", "Ideographic"},
    133237: {"Unified_Ideograph", "Ideographic"},
    133238: {"Unified_Ideograph", "Ideographic"},
    133239: {"Unified_Ideograph", "Ideographic"},
    133240: {"Unified_Ideograph", "Ideographic"},
    133241: {"Unified_Ideograph", "Ideographic"},
    133242: {"Unified_Ideograph", "Ideographic"},
    133243: {"Unified_Ideograph", "Ideographic"},
    133244: {"Unified_Ideograph", "Ideographic"},
    133245: {"Unified_Ideograph", "Ideographic"},
    133246: {"Unified_Ideograph", "Ideographic"},
    133247: {"Unified_Ideograph", "Ideographic"},
    133248: {"Unified_Ideograph", "Ideographic"},
    133249: {"Unified_Ideograph", "Ideographic"},
    133250: {"Unified_Ideograph", "Ideographic"},
    133251: {"Unified_Ideograph", "Ideographic"},
    133252: {"Unified_Ideograph", "Ideographic"},
    133253: {"Unified_Ideograph", "Ideographic"},
    133254: {"Unified_Ideograph", "Ideographic"},
    133255: {"Unified_Ideograph", "Ideographic"},
    133256: {"Unified_Ideograph", "Ideographic"},
    133257: {"Unified_Ideograph", "Ideographic"},
    133258: {"Unified_Ideograph", "Ideographic"},
    133259: {"Unified_Ideograph", "Ideographic"},
    133260: {"Unified_Ideograph", "Ideographic"},
    133261: {"Unified_Ideograph", "Ideographic"},
    133262: {"Unified_Ideograph", "Ideographic"},
    133263: {"Unified_Ideograph", "Ideographic"},
    133264: {"Unified_Ideograph", "Ideographic"},
    133265: {"Unified_Ideograph", "Ideographic"},
    133266: {"Unified_Ideograph", "Ideographic"},
    133267: {"Unified_Ideograph", "Ideographic"},
    133268: {"Unified_Ideograph", "Ideographic"},
    133269: {"Unified_Ideograph", "Ideographic"},
    133270: {"Unified_Ideograph", "Ideographic"},
    133271: {"Unified_Ideograph", "Ideographic"},
    133272: {"Unified_Ideograph", "Ideographic"},
    133273: {"Unified_Ideograph", "Ideographic"},
    133274: {"Unified_Ideograph", "Ideographic"},
    133275: {"Unified_Ideograph", "Ideographic"},
    133276: {"Unified_Ideograph", "Ideographic"},
    133277: {"Unified_Ideograph", "Ideographic"},
    133278: {"Unified_Ideograph", "Ideographic"},
    133279: {"Unified_Ideograph", "Ideographic"},
    133280: {"Unified_Ideograph", "Ideographic"},
    133281: {"Unified_Ideograph", "Ideographic"},
    133282: {"Unified_Ideograph", "Ideographic"},
    133283: {"Unified_Ideograph", "Ideographic"},
    133284: {"Unified_Ideograph", "Ideographic"},
    133285: {"Unified_Ideograph", "Ideographic"},
    133286: {"Unified_Ideograph", "Ideographic"},
    133287: {"Unified_Ideograph", "Ideographic"},
    133288: {"Unified_Ideograph", "Ideographic"},
    133289: {"Unified_Ideograph", "Ideographic"},
    133290: {"Unified_Ideograph", "Ideographic"},
    133291: {"Unified_Ideograph", "Ideographic"},
    133292: {"Unified_Ideograph", "Ideographic"},
    133293: {"Unified_Ideograph", "Ideographic"},
    133294: {"Unified_Ideograph", "Ideographic"},
    133295: {"Unified_Ideograph", "Ideographic"},
    133296: {"Unified_Ideograph", "Ideographic"},
    133297: {"Unified_Ideograph", "Ideographic"},
    133298: {"Unified_Ideograph", "Ideographic"},
    133299: {"Unified_Ideograph", "Ideographic"},
    133300: {"Unified_Ideograph", "Ideographic"},
    133301: {"Unified_Ideograph", "Ideographic"},
    133302: {"Unified_Ideograph", "Ideographic"},
    133303: {"Unified_Ideograph", "Ideographic"},
    133304: {"Unified_Ideograph", "Ideographic"},
    133305: {"Unified_Ideograph", "Ideographic"},
    133306: {"Unified_Ideograph", "Ideographic"},
    133307: {"Unified_Ideograph", "Ideographic"},
    133308: {"Unified_Ideograph", "Ideographic"},
    133309: {"Unified_Ideograph", "Ideographic"},
    133310: {"Unified_Ideograph", "Ideographic"},
    133311: {"Unified_Ideograph", "Ideographic"},
    133312: {"Unified_Ideograph", "Ideographic"},
    133313: {"Unified_Ideograph", "Ideographic"},
    133314: {"Unified_Ideograph", "Ideographic"},
    133315: {"Unified_Ideograph", "Ideographic"},
    133316: {"Unified_Ideograph", "Ideographic"},
    133317: {"Unified_Ideograph", "Ideographic"},
    133318: {"Unified_Ideograph", "Ideographic"},
    133319: {"Unified_Ideograph", "Ideographic"},
    133320: {"Unified_Ideograph", "Ideographic"},
    133321: {"Unified_Ideograph", "Ideographic"},
    133322: {"Unified_Ideograph", "Ideographic"},
    133323: {"Unified_Ideograph", "Ideographic"},
    133324: {"Unified_Ideograph", "Ideographic"},
    133325: {"Unified_Ideograph", "Ideographic"},
    133326: {"Unified_Ideograph", "Ideographic"},
    133327: {"Unified_Ideograph", "Ideographic"},
    133328: {"Unified_Ideograph", "Ideographic"},
    133329: {"Unified_Ideograph", "Ideographic"},
    133330: {"Unified_Ideograph", "Ideographic"},
    133331: {"Unified_Ideograph", "Ideographic"},
    133332: {"Unified_Ideograph", "Ideographic"},
    133333: {"Unified_Ideograph", "Ideographic"},
    133334: {"Unified_Ideograph", "Ideographic"},
    133335: {"Unified_Ideograph", "Ideographic"},
    133336: {"Unified_Ideograph", "Ideographic"},
    133337: {"Unified_Ideograph", "Ideographic"},
    133338: {"Unified_Ideograph", "Ideographic"},
    133339: {"Unified_Ideograph", "Ideographic"},
    133340: {"Unified_Ideograph", "Ideographic"},
    133341: {"Unified_Ideograph", "Ideographic"},
    133342: {"Unified_Ideograph", "Ideographic"},
    133343: {"Unified_Ideograph", "Ideographic"},
    133344: {"Unified_Ideograph", "Ideographic"},
    133345: {"Unified_Ideograph", "Ideographic"},
    133346: {"Unified_Ideograph", "Ideographic"},
    133347: {"Unified_Ideograph", "Ideographic"},
    133348: {"Unified_Ideograph", "Ideographic"},
    133349: {"Unified_Ideograph", "Ideographic"},
    133350: {"Unified_Ideograph", "Ideographic"},
    133351: {"Unified_Ideograph", "Ideographic"},
    133352: {"Unified_Ideograph", "Ideographic"},
    133353: {"Unified_Ideograph", "Ideographic"},
    133354: {"Unified_Ideograph", "Ideographic"},
    133355: {"Unified_Ideograph", "Ideographic"},
    133356: {"Unified_Ideograph", "Ideographic"},
    133357: {"Unified_Ideograph", "Ideographic"},
    133358: {"Unified_Ideograph", "Ideographic"},
    133359: {"Unified_Ideograph", "Ideographic"},
    133360: {"Unified_Ideograph", "Ideographic"},
    133361: {"Unified_Ideograph", "Ideographic"},
    133362: {"Unified_Ideograph", "Ideographic"},
    133363: {"Unified_Ideograph", "Ideographic"},
    133364: {"Unified_Ideograph", "Ideographic"},
    133365: {"Unified_Ideograph", "Ideographic"},
    133366: {"Unified_Ideograph", "Ideographic"},
    133367: {"Unified_Ideograph", "Ideographic"},
    133368: {"Unified_Ideograph", "Ideographic"},
    133369: {"Unified_Ideograph", "Ideographic"},
    133370: {"Unified_Ideograph", "Ideographic"},
    133371: {"Unified_Ideograph", "Ideographic"},
    133372: {"Unified_Ideograph", "Ideographic"},
    133373: {"Unified_Ideograph", "Ideographic"},
    133374: {"Unified_Ideograph", "Ideographic"},
    133375: {"Unified_Ideograph", "Ideographic"},
    133376: {"Unified_Ideograph", "Ideographic"},
    133377: {"Unified_Ideograph", "Ideographic"},
    133378: {"Unified_Ideograph", "Ideographic"},
    133379: {"Unified_Ideograph", "Ideographic"},
    133380: {"Unified_Ideograph", "Ideographic"},
    133381: {"Unified_Ideograph", "Ideographic"},
    133382: {"Unified_Ideograph", "Ideographic"},
    133383: {"Unified_Ideograph", "Ideographic"},
    133384: {"Unified_Ideograph", "Ideographic"},
    133385: {"Unified_Ideograph", "Ideographic"},
    133386: {"Unified_Ideograph", "Ideographic"},
    133387: {"Unified_Ideograph", "Ideographic"},
    133388: {"Unified_Ideograph", "Ideographic"},
    133389: {"Unified_Ideograph", "Ideographic"},
    133390: {"Unified_Ideograph", "Ideographic"},
    133391: {"Unified_Ideograph", "Ideographic"},
    133392: {"Unified_Ideograph", "Ideographic"},
    133393: {"Unified_Ideograph", "Ideographic"},
    133394: {"Unified_Ideograph", "Ideographic"},
    133395: {"Unified_Ideograph", "Ideographic"},
    133396: {"Unified_Ideograph", "Ideographic"},
    133397: {"Unified_Ideograph", "Ideographic"},
    133398: {"Unified_Ideograph", "Ideographic"},
    133399: {"Unified_Ideograph", "Ideographic"},
    133400: {"Unified_Ideograph", "Ideographic"},
    133401: {"Unified_Ideograph", "Ideographic"},
    133402: {"Unified_Ideograph", "Ideographic"},
    133403: {"Unified_Ideograph", "Ideographic"},
    133404: {"Unified_Ideograph", "Ideographic"},
    133405: {"Unified_Ideograph", "Ideographic"},
    133406: {"Unified_Ideograph", "Ideographic"},
    133407: {"Unified_Ideograph", "Ideographic"},
    133408: {"Unified_Ideograph", "Ideographic"},
    133409: {"Unified_Ideograph", "Ideographic"},
    133410: {"Unified_Ideograph", "Ideographic"},
    133411: {"Unified_Ideograph", "Ideographic"},
    133412: {"Unified_Ideograph", "Ideographic"},
    133413: {"Unified_Ideograph", "Ideographic"},
    133414: {"Unified_Ideograph", "Ideographic"},
    133415: {"Unified_Ideograph", "Ideographic"},
    133416: {"Unified_Ideograph", "Ideographic"},
    133417: {"Unified_Ideograph", "Ideographic"},
    133418: {"Unified_Ideograph", "Ideographic"},
    133419: {"Unified_Ideograph", "Ideographic"},
    133420: {"Unified_Ideograph", "Ideographic"},
    133421: {"Unified_Ideograph", "Ideographic"},
    133422: {"Unified_Ideograph", "Ideographic"},
    133423: {"Unified_Ideograph", "Ideographic"},
    133424: {"Unified_Ideograph", "Ideographic"},
    133425: {"Unified_Ideograph", "Ideographic"},
    133426: {"Unified_Ideograph", "Ideographic"},
    133427: {"Unified_Ideograph", "Ideographic"},
    133428: {"Unified_Ideograph", "Ideographic"},
    133429: {"Unified_Ideograph", "Ideographic"},
    133430: {"Unified_Ideograph", "Ideographic"},
    133431: {"Unified_Ideograph", "Ideographic"},
    133432: {"Unified_Ideograph", "Ideographic"},
    133433: {"Unified_Ideograph", "Ideographic"},
    133434: {"Unified_Ideograph", "Ideographic"},
    133435: {"Unified_Ideograph", "Ideographic"},
    133436: {"Unified_Ideograph", "Ideographic"},
    133437: {"Unified_Ideograph", "Ideographic"},
    133438: {"Unified_Ideograph", "Ideographic"},
    133439: {"Unified_Ideograph", "Ideographic"},
    133440: {"Unified_Ideograph", "Ideographic"},
    133441: {"Unified_Ideograph", "Ideographic"},
    133442: {"Unified_Ideograph", "Ideographic"},
    133443: {"Unified_Ideograph", "Ideographic"},
    133444: {"Unified_Ideograph", "Ideographic"},
    133445: {"Unified_Ideograph", "Ideographic"},
    133446: {"Unified_Ideograph", "Ideographic"},
    133447: {"Unified_Ideograph", "Ideographic"},
    133448: {"Unified_Ideograph", "Ideographic"},
    133449: {"Unified_Ideograph", "Ideographic"},
    133450: {"Unified_Ideograph", "Ideographic"},
    133451: {"Unified_Ideograph", "Ideographic"},
    133452: {"Unified_Ideograph", "Ideographic"},
    133453: {"Unified_Ideograph", "Ideographic"},
    133454: {"Unified_Ideograph", "Ideographic"},
    133455: {"Unified_Ideograph", "Ideographic"},
    133456: {"Unified_Ideograph", "Ideographic"},
    133457: {"Unified_Ideograph", "Ideographic"},
    133458: {"Unified_Ideograph", "Ideographic"},
    133459: {"Unified_Ideograph", "Ideographic"},
    133460: {"Unified_Ideograph", "Ideographic"},
    133461: {"Unified_Ideograph", "Ideographic"},
    133462: {"Unified_Ideograph", "Ideographic"},
    133463: {"Unified_Ideograph", "Ideographic"},
    133464: {"Unified_Ideograph", "Ideographic"},
    133465: {"Unified_Ideograph", "Ideographic"},
    133466: {"Unified_Ideograph", "Ideographic"},
    133467: {"Unified_Ideograph", "Ideographic"},
    133468: {"Unified_Ideograph", "Ideographic"},
    133469: {"Unified_Ideograph", "Ideographic"},
    133470: {"Unified_Ideograph", "Ideographic"},
    133471: {"Unified_Ideograph", "Ideographic"},
    133472: {"Unified_Ideograph", "Ideographic"},
    133473: {"Unified_Ideograph", "Ideographic"},
    133474: {"Unified_Ideograph", "Ideographic"},
    133475: {"Unified_Ideograph", "Ideographic"},
    133476: {"Unified_Ideograph", "Ideographic"},
    133477: {"Unified_Ideograph", "Ideographic"},
    133478: {"Unified_Ideograph", "Ideographic"},
    133479: {"Unified_Ideograph", "Ideographic"},
    133480: {"Unified_Ideograph", "Ideographic"},
    133481: {"Unified_Ideograph", "Ideographic"},
    133482: {"Unified_Ideograph", "Ideographic"},
    133483: {"Unified_Ideograph", "Ideographic"},
    133484: {"Unified_Ideograph", "Ideographic"},
    133485: {"Unified_Ideograph", "Ideographic"},
    133486: {"Unified_Ideograph", "Ideographic"},
    133487: {"Unified_Ideograph", "Ideographic"},
    133488: {"Unified_Ideograph", "Ideographic"},
    133489: {"Unified_Ideograph", "Ideographic"},
    133490: {"Unified_Ideograph", "Ideographic"},
    133491: {"Unified_Ideograph", "Ideographic"},
    133492: {"Unified_Ideograph", "Ideographic"},
    133493: {"Unified_Ideograph", "Ideographic"},
    133494: {"Unified_Ideograph", "Ideographic"},
    133495: {"Unified_Ideograph", "Ideographic"},
    133496: {"Unified_Ideograph", "Ideographic"},
    133497: {"Unified_Ideograph", "Ideographic"},
    133498: {"Unified_Ideograph", "Ideographic"},
    133499: {"Unified_Ideograph", "Ideographic"},
    133500: {"Unified_Ideograph", "Ideographic"},
    133501: {"Unified_Ideograph", "Ideographic"},
    133502: {"Unified_Ideograph", "Ideographic"},
    133503: {"Unified_Ideograph", "Ideographic"},
    133504: {"Unified_Ideograph", "Ideographic"},
    133505: {"Unified_Ideograph", "Ideographic"},
    133506: {"Unified_Ideograph", "Ideographic"},
    133507: {"Unified_Ideograph", "Ideographic"},
    133508: {"Unified_Ideograph", "Ideographic"},
    133509: {"Unified_Ideograph", "Ideographic"},
    133510: {"Unified_Ideograph", "Ideographic"},
    133511: {"Unified_Ideograph", "Ideographic"},
    133512: {"Unified_Ideograph", "Ideographic"},
    133513: {"Unified_Ideograph", "Ideographic"},
    133514: {"Unified_Ideograph", "Ideographic"},
    133515: {"Unified_Ideograph", "Ideographic"},
    133516: {"Unified_Ideograph", "Ideographic"},
    133517: {"Unified_Ideograph", "Ideographic"},
    133518: {"Unified_Ideograph", "Ideographic"},
    133519: {"Unified_Ideograph", "Ideographic"},
    133520: {"Unified_Ideograph", "Ideographic"},
    133521: {"Unified_Ideograph", "Ideographic"},
    133522: {"Unified_Ideograph", "Ideographic"},
    133523: {"Unified_Ideograph", "Ideographic"},
    133524: {"Unified_Ideograph", "Ideographic"},
    133525: {"Unified_Ideograph", "Ideographic"},
    133526: {"Unified_Ideograph", "Ideographic"},
    133527: {"Unified_Ideograph", "Ideographic"},
    133528: {"Unified_Ideograph", "Ideographic"},
    133529: {"Unified_Ideograph", "Ideographic"},
    133530: {"Unified_Ideograph", "Ideographic"},
    133531: {"Unified_Ideograph", "Ideographic"},
    133532: {"Unified_Ideograph", "Ideographic"},
    133533: {"Unified_Ideograph", "Ideographic"},
    133534: {"Unified_Ideograph", "Ideographic"},
    133535: {"Unified_Ideograph", "Ideographic"},
    133536: {"Unified_Ideograph", "Ideographic"},
    133537: {"Unified_Ideograph", "Ideographic"},
    133538: {"Unified_Ideograph", "Ideographic"},
    133539: {"Unified_Ideograph", "Ideographic"},
    133540: {"Unified_Ideograph", "Ideographic"},
    133541: {"Unified_Ideograph", "Ideographic"},
    133542: {"Unified_Ideograph", "Ideographic"},
    133543: {"Unified_Ideograph", "Ideographic"},
    133544: {"Unified_Ideograph", "Ideographic"},
    133545: {"Unified_Ideograph", "Ideographic"},
    133546: {"Unified_Ideograph", "Ideographic"},
    133547: {"Unified_Ideograph", "Ideographic"},
    133548: {"Unified_Ideograph", "Ideographic"},
    133549: {"Unified_Ideograph", "Ideographic"},
    133550: {"Unified_Ideograph", "Ideographic"},
    133551: {"Unified_Ideograph", "Ideographic"},
    133552: {"Unified_Ideograph", "Ideographic"},
    133553: {"Unified_Ideograph", "Ideographic"},
    133554: {"Unified_Ideograph", "Ideographic"},
    133555: {"Unified_Ideograph", "Ideographic"},
    133556: {"Unified_Ideograph", "Ideographic"},
    133557: {"Unified_Ideograph", "Ideographic"},
    133558: {"Unified_Ideograph", "Ideographic"},
    133559: {"Unified_Ideograph", "Ideographic"},
    133560: {"Unified_Ideograph", "Ideographic"},
    133561: {"Unified_Ideograph", "Ideographic"},
    133562: {"Unified_Ideograph", "Ideographic"},
    133563: {"Unified_Ideograph", "Ideographic"},
    133564: {"Unified_Ideograph", "Ideographic"},
    133565: {"Unified_Ideograph", "Ideographic"},
    133566: {"Unified_Ideograph", "Ideographic"},
    133567: {"Unified_Ideograph", "Ideographic"},
    133568: {"Unified_Ideograph", "Ideographic"},
    133569: {"Unified_Ideograph", "Ideographic"},
    133570: {"Unified_Ideograph", "Ideographic"},
    133571: {"Unified_Ideograph", "Ideographic"},
    133572: {"Unified_Ideograph", "Ideographic"},
    133573: {"Unified_Ideograph", "Ideographic"},
    133574: {"Unified_Ideograph", "Ideographic"},
    133575: {"Unified_Ideograph", "Ideographic"},
    133576: {"Unified_Ideograph", "Ideographic"},
    133577: {"Unified_Ideograph", "Ideographic"},
    133578: {"Unified_Ideograph", "Ideographic"},
    133579: {"Unified_Ideograph", "Ideographic"},
    133580: {"Unified_Ideograph", "Ideographic"},
    133581: {"Unified_Ideograph", "Ideographic"},
    133582: {"Unified_Ideograph", "Ideographic"},
    133583: {"Unified_Ideograph", "Ideographic"},
    133584: {"Unified_Ideograph", "Ideographic"},
    133585: {"Unified_Ideograph", "Ideographic"},
    133586: {"Unified_Ideograph", "Ideographic"},
    133587: {"Unified_Ideograph", "Ideographic"},
    133588: {"Unified_Ideograph", "Ideographic"},
    133589: {"Unified_Ideograph", "Ideographic"},
    133590: {"Unified_Ideograph", "Ideographic"},
    133591: {"Unified_Ideograph", "Ideographic"},
    133592: {"Unified_Ideograph", "Ideographic"},
    133593: {"Unified_Ideograph", "Ideographic"},
    133594: {"Unified_Ideograph", "Ideographic"},
    133595: {"Unified_Ideograph", "Ideographic"},
    133596: {"Unified_Ideograph", "Ideographic"},
    133597: {"Unified_Ideograph", "Ideographic"},
    133598: {"Unified_Ideograph", "Ideographic"},
    133599: {"Unified_Ideograph", "Ideographic"},
    133600: {"Unified_Ideograph", "Ideographic"},
    133601: {"Unified_Ideograph", "Ideographic"},
    133602: {"Unified_Ideograph", "Ideographic"},
    133603: {"Unified_Ideograph", "Ideographic"},
    133604: {"Unified_Ideograph", "Ideographic"},
    133605: {"Unified_Ideograph", "Ideographic"},
    133606: {"Unified_Ideograph", "Ideographic"},
    133607: {"Unified_Ideograph", "Ideographic"},
    133608: {"Unified_Ideograph", "Ideographic"},
    133609: {"Unified_Ideograph", "Ideographic"},
    133610: {"Unified_Ideograph", "Ideographic"},
    133611: {"Unified_Ideograph", "Ideographic"},
    133612: {"Unified_Ideograph", "Ideographic"},
    133613: {"Unified_Ideograph", "Ideographic"},
    133614: {"Unified_Ideograph", "Ideographic"},
    133615: {"Unified_Ideograph", "Ideographic"},
    133616: {"Unified_Ideograph", "Ideographic"},
    133617: {"Unified_Ideograph", "Ideographic"},
    133618: {"Unified_Ideograph", "Ideographic"},
    133619: {"Unified_Ideograph", "Ideographic"},
    133620: {"Unified_Ideograph", "Ideographic"},
    133621: {"Unified_Ideograph", "Ideographic"},
    133622: {"Unified_Ideograph", "Ideographic"},
    133623: {"Unified_Ideograph", "Ideographic"},
    133624: {"Unified_Ideograph", "Ideographic"},
    133625: {"Unified_Ideograph", "Ideographic"},
    133626: {"Unified_Ideograph", "Ideographic"},
    133627: {"Unified_Ideograph", "Ideographic"},
    133628: {"Unified_Ideograph", "Ideographic"},
    133629: {"Unified_Ideograph", "Ideographic"},
    133630: {"Unified_Ideograph", "Ideographic"},
    133631: {"Unified_Ideograph", "Ideographic"},
    133632: {"Unified_Ideograph", "Ideographic"},
    133633: {"Unified_Ideograph", "Ideographic"},
    133634: {"Unified_Ideograph", "Ideographic"},
    133635: {"Unified_Ideograph", "Ideographic"},
    133636: {"Unified_Ideograph", "Ideographic"},
    133637: {"Unified_Ideograph", "Ideographic"},
    133638: {"Unified_Ideograph", "Ideographic"},
    133639: {"Unified_Ideograph", "Ideographic"},
    133640: {"Unified_Ideograph", "Ideographic"},
    133641: {"Unified_Ideograph", "Ideographic"},
    133642: {"Unified_Ideograph", "Ideographic"},
    133643: {"Unified_Ideograph", "Ideographic"},
    133644: {"Unified_Ideograph", "Ideographic"},
    133645: {"Unified_Ideograph", "Ideographic"},
    133646: {"Unified_Ideograph", "Ideographic"},
    133647: {"Unified_Ideograph", "Ideographic"},
    133648: {"Unified_Ideograph", "Ideographic"},
    133649: {"Unified_Ideograph", "Ideographic"},
    133650: {"Unified_Ideograph", "Ideographic"},
    133651: {"Unified_Ideograph", "Ideographic"},
    133652: {"Unified_Ideograph", "Ideographic"},
    133653: {"Unified_Ideograph", "Ideographic"},
    133654: {"Unified_Ideograph", "Ideographic"},
    133655: {"Unified_Ideograph", "Ideographic"},
    133656: {"Unified_Ideograph", "Ideographic"},
    133657: {"Unified_Ideograph", "Ideographic"},
    133658: {"Unified_Ideograph", "Ideographic"},
    133659: {"Unified_Ideograph", "Ideographic"},
    133660: {"Unified_Ideograph", "Ideographic"},
    133661: {"Unified_Ideograph", "Ideographic"},
    133662: {"Unified_Ideograph", "Ideographic"},
    133663: {"Unified_Ideograph", "Ideographic"},
    133664: {"Unified_Ideograph", "Ideographic"},
    133665: {"Unified_Ideograph", "Ideographic"},
    133666: {"Unified_Ideograph", "Ideographic"},
    133667: {"Unified_Ideograph", "Ideographic"},
    133668: {"Unified_Ideograph", "Ideographic"},
    133669: {"Unified_Ideograph", "Ideographic"},
    133670: {"Unified_Ideograph", "Ideographic"},
    133671: {"Unified_Ideograph", "Ideographic"},
    133672: {"Unified_Ideograph", "Ideographic"},
    133673: {"Unified_Ideograph", "Ideographic"},
    133674: {"Unified_Ideograph", "Ideographic"},
    133675: {"Unified_Ideograph", "Ideographic"},
    133676: {"Unified_Ideograph", "Ideographic"},
    133677: {"Unified_Ideograph", "Ideographic"},
    133678: {"Unified_Ideograph", "Ideographic"},
    133679: {"Unified_Ideograph", "Ideographic"},
    133680: {"Unified_Ideograph", "Ideographic"},
    133681: {"Unified_Ideograph", "Ideographic"},
    133682: {"Unified_Ideograph", "Ideographic"},
    133683: {"Unified_Ideograph", "Ideographic"},
    133684: {"Unified_Ideograph", "Ideographic"},
    133685: {"Unified_Ideograph", "Ideographic"},
    133686: {"Unified_Ideograph", "Ideographic"},
    133687: {"Unified_Ideograph", "Ideographic"},
    133688: {"Unified_Ideograph", "Ideographic"},
    133689: {"Unified_Ideograph", "Ideographic"},
    133690: {"Unified_Ideograph", "Ideographic"},
    133691: {"Unified_Ideograph", "Ideographic"},
    133692: {"Unified_Ideograph", "Ideographic"},
    133693: {"Unified_Ideograph", "Ideographic"},
    133694: {"Unified_Ideograph", "Ideographic"},
    133695: {"Unified_Ideograph", "Ideographic"},
    133696: {"Unified_Ideograph", "Ideographic"},
    133697: {"Unified_Ideograph", "Ideographic"},
    133698: {"Unified_Ideograph", "Ideographic"},
    133699: {"Unified_Ideograph", "Ideographic"},
    133700: {"Unified_Ideograph", "Ideographic"},
    133701: {"Unified_Ideograph", "Ideographic"},
    133702: {"Unified_Ideograph", "Ideographic"},
    133703: {"Unified_Ideograph", "Ideographic"},
    133704: {"Unified_Ideograph", "Ideographic"},
    133705: {"Unified_Ideograph", "Ideographic"},
    133706: {"Unified_Ideograph", "Ideographic"},
    133707: {"Unified_Ideograph", "Ideographic"},
    133708: {"Unified_Ideograph", "Ideographic"},
    133709: {"Unified_Ideograph", "Ideographic"},
    133710: {"Unified_Ideograph", "Ideographic"},
    133711: {"Unified_Ideograph", "Ideographic"},
    133712: {"Unified_Ideograph", "Ideographic"},
    133713: {"Unified_Ideograph", "Ideographic"},
    133714: {"Unified_Ideograph", "Ideographic"},
    133715: {"Unified_Ideograph", "Ideographic"},
    133716: {"Unified_Ideograph", "Ideographic"},
    133717: {"Unified_Ideograph", "Ideographic"},
    133718: {"Unified_Ideograph", "Ideographic"},
    133719: {"Unified_Ideograph", "Ideographic"},
    133720: {"Unified_Ideograph", "Ideographic"},
    133721: {"Unified_Ideograph", "Ideographic"},
    133722: {"Unified_Ideograph", "Ideographic"},
    133723: {"Unified_Ideograph", "Ideographic"},
    133724: {"Unified_Ideograph", "Ideographic"},
    133725: {"Unified_Ideograph", "Ideographic"},
    133726: {"Unified_Ideograph", "Ideographic"},
    133727: {"Unified_Ideograph", "Ideographic"},
    133728: {"Unified_Ideograph", "Ideographic"},
    133729: {"Unified_Ideograph", "Ideographic"},
    133730: {"Unified_Ideograph", "Ideographic"},
    133731: {"Unified_Ideograph", "Ideographic"},
    133732: {"Unified_Ideograph", "Ideographic"},
    133733: {"Unified_Ideograph", "Ideographic"},
    133734: {"Unified_Ideograph", "Ideographic"},
    133735: {"Unified_Ideograph", "Ideographic"},
    133736: {"Unified_Ideograph", "Ideographic"},
    133737: {"Unified_Ideograph", "Ideographic"},
    133738: {"Unified_Ideograph", "Ideographic"},
    133739: {"Unified_Ideograph", "Ideographic"},
    133740: {"Unified_Ideograph", "Ideographic"},
    133741: {"Unified_Ideograph", "Ideographic"},
    133742: {"Unified_Ideograph", "Ideographic"},
    133743: {"Unified_Ideograph", "Ideographic"},
    133744: {"Unified_Ideograph", "Ideographic"},
    133745: {"Unified_Ideograph", "Ideographic"},
    133746: {"Unified_Ideograph", "Ideographic"},
    133747: {"Unified_Ideograph", "Ideographic"},
    133748: {"Unified_Ideograph", "Ideographic"},
    133749: {"Unified_Ideograph", "Ideographic"},
    133750: {"Unified_Ideograph", "Ideographic"},
    133751: {"Unified_Ideograph", "Ideographic"},
    133752: {"Unified_Ideograph", "Ideographic"},
    133753: {"Unified_Ideograph", "Ideographic"},
    133754: {"Unified_Ideograph", "Ideographic"},
    133755: {"Unified_Ideograph", "Ideographic"},
    133756: {"Unified_Ideograph", "Ideographic"},
    133757: {"Unified_Ideograph", "Ideographic"},
    133758: {"Unified_Ideograph", "Ideographic"},
    133759: {"Unified_Ideograph", "Ideographic"},
    133760: {"Unified_Ideograph", "Ideographic"},
    133761: {"Unified_Ideograph", "Ideographic"},
    133762: {"Unified_Ideograph", "Ideographic"},
    133763: {"Unified_Ideograph", "Ideographic"},
    133764: {"Unified_Ideograph", "Ideographic"},
    133765: {"Unified_Ideograph", "Ideographic"},
    133766: {"Unified_Ideograph", "Ideographic"},
    133767: {"Unified_Ideograph", "Ideographic"},
    133768: {"Unified_Ideograph", "Ideographic"},
    133769: {"Unified_Ideograph", "Ideographic"},
    133770: {"Unified_Ideograph", "Ideographic"},
    133771: {"Unified_Ideograph", "Ideographic"},
    133772: {"Unified_Ideograph", "Ideographic"},
    133773: {"Unified_Ideograph", "Ideographic"},
    133774: {"Unified_Ideograph", "Ideographic"},
    133775: {"Unified_Ideograph", "Ideographic"},
    133776: {"Unified_Ideograph", "Ideographic"},
    133777: {"Unified_Ideograph", "Ideographic"},
    133778: {"Unified_Ideograph", "Ideographic"},
    133779: {"Unified_Ideograph", "Ideographic"},
    133780: {"Unified_Ideograph", "Ideographic"},
    133781: {"Unified_Ideograph", "Ideographic"},
    133782: {"Unified_Ideograph", "Ideographic"},
    133783: {"Unified_Ideograph", "Ideographic"},
    133784: {"Unified_Ideograph", "Ideographic"},
    133785: {"Unified_Ideograph", "Ideographic"},
    133786: {"Unified_Ideograph", "Ideographic"},
    133787: {"Unified_Ideograph", "Ideographic"},
    133788: {"Unified_Ideograph", "Ideographic"},
    133789: {"Unified_Ideograph", "Ideographic"},
    133790: {"Unified_Ideograph", "Ideographic"},
    133791: {"Unified_Ideograph", "Ideographic"},
    133792: {"Unified_Ideograph", "Ideographic"},
    133793: {"Unified_Ideograph", "Ideographic"},
    133794: {"Unified_Ideograph", "Ideographic"},
    133795: {"Unified_Ideograph", "Ideographic"},
    133796: {"Unified_Ideograph", "Ideographic"},
    133797: {"Unified_Ideograph", "Ideographic"},
    133798: {"Unified_Ideograph", "Ideographic"},
    133799: {"Unified_Ideograph", "Ideographic"},
    133800: {"Unified_Ideograph", "Ideographic"},
    133801: {"Unified_Ideograph", "Ideographic"},
    133802: {"Unified_Ideograph", "Ideographic"},
    133803: {"Unified_Ideograph", "Ideographic"},
    133804: {"Unified_Ideograph", "Ideographic"},
    133805: {"Unified_Ideograph", "Ideographic"},
    133806: {"Unified_Ideograph", "Ideographic"},
    133807: {"Unified_Ideograph", "Ideographic"},
    133808: {"Unified_Ideograph", "Ideographic"},
    133809: {"Unified_Ideograph", "Ideographic"},
    133810: {"Unified_Ideograph", "Ideographic"},
    133811: {"Unified_Ideograph", "Ideographic"},
    133812: {"Unified_Ideograph", "Ideographic"},
    133813: {"Unified_Ideograph", "Ideographic"},
    133814: {"Unified_Ideograph", "Ideographic"},
    133815: {"Unified_Ideograph", "Ideographic"},
    133816: {"Unified_Ideograph", "Ideographic"},
    133817: {"Unified_Ideograph", "Ideographic"},
    133818: {"Unified_Ideograph", "Ideographic"},
    133819: {"Unified_Ideograph", "Ideographic"},
    133820: {"Unified_Ideograph", "Ideographic"},
    133821: {"Unified_Ideograph", "Ideographic"},
    133822: {"Unified_Ideograph", "Ideographic"},
    133823: {"Unified_Ideograph", "Ideographic"},
    133824: {"Unified_Ideograph", "Ideographic"},
    133825: {"Unified_Ideograph", "Ideographic"},
    133826: {"Unified_Ideograph", "Ideographic"},
    133827: {"Unified_Ideograph", "Ideographic"},
    133828: {"Unified_Ideograph", "Ideographic"},
    133829: {"Unified_Ideograph", "Ideographic"},
    133830: {"Unified_Ideograph", "Ideographic"},
    133831: {"Unified_Ideograph", "Ideographic"},
    133832: {"Unified_Ideograph", "Ideographic"},
    133833: {"Unified_Ideograph", "Ideographic"},
    133834: {"Unified_Ideograph", "Ideographic"},
    133835: {"Unified_Ideograph", "Ideographic"},
    133836: {"Unified_Ideograph", "Ideographic"},
    133837: {"Unified_Ideograph", "Ideographic"},
    133838: {"Unified_Ideograph", "Ideographic"},
    133839: {"Unified_Ideograph", "Ideographic"},
    133840: {"Unified_Ideograph", "Ideographic"},
    133841: {"Unified_Ideograph", "Ideographic"},
    133842: {"Unified_Ideograph", "Ideographic"},
    133843: {"Unified_Ideograph", "Ideographic"},
    133844: {"Unified_Ideograph", "Ideographic"},
    133845: {"Unified_Ideograph", "Ideographic"},
    133846: {"Unified_Ideograph", "Ideographic"},
    133847: {"Unified_Ideograph", "Ideographic"},
    133848: {"Unified_Ideograph", "Ideographic"},
    133849: {"Unified_Ideograph", "Ideographic"},
    133850: {"Unified_Ideograph", "Ideographic"},
    133851: {"Unified_Ideograph", "Ideographic"},
    133852: {"Unified_Ideograph", "Ideographic"},
    133853: {"Unified_Ideograph", "Ideographic"},
    133854: {"Unified_Ideograph", "Ideographic"},
    133855: {"Unified_Ideograph", "Ideographic"},
    133856: {"Unified_Ideograph", "Ideographic"},
    133857: {"Unified_Ideograph", "Ideographic"},
    133858: {"Unified_Ideograph", "Ideographic"},
    133859: {"Unified_Ideograph", "Ideographic"},
    133860: {"Unified_Ideograph", "Ideographic"},
    133861: {"Unified_Ideograph", "Ideographic"},
    133862: {"Unified_Ideograph", "Ideographic"},
    133863: {"Unified_Ideograph", "Ideographic"},
    133864: {"Unified_Ideograph", "Ideographic"},
    133865: {"Unified_Ideograph", "Ideographic"},
    133866: {"Unified_Ideograph", "Ideographic"},
    133867: {"Unified_Ideograph", "Ideographic"},
    133868: {"Unified_Ideograph", "Ideographic"},
    133869: {"Unified_Ideograph", "Ideographic"},
    133870: {"Unified_Ideograph", "Ideographic"},
    133871: {"Unified_Ideograph", "Ideographic"},
    133872: {"Unified_Ideograph", "Ideographic"},
    133873: {"Unified_Ideograph", "Ideographic"},
    133874: {"Unified_Ideograph", "Ideographic"},
    133875: {"Unified_Ideograph", "Ideographic"},
    133876: {"Unified_Ideograph", "Ideographic"},
    133877: {"Unified_Ideograph", "Ideographic"},
    133878: {"Unified_Ideograph", "Ideographic"},
    133879: {"Unified_Ideograph", "Ideographic"},
    133880: {"Unified_Ideograph", "Ideographic"},
    133881: {"Unified_Ideograph", "Ideographic"},
    133882: {"Unified_Ideograph", "Ideographic"},
    133883: {"Unified_Ideograph", "Ideographic"},
    133884: {"Unified_Ideograph", "Ideographic"},
    133885: {"Unified_Ideograph", "Ideographic"},
    133886: {"Unified_Ideograph", "Ideographic"},
    133887: {"Unified_Ideograph", "Ideographic"},
    133888: {"Unified_Ideograph", "Ideographic"},
    133889: {"Unified_Ideograph", "Ideographic"},
    133890: {"Unified_Ideograph", "Ideographic"},
    133891: {"Unified_Ideograph", "Ideographic"},
    133892: {"Unified_Ideograph", "Ideographic"},
    133893: {"Unified_Ideograph", "Ideographic"},
    133894: {"Unified_Ideograph", "Ideographic"},
    133895: {"Unified_Ideograph", "Ideographic"},
    133896: {"Unified_Ideograph", "Ideographic"},
    133897: {"Unified_Ideograph", "Ideographic"},
    133898: {"Unified_Ideograph", "Ideographic"},
    133899: {"Unified_Ideograph", "Ideographic"},
    133900: {"Unified_Ideograph", "Ideographic"},
    133901: {"Unified_Ideograph", "Ideographic"},
    133902: {"Unified_Ideograph", "Ideographic"},
    133903: {"Unified_Ideograph", "Ideographic"},
    133904: {"Unified_Ideograph", "Ideographic"},
    133905: {"Unified_Ideograph", "Ideographic"},
    133906: {"Unified_Ideograph", "Ideographic"},
    133907: {"Unified_Ideograph", "Ideographic"},
    133908: {"Unified_Ideograph", "Ideographic"},
    133909: {"Unified_Ideograph", "Ideographic"},
    133910: {"Unified_Ideograph", "Ideographic"},
    133911: {"Unified_Ideograph", "Ideographic"},
    133912: {"Unified_Ideograph", "Ideographic"},
    133913: {"Unified_Ideograph", "Ideographic"},
    133914: {"Unified_Ideograph", "Ideographic"},
    133915: {"Unified_Ideograph", "Ideographic"},
    133916: {"Unified_Ideograph", "Ideographic"},
    133917: {"Unified_Ideograph", "Ideographic"},
    133918: {"Unified_Ideograph", "Ideographic"},
    133919: {"Unified_Ideograph", "Ideographic"},
    133920: {"Unified_Ideograph", "Ideographic"},
    133921: {"Unified_Ideograph", "Ideographic"},
    133922: {"Unified_Ideograph", "Ideographic"},
    133923: {"Unified_Ideograph", "Ideographic"},
    133924: {"Unified_Ideograph", "Ideographic"},
    133925: {"Unified_Ideograph", "Ideographic"},
    133926: {"Unified_Ideograph", "Ideographic"},
    133927: {"Unified_Ideograph", "Ideographic"},
    133928: {"Unified_Ideograph", "Ideographic"},
    133929: {"Unified_Ideograph", "Ideographic"},
    133930: {"Unified_Ideograph", "Ideographic"},
    133931: {"Unified_Ideograph", "Ideographic"},
    133932: {"Unified_Ideograph", "Ideographic"},
    133933: {"Unified_Ideograph", "Ideographic"},
    133934: {"Unified_Ideograph", "Ideographic"},
    133935: {"Unified_Ideograph", "Ideographic"},
    133936: {"Unified_Ideograph", "Ideographic"},
    133937: {"Unified_Ideograph", "Ideographic"},
    133938: {"Unified_Ideograph", "Ideographic"},
    133939: {"Unified_Ideograph", "Ideographic"},
    133940: {"Unified_Ideograph", "Ideographic"},
    133941: {"Unified_Ideograph", "Ideographic"},
    133942: {"Unified_Ideograph", "Ideographic"},
    133943: {"Unified_Ideograph", "Ideographic"},
    133944: {"Unified_Ideograph", "Ideographic"},
    133945: {"Unified_Ideograph", "Ideographic"},
    133946: {"Unified_Ideograph", "Ideographic"},
    133947: {"Unified_Ideograph", "Ideographic"},
    133948: {"Unified_Ideograph", "Ideographic"},
    133949: {"Unified_Ideograph", "Ideographic"},
    133950: {"Unified_Ideograph", "Ideographic"},
    133951: {"Unified_Ideograph", "Ideographic"},
    133952: {"Unified_Ideograph", "Ideographic"},
    133953: {"Unified_Ideograph", "Ideographic"},
    133954: {"Unified_Ideograph", "Ideographic"},
    133955: {"Unified_Ideograph", "Ideographic"},
    133956: {"Unified_Ideograph", "Ideographic"},
    133957: {"Unified_Ideograph", "Ideographic"},
    133958: {"Unified_Ideograph", "Ideographic"},
    133959: {"Unified_Ideograph", "Ideographic"},
    133960: {"Unified_Ideograph", "Ideographic"},
    133961: {"Unified_Ideograph", "Ideographic"},
    133962: {"Unified_Ideograph", "Ideographic"},
    133963: {"Unified_Ideograph", "Ideographic"},
    133964: {"Unified_Ideograph", "Ideographic"},
    133965: {"Unified_Ideograph", "Ideographic"},
    133966: {"Unified_Ideograph", "Ideographic"},
    133967: {"Unified_Ideograph", "Ideographic"},
    133968: {"Unified_Ideograph", "Ideographic"},
    133969: {"Unified_Ideograph", "Ideographic"},
    133970: {"Unified_Ideograph", "Ideographic"},
    133971: {"Unified_Ideograph", "Ideographic"},
    133972: {"Unified_Ideograph", "Ideographic"},
    133973: {"Unified_Ideograph", "Ideographic"},
    133974: {"Unified_Ideograph", "Ideographic"},
    133975: {"Unified_Ideograph", "Ideographic"},
    133976: {"Unified_Ideograph", "Ideographic"},
    133977: {"Unified_Ideograph", "Ideographic"},
    133978: {"Unified_Ideograph", "Ideographic"},
    133979: {"Unified_Ideograph", "Ideographic"},
    133980: {"Unified_Ideograph", "Ideographic"},
    133981: {"Unified_Ideograph", "Ideographic"},
    133982: {"Unified_Ideograph", "Ideographic"},
    133983: {"Unified_Ideograph", "Ideographic"},
    133984: {"Unified_Ideograph", "Ideographic"},
    133985: {"Unified_Ideograph", "Ideographic"},
    133986: {"Unified_Ideograph", "Ideographic"},
    133987: {"Unified_Ideograph", "Ideographic"},
    133988: {"Unified_Ideograph", "Ideographic"},
    133989: {"Unified_Ideograph", "Ideographic"},
    133990: {"Unified_Ideograph", "Ideographic"},
    133991: {"Unified_Ideograph", "Ideographic"},
    133992: {"Unified_Ideograph", "Ideographic"},
    133993: {"Unified_Ideograph", "Ideographic"},
    133994: {"Unified_Ideograph", "Ideographic"},
    133995: {"Unified_Ideograph", "Ideographic"},
    133996: {"Unified_Ideograph", "Ideographic"},
    133997: {"Unified_Ideograph", "Ideographic"},
    133998: {"Unified_Ideograph", "Ideographic"},
    133999: {"Unified_Ideograph", "Ideographic"},
    134000: {"Unified_Ideograph", "Ideographic"},
    134001: {"Unified_Ideograph", "Ideographic"},
    134002: {"Unified_Ideograph", "Ideographic"},
    134003: {"Unified_Ideograph", "Ideographic"},
    134004: {"Unified_Ideograph", "Ideographic"},
    134005: {"Unified_Ideograph", "Ideographic"},
    134006: {"Unified_Ideograph", "Ideographic"},
    134007: {"Unified_Ideograph", "Ideographic"},
    134008: {"Unified_Ideograph", "Ideographic"},
    134009: {"Unified_Ideograph", "Ideographic"},
    134010: {"Unified_Ideograph", "Ideographic"},
    134011: {"Unified_Ideograph", "Ideographic"},
    134012: {"Unified_Ideograph", "Ideographic"},
    134013: {"Unified_Ideograph", "Ideographic"},
    134014: {"Unified_Ideograph", "Ideographic"},
    134015: {"Unified_Ideograph", "Ideographic"},
    134016: {"Unified_Ideograph", "Ideographic"},
    134017: {"Unified_Ideograph", "Ideographic"},
    134018: {"Unified_Ideograph", "Ideographic"},
    134019: {"Unified_Ideograph", "Ideographic"},
    134020: {"Unified_Ideograph", "Ideographic"},
    134021: {"Unified_Ideograph", "Ideographic"},
    134022: {"Unified_Ideograph", "Ideographic"},
    134023: {"Unified_Ideograph", "Ideographic"},
    134024: {"Unified_Ideograph", "Ideographic"},
    134025: {"Unified_Ideograph", "Ideographic"},
    134026: {"Unified_Ideograph", "Ideographic"},
    134027: {"Unified_Ideograph", "Ideographic"},
    134028: {"Unified_Ideograph", "Ideographic"},
    134029: {"Unified_Ideograph", "Ideographic"},
    134030: {"Unified_Ideograph", "Ideographic"},
    134031: {"Unified_Ideograph", "Ideographic"},
    134032: {"Unified_Ideograph", "Ideographic"},
    134033: {"Unified_Ideograph", "Ideographic"},
    134034: {"Unified_Ideograph", "Ideographic"},
    134035: {"Unified_Ideograph", "Ideographic"},
    134036: {"Unified_Ideograph", "Ideographic"},
    134037: {"Unified_Ideograph", "Ideographic"},
    134038: {"Unified_Ideograph", "Ideographic"},
    134039: {"Unified_Ideograph", "Ideographic"},
    134040: {"Unified_Ideograph", "Ideographic"},
    134041: {"Unified_Ideograph", "Ideographic"},
    134042: {"Unified_Ideograph", "Ideographic"},
    134043: {"Unified_Ideograph", "Ideographic"},
    134044: {"Unified_Ideograph", "Ideographic"},
    134045: {"Unified_Ideograph", "Ideographic"},
    134046: {"Unified_Ideograph", "Ideographic"},
    134047: {"Unified_Ideograph", "Ideographic"},
    134048: {"Unified_Ideograph", "Ideographic"},
    134049: {"Unified_Ideograph", "Ideographic"},
    134050: {"Unified_Ideograph", "Ideographic"},
    134051: {"Unified_Ideograph", "Ideographic"},
    134052: {"Unified_Ideograph", "Ideographic"},
    134053: {"Unified_Ideograph", "Ideographic"},
    134054: {"Unified_Ideograph", "Ideographic"},
    134055: {"Unified_Ideograph", "Ideographic"},
    134056: {"Unified_Ideograph", "Ideographic"},
    134057: {"Unified_Ideograph", "Ideographic"},
    134058: {"Unified_Ideograph", "Ideographic"},
    134059: {"Unified_Ideograph", "Ideographic"},
    134060: {"Unified_Ideograph", "Ideographic"},
    134061: {"Unified_Ideograph", "Ideographic"},
    134062: {"Unified_Ideograph", "Ideographic"},
    134063: {"Unified_Ideograph", "Ideographic"},
    134064: {"Unified_Ideograph", "Ideographic"},
    134065: {"Unified_Ideograph", "Ideographic"},
    134066: {"Unified_Ideograph", "Ideographic"},
    134067: {"Unified_Ideograph", "Ideographic"},
    134068: {"Unified_Ideograph", "Ideographic"},
    134069: {"Unified_Ideograph", "Ideographic"},
    134070: {"Unified_Ideograph", "Ideographic"},
    134071: {"Unified_Ideograph", "Ideographic"},
    134072: {"Unified_Ideograph", "Ideographic"},
    134073: {"Unified_Ideograph", "Ideographic"},
    134074: {"Unified_Ideograph", "Ideographic"},
    134075: {"Unified_Ideograph", "Ideographic"},
    134076: {"Unified_Ideograph", "Ideographic"},
    134077: {"Unified_Ideograph", "Ideographic"},
    134078: {"Unified_Ideograph", "Ideographic"},
    134079: {"Unified_Ideograph", "Ideographic"},
    134080: {"Unified_Ideograph", "Ideographic"},
    134081: {"Unified_Ideograph", "Ideographic"},
    134082: {"Unified_Ideograph", "Ideographic"},
    134083: {"Unified_Ideograph", "Ideographic"},
    134084: {"Unified_Ideograph", "Ideographic"},
    134085: {"Unified_Ideograph", "Ideographic"},
    134086: {"Unified_Ideograph", "Ideographic"},
    134087: {"Unified_Ideograph", "Ideographic"},
    134088: {"Unified_Ideograph", "Ideographic"},
    134089: {"Unified_Ideograph", "Ideographic"},
    134090: {"Unified_Ideograph", "Ideographic"},
    134091: {"Unified_Ideograph", "Ideographic"},
    134092: {"Unified_Ideograph", "Ideographic"},
    134093: {"Unified_Ideograph", "Ideographic"},
    134094: {"Unified_Ideograph", "Ideographic"},
    134095: {"Unified_Ideograph", "Ideographic"},
    134096: {"Unified_Ideograph", "Ideographic"},
    134097: {"Unified_Ideograph", "Ideographic"},
    134098: {"Unified_Ideograph", "Ideographic"},
    134099: {"Unified_Ideograph", "Ideographic"},
    134100: {"Unified_Ideograph", "Ideographic"},
    134101: {"Unified_Ideograph", "Ideographic"},
    134102: {"Unified_Ideograph", "Ideographic"},
    134103: {"Unified_Ideograph", "Ideographic"},
    134104: {"Unified_Ideograph", "Ideographic"},
    134105: {"Unified_Ideograph", "Ideographic"},
    134106: {"Unified_Ideograph", "Ideographic"},
    134107: {"Unified_Ideograph", "Ideographic"},
    134108: {"Unified_Ideograph", "Ideographic"},
    134109: {"Unified_Ideograph", "Ideographic"},
    134110: {"Unified_Ideograph", "Ideographic"},
    134111: {"Unified_Ideograph", "Ideographic"},
    134112: {"Unified_Ideograph", "Ideographic"},
    134113: {"Unified_Ideograph", "Ideographic"},
    134114: {"Unified_Ideograph", "Ideographic"},
    134115: {"Unified_Ideograph", "Ideographic"},
    134116: {"Unified_Ideograph", "Ideographic"},
    134117: {"Unified_Ideograph", "Ideographic"},
    134118: {"Unified_Ideograph", "Ideographic"},
    134119: {"Unified_Ideograph", "Ideographic"},
    134120: {"Unified_Ideograph", "Ideographic"},
    134121: {"Unified_Ideograph", "Ideographic"},
    134122: {"Unified_Ideograph", "Ideographic"},
    134123: {"Unified_Ideograph", "Ideographic"},
    134124: {"Unified_Ideograph", "Ideographic"},
    134125: {"Unified_Ideograph", "Ideographic"},
    134126: {"Unified_Ideograph", "Ideographic"},
    134127: {"Unified_Ideograph", "Ideographic"},
    134128: {"Unified_Ideograph", "Ideographic"},
    134129: {"Unified_Ideograph", "Ideographic"},
    134130: {"Unified_Ideograph", "Ideographic"},
    134131: {"Unified_Ideograph", "Ideographic"},
    134132: {"Unified_Ideograph", "Ideographic"},
    134133: {"Unified_Ideograph", "Ideographic"},
    134134: {"Unified_Ideograph", "Ideographic"},
    134135: {"Unified_Ideograph", "Ideographic"},
    134136: {"Unified_Ideograph", "Ideographic"},
    134137: {"Unified_Ideograph", "Ideographic"},
    134138: {"Unified_Ideograph", "Ideographic"},
    134139: {"Unified_Ideograph", "Ideographic"},
    134140: {"Unified_Ideograph", "Ideographic"},
    134141: {"Unified_Ideograph", "Ideographic"},
    134142: {"Unified_Ideograph", "Ideographic"},
    134143: {"Unified_Ideograph", "Ideographic"},
    134144: {"Unified_Ideograph", "Ideographic"},
    134145: {"Unified_Ideograph", "Ideographic"},
    134146: {"Unified_Ideograph", "Ideographic"},
    134147: {"Unified_Ideograph", "Ideographic"},
    134148: {"Unified_Ideograph", "Ideographic"},
    134149: {"Unified_Ideograph", "Ideographic"},
    134150: {"Unified_Ideograph", "Ideographic"},
    134151: {"Unified_Ideograph", "Ideographic"},
    134152: {"Unified_Ideograph", "Ideographic"},
    134153: {"Unified_Ideograph", "Ideographic"},
    134154: {"Unified_Ideograph", "Ideographic"},
    134155: {"Unified_Ideograph", "Ideographic"},
    134156: {"Unified_Ideograph", "Ideographic"},
    134157: {"Unified_Ideograph", "Ideographic"},
    134158: {"Unified_Ideograph", "Ideographic"},
    134159: {"Unified_Ideograph", "Ideographic"},
    134160: {"Unified_Ideograph", "Ideographic"},
    134161: {"Unified_Ideograph", "Ideographic"},
    134162: {"Unified_Ideograph", "Ideographic"},
    134163: {"Unified_Ideograph", "Ideographic"},
    134164: {"Unified_Ideograph", "Ideographic"},
    134165: {"Unified_Ideograph", "Ideographic"},
    134166: {"Unified_Ideograph", "Ideographic"},
    134167: {"Unified_Ideograph", "Ideographic"},
    134168: {"Unified_Ideograph", "Ideographic"},
    134169: {"Unified_Ideograph", "Ideographic"},
    134170: {"Unified_Ideograph", "Ideographic"},
    134171: {"Unified_Ideograph", "Ideographic"},
    134172: {"Unified_Ideograph", "Ideographic"},
    134173: {"Unified_Ideograph", "Ideographic"},
    134174: {"Unified_Ideograph", "Ideographic"},
    134175: {"Unified_Ideograph", "Ideographic"},
    134176: {"Unified_Ideograph", "Ideographic"},
    134177: {"Unified_Ideograph", "Ideographic"},
    134178: {"Unified_Ideograph", "Ideographic"},
    134179: {"Unified_Ideograph", "Ideographic"},
    134180: {"Unified_Ideograph", "Ideographic"},
    134181: {"Unified_Ideograph", "Ideographic"},
    134182: {"Unified_Ideograph", "Ideographic"},
    134183: {"Unified_Ideograph", "Ideographic"},
    134184: {"Unified_Ideograph", "Ideographic"},
    134185: {"Unified_Ideograph", "Ideographic"},
    134186: {"Unified_Ideograph", "Ideographic"},
    134187: {"Unified_Ideograph", "Ideographic"},
    134188: {"Unified_Ideograph", "Ideographic"},
    134189: {"Unified_Ideograph", "Ideographic"},
    134190: {"Unified_Ideograph", "Ideographic"},
    134191: {"Unified_Ideograph", "Ideographic"},
    134192: {"Unified_Ideograph", "Ideographic"},
    134193: {"Unified_Ideograph", "Ideographic"},
    134194: {"Unified_Ideograph", "Ideographic"},
    134195: {"Unified_Ideograph", "Ideographic"},
    134196: {"Unified_Ideograph", "Ideographic"},
    134197: {"Unified_Ideograph", "Ideographic"},
    134198: {"Unified_Ideograph", "Ideographic"},
    134199: {"Unified_Ideograph", "Ideographic"},
    134200: {"Unified_Ideograph", "Ideographic"},
    134201: {"Unified_Ideograph", "Ideographic"},
    134202: {"Unified_Ideograph", "Ideographic"},
    134203: {"Unified_Ideograph", "Ideographic"},
    134204: {"Unified_Ideograph", "Ideographic"},
    134205: {"Unified_Ideograph", "Ideographic"},
    134206: {"Unified_Ideograph", "Ideographic"},
    134207: {"Unified_Ideograph", "Ideographic"},
    134208: {"Unified_Ideograph", "Ideographic"},
    134209: {"Unified_Ideograph", "Ideographic"},
    134210: {"Unified_Ideograph", "Ideographic"},
    134211: {"Unified_Ideograph", "Ideographic"},
    134212: {"Unified_Ideograph", "Ideographic"},
    134213: {"Unified_Ideograph", "Ideographic"},
    134214: {"Unified_Ideograph", "Ideographic"},
    134215: {"Unified_Ideograph", "Ideographic"},
    134216: {"Unified_Ideograph", "Ideographic"},
    134217: {"Unified_Ideograph", "Ideographic"},
    134218: {"Unified_Ideograph", "Ideographic"},
    134219: {"Unified_Ideograph", "Ideographic"},
    134220: {"Unified_Ideograph", "Ideographic"},
    134221: {"Unified_Ideograph", "Ideographic"},
    134222: {"Unified_Ideograph", "Ideographic"},
    134223: {"Unified_Ideograph", "Ideographic"},
    134224: {"Unified_Ideograph", "Ideographic"},
    134225: {"Unified_Ideograph", "Ideographic"},
    134226: {"Unified_Ideograph", "Ideographic"},
    134227: {"Unified_Ideograph", "Ideographic"},
    134228: {"Unified_Ideograph", "Ideographic"},
    134229: {"Unified_Ideograph", "Ideographic"},
    134230: {"Unified_Ideograph", "Ideographic"},
    134231: {"Unified_Ideograph", "Ideographic"},
    134232: {"Unified_Ideograph", "Ideographic"},
    134233: {"Unified_Ideograph", "Ideographic"},
    134234: {"Unified_Ideograph", "Ideographic"},
    134235: {"Unified_Ideograph", "Ideographic"},
    134236: {"Unified_Ideograph", "Ideographic"},
    134237: {"Unified_Ideograph", "Ideographic"},
    134238: {"Unified_Ideograph", "Ideographic"},
    134239: {"Unified_Ideograph", "Ideographic"},
    134240: {"Unified_Ideograph", "Ideographic"},
    134241: {"Unified_Ideograph", "Ideographic"},
    134242: {"Unified_Ideograph", "Ideographic"},
    134243: {"Unified_Ideograph", "Ideographic"},
    134244: {"Unified_Ideograph", "Ideographic"},
    134245: {"Unified_Ideograph", "Ideographic"},
    134246: {"Unified_Ideograph", "Ideographic"},
    134247: {"Unified_Ideograph", "Ideographic"},
    134248: {"Unified_Ideograph", "Ideographic"},
    134249: {"Unified_Ideograph", "Ideographic"},
    134250: {"Unified_Ideograph", "Ideographic"},
    134251: {"Unified_Ideograph", "Ideographic"},
    134252: {"Unified_Ideograph", "Ideographic"},
    134253: {"Unified_Ideograph", "Ideographic"},
    134254: {"Unified_Ideograph", "Ideographic"},
    134255: {"Unified_Ideograph", "Ideographic"},
    134256: {"Unified_Ideograph", "Ideographic"},
    134257: {"Unified_Ideograph", "Ideographic"},
    134258: {"Unified_Ideograph", "Ideographic"},
    134259: {"Unified_Ideograph", "Ideographic"},
    134260: {"Unified_Ideograph", "Ideographic"},
    134261: {"Unified_Ideograph", "Ideographic"},
    134262: {"Unified_Ideograph", "Ideographic"},
    134263: {"Unified_Ideograph", "Ideographic"},
    134264: {"Unified_Ideograph", "Ideographic"},
    134265: {"Unified_Ideograph", "Ideographic"},
    134266: {"Unified_Ideograph", "Ideographic"},
    134267: {"Unified_Ideograph", "Ideographic"},
    134268: {"Unified_Ideograph", "Ideographic"},
    134269: {"Unified_Ideograph", "Ideographic"},
    134270: {"Unified_Ideograph", "Ideographic"},
    134271: {"Unified_Ideograph", "Ideographic"},
    134272: {"Unified_Ideograph", "Ideographic"},
    134273: {"Unified_Ideograph", "Ideographic"},
    134274: {"Unified_Ideograph", "Ideographic"},
    134275: {"Unified_Ideograph", "Ideographic"},
    134276: {"Unified_Ideograph", "Ideographic"},
    134277: {"Unified_Ideograph", "Ideographic"},
    134278: {"Unified_Ideograph", "Ideographic"},
    134279: {"Unified_Ideograph", "Ideographic"},
    134280: {"Unified_Ideograph", "Ideographic"},
    134281: {"Unified_Ideograph", "Ideographic"},
    134282: {"Unified_Ideograph", "Ideographic"},
    134283: {"Unified_Ideograph", "Ideographic"},
    134284: {"Unified_Ideograph", "Ideographic"},
    134285: {"Unified_Ideograph", "Ideographic"},
    134286: {"Unified_Ideograph", "Ideographic"},
    134287: {"Unified_Ideograph", "Ideographic"},
    134288: {"Unified_Ideograph", "Ideographic"},
    134289: {"Unified_Ideograph", "Ideographic"},
    134290: {"Unified_Ideograph", "Ideographic"},
    134291: {"Unified_Ideograph", "Ideographic"},
    134292: {"Unified_Ideograph", "Ideographic"},
    134293: {"Unified_Ideograph", "Ideographic"},
    134294: {"Unified_Ideograph", "Ideographic"},
    134295: {"Unified_Ideograph", "Ideographic"},
    134296: {"Unified_Ideograph", "Ideographic"},
    134297: {"Unified_Ideograph", "Ideographic"},
    134298: {"Unified_Ideograph", "Ideographic"},
    134299: {"Unified_Ideograph", "Ideographic"},
    134300: {"Unified_Ideograph", "Ideographic"},
    134301: {"Unified_Ideograph", "Ideographic"},
    134302: {"Unified_Ideograph", "Ideographic"},
    134303: {"Unified_Ideograph", "Ideographic"},
    134304: {"Unified_Ideograph", "Ideographic"},
    134305: {"Unified_Ideograph", "Ideographic"},
    134306: {"Unified_Ideograph", "Ideographic"},
    134307: {"Unified_Ideograph", "Ideographic"},
    134308: {"Unified_Ideograph", "Ideographic"},
    134309: {"Unified_Ideograph", "Ideographic"},
    134310: {"Unified_Ideograph", "Ideographic"},
    134311: {"Unified_Ideograph", "Ideographic"},
    134312: {"Unified_Ideograph", "Ideographic"},
    134313: {"Unified_Ideograph", "Ideographic"},
    134314: {"Unified_Ideograph", "Ideographic"},
    134315: {"Unified_Ideograph", "Ideographic"},
    134316: {"Unified_Ideograph", "Ideographic"},
    134317: {"Unified_Ideograph", "Ideographic"},
    134318: {"Unified_Ideograph", "Ideographic"},
    134319: {"Unified_Ideograph", "Ideographic"},
    134320: {"Unified_Ideograph", "Ideographic"},
    134321: {"Unified_Ideograph", "Ideographic"},
    134322: {"Unified_Ideograph", "Ideographic"},
    134323: {"Unified_Ideograph", "Ideographic"},
    134324: {"Unified_Ideograph", "Ideographic"},
    134325: {"Unified_Ideograph", "Ideographic"},
    134326: {"Unified_Ideograph", "Ideographic"},
    134327: {"Unified_Ideograph", "Ideographic"},
    134328: {"Unified_Ideograph", "Ideographic"},
    134329: {"Unified_Ideograph", "Ideographic"},
    134330: {"Unified_Ideograph", "Ideographic"},
    134331: {"Unified_Ideograph", "Ideographic"},
    134332: {"Unified_Ideograph", "Ideographic"},
    134333: {"Unified_Ideograph", "Ideographic"},
    134334: {"Unified_Ideograph", "Ideographic"},
    134335: {"Unified_Ideograph", "Ideographic"},
    134336: {"Unified_Ideograph", "Ideographic"},
    134337: {"Unified_Ideograph", "Ideographic"},
    134338: {"Unified_Ideograph", "Ideographic"},
    134339: {"Unified_Ideograph", "Ideographic"},
    134340: {"Unified_Ideograph", "Ideographic"},
    134341: {"Unified_Ideograph", "Ideographic"},
    134342: {"Unified_Ideograph", "Ideographic"},
    134343: {"Unified_Ideograph", "Ideographic"},
    134344: {"Unified_Ideograph", "Ideographic"},
    134345: {"Unified_Ideograph", "Ideographic"},
    134346: {"Unified_Ideograph", "Ideographic"},
    134347: {"Unified_Ideograph", "Ideographic"},
    134348: {"Unified_Ideograph", "Ideographic"},
    134349: {"Unified_Ideograph", "Ideographic"},
    134350: {"Unified_Ideograph", "Ideographic"},
    134351: {"Unified_Ideograph", "Ideographic"},
    134352: {"Unified_Ideograph", "Ideographic"},
    134353: {"Unified_Ideograph", "Ideographic"},
    134354: {"Unified_Ideograph", "Ideographic"},
    134355: {"Unified_Ideograph", "Ideographic"},
    134356: {"Unified_Ideograph", "Ideographic"},
    134357: {"Unified_Ideograph", "Ideographic"},
    134358: {"Unified_Ideograph", "Ideographic"},
    134359: {"Unified_Ideograph", "Ideographic"},
    134360: {"Unified_Ideograph", "Ideographic"},
    134361: {"Unified_Ideograph", "Ideographic"},
    134362: {"Unified_Ideograph", "Ideographic"},
    134363: {"Unified_Ideograph", "Ideographic"},
    134364: {"Unified_Ideograph", "Ideographic"},
    134365: {"Unified_Ideograph", "Ideographic"},
    134366: {"Unified_Ideograph", "Ideographic"},
    134367: {"Unified_Ideograph", "Ideographic"},
    134368: {"Unified_Ideograph", "Ideographic"},
    134369: {"Unified_Ideograph", "Ideographic"},
    134370: {"Unified_Ideograph", "Ideographic"},
    134371: {"Unified_Ideograph", "Ideographic"},
    134372: {"Unified_Ideograph", "Ideographic"},
    134373: {"Unified_Ideograph", "Ideographic"},
    134374: {"Unified_Ideograph", "Ideographic"},
    134375: {"Unified_Ideograph", "Ideographic"},
    134376: {"Unified_Ideograph", "Ideographic"},
    134377: {"Unified_Ideograph", "Ideographic"},
    134378: {"Unified_Ideograph", "Ideographic"},
    134379: {"Unified_Ideograph", "Ideographic"},
    134380: {"Unified_Ideograph", "Ideographic"},
    134381: {"Unified_Ideograph", "Ideographic"},
    134382: {"Unified_Ideograph", "Ideographic"},
    134383: {"Unified_Ideograph", "Ideographic"},
    134384: {"Unified_Ideograph", "Ideographic"},
    134385: {"Unified_Ideograph", "Ideographic"},
    134386: {"Unified_Ideograph", "Ideographic"},
    134387: {"Unified_Ideograph", "Ideographic"},
    134388: {"Unified_Ideograph", "Ideographic"},
    134389: {"Unified_Ideograph", "Ideographic"},
    134390: {"Unified_Ideograph", "Ideographic"},
    134391: {"Unified_Ideograph", "Ideographic"},
    134392: {"Unified_Ideograph", "Ideographic"},
    134393: {"Unified_Ideograph", "Ideographic"},
    134394: {"Unified_Ideograph", "Ideographic"},
    134395: {"Unified_Ideograph", "Ideographic"},
    134396: {"Unified_Ideograph", "Ideographic"},
    134397: {"Unified_Ideograph", "Ideographic"},
    134398: {"Unified_Ideograph", "Ideographic"},
    134399: {"Unified_Ideograph", "Ideographic"},
    134400: {"Unified_Ideograph", "Ideographic"},
    134401: {"Unified_Ideograph", "Ideographic"},
    134402: {"Unified_Ideograph", "Ideographic"},
    134403: {"Unified_Ideograph", "Ideographic"},
    134404: {"Unified_Ideograph", "Ideographic"},
    134405: {"Unified_Ideograph", "Ideographic"},
    134406: {"Unified_Ideograph", "Ideographic"},
    134407: {"Unified_Ideograph", "Ideographic"},
    134408: {"Unified_Ideograph", "Ideographic"},
    134409: {"Unified_Ideograph", "Ideographic"},
    134410: {"Unified_Ideograph", "Ideographic"},
    134411: {"Unified_Ideograph", "Ideographic"},
    134412: {"Unified_Ideograph", "Ideographic"},
    134413: {"Unified_Ideograph", "Ideographic"},
    134414: {"Unified_Ideograph", "Ideographic"},
    134415: {"Unified_Ideograph", "Ideographic"},
    134416: {"Unified_Ideograph", "Ideographic"},
    134417: {"Unified_Ideograph", "Ideographic"},
    134418: {"Unified_Ideograph", "Ideographic"},
    134419: {"Unified_Ideograph", "Ideographic"},
    134420: {"Unified_Ideograph", "Ideographic"},
    134421: {"Unified_Ideograph", "Ideographic"},
    134422: {"Unified_Ideograph", "Ideographic"},
    134423: {"Unified_Ideograph", "Ideographic"},
    134424: {"Unified_Ideograph", "Ideographic"},
    134425: {"Unified_Ideograph", "Ideographic"},
    134426: {"Unified_Ideograph", "Ideographic"},
    134427: {"Unified_Ideograph", "Ideographic"},
    134428: {"Unified_Ideograph", "Ideographic"},
    134429: {"Unified_Ideograph", "Ideographic"},
    134430: {"Unified_Ideograph", "Ideographic"},
    134431: {"Unified_Ideograph", "Ideographic"},
    134432: {"Unified_Ideograph", "Ideographic"},
    134433: {"Unified_Ideograph", "Ideographic"},
    134434: {"Unified_Ideograph", "Ideographic"},
    134435: {"Unified_Ideograph", "Ideographic"},
    134436: {"Unified_Ideograph", "Ideographic"},
    134437: {"Unified_Ideograph", "Ideographic"},
    134438: {"Unified_Ideograph", "Ideographic"},
    134439: {"Unified_Ideograph", "Ideographic"},
    134440: {"Unified_Ideograph", "Ideographic"},
    134441: {"Unified_Ideograph", "Ideographic"},
    134442: {"Unified_Ideograph", "Ideographic"},
    134443: {"Unified_Ideograph", "Ideographic"},
    134444: {"Unified_Ideograph", "Ideographic"},
    134445: {"Unified_Ideograph", "Ideographic"},
    134446: {"Unified_Ideograph", "Ideographic"},
    134447: {"Unified_Ideograph", "Ideographic"},
    134448: {"Unified_Ideograph", "Ideographic"},
    134449: {"Unified_Ideograph", "Ideographic"},
    134450: {"Unified_Ideograph", "Ideographic"},
    134451: {"Unified_Ideograph", "Ideographic"},
    134452: {"Unified_Ideograph", "Ideographic"},
    134453: {"Unified_Ideograph", "Ideographic"},
    134454: {"Unified_Ideograph", "Ideographic"},
    134455: {"Unified_Ideograph", "Ideographic"},
    134456: {"Unified_Ideograph", "Ideographic"},
    134457: {"Unified_Ideograph", "Ideographic"},
    134458: {"Unified_Ideograph", "Ideographic"},
    134459: {"Unified_Ideograph", "Ideographic"},
    134460: {"Unified_Ideograph", "Ideographic"},
    134461: {"Unified_Ideograph", "Ideographic"},
    134462: {"Unified_Ideograph", "Ideographic"},
    134463: {"Unified_Ideograph", "Ideographic"},
    134464: {"Unified_Ideograph", "Ideographic"},
    134465: {"Unified_Ideograph", "Ideographic"},
    134466: {"Unified_Ideograph", "Ideographic"},
    134467: {"Unified_Ideograph", "Ideographic"},
    134468: {"Unified_Ideograph", "Ideographic"},
    134469: {"Unified_Ideograph", "Ideographic"},
    134470: {"Unified_Ideograph", "Ideographic"},
    134471: {"Unified_Ideograph", "Ideographic"},
    134472: {"Unified_Ideograph", "Ideographic"},
    134473: {"Unified_Ideograph", "Ideographic"},
    134474: {"Unified_Ideograph", "Ideographic"},
    134475: {"Unified_Ideograph", "Ideographic"},
    134476: {"Unified_Ideograph", "Ideographic"},
    134477: {"Unified_Ideograph", "Ideographic"},
    134478: {"Unified_Ideograph", "Ideographic"},
    134479: {"Unified_Ideograph", "Ideographic"},
    134480: {"Unified_Ideograph", "Ideographic"},
    134481: {"Unified_Ideograph", "Ideographic"},
    134482: {"Unified_Ideograph", "Ideographic"},
    134483: {"Unified_Ideograph", "Ideographic"},
    134484: {"Unified_Ideograph", "Ideographic"},
    134485: {"Unified_Ideograph", "Ideographic"},
    134486: {"Unified_Ideograph", "Ideographic"},
    134487: {"Unified_Ideograph", "Ideographic"},
    134488: {"Unified_Ideograph", "Ideographic"},
    134489: {"Unified_Ideograph", "Ideographic"},
    134490: {"Unified_Ideograph", "Ideographic"},
    134491: {"Unified_Ideograph", "Ideographic"},
    134492: {"Unified_Ideograph", "Ideographic"},
    134493: {"Unified_Ideograph", "Ideographic"},
    134494: {"Unified_Ideograph", "Ideographic"},
    134495: {"Unified_Ideograph", "Ideographic"},
    134496: {"Unified_Ideograph", "Ideographic"},
    134497: {"Unified_Ideograph", "Ideographic"},
    134498: {"Unified_Ideograph", "Ideographic"},
    134499: {"Unified_Ideograph", "Ideographic"},
    134500: {"Unified_Ideograph", "Ideographic"},
    134501: {"Unified_Ideograph", "Ideographic"},
    134502: {"Unified_Ideograph", "Ideographic"},
    134503: {"Unified_Ideograph", "Ideographic"},
    134504: {"Unified_Ideograph", "Ideographic"},
    134505: {"Unified_Ideograph", "Ideographic"},
    134506: {"Unified_Ideograph", "Ideographic"},
    134507: {"Unified_Ideograph", "Ideographic"},
    134508: {"Unified_Ideograph", "Ideographic"},
    134509: {"Unified_Ideograph", "Ideographic"},
    134510: {"Unified_Ideograph", "Ideographic"},
    134511: {"Unified_Ideograph", "Ideographic"},
    134512: {"Unified_Ideograph", "Ideographic"},
    134513: {"Unified_Ideograph", "Ideographic"},
    134514: {"Unified_Ideograph", "Ideographic"},
    134515: {"Unified_Ideograph", "Ideographic"},
    134516: {"Unified_Ideograph", "Ideographic"},
    134517: {"Unified_Ideograph", "Ideographic"},
    134518: {"Unified_Ideograph", "Ideographic"},
    134519: {"Unified_Ideograph", "Ideographic"},
    134520: {"Unified_Ideograph", "Ideographic"},
    134521: {"Unified_Ideograph", "Ideographic"},
    134522: {"Unified_Ideograph", "Ideographic"},
    134523: {"Unified_Ideograph", "Ideographic"},
    134524: {"Unified_Ideograph", "Ideographic"},
    134525: {"Unified_Ideograph", "Ideographic"},
    134526: {"Unified_Ideograph", "Ideographic"},
    134527: {"Unified_Ideograph", "Ideographic"},
    134528: {"Unified_Ideograph", "Ideographic"},
    134529: {"Unified_Ideograph", "Ideographic"},
    134530: {"Unified_Ideograph", "Ideographic"},
    134531: {"Unified_Ideograph", "Ideographic"},
    134532: {"Unified_Ideograph", "Ideographic"},
    134533: {"Unified_Ideograph", "Ideographic"},
    134534: {"Unified_Ideograph", "Ideographic"},
    134535: {"Unified_Ideograph", "Ideographic"},
    134536: {"Unified_Ideograph", "Ideographic"},
    134537: {"Unified_Ideograph", "Ideographic"},
    134538: {"Unified_Ideograph", "Ideographic"},
    134539: {"Unified_Ideograph", "Ideographic"},
    134540: {"Unified_Ideograph", "Ideographic"},
    134541: {"Unified_Ideograph", "Ideographic"},
    134542: {"Unified_Ideograph", "Ideographic"},
    134543: {"Unified_Ideograph", "Ideographic"},
    134544: {"Unified_Ideograph", "Ideographic"},
    134545: {"Unified_Ideograph", "Ideographic"},
    134546: {"Unified_Ideograph", "Ideographic"},
    134547: {"Unified_Ideograph", "Ideographic"},
    134548: {"Unified_Ideograph", "Ideographic"},
    134549: {"Unified_Ideograph", "Ideographic"},
    134550: {"Unified_Ideograph", "Ideographic"},
    134551: {"Unified_Ideograph", "Ideographic"},
    134552: {"Unified_Ideograph", "Ideographic"},
    134553: {"Unified_Ideograph", "Ideographic"},
    134554: {"Unified_Ideograph", "Ideographic"},
    134555: {"Unified_Ideograph", "Ideographic"},
    134556: {"Unified_Ideograph", "Ideographic"},
    134557: {"Unified_Ideograph", "Ideographic"},
    134558: {"Unified_Ideograph", "Ideographic"},
    134559: {"Unified_Ideograph", "Ideographic"},
    134560: {"Unified_Ideograph", "Ideographic"},
    134561: {"Unified_Ideograph", "Ideographic"},
    134562: {"Unified_Ideograph", "Ideographic"},
    134563: {"Unified_Ideograph", "Ideographic"},
    134564: {"Unified_Ideograph", "Ideographic"},
    134565: {"Unified_Ideograph", "Ideographic"},
    134566: {"Unified_Ideograph", "Ideographic"},
    134567: {"Unified_Ideograph", "Ideographic"},
    134568: {"Unified_Ideograph", "Ideographic"},
    134569: {"Unified_Ideograph", "Ideographic"},
    134570: {"Unified_Ideograph", "Ideographic"},
    134571: {"Unified_Ideograph", "Ideographic"},
    134572: {"Unified_Ideograph", "Ideographic"},
    134573: {"Unified_Ideograph", "Ideographic"},
    134574: {"Unified_Ideograph", "Ideographic"},
    134575: {"Unified_Ideograph", "Ideographic"},
    134576: {"Unified_Ideograph", "Ideographic"},
    134577: {"Unified_Ideograph", "Ideographic"},
    134578: {"Unified_Ideograph", "Ideographic"},
    134579: {"Unified_Ideograph", "Ideographic"},
    134580: {"Unified_Ideograph", "Ideographic"},
    134581: {"Unified_Ideograph", "Ideographic"},
    134582: {"Unified_Ideograph", "Ideographic"},
    134583: {"Unified_Ideograph", "Ideographic"},
    134584: {"Unified_Ideograph", "Ideographic"},
    134585: {"Unified_Ideograph", "Ideographic"},
    134586: {"Unified_Ideograph", "Ideographic"},
    134587: {"Unified_Ideograph", "Ideographic"},
    134588: {"Unified_Ideograph", "Ideographic"},
    134589: {"Unified_Ideograph", "Ideographic"},
    134590: {"Unified_Ideograph", "Ideographic"},
    134591: {"Unified_Ideograph", "Ideographic"},
    134592: {"Unified_Ideograph", "Ideographic"},
    134593: {"Unified_Ideograph", "Ideographic"},
    134594: {"Unified_Ideograph", "Ideographic"},
    134595: {"Unified_Ideograph", "Ideographic"},
    134596: {"Unified_Ideograph", "Ideographic"},
    134597: {"Unified_Ideograph", "Ideographic"},
    134598: {"Unified_Ideograph", "Ideographic"},
    134599: {"Unified_Ideograph", "Ideographic"},
    134600: {"Unified_Ideograph", "Ideographic"},
    134601: {"Unified_Ideograph", "Ideographic"},
    134602: {"Unified_Ideograph", "Ideographic"},
    134603: {"Unified_Ideograph", "Ideographic"},
    134604: {"Unified_Ideograph", "Ideographic"},
    134605: {"Unified_Ideograph", "Ideographic"},
    134606: {"Unified_Ideograph", "Ideographic"},
    134607: {"Unified_Ideograph", "Ideographic"},
    134608: {"Unified_Ideograph", "Ideographic"},
    134609: {"Unified_Ideograph", "Ideographic"},
    134610: {"Unified_Ideograph", "Ideographic"},
    134611: {"Unified_Ideograph", "Ideographic"},
    134612: {"Unified_Ideograph", "Ideographic"},
    134613: {"Unified_Ideograph", "Ideographic"},
    134614: {"Unified_Ideograph", "Ideographic"},
    134615: {"Unified_Ideograph", "Ideographic"},
    134616: {"Unified_Ideograph", "Ideographic"},
    134617: {"Unified_Ideograph", "Ideographic"},
    134618: {"Unified_Ideograph", "Ideographic"},
    134619: {"Unified_Ideograph", "Ideographic"},
    134620: {"Unified_Ideograph", "Ideographic"},
    134621: {"Unified_Ideograph", "Ideographic"},
    134622: {"Unified_Ideograph", "Ideographic"},
    134623: {"Unified_Ideograph", "Ideographic"},
    134624: {"Unified_Ideograph", "Ideographic"},
    134625: {"Unified_Ideograph", "Ideographic"},
    134626: {"Unified_Ideograph", "Ideographic"},
    134627: {"Unified_Ideograph", "Ideographic"},
    134628: {"Unified_Ideograph", "Ideographic"},
    134629: {"Unified_Ideograph", "Ideographic"},
    134630: {"Unified_Ideograph", "Ideographic"},
    134631: {"Unified_Ideograph", "Ideographic"},
    134632: {"Unified_Ideograph", "Ideographic"},
    134633: {"Unified_Ideograph", "Ideographic"},
    134634: {"Unified_Ideograph", "Ideographic"},
    134635: {"Unified_Ideograph", "Ideographic"},
    134636: {"Unified_Ideograph", "Ideographic"},
    134637: {"Unified_Ideograph", "Ideographic"},
    134638: {"Unified_Ideograph", "Ideographic"},
    134639: {"Unified_Ideograph", "Ideographic"},
    134640: {"Unified_Ideograph", "Ideographic"},
    134641: {"Unified_Ideograph", "Ideographic"},
    134642: {"Unified_Ideograph", "Ideographic"},
    134643: {"Unified_Ideograph", "Ideographic"},
    134644: {"Unified_Ideograph", "Ideographic"},
    134645: {"Unified_Ideograph", "Ideographic"},
    134646: {"Unified_Ideograph", "Ideographic"},
    134647: {"Unified_Ideograph", "Ideographic"},
    134648: {"Unified_Ideograph", "Ideographic"},
    134649: {"Unified_Ideograph", "Ideographic"},
    134650: {"Unified_Ideograph", "Ideographic"},
    134651: {"Unified_Ideograph", "Ideographic"},
    134652: {"Unified_Ideograph", "Ideographic"},
    134653: {"Unified_Ideograph", "Ideographic"},
    134654: {"Unified_Ideograph", "Ideographic"},
    134655: {"Unified_Ideograph", "Ideographic"},
    134656: {"Unified_Ideograph", "Ideographic"},
    134657: {"Unified_Ideograph", "Ideographic"},
    134658: {"Unified_Ideograph", "Ideographic"},
    134659: {"Unified_Ideograph", "Ideographic"},
    134660: {"Unified_Ideograph", "Ideographic"},
    134661: {"Unified_Ideograph", "Ideographic"},
    134662: {"Unified_Ideograph", "Ideographic"},
    134663: {"Unified_Ideograph", "Ideographic"},
    134664: {"Unified_Ideograph", "Ideographic"},
    134665: {"Unified_Ideograph", "Ideographic"},
    134666: {"Unified_Ideograph", "Ideographic"},
    134667: {"Unified_Ideograph", "Ideographic"},
    134668: {"Unified_Ideograph", "Ideographic"},
    134669: {"Unified_Ideograph", "Ideographic"},
    134670: {"Unified_Ideograph", "Ideographic"},
    134671: {"Unified_Ideograph", "Ideographic"},
    134672: {"Unified_Ideograph", "Ideographic"},
    134673: {"Unified_Ideograph", "Ideographic"},
    134674: {"Unified_Ideograph", "Ideographic"},
    134675: {"Unified_Ideograph", "Ideographic"},
    134676: {"Unified_Ideograph", "Ideographic"},
    134677: {"Unified_Ideograph", "Ideographic"},
    134678: {"Unified_Ideograph", "Ideographic"},
    134679: {"Unified_Ideograph", "Ideographic"},
    134680: {"Unified_Ideograph", "Ideographic"},
    134681: {"Unified_Ideograph", "Ideographic"},
    134682: {"Unified_Ideograph", "Ideographic"},
    134683: {"Unified_Ideograph", "Ideographic"},
    134684: {"Unified_Ideograph", "Ideographic"},
    134685: {"Unified_Ideograph", "Ideographic"},
    134686: {"Unified_Ideograph", "Ideographic"},
    134687: {"Unified_Ideograph", "Ideographic"},
    134688: {"Unified_Ideograph", "Ideographic"},
    134689: {"Unified_Ideograph", "Ideographic"},
    134690: {"Unified_Ideograph", "Ideographic"},
    134691: {"Unified_Ideograph", "Ideographic"},
    134692: {"Unified_Ideograph", "Ideographic"},
    134693: {"Unified_Ideograph", "Ideographic"},
    134694: {"Unified_Ideograph", "Ideographic"},
    134695: {"Unified_Ideograph", "Ideographic"},
    134696: {"Unified_Ideograph", "Ideographic"},
    134697: {"Unified_Ideograph", "Ideographic"},
    134698: {"Unified_Ideograph", "Ideographic"},
    134699: {"Unified_Ideograph", "Ideographic"},
    134700: {"Unified_Ideograph", "Ideographic"},
    134701: {"Unified_Ideograph", "Ideographic"},
    134702: {"Unified_Ideograph", "Ideographic"},
    134703: {"Unified_Ideograph", "Ideographic"},
    134704: {"Unified_Ideograph", "Ideographic"},
    134705: {"Unified_Ideograph", "Ideographic"},
    134706: {"Unified_Ideograph", "Ideographic"},
    134707: {"Unified_Ideograph", "Ideographic"},
    134708: {"Unified_Ideograph", "Ideographic"},
    134709: {"Unified_Ideograph", "Ideographic"},
    134710: {"Unified_Ideograph", "Ideographic"},
    134711: {"Unified_Ideograph", "Ideographic"},
    134712: {"Unified_Ideograph", "Ideographic"},
    134713: {"Unified_Ideograph", "Ideographic"},
    134714: {"Unified_Ideograph", "Ideographic"},
    134715: {"Unified_Ideograph", "Ideographic"},
    134716: {"Unified_Ideograph", "Ideographic"},
    134717: {"Unified_Ideograph", "Ideographic"},
    134718: {"Unified_Ideograph", "Ideographic"},
    134719: {"Unified_Ideograph", "Ideographic"},
    134720: {"Unified_Ideograph", "Ideographic"},
    134721: {"Unified_Ideograph", "Ideographic"},
    134722: {"Unified_Ideograph", "Ideographic"},
    134723: {"Unified_Ideograph", "Ideographic"},
    134724: {"Unified_Ideograph", "Ideographic"},
    134725: {"Unified_Ideograph", "Ideographic"},
    134726: {"Unified_Ideograph", "Ideographic"},
    134727: {"Unified_Ideograph", "Ideographic"},
    134728: {"Unified_Ideograph", "Ideographic"},
    134729: {"Unified_Ideograph", "Ideographic"},
    134730: {"Unified_Ideograph", "Ideographic"},
    134731: {"Unified_Ideograph", "Ideographic"},
    134732: {"Unified_Ideograph", "Ideographic"},
    134733: {"Unified_Ideograph", "Ideographic"},
    134734: {"Unified_Ideograph", "Ideographic"},
    134735: {"Unified_Ideograph", "Ideographic"},
    134736: {"Unified_Ideograph", "Ideographic"},
    134737: {"Unified_Ideograph", "Ideographic"},
    134738: {"Unified_Ideograph", "Ideographic"},
    134739: {"Unified_Ideograph", "Ideographic"},
    134740: {"Unified_Ideograph", "Ideographic"},
    134741: {"Unified_Ideograph", "Ideographic"},
    134742: {"Unified_Ideograph", "Ideographic"},
    134743: {"Unified_Ideograph", "Ideographic"},
    134744: {"Unified_Ideograph", "Ideographic"},
    134745: {"Unified_Ideograph", "Ideographic"},
    134746: {"Unified_Ideograph", "Ideographic"},
    134747: {"Unified_Ideograph", "Ideographic"},
    134748: {"Unified_Ideograph", "Ideographic"},
    134749: {"Unified_Ideograph", "Ideographic"},
    134750: {"Unified_Ideograph", "Ideographic"},
    134751: {"Unified_Ideograph", "Ideographic"},
    134752: {"Unified_Ideograph", "Ideographic"},
    134753: {"Unified_Ideograph", "Ideographic"},
    134754: {"Unified_Ideograph", "Ideographic"},
    134755: {"Unified_Ideograph", "Ideographic"},
    134756: {"Unified_Ideograph", "Ideographic"},
    134757: {"Unified_Ideograph", "Ideographic"},
    134758: {"Unified_Ideograph", "Ideographic"},
    134759: {"Unified_Ideograph", "Ideographic"},
    134760: {"Unified_Ideograph", "Ideographic"},
    134761: {"Unified_Ideograph", "Ideographic"},
    134762: {"Unified_Ideograph", "Ideographic"},
    134763: {"Unified_Ideograph", "Ideographic"},
    134764: {"Unified_Ideograph", "Ideographic"},
    134765: {"Unified_Ideograph", "Ideographic"},
    134766: {"Unified_Ideograph", "Ideographic"},
    134767: {"Unified_Ideograph", "Ideographic"},
    134768: {"Unified_Ideograph", "Ideographic"},
    134769: {"Unified_Ideograph", "Ideographic"},
    134770: {"Unified_Ideograph", "Ideographic"},
    134771: {"Unified_Ideograph", "Ideographic"},
    134772: {"Unified_Ideograph", "Ideographic"},
    134773: {"Unified_Ideograph", "Ideographic"},
    134774: {"Unified_Ideograph", "Ideographic"},
    134775: {"Unified_Ideograph", "Ideographic"},
    134776: {"Unified_Ideograph", "Ideographic"},
    134777: {"Unified_Ideograph", "Ideographic"},
    134778: {"Unified_Ideograph", "Ideographic"},
    134779: {"Unified_Ideograph", "Ideographic"},
    134780: {"Unified_Ideograph", "Ideographic"},
    134781: {"Unified_Ideograph", "Ideographic"},
    134782: {"Unified_Ideograph", "Ideographic"},
    134783: {"Unified_Ideograph", "Ideographic"},
    134784: {"Unified_Ideograph", "Ideographic"},
    134785: {"Unified_Ideograph", "Ideographic"},
    134786: {"Unified_Ideograph", "Ideographic"},
    134787: {"Unified_Ideograph", "Ideographic"},
    134788: {"Unified_Ideograph", "Ideographic"},
    134789: {"Unified_Ideograph", "Ideographic"},
    134790: {"Unified_Ideograph", "Ideographic"},
    134791: {"Unified_Ideograph", "Ideographic"},
    134792: {"Unified_Ideograph", "Ideographic"},
    134793: {"Unified_Ideograph", "Ideographic"},
    134794: {"Unified_Ideograph", "Ideographic"},
    134795: {"Unified_Ideograph", "Ideographic"},
    134796: {"Unified_Ideograph", "Ideographic"},
    134797: {"Unified_Ideograph", "Ideographic"},
    134798: {"Unified_Ideograph", "Ideographic"},
    134799: {"Unified_Ideograph", "Ideographic"},
    134800: {"Unified_Ideograph", "Ideographic"},
    134801: {"Unified_Ideograph", "Ideographic"},
    134802: {"Unified_Ideograph", "Ideographic"},
    134803: {"Unified_Ideograph", "Ideographic"},
    134804: {"Unified_Ideograph", "Ideographic"},
    134805: {"Unified_Ideograph", "Ideographic"},
    134806: {"Unified_Ideograph", "Ideographic"},
    134807: {"Unified_Ideograph", "Ideographic"},
    134808: {"Unified_Ideograph", "Ideographic"},
    134809: {"Unified_Ideograph", "Ideographic"},
    134810: {"Unified_Ideograph", "Ideographic"},
    134811: {"Unified_Ideograph", "Ideographic"},
    134812: {"Unified_Ideograph", "Ideographic"},
    134813: {"Unified_Ideograph", "Ideographic"},
    134814: {"Unified_Ideograph", "Ideographic"},
    134815: {"Unified_Ideograph", "Ideographic"},
    134816: {"Unified_Ideograph", "Ideographic"},
    134817: {"Unified_Ideograph", "Ideographic"},
    134818: {"Unified_Ideograph", "Ideographic"},
    134819: {"Unified_Ideograph", "Ideographic"},
    134820: {"Unified_Ideograph", "Ideographic"},
    134821: {"Unified_Ideograph", "Ideographic"},
    134822: {"Unified_Ideograph", "Ideographic"},
    134823: {"Unified_Ideograph", "Ideographic"},
    134824: {"Unified_Ideograph", "Ideographic"},
    134825: {"Unified_Ideograph", "Ideographic"},
    134826: {"Unified_Ideograph", "Ideographic"},
    134827: {"Unified_Ideograph", "Ideographic"},
    134828: {"Unified_Ideograph", "Ideographic"},
    134829: {"Unified_Ideograph", "Ideographic"},
    134830: {"Unified_Ideograph", "Ideographic"},
    134831: {"Unified_Ideograph", "Ideographic"},
    134832: {"Unified_Ideograph", "Ideographic"},
    134833: {"Unified_Ideograph", "Ideographic"},
    134834: {"Unified_Ideograph", "Ideographic"},
    134835: {"Unified_Ideograph", "Ideographic"},
    134836: {"Unified_Ideograph", "Ideographic"},
    134837: {"Unified_Ideograph", "Ideographic"},
    134838: {"Unified_Ideograph", "Ideographic"},
    134839: {"Unified_Ideograph", "Ideographic"},
    134840: {"Unified_Ideograph", "Ideographic"},
    134841: {"Unified_Ideograph", "Ideographic"},
    134842: {"Unified_Ideograph", "Ideographic"},
    134843: {"Unified_Ideograph", "Ideographic"},
    134844: {"Unified_Ideograph", "Ideographic"},
    134845: {"Unified_Ideograph", "Ideographic"},
    134846: {"Unified_Ideograph", "Ideographic"},
    134847: {"Unified_Ideograph", "Ideographic"},
    134848: {"Unified_Ideograph", "Ideographic"},
    134849: {"Unified_Ideograph", "Ideographic"},
    134850: {"Unified_Ideograph", "Ideographic"},
    134851: {"Unified_Ideograph", "Ideographic"},
    134852: {"Unified_Ideograph", "Ideographic"},
    134853: {"Unified_Ideograph", "Ideographic"},
    134854: {"Unified_Ideograph", "Ideographic"},
    134855: {"Unified_Ideograph", "Ideographic"},
    134856: {"Unified_Ideograph", "Ideographic"},
    134857: {"Unified_Ideograph", "Ideographic"},
    134858: {"Unified_Ideograph", "Ideographic"},
    134859: {"Unified_Ideograph", "Ideographic"},
    134860: {"Unified_Ideograph", "Ideographic"},
    134861: {"Unified_Ideograph", "Ideographic"},
    134862: {"Unified_Ideograph", "Ideographic"},
    134863: {"Unified_Ideograph", "Ideographic"},
    134864: {"Unified_Ideograph", "Ideographic"},
    134865: {"Unified_Ideograph", "Ideographic"},
    134866: {"Unified_Ideograph", "Ideographic"},
    134867: {"Unified_Ideograph", "Ideographic"},
    134868: {"Unified_Ideograph", "Ideographic"},
    134869: {"Unified_Ideograph", "Ideographic"},
    134870: {"Unified_Ideograph", "Ideographic"},
    134871: {"Unified_Ideograph", "Ideographic"},
    134872: {"Unified_Ideograph", "Ideographic"},
    134873: {"Unified_Ideograph", "Ideographic"},
    134874: {"Unified_Ideograph", "Ideographic"},
    134875: {"Unified_Ideograph", "Ideographic"},
    134876: {"Unified_Ideograph", "Ideographic"},
    134877: {"Unified_Ideograph", "Ideographic"},
    134878: {"Unified_Ideograph", "Ideographic"},
    134879: {"Unified_Ideograph", "Ideographic"},
    134880: {"Unified_Ideograph", "Ideographic"},
    134881: {"Unified_Ideograph", "Ideographic"},
    134882: {"Unified_Ideograph", "Ideographic"},
    134883: {"Unified_Ideograph", "Ideographic"},
    134884: {"Unified_Ideograph", "Ideographic"},
    134885: {"Unified_Ideograph", "Ideographic"},
    134886: {"Unified_Ideograph", "Ideographic"},
    134887: {"Unified_Ideograph", "Ideographic"},
    134888: {"Unified_Ideograph", "Ideographic"},
    134889: {"Unified_Ideograph", "Ideographic"},
    134890: {"Unified_Ideograph", "Ideographic"},
    134891: {"Unified_Ideograph", "Ideographic"},
    134892: {"Unified_Ideograph", "Ideographic"},
    134893: {"Unified_Ideograph", "Ideographic"},
    134894: {"Unified_Ideograph", "Ideographic"},
    134895: {"Unified_Ideograph", "Ideographic"},
    134896: {"Unified_Ideograph", "Ideographic"},
    134897: {"Unified_Ideograph", "Ideographic"},
    134898: {"Unified_Ideograph", "Ideographic"},
    134899: {"Unified_Ideograph", "Ideographic"},
    134900: {"Unified_Ideograph", "Ideographic"},
    134901: {"Unified_Ideograph", "Ideographic"},
    134902: {"Unified_Ideograph", "Ideographic"},
    134903: {"Unified_Ideograph", "Ideographic"},
    134904: {"Unified_Ideograph", "Ideographic"},
    134905: {"Unified_Ideograph", "Ideographic"},
    134906: {"Unified_Ideograph", "Ideographic"},
    134907: {"Unified_Ideograph", "Ideographic"},
    134908: {"Unified_Ideograph", "Ideographic"},
    134909: {"Unified_Ideograph", "Ideographic"},
    134910: {"Unified_Ideograph", "Ideographic"},
    134911: {"Unified_Ideograph", "Ideographic"},
    134912: {"Unified_Ideograph", "Ideographic"},
    134913: {"Unified_Ideograph", "Ideographic"},
    134914: {"Unified_Ideograph", "Ideographic"},
    134915: {"Unified_Ideograph", "Ideographic"},
    134916: {"Unified_Ideograph", "Ideographic"},
    134917: {"Unified_Ideograph", "Ideographic"},
    134918: {"Unified_Ideograph", "Ideographic"},
    134919: {"Unified_Ideograph", "Ideographic"},
    134920: {"Unified_Ideograph", "Ideographic"},
    134921: {"Unified_Ideograph", "Ideographic"},
    134922: {"Unified_Ideograph", "Ideographic"},
    134923: {"Unified_Ideograph", "Ideographic"},
    134924: {"Unified_Ideograph", "Ideographic"},
    134925: {"Unified_Ideograph", "Ideographic"},
    134926: {"Unified_Ideograph", "Ideographic"},
    134927: {"Unified_Ideograph", "Ideographic"},
    134928: {"Unified_Ideograph", "Ideographic"},
    134929: {"Unified_Ideograph", "Ideographic"},
    134930: {"Unified_Ideograph", "Ideographic"},
    134931: {"Unified_Ideograph", "Ideographic"},
    134932: {"Unified_Ideograph", "Ideographic"},
    134933: {"Unified_Ideograph", "Ideographic"},
    134934: {"Unified_Ideograph", "Ideographic"},
    134935: {"Unified_Ideograph", "Ideographic"},
    134936: {"Unified_Ideograph", "Ideographic"},
    134937: {"Unified_Ideograph", "Ideographic"},
    134938: {"Unified_Ideograph", "Ideographic"},
    134939: {"Unified_Ideograph", "Ideographic"},
    134940: {"Unified_Ideograph", "Ideographic"},
    134941: {"Unified_Ideograph", "Ideographic"},
    134942: {"Unified_Ideograph", "Ideographic"},
    134943: {"Unified_Ideograph", "Ideographic"},
    134944: {"Unified_Ideograph", "Ideographic"},
    134945: {"Unified_Ideograph", "Ideographic"},
    134946: {"Unified_Ideograph", "Ideographic"},
    134947: {"Unified_Ideograph", "Ideographic"},
    134948: {"Unified_Ideograph", "Ideographic"},
    134949: {"Unified_Ideograph", "Ideographic"},
    134950: {"Unified_Ideograph", "Ideographic"},
    134951: {"Unified_Ideograph", "Ideographic"},
    134952: {"Unified_Ideograph", "Ideographic"},
    134953: {"Unified_Ideograph", "Ideographic"},
    134954: {"Unified_Ideograph", "Ideographic"},
    134955: {"Unified_Ideograph", "Ideographic"},
    134956: {"Unified_Ideograph", "Ideographic"},
    134957: {"Unified_Ideograph", "Ideographic"},
    134958: {"Unified_Ideograph", "Ideographic"},
    134959: {"Unified_Ideograph", "Ideographic"},
    134960: {"Unified_Ideograph", "Ideographic"},
    134961: {"Unified_Ideograph", "Ideographic"},
    134962: {"Unified_Ideograph", "Ideographic"},
    134963: {"Unified_Ideograph", "Ideographic"},
    134964: {"Unified_Ideograph", "Ideographic"},
    134965: {"Unified_Ideograph", "Ideographic"},
    134966: {"Unified_Ideograph", "Ideographic"},
    134967: {"Unified_Ideograph", "Ideographic"},
    134968: {"Unified_Ideograph", "Ideographic"},
    134969: {"Unified_Ideograph", "Ideographic"},
    134970: {"Unified_Ideograph", "Ideographic"},
    134971: {"Unified_Ideograph", "Ideographic"},
    134972: {"Unified_Ideograph", "Ideographic"},
    134973: {"Unified_Ideograph", "Ideographic"},
    134974: {"Unified_Ideograph", "Ideographic"},
    134975: {"Unified_Ideograph", "Ideographic"},
    134976: {"Unified_Ideograph", "Ideographic"},
    134977: {"Unified_Ideograph", "Ideographic"},
    134978: {"Unified_Ideograph", "Ideographic"},
    134979: {"Unified_Ideograph", "Ideographic"},
    134980: {"Unified_Ideograph", "Ideographic"},
    134981: {"Unified_Ideograph", "Ideographic"},
    134982: {"Unified_Ideograph", "Ideographic"},
    134983: {"Unified_Ideograph", "Ideographic"},
    134984: {"Unified_Ideograph", "Ideographic"},
    134985: {"Unified_Ideograph", "Ideographic"},
    134986: {"Unified_Ideograph", "Ideographic"},
    134987: {"Unified_Ideograph", "Ideographic"},
    134988: {"Unified_Ideograph", "Ideographic"},
    134989: {"Unified_Ideograph", "Ideographic"},
    134990: {"Unified_Ideograph", "Ideographic"},
    134991: {"Unified_Ideograph", "Ideographic"},
    134992: {"Unified_Ideograph", "Ideographic"},
    134993: {"Unified_Ideograph", "Ideographic"},
    134994: {"Unified_Ideograph", "Ideographic"},
    134995: {"Unified_Ideograph", "Ideographic"},
    134996: {"Unified_Ideograph", "Ideographic"},
    134997: {"Unified_Ideograph", "Ideographic"},
    134998: {"Unified_Ideograph", "Ideographic"},
    134999: {"Unified_Ideograph", "Ideographic"},
    135000: {"Unified_Ideograph", "Ideographic"},
    135001: {"Unified_Ideograph", "Ideographic"},
    135002: {"Unified_Ideograph", "Ideographic"},
    135003: {"Unified_Ideograph", "Ideographic"},
    135004: {"Unified_Ideograph", "Ideographic"},
    135005: {"Unified_Ideograph", "Ideographic"},
    135006: {"Unified_Ideograph", "Ideographic"},
    135007: {"Unified_Ideograph", "Ideographic"},
    135008: {"Unified_Ideograph", "Ideographic"},
    135009: {"Unified_Ideograph", "Ideographic"},
    135010: {"Unified_Ideograph", "Ideographic"},
    135011: {"Unified_Ideograph", "Ideographic"},
    135012: {"Unified_Ideograph", "Ideographic"},
    135013: {"Unified_Ideograph", "Ideographic"},
    135014: {"Unified_Ideograph", "Ideographic"},
    135015: {"Unified_Ideograph", "Ideographic"},
    135016: {"Unified_Ideograph", "Ideographic"},
    135017: {"Unified_Ideograph", "Ideographic"},
    135018: {"Unified_Ideograph", "Ideographic"},
    135019: {"Unified_Ideograph", "Ideographic"},
    135020: {"Unified_Ideograph", "Ideographic"},
    135021: {"Unified_Ideograph", "Ideographic"},
    135022: {"Unified_Ideograph", "Ideographic"},
    135023: {"Unified_Ideograph", "Ideographic"},
    135024: {"Unified_Ideograph", "Ideographic"},
    135025: {"Unified_Ideograph", "Ideographic"},
    135026: {"Unified_Ideograph", "Ideographic"},
    135027: {"Unified_Ideograph", "Ideographic"},
    135028: {"Unified_Ideograph", "Ideographic"},
    135029: {"Unified_Ideograph", "Ideographic"},
    135030: {"Unified_Ideograph", "Ideographic"},
    135031: {"Unified_Ideograph", "Ideographic"},
    135032: {"Unified_Ideograph", "Ideographic"},
    135033: {"Unified_Ideograph", "Ideographic"},
    135034: {"Unified_Ideograph", "Ideographic"},
    135035: {"Unified_Ideograph", "Ideographic"},
    135036: {"Unified_Ideograph", "Ideographic"},
    135037: {"Unified_Ideograph", "Ideographic"},
    135038: {"Unified_Ideograph", "Ideographic"},
    135039: {"Unified_Ideograph", "Ideographic"},
    135040: {"Unified_Ideograph", "Ideographic"},
    135041: {"Unified_Ideograph", "Ideographic"},
    135042: {"Unified_Ideograph", "Ideographic"},
    135043: {"Unified_Ideograph", "Ideographic"},
    135044: {"Unified_Ideograph", "Ideographic"},
    135045: {"Unified_Ideograph", "Ideographic"},
    135046: {"Unified_Ideograph", "Ideographic"},
    135047: {"Unified_Ideograph", "Ideographic"},
    135048: {"Unified_Ideograph", "Ideographic"},
    135049: {"Unified_Ideograph", "Ideographic"},
    135050: {"Unified_Ideograph", "Ideographic"},
    135051: {"Unified_Ideograph", "Ideographic"},
    135052: {"Unified_Ideograph", "Ideographic"},
    135053: {"Unified_Ideograph", "Ideographic"},
    135054: {"Unified_Ideograph", "Ideographic"},
    135055: {"Unified_Ideograph", "Ideographic"},
    135056: {"Unified_Ideograph", "Ideographic"},
    135057: {"Unified_Ideograph", "Ideographic"},
    135058: {"Unified_Ideograph", "Ideographic"},
    135059: {"Unified_Ideograph", "Ideographic"},
    135060: {"Unified_Ideograph", "Ideographic"},
    135061: {"Unified_Ideograph", "Ideographic"},
    135062: {"Unified_Ideograph", "Ideographic"},
    135063: {"Unified_Ideograph", "Ideographic"},
    135064: {"Unified_Ideograph", "Ideographic"},
    135065: {"Unified_Ideograph", "Ideographic"},
    135066: {"Unified_Ideograph", "Ideographic"},
    135067: {"Unified_Ideograph", "Ideographic"},
    135068: {"Unified_Ideograph", "Ideographic"},
    135069: {"Unified_Ideograph", "Ideographic"},
    135070: {"Unified_Ideograph", "Ideographic"},
    135071: {"Unified_Ideograph", "Ideographic"},
    135072: {"Unified_Ideograph", "Ideographic"},
    135073: {"Unified_Ideograph", "Ideographic"},
    135074: {"Unified_Ideograph", "Ideographic"},
    135075: {"Unified_Ideograph", "Ideographic"},
    135076: {"Unified_Ideograph", "Ideographic"},
    135077: {"Unified_Ideograph", "Ideographic"},
    135078: {"Unified_Ideograph", "Ideographic"},
    135079: {"Unified_Ideograph", "Ideographic"},
    135080: {"Unified_Ideograph", "Ideographic"},
    135081: {"Unified_Ideograph", "Ideographic"},
    135082: {"Unified_Ideograph", "Ideographic"},
    135083: {"Unified_Ideograph", "Ideographic"},
    135084: {"Unified_Ideograph", "Ideographic"},
    135085: {"Unified_Ideograph", "Ideographic"},
    135086: {"Unified_Ideograph", "Ideographic"},
    135087: {"Unified_Ideograph", "Ideographic"},
    135088: {"Unified_Ideograph", "Ideographic"},
    135089: {"Unified_Ideograph", "Ideographic"},
    135090: {"Unified_Ideograph", "Ideographic"},
    135091: {"Unified_Ideograph", "Ideographic"},
    135092: {"Unified_Ideograph", "Ideographic"},
    135093: {"Unified_Ideograph", "Ideographic"},
    135094: {"Unified_Ideograph", "Ideographic"},
    135095: {"Unified_Ideograph", "Ideographic"},
    135096: {"Unified_Ideograph", "Ideographic"},
    135097: {"Unified_Ideograph", "Ideographic"},
    135098: {"Unified_Ideograph", "Ideographic"},
    135099: {"Unified_Ideograph", "Ideographic"},
    135100: {"Unified_Ideograph", "Ideographic"},
    135101: {"Unified_Ideograph", "Ideographic"},
    135102: {"Unified_Ideograph", "Ideographic"},
    135103: {"Unified_Ideograph", "Ideographic"},
    135104: {"Unified_Ideograph", "Ideographic"},
    135105: {"Unified_Ideograph", "Ideographic"},
    135106: {"Unified_Ideograph", "Ideographic"},
    135107: {"Unified_Ideograph", "Ideographic"},
    135108: {"Unified_Ideograph", "Ideographic"},
    135109: {"Unified_Ideograph", "Ideographic"},
    135110: {"Unified_Ideograph", "Ideographic"},
    135111: {"Unified_Ideograph", "Ideographic"},
    135112: {"Unified_Ideograph", "Ideographic"},
    135113: {"Unified_Ideograph", "Ideographic"},
    135114: {"Unified_Ideograph", "Ideographic"},
    135115: {"Unified_Ideograph", "Ideographic"},
    135116: {"Unified_Ideograph", "Ideographic"},
    135117: {"Unified_Ideograph", "Ideographic"},
    135118: {"Unified_Ideograph", "Ideographic"},
    135119: {"Unified_Ideograph", "Ideographic"},
    135120: {"Unified_Ideograph", "Ideographic"},
    135121: {"Unified_Ideograph", "Ideographic"},
    135122: {"Unified_Ideograph", "Ideographic"},
    135123: {"Unified_Ideograph", "Ideographic"},
    135124: {"Unified_Ideograph", "Ideographic"},
    135125: {"Unified_Ideograph", "Ideographic"},
    135126: {"Unified_Ideograph", "Ideographic"},
    135127: {"Unified_Ideograph", "Ideographic"},
    135128: {"Unified_Ideograph", "Ideographic"},
    135129: {"Unified_Ideograph", "Ideographic"},
    135130: {"Unified_Ideograph", "Ideographic"},
    135131: {"Unified_Ideograph", "Ideographic"},
    135132: {"Unified_Ideograph", "Ideographic"},
    135133: {"Unified_Ideograph", "Ideographic"},
    135134: {"Unified_Ideograph", "Ideographic"},
    135135: {"Unified_Ideograph", "Ideographic"},
    135136: {"Unified_Ideograph", "Ideographic"},
    135137: {"Unified_Ideograph", "Ideographic"},
    135138: {"Unified_Ideograph", "Ideographic"},
    135139: {"Unified_Ideograph", "Ideographic"},
    135140: {"Unified_Ideograph", "Ideographic"},
    135141: {"Unified_Ideograph", "Ideographic"},
    135142: {"Unified_Ideograph", "Ideographic"},
    135143: {"Unified_Ideograph", "Ideographic"},
    135144: {"Unified_Ideograph", "Ideographic"},
    135145: {"Unified_Ideograph", "Ideographic"},
    135146: {"Unified_Ideograph", "Ideographic"},
    135147: {"Unified_Ideograph", "Ideographic"},
    135148: {"Unified_Ideograph", "Ideographic"},
    135149: {"Unified_Ideograph", "Ideographic"},
    135150: {"Unified_Ideograph", "Ideographic"},
    135151: {"Unified_Ideograph", "Ideographic"},
    135152: {"Unified_Ideograph", "Ideographic"},
    135153: {"Unified_Ideograph", "Ideographic"},
    135154: {"Unified_Ideograph", "Ideographic"},
    135155: {"Unified_Ideograph", "Ideographic"},
    135156: {"Unified_Ideograph", "Ideographic"},
    135157: {"Unified_Ideograph", "Ideographic"},
    135158: {"Unified_Ideograph", "Ideographic"},
    135159: {"Unified_Ideograph", "Ideographic"},
    135160: {"Unified_Ideograph", "Ideographic"},
    135161: {"Unified_Ideograph", "Ideographic"},
    135162: {"Unified_Ideograph", "Ideographic"},
    135163: {"Unified_Ideograph", "Ideographic"},
    135164: {"Unified_Ideograph", "Ideographic"},
    135165: {"Unified_Ideograph", "Ideographic"},
    135166: {"Unified_Ideograph", "Ideographic"},
    135167: {"Unified_Ideograph", "Ideographic"},
    135168: {"Unified_Ideograph", "Ideographic"},
    135169: {"Unified_Ideograph", "Ideographic"},
    135170: {"Unified_Ideograph", "Ideographic"},
    135171: {"Unified_Ideograph", "Ideographic"},
    135172: {"Unified_Ideograph", "Ideographic"},
    135173: {"Unified_Ideograph", "Ideographic"},
    135174: {"Unified_Ideograph", "Ideographic"},
    135175: {"Unified_Ideograph", "Ideographic"},
    135176: {"Unified_Ideograph", "Ideographic"},
    135177: {"Unified_Ideograph", "Ideographic"},
    135178: {"Unified_Ideograph", "Ideographic"},
    135179: {"Unified_Ideograph", "Ideographic"},
    135180: {"Unified_Ideograph", "Ideographic"},
    135181: {"Unified_Ideograph", "Ideographic"},
    135182: {"Unified_Ideograph", "Ideographic"},
    135183: {"Unified_Ideograph", "Ideographic"},
    135184: {"Unified_Ideograph", "Ideographic"},
    135185: {"Unified_Ideograph", "Ideographic"},
    135186: {"Unified_Ideograph", "Ideographic"},
    135187: {"Unified_Ideograph", "Ideographic"},
    135188: {"Unified_Ideograph", "Ideographic"},
    135189: {"Unified_Ideograph", "Ideographic"},
    135190: {"Unified_Ideograph", "Ideographic"},
    135191: {"Unified_Ideograph", "Ideographic"},
    135192: {"Unified_Ideograph", "Ideographic"},
    135193: {"Unified_Ideograph", "Ideographic"},
    135194: {"Unified_Ideograph", "Ideographic"},
    135195: {"Unified_Ideograph", "Ideographic"},
    135196: {"Unified_Ideograph", "Ideographic"},
    135197: {"Unified_Ideograph", "Ideographic"},
    135198: {"Unified_Ideograph", "Ideographic"},
    135199: {"Unified_Ideograph", "Ideographic"},
    135200: {"Unified_Ideograph", "Ideographic"},
    135201: {"Unified_Ideograph", "Ideographic"},
    135202: {"Unified_Ideograph", "Ideographic"},
    135203: {"Unified_Ideograph", "Ideographic"},
    135204: {"Unified_Ideograph", "Ideographic"},
    135205: {"Unified_Ideograph", "Ideographic"},
    135206: {"Unified_Ideograph", "Ideographic"},
    135207: {"Unified_Ideograph", "Ideographic"},
    135208: {"Unified_Ideograph", "Ideographic"},
    135209: {"Unified_Ideograph", "Ideographic"},
    135210: {"Unified_Ideograph", "Ideographic"},
    135211: {"Unified_Ideograph", "Ideographic"},
    135212: {"Unified_Ideograph", "Ideographic"},
    135213: {"Unified_Ideograph", "Ideographic"},
    135214: {"Unified_Ideograph", "Ideographic"},
    135215: {"Unified_Ideograph", "Ideographic"},
    135216: {"Unified_Ideograph", "Ideographic"},
    135217: {"Unified_Ideograph", "Ideographic"},
    135218: {"Unified_Ideograph", "Ideographic"},
    135219: {"Unified_Ideograph", "Ideographic"},
    135220: {"Unified_Ideograph", "Ideographic"},
    135221: {"Unified_Ideograph", "Ideographic"},
    135222: {"Unified_Ideograph", "Ideographic"},
    135223: {"Unified_Ideograph", "Ideographic"},
    135224: {"Unified_Ideograph", "Ideographic"},
    135225: {"Unified_Ideograph", "Ideographic"},
    135226: {"Unified_Ideograph", "Ideographic"},
    135227: {"Unified_Ideograph", "Ideographic"},
    135228: {"Unified_Ideograph", "Ideographic"},
    135229: {"Unified_Ideograph", "Ideographic"},
    135230: {"Unified_Ideograph", "Ideographic"},
    135231: {"Unified_Ideograph", "Ideographic"},
    135232: {"Unified_Ideograph", "Ideographic"},
    135233: {"Unified_Ideograph", "Ideographic"},
    135234: {"Unified_Ideograph", "Ideographic"},
    135235: {"Unified_Ideograph", "Ideographic"},
    135236: {"Unified_Ideograph", "Ideographic"},
    135237: {"Unified_Ideograph", "Ideographic"},
    135238: {"Unified_Ideograph", "Ideographic"},
    135239: {"Unified_Ideograph", "Ideographic"},
    135240: {"Unified_Ideograph", "Ideographic"},
    135241: {"Unified_Ideograph", "Ideographic"},
    135242: {"Unified_Ideograph", "Ideographic"},
    135243: {"Unified_Ideograph", "Ideographic"},
    135244: {"Unified_Ideograph", "Ideographic"},
    135245: {"Unified_Ideograph", "Ideographic"},
    135246: {"Unified_Ideograph", "Ideographic"},
    135247: {"Unified_Ideograph", "Ideographic"},
    135248: {"Unified_Ideograph", "Ideographic"},
    135249: {"Unified_Ideograph", "Ideographic"},
    135250: {"Unified_Ideograph", "Ideographic"},
    135251: {"Unified_Ideograph", "Ideographic"},
    135252: {"Unified_Ideograph", "Ideographic"},
    135253: {"Unified_Ideograph", "Ideographic"},
    135254: {"Unified_Ideograph", "Ideographic"},
    135255: {"Unified_Ideograph", "Ideographic"},
    135256: {"Unified_Ideograph", "Ideographic"},
    135257: {"Unified_Ideograph", "Ideographic"},
    135258: {"Unified_Ideograph", "Ideographic"},
    135259: {"Unified_Ideograph", "Ideographic"},
    135260: {"Unified_Ideograph", "Ideographic"},
    135261: {"Unified_Ideograph", "Ideographic"},
    135262: {"Unified_Ideograph", "Ideographic"},
    135263: {"Unified_Ideograph", "Ideographic"},
    135264: {"Unified_Ideograph", "Ideographic"},
    135265: {"Unified_Ideograph", "Ideographic"},
    135266: {"Unified_Ideograph", "Ideographic"},
    135267: {"Unified_Ideograph", "Ideographic"},
    135268: {"Unified_Ideograph", "Ideographic"},
    135269: {"Unified_Ideograph", "Ideographic"},
    135270: {"Unified_Ideograph", "Ideographic"},
    135271: {"Unified_Ideograph", "Ideographic"},
    135272: {"Unified_Ideograph", "Ideographic"},
    135273: {"Unified_Ideograph", "Ideographic"},
    135274: {"Unified_Ideograph", "Ideographic"},
    135275: {"Unified_Ideograph", "Ideographic"},
    135276: {"Unified_Ideograph", "Ideographic"},
    135277: {"Unified_Ideograph", "Ideographic"},
    135278: {"Unified_Ideograph", "Ideographic"},
    135279: {"Unified_Ideograph", "Ideographic"},
    135280: {"Unified_Ideograph", "Ideographic"},
    135281: {"Unified_Ideograph", "Ideographic"},
    135282: {"Unified_Ideograph", "Ideographic"},
    135283: {"Unified_Ideograph", "Ideographic"},
    135284: {"Unified_Ideograph", "Ideographic"},
    135285: {"Unified_Ideograph", "Ideographic"},
    135286: {"Unified_Ideograph", "Ideographic"},
    135287: {"Unified_Ideograph", "Ideographic"},
    135288: {"Unified_Ideograph", "Ideographic"},
    135289: {"Unified_Ideograph", "Ideographic"},
    135290: {"Unified_Ideograph", "Ideographic"},
    135291: {"Unified_Ideograph", "Ideographic"},
    135292: {"Unified_Ideograph", "Ideographic"},
    135293: {"Unified_Ideograph", "Ideographic"},
    135294: {"Unified_Ideograph", "Ideographic"},
    135295: {"Unified_Ideograph", "Ideographic"},
    135296: {"Unified_Ideograph", "Ideographic"},
    135297: {"Unified_Ideograph", "Ideographic"},
    135298: {"Unified_Ideograph", "Ideographic"},
    135299: {"Unified_Ideograph", "Ideographic"},
    135300: {"Unified_Ideograph", "Ideographic"},
    135301: {"Unified_Ideograph", "Ideographic"},
    135302: {"Unified_Ideograph", "Ideographic"},
    135303: {"Unified_Ideograph", "Ideographic"},
    135304: {"Unified_Ideograph", "Ideographic"},
    135305: {"Unified_Ideograph", "Ideographic"},
    135306: {"Unified_Ideograph", "Ideographic"},
    135307: {"Unified_Ideograph", "Ideographic"},
    135308: {"Unified_Ideograph", "Ideographic"},
    135309: {"Unified_Ideograph", "Ideographic"},
    135310: {"Unified_Ideograph", "Ideographic"},
    135311: {"Unified_Ideograph", "Ideographic"},
    135312: {"Unified_Ideograph", "Ideographic"},
    135313: {"Unified_Ideograph", "Ideographic"},
    135314: {"Unified_Ideograph", "Ideographic"},
    135315: {"Unified_Ideograph", "Ideographic"},
    135316: {"Unified_Ideograph", "Ideographic"},
    135317: {"Unified_Ideograph", "Ideographic"},
    135318: {"Unified_Ideograph", "Ideographic"},
    135319: {"Unified_Ideograph", "Ideographic"},
    135320: {"Unified_Ideograph", "Ideographic"},
    135321: {"Unified_Ideograph", "Ideographic"},
    135322: {"Unified_Ideograph", "Ideographic"},
    135323: {"Unified_Ideograph", "Ideographic"},
    135324: {"Unified_Ideograph", "Ideographic"},
    135325: {"Unified_Ideograph", "Ideographic"},
    135326: {"Unified_Ideograph", "Ideographic"},
    135327: {"Unified_Ideograph", "Ideographic"},
    135328: {"Unified_Ideograph", "Ideographic"},
    135329: {"Unified_Ideograph", "Ideographic"},
    135330: {"Unified_Ideograph", "Ideographic"},
    135331: {"Unified_Ideograph", "Ideographic"},
    135332: {"Unified_Ideograph", "Ideographic"},
    135333: {"Unified_Ideograph", "Ideographic"},
    135334: {"Unified_Ideograph", "Ideographic"},
    135335: {"Unified_Ideograph", "Ideographic"},
    135336: {"Unified_Ideograph", "Ideographic"},
    135337: {"Unified_Ideograph", "Ideographic"},
    135338: {"Unified_Ideograph", "Ideographic"},
    135339: {"Unified_Ideograph", "Ideographic"},
    135340: {"Unified_Ideograph", "Ideographic"},
    135341: {"Unified_Ideograph", "Ideographic"},
    135342: {"Unified_Ideograph", "Ideographic"},
    135343: {"Unified_Ideograph", "Ideographic"},
    135344: {"Unified_Ideograph", "Ideographic"},
    135345: {"Unified_Ideograph", "Ideographic"},
    135346: {"Unified_Ideograph", "Ideographic"},
    135347: {"Unified_Ideograph", "Ideographic"},
    135348: {"Unified_Ideograph", "Ideographic"},
    135349: {"Unified_Ideograph", "Ideographic"},
    135350: {"Unified_Ideograph", "Ideographic"},
    135351: {"Unified_Ideograph", "Ideographic"},
    135352: {"Unified_Ideograph", "Ideographic"},
    135353: {"Unified_Ideograph", "Ideographic"},
    135354: {"Unified_Ideograph", "Ideographic"},
    135355: {"Unified_Ideograph", "Ideographic"},
    135356: {"Unified_Ideograph", "Ideographic"},
    135357: {"Unified_Ideograph", "Ideographic"},
    135358: {"Unified_Ideograph", "Ideographic"},
    135359: {"Unified_Ideograph", "Ideographic"},
    135360: {"Unified_Ideograph", "Ideographic"},
    135361: {"Unified_Ideograph", "Ideographic"},
    135362: {"Unified_Ideograph", "Ideographic"},
    135363: {"Unified_Ideograph", "Ideographic"},
    135364: {"Unified_Ideograph", "Ideographic"},
    135365: {"Unified_Ideograph", "Ideographic"},
    135366: {"Unified_Ideograph", "Ideographic"},
    135367: {"Unified_Ideograph", "Ideographic"},
    135368: {"Unified_Ideograph", "Ideographic"},
    135369: {"Unified_Ideograph", "Ideographic"},
    135370: {"Unified_Ideograph", "Ideographic"},
    135371: {"Unified_Ideograph", "Ideographic"},
    135372: {"Unified_Ideograph", "Ideographic"},
    135373: {"Unified_Ideograph", "Ideographic"},
    135374: {"Unified_Ideograph", "Ideographic"},
    135375: {"Unified_Ideograph", "Ideographic"},
    135376: {"Unified_Ideograph", "Ideographic"},
    135377: {"Unified_Ideograph", "Ideographic"},
    135378: {"Unified_Ideograph", "Ideographic"},
    135379: {"Unified_Ideograph", "Ideographic"},
    135380: {"Unified_Ideograph", "Ideographic"},
    135381: {"Unified_Ideograph", "Ideographic"},
    135382: {"Unified_Ideograph", "Ideographic"},
    135383: {"Unified_Ideograph", "Ideographic"},
    135384: {"Unified_Ideograph", "Ideographic"},
    135385: {"Unified_Ideograph", "Ideographic"},
    135386: {"Unified_Ideograph", "Ideographic"},
    135387: {"Unified_Ideograph", "Ideographic"},
    135388: {"Unified_Ideograph", "Ideographic"},
    135389: {"Unified_Ideograph", "Ideographic"},
    135390: {"Unified_Ideograph", "Ideographic"},
    135391: {"Unified_Ideograph", "Ideographic"},
    135392: {"Unified_Ideograph", "Ideographic"},
    135393: {"Unified_Ideograph", "Ideographic"},
    135394: {"Unified_Ideograph", "Ideographic"},
    135395: {"Unified_Ideograph", "Ideographic"},
    135396: {"Unified_Ideograph", "Ideographic"},
    135397: {"Unified_Ideograph", "Ideographic"},
    135398: {"Unified_Ideograph", "Ideographic"},
    135399: {"Unified_Ideograph", "Ideographic"},
    135400: {"Unified_Ideograph", "Ideographic"},
    135401: {"Unified_Ideograph", "Ideographic"},
    135402: {"Unified_Ideograph", "Ideographic"},
    135403: {"Unified_Ideograph", "Ideographic"},
    135404: {"Unified_Ideograph", "Ideographic"},
    135405: {"Unified_Ideograph", "Ideographic"},
    135406: {"Unified_Ideograph", "Ideographic"},
    135407: {"Unified_Ideograph", "Ideographic"},
    135408: {"Unified_Ideograph", "Ideographic"},
    135409: {"Unified_Ideograph", "Ideographic"},
    135410: {"Unified_Ideograph", "Ideographic"},
    135411: {"Unified_Ideograph", "Ideographic"},
    135412: {"Unified_Ideograph", "Ideographic"},
    135413: {"Unified_Ideograph", "Ideographic"},
    135414: {"Unified_Ideograph", "Ideographic"},
    135415: {"Unified_Ideograph", "Ideographic"},
    135416: {"Unified_Ideograph", "Ideographic"},
    135417: {"Unified_Ideograph", "Ideographic"},
    135418: {"Unified_Ideograph", "Ideographic"},
    135419: {"Unified_Ideograph", "Ideographic"},
    135420: {"Unified_Ideograph", "Ideographic"},
    135421: {"Unified_Ideograph", "Ideographic"},
    135422: {"Unified_Ideograph", "Ideographic"},
    135423: {"Unified_Ideograph", "Ideographic"},
    135424: {"Unified_Ideograph", "Ideographic"},
    135425: {"Unified_Ideograph", "Ideographic"},
    135426: {"Unified_Ideograph", "Ideographic"},
    135427: {"Unified_Ideograph", "Ideographic"},
    135428: {"Unified_Ideograph", "Ideographic"},
    135429: {"Unified_Ideograph", "Ideographic"},
    135430: {"Unified_Ideograph", "Ideographic"},
    135431: {"Unified_Ideograph", "Ideographic"},
    135432: {"Unified_Ideograph", "Ideographic"},
    135433: {"Unified_Ideograph", "Ideographic"},
    135434: {"Unified_Ideograph", "Ideographic"},
    135435: {"Unified_Ideograph", "Ideographic"},
    135436: {"Unified_Ideograph", "Ideographic"},
    135437: {"Unified_Ideograph", "Ideographic"},
    135438: {"Unified_Ideograph", "Ideographic"},
    135439: {"Unified_Ideograph", "Ideographic"},
    135440: {"Unified_Ideograph", "Ideographic"},
    135441: {"Unified_Ideograph", "Ideographic"},
    135442: {"Unified_Ideograph", "Ideographic"},
    135443: {"Unified_Ideograph", "Ideographic"},
    135444: {"Unified_Ideograph", "Ideographic"},
    135445: {"Unified_Ideograph", "Ideographic"},
    135446: {"Unified_Ideograph", "Ideographic"},
    135447: {"Unified_Ideograph", "Ideographic"},
    135448: {"Unified_Ideograph", "Ideographic"},
    135449: {"Unified_Ideograph", "Ideographic"},
    135450: {"Unified_Ideograph", "Ideographic"},
    135451: {"Unified_Ideograph", "Ideographic"},
    135452: {"Unified_Ideograph", "Ideographic"},
    135453: {"Unified_Ideograph", "Ideographic"},
    135454: {"Unified_Ideograph", "Ideographic"},
    135455: {"Unified_Ideograph", "Ideographic"},
    135456: {"Unified_Ideograph", "Ideographic"},
    135457: {"Unified_Ideograph", "Ideographic"},
    135458: {"Unified_Ideograph", "Ideographic"},
    135459: {"Unified_Ideograph", "Ideographic"},
    135460: {"Unified_Ideograph", "Ideographic"},
    135461: {"Unified_Ideograph", "Ideographic"},
    135462: {"Unified_Ideograph", "Ideographic"},
    135463: {"Unified_Ideograph", "Ideographic"},
    135464: {"Unified_Ideograph", "Ideographic"},
    135465: {"Unified_Ideograph", "Ideographic"},
    135466: {"Unified_Ideograph", "Ideographic"},
    135467: {"Unified_Ideograph", "Ideographic"},
    135468: {"Unified_Ideograph", "Ideographic"},
    135469: {"Unified_Ideograph", "Ideographic"},
    135470: {"Unified_Ideograph", "Ideographic"},
    135471: {"Unified_Ideograph", "Ideographic"},
    135472: {"Unified_Ideograph", "Ideographic"},
    135473: {"Unified_Ideograph", "Ideographic"},
    135474: {"Unified_Ideograph", "Ideographic"},
    135475: {"Unified_Ideograph", "Ideographic"},
    135476: {"Unified_Ideograph", "Ideographic"},
    135477: {"Unified_Ideograph", "Ideographic"},
    135478: {"Unified_Ideograph", "Ideographic"},
    135479: {"Unified_Ideograph", "Ideographic"},
    135480: {"Unified_Ideograph", "Ideographic"},
    135481: {"Unified_Ideograph", "Ideographic"},
    135482: {"Unified_Ideograph", "Ideographic"},
    135483: {"Unified_Ideograph", "Ideographic"},
    135484: {"Unified_Ideograph", "Ideographic"},
    135485: {"Unified_Ideograph", "Ideographic"},
    135486: {"Unified_Ideograph", "Ideographic"},
    135487: {"Unified_Ideograph", "Ideographic"},
    135488: {"Unified_Ideograph", "Ideographic"},
    135489: {"Unified_Ideograph", "Ideographic"},
    135490: {"Unified_Ideograph", "Ideographic"},
    135491: {"Unified_Ideograph", "Ideographic"},
    135492: {"Unified_Ideograph", "Ideographic"},
    135493: {"Unified_Ideograph", "Ideographic"},
    135494: {"Unified_Ideograph", "Ideographic"},
    135495: {"Unified_Ideograph", "Ideographic"},
    135496: {"Unified_Ideograph", "Ideographic"},
    135497: {"Unified_Ideograph", "Ideographic"},
    135498: {"Unified_Ideograph", "Ideographic"},
    135499: {"Unified_Ideograph", "Ideographic"},
    135500: {"Unified_Ideograph", "Ideographic"},
    135501: {"Unified_Ideograph", "Ideographic"},
    135502: {"Unified_Ideograph", "Ideographic"},
    135503: {"Unified_Ideograph", "Ideographic"},
    135504: {"Unified_Ideograph", "Ideographic"},
    135505: {"Unified_Ideograph", "Ideographic"},
    135506: {"Unified_Ideograph", "Ideographic"},
    135507: {"Unified_Ideograph", "Ideographic"},
    135508: {"Unified_Ideograph", "Ideographic"},
    135509: {"Unified_Ideograph", "Ideographic"},
    135510: {"Unified_Ideograph", "Ideographic"},
    135511: {"Unified_Ideograph", "Ideographic"},
    135512: {"Unified_Ideograph", "Ideographic"},
    135513: {"Unified_Ideograph", "Ideographic"},
    135514: {"Unified_Ideograph", "Ideographic"},
    135515: {"Unified_Ideograph", "Ideographic"},
    135516: {"Unified_Ideograph", "Ideographic"},
    135517: {"Unified_Ideograph", "Ideographic"},
    135518: {"Unified_Ideograph", "Ideographic"},
    135519: {"Unified_Ideograph", "Ideographic"},
    135520: {"Unified_Ideograph", "Ideographic"},
    135521: {"Unified_Ideograph", "Ideographic"},
    135522: {"Unified_Ideograph", "Ideographic"},
    135523: {"Unified_Ideograph", "Ideographic"},
    135524: {"Unified_Ideograph", "Ideographic"},
    135525: {"Unified_Ideograph", "Ideographic"},
    135526: {"Unified_Ideograph", "Ideographic"},
    135527: {"Unified_Ideograph", "Ideographic"},
    135528: {"Unified_Ideograph", "Ideographic"},
    135529: {"Unified_Ideograph", "Ideographic"},
    135530: {"Unified_Ideograph", "Ideographic"},
    135531: {"Unified_Ideograph", "Ideographic"},
    135532: {"Unified_Ideograph", "Ideographic"},
    135533: {"Unified_Ideograph", "Ideographic"},
    135534: {"Unified_Ideograph", "Ideographic"},
    135535: {"Unified_Ideograph", "Ideographic"},
    135536: {"Unified_Ideograph", "Ideographic"},
    135537: {"Unified_Ideograph", "Ideographic"},
    135538: {"Unified_Ideograph", "Ideographic"},
    135539: {"Unified_Ideograph", "Ideographic"},
    135540: {"Unified_Ideograph", "Ideographic"},
    135541: {"Unified_Ideograph", "Ideographic"},
    135542: {"Unified_Ideograph", "Ideographic"},
    135543: {"Unified_Ideograph", "Ideographic"},
    135544: {"Unified_Ideograph", "Ideographic"},
    135545: {"Unified_Ideograph", "Ideographic"},
    135546: {"Unified_Ideograph", "Ideographic"},
    135547: {"Unified_Ideograph", "Ideographic"},
    135548: {"Unified_Ideograph", "Ideographic"},
    135549: {"Unified_Ideograph", "Ideographic"},
    135550: {"Unified_Ideograph", "Ideographic"},
    135551: {"Unified_Ideograph", "Ideographic"},
    135552: {"Unified_Ideograph", "Ideographic"},
    135553: {"Unified_Ideograph", "Ideographic"},
    135554: {"Unified_Ideograph", "Ideographic"},
    135555: {"Unified_Ideograph", "Ideographic"},
    135556: {"Unified_Ideograph", "Ideographic"},
    135557: {"Unified_Ideograph", "Ideographic"},
    135558: {"Unified_Ideograph", "Ideographic"},
    135559: {"Unified_Ideograph", "Ideographic"},
    135560: {"Unified_Ideograph", "Ideographic"},
    135561: {"Unified_Ideograph", "Ideographic"},
    135562: {"Unified_Ideograph", "Ideographic"},
    135563: {"Unified_Ideograph", "Ideographic"},
    135564: {"Unified_Ideograph", "Ideographic"},
    135565: {"Unified_Ideograph", "Ideographic"},
    135566: {"Unified_Ideograph", "Ideographic"},
    135567: {"Unified_Ideograph", "Ideographic"},
    135568: {"Unified_Ideograph", "Ideographic"},
    135569: {"Unified_Ideograph", "Ideographic"},
    135570: {"Unified_Ideograph", "Ideographic"},
    135571: {"Unified_Ideograph", "Ideographic"},
    135572: {"Unified_Ideograph", "Ideographic"},
    135573: {"Unified_Ideograph", "Ideographic"},
    135574: {"Unified_Ideograph", "Ideographic"},
    135575: {"Unified_Ideograph", "Ideographic"},
    135576: {"Unified_Ideograph", "Ideographic"},
    135577: {"Unified_Ideograph", "Ideographic"},
    135578: {"Unified_Ideograph", "Ideographic"},
    135579: {"Unified_Ideograph", "Ideographic"},
    135580: {"Unified_Ideograph", "Ideographic"},
    135581: {"Unified_Ideograph", "Ideographic"},
    135582: {"Unified_Ideograph", "Ideographic"},
    135583: {"Unified_Ideograph", "Ideographic"},
    135584: {"Unified_Ideograph", "Ideographic"},
    135585: {"Unified_Ideograph", "Ideographic"},
    135586: {"Unified_Ideograph", "Ideographic"},
    135587: {"Unified_Ideograph", "Ideographic"},
    135588: {"Unified_Ideograph", "Ideographic"},
    135589: {"Unified_Ideograph", "Ideographic"},
    135590: {"Unified_Ideograph", "Ideographic"},
    135591: {"Unified_Ideograph", "Ideographic"},
    135592: {"Unified_Ideograph", "Ideographic"},
    135593: {"Unified_Ideograph", "Ideographic"},
    135594: {"Unified_Ideograph", "Ideographic"},
    135595: {"Unified_Ideograph", "Ideographic"},
    135596: {"Unified_Ideograph", "Ideographic"},
    135597: {"Unified_Ideograph", "Ideographic"},
    135598: {"Unified_Ideograph", "Ideographic"},
    135599: {"Unified_Ideograph", "Ideographic"},
    135600: {"Unified_Ideograph", "Ideographic"},
    135601: {"Unified_Ideograph", "Ideographic"},
    135602: {"Unified_Ideograph", "Ideographic"},
    135603: {"Unified_Ideograph", "Ideographic"},
    135604: {"Unified_Ideograph", "Ideographic"},
    135605: {"Unified_Ideograph", "Ideographic"},
    135606: {"Unified_Ideograph", "Ideographic"},
    135607: {"Unified_Ideograph", "Ideographic"},
    135608: {"Unified_Ideograph", "Ideographic"},
    135609: {"Unified_Ideograph", "Ideographic"},
    135610: {"Unified_Ideograph", "Ideographic"},
    135611: {"Unified_Ideograph", "Ideographic"},
    135612: {"Unified_Ideograph", "Ideographic"},
    135613: {"Unified_Ideograph", "Ideographic"},
    135614: {"Unified_Ideograph", "Ideographic"},
    135615: {"Unified_Ideograph", "Ideographic"},
    135616: {"Unified_Ideograph", "Ideographic"},
    135617: {"Unified_Ideograph", "Ideographic"},
    135618: {"Unified_Ideograph", "Ideographic"},
    135619: {"Unified_Ideograph", "Ideographic"},
    135620: {"Unified_Ideograph", "Ideographic"},
    135621: {"Unified_Ideograph", "Ideographic"},
    135622: {"Unified_Ideograph", "Ideographic"},
    135623: {"Unified_Ideograph", "Ideographic"},
    135624: {"Unified_Ideograph", "Ideographic"},
    135625: {"Unified_Ideograph", "Ideographic"},
    135626: {"Unified_Ideograph", "Ideographic"},
    135627: {"Unified_Ideograph", "Ideographic"},
    135628: {"Unified_Ideograph", "Ideographic"},
    135629: {"Unified_Ideograph", "Ideographic"},
    135630: {"Unified_Ideograph", "Ideographic"},
    135631: {"Unified_Ideograph", "Ideographic"},
    135632: {"Unified_Ideograph", "Ideographic"},
    135633: {"Unified_Ideograph", "Ideographic"},
    135634: {"Unified_Ideograph", "Ideographic"},
    135635: {"Unified_Ideograph", "Ideographic"},
    135636: {"Unified_Ideograph", "Ideographic"},
    135637: {"Unified_Ideograph", "Ideographic"},
    135638: {"Unified_Ideograph", "Ideographic"},
    135639: {"Unified_Ideograph", "Ideographic"},
    135640: {"Unified_Ideograph", "Ideographic"},
    135641: {"Unified_Ideograph", "Ideographic"},
    135642: {"Unified_Ideograph", "Ideographic"},
    135643: {"Unified_Ideograph", "Ideographic"},
    135644: {"Unified_Ideograph", "Ideographic"},
    135645: {"Unified_Ideograph", "Ideographic"},
    135646: {"Unified_Ideograph", "Ideographic"},
    135647: {"Unified_Ideograph", "Ideographic"},
    135648: {"Unified_Ideograph", "Ideographic"},
    135649: {"Unified_Ideograph", "Ideographic"},
    135650: {"Unified_Ideograph", "Ideographic"},
    135651: {"Unified_Ideograph", "Ideographic"},
    135652: {"Unified_Ideograph", "Ideographic"},
    135653: {"Unified_Ideograph", "Ideographic"},
    135654: {"Unified_Ideograph", "Ideographic"},
    135655: {"Unified_Ideograph", "Ideographic"},
    135656: {"Unified_Ideograph", "Ideographic"},
    135657: {"Unified_Ideograph", "Ideographic"},
    135658: {"Unified_Ideograph", "Ideographic"},
    135659: {"Unified_Ideograph", "Ideographic"},
    135660: {"Unified_Ideograph", "Ideographic"},
    135661: {"Unified_Ideograph", "Ideographic"},
    135662: {"Unified_Ideograph", "Ideographic"},
    135663: {"Unified_Ideograph", "Ideographic"},
    135664: {"Unified_Ideograph", "Ideographic"},
    135665: {"Unified_Ideograph", "Ideographic"},
    135666: {"Unified_Ideograph", "Ideographic"},
    135667: {"Unified_Ideograph", "Ideographic"},
    135668: {"Unified_Ideograph", "Ideographic"},
    135669: {"Unified_Ideograph", "Ideographic"},
    135670: {"Unified_Ideograph", "Ideographic"},
    135671: {"Unified_Ideograph", "Ideographic"},
    135672: {"Unified_Ideograph", "Ideographic"},
    135673: {"Unified_Ideograph", "Ideographic"},
    135674: {"Unified_Ideograph", "Ideographic"},
    135675: {"Unified_Ideograph", "Ideographic"},
    135676: {"Unified_Ideograph", "Ideographic"},
    135677: {"Unified_Ideograph", "Ideographic"},
    135678: {"Unified_Ideograph", "Ideographic"},
    135679: {"Unified_Ideograph", "Ideographic"},
    135680: {"Unified_Ideograph", "Ideographic"},
    135681: {"Unified_Ideograph", "Ideographic"},
    135682: {"Unified_Ideograph", "Ideographic"},
    135683: {"Unified_Ideograph", "Ideographic"},
    135684: {"Unified_Ideograph", "Ideographic"},
    135685: {"Unified_Ideograph", "Ideographic"},
    135686: {"Unified_Ideograph", "Ideographic"},
    135687: {"Unified_Ideograph", "Ideographic"},
    135688: {"Unified_Ideograph", "Ideographic"},
    135689: {"Unified_Ideograph", "Ideographic"},
    135690: {"Unified_Ideograph", "Ideographic"},
    135691: {"Unified_Ideograph", "Ideographic"},
    135692: {"Unified_Ideograph", "Ideographic"},
    135693: {"Unified_Ideograph", "Ideographic"},
    135694: {"Unified_Ideograph", "Ideographic"},
    135695: {"Unified_Ideograph", "Ideographic"},
    135696: {"Unified_Ideograph", "Ideographic"},
    135697: {"Unified_Ideograph", "Ideographic"},
    135698: {"Unified_Ideograph", "Ideographic"},
    135699: {"Unified_Ideograph", "Ideographic"},
    135700: {"Unified_Ideograph", "Ideographic"},
    135701: {"Unified_Ideograph", "Ideographic"},
    135702: {"Unified_Ideograph", "Ideographic"},
    135703: {"Unified_Ideograph", "Ideographic"},
    135704: {"Unified_Ideograph", "Ideographic"},
    135705: {"Unified_Ideograph", "Ideographic"},
    135706: {"Unified_Ideograph", "Ideographic"},
    135707: {"Unified_Ideograph", "Ideographic"},
    135708: {"Unified_Ideograph", "Ideographic"},
    135709: {"Unified_Ideograph", "Ideographic"},
    135710: {"Unified_Ideograph", "Ideographic"},
    135711: {"Unified_Ideograph", "Ideographic"},
    135712: {"Unified_Ideograph", "Ideographic"},
    135713: {"Unified_Ideograph", "Ideographic"},
    135714: {"Unified_Ideograph", "Ideographic"},
    135715: {"Unified_Ideograph", "Ideographic"},
    135716: {"Unified_Ideograph", "Ideographic"},
    135717: {"Unified_Ideograph", "Ideographic"},
    135718: {"Unified_Ideograph", "Ideographic"},
    135719: {"Unified_Ideograph", "Ideographic"},
    135720: {"Unified_Ideograph", "Ideographic"},
    135721: {"Unified_Ideograph", "Ideographic"},
    135722: {"Unified_Ideograph", "Ideographic"},
    135723: {"Unified_Ideograph", "Ideographic"},
    135724: {"Unified_Ideograph", "Ideographic"},
    135725: {"Unified_Ideograph", "Ideographic"},
    135726: {"Unified_Ideograph", "Ideographic"},
    135727: {"Unified_Ideograph", "Ideographic"},
    135728: {"Unified_Ideograph", "Ideographic"},
    135729: {"Unified_Ideograph", "Ideographic"},
    135730: {"Unified_Ideograph", "Ideographic"},
    135731: {"Unified_Ideograph", "Ideographic"},
    135732: {"Unified_Ideograph", "Ideographic"},
    135733: {"Unified_Ideograph", "Ideographic"},
    135734: {"Unified_Ideograph", "Ideographic"},
    135735: {"Unified_Ideograph", "Ideographic"},
    135736: {"Unified_Ideograph", "Ideographic"},
    135737: {"Unified_Ideograph", "Ideographic"},
    135738: {"Unified_Ideograph", "Ideographic"},
    135739: {"Unified_Ideograph", "Ideographic"},
    135740: {"Unified_Ideograph", "Ideographic"},
    135741: {"Unified_Ideograph", "Ideographic"},
    135742: {"Unified_Ideograph", "Ideographic"},
    135743: {"Unified_Ideograph", "Ideographic"},
    135744: {"Unified_Ideograph", "Ideographic"},
    135745: {"Unified_Ideograph", "Ideographic"},
    135746: {"Unified_Ideograph", "Ideographic"},
    135747: {"Unified_Ideograph", "Ideographic"},
    135748: {"Unified_Ideograph", "Ideographic"},
    135749: {"Unified_Ideograph", "Ideographic"},
    135750: {"Unified_Ideograph", "Ideographic"},
    135751: {"Unified_Ideograph", "Ideographic"},
    135752: {"Unified_Ideograph", "Ideographic"},
    135753: {"Unified_Ideograph", "Ideographic"},
    135754: {"Unified_Ideograph", "Ideographic"},
    135755: {"Unified_Ideograph", "Ideographic"},
    135756: {"Unified_Ideograph", "Ideographic"},
    135757: {"Unified_Ideograph", "Ideographic"},
    135758: {"Unified_Ideograph", "Ideographic"},
    135759: {"Unified_Ideograph", "Ideographic"},
    135760: {"Unified_Ideograph", "Ideographic"},
    135761: {"Unified_Ideograph", "Ideographic"},
    135762: {"Unified_Ideograph", "Ideographic"},
    135763: {"Unified_Ideograph", "Ideographic"},
    135764: {"Unified_Ideograph", "Ideographic"},
    135765: {"Unified_Ideograph", "Ideographic"},
    135766: {"Unified_Ideograph", "Ideographic"},
    135767: {"Unified_Ideograph", "Ideographic"},
    135768: {"Unified_Ideograph", "Ideographic"},
    135769: {"Unified_Ideograph", "Ideographic"},
    135770: {"Unified_Ideograph", "Ideographic"},
    135771: {"Unified_Ideograph", "Ideographic"},
    135772: {"Unified_Ideograph", "Ideographic"},
    135773: {"Unified_Ideograph", "Ideographic"},
    135774: {"Unified_Ideograph", "Ideographic"},
    135775: {"Unified_Ideograph", "Ideographic"},
    135776: {"Unified_Ideograph", "Ideographic"},
    135777: {"Unified_Ideograph", "Ideographic"},
    135778: {"Unified_Ideograph", "Ideographic"},
    135779: {"Unified_Ideograph", "Ideographic"},
    135780: {"Unified_Ideograph", "Ideographic"},
    135781: {"Unified_Ideograph", "Ideographic"},
    135782: {"Unified_Ideograph", "Ideographic"},
    135783: {"Unified_Ideograph", "Ideographic"},
    135784: {"Unified_Ideograph", "Ideographic"},
    135785: {"Unified_Ideograph", "Ideographic"},
    135786: {"Unified_Ideograph", "Ideographic"},
    135787: {"Unified_Ideograph", "Ideographic"},
    135788: {"Unified_Ideograph", "Ideographic"},
    135789: {"Unified_Ideograph", "Ideographic"},
    135790: {"Unified_Ideograph", "Ideographic"},
    135791: {"Unified_Ideograph", "Ideographic"},
    135792: {"Unified_Ideograph", "Ideographic"},
    135793: {"Unified_Ideograph", "Ideographic"},
    135794: {"Unified_Ideograph", "Ideographic"},
    135795: {"Unified_Ideograph", "Ideographic"},
    135796: {"Unified_Ideograph", "Ideographic"},
    135797: {"Unified_Ideograph", "Ideographic"},
    135798: {"Unified_Ideograph", "Ideographic"},
    135799: {"Unified_Ideograph", "Ideographic"},
    135800: {"Unified_Ideograph", "Ideographic"},
    135801: {"Unified_Ideograph", "Ideographic"},
    135802: {"Unified_Ideograph", "Ideographic"},
    135803: {"Unified_Ideograph", "Ideographic"},
    135804: {"Unified_Ideograph", "Ideographic"},
    135805: {"Unified_Ideograph", "Ideographic"},
    135806: {"Unified_Ideograph", "Ideographic"},
    135807: {"Unified_Ideograph", "Ideographic"},
    135808: {"Unified_Ideograph", "Ideographic"},
    135809: {"Unified_Ideograph", "Ideographic"},
    135810: {"Unified_Ideograph", "Ideographic"},
    135811: {"Unified_Ideograph", "Ideographic"},
    135812: {"Unified_Ideograph", "Ideographic"},
    135813: {"Unified_Ideograph", "Ideographic"},
    135814: {"Unified_Ideograph", "Ideographic"},
    135815: {"Unified_Ideograph", "Ideographic"},
    135816: {"Unified_Ideograph", "Ideographic"},
    135817: {"Unified_Ideograph", "Ideographic"},
    135818: {"Unified_Ideograph", "Ideographic"},
    135819: {"Unified_Ideograph", "Ideographic"},
    135820: {"Unified_Ideograph", "Ideographic"},
    135821: {"Unified_Ideograph", "Ideographic"},
    135822: {"Unified_Ideograph", "Ideographic"},
    135823: {"Unified_Ideograph", "Ideographic"},
    135824: {"Unified_Ideograph", "Ideographic"},
    135825: {"Unified_Ideograph", "Ideographic"},
    135826: {"Unified_Ideograph", "Ideographic"},
    135827: {"Unified_Ideograph", "Ideographic"},
    135828: {"Unified_Ideograph", "Ideographic"},
    135829: {"Unified_Ideograph", "Ideographic"},
    135830: {"Unified_Ideograph", "Ideographic"},
    135831: {"Unified_Ideograph", "Ideographic"},
    135832: {"Unified_Ideograph", "Ideographic"},
    135833: {"Unified_Ideograph", "Ideographic"},
    135834: {"Unified_Ideograph", "Ideographic"},
    135835: {"Unified_Ideograph", "Ideographic"},
    135836: {"Unified_Ideograph", "Ideographic"},
    135837: {"Unified_Ideograph", "Ideographic"},
    135838: {"Unified_Ideograph", "Ideographic"},
    135839: {"Unified_Ideograph", "Ideographic"},
    135840: {"Unified_Ideograph", "Ideographic"},
    135841: {"Unified_Ideograph", "Ideographic"},
    135842: {"Unified_Ideograph", "Ideographic"},
    135843: {"Unified_Ideograph", "Ideographic"},
    135844: {"Unified_Ideograph", "Ideographic"},
    135845: {"Unified_Ideograph", "Ideographic"},
    135846: {"Unified_Ideograph", "Ideographic"},
    135847: {"Unified_Ideograph", "Ideographic"},
    135848: {"Unified_Ideograph", "Ideographic"},
    135849: {"Unified_Ideograph", "Ideographic"},
    135850: {"Unified_Ideograph", "Ideographic"},
    135851: {"Unified_Ideograph", "Ideographic"},
    135852: {"Unified_Ideograph", "Ideographic"},
    135853: {"Unified_Ideograph", "Ideographic"},
    135854: {"Unified_Ideograph", "Ideographic"},
    135855: {"Unified_Ideograph", "Ideographic"},
    135856: {"Unified_Ideograph", "Ideographic"},
    135857: {"Unified_Ideograph", "Ideographic"},
    135858: {"Unified_Ideograph", "Ideographic"},
    135859: {"Unified_Ideograph", "Ideographic"},
    135860: {"Unified_Ideograph", "Ideographic"},
    135861: {"Unified_Ideograph", "Ideographic"},
    135862: {"Unified_Ideograph", "Ideographic"},
    135863: {"Unified_Ideograph", "Ideographic"},
    135864: {"Unified_Ideograph", "Ideographic"},
    135865: {"Unified_Ideograph", "Ideographic"},
    135866: {"Unified_Ideograph", "Ideographic"},
    135867: {"Unified_Ideograph", "Ideographic"},
    135868: {"Unified_Ideograph", "Ideographic"},
    135869: {"Unified_Ideograph", "Ideographic"},
    135870: {"Unified_Ideograph", "Ideographic"},
    135871: {"Unified_Ideograph", "Ideographic"},
    135872: {"Unified_Ideograph", "Ideographic"},
    135873: {"Unified_Ideograph", "Ideographic"},
    135874: {"Unified_Ideograph", "Ideographic"},
    135875: {"Unified_Ideograph", "Ideographic"},
    135876: {"Unified_Ideograph", "Ideographic"},
    135877: {"Unified_Ideograph", "Ideographic"},
    135878: {"Unified_Ideograph", "Ideographic"},
    135879: {"Unified_Ideograph", "Ideographic"},
    135880: {"Unified_Ideograph", "Ideographic"},
    135881: {"Unified_Ideograph", "Ideographic"},
    135882: {"Unified_Ideograph", "Ideographic"},
    135883: {"Unified_Ideograph", "Ideographic"},
    135884: {"Unified_Ideograph", "Ideographic"},
    135885: {"Unified_Ideograph", "Ideographic"},
    135886: {"Unified_Ideograph", "Ideographic"},
    135887: {"Unified_Ideograph", "Ideographic"},
    135888: {"Unified_Ideograph", "Ideographic"},
    135889: {"Unified_Ideograph", "Ideographic"},
    135890: {"Unified_Ideograph", "Ideographic"},
    135891: {"Unified_Ideograph", "Ideographic"},
    135892: {"Unified_Ideograph", "Ideographic"},
    135893: {"Unified_Ideograph", "Ideographic"},
    135894: {"Unified_Ideograph", "Ideographic"},
    135895: {"Unified_Ideograph", "Ideographic"},
    135896: {"Unified_Ideograph", "Ideographic"},
    135897: {"Unified_Ideograph", "Ideographic"},
    135898: {"Unified_Ideograph", "Ideographic"},
    135899: {"Unified_Ideograph", "Ideographic"},
    135900: {"Unified_Ideograph", "Ideographic"},
    135901: {"Unified_Ideograph", "Ideographic"},
    135902: {"Unified_Ideograph", "Ideographic"},
    135903: {"Unified_Ideograph", "Ideographic"},
    135904: {"Unified_Ideograph", "Ideographic"},
    135905: {"Unified_Ideograph", "Ideographic"},
    135906: {"Unified_Ideograph", "Ideographic"},
    135907: {"Unified_Ideograph", "Ideographic"},
    135908: {"Unified_Ideograph", "Ideographic"},
    135909: {"Unified_Ideograph", "Ideographic"},
    135910: {"Unified_Ideograph", "Ideographic"},
    135911: {"Unified_Ideograph", "Ideographic"},
    135912: {"Unified_Ideograph", "Ideographic"},
    135913: {"Unified_Ideograph", "Ideographic"},
    135914: {"Unified_Ideograph", "Ideographic"},
    135915: {"Unified_Ideograph", "Ideographic"},
    135916: {"Unified_Ideograph", "Ideographic"},
    135917: {"Unified_Ideograph", "Ideographic"},
    135918: {"Unified_Ideograph", "Ideographic"},
    135919: {"Unified_Ideograph", "Ideographic"},
    135920: {"Unified_Ideograph", "Ideographic"},
    135921: {"Unified_Ideograph", "Ideographic"},
    135922: {"Unified_Ideograph", "Ideographic"},
    135923: {"Unified_Ideograph", "Ideographic"},
    135924: {"Unified_Ideograph", "Ideographic"},
    135925: {"Unified_Ideograph", "Ideographic"},
    135926: {"Unified_Ideograph", "Ideographic"},
    135927: {"Unified_Ideograph", "Ideographic"},
    135928: {"Unified_Ideograph", "Ideographic"},
    135929: {"Unified_Ideograph", "Ideographic"},
    135930: {"Unified_Ideograph", "Ideographic"},
    135931: {"Unified_Ideograph", "Ideographic"},
    135932: {"Unified_Ideograph", "Ideographic"},
    135933: {"Unified_Ideograph", "Ideographic"},
    135934: {"Unified_Ideograph", "Ideographic"},
    135935: {"Unified_Ideograph", "Ideographic"},
    135936: {"Unified_Ideograph", "Ideographic"},
    135937: {"Unified_Ideograph", "Ideographic"},
    135938: {"Unified_Ideograph", "Ideographic"},
    135939: {"Unified_Ideograph", "Ideographic"},
    135940: {"Unified_Ideograph", "Ideographic"},
    135941: {"Unified_Ideograph", "Ideographic"},
    135942: {"Unified_Ideograph", "Ideographic"},
    135943: {"Unified_Ideograph", "Ideographic"},
    135944: {"Unified_Ideograph", "Ideographic"},
    135945: {"Unified_Ideograph", "Ideographic"},
    135946: {"Unified_Ideograph", "Ideographic"},
    135947: {"Unified_Ideograph", "Ideographic"},
    135948: {"Unified_Ideograph", "Ideographic"},
    135949: {"Unified_Ideograph", "Ideographic"},
    135950: {"Unified_Ideograph", "Ideographic"},
    135951: {"Unified_Ideograph", "Ideographic"},
    135952: {"Unified_Ideograph", "Ideographic"},
    135953: {"Unified_Ideograph", "Ideographic"},
    135954: {"Unified_Ideograph", "Ideographic"},
    135955: {"Unified_Ideograph", "Ideographic"},
    135956: {"Unified_Ideograph", "Ideographic"},
    135957: {"Unified_Ideograph", "Ideographic"},
    135958: {"Unified_Ideograph", "Ideographic"},
    135959: {"Unified_Ideograph", "Ideographic"},
    135960: {"Unified_Ideograph", "Ideographic"},
    135961: {"Unified_Ideograph", "Ideographic"},
    135962: {"Unified_Ideograph", "Ideographic"},
    135963: {"Unified_Ideograph", "Ideographic"},
    135964: {"Unified_Ideograph", "Ideographic"},
    135965: {"Unified_Ideograph", "Ideographic"},
    135966: {"Unified_Ideograph", "Ideographic"},
    135967: {"Unified_Ideograph", "Ideographic"},
    135968: {"Unified_Ideograph", "Ideographic"},
    135969: {"Unified_Ideograph", "Ideographic"},
    135970: {"Unified_Ideograph", "Ideographic"},
    135971: {"Unified_Ideograph", "Ideographic"},
    135972: {"Unified_Ideograph", "Ideographic"},
    135973: {"Unified_Ideograph", "Ideographic"},
    135974: {"Unified_Ideograph", "Ideographic"},
    135975: {"Unified_Ideograph", "Ideographic"},
    135976: {"Unified_Ideograph", "Ideographic"},
    135977: {"Unified_Ideograph", "Ideographic"},
    135978: {"Unified_Ideograph", "Ideographic"},
    135979: {"Unified_Ideograph", "Ideographic"},
    135980: {"Unified_Ideograph", "Ideographic"},
    135981: {"Unified_Ideograph", "Ideographic"},
    135982: {"Unified_Ideograph", "Ideographic"},
    135983: {"Unified_Ideograph", "Ideographic"},
    135984: {"Unified_Ideograph", "Ideographic"},
    135985: {"Unified_Ideograph", "Ideographic"},
    135986: {"Unified_Ideograph", "Ideographic"},
    135987: {"Unified_Ideograph", "Ideographic"},
    135988: {"Unified_Ideograph", "Ideographic"},
    135989: {"Unified_Ideograph", "Ideographic"},
    135990: {"Unified_Ideograph", "Ideographic"},
    135991: {"Unified_Ideograph", "Ideographic"},
    135992: {"Unified_Ideograph", "Ideographic"},
    135993: {"Unified_Ideograph", "Ideographic"},
    135994: {"Unified_Ideograph", "Ideographic"},
    135995: {"Unified_Ideograph", "Ideographic"},
    135996: {"Unified_Ideograph", "Ideographic"},
    135997: {"Unified_Ideograph", "Ideographic"},
    135998: {"Unified_Ideograph", "Ideographic"},
    135999: {"Unified_Ideograph", "Ideographic"},
    136000: {"Unified_Ideograph", "Ideographic"},
    136001: {"Unified_Ideograph", "Ideographic"},
    136002: {"Unified_Ideograph", "Ideographic"},
    136003: {"Unified_Ideograph", "Ideographic"},
    136004: {"Unified_Ideograph", "Ideographic"},
    136005: {"Unified_Ideograph", "Ideographic"},
    136006: {"Unified_Ideograph", "Ideographic"},
    136007: {"Unified_Ideograph", "Ideographic"},
    136008: {"Unified_Ideograph", "Ideographic"},
    136009: {"Unified_Ideograph", "Ideographic"},
    136010: {"Unified_Ideograph", "Ideographic"},
    136011: {"Unified_Ideograph", "Ideographic"},
    136012: {"Unified_Ideograph", "Ideographic"},
    136013: {"Unified_Ideograph", "Ideographic"},
    136014: {"Unified_Ideograph", "Ideographic"},
    136015: {"Unified_Ideograph", "Ideographic"},
    136016: {"Unified_Ideograph", "Ideographic"},
    136017: {"Unified_Ideograph", "Ideographic"},
    136018: {"Unified_Ideograph", "Ideographic"},
    136019: {"Unified_Ideograph", "Ideographic"},
    136020: {"Unified_Ideograph", "Ideographic"},
    136021: {"Unified_Ideograph", "Ideographic"},
    136022: {"Unified_Ideograph", "Ideographic"},
    136023: {"Unified_Ideograph", "Ideographic"},
    136024: {"Unified_Ideograph", "Ideographic"},
    136025: {"Unified_Ideograph", "Ideographic"},
    136026: {"Unified_Ideograph", "Ideographic"},
    136027: {"Unified_Ideograph", "Ideographic"},
    136028: {"Unified_Ideograph", "Ideographic"},
    136029: {"Unified_Ideograph", "Ideographic"},
    136030: {"Unified_Ideograph", "Ideographic"},
    136031: {"Unified_Ideograph", "Ideographic"},
    136032: {"Unified_Ideograph", "Ideographic"},
    136033: {"Unified_Ideograph", "Ideographic"},
    136034: {"Unified_Ideograph", "Ideographic"},
    136035: {"Unified_Ideograph", "Ideographic"},
    136036: {"Unified_Ideograph", "Ideographic"},
    136037: {"Unified_Ideograph", "Ideographic"},
    136038: {"Unified_Ideograph", "Ideographic"},
    136039: {"Unified_Ideograph", "Ideographic"},
    136040: {"Unified_Ideograph", "Ideographic"},
    136041: {"Unified_Ideograph", "Ideographic"},
    136042: {"Unified_Ideograph", "Ideographic"},
    136043: {"Unified_Ideograph", "Ideographic"},
    136044: {"Unified_Ideograph", "Ideographic"},
    136045: {"Unified_Ideograph", "Ideographic"},
    136046: {"Unified_Ideograph", "Ideographic"},
    136047: {"Unified_Ideograph", "Ideographic"},
    136048: {"Unified_Ideograph", "Ideographic"},
    136049: {"Unified_Ideograph", "Ideographic"},
    136050: {"Unified_Ideograph", "Ideographic"},
    136051: {"Unified_Ideograph", "Ideographic"},
    136052: {"Unified_Ideograph", "Ideographic"},
    136053: {"Unified_Ideograph", "Ideographic"},
    136054: {"Unified_Ideograph", "Ideographic"},
    136055: {"Unified_Ideograph", "Ideographic"},
    136056: {"Unified_Ideograph", "Ideographic"},
    136057: {"Unified_Ideograph", "Ideographic"},
    136058: {"Unified_Ideograph", "Ideographic"},
    136059: {"Unified_Ideograph", "Ideographic"},
    136060: {"Unified_Ideograph", "Ideographic"},
    136061: {"Unified_Ideograph", "Ideographic"},
    136062: {"Unified_Ideograph", "Ideographic"},
    136063: {"Unified_Ideograph", "Ideographic"},
    136064: {"Unified_Ideograph", "Ideographic"},
    136065: {"Unified_Ideograph", "Ideographic"},
    136066: {"Unified_Ideograph", "Ideographic"},
    136067: {"Unified_Ideograph", "Ideographic"},
    136068: {"Unified_Ideograph", "Ideographic"},
    136069: {"Unified_Ideograph", "Ideographic"},
    136070: {"Unified_Ideograph", "Ideographic"},
    136071: {"Unified_Ideograph", "Ideographic"},
    136072: {"Unified_Ideograph", "Ideographic"},
    136073: {"Unified_Ideograph", "Ideographic"},
    136074: {"Unified_Ideograph", "Ideographic"},
    136075: {"Unified_Ideograph", "Ideographic"},
    136076: {"Unified_Ideograph", "Ideographic"},
    136077: {"Unified_Ideograph", "Ideographic"},
    136078: {"Unified_Ideograph", "Ideographic"},
    136079: {"Unified_Ideograph", "Ideographic"},
    136080: {"Unified_Ideograph", "Ideographic"},
    136081: {"Unified_Ideograph", "Ideographic"},
    136082: {"Unified_Ideograph", "Ideographic"},
    136083: {"Unified_Ideograph", "Ideographic"},
    136084: {"Unified_Ideograph", "Ideographic"},
    136085: {"Unified_Ideograph", "Ideographic"},
    136086: {"Unified_Ideograph", "Ideographic"},
    136087: {"Unified_Ideograph", "Ideographic"},
    136088: {"Unified_Ideograph", "Ideographic"},
    136089: {"Unified_Ideograph", "Ideographic"},
    136090: {"Unified_Ideograph", "Ideographic"},
    136091: {"Unified_Ideograph", "Ideographic"},
    136092: {"Unified_Ideograph", "Ideographic"},
    136093: {"Unified_Ideograph", "Ideographic"},
    136094: {"Unified_Ideograph", "Ideographic"},
    136095: {"Unified_Ideograph", "Ideographic"},
    136096: {"Unified_Ideograph", "Ideographic"},
    136097: {"Unified_Ideograph", "Ideographic"},
    136098: {"Unified_Ideograph", "Ideographic"},
    136099: {"Unified_Ideograph", "Ideographic"},
    136100: {"Unified_Ideograph", "Ideographic"},
    136101: {"Unified_Ideograph", "Ideographic"},
    136102: {"Unified_Ideograph", "Ideographic"},
    136103: {"Unified_Ideograph", "Ideographic"},
    136104: {"Unified_Ideograph", "Ideographic"},
    136105: {"Unified_Ideograph", "Ideographic"},
    136106: {"Unified_Ideograph", "Ideographic"},
    136107: {"Unified_Ideograph", "Ideographic"},
    136108: {"Unified_Ideograph", "Ideographic"},
    136109: {"Unified_Ideograph", "Ideographic"},
    136110: {"Unified_Ideograph", "Ideographic"},
    136111: {"Unified_Ideograph", "Ideographic"},
    136112: {"Unified_Ideograph", "Ideographic"},
    136113: {"Unified_Ideograph", "Ideographic"},
    136114: {"Unified_Ideograph", "Ideographic"},
    136115: {"Unified_Ideograph", "Ideographic"},
    136116: {"Unified_Ideograph", "Ideographic"},
    136117: {"Unified_Ideograph", "Ideographic"},
    136118: {"Unified_Ideograph", "Ideographic"},
    136119: {"Unified_Ideograph", "Ideographic"},
    136120: {"Unified_Ideograph", "Ideographic"},
    136121: {"Unified_Ideograph", "Ideographic"},
    136122: {"Unified_Ideograph", "Ideographic"},
    136123: {"Unified_Ideograph", "Ideographic"},
    136124: {"Unified_Ideograph", "Ideographic"},
    136125: {"Unified_Ideograph", "Ideographic"},
    136126: {"Unified_Ideograph", "Ideographic"},
    136127: {"Unified_Ideograph", "Ideographic"},
    136128: {"Unified_Ideograph", "Ideographic"},
    136129: {"Unified_Ideograph", "Ideographic"},
    136130: {"Unified_Ideograph", "Ideographic"},
    136131: {"Unified_Ideograph", "Ideographic"},
    136132: {"Unified_Ideograph", "Ideographic"},
    136133: {"Unified_Ideograph", "Ideographic"},
    136134: {"Unified_Ideograph", "Ideographic"},
    136135: {"Unified_Ideograph", "Ideographic"},
    136136: {"Unified_Ideograph", "Ideographic"},
    136137: {"Unified_Ideograph", "Ideographic"},
    136138: {"Unified_Ideograph", "Ideographic"},
    136139: {"Unified_Ideograph", "Ideographic"},
    136140: {"Unified_Ideograph", "Ideographic"},
    136141: {"Unified_Ideograph", "Ideographic"},
    136142: {"Unified_Ideograph", "Ideographic"},
    136143: {"Unified_Ideograph", "Ideographic"},
    136144: {"Unified_Ideograph", "Ideographic"},
    136145: {"Unified_Ideograph", "Ideographic"},
    136146: {"Unified_Ideograph", "Ideographic"},
    136147: {"Unified_Ideograph", "Ideographic"},
    136148: {"Unified_Ideograph", "Ideographic"},
    136149: {"Unified_Ideograph", "Ideographic"},
    136150: {"Unified_Ideograph", "Ideographic"},
    136151: {"Unified_Ideograph", "Ideographic"},
    136152: {"Unified_Ideograph", "Ideographic"},
    136153: {"Unified_Ideograph", "Ideographic"},
    136154: {"Unified_Ideograph", "Ideographic"},
    136155: {"Unified_Ideograph", "Ideographic"},
    136156: {"Unified_Ideograph", "Ideographic"},
    136157: {"Unified_Ideograph", "Ideographic"},
    136158: {"Unified_Ideograph", "Ideographic"},
    136159: {"Unified_Ideograph", "Ideographic"},
    136160: {"Unified_Ideograph", "Ideographic"},
    136161: {"Unified_Ideograph", "Ideographic"},
    136162: {"Unified_Ideograph", "Ideographic"},
    136163: {"Unified_Ideograph", "Ideographic"},
    136164: {"Unified_Ideograph", "Ideographic"},
    136165: {"Unified_Ideograph", "Ideographic"},
    136166: {"Unified_Ideograph", "Ideographic"},
    136167: {"Unified_Ideograph", "Ideographic"},
    136168: {"Unified_Ideograph", "Ideographic"},
    136169: {"Unified_Ideograph", "Ideographic"},
    136170: {"Unified_Ideograph", "Ideographic"},
    136171: {"Unified_Ideograph", "Ideographic"},
    136172: {"Unified_Ideograph", "Ideographic"},
    136173: {"Unified_Ideograph", "Ideographic"},
    136174: {"Unified_Ideograph", "Ideographic"},
    136175: {"Unified_Ideograph", "Ideographic"},
    136176: {"Unified_Ideograph", "Ideographic"},
    136177: {"Unified_Ideograph", "Ideographic"},
    136178: {"Unified_Ideograph", "Ideographic"},
    136179: {"Unified_Ideograph", "Ideographic"},
    136180: {"Unified_Ideograph", "Ideographic"},
    136181: {"Unified_Ideograph", "Ideographic"},
    136182: {"Unified_Ideograph", "Ideographic"},
    136183: {"Unified_Ideograph", "Ideographic"},
    136184: {"Unified_Ideograph", "Ideographic"},
    136185: {"Unified_Ideograph", "Ideographic"},
    136186: {"Unified_Ideograph", "Ideographic"},
    136187: {"Unified_Ideograph", "Ideographic"},
    136188: {"Unified_Ideograph", "Ideographic"},
    136189: {"Unified_Ideograph", "Ideographic"},
    136190: {"Unified_Ideograph", "Ideographic"},
    136191: {"Unified_Ideograph", "Ideographic"},
    136192: {"Unified_Ideograph", "Ideographic"},
    136193: {"Unified_Ideograph", "Ideographic"},
    136194: {"Unified_Ideograph", "Ideographic"},
    136195: {"Unified_Ideograph", "Ideographic"},
    136196: {"Unified_Ideograph", "Ideographic"},
    136197: {"Unified_Ideograph", "Ideographic"},
    136198: {"Unified_Ideograph", "Ideographic"},
    136199: {"Unified_Ideograph", "Ideographic"},
    136200: {"Unified_Ideograph", "Ideographic"},
    136201: {"Unified_Ideograph", "Ideographic"},
    136202: {"Unified_Ideograph", "Ideographic"},
    136203: {"Unified_Ideograph", "Ideographic"},
    136204: {"Unified_Ideograph", "Ideographic"},
    136205: {"Unified_Ideograph", "Ideographic"},
    136206: {"Unified_Ideograph", "Ideographic"},
    136207: {"Unified_Ideograph", "Ideographic"},
    136208: {"Unified_Ideograph", "Ideographic"},
    136209: {"Unified_Ideograph", "Ideographic"},
    136210: {"Unified_Ideograph", "Ideographic"},
    136211: {"Unified_Ideograph", "Ideographic"},
    136212: {"Unified_Ideograph", "Ideographic"},
    136213: {"Unified_Ideograph", "Ideographic"},
    136214: {"Unified_Ideograph", "Ideographic"},
    136215: {"Unified_Ideograph", "Ideographic"},
    136216: {"Unified_Ideograph", "Ideographic"},
    136217: {"Unified_Ideograph", "Ideographic"},
    136218: {"Unified_Ideograph", "Ideographic"},
    136219: {"Unified_Ideograph", "Ideographic"},
    136220: {"Unified_Ideograph", "Ideographic"},
    136221: {"Unified_Ideograph", "Ideographic"},
    136222: {"Unified_Ideograph", "Ideographic"},
    136223: {"Unified_Ideograph", "Ideographic"},
    136224: {"Unified_Ideograph", "Ideographic"},
    136225: {"Unified_Ideograph", "Ideographic"},
    136226: {"Unified_Ideograph", "Ideographic"},
    136227: {"Unified_Ideograph", "Ideographic"},
    136228: {"Unified_Ideograph", "Ideographic"},
    136229: {"Unified_Ideograph", "Ideographic"},
    136230: {"Unified_Ideograph", "Ideographic"},
    136231: {"Unified_Ideograph", "Ideographic"},
    136232: {"Unified_Ideograph", "Ideographic"},
    136233: {"Unified_Ideograph", "Ideographic"},
    136234: {"Unified_Ideograph", "Ideographic"},
    136235: {"Unified_Ideograph", "Ideographic"},
    136236: {"Unified_Ideograph", "Ideographic"},
    136237: {"Unified_Ideograph", "Ideographic"},
    136238: {"Unified_Ideograph", "Ideographic"},
    136239: {"Unified_Ideograph", "Ideographic"},
    136240: {"Unified_Ideograph", "Ideographic"},
    136241: {"Unified_Ideograph", "Ideographic"},
    136242: {"Unified_Ideograph", "Ideographic"},
    136243: {"Unified_Ideograph", "Ideographic"},
    136244: {"Unified_Ideograph", "Ideographic"},
    136245: {"Unified_Ideograph", "Ideographic"},
    136246: {"Unified_Ideograph", "Ideographic"},
    136247: {"Unified_Ideograph", "Ideographic"},
    136248: {"Unified_Ideograph", "Ideographic"},
    136249: {"Unified_Ideograph", "Ideographic"},
    136250: {"Unified_Ideograph", "Ideographic"},
    136251: {"Unified_Ideograph", "Ideographic"},
    136252: {"Unified_Ideograph", "Ideographic"},
    136253: {"Unified_Ideograph", "Ideographic"},
    136254: {"Unified_Ideograph", "Ideographic"},
    136255: {"Unified_Ideograph", "Ideographic"},
    136256: {"Unified_Ideograph", "Ideographic"},
    136257: {"Unified_Ideograph", "Ideographic"},
    136258: {"Unified_Ideograph", "Ideographic"},
    136259: {"Unified_Ideograph", "Ideographic"},
    136260: {"Unified_Ideograph", "Ideographic"},
    136261: {"Unified_Ideograph", "Ideographic"},
    136262: {"Unified_Ideograph", "Ideographic"},
    136263: {"Unified_Ideograph", "Ideographic"},
    136264: {"Unified_Ideograph", "Ideographic"},
    136265: {"Unified_Ideograph", "Ideographic"},
    136266: {"Unified_Ideograph", "Ideographic"},
    136267: {"Unified_Ideograph", "Ideographic"},
    136268: {"Unified_Ideograph", "Ideographic"},
    136269: {"Unified_Ideograph", "Ideographic"},
    136270: {"Unified_Ideograph", "Ideographic"},
    136271: {"Unified_Ideograph", "Ideographic"},
    136272: {"Unified_Ideograph", "Ideographic"},
    136273: {"Unified_Ideograph", "Ideographic"},
    136274: {"Unified_Ideograph", "Ideographic"},
    136275: {"Unified_Ideograph", "Ideographic"},
    136276: {"Unified_Ideograph", "Ideographic"},
    136277: {"Unified_Ideograph", "Ideographic"},
    136278: {"Unified_Ideograph", "Ideographic"},
    136279: {"Unified_Ideograph", "Ideographic"},
    136280: {"Unified_Ideograph", "Ideographic"},
    136281: {"Unified_Ideograph", "Ideographic"},
    136282: {"Unified_Ideograph", "Ideographic"},
    136283: {"Unified_Ideograph", "Ideographic"},
    136284: {"Unified_Ideograph", "Ideographic"},
    136285: {"Unified_Ideograph", "Ideographic"},
    136286: {"Unified_Ideograph", "Ideographic"},
    136287: {"Unified_Ideograph", "Ideographic"},
    136288: {"Unified_Ideograph", "Ideographic"},
    136289: {"Unified_Ideograph", "Ideographic"},
    136290: {"Unified_Ideograph", "Ideographic"},
    136291: {"Unified_Ideograph", "Ideographic"},
    136292: {"Unified_Ideograph", "Ideographic"},
    136293: {"Unified_Ideograph", "Ideographic"},
    136294: {"Unified_Ideograph", "Ideographic"},
    136295: {"Unified_Ideograph", "Ideographic"},
    136296: {"Unified_Ideograph", "Ideographic"},
    136297: {"Unified_Ideograph", "Ideographic"},
    136298: {"Unified_Ideograph", "Ideographic"},
    136299: {"Unified_Ideograph", "Ideographic"},
    136300: {"Unified_Ideograph", "Ideographic"},
    136301: {"Unified_Ideograph", "Ideographic"},
    136302: {"Unified_Ideograph", "Ideographic"},
    136303: {"Unified_Ideograph", "Ideographic"},
    136304: {"Unified_Ideograph", "Ideographic"},
    136305: {"Unified_Ideograph", "Ideographic"},
    136306: {"Unified_Ideograph", "Ideographic"},
    136307: {"Unified_Ideograph", "Ideographic"},
    136308: {"Unified_Ideograph", "Ideographic"},
    136309: {"Unified_Ideograph", "Ideographic"},
    136310: {"Unified_Ideograph", "Ideographic"},
    136311: {"Unified_Ideograph", "Ideographic"},
    136312: {"Unified_Ideograph", "Ideographic"},
    136313: {"Unified_Ideograph", "Ideographic"},
    136314: {"Unified_Ideograph", "Ideographic"},
    136315: {"Unified_Ideograph", "Ideographic"},
    136316: {"Unified_Ideograph", "Ideographic"},
    136317: {"Unified_Ideograph", "Ideographic"},
    136318: {"Unified_Ideograph", "Ideographic"},
    136319: {"Unified_Ideograph", "Ideographic"},
    136320: {"Unified_Ideograph", "Ideographic"},
    136321: {"Unified_Ideograph", "Ideographic"},
    136322: {"Unified_Ideograph", "Ideographic"},
    136323: {"Unified_Ideograph", "Ideographic"},
    136324: {"Unified_Ideograph", "Ideographic"},
    136325: {"Unified_Ideograph", "Ideographic"},
    136326: {"Unified_Ideograph", "Ideographic"},
    136327: {"Unified_Ideograph", "Ideographic"},
    136328: {"Unified_Ideograph", "Ideographic"},
    136329: {"Unified_Ideograph", "Ideographic"},
    136330: {"Unified_Ideograph", "Ideographic"},
    136331: {"Unified_Ideograph", "Ideographic"},
    136332: {"Unified_Ideograph", "Ideographic"},
    136333: {"Unified_Ideograph", "Ideographic"},
    136334: {"Unified_Ideograph", "Ideographic"},
    136335: {"Unified_Ideograph", "Ideographic"},
    136336: {"Unified_Ideograph", "Ideographic"},
    136337: {"Unified_Ideograph", "Ideographic"},
    136338: {"Unified_Ideograph", "Ideographic"},
    136339: {"Unified_Ideograph", "Ideographic"},
    136340: {"Unified_Ideograph", "Ideographic"},
    136341: {"Unified_Ideograph", "Ideographic"},
    136342: {"Unified_Ideograph", "Ideographic"},
    136343: {"Unified_Ideograph", "Ideographic"},
    136344: {"Unified_Ideograph", "Ideographic"},
    136345: {"Unified_Ideograph", "Ideographic"},
    136346: {"Unified_Ideograph", "Ideographic"},
    136347: {"Unified_Ideograph", "Ideographic"},
    136348: {"Unified_Ideograph", "Ideographic"},
    136349: {"Unified_Ideograph", "Ideographic"},
    136350: {"Unified_Ideograph", "Ideographic"},
    136351: {"Unified_Ideograph", "Ideographic"},
    136352: {"Unified_Ideograph", "Ideographic"},
    136353: {"Unified_Ideograph", "Ideographic"},
    136354: {"Unified_Ideograph", "Ideographic"},
    136355: {"Unified_Ideograph", "Ideographic"},
    136356: {"Unified_Ideograph", "Ideographic"},
    136357: {"Unified_Ideograph", "Ideographic"},
    136358: {"Unified_Ideograph", "Ideographic"},
    136359: {"Unified_Ideograph", "Ideographic"},
    136360: {"Unified_Ideograph", "Ideographic"},
    136361: {"Unified_Ideograph", "Ideographic"},
    136362: {"Unified_Ideograph", "Ideographic"},
    136363: {"Unified_Ideograph", "Ideographic"},
    136364: {"Unified_Ideograph", "Ideographic"},
    136365: {"Unified_Ideograph", "Ideographic"},
    136366: {"Unified_Ideograph", "Ideographic"},
    136367: {"Unified_Ideograph", "Ideographic"},
    136368: {"Unified_Ideograph", "Ideographic"},
    136369: {"Unified_Ideograph", "Ideographic"},
    136370: {"Unified_Ideograph", "Ideographic"},
    136371: {"Unified_Ideograph", "Ideographic"},
    136372: {"Unified_Ideograph", "Ideographic"},
    136373: {"Unified_Ideograph", "Ideographic"},
    136374: {"Unified_Ideograph", "Ideographic"},
    136375: {"Unified_Ideograph", "Ideographic"},
    136376: {"Unified_Ideograph", "Ideographic"},
    136377: {"Unified_Ideograph", "Ideographic"},
    136378: {"Unified_Ideograph", "Ideographic"},
    136379: {"Unified_Ideograph", "Ideographic"},
    136380: {"Unified_Ideograph", "Ideographic"},
    136381: {"Unified_Ideograph", "Ideographic"},
    136382: {"Unified_Ideograph", "Ideographic"},
    136383: {"Unified_Ideograph", "Ideographic"},
    136384: {"Unified_Ideograph", "Ideographic"},
    136385: {"Unified_Ideograph", "Ideographic"},
    136386: {"Unified_Ideograph", "Ideographic"},
    136387: {"Unified_Ideograph", "Ideographic"},
    136388: {"Unified_Ideograph", "Ideographic"},
    136389: {"Unified_Ideograph", "Ideographic"},
    136390: {"Unified_Ideograph", "Ideographic"},
    136391: {"Unified_Ideograph", "Ideographic"},
    136392: {"Unified_Ideograph", "Ideographic"},
    136393: {"Unified_Ideograph", "Ideographic"},
    136394: {"Unified_Ideograph", "Ideographic"},
    136395: {"Unified_Ideograph", "Ideographic"},
    136396: {"Unified_Ideograph", "Ideographic"},
    136397: {"Unified_Ideograph", "Ideographic"},
    136398: {"Unified_Ideograph", "Ideographic"},
    136399: {"Unified_Ideograph", "Ideographic"},
    136400: {"Unified_Ideograph", "Ideographic"},
    136401: {"Unified_Ideograph", "Ideographic"},
    136402: {"Unified_Ideograph", "Ideographic"},
    136403: {"Unified_Ideograph", "Ideographic"},
    136404: {"Unified_Ideograph", "Ideographic"},
    136405: {"Unified_Ideograph", "Ideographic"},
    136406: {"Unified_Ideograph", "Ideographic"},
    136407: {"Unified_Ideograph", "Ideographic"},
    136408: {"Unified_Ideograph", "Ideographic"},
    136409: {"Unified_Ideograph", "Ideographic"},
    136410: {"Unified_Ideograph", "Ideographic"},
    136411: {"Unified_Ideograph", "Ideographic"},
    136412: {"Unified_Ideograph", "Ideographic"},
    136413: {"Unified_Ideograph", "Ideographic"},
    136414: {"Unified_Ideograph", "Ideographic"},
    136415: {"Unified_Ideograph", "Ideographic"},
    136416: {"Unified_Ideograph", "Ideographic"},
    136417: {"Unified_Ideograph", "Ideographic"},
    136418: {"Unified_Ideograph", "Ideographic"},
    136419: {"Unified_Ideograph", "Ideographic"},
    136420: {"Unified_Ideograph", "Ideographic"},
    136421: {"Unified_Ideograph", "Ideographic"},
    136422: {"Unified_Ideograph", "Ideographic"},
    136423: {"Unified_Ideograph", "Ideographic"},
    136424: {"Unified_Ideograph", "Ideographic"},
    136425: {"Unified_Ideograph", "Ideographic"},
    136426: {"Unified_Ideograph", "Ideographic"},
    136427: {"Unified_Ideograph", "Ideographic"},
    136428: {"Unified_Ideograph", "Ideographic"},
    136429: {"Unified_Ideograph", "Ideographic"},
    136430: {"Unified_Ideograph", "Ideographic"},
    136431: {"Unified_Ideograph", "Ideographic"},
    136432: {"Unified_Ideograph", "Ideographic"},
    136433: {"Unified_Ideograph", "Ideographic"},
    136434: {"Unified_Ideograph", "Ideographic"},
    136435: {"Unified_Ideograph", "Ideographic"},
    136436: {"Unified_Ideograph", "Ideographic"},
    136437: {"Unified_Ideograph", "Ideographic"},
    136438: {"Unified_Ideograph", "Ideographic"},
    136439: {"Unified_Ideograph", "Ideographic"},
    136440: {"Unified_Ideograph", "Ideographic"},
    136441: {"Unified_Ideograph", "Ideographic"},
    136442: {"Unified_Ideograph", "Ideographic"},
    136443: {"Unified_Ideograph", "Ideographic"},
    136444: {"Unified_Ideograph", "Ideographic"},
    136445: {"Unified_Ideograph", "Ideographic"},
    136446: {"Unified_Ideograph", "Ideographic"},
    136447: {"Unified_Ideograph", "Ideographic"},
    136448: {"Unified_Ideograph", "Ideographic"},
    136449: {"Unified_Ideograph", "Ideographic"},
    136450: {"Unified_Ideograph", "Ideographic"},
    136451: {"Unified_Ideograph", "Ideographic"},
    136452: {"Unified_Ideograph", "Ideographic"},
    136453: {"Unified_Ideograph", "Ideographic"},
    136454: {"Unified_Ideograph", "Ideographic"},
    136455: {"Unified_Ideograph", "Ideographic"},
    136456: {"Unified_Ideograph", "Ideographic"},
    136457: {"Unified_Ideograph", "Ideographic"},
    136458: {"Unified_Ideograph", "Ideographic"},
    136459: {"Unified_Ideograph", "Ideographic"},
    136460: {"Unified_Ideograph", "Ideographic"},
    136461: {"Unified_Ideograph", "Ideographic"},
    136462: {"Unified_Ideograph", "Ideographic"},
    136463: {"Unified_Ideograph", "Ideographic"},
    136464: {"Unified_Ideograph", "Ideographic"},
    136465: {"Unified_Ideograph", "Ideographic"},
    136466: {"Unified_Ideograph", "Ideographic"},
    136467: {"Unified_Ideograph", "Ideographic"},
    136468: {"Unified_Ideograph", "Ideographic"},
    136469: {"Unified_Ideograph", "Ideographic"},
    136470: {"Unified_Ideograph", "Ideographic"},
    136471: {"Unified_Ideograph", "Ideographic"},
    136472: {"Unified_Ideograph", "Ideographic"},
    136473: {"Unified_Ideograph", "Ideographic"},
    136474: {"Unified_Ideograph", "Ideographic"},
    136475: {"Unified_Ideograph", "Ideographic"},
    136476: {"Unified_Ideograph", "Ideographic"},
    136477: {"Unified_Ideograph", "Ideographic"},
    136478: {"Unified_Ideograph", "Ideographic"},
    136479: {"Unified_Ideograph", "Ideographic"},
    136480: {"Unified_Ideograph", "Ideographic"},
    136481: {"Unified_Ideograph", "Ideographic"},
    136482: {"Unified_Ideograph", "Ideographic"},
    136483: {"Unified_Ideograph", "Ideographic"},
    136484: {"Unified_Ideograph", "Ideographic"},
    136485: {"Unified_Ideograph", "Ideographic"},
    136486: {"Unified_Ideograph", "Ideographic"},
    136487: {"Unified_Ideograph", "Ideographic"},
    136488: {"Unified_Ideograph", "Ideographic"},
    136489: {"Unified_Ideograph", "Ideographic"},
    136490: {"Unified_Ideograph", "Ideographic"},
    136491: {"Unified_Ideograph", "Ideographic"},
    136492: {"Unified_Ideograph", "Ideographic"},
    136493: {"Unified_Ideograph", "Ideographic"},
    136494: {"Unified_Ideograph", "Ideographic"},
    136495: {"Unified_Ideograph", "Ideographic"},
    136496: {"Unified_Ideograph", "Ideographic"},
    136497: {"Unified_Ideograph", "Ideographic"},
    136498: {"Unified_Ideograph", "Ideographic"},
    136499: {"Unified_Ideograph", "Ideographic"},
    136500: {"Unified_Ideograph", "Ideographic"},
    136501: {"Unified_Ideograph", "Ideographic"},
    136502: {"Unified_Ideograph", "Ideographic"},
    136503: {"Unified_Ideograph", "Ideographic"},
    136504: {"Unified_Ideograph", "Ideographic"},
    136505: {"Unified_Ideograph", "Ideographic"},
    136506: {"Unified_Ideograph", "Ideographic"},
    136507: {"Unified_Ideograph", "Ideographic"},
    136508: {"Unified_Ideograph", "Ideographic"},
    136509: {"Unified_Ideograph", "Ideographic"},
    136510: {"Unified_Ideograph", "Ideographic"},
    136511: {"Unified_Ideograph", "Ideographic"},
    136512: {"Unified_Ideograph", "Ideographic"},
    136513: {"Unified_Ideograph", "Ideographic"},
    136514: {"Unified_Ideograph", "Ideographic"},
    136515: {"Unified_Ideograph", "Ideographic"},
    136516: {"Unified_Ideograph", "Ideographic"},
    136517: {"Unified_Ideograph", "Ideographic"},
    136518: {"Unified_Ideograph", "Ideographic"},
    136519: {"Unified_Ideograph", "Ideographic"},
    136520: {"Unified_Ideograph", "Ideographic"},
    136521: {"Unified_Ideograph", "Ideographic"},
    136522: {"Unified_Ideograph", "Ideographic"},
    136523: {"Unified_Ideograph", "Ideographic"},
    136524: {"Unified_Ideograph", "Ideographic"},
    136525: {"Unified_Ideograph", "Ideographic"},
    136526: {"Unified_Ideograph", "Ideographic"},
    136527: {"Unified_Ideograph", "Ideographic"},
    136528: {"Unified_Ideograph", "Ideographic"},
    136529: {"Unified_Ideograph", "Ideographic"},
    136530: {"Unified_Ideograph", "Ideographic"},
    136531: {"Unified_Ideograph", "Ideographic"},
    136532: {"Unified_Ideograph", "Ideographic"},
    136533: {"Unified_Ideograph", "Ideographic"},
    136534: {"Unified_Ideograph", "Ideographic"},
    136535: {"Unified_Ideograph", "Ideographic"},
    136536: {"Unified_Ideograph", "Ideographic"},
    136537: {"Unified_Ideograph", "Ideographic"},
    136538: {"Unified_Ideograph", "Ideographic"},
    136539: {"Unified_Ideograph", "Ideographic"},
    136540: {"Unified_Ideograph", "Ideographic"},
    136541: {"Unified_Ideograph", "Ideographic"},
    136542: {"Unified_Ideograph", "Ideographic"},
    136543: {"Unified_Ideograph", "Ideographic"},
    136544: {"Unified_Ideograph", "Ideographic"},
    136545: {"Unified_Ideograph", "Ideographic"},
    136546: {"Unified_Ideograph", "Ideographic"},
    136547: {"Unified_Ideograph", "Ideographic"},
    136548: {"Unified_Ideograph", "Ideographic"},
    136549: {"Unified_Ideograph", "Ideographic"},
    136550: {"Unified_Ideograph", "Ideographic"},
    136551: {"Unified_Ideograph", "Ideographic"},
    136552: {"Unified_Ideograph", "Ideographic"},
    136553: {"Unified_Ideograph", "Ideographic"},
    136554: {"Unified_Ideograph", "Ideographic"},
    136555: {"Unified_Ideograph", "Ideographic"},
    136556: {"Unified_Ideograph", "Ideographic"},
    136557: {"Unified_Ideograph", "Ideographic"},
    136558: {"Unified_Ideograph", "Ideographic"},
    136559: {"Unified_Ideograph", "Ideographic"},
    136560: {"Unified_Ideograph", "Ideographic"},
    136561: {"Unified_Ideograph", "Ideographic"},
    136562: {"Unified_Ideograph", "Ideographic"},
    136563: {"Unified_Ideograph", "Ideographic"},
    136564: {"Unified_Ideograph", "Ideographic"},
    136565: {"Unified_Ideograph", "Ideographic"},
    136566: {"Unified_Ideograph", "Ideographic"},
    136567: {"Unified_Ideograph", "Ideographic"},
    136568: {"Unified_Ideograph", "Ideographic"},
    136569: {"Unified_Ideograph", "Ideographic"},
    136570: {"Unified_Ideograph", "Ideographic"},
    136571: {"Unified_Ideograph", "Ideographic"},
    136572: {"Unified_Ideograph", "Ideographic"},
    136573: {"Unified_Ideograph", "Ideographic"},
    136574: {"Unified_Ideograph", "Ideographic"},
    136575: {"Unified_Ideograph", "Ideographic"},
    136576: {"Unified_Ideograph", "Ideographic"},
    136577: {"Unified_Ideograph", "Ideographic"},
    136578: {"Unified_Ideograph", "Ideographic"},
    136579: {"Unified_Ideograph", "Ideographic"},
    136580: {"Unified_Ideograph", "Ideographic"},
    136581: {"Unified_Ideograph", "Ideographic"},
    136582: {"Unified_Ideograph", "Ideographic"},
    136583: {"Unified_Ideograph", "Ideographic"},
    136584: {"Unified_Ideograph", "Ideographic"},
    136585: {"Unified_Ideograph", "Ideographic"},
    136586: {"Unified_Ideograph", "Ideographic"},
    136587: {"Unified_Ideograph", "Ideographic"},
    136588: {"Unified_Ideograph", "Ideographic"},
    136589: {"Unified_Ideograph", "Ideographic"},
    136590: {"Unified_Ideograph", "Ideographic"},
    136591: {"Unified_Ideograph", "Ideographic"},
    136592: {"Unified_Ideograph", "Ideographic"},
    136593: {"Unified_Ideograph", "Ideographic"},
    136594: {"Unified_Ideograph", "Ideographic"},
    136595: {"Unified_Ideograph", "Ideographic"},
    136596: {"Unified_Ideograph", "Ideographic"},
    136597: {"Unified_Ideograph", "Ideographic"},
    136598: {"Unified_Ideograph", "Ideographic"},
    136599: {"Unified_Ideograph", "Ideographic"},
    136600: {"Unified_Ideograph", "Ideographic"},
    136601: {"Unified_Ideograph", "Ideographic"},
    136602: {"Unified_Ideograph", "Ideographic"},
    136603: {"Unified_Ideograph", "Ideographic"},
    136604: {"Unified_Ideograph", "Ideographic"},
    136605: {"Unified_Ideograph", "Ideographic"},
    136606: {"Unified_Ideograph", "Ideographic"},
    136607: {"Unified_Ideograph", "Ideographic"},
    136608: {"Unified_Ideograph", "Ideographic"},
    136609: {"Unified_Ideograph", "Ideographic"},
    136610: {"Unified_Ideograph", "Ideographic"},
    136611: {"Unified_Ideograph", "Ideographic"},
    136612: {"Unified_Ideograph", "Ideographic"},
    136613: {"Unified_Ideograph", "Ideographic"},
    136614: {"Unified_Ideograph", "Ideographic"},
    136615: {"Unified_Ideograph", "Ideographic"},
    136616: {"Unified_Ideograph", "Ideographic"},
    136617: {"Unified_Ideograph", "Ideographic"},
    136618: {"Unified_Ideograph", "Ideographic"},
    136619: {"Unified_Ideograph", "Ideographic"},
    136620: {"Unified_Ideograph", "Ideographic"},
    136621: {"Unified_Ideograph", "Ideographic"},
    136622: {"Unified_Ideograph", "Ideographic"},
    136623: {"Unified_Ideograph", "Ideographic"},
    136624: {"Unified_Ideograph", "Ideographic"},
    136625: {"Unified_Ideograph", "Ideographic"},
    136626: {"Unified_Ideograph", "Ideographic"},
    136627: {"Unified_Ideograph", "Ideographic"},
    136628: {"Unified_Ideograph", "Ideographic"},
    136629: {"Unified_Ideograph", "Ideographic"},
    136630: {"Unified_Ideograph", "Ideographic"},
    136631: {"Unified_Ideograph", "Ideographic"},
    136632: {"Unified_Ideograph", "Ideographic"},
    136633: {"Unified_Ideograph", "Ideographic"},
    136634: {"Unified_Ideograph", "Ideographic"},
    136635: {"Unified_Ideograph", "Ideographic"},
    136636: {"Unified_Ideograph", "Ideographic"},
    136637: {"Unified_Ideograph", "Ideographic"},
    136638: {"Unified_Ideograph", "Ideographic"},
    136639: {"Unified_Ideograph", "Ideographic"},
    136640: {"Unified_Ideograph", "Ideographic"},
    136641: {"Unified_Ideograph", "Ideographic"},
    136642: {"Unified_Ideograph", "Ideographic"},
    136643: {"Unified_Ideograph", "Ideographic"},
    136644: {"Unified_Ideograph", "Ideographic"},
    136645: {"Unified_Ideograph", "Ideographic"},
    136646: {"Unified_Ideograph", "Ideographic"},
    136647: {"Unified_Ideograph", "Ideographic"},
    136648: {"Unified_Ideograph", "Ideographic"},
    136649: {"Unified_Ideograph", "Ideographic"},
    136650: {"Unified_Ideograph", "Ideographic"},
    136651: {"Unified_Ideograph", "Ideographic"},
    136652: {"Unified_Ideograph", "Ideographic"},
    136653: {"Unified_Ideograph", "Ideographic"},
    136654: {"Unified_Ideograph", "Ideographic"},
    136655: {"Unified_Ideograph", "Ideographic"},
    136656: {"Unified_Ideograph", "Ideographic"},
    136657: {"Unified_Ideograph", "Ideographic"},
    136658: {"Unified_Ideograph", "Ideographic"},
    136659: {"Unified_Ideograph", "Ideographic"},
    136660: {"Unified_Ideograph", "Ideographic"},
    136661: {"Unified_Ideograph", "Ideographic"},
    136662: {"Unified_Ideograph", "Ideographic"},
    136663: {"Unified_Ideograph", "Ideographic"},
    136664: {"Unified_Ideograph", "Ideographic"},
    136665: {"Unified_Ideograph", "Ideographic"},
    136666: {"Unified_Ideograph", "Ideographic"},
    136667: {"Unified_Ideograph", "Ideographic"},
    136668: {"Unified_Ideograph", "Ideographic"},
    136669: {"Unified_Ideograph", "Ideographic"},
    136670: {"Unified_Ideograph", "Ideographic"},
    136671: {"Unified_Ideograph", "Ideographic"},
    136672: {"Unified_Ideograph", "Ideographic"},
    136673: {"Unified_Ideograph", "Ideographic"},
    136674: {"Unified_Ideograph", "Ideographic"},
    136675: {"Unified_Ideograph", "Ideographic"},
    136676: {"Unified_Ideograph", "Ideographic"},
    136677: {"Unified_Ideograph", "Ideographic"},
    136678: {"Unified_Ideograph", "Ideographic"},
    136679: {"Unified_Ideograph", "Ideographic"},
    136680: {"Unified_Ideograph", "Ideographic"},
    136681: {"Unified_Ideograph", "Ideographic"},
    136682: {"Unified_Ideograph", "Ideographic"},
    136683: {"Unified_Ideograph", "Ideographic"},
    136684: {"Unified_Ideograph", "Ideographic"},
    136685: {"Unified_Ideograph", "Ideographic"},
    136686: {"Unified_Ideograph", "Ideographic"},
    136687: {"Unified_Ideograph", "Ideographic"},
    136688: {"Unified_Ideograph", "Ideographic"},
    136689: {"Unified_Ideograph", "Ideographic"},
    136690: {"Unified_Ideograph", "Ideographic"},
    136691: {"Unified_Ideograph", "Ideographic"},
    136692: {"Unified_Ideograph", "Ideographic"},
    136693: {"Unified_Ideograph", "Ideographic"},
    136694: {"Unified_Ideograph", "Ideographic"},
    136695: {"Unified_Ideograph", "Ideographic"},
    136696: {"Unified_Ideograph", "Ideographic"},
    136697: {"Unified_Ideograph", "Ideographic"},
    136698: {"Unified_Ideograph", "Ideographic"},
    136699: {"Unified_Ideograph", "Ideographic"},
    136700: {"Unified_Ideograph", "Ideographic"},
    136701: {"Unified_Ideograph", "Ideographic"},
    136702: {"Unified_Ideograph", "Ideographic"},
    136703: {"Unified_Ideograph", "Ideographic"},
    136704: {"Unified_Ideograph", "Ideographic"},
    136705: {"Unified_Ideograph", "Ideographic"},
    136706: {"Unified_Ideograph", "Ideographic"},
    136707: {"Unified_Ideograph", "Ideographic"},
    136708: {"Unified_Ideograph", "Ideographic"},
    136709: {"Unified_Ideograph", "Ideographic"},
    136710: {"Unified_Ideograph", "Ideographic"},
    136711: {"Unified_Ideograph", "Ideographic"},
    136712: {"Unified_Ideograph", "Ideographic"},
    136713: {"Unified_Ideograph", "Ideographic"},
    136714: {"Unified_Ideograph", "Ideographic"},
    136715: {"Unified_Ideograph", "Ideographic"},
    136716: {"Unified_Ideograph", "Ideographic"},
    136717: {"Unified_Ideograph", "Ideographic"},
    136718: {"Unified_Ideograph", "Ideographic"},
    136719: {"Unified_Ideograph", "Ideographic"},
    136720: {"Unified_Ideograph", "Ideographic"},
    136721: {"Unified_Ideograph", "Ideographic"},
    136722: {"Unified_Ideograph", "Ideographic"},
    136723: {"Unified_Ideograph", "Ideographic"},
    136724: {"Unified_Ideograph", "Ideographic"},
    136725: {"Unified_Ideograph", "Ideographic"},
    136726: {"Unified_Ideograph", "Ideographic"},
    136727: {"Unified_Ideograph", "Ideographic"},
    136728: {"Unified_Ideograph", "Ideographic"},
    136729: {"Unified_Ideograph", "Ideographic"},
    136730: {"Unified_Ideograph", "Ideographic"},
    136731: {"Unified_Ideograph", "Ideographic"},
    136732: {"Unified_Ideograph", "Ideographic"},
    136733: {"Unified_Ideograph", "Ideographic"},
    136734: {"Unified_Ideograph", "Ideographic"},
    136735: {"Unified_Ideograph", "Ideographic"},
    136736: {"Unified_Ideograph", "Ideographic"},
    136737: {"Unified_Ideograph", "Ideographic"},
    136738: {"Unified_Ideograph", "Ideographic"},
    136739: {"Unified_Ideograph", "Ideographic"},
    136740: {"Unified_Ideograph", "Ideographic"},
    136741: {"Unified_Ideograph", "Ideographic"},
    136742: {"Unified_Ideograph", "Ideographic"},
    136743: {"Unified_Ideograph", "Ideographic"},
    136744: {"Unified_Ideograph", "Ideographic"},
    136745: {"Unified_Ideograph", "Ideographic"},
    136746: {"Unified_Ideograph", "Ideographic"},
    136747: {"Unified_Ideograph", "Ideographic"},
    136748: {"Unified_Ideograph", "Ideographic"},
    136749: {"Unified_Ideograph", "Ideographic"},
    136750: {"Unified_Ideograph", "Ideographic"},
    136751: {"Unified_Ideograph", "Ideographic"},
    136752: {"Unified_Ideograph", "Ideographic"},
    136753: {"Unified_Ideograph", "Ideographic"},
    136754: {"Unified_Ideograph", "Ideographic"},
    136755: {"Unified_Ideograph", "Ideographic"},
    136756: {"Unified_Ideograph", "Ideographic"},
    136757: {"Unified_Ideograph", "Ideographic"},
    136758: {"Unified_Ideograph", "Ideographic"},
    136759: {"Unified_Ideograph", "Ideographic"},
    136760: {"Unified_Ideograph", "Ideographic"},
    136761: {"Unified_Ideograph", "Ideographic"},
    136762: {"Unified_Ideograph", "Ideographic"},
    136763: {"Unified_Ideograph", "Ideographic"},
    136764: {"Unified_Ideograph", "Ideographic"},
    136765: {"Unified_Ideograph", "Ideographic"},
    136766: {"Unified_Ideograph", "Ideographic"},
    136767: {"Unified_Ideograph", "Ideographic"},
    136768: {"Unified_Ideograph", "Ideographic"},
    136769: {"Unified_Ideograph", "Ideographic"},
    136770: {"Unified_Ideograph", "Ideographic"},
    136771: {"Unified_Ideograph", "Ideographic"},
    136772: {"Unified_Ideograph", "Ideographic"},
    136773: {"Unified_Ideograph", "Ideographic"},
    136774: {"Unified_Ideograph", "Ideographic"},
    136775: {"Unified_Ideograph", "Ideographic"},
    136776: {"Unified_Ideograph", "Ideographic"},
    136777: {"Unified_Ideograph", "Ideographic"},
    136778: {"Unified_Ideograph", "Ideographic"},
    136779: {"Unified_Ideograph", "Ideographic"},
    136780: {"Unified_Ideograph", "Ideographic"},
    136781: {"Unified_Ideograph", "Ideographic"},
    136782: {"Unified_Ideograph", "Ideographic"},
    136783: {"Unified_Ideograph", "Ideographic"},
    136784: {"Unified_Ideograph", "Ideographic"},
    136785: {"Unified_Ideograph", "Ideographic"},
    136786: {"Unified_Ideograph", "Ideographic"},
    136787: {"Unified_Ideograph", "Ideographic"},
    136788: {"Unified_Ideograph", "Ideographic"},
    136789: {"Unified_Ideograph", "Ideographic"},
    136790: {"Unified_Ideograph", "Ideographic"},
    136791: {"Unified_Ideograph", "Ideographic"},
    136792: {"Unified_Ideograph", "Ideographic"},
    136793: {"Unified_Ideograph", "Ideographic"},
    136794: {"Unified_Ideograph", "Ideographic"},
    136795: {"Unified_Ideograph", "Ideographic"},
    136796: {"Unified_Ideograph", "Ideographic"},
    136797: {"Unified_Ideograph", "Ideographic"},
    136798: {"Unified_Ideograph", "Ideographic"},
    136799: {"Unified_Ideograph", "Ideographic"},
    136800: {"Unified_Ideograph", "Ideographic"},
    136801: {"Unified_Ideograph", "Ideographic"},
    136802: {"Unified_Ideograph", "Ideographic"},
    136803: {"Unified_Ideograph", "Ideographic"},
    136804: {"Unified_Ideograph", "Ideographic"},
    136805: {"Unified_Ideograph", "Ideographic"},
    136806: {"Unified_Ideograph", "Ideographic"},
    136807: {"Unified_Ideograph", "Ideographic"},
    136808: {"Unified_Ideograph", "Ideographic"},
    136809: {"Unified_Ideograph", "Ideographic"},
    136810: {"Unified_Ideograph", "Ideographic"},
    136811: {"Unified_Ideograph", "Ideographic"},
    136812: {"Unified_Ideograph", "Ideographic"},
    136813: {"Unified_Ideograph", "Ideographic"},
    136814: {"Unified_Ideograph", "Ideographic"},
    136815: {"Unified_Ideograph", "Ideographic"},
    136816: {"Unified_Ideograph", "Ideographic"},
    136817: {"Unified_Ideograph", "Ideographic"},
    136818: {"Unified_Ideograph", "Ideographic"},
    136819: {"Unified_Ideograph", "Ideographic"},
    136820: {"Unified_Ideograph", "Ideographic"},
    136821: {"Unified_Ideograph", "Ideographic"},
    136822: {"Unified_Ideograph", "Ideographic"},
    136823: {"Unified_Ideograph", "Ideographic"},
    136824: {"Unified_Ideograph", "Ideographic"},
    136825: {"Unified_Ideograph", "Ideographic"},
    136826: {"Unified_Ideograph", "Ideographic"},
    136827: {"Unified_Ideograph", "Ideographic"},
    136828: {"Unified_Ideograph", "Ideographic"},
    136829: {"Unified_Ideograph", "Ideographic"},
    136830: {"Unified_Ideograph", "Ideographic"},
    136831: {"Unified_Ideograph", "Ideographic"},
    136832: {"Unified_Ideograph", "Ideographic"},
    136833: {"Unified_Ideograph", "Ideographic"},
    136834: {"Unified_Ideograph", "Ideographic"},
    136835: {"Unified_Ideograph", "Ideographic"},
    136836: {"Unified_Ideograph", "Ideographic"},
    136837: {"Unified_Ideograph", "Ideographic"},
    136838: {"Unified_Ideograph", "Ideographic"},
    136839: {"Unified_Ideograph", "Ideographic"},
    136840: {"Unified_Ideograph", "Ideographic"},
    136841: {"Unified_Ideograph", "Ideographic"},
    136842: {"Unified_Ideograph", "Ideographic"},
    136843: {"Unified_Ideograph", "Ideographic"},
    136844: {"Unified_Ideograph", "Ideographic"},
    136845: {"Unified_Ideograph", "Ideographic"},
    136846: {"Unified_Ideograph", "Ideographic"},
    136847: {"Unified_Ideograph", "Ideographic"},
    136848: {"Unified_Ideograph", "Ideographic"},
    136849: {"Unified_Ideograph", "Ideographic"},
    136850: {"Unified_Ideograph", "Ideographic"},
    136851: {"Unified_Ideograph", "Ideographic"},
    136852: {"Unified_Ideograph", "Ideographic"},
    136853: {"Unified_Ideograph", "Ideographic"},
    136854: {"Unified_Ideograph", "Ideographic"},
    136855: {"Unified_Ideograph", "Ideographic"},
    136856: {"Unified_Ideograph", "Ideographic"},
    136857: {"Unified_Ideograph", "Ideographic"},
    136858: {"Unified_Ideograph", "Ideographic"},
    136859: {"Unified_Ideograph", "Ideographic"},
    136860: {"Unified_Ideograph", "Ideographic"},
    136861: {"Unified_Ideograph", "Ideographic"},
    136862: {"Unified_Ideograph", "Ideographic"},
    136863: {"Unified_Ideograph", "Ideographic"},
    136864: {"Unified_Ideograph", "Ideographic"},
    136865: {"Unified_Ideograph", "Ideographic"},
    136866: {"Unified_Ideograph", "Ideographic"},
    136867: {"Unified_Ideograph", "Ideographic"},
    136868: {"Unified_Ideograph", "Ideographic"},
    136869: {"Unified_Ideograph", "Ideographic"},
    136870: {"Unified_Ideograph", "Ideographic"},
    136871: {"Unified_Ideograph", "Ideographic"},
    136872: {"Unified_Ideograph", "Ideographic"},
    136873: {"Unified_Ideograph", "Ideographic"},
    136874: {"Unified_Ideograph", "Ideographic"},
    136875: {"Unified_Ideograph", "Ideographic"},
    136876: {"Unified_Ideograph", "Ideographic"},
    136877: {"Unified_Ideograph", "Ideographic"},
    136878: {"Unified_Ideograph", "Ideographic"},
    136879: {"Unified_Ideograph", "Ideographic"},
    136880: {"Unified_Ideograph", "Ideographic"},
    136881: {"Unified_Ideograph", "Ideographic"},
    136882: {"Unified_Ideograph", "Ideographic"},
    136883: {"Unified_Ideograph", "Ideographic"},
    136884: {"Unified_Ideograph", "Ideographic"},
    136885: {"Unified_Ideograph", "Ideographic"},
    136886: {"Unified_Ideograph", "Ideographic"},
    136887: {"Unified_Ideograph", "Ideographic"},
    136888: {"Unified_Ideograph", "Ideographic"},
    136889: {"Unified_Ideograph", "Ideographic"},
    136890: {"Unified_Ideograph", "Ideographic"},
    136891: {"Unified_Ideograph", "Ideographic"},
    136892: {"Unified_Ideograph", "Ideographic"},
    136893: {"Unified_Ideograph", "Ideographic"},
    136894: {"Unified_Ideograph", "Ideographic"},
    136895: {"Unified_Ideograph", "Ideographic"},
    136896: {"Unified_Ideograph", "Ideographic"},
    136897: {"Unified_Ideograph", "Ideographic"},
    136898: {"Unified_Ideograph", "Ideographic"},
    136899: {"Unified_Ideograph", "Ideographic"},
    136900: {"Unified_Ideograph", "Ideographic"},
    136901: {"Unified_Ideograph", "Ideographic"},
    136902: {"Unified_Ideograph", "Ideographic"},
    136903: {"Unified_Ideograph", "Ideographic"},
    136904: {"Unified_Ideograph", "Ideographic"},
    136905: {"Unified_Ideograph", "Ideographic"},
    136906: {"Unified_Ideograph", "Ideographic"},
    136907: {"Unified_Ideograph", "Ideographic"},
    136908: {"Unified_Ideograph", "Ideographic"},
    136909: {"Unified_Ideograph", "Ideographic"},
    136910: {"Unified_Ideograph", "Ideographic"},
    136911: {"Unified_Ideograph", "Ideographic"},
    136912: {"Unified_Ideograph", "Ideographic"},
    136913: {"Unified_Ideograph", "Ideographic"},
    136914: {"Unified_Ideograph", "Ideographic"},
    136915: {"Unified_Ideograph", "Ideographic"},
    136916: {"Unified_Ideograph", "Ideographic"},
    136917: {"Unified_Ideograph", "Ideographic"},
    136918: {"Unified_Ideograph", "Ideographic"},
    136919: {"Unified_Ideograph", "Ideographic"},
    136920: {"Unified_Ideograph", "Ideographic"},
    136921: {"Unified_Ideograph", "Ideographic"},
    136922: {"Unified_Ideograph", "Ideographic"},
    136923: {"Unified_Ideograph", "Ideographic"},
    136924: {"Unified_Ideograph", "Ideographic"},
    136925: {"Unified_Ideograph", "Ideographic"},
    136926: {"Unified_Ideograph", "Ideographic"},
    136927: {"Unified_Ideograph", "Ideographic"},
    136928: {"Unified_Ideograph", "Ideographic"},
    136929: {"Unified_Ideograph", "Ideographic"},
    136930: {"Unified_Ideograph", "Ideographic"},
    136931: {"Unified_Ideograph", "Ideographic"},
    136932: {"Unified_Ideograph", "Ideographic"},
    136933: {"Unified_Ideograph", "Ideographic"},
    136934: {"Unified_Ideograph", "Ideographic"},
    136935: {"Unified_Ideograph", "Ideographic"},
    136936: {"Unified_Ideograph", "Ideographic"},
    136937: {"Unified_Ideograph", "Ideographic"},
    136938: {"Unified_Ideograph", "Ideographic"},
    136939: {"Unified_Ideograph", "Ideographic"},
    136940: {"Unified_Ideograph", "Ideographic"},
    136941: {"Unified_Ideograph", "Ideographic"},
    136942: {"Unified_Ideograph", "Ideographic"},
    136943: {"Unified_Ideograph", "Ideographic"},
    136944: {"Unified_Ideograph", "Ideographic"},
    136945: {"Unified_Ideograph", "Ideographic"},
    136946: {"Unified_Ideograph", "Ideographic"},
    136947: {"Unified_Ideograph", "Ideographic"},
    136948: {"Unified_Ideograph", "Ideographic"},
    136949: {"Unified_Ideograph", "Ideographic"},
    136950: {"Unified_Ideograph", "Ideographic"},
    136951: {"Unified_Ideograph", "Ideographic"},
    136952: {"Unified_Ideograph", "Ideographic"},
    136953: {"Unified_Ideograph", "Ideographic"},
    136954: {"Unified_Ideograph", "Ideographic"},
    136955: {"Unified_Ideograph", "Ideographic"},
    136956: {"Unified_Ideograph", "Ideographic"},
    136957: {"Unified_Ideograph", "Ideographic"},
    136958: {"Unified_Ideograph", "Ideographic"},
    136959: {"Unified_Ideograph", "Ideographic"},
    136960: {"Unified_Ideograph", "Ideographic"},
    136961: {"Unified_Ideograph", "Ideographic"},
    136962: {"Unified_Ideograph", "Ideographic"},
    136963: {"Unified_Ideograph", "Ideographic"},
    136964: {"Unified_Ideograph", "Ideographic"},
    136965: {"Unified_Ideograph", "Ideographic"},
    136966: {"Unified_Ideograph", "Ideographic"},
    136967: {"Unified_Ideograph", "Ideographic"},
    136968: {"Unified_Ideograph", "Ideographic"},
    136969: {"Unified_Ideograph", "Ideographic"},
    136970: {"Unified_Ideograph", "Ideographic"},
    136971: {"Unified_Ideograph", "Ideographic"},
    136972: {"Unified_Ideograph", "Ideographic"},
    136973: {"Unified_Ideograph", "Ideographic"},
    136974: {"Unified_Ideograph", "Ideographic"},
    136975: {"Unified_Ideograph", "Ideographic"},
    136976: {"Unified_Ideograph", "Ideographic"},
    136977: {"Unified_Ideograph", "Ideographic"},
    136978: {"Unified_Ideograph", "Ideographic"},
    136979: {"Unified_Ideograph", "Ideographic"},
    136980: {"Unified_Ideograph", "Ideographic"},
    136981: {"Unified_Ideograph", "Ideographic"},
    136982: {"Unified_Ideograph", "Ideographic"},
    136983: {"Unified_Ideograph", "Ideographic"},
    136984: {"Unified_Ideograph", "Ideographic"},
    136985: {"Unified_Ideograph", "Ideographic"},
    136986: {"Unified_Ideograph", "Ideographic"},
    136987: {"Unified_Ideograph", "Ideographic"},
    136988: {"Unified_Ideograph", "Ideographic"},
    136989: {"Unified_Ideograph", "Ideographic"},
    136990: {"Unified_Ideograph", "Ideographic"},
    136991: {"Unified_Ideograph", "Ideographic"},
    136992: {"Unified_Ideograph", "Ideographic"},
    136993: {"Unified_Ideograph", "Ideographic"},
    136994: {"Unified_Ideograph", "Ideographic"},
    136995: {"Unified_Ideograph", "Ideographic"},
    136996: {"Unified_Ideograph", "Ideographic"},
    136997: {"Unified_Ideograph", "Ideographic"},
    136998: {"Unified_Ideograph", "Ideographic"},
    136999: {"Unified_Ideograph", "Ideographic"},
    137000: {"Unified_Ideograph", "Ideographic"},
    137001: {"Unified_Ideograph", "Ideographic"},
    137002: {"Unified_Ideograph", "Ideographic"},
    137003: {"Unified_Ideograph", "Ideographic"},
    137004: {"Unified_Ideograph", "Ideographic"},
    137005: {"Unified_Ideograph", "Ideographic"},
    137006: {"Unified_Ideograph", "Ideographic"},
    137007: {"Unified_Ideograph", "Ideographic"},
    137008: {"Unified_Ideograph", "Ideographic"},
    137009: {"Unified_Ideograph", "Ideographic"},
    137010: {"Unified_Ideograph", "Ideographic"},
    137011: {"Unified_Ideograph", "Ideographic"},
    137012: {"Unified_Ideograph", "Ideographic"},
    137013: {"Unified_Ideograph", "Ideographic"},
    137014: {"Unified_Ideograph", "Ideographic"},
    137015: {"Unified_Ideograph", "Ideographic"},
    137016: {"Unified_Ideograph", "Ideographic"},
    137017: {"Unified_Ideograph", "Ideographic"},
    137018: {"Unified_Ideograph", "Ideographic"},
    137019: {"Unified_Ideograph", "Ideographic"},
    137020: {"Unified_Ideograph", "Ideographic"},
    137021: {"Unified_Ideograph", "Ideographic"},
    137022: {"Unified_Ideograph", "Ideographic"},
    137023: {"Unified_Ideograph", "Ideographic"},
    137024: {"Unified_Ideograph", "Ideographic"},
    137025: {"Unified_Ideograph", "Ideographic"},
    137026: {"Unified_Ideograph", "Ideographic"},
    137027: {"Unified_Ideograph", "Ideographic"},
    137028: {"Unified_Ideograph", "Ideographic"},
    137029: {"Unified_Ideograph", "Ideographic"},
    137030: {"Unified_Ideograph", "Ideographic"},
    137031: {"Unified_Ideograph", "Ideographic"},
    137032: {"Unified_Ideograph", "Ideographic"},
    137033: {"Unified_Ideograph", "Ideographic"},
    137034: {"Unified_Ideograph", "Ideographic"},
    137035: {"Unified_Ideograph", "Ideographic"},
    137036: {"Unified_Ideograph", "Ideographic"},
    137037: {"Unified_Ideograph", "Ideographic"},
    137038: {"Unified_Ideograph", "Ideographic"},
    137039: {"Unified_Ideograph", "Ideographic"},
    137040: {"Unified_Ideograph", "Ideographic"},
    137041: {"Unified_Ideograph", "Ideographic"},
    137042: {"Unified_Ideograph", "Ideographic"},
    137043: {"Unified_Ideograph", "Ideographic"},
    137044: {"Unified_Ideograph", "Ideographic"},
    137045: {"Unified_Ideograph", "Ideographic"},
    137046: {"Unified_Ideograph", "Ideographic"},
    137047: {"Unified_Ideograph", "Ideographic"},
    137048: {"Unified_Ideograph", "Ideographic"},
    137049: {"Unified_Ideograph", "Ideographic"},
    137050: {"Unified_Ideograph", "Ideographic"},
    137051: {"Unified_Ideograph", "Ideographic"},
    137052: {"Unified_Ideograph", "Ideographic"},
    137053: {"Unified_Ideograph", "Ideographic"},
    137054: {"Unified_Ideograph", "Ideographic"},
    137055: {"Unified_Ideograph", "Ideographic"},
    137056: {"Unified_Ideograph", "Ideographic"},
    137057: {"Unified_Ideograph", "Ideographic"},
    137058: {"Unified_Ideograph", "Ideographic"},
    137059: {"Unified_Ideograph", "Ideographic"},
    137060: {"Unified_Ideograph", "Ideographic"},
    137061: {"Unified_Ideograph", "Ideographic"},
    137062: {"Unified_Ideograph", "Ideographic"},
    137063: {"Unified_Ideograph", "Ideographic"},
    137064: {"Unified_Ideograph", "Ideographic"},
    137065: {"Unified_Ideograph", "Ideographic"},
    137066: {"Unified_Ideograph", "Ideographic"},
    137067: {"Unified_Ideograph", "Ideographic"},
    137068: {"Unified_Ideograph", "Ideographic"},
    137069: {"Unified_Ideograph", "Ideographic"},
    137070: {"Unified_Ideograph", "Ideographic"},
    137071: {"Unified_Ideograph", "Ideographic"},
    137072: {"Unified_Ideograph", "Ideographic"},
    137073: {"Unified_Ideograph", "Ideographic"},
    137074: {"Unified_Ideograph", "Ideographic"},
    137075: {"Unified_Ideograph", "Ideographic"},
    137076: {"Unified_Ideograph", "Ideographic"},
    137077: {"Unified_Ideograph", "Ideographic"},
    137078: {"Unified_Ideograph", "Ideographic"},
    137079: {"Unified_Ideograph", "Ideographic"},
    137080: {"Unified_Ideograph", "Ideographic"},
    137081: {"Unified_Ideograph", "Ideographic"},
    137082: {"Unified_Ideograph", "Ideographic"},
    137083: {"Unified_Ideograph", "Ideographic"},
    137084: {"Unified_Ideograph", "Ideographic"},
    137085: {"Unified_Ideograph", "Ideographic"},
    137086: {"Unified_Ideograph", "Ideographic"},
    137087: {"Unified_Ideograph", "Ideographic"},
    137088: {"Unified_Ideograph", "Ideographic"},
    137089: {"Unified_Ideograph", "Ideographic"},
    137090: {"Unified_Ideograph", "Ideographic"},
    137091: {"Unified_Ideograph", "Ideographic"},
    137092: {"Unified_Ideograph", "Ideographic"},
    137093: {"Unified_Ideograph", "Ideographic"},
    137094: {"Unified_Ideograph", "Ideographic"},
    137095: {"Unified_Ideograph", "Ideographic"},
    137096: {"Unified_Ideograph", "Ideographic"},
    137097: {"Unified_Ideograph", "Ideographic"},
    137098: {"Unified_Ideograph", "Ideographic"},
    137099: {"Unified_Ideograph", "Ideographic"},
    137100: {"Unified_Ideograph", "Ideographic"},
    137101: {"Unified_Ideograph", "Ideographic"},
    137102: {"Unified_Ideograph", "Ideographic"},
    137103: {"Unified_Ideograph", "Ideographic"},
    137104: {"Unified_Ideograph", "Ideographic"},
    137105: {"Unified_Ideograph", "Ideographic"},
    137106: {"Unified_Ideograph", "Ideographic"},
    137107: {"Unified_Ideograph", "Ideographic"},
    137108: {"Unified_Ideograph", "Ideographic"},
    137109: {"Unified_Ideograph", "Ideographic"},
    137110: {"Unified_Ideograph", "Ideographic"},
    137111: {"Unified_Ideograph", "Ideographic"},
    137112: {"Unified_Ideograph", "Ideographic"},
    137113: {"Unified_Ideograph", "Ideographic"},
    137114: {"Unified_Ideograph", "Ideographic"},
    137115: {"Unified_Ideograph", "Ideographic"},
    137116: {"Unified_Ideograph", "Ideographic"},
    137117: {"Unified_Ideograph", "Ideographic"},
    137118: {"Unified_Ideograph", "Ideographic"},
    137119: {"Unified_Ideograph", "Ideographic"},
    137120: {"Unified_Ideograph", "Ideographic"},
    137121: {"Unified_Ideograph", "Ideographic"},
    137122: {"Unified_Ideograph", "Ideographic"},
    137123: {"Unified_Ideograph", "Ideographic"},
    137124: {"Unified_Ideograph", "Ideographic"},
    137125: {"Unified_Ideograph", "Ideographic"},
    137126: {"Unified_Ideograph", "Ideographic"},
    137127: {"Unified_Ideograph", "Ideographic"},
    137128: {"Unified_Ideograph", "Ideographic"},
    137129: {"Unified_Ideograph", "Ideographic"},
    137130: {"Unified_Ideograph", "Ideographic"},
    137131: {"Unified_Ideograph", "Ideographic"},
    137132: {"Unified_Ideograph", "Ideographic"},
    137133: {"Unified_Ideograph", "Ideographic"},
    137134: {"Unified_Ideograph", "Ideographic"},
    137135: {"Unified_Ideograph", "Ideographic"},
    137136: {"Unified_Ideograph", "Ideographic"},
    137137: {"Unified_Ideograph", "Ideographic"},
    137138: {"Unified_Ideograph", "Ideographic"},
    137139: {"Unified_Ideograph", "Ideographic"},
    137140: {"Unified_Ideograph", "Ideographic"},
    137141: {"Unified_Ideograph", "Ideographic"},
    137142: {"Unified_Ideograph", "Ideographic"},
    137143: {"Unified_Ideograph", "Ideographic"},
    137144: {"Unified_Ideograph", "Ideographic"},
    137145: {"Unified_Ideograph", "Ideographic"},
    137146: {"Unified_Ideograph", "Ideographic"},
    137147: {"Unified_Ideograph", "Ideographic"},
    137148: {"Unified_Ideograph", "Ideographic"},
    137149: {"Unified_Ideograph", "Ideographic"},
    137150: {"Unified_Ideograph", "Ideographic"},
    137151: {"Unified_Ideograph", "Ideographic"},
    137152: {"Unified_Ideograph", "Ideographic"},
    137153: {"Unified_Ideograph", "Ideographic"},
    137154: {"Unified_Ideograph", "Ideographic"},
    137155: {"Unified_Ideograph", "Ideographic"},
    137156: {"Unified_Ideograph", "Ideographic"},
    137157: {"Unified_Ideograph", "Ideographic"},
    137158: {"Unified_Ideograph", "Ideographic"},
    137159: {"Unified_Ideograph", "Ideographic"},
    137160: {"Unified_Ideograph", "Ideographic"},
    137161: {"Unified_Ideograph", "Ideographic"},
    137162: {"Unified_Ideograph", "Ideographic"},
    137163: {"Unified_Ideograph", "Ideographic"},
    137164: {"Unified_Ideograph", "Ideographic"},
    137165: {"Unified_Ideograph", "Ideographic"},
    137166: {"Unified_Ideograph", "Ideographic"},
    137167: {"Unified_Ideograph", "Ideographic"},
    137168: {"Unified_Ideograph", "Ideographic"},
    137169: {"Unified_Ideograph", "Ideographic"},
    137170: {"Unified_Ideograph", "Ideographic"},
    137171: {"Unified_Ideograph", "Ideographic"},
    137172: {"Unified_Ideograph", "Ideographic"},
    137173: {"Unified_Ideograph", "Ideographic"},
    137174: {"Unified_Ideograph", "Ideographic"},
    137175: {"Unified_Ideograph", "Ideographic"},
    137176: {"Unified_Ideograph", "Ideographic"},
    137177: {"Unified_Ideograph", "Ideographic"},
    137178: {"Unified_Ideograph", "Ideographic"},
    137179: {"Unified_Ideograph", "Ideographic"},
    137180: {"Unified_Ideograph", "Ideographic"},
    137181: {"Unified_Ideograph", "Ideographic"},
    137182: {"Unified_Ideograph", "Ideographic"},
    137183: {"Unified_Ideograph", "Ideographic"},
    137184: {"Unified_Ideograph", "Ideographic"},
    137185: {"Unified_Ideograph", "Ideographic"},
    137186: {"Unified_Ideograph", "Ideographic"},
    137187: {"Unified_Ideograph", "Ideographic"},
    137188: {"Unified_Ideograph", "Ideographic"},
    137189: {"Unified_Ideograph", "Ideographic"},
    137190: {"Unified_Ideograph", "Ideographic"},
    137191: {"Unified_Ideograph", "Ideographic"},
    137192: {"Unified_Ideograph", "Ideographic"},
    137193: {"Unified_Ideograph", "Ideographic"},
    137194: {"Unified_Ideograph", "Ideographic"},
    137195: {"Unified_Ideograph", "Ideographic"},
    137196: {"Unified_Ideograph", "Ideographic"},
    137197: {"Unified_Ideograph", "Ideographic"},
    137198: {"Unified_Ideograph", "Ideographic"},
    137199: {"Unified_Ideograph", "Ideographic"},
    137200: {"Unified_Ideograph", "Ideographic"},
    137201: {"Unified_Ideograph", "Ideographic"},
    137202: {"Unified_Ideograph", "Ideographic"},
    137203: {"Unified_Ideograph", "Ideographic"},
    137204: {"Unified_Ideograph", "Ideographic"},
    137205: {"Unified_Ideograph", "Ideographic"},
    137206: {"Unified_Ideograph", "Ideographic"},
    137207: {"Unified_Ideograph", "Ideographic"},
    137208: {"Unified_Ideograph", "Ideographic"},
    137209: {"Unified_Ideograph", "Ideographic"},
    137210: {"Unified_Ideograph", "Ideographic"},
    137211: {"Unified_Ideograph", "Ideographic"},
    137212: {"Unified_Ideograph", "Ideographic"},
    137213: {"Unified_Ideograph", "Ideographic"},
    137214: {"Unified_Ideograph", "Ideographic"},
    137215: {"Unified_Ideograph", "Ideographic"},
    137216: {"Unified_Ideograph", "Ideographic"},
    137217: {"Unified_Ideograph", "Ideographic"},
    137218: {"Unified_Ideograph", "Ideographic"},
    137219: {"Unified_Ideograph", "Ideographic"},
    137220: {"Unified_Ideograph", "Ideographic"},
    137221: {"Unified_Ideograph", "Ideographic"},
    137222: {"Unified_Ideograph", "Ideographic"},
    137223: {"Unified_Ideograph", "Ideographic"},
    137224: {"Unified_Ideograph", "Ideographic"},
    137225: {"Unified_Ideograph", "Ideographic"},
    137226: {"Unified_Ideograph", "Ideographic"},
    137227: {"Unified_Ideograph", "Ideographic"},
    137228: {"Unified_Ideograph", "Ideographic"},
    137229: {"Unified_Ideograph", "Ideographic"},
    137230: {"Unified_Ideograph", "Ideographic"},
    137231: {"Unified_Ideograph", "Ideographic"},
    137232: {"Unified_Ideograph", "Ideographic"},
    137233: {"Unified_Ideograph", "Ideographic"},
    137234: {"Unified_Ideograph", "Ideographic"},
    137235: {"Unified_Ideograph", "Ideographic"},
    137236: {"Unified_Ideograph", "Ideographic"},
    137237: {"Unified_Ideograph", "Ideographic"},
    137238: {"Unified_Ideograph", "Ideographic"},
    137239: {"Unified_Ideograph", "Ideographic"},
    137240: {"Unified_Ideograph", "Ideographic"},
    137241: {"Unified_Ideograph", "Ideographic"},
    137242: {"Unified_Ideograph", "Ideographic"},
    137243: {"Unified_Ideograph", "Ideographic"},
    137244: {"Unified_Ideograph", "Ideographic"},
    137245: {"Unified_Ideograph", "Ideographic"},
    137246: {"Unified_Ideograph", "Ideographic"},
    137247: {"Unified_Ideograph", "Ideographic"},
    137248: {"Unified_Ideograph", "Ideographic"},
    137249: {"Unified_Ideograph", "Ideographic"},
    137250: {"Unified_Ideograph", "Ideographic"},
    137251: {"Unified_Ideograph", "Ideographic"},
    137252: {"Unified_Ideograph", "Ideographic"},
    137253: {"Unified_Ideograph", "Ideographic"},
    137254: {"Unified_Ideograph", "Ideographic"},
    137255: {"Unified_Ideograph", "Ideographic"},
    137256: {"Unified_Ideograph", "Ideographic"},
    137257: {"Unified_Ideograph", "Ideographic"},
    137258: {"Unified_Ideograph", "Ideographic"},
    137259: {"Unified_Ideograph", "Ideographic"},
    137260: {"Unified_Ideograph", "Ideographic"},
    137261: {"Unified_Ideograph", "Ideographic"},
    137262: {"Unified_Ideograph", "Ideographic"},
    137263: {"Unified_Ideograph", "Ideographic"},
    137264: {"Unified_Ideograph", "Ideographic"},
    137265: {"Unified_Ideograph", "Ideographic"},
    137266: {"Unified_Ideograph", "Ideographic"},
    137267: {"Unified_Ideograph", "Ideographic"},
    137268: {"Unified_Ideograph", "Ideographic"},
    137269: {"Unified_Ideograph", "Ideographic"},
    137270: {"Unified_Ideograph", "Ideographic"},
    137271: {"Unified_Ideograph", "Ideographic"},
    137272: {"Unified_Ideograph", "Ideographic"},
    137273: {"Unified_Ideograph", "Ideographic"},
    137274: {"Unified_Ideograph", "Ideographic"},
    137275: {"Unified_Ideograph", "Ideographic"},
    137276: {"Unified_Ideograph", "Ideographic"},
    137277: {"Unified_Ideograph", "Ideographic"},
    137278: {"Unified_Ideograph", "Ideographic"},
    137279: {"Unified_Ideograph", "Ideographic"},
    137280: {"Unified_Ideograph", "Ideographic"},
    137281: {"Unified_Ideograph", "Ideographic"},
    137282: {"Unified_Ideograph", "Ideographic"},
    137283: {"Unified_Ideograph", "Ideographic"},
    137284: {"Unified_Ideograph", "Ideographic"},
    137285: {"Unified_Ideograph", "Ideographic"},
    137286: {"Unified_Ideograph", "Ideographic"},
    137287: {"Unified_Ideograph", "Ideographic"},
    137288: {"Unified_Ideograph", "Ideographic"},
    137289: {"Unified_Ideograph", "Ideographic"},
    137290: {"Unified_Ideograph", "Ideographic"},
    137291: {"Unified_Ideograph", "Ideographic"},
    137292: {"Unified_Ideograph", "Ideographic"},
    137293: {"Unified_Ideograph", "Ideographic"},
    137294: {"Unified_Ideograph", "Ideographic"},
    137295: {"Unified_Ideograph", "Ideographic"},
    137296: {"Unified_Ideograph", "Ideographic"},
    137297: {"Unified_Ideograph", "Ideographic"},
    137298: {"Unified_Ideograph", "Ideographic"},
    137299: {"Unified_Ideograph", "Ideographic"},
    137300: {"Unified_Ideograph", "Ideographic"},
    137301: {"Unified_Ideograph", "Ideographic"},
    137302: {"Unified_Ideograph", "Ideographic"},
    137303: {"Unified_Ideograph", "Ideographic"},
    137304: {"Unified_Ideograph", "Ideographic"},
    137305: {"Unified_Ideograph", "Ideographic"},
    137306: {"Unified_Ideograph", "Ideographic"},
    137307: {"Unified_Ideograph", "Ideographic"},
    137308: {"Unified_Ideograph", "Ideographic"},
    137309: {"Unified_Ideograph", "Ideographic"},
    137310: {"Unified_Ideograph", "Ideographic"},
    137311: {"Unified_Ideograph", "Ideographic"},
    137312: {"Unified_Ideograph", "Ideographic"},
    137313: {"Unified_Ideograph", "Ideographic"},
    137314: {"Unified_Ideograph", "Ideographic"},
    137315: {"Unified_Ideograph", "Ideographic"},
    137316: {"Unified_Ideograph", "Ideographic"},
    137317: {"Unified_Ideograph", "Ideographic"},
    137318: {"Unified_Ideograph", "Ideographic"},
    137319: {"Unified_Ideograph", "Ideographic"},
    137320: {"Unified_Ideograph", "Ideographic"},
    137321: {"Unified_Ideograph", "Ideographic"},
    137322: {"Unified_Ideograph", "Ideographic"},
    137323: {"Unified_Ideograph", "Ideographic"},
    137324: {"Unified_Ideograph", "Ideographic"},
    137325: {"Unified_Ideograph", "Ideographic"},
    137326: {"Unified_Ideograph", "Ideographic"},
    137327: {"Unified_Ideograph", "Ideographic"},
    137328: {"Unified_Ideograph", "Ideographic"},
    137329: {"Unified_Ideograph", "Ideographic"},
    137330: {"Unified_Ideograph", "Ideographic"},
    137331: {"Unified_Ideograph", "Ideographic"},
    137332: {"Unified_Ideograph", "Ideographic"},
    137333: {"Unified_Ideograph", "Ideographic"},
    137334: {"Unified_Ideograph", "Ideographic"},
    137335: {"Unified_Ideograph", "Ideographic"},
    137336: {"Unified_Ideograph", "Ideographic"},
    137337: {"Unified_Ideograph", "Ideographic"},
    137338: {"Unified_Ideograph", "Ideographic"},
    137339: {"Unified_Ideograph", "Ideographic"},
    137340: {"Unified_Ideograph", "Ideographic"},
    137341: {"Unified_Ideograph", "Ideographic"},
    137342: {"Unified_Ideograph", "Ideographic"},
    137343: {"Unified_Ideograph", "Ideographic"},
    137344: {"Unified_Ideograph", "Ideographic"},
    137345: {"Unified_Ideograph", "Ideographic"},
    137346: {"Unified_Ideograph", "Ideographic"},
    137347: {"Unified_Ideograph", "Ideographic"},
    137348: {"Unified_Ideograph", "Ideographic"},
    137349: {"Unified_Ideograph", "Ideographic"},
    137350: {"Unified_Ideograph", "Ideographic"},
    137351: {"Unified_Ideograph", "Ideographic"},
    137352: {"Unified_Ideograph", "Ideographic"},
    137353: {"Unified_Ideograph", "Ideographic"},
    137354: {"Unified_Ideograph", "Ideographic"},
    137355: {"Unified_Ideograph", "Ideographic"},
    137356: {"Unified_Ideograph", "Ideographic"},
    137357: {"Unified_Ideograph", "Ideographic"},
    137358: {"Unified_Ideograph", "Ideographic"},
    137359: {"Unified_Ideograph", "Ideographic"},
    137360: {"Unified_Ideograph", "Ideographic"},
    137361: {"Unified_Ideograph", "Ideographic"},
    137362: {"Unified_Ideograph", "Ideographic"},
    137363: {"Unified_Ideograph", "Ideographic"},
    137364: {"Unified_Ideograph", "Ideographic"},
    137365: {"Unified_Ideograph", "Ideographic"},
    137366: {"Unified_Ideograph", "Ideographic"},
    137367: {"Unified_Ideograph", "Ideographic"},
    137368: {"Unified_Ideograph", "Ideographic"},
    137369: {"Unified_Ideograph", "Ideographic"},
    137370: {"Unified_Ideograph", "Ideographic"},
    137371: {"Unified_Ideograph", "Ideographic"},
    137372: {"Unified_Ideograph", "Ideographic"},
    137373: {"Unified_Ideograph", "Ideographic"},
    137374: {"Unified_Ideograph", "Ideographic"},
    137375: {"Unified_Ideograph", "Ideographic"},
    137376: {"Unified_Ideograph", "Ideographic"},
    137377: {"Unified_Ideograph", "Ideographic"},
    137378: {"Unified_Ideograph", "Ideographic"},
    137379: {"Unified_Ideograph", "Ideographic"},
    137380: {"Unified_Ideograph", "Ideographic"},
    137381: {"Unified_Ideograph", "Ideographic"},
    137382: {"Unified_Ideograph", "Ideographic"},
    137383: {"Unified_Ideograph", "Ideographic"},
    137384: {"Unified_Ideograph", "Ideographic"},
    137385: {"Unified_Ideograph", "Ideographic"},
    137386: {"Unified_Ideograph", "Ideographic"},
    137387: {"Unified_Ideograph", "Ideographic"},
    137388: {"Unified_Ideograph", "Ideographic"},
    137389: {"Unified_Ideograph", "Ideographic"},
    137390: {"Unified_Ideograph", "Ideographic"},
    137391: {"Unified_Ideograph", "Ideographic"},
    137392: {"Unified_Ideograph", "Ideographic"},
    137393: {"Unified_Ideograph", "Ideographic"},
    137394: {"Unified_Ideograph", "Ideographic"},
    137395: {"Unified_Ideograph", "Ideographic"},
    137396: {"Unified_Ideograph", "Ideographic"},
    137397: {"Unified_Ideograph", "Ideographic"},
    137398: {"Unified_Ideograph", "Ideographic"},
    137399: {"Unified_Ideograph", "Ideographic"},
    137400: {"Unified_Ideograph", "Ideographic"},
    137401: {"Unified_Ideograph", "Ideographic"},
    137402: {"Unified_Ideograph", "Ideographic"},
    137403: {"Unified_Ideograph", "Ideographic"},
    137404: {"Unified_Ideograph", "Ideographic"},
    137405: {"Unified_Ideograph", "Ideographic"},
    137406: {"Unified_Ideograph", "Ideographic"},
    137407: {"Unified_Ideograph", "Ideographic"},
    137408: {"Unified_Ideograph", "Ideographic"},
    137409: {"Unified_Ideograph", "Ideographic"},
    137410: {"Unified_Ideograph", "Ideographic"},
    137411: {"Unified_Ideograph", "Ideographic"},
    137412: {"Unified_Ideograph", "Ideographic"},
    137413: {"Unified_Ideograph", "Ideographic"},
    137414: {"Unified_Ideograph", "Ideographic"},
    137415: {"Unified_Ideograph", "Ideographic"},
    137416: {"Unified_Ideograph", "Ideographic"},
    137417: {"Unified_Ideograph", "Ideographic"},
    137418: {"Unified_Ideograph", "Ideographic"},
    137419: {"Unified_Ideograph", "Ideographic"},
    137420: {"Unified_Ideograph", "Ideographic"},
    137421: {"Unified_Ideograph", "Ideographic"},
    137422: {"Unified_Ideograph", "Ideographic"},
    137423: {"Unified_Ideograph", "Ideographic"},
    137424: {"Unified_Ideograph", "Ideographic"},
    137425: {"Unified_Ideograph", "Ideographic"},
    137426: {"Unified_Ideograph", "Ideographic"},
    137427: {"Unified_Ideograph", "Ideographic"},
    137428: {"Unified_Ideograph", "Ideographic"},
    137429: {"Unified_Ideograph", "Ideographic"},
    137430: {"Unified_Ideograph", "Ideographic"},
    137431: {"Unified_Ideograph", "Ideographic"},
    137432: {"Unified_Ideograph", "Ideographic"},
    137433: {"Unified_Ideograph", "Ideographic"},
    137434: {"Unified_Ideograph", "Ideographic"},
    137435: {"Unified_Ideograph", "Ideographic"},
    137436: {"Unified_Ideograph", "Ideographic"},
    137437: {"Unified_Ideograph", "Ideographic"},
    137438: {"Unified_Ideograph", "Ideographic"},
    137439: {"Unified_Ideograph", "Ideographic"},
    137440: {"Unified_Ideograph", "Ideographic"},
    137441: {"Unified_Ideograph", "Ideographic"},
    137442: {"Unified_Ideograph", "Ideographic"},
    137443: {"Unified_Ideograph", "Ideographic"},
    137444: {"Unified_Ideograph", "Ideographic"},
    137445: {"Unified_Ideograph", "Ideographic"},
    137446: {"Unified_Ideograph", "Ideographic"},
    137447: {"Unified_Ideograph", "Ideographic"},
    137448: {"Unified_Ideograph", "Ideographic"},
    137449: {"Unified_Ideograph", "Ideographic"},
    137450: {"Unified_Ideograph", "Ideographic"},
    137451: {"Unified_Ideograph", "Ideographic"},
    137452: {"Unified_Ideograph", "Ideographic"},
    137453: {"Unified_Ideograph", "Ideographic"},
    137454: {"Unified_Ideograph", "Ideographic"},
    137455: {"Unified_Ideograph", "Ideographic"},
    137456: {"Unified_Ideograph", "Ideographic"},
    137457: {"Unified_Ideograph", "Ideographic"},
    137458: {"Unified_Ideograph", "Ideographic"},
    137459: {"Unified_Ideograph", "Ideographic"},
    137460: {"Unified_Ideograph", "Ideographic"},
    137461: {"Unified_Ideograph", "Ideographic"},
    137462: {"Unified_Ideograph", "Ideographic"},
    137463: {"Unified_Ideograph", "Ideographic"},
    137464: {"Unified_Ideograph", "Ideographic"},
    137465: {"Unified_Ideograph", "Ideographic"},
    137466: {"Unified_Ideograph", "Ideographic"},
    137467: {"Unified_Ideograph", "Ideographic"},
    137468: {"Unified_Ideograph", "Ideographic"},
    137469: {"Unified_Ideograph", "Ideographic"},
    137470: {"Unified_Ideograph", "Ideographic"},
    137471: {"Unified_Ideograph", "Ideographic"},
    137472: {"Unified_Ideograph", "Ideographic"},
    137473: {"Unified_Ideograph", "Ideographic"},
    137474: {"Unified_Ideograph", "Ideographic"},
    137475: {"Unified_Ideograph", "Ideographic"},
    137476: {"Unified_Ideograph", "Ideographic"},
    137477: {"Unified_Ideograph", "Ideographic"},
    137478: {"Unified_Ideograph", "Ideographic"},
    137479: {"Unified_Ideograph", "Ideographic"},
    137480: {"Unified_Ideograph", "Ideographic"},
    137481: {"Unified_Ideograph", "Ideographic"},
    137482: {"Unified_Ideograph", "Ideographic"},
    137483: {"Unified_Ideograph", "Ideographic"},
    137484: {"Unified_Ideograph", "Ideographic"},
    137485: {"Unified_Ideograph", "Ideographic"},
    137486: {"Unified_Ideograph", "Ideographic"},
    137487: {"Unified_Ideograph", "Ideographic"},
    137488: {"Unified_Ideograph", "Ideographic"},
    137489: {"Unified_Ideograph", "Ideographic"},
    137490: {"Unified_Ideograph", "Ideographic"},
    137491: {"Unified_Ideograph", "Ideographic"},
    137492: {"Unified_Ideograph", "Ideographic"},
    137493: {"Unified_Ideograph", "Ideographic"},
    137494: {"Unified_Ideograph", "Ideographic"},
    137495: {"Unified_Ideograph", "Ideographic"},
    137496: {"Unified_Ideograph", "Ideographic"},
    137497: {"Unified_Ideograph", "Ideographic"},
    137498: {"Unified_Ideograph", "Ideographic"},
    137499: {"Unified_Ideograph", "Ideographic"},
    137500: {"Unified_Ideograph", "Ideographic"},
    137501: {"Unified_Ideograph", "Ideographic"},
    137502: {"Unified_Ideograph", "Ideographic"},
    137503: {"Unified_Ideograph", "Ideographic"},
    137504: {"Unified_Ideograph", "Ideographic"},
    137505: {"Unified_Ideograph", "Ideographic"},
    137506: {"Unified_Ideograph", "Ideographic"},
    137507: {"Unified_Ideograph", "Ideographic"},
    137508: {"Unified_Ideograph", "Ideographic"},
    137509: {"Unified_Ideograph", "Ideographic"},
    137510: {"Unified_Ideograph", "Ideographic"},
    137511: {"Unified_Ideograph", "Ideographic"},
    137512: {"Unified_Ideograph", "Ideographic"},
    137513: {"Unified_Ideograph", "Ideographic"},
    137514: {"Unified_Ideograph", "Ideographic"},
    137515: {"Unified_Ideograph", "Ideographic"},
    137516: {"Unified_Ideograph", "Ideographic"},
    137517: {"Unified_Ideograph", "Ideographic"},
    137518: {"Unified_Ideograph", "Ideographic"},
    137519: {"Unified_Ideograph", "Ideographic"},
    137520: {"Unified_Ideograph", "Ideographic"},
    137521: {"Unified_Ideograph", "Ideographic"},
    137522: {"Unified_Ideograph", "Ideographic"},
    137523: {"Unified_Ideograph", "Ideographic"},
    137524: {"Unified_Ideograph", "Ideographic"},
    137525: {"Unified_Ideograph", "Ideographic"},
    137526: {"Unified_Ideograph", "Ideographic"},
    137527: {"Unified_Ideograph", "Ideographic"},
    137528: {"Unified_Ideograph", "Ideographic"},
    137529: {"Unified_Ideograph", "Ideographic"},
    137530: {"Unified_Ideograph", "Ideographic"},
    137531: {"Unified_Ideograph", "Ideographic"},
    137532: {"Unified_Ideograph", "Ideographic"},
    137533: {"Unified_Ideograph", "Ideographic"},
    137534: {"Unified_Ideograph", "Ideographic"},
    137535: {"Unified_Ideograph", "Ideographic"},
    137536: {"Unified_Ideograph", "Ideographic"},
    137537: {"Unified_Ideograph", "Ideographic"},
    137538: {"Unified_Ideograph", "Ideographic"},
    137539: {"Unified_Ideograph", "Ideographic"},
    137540: {"Unified_Ideograph", "Ideographic"},
    137541: {"Unified_Ideograph", "Ideographic"},
    137542: {"Unified_Ideograph", "Ideographic"},
    137543: {"Unified_Ideograph", "Ideographic"},
    137544: {"Unified_Ideograph", "Ideographic"},
    137545: {"Unified_Ideograph", "Ideographic"},
    137546: {"Unified_Ideograph", "Ideographic"},
    137547: {"Unified_Ideograph", "Ideographic"},
    137548: {"Unified_Ideograph", "Ideographic"},
    137549: {"Unified_Ideograph", "Ideographic"},
    137550: {"Unified_Ideograph", "Ideographic"},
    137551: {"Unified_Ideograph", "Ideographic"},
    137552: {"Unified_Ideograph", "Ideographic"},
    137553: {"Unified_Ideograph", "Ideographic"},
    137554: {"Unified_Ideograph", "Ideographic"},
    137555: {"Unified_Ideograph", "Ideographic"},
    137556: {"Unified_Ideograph", "Ideographic"},
    137557: {"Unified_Ideograph", "Ideographic"},
    137558: {"Unified_Ideograph", "Ideographic"},
    137559: {"Unified_Ideograph", "Ideographic"},
    137560: {"Unified_Ideograph", "Ideographic"},
    137561: {"Unified_Ideograph", "Ideographic"},
    137562: {"Unified_Ideograph", "Ideographic"},
    137563: {"Unified_Ideograph", "Ideographic"},
    137564: {"Unified_Ideograph", "Ideographic"},
    137565: {"Unified_Ideograph", "Ideographic"},
    137566: {"Unified_Ideograph", "Ideographic"},
    137567: {"Unified_Ideograph", "Ideographic"},
    137568: {"Unified_Ideograph", "Ideographic"},
    137569: {"Unified_Ideograph", "Ideographic"},
    137570: {"Unified_Ideograph", "Ideographic"},
    137571: {"Unified_Ideograph", "Ideographic"},
    137572: {"Unified_Ideograph", "Ideographic"},
    137573: {"Unified_Ideograph", "Ideographic"},
    137574: {"Unified_Ideograph", "Ideographic"},
    137575: {"Unified_Ideograph", "Ideographic"},
    137576: {"Unified_Ideograph", "Ideographic"},
    137577: {"Unified_Ideograph", "Ideographic"},
    137578: {"Unified_Ideograph", "Ideographic"},
    137579: {"Unified_Ideograph", "Ideographic"},
    137580: {"Unified_Ideograph", "Ideographic"},
    137581: {"Unified_Ideograph", "Ideographic"},
    137582: {"Unified_Ideograph", "Ideographic"},
    137583: {"Unified_Ideograph", "Ideographic"},
    137584: {"Unified_Ideograph", "Ideographic"},
    137585: {"Unified_Ideograph", "Ideographic"},
    137586: {"Unified_Ideograph", "Ideographic"},
    137587: {"Unified_Ideograph", "Ideographic"},
    137588: {"Unified_Ideograph", "Ideographic"},
    137589: {"Unified_Ideograph", "Ideographic"},
    137590: {"Unified_Ideograph", "Ideographic"},
    137591: {"Unified_Ideograph", "Ideographic"},
    137592: {"Unified_Ideograph", "Ideographic"},
    137593: {"Unified_Ideograph", "Ideographic"},
    137594: {"Unified_Ideograph", "Ideographic"},
    137595: {"Unified_Ideograph", "Ideographic"},
    137596: {"Unified_Ideograph", "Ideographic"},
    137597: {"Unified_Ideograph", "Ideographic"},
    137598: {"Unified_Ideograph", "Ideographic"},
    137599: {"Unified_Ideograph", "Ideographic"},
    137600: {"Unified_Ideograph", "Ideographic"},
    137601: {"Unified_Ideograph", "Ideographic"},
    137602: {"Unified_Ideograph", "Ideographic"},
    137603: {"Unified_Ideograph", "Ideographic"},
    137604: {"Unified_Ideograph", "Ideographic"},
    137605: {"Unified_Ideograph", "Ideographic"},
    137606: {"Unified_Ideograph", "Ideographic"},
    137607: {"Unified_Ideograph", "Ideographic"},
    137608: {"Unified_Ideograph", "Ideographic"},
    137609: {"Unified_Ideograph", "Ideographic"},
    137610: {"Unified_Ideograph", "Ideographic"},
    137611: {"Unified_Ideograph", "Ideographic"},
    137612: {"Unified_Ideograph", "Ideographic"},
    137613: {"Unified_Ideograph", "Ideographic"},
    137614: {"Unified_Ideograph", "Ideographic"},
    137615: {"Unified_Ideograph", "Ideographic"},
    137616: {"Unified_Ideograph", "Ideographic"},
    137617: {"Unified_Ideograph", "Ideographic"},
    137618: {"Unified_Ideograph", "Ideographic"},
    137619: {"Unified_Ideograph", "Ideographic"},
    137620: {"Unified_Ideograph", "Ideographic"},
    137621: {"Unified_Ideograph", "Ideographic"},
    137622: {"Unified_Ideograph", "Ideographic"},
    137623: {"Unified_Ideograph", "Ideographic"},
    137624: {"Unified_Ideograph", "Ideographic"},
    137625: {"Unified_Ideograph", "Ideographic"},
    137626: {"Unified_Ideograph", "Ideographic"},
    137627: {"Unified_Ideograph", "Ideographic"},
    137628: {"Unified_Ideograph", "Ideographic"},
    137629: {"Unified_Ideograph", "Ideographic"},
    137630: {"Unified_Ideograph", "Ideographic"},
    137631: {"Unified_Ideograph", "Ideographic"},
    137632: {"Unified_Ideograph", "Ideographic"},
    137633: {"Unified_Ideograph", "Ideographic"},
    137634: {"Unified_Ideograph", "Ideographic"},
    137635: {"Unified_Ideograph", "Ideographic"},
    137636: {"Unified_Ideograph", "Ideographic"},
    137637: {"Unified_Ideograph", "Ideographic"},
    137638: {"Unified_Ideograph", "Ideographic"},
    137639: {"Unified_Ideograph", "Ideographic"},
    137640: {"Unified_Ideograph", "Ideographic"},
    137641: {"Unified_Ideograph", "Ideographic"},
    137642: {"Unified_Ideograph", "Ideographic"},
    137643: {"Unified_Ideograph", "Ideographic"},
    137644: {"Unified_Ideograph", "Ideographic"},
    137645: {"Unified_Ideograph", "Ideographic"},
    137646: {"Unified_Ideograph", "Ideographic"},
    137647: {"Unified_Ideograph", "Ideographic"},
    137648: {"Unified_Ideograph", "Ideographic"},
    137649: {"Unified_Ideograph", "Ideographic"},
    137650: {"Unified_Ideograph", "Ideographic"},
    137651: {"Unified_Ideograph", "Ideographic"},
    137652: {"Unified_Ideograph", "Ideographic"},
    137653: {"Unified_Ideograph", "Ideographic"},
    137654: {"Unified_Ideograph", "Ideographic"},
    137655: {"Unified_Ideograph", "Ideographic"},
    137656: {"Unified_Ideograph", "Ideographic"},
    137657: {"Unified_Ideograph", "Ideographic"},
    137658: {"Unified_Ideograph", "Ideographic"},
    137659: {"Unified_Ideograph", "Ideographic"},
    137660: {"Unified_Ideograph", "Ideographic"},
    137661: {"Unified_Ideograph", "Ideographic"},
    137662: {"Unified_Ideograph", "Ideographic"},
    137663: {"Unified_Ideograph", "Ideographic"},
    137664: {"Unified_Ideograph", "Ideographic"},
    137665: {"Unified_Ideograph", "Ideographic"},
    137666: {"Unified_Ideograph", "Ideographic"},
    137667: {"Unified_Ideograph", "Ideographic"},
    137668: {"Unified_Ideograph", "Ideographic"},
    137669: {"Unified_Ideograph", "Ideographic"},
    137670: {"Unified_Ideograph", "Ideographic"},
    137671: {"Unified_Ideograph", "Ideographic"},
    137672: {"Unified_Ideograph", "Ideographic"},
    137673: {"Unified_Ideograph", "Ideographic"},
    137674: {"Unified_Ideograph", "Ideographic"},
    137675: {"Unified_Ideograph", "Ideographic"},
    137676: {"Unified_Ideograph", "Ideographic"},
    137677: {"Unified_Ideograph", "Ideographic"},
    137678: {"Unified_Ideograph", "Ideographic"},
    137679: {"Unified_Ideograph", "Ideographic"},
    137680: {"Unified_Ideograph", "Ideographic"},
    137681: {"Unified_Ideograph", "Ideographic"},
    137682: {"Unified_Ideograph", "Ideographic"},
    137683: {"Unified_Ideograph", "Ideographic"},
    137684: {"Unified_Ideograph", "Ideographic"},
    137685: {"Unified_Ideograph", "Ideographic"},
    137686: {"Unified_Ideograph", "Ideographic"},
    137687: {"Unified_Ideograph", "Ideographic"},
    137688: {"Unified_Ideograph", "Ideographic"},
    137689: {"Unified_Ideograph", "Ideographic"},
    137690: {"Unified_Ideograph", "Ideographic"},
    137691: {"Unified_Ideograph", "Ideographic"},
    137692: {"Unified_Ideograph", "Ideographic"},
    137693: {"Unified_Ideograph", "Ideographic"},
    137694: {"Unified_Ideograph", "Ideographic"},
    137695: {"Unified_Ideograph", "Ideographic"},
    137696: {"Unified_Ideograph", "Ideographic"},
    137697: {"Unified_Ideograph", "Ideographic"},
    137698: {"Unified_Ideograph", "Ideographic"},
    137699: {"Unified_Ideograph", "Ideographic"},
    137700: {"Unified_Ideograph", "Ideographic"},
    137701: {"Unified_Ideograph", "Ideographic"},
    137702: {"Unified_Ideograph", "Ideographic"},
    137703: {"Unified_Ideograph", "Ideographic"},
    137704: {"Unified_Ideograph", "Ideographic"},
    137705: {"Unified_Ideograph", "Ideographic"},
    137706: {"Unified_Ideograph", "Ideographic"},
    137707: {"Unified_Ideograph", "Ideographic"},
    137708: {"Unified_Ideograph", "Ideographic"},
    137709: {"Unified_Ideograph", "Ideographic"},
    137710: {"Unified_Ideograph", "Ideographic"},
    137711: {"Unified_Ideograph", "Ideographic"},
    137712: {"Unified_Ideograph", "Ideographic"},
    137713: {"Unified_Ideograph", "Ideographic"},
    137714: {"Unified_Ideograph", "Ideographic"},
    137715: {"Unified_Ideograph", "Ideographic"},
    137716: {"Unified_Ideograph", "Ideographic"},
    137717: {"Unified_Ideograph", "Ideographic"},
    137718: {"Unified_Ideograph", "Ideographic"},
    137719: {"Unified_Ideograph", "Ideographic"},
    137720: {"Unified_Ideograph", "Ideographic"},
    137721: {"Unified_Ideograph", "Ideographic"},
    137722: {"Unified_Ideograph", "Ideographic"},
    137723: {"Unified_Ideograph", "Ideographic"},
    137724: {"Unified_Ideograph", "Ideographic"},
    137725: {"Unified_Ideograph", "Ideographic"},
    137726: {"Unified_Ideograph", "Ideographic"},
    137727: {"Unified_Ideograph", "Ideographic"},
    137728: {"Unified_Ideograph", "Ideographic"},
    137729: {"Unified_Ideograph", "Ideographic"},
    137730: {"Unified_Ideograph", "Ideographic"},
    137731: {"Unified_Ideograph", "Ideographic"},
    137732: {"Unified_Ideograph", "Ideographic"},
    137733: {"Unified_Ideograph", "Ideographic"},
    137734: {"Unified_Ideograph", "Ideographic"},
    137735: {"Unified_Ideograph", "Ideographic"},
    137736: {"Unified_Ideograph", "Ideographic"},
    137737: {"Unified_Ideograph", "Ideographic"},
    137738: {"Unified_Ideograph", "Ideographic"},
    137739: {"Unified_Ideograph", "Ideographic"},
    137740: {"Unified_Ideograph", "Ideographic"},
    137741: {"Unified_Ideograph", "Ideographic"},
    137742: {"Unified_Ideograph", "Ideographic"},
    137743: {"Unified_Ideograph", "Ideographic"},
    137744: {"Unified_Ideograph", "Ideographic"},
    137745: {"Unified_Ideograph", "Ideographic"},
    137746: {"Unified_Ideograph", "Ideographic"},
    137747: {"Unified_Ideograph", "Ideographic"},
    137748: {"Unified_Ideograph", "Ideographic"},
    137749: {"Unified_Ideograph", "Ideographic"},
    137750: {"Unified_Ideograph", "Ideographic"},
    137751: {"Unified_Ideograph", "Ideographic"},
    137752: {"Unified_Ideograph", "Ideographic"},
    137753: {"Unified_Ideograph", "Ideographic"},
    137754: {"Unified_Ideograph", "Ideographic"},
    137755: {"Unified_Ideograph", "Ideographic"},
    137756: {"Unified_Ideograph", "Ideographic"},
    137757: {"Unified_Ideograph", "Ideographic"},
    137758: {"Unified_Ideograph", "Ideographic"},
    137759: {"Unified_Ideograph", "Ideographic"},
    137760: {"Unified_Ideograph", "Ideographic"},
    137761: {"Unified_Ideograph", "Ideographic"},
    137762: {"Unified_Ideograph", "Ideographic"},
    137763: {"Unified_Ideograph", "Ideographic"},
    137764: {"Unified_Ideograph", "Ideographic"},
    137765: {"Unified_Ideograph", "Ideographic"},
    137766: {"Unified_Ideograph", "Ideographic"},
    137767: {"Unified_Ideograph", "Ideographic"},
    137768: {"Unified_Ideograph", "Ideographic"},
    137769: {"Unified_Ideograph", "Ideographic"},
    137770: {"Unified_Ideograph", "Ideographic"},
    137771: {"Unified_Ideograph", "Ideographic"},
    137772: {"Unified_Ideograph", "Ideographic"},
    137773: {"Unified_Ideograph", "Ideographic"},
    137774: {"Unified_Ideograph", "Ideographic"},
    137775: {"Unified_Ideograph", "Ideographic"},
    137776: {"Unified_Ideograph", "Ideographic"},
    137777: {"Unified_Ideograph", "Ideographic"},
    137778: {"Unified_Ideograph", "Ideographic"},
    137779: {"Unified_Ideograph", "Ideographic"},
    137780: {"Unified_Ideograph", "Ideographic"},
    137781: {"Unified_Ideograph", "Ideographic"},
    137782: {"Unified_Ideograph", "Ideographic"},
    137783: {"Unified_Ideograph", "Ideographic"},
    137784: {"Unified_Ideograph", "Ideographic"},
    137785: {"Unified_Ideograph", "Ideographic"},
    137786: {"Unified_Ideograph", "Ideographic"},
    137787: {"Unified_Ideograph", "Ideographic"},
    137788: {"Unified_Ideograph", "Ideographic"},
    137789: {"Unified_Ideograph", "Ideographic"},
    137790: {"Unified_Ideograph", "Ideographic"},
    137791: {"Unified_Ideograph", "Ideographic"},
    137792: {"Unified_Ideograph", "Ideographic"},
    137793: {"Unified_Ideograph", "Ideographic"},
    137794: {"Unified_Ideograph", "Ideographic"},
    137795: {"Unified_Ideograph", "Ideographic"},
    137796: {"Unified_Ideograph", "Ideographic"},
    137797: {"Unified_Ideograph", "Ideographic"},
    137798: {"Unified_Ideograph", "Ideographic"},
    137799: {"Unified_Ideograph", "Ideographic"},
    137800: {"Unified_Ideograph", "Ideographic"},
    137801: {"Unified_Ideograph", "Ideographic"},
    137802: {"Unified_Ideograph", "Ideographic"},
    137803: {"Unified_Ideograph", "Ideographic"},
    137804: {"Unified_Ideograph", "Ideographic"},
    137805: {"Unified_Ideograph", "Ideographic"},
    137806: {"Unified_Ideograph", "Ideographic"},
    137807: {"Unified_Ideograph", "Ideographic"},
    137808: {"Unified_Ideograph", "Ideographic"},
    137809: {"Unified_Ideograph", "Ideographic"},
    137810: {"Unified_Ideograph", "Ideographic"},
    137811: {"Unified_Ideograph", "Ideographic"},
    137812: {"Unified_Ideograph", "Ideographic"},
    137813: {"Unified_Ideograph", "Ideographic"},
    137814: {"Unified_Ideograph", "Ideographic"},
    137815: {"Unified_Ideograph", "Ideographic"},
    137816: {"Unified_Ideograph", "Ideographic"},
    137817: {"Unified_Ideograph", "Ideographic"},
    137818: {"Unified_Ideograph", "Ideographic"},
    137819: {"Unified_Ideograph", "Ideographic"},
    137820: {"Unified_Ideograph", "Ideographic"},
    137821: {"Unified_Ideograph", "Ideographic"},
    137822: {"Unified_Ideograph", "Ideographic"},
    137823: {"Unified_Ideograph", "Ideographic"},
    137824: {"Unified_Ideograph", "Ideographic"},
    137825: {"Unified_Ideograph", "Ideographic"},
    137826: {"Unified_Ideograph", "Ideographic"},
    137827: {"Unified_Ideograph", "Ideographic"},
    137828: {"Unified_Ideograph", "Ideographic"},
    137829: {"Unified_Ideograph", "Ideographic"},
    137830: {"Unified_Ideograph", "Ideographic"},
    137831: {"Unified_Ideograph", "Ideographic"},
    137832: {"Unified_Ideograph", "Ideographic"},
    137833: {"Unified_Ideograph", "Ideographic"},
    137834: {"Unified_Ideograph", "Ideographic"},
    137835: {"Unified_Ideograph", "Ideographic"},
    137836: {"Unified_Ideograph", "Ideographic"},
    137837: {"Unified_Ideograph", "Ideographic"},
    137838: {"Unified_Ideograph", "Ideographic"},
    137839: {"Unified_Ideograph", "Ideographic"},
    137840: {"Unified_Ideograph", "Ideographic"},
    137841: {"Unified_Ideograph", "Ideographic"},
    137842: {"Unified_Ideograph", "Ideographic"},
    137843: {"Unified_Ideograph", "Ideographic"},
    137844: {"Unified_Ideograph", "Ideographic"},
    137845: {"Unified_Ideograph", "Ideographic"},
    137846: {"Unified_Ideograph", "Ideographic"},
    137847: {"Unified_Ideograph", "Ideographic"},
    137848: {"Unified_Ideograph", "Ideographic"},
    137849: {"Unified_Ideograph", "Ideographic"},
    137850: {"Unified_Ideograph", "Ideographic"},
    137851: {"Unified_Ideograph", "Ideographic"},
    137852: {"Unified_Ideograph", "Ideographic"},
    137853: {"Unified_Ideograph", "Ideographic"},
    137854: {"Unified_Ideograph", "Ideographic"},
    137855: {"Unified_Ideograph", "Ideographic"},
    137856: {"Unified_Ideograph", "Ideographic"},
    137857: {"Unified_Ideograph", "Ideographic"},
    137858: {"Unified_Ideograph", "Ideographic"},
    137859: {"Unified_Ideograph", "Ideographic"},
    137860: {"Unified_Ideograph", "Ideographic"},
    137861: {"Unified_Ideograph", "Ideographic"},
    137862: {"Unified_Ideograph", "Ideographic"},
    137863: {"Unified_Ideograph", "Ideographic"},
    137864: {"Unified_Ideograph", "Ideographic"},
    137865: {"Unified_Ideograph", "Ideographic"},
    137866: {"Unified_Ideograph", "Ideographic"},
    137867: {"Unified_Ideograph", "Ideographic"},
    137868: {"Unified_Ideograph", "Ideographic"},
    137869: {"Unified_Ideograph", "Ideographic"},
    137870: {"Unified_Ideograph", "Ideographic"},
    137871: {"Unified_Ideograph", "Ideographic"},
    137872: {"Unified_Ideograph", "Ideographic"},
    137873: {"Unified_Ideograph", "Ideographic"},
    137874: {"Unified_Ideograph", "Ideographic"},
    137875: {"Unified_Ideograph", "Ideographic"},
    137876: {"Unified_Ideograph", "Ideographic"},
    137877: {"Unified_Ideograph", "Ideographic"},
    137878: {"Unified_Ideograph", "Ideographic"},
    137879: {"Unified_Ideograph", "Ideographic"},
    137880: {"Unified_Ideograph", "Ideographic"},
    137881: {"Unified_Ideograph", "Ideographic"},
    137882: {"Unified_Ideograph", "Ideographic"},
    137883: {"Unified_Ideograph", "Ideographic"},
    137884: {"Unified_Ideograph", "Ideographic"},
    137885: {"Unified_Ideograph", "Ideographic"},
    137886: {"Unified_Ideograph", "Ideographic"},
    137887: {"Unified_Ideograph", "Ideographic"},
    137888: {"Unified_Ideograph", "Ideographic"},
    137889: {"Unified_Ideograph", "Ideographic"},
    137890: {"Unified_Ideograph", "Ideographic"},
    137891: {"Unified_Ideograph", "Ideographic"},
    137892: {"Unified_Ideograph", "Ideographic"},
    137893: {"Unified_Ideograph", "Ideographic"},
    137894: {"Unified_Ideograph", "Ideographic"},
    137895: {"Unified_Ideograph", "Ideographic"},
    137896: {"Unified_Ideograph", "Ideographic"},
    137897: {"Unified_Ideograph", "Ideographic"},
    137898: {"Unified_Ideograph", "Ideographic"},
    137899: {"Unified_Ideograph", "Ideographic"},
    137900: {"Unified_Ideograph", "Ideographic"},
    137901: {"Unified_Ideograph", "Ideographic"},
    137902: {"Unified_Ideograph", "Ideographic"},
    137903: {"Unified_Ideograph", "Ideographic"},
    137904: {"Unified_Ideograph", "Ideographic"},
    137905: {"Unified_Ideograph", "Ideographic"},
    137906: {"Unified_Ideograph", "Ideographic"},
    137907: {"Unified_Ideograph", "Ideographic"},
    137908: {"Unified_Ideograph", "Ideographic"},
    137909: {"Unified_Ideograph", "Ideographic"},
    137910: {"Unified_Ideograph", "Ideographic"},
    137911: {"Unified_Ideograph", "Ideographic"},
    137912: {"Unified_Ideograph", "Ideographic"},
    137913: {"Unified_Ideograph", "Ideographic"},
    137914: {"Unified_Ideograph", "Ideographic"},
    137915: {"Unified_Ideograph", "Ideographic"},
    137916: {"Unified_Ideograph", "Ideographic"},
    137917: {"Unified_Ideograph", "Ideographic"},
    137918: {"Unified_Ideograph", "Ideographic"},
    137919: {"Unified_Ideograph", "Ideographic"},
    137920: {"Unified_Ideograph", "Ideographic"},
    137921: {"Unified_Ideograph", "Ideographic"},
    137922: {"Unified_Ideograph", "Ideographic"},
    137923: {"Unified_Ideograph", "Ideographic"},
    137924: {"Unified_Ideograph", "Ideographic"},
    137925: {"Unified_Ideograph", "Ideographic"},
    137926: {"Unified_Ideograph", "Ideographic"},
    137927: {"Unified_Ideograph", "Ideographic"},
    137928: {"Unified_Ideograph", "Ideographic"},
    137929: {"Unified_Ideograph", "Ideographic"},
    137930: {"Unified_Ideograph", "Ideographic"},
    137931: {"Unified_Ideograph", "Ideographic"},
    137932: {"Unified_Ideograph", "Ideographic"},
    137933: {"Unified_Ideograph", "Ideographic"},
    137934: {"Unified_Ideograph", "Ideographic"},
    137935: {"Unified_Ideograph", "Ideographic"},
    137936: {"Unified_Ideograph", "Ideographic"},
    137937: {"Unified_Ideograph", "Ideographic"},
    137938: {"Unified_Ideograph", "Ideographic"},
    137939: {"Unified_Ideograph", "Ideographic"},
    137940: {"Unified_Ideograph", "Ideographic"},
    137941: {"Unified_Ideograph", "Ideographic"},
    137942: {"Unified_Ideograph", "Ideographic"},
    137943: {"Unified_Ideograph", "Ideographic"},
    137944: {"Unified_Ideograph", "Ideographic"},
    137945: {"Unified_Ideograph", "Ideographic"},
    137946: {"Unified_Ideograph", "Ideographic"},
    137947: {"Unified_Ideograph", "Ideographic"},
    137948: {"Unified_Ideograph", "Ideographic"},
    137949: {"Unified_Ideograph", "Ideographic"},
    137950: {"Unified_Ideograph", "Ideographic"},
    137951: {"Unified_Ideograph", "Ideographic"},
    137952: {"Unified_Ideograph", "Ideographic"},
    137953: {"Unified_Ideograph", "Ideographic"},
    137954: {"Unified_Ideograph", "Ideographic"},
    137955: {"Unified_Ideograph", "Ideographic"},
    137956: {"Unified_Ideograph", "Ideographic"},
    137957: {"Unified_Ideograph", "Ideographic"},
    137958: {"Unified_Ideograph", "Ideographic"},
    137959: {"Unified_Ideograph", "Ideographic"},
    137960: {"Unified_Ideograph", "Ideographic"},
    137961: {"Unified_Ideograph", "Ideographic"},
    137962: {"Unified_Ideograph", "Ideographic"},
    137963: {"Unified_Ideograph", "Ideographic"},
    137964: {"Unified_Ideograph", "Ideographic"},
    137965: {"Unified_Ideograph", "Ideographic"},
    137966: {"Unified_Ideograph", "Ideographic"},
    137967: {"Unified_Ideograph", "Ideographic"},
    137968: {"Unified_Ideograph", "Ideographic"},
    137969: {"Unified_Ideograph", "Ideographic"},
    137970: {"Unified_Ideograph", "Ideographic"},
    137971: {"Unified_Ideograph", "Ideographic"},
    137972: {"Unified_Ideograph", "Ideographic"},
    137973: {"Unified_Ideograph", "Ideographic"},
    137974: {"Unified_Ideograph", "Ideographic"},
    137975: {"Unified_Ideograph", "Ideographic"},
    137976: {"Unified_Ideograph", "Ideographic"},
    137977: {"Unified_Ideograph", "Ideographic"},
    137978: {"Unified_Ideograph", "Ideographic"},
    137979: {"Unified_Ideograph", "Ideographic"},
    137980: {"Unified_Ideograph", "Ideographic"},
    137981: {"Unified_Ideograph", "Ideographic"},
    137982: {"Unified_Ideograph", "Ideographic"},
    137983: {"Unified_Ideograph", "Ideographic"},
    137984: {"Unified_Ideograph", "Ideographic"},
    137985: {"Unified_Ideograph", "Ideographic"},
    137986: {"Unified_Ideograph", "Ideographic"},
    137987: {"Unified_Ideograph", "Ideographic"},
    137988: {"Unified_Ideograph", "Ideographic"},
    137989: {"Unified_Ideograph", "Ideographic"},
    137990: {"Unified_Ideograph", "Ideographic"},
    137991: {"Unified_Ideograph", "Ideographic"},
    137992: {"Unified_Ideograph", "Ideographic"},
    137993: {"Unified_Ideograph", "Ideographic"},
    137994: {"Unified_Ideograph", "Ideographic"},
    137995: {"Unified_Ideograph", "Ideographic"},
    137996: {"Unified_Ideograph", "Ideographic"},
    137997: {"Unified_Ideograph", "Ideographic"},
    137998: {"Unified_Ideograph", "Ideographic"},
    137999: {"Unified_Ideograph", "Ideographic"},
    138000: {"Unified_Ideograph", "Ideographic"},
    138001: {"Unified_Ideograph", "Ideographic"},
    138002: {"Unified_Ideograph", "Ideographic"},
    138003: {"Unified_Ideograph", "Ideographic"},
    138004: {"Unified_Ideograph", "Ideographic"},
    138005: {"Unified_Ideograph", "Ideographic"},
    138006: {"Unified_Ideograph", "Ideographic"},
    138007: {"Unified_Ideograph", "Ideographic"},
    138008: {"Unified_Ideograph", "Ideographic"},
    138009: {"Unified_Ideograph", "Ideographic"},
    138010: {"Unified_Ideograph", "Ideographic"},
    138011: {"Unified_Ideograph", "Ideographic"},
    138012: {"Unified_Ideograph", "Ideographic"},
    138013: {"Unified_Ideograph", "Ideographic"},
    138014: {"Unified_Ideograph", "Ideographic"},
    138015: {"Unified_Ideograph", "Ideographic"},
    138016: {"Unified_Ideograph", "Ideographic"},
    138017: {"Unified_Ideograph", "Ideographic"},
    138018: {"Unified_Ideograph", "Ideographic"},
    138019: {"Unified_Ideograph", "Ideographic"},
    138020: {"Unified_Ideograph", "Ideographic"},
    138021: {"Unified_Ideograph", "Ideographic"},
    138022: {"Unified_Ideograph", "Ideographic"},
    138023: {"Unified_Ideograph", "Ideographic"},
    138024: {"Unified_Ideograph", "Ideographic"},
    138025: {"Unified_Ideograph", "Ideographic"},
    138026: {"Unified_Ideograph", "Ideographic"},
    138027: {"Unified_Ideograph", "Ideographic"},
    138028: {"Unified_Ideograph", "Ideographic"},
    138029: {"Unified_Ideograph", "Ideographic"},
    138030: {"Unified_Ideograph", "Ideographic"},
    138031: {"Unified_Ideograph", "Ideographic"},
    138032: {"Unified_Ideograph", "Ideographic"},
    138033: {"Unified_Ideograph", "Ideographic"},
    138034: {"Unified_Ideograph", "Ideographic"},
    138035: {"Unified_Ideograph", "Ideographic"},
    138036: {"Unified_Ideograph", "Ideographic"},
    138037: {"Unified_Ideograph", "Ideographic"},
    138038: {"Unified_Ideograph", "Ideographic"},
    138039: {"Unified_Ideograph", "Ideographic"},
    138040: {"Unified_Ideograph", "Ideographic"},
    138041: {"Unified_Ideograph", "Ideographic"},
    138042: {"Unified_Ideograph", "Ideographic"},
    138043: {"Unified_Ideograph", "Ideographic"},
    138044: {"Unified_Ideograph", "Ideographic"},
    138045: {"Unified_Ideograph", "Ideographic"},
    138046: {"Unified_Ideograph", "Ideographic"},
    138047: {"Unified_Ideograph", "Ideographic"},
    138048: {"Unified_Ideograph", "Ideographic"},
    138049: {"Unified_Ideograph", "Ideographic"},
    138050: {"Unified_Ideograph", "Ideographic"},
    138051: {"Unified_Ideograph", "Ideographic"},
    138052: {"Unified_Ideograph", "Ideographic"},
    138053: {"Unified_Ideograph", "Ideographic"},
    138054: {"Unified_Ideograph", "Ideographic"},
    138055: {"Unified_Ideograph", "Ideographic"},
    138056: {"Unified_Ideograph", "Ideographic"},
    138057: {"Unified_Ideograph", "Ideographic"},
    138058: {"Unified_Ideograph", "Ideographic"},
    138059: {"Unified_Ideograph", "Ideographic"},
    138060: {"Unified_Ideograph", "Ideographic"},
    138061: {"Unified_Ideograph", "Ideographic"},
    138062: {"Unified_Ideograph", "Ideographic"},
    138063: {"Unified_Ideograph", "Ideographic"},
    138064: {"Unified_Ideograph", "Ideographic"},
    138065: {"Unified_Ideograph", "Ideographic"},
    138066: {"Unified_Ideograph", "Ideographic"},
    138067: {"Unified_Ideograph", "Ideographic"},
    138068: {"Unified_Ideograph", "Ideographic"},
    138069: {"Unified_Ideograph", "Ideographic"},
    138070: {"Unified_Ideograph", "Ideographic"},
    138071: {"Unified_Ideograph", "Ideographic"},
    138072: {"Unified_Ideograph", "Ideographic"},
    138073: {"Unified_Ideograph", "Ideographic"},
    138074: {"Unified_Ideograph", "Ideographic"},
    138075: {"Unified_Ideograph", "Ideographic"},
    138076: {"Unified_Ideograph", "Ideographic"},
    138077: {"Unified_Ideograph", "Ideographic"},
    138078: {"Unified_Ideograph", "Ideographic"},
    138079: {"Unified_Ideograph", "Ideographic"},
    138080: {"Unified_Ideograph", "Ideographic"},
    138081: {"Unified_Ideograph", "Ideographic"},
    138082: {"Unified_Ideograph", "Ideographic"},
    138083: {"Unified_Ideograph", "Ideographic"},
    138084: {"Unified_Ideograph", "Ideographic"},
    138085: {"Unified_Ideograph", "Ideographic"},
    138086: {"Unified_Ideograph", "Ideographic"},
    138087: {"Unified_Ideograph", "Ideographic"},
    138088: {"Unified_Ideograph", "Ideographic"},
    138089: {"Unified_Ideograph", "Ideographic"},
    138090: {"Unified_Ideograph", "Ideographic"},
    138091: {"Unified_Ideograph", "Ideographic"},
    138092: {"Unified_Ideograph", "Ideographic"},
    138093: {"Unified_Ideograph", "Ideographic"},
    138094: {"Unified_Ideograph", "Ideographic"},
    138095: {"Unified_Ideograph", "Ideographic"},
    138096: {"Unified_Ideograph", "Ideographic"},
    138097: {"Unified_Ideograph", "Ideographic"},
    138098: {"Unified_Ideograph", "Ideographic"},
    138099: {"Unified_Ideograph", "Ideographic"},
    138100: {"Unified_Ideograph", "Ideographic"},
    138101: {"Unified_Ideograph", "Ideographic"},
    138102: {"Unified_Ideograph", "Ideographic"},
    138103: {"Unified_Ideograph", "Ideographic"},
    138104: {"Unified_Ideograph", "Ideographic"},
    138105: {"Unified_Ideograph", "Ideographic"},
    138106: {"Unified_Ideograph", "Ideographic"},
    138107: {"Unified_Ideograph", "Ideographic"},
    138108: {"Unified_Ideograph", "Ideographic"},
    138109: {"Unified_Ideograph", "Ideographic"},
    138110: {"Unified_Ideograph", "Ideographic"},
    138111: {"Unified_Ideograph", "Ideographic"},
    138112: {"Unified_Ideograph", "Ideographic"},
    138113: {"Unified_Ideograph", "Ideographic"},
    138114: {"Unified_Ideograph", "Ideographic"},
    138115: {"Unified_Ideograph", "Ideographic"},
    138116: {"Unified_Ideograph", "Ideographic"},
    138117: {"Unified_Ideograph", "Ideographic"},
    138118: {"Unified_Ideograph", "Ideographic"},
    138119: {"Unified_Ideograph", "Ideographic"},
    138120: {"Unified_Ideograph", "Ideographic"},
    138121: {"Unified_Ideograph", "Ideographic"},
    138122: {"Unified_Ideograph", "Ideographic"},
    138123: {"Unified_Ideograph", "Ideographic"},
    138124: {"Unified_Ideograph", "Ideographic"},
    138125: {"Unified_Ideograph", "Ideographic"},
    138126: {"Unified_Ideograph", "Ideographic"},
    138127: {"Unified_Ideograph", "Ideographic"},
    138128: {"Unified_Ideograph", "Ideographic"},
    138129: {"Unified_Ideograph", "Ideographic"},
    138130: {"Unified_Ideograph", "Ideographic"},
    138131: {"Unified_Ideograph", "Ideographic"},
    138132: {"Unified_Ideograph", "Ideographic"},
    138133: {"Unified_Ideograph", "Ideographic"},
    138134: {"Unified_Ideograph", "Ideographic"},
    138135: {"Unified_Ideograph", "Ideographic"},
    138136: {"Unified_Ideograph", "Ideographic"},
    138137: {"Unified_Ideograph", "Ideographic"},
    138138: {"Unified_Ideograph", "Ideographic"},
    138139: {"Unified_Ideograph", "Ideographic"},
    138140: {"Unified_Ideograph", "Ideographic"},
    138141: {"Unified_Ideograph", "Ideographic"},
    138142: {"Unified_Ideograph", "Ideographic"},
    138143: {"Unified_Ideograph", "Ideographic"},
    138144: {"Unified_Ideograph", "Ideographic"},
    138145: {"Unified_Ideograph", "Ideographic"},
    138146: {"Unified_Ideograph", "Ideographic"},
    138147: {"Unified_Ideograph", "Ideographic"},
    138148: {"Unified_Ideograph", "Ideographic"},
    138149: {"Unified_Ideograph", "Ideographic"},
    138150: {"Unified_Ideograph", "Ideographic"},
    138151: {"Unified_Ideograph", "Ideographic"},
    138152: {"Unified_Ideograph", "Ideographic"},
    138153: {"Unified_Ideograph", "Ideographic"},
    138154: {"Unified_Ideograph", "Ideographic"},
    138155: {"Unified_Ideograph", "Ideographic"},
    138156: {"Unified_Ideograph", "Ideographic"},
    138157: {"Unified_Ideograph", "Ideographic"},
    138158: {"Unified_Ideograph", "Ideographic"},
    138159: {"Unified_Ideograph", "Ideographic"},
    138160: {"Unified_Ideograph", "Ideographic"},
    138161: {"Unified_Ideograph", "Ideographic"},
    138162: {"Unified_Ideograph", "Ideographic"},
    138163: {"Unified_Ideograph", "Ideographic"},
    138164: {"Unified_Ideograph", "Ideographic"},
    138165: {"Unified_Ideograph", "Ideographic"},
    138166: {"Unified_Ideograph", "Ideographic"},
    138167: {"Unified_Ideograph", "Ideographic"},
    138168: {"Unified_Ideograph", "Ideographic"},
    138169: {"Unified_Ideograph", "Ideographic"},
    138170: {"Unified_Ideograph", "Ideographic"},
    138171: {"Unified_Ideograph", "Ideographic"},
    138172: {"Unified_Ideograph", "Ideographic"},
    138173: {"Unified_Ideograph", "Ideographic"},
    138174: {"Unified_Ideograph", "Ideographic"},
    138175: {"Unified_Ideograph", "Ideographic"},
    138176: {"Unified_Ideograph", "Ideographic"},
    138177: {"Unified_Ideograph", "Ideographic"},
    138178: {"Unified_Ideograph", "Ideographic"},
    138179: {"Unified_Ideograph", "Ideographic"},
    138180: {"Unified_Ideograph", "Ideographic"},
    138181: {"Unified_Ideograph", "Ideographic"},
    138182: {"Unified_Ideograph", "Ideographic"},
    138183: {"Unified_Ideograph", "Ideographic"},
    138184: {"Unified_Ideograph", "Ideographic"},
    138185: {"Unified_Ideograph", "Ideographic"},
    138186: {"Unified_Ideograph", "Ideographic"},
    138187: {"Unified_Ideograph", "Ideographic"},
    138188: {"Unified_Ideograph", "Ideographic"},
    138189: {"Unified_Ideograph", "Ideographic"},
    138190: {"Unified_Ideograph", "Ideographic"},
    138191: {"Unified_Ideograph", "Ideographic"},
    138192: {"Unified_Ideograph", "Ideographic"},
    138193: {"Unified_Ideograph", "Ideographic"},
    138194: {"Unified_Ideograph", "Ideographic"},
    138195: {"Unified_Ideograph", "Ideographic"},
    138196: {"Unified_Ideograph", "Ideographic"},
    138197: {"Unified_Ideograph", "Ideographic"},
    138198: {"Unified_Ideograph", "Ideographic"},
    138199: {"Unified_Ideograph", "Ideographic"},
    138200: {"Unified_Ideograph", "Ideographic"},
    138201: {"Unified_Ideograph", "Ideographic"},
    138202: {"Unified_Ideograph", "Ideographic"},
    138203: {"Unified_Ideograph", "Ideographic"},
    138204: {"Unified_Ideograph", "Ideographic"},
    138205: {"Unified_Ideograph", "Ideographic"},
    138206: {"Unified_Ideograph", "Ideographic"},
    138207: {"Unified_Ideograph", "Ideographic"},
    138208: {"Unified_Ideograph", "Ideographic"},
    138209: {"Unified_Ideograph", "Ideographic"},
    138210: {"Unified_Ideograph", "Ideographic"},
    138211: {"Unified_Ideograph", "Ideographic"},
    138212: {"Unified_Ideograph", "Ideographic"},
    138213: {"Unified_Ideograph", "Ideographic"},
    138214: {"Unified_Ideograph", "Ideographic"},
    138215: {"Unified_Ideograph", "Ideographic"},
    138216: {"Unified_Ideograph", "Ideographic"},
    138217: {"Unified_Ideograph", "Ideographic"},
    138218: {"Unified_Ideograph", "Ideographic"},
    138219: {"Unified_Ideograph", "Ideographic"},
    138220: {"Unified_Ideograph", "Ideographic"},
    138221: {"Unified_Ideograph", "Ideographic"},
    138222: {"Unified_Ideograph", "Ideographic"},
    138223: {"Unified_Ideograph", "Ideographic"},
    138224: {"Unified_Ideograph", "Ideographic"},
    138225: {"Unified_Ideograph", "Ideographic"},
    138226: {"Unified_Ideograph", "Ideographic"},
    138227: {"Unified_Ideograph", "Ideographic"},
    138228: {"Unified_Ideograph", "Ideographic"},
    138229: {"Unified_Ideograph", "Ideographic"},
    138230: {"Unified_Ideograph", "Ideographic"},
    138231: {"Unified_Ideograph", "Ideographic"},
    138232: {"Unified_Ideograph", "Ideographic"},
    138233: {"Unified_Ideograph", "Ideographic"},
    138234: {"Unified_Ideograph", "Ideographic"},
    138235: {"Unified_Ideograph", "Ideographic"},
    138236: {"Unified_Ideograph", "Ideographic"},
    138237: {"Unified_Ideograph", "Ideographic"},
    138238: {"Unified_Ideograph", "Ideographic"},
    138239: {"Unified_Ideograph", "Ideographic"},
    138240: {"Unified_Ideograph", "Ideographic"},
    138241: {"Unified_Ideograph", "Ideographic"},
    138242: {"Unified_Ideograph", "Ideographic"},
    138243: {"Unified_Ideograph", "Ideographic"},
    138244: {"Unified_Ideograph", "Ideographic"},
    138245: {"Unified_Ideograph", "Ideographic"},
    138246: {"Unified_Ideograph", "Ideographic"},
    138247: {"Unified_Ideograph", "Ideographic"},
    138248: {"Unified_Ideograph", "Ideographic"},
    138249: {"Unified_Ideograph", "Ideographic"},
    138250: {"Unified_Ideograph", "Ideographic"},
    138251: {"Unified_Ideograph", "Ideographic"},
    138252: {"Unified_Ideograph", "Ideographic"},
    138253: {"Unified_Ideograph", "Ideographic"},
    138254: {"Unified_Ideograph", "Ideographic"},
    138255: {"Unified_Ideograph", "Ideographic"},
    138256: {"Unified_Ideograph", "Ideographic"},
    138257: {"Unified_Ideograph", "Ideographic"},
    138258: {"Unified_Ideograph", "Ideographic"},
    138259: {"Unified_Ideograph", "Ideographic"},
    138260: {"Unified_Ideograph", "Ideographic"},
    138261: {"Unified_Ideograph", "Ideographic"},
    138262: {"Unified_Ideograph", "Ideographic"},
    138263: {"Unified_Ideograph", "Ideographic"},
    138264: {"Unified_Ideograph", "Ideographic"},
    138265: {"Unified_Ideograph", "Ideographic"},
    138266: {"Unified_Ideograph", "Ideographic"},
    138267: {"Unified_Ideograph", "Ideographic"},
    138268: {"Unified_Ideograph", "Ideographic"},
    138269: {"Unified_Ideograph", "Ideographic"},
    138270: {"Unified_Ideograph", "Ideographic"},
    138271: {"Unified_Ideograph", "Ideographic"},
    138272: {"Unified_Ideograph", "Ideographic"},
    138273: {"Unified_Ideograph", "Ideographic"},
    138274: {"Unified_Ideograph", "Ideographic"},
    138275: {"Unified_Ideograph", "Ideographic"},
    138276: {"Unified_Ideograph", "Ideographic"},
    138277: {"Unified_Ideograph", "Ideographic"},
    138278: {"Unified_Ideograph", "Ideographic"},
    138279: {"Unified_Ideograph", "Ideographic"},
    138280: {"Unified_Ideograph", "Ideographic"},
    138281: {"Unified_Ideograph", "Ideographic"},
    138282: {"Unified_Ideograph", "Ideographic"},
    138283: {"Unified_Ideograph", "Ideographic"},
    138284: {"Unified_Ideograph", "Ideographic"},
    138285: {"Unified_Ideograph", "Ideographic"},
    138286: {"Unified_Ideograph", "Ideographic"},
    138287: {"Unified_Ideograph", "Ideographic"},
    138288: {"Unified_Ideograph", "Ideographic"},
    138289: {"Unified_Ideograph", "Ideographic"},
    138290: {"Unified_Ideograph", "Ideographic"},
    138291: {"Unified_Ideograph", "Ideographic"},
    138292: {"Unified_Ideograph", "Ideographic"},
    138293: {"Unified_Ideograph", "Ideographic"},
    138294: {"Unified_Ideograph", "Ideographic"},
    138295: {"Unified_Ideograph", "Ideographic"},
    138296: {"Unified_Ideograph", "Ideographic"},
    138297: {"Unified_Ideograph", "Ideographic"},
    138298: {"Unified_Ideograph", "Ideographic"},
    138299: {"Unified_Ideograph", "Ideographic"},
    138300: {"Unified_Ideograph", "Ideographic"},
    138301: {"Unified_Ideograph", "Ideographic"},
    138302: {"Unified_Ideograph", "Ideographic"},
    138303: {"Unified_Ideograph", "Ideographic"},
    138304: {"Unified_Ideograph", "Ideographic"},
    138305: {"Unified_Ideograph", "Ideographic"},
    138306: {"Unified_Ideograph", "Ideographic"},
    138307: {"Unified_Ideograph", "Ideographic"},
    138308: {"Unified_Ideograph", "Ideographic"},
    138309: {"Unified_Ideograph", "Ideographic"},
    138310: {"Unified_Ideograph", "Ideographic"},
    138311: {"Unified_Ideograph", "Ideographic"},
    138312: {"Unified_Ideograph", "Ideographic"},
    138313: {"Unified_Ideograph", "Ideographic"},
    138314: {"Unified_Ideograph", "Ideographic"},
    138315: {"Unified_Ideograph", "Ideographic"},
    138316: {"Unified_Ideograph", "Ideographic"},
    138317: {"Unified_Ideograph", "Ideographic"},
    138318: {"Unified_Ideograph", "Ideographic"},
    138319: {"Unified_Ideograph", "Ideographic"},
    138320: {"Unified_Ideograph", "Ideographic"},
    138321: {"Unified_Ideograph", "Ideographic"},
    138322: {"Unified_Ideograph", "Ideographic"},
    138323: {"Unified_Ideograph", "Ideographic"},
    138324: {"Unified_Ideograph", "Ideographic"},
    138325: {"Unified_Ideograph", "Ideographic"},
    138326: {"Unified_Ideograph", "Ideographic"},
    138327: {"Unified_Ideograph", "Ideographic"},
    138328: {"Unified_Ideograph", "Ideographic"},
    138329: {"Unified_Ideograph", "Ideographic"},
    138330: {"Unified_Ideograph", "Ideographic"},
    138331: {"Unified_Ideograph", "Ideographic"},
    138332: {"Unified_Ideograph", "Ideographic"},
    138333: {"Unified_Ideograph", "Ideographic"},
    138334: {"Unified_Ideograph", "Ideographic"},
    138335: {"Unified_Ideograph", "Ideographic"},
    138336: {"Unified_Ideograph", "Ideographic"},
    138337: {"Unified_Ideograph", "Ideographic"},
    138338: {"Unified_Ideograph", "Ideographic"},
    138339: {"Unified_Ideograph", "Ideographic"},
    138340: {"Unified_Ideograph", "Ideographic"},
    138341: {"Unified_Ideograph", "Ideographic"},
    138342: {"Unified_Ideograph", "Ideographic"},
    138343: {"Unified_Ideograph", "Ideographic"},
    138344: {"Unified_Ideograph", "Ideographic"},
    138345: {"Unified_Ideograph", "Ideographic"},
    138346: {"Unified_Ideograph", "Ideographic"},
    138347: {"Unified_Ideograph", "Ideographic"},
    138348: {"Unified_Ideograph", "Ideographic"},
    138349: {"Unified_Ideograph", "Ideographic"},
    138350: {"Unified_Ideograph", "Ideographic"},
    138351: {"Unified_Ideograph", "Ideographic"},
    138352: {"Unified_Ideograph", "Ideographic"},
    138353: {"Unified_Ideograph", "Ideographic"},
    138354: {"Unified_Ideograph", "Ideographic"},
    138355: {"Unified_Ideograph", "Ideographic"},
    138356: {"Unified_Ideograph", "Ideographic"},
    138357: {"Unified_Ideograph", "Ideographic"},
    138358: {"Unified_Ideograph", "Ideographic"},
    138359: {"Unified_Ideograph", "Ideographic"},
    138360: {"Unified_Ideograph", "Ideographic"},
    138361: {"Unified_Ideograph", "Ideographic"},
    138362: {"Unified_Ideograph", "Ideographic"},
    138363: {"Unified_Ideograph", "Ideographic"},
    138364: {"Unified_Ideograph", "Ideographic"},
    138365: {"Unified_Ideograph", "Ideographic"},
    138366: {"Unified_Ideograph", "Ideographic"},
    138367: {"Unified_Ideograph", "Ideographic"},
    138368: {"Unified_Ideograph", "Ideographic"},
    138369: {"Unified_Ideograph", "Ideographic"},
    138370: {"Unified_Ideograph", "Ideographic"},
    138371: {"Unified_Ideograph", "Ideographic"},
    138372: {"Unified_Ideograph", "Ideographic"},
    138373: {"Unified_Ideograph", "Ideographic"},
    138374: {"Unified_Ideograph", "Ideographic"},
    138375: {"Unified_Ideograph", "Ideographic"},
    138376: {"Unified_Ideograph", "Ideographic"},
    138377: {"Unified_Ideograph", "Ideographic"},
    138378: {"Unified_Ideograph", "Ideographic"},
    138379: {"Unified_Ideograph", "Ideographic"},
    138380: {"Unified_Ideograph", "Ideographic"},
    138381: {"Unified_Ideograph", "Ideographic"},
    138382: {"Unified_Ideograph", "Ideographic"},
    138383: {"Unified_Ideograph", "Ideographic"},
    138384: {"Unified_Ideograph", "Ideographic"},
    138385: {"Unified_Ideograph", "Ideographic"},
    138386: {"Unified_Ideograph", "Ideographic"},
    138387: {"Unified_Ideograph", "Ideographic"},
    138388: {"Unified_Ideograph", "Ideographic"},
    138389: {"Unified_Ideograph", "Ideographic"},
    138390: {"Unified_Ideograph", "Ideographic"},
    138391: {"Unified_Ideograph", "Ideographic"},
    138392: {"Unified_Ideograph", "Ideographic"},
    138393: {"Unified_Ideograph", "Ideographic"},
    138394: {"Unified_Ideograph", "Ideographic"},
    138395: {"Unified_Ideograph", "Ideographic"},
    138396: {"Unified_Ideograph", "Ideographic"},
    138397: {"Unified_Ideograph", "Ideographic"},
    138398: {"Unified_Ideograph", "Ideographic"},
    138399: {"Unified_Ideograph", "Ideographic"},
    138400: {"Unified_Ideograph", "Ideographic"},
    138401: {"Unified_Ideograph", "Ideographic"},
    138402: {"Unified_Ideograph", "Ideographic"},
    138403: {"Unified_Ideograph", "Ideographic"},
    138404: {"Unified_Ideograph", "Ideographic"},
    138405: {"Unified_Ideograph", "Ideographic"},
    138406: {"Unified_Ideograph", "Ideographic"},
    138407: {"Unified_Ideograph", "Ideographic"},
    138408: {"Unified_Ideograph", "Ideographic"},
    138409: {"Unified_Ideograph", "Ideographic"},
    138410: {"Unified_Ideograph", "Ideographic"},
    138411: {"Unified_Ideograph", "Ideographic"},
    138412: {"Unified_Ideograph", "Ideographic"},
    138413: {"Unified_Ideograph", "Ideographic"},
    138414: {"Unified_Ideograph", "Ideographic"},
    138415: {"Unified_Ideograph", "Ideographic"},
    138416: {"Unified_Ideograph", "Ideographic"},
    138417: {"Unified_Ideograph", "Ideographic"},
    138418: {"Unified_Ideograph", "Ideographic"},
    138419: {"Unified_Ideograph", "Ideographic"},
    138420: {"Unified_Ideograph", "Ideographic"},
    138421: {"Unified_Ideograph", "Ideographic"},
    138422: {"Unified_Ideograph", "Ideographic"},
    138423: {"Unified_Ideograph", "Ideographic"},
    138424: {"Unified_Ideograph", "Ideographic"},
    138425: {"Unified_Ideograph", "Ideographic"},
    138426: {"Unified_Ideograph", "Ideographic"},
    138427: {"Unified_Ideograph", "Ideographic"},
    138428: {"Unified_Ideograph", "Ideographic"},
    138429: {"Unified_Ideograph", "Ideographic"},
    138430: {"Unified_Ideograph", "Ideographic"},
    138431: {"Unified_Ideograph", "Ideographic"},
    138432: {"Unified_Ideograph", "Ideographic"},
    138433: {"Unified_Ideograph", "Ideographic"},
    138434: {"Unified_Ideograph", "Ideographic"},
    138435: {"Unified_Ideograph", "Ideographic"},
    138436: {"Unified_Ideograph", "Ideographic"},
    138437: {"Unified_Ideograph", "Ideographic"},
    138438: {"Unified_Ideograph", "Ideographic"},
    138439: {"Unified_Ideograph", "Ideographic"},
    138440: {"Unified_Ideograph", "Ideographic"},
    138441: {"Unified_Ideograph", "Ideographic"},
    138442: {"Unified_Ideograph", "Ideographic"},
    138443: {"Unified_Ideograph", "Ideographic"},
    138444: {"Unified_Ideograph", "Ideographic"},
    138445: {"Unified_Ideograph", "Ideographic"},
    138446: {"Unified_Ideograph", "Ideographic"},
    138447: {"Unified_Ideograph", "Ideographic"},
    138448: {"Unified_Ideograph", "Ideographic"},
    138449: {"Unified_Ideograph", "Ideographic"},
    138450: {"Unified_Ideograph", "Ideographic"},
    138451: {"Unified_Ideograph", "Ideographic"},
    138452: {"Unified_Ideograph", "Ideographic"},
    138453: {"Unified_Ideograph", "Ideographic"},
    138454: {"Unified_Ideograph", "Ideographic"},
    138455: {"Unified_Ideograph", "Ideographic"},
    138456: {"Unified_Ideograph", "Ideographic"},
    138457: {"Unified_Ideograph", "Ideographic"},
    138458: {"Unified_Ideograph", "Ideographic"},
    138459: {"Unified_Ideograph", "Ideographic"},
    138460: {"Unified_Ideograph", "Ideographic"},
    138461: {"Unified_Ideograph", "Ideographic"},
    138462: {"Unified_Ideograph", "Ideographic"},
    138463: {"Unified_Ideograph", "Ideographic"},
    138464: {"Unified_Ideograph", "Ideographic"},
    138465: {"Unified_Ideograph", "Ideographic"},
    138466: {"Unified_Ideograph", "Ideographic"},
    138467: {"Unified_Ideograph", "Ideographic"},
    138468: {"Unified_Ideograph", "Ideographic"},
    138469: {"Unified_Ideograph", "Ideographic"},
    138470: {"Unified_Ideograph", "Ideographic"},
    138471: {"Unified_Ideograph", "Ideographic"},
    138472: {"Unified_Ideograph", "Ideographic"},
    138473: {"Unified_Ideograph", "Ideographic"},
    138474: {"Unified_Ideograph", "Ideographic"},
    138475: {"Unified_Ideograph", "Ideographic"},
    138476: {"Unified_Ideograph", "Ideographic"},
    138477: {"Unified_Ideograph", "Ideographic"},
    138478: {"Unified_Ideograph", "Ideographic"},
    138479: {"Unified_Ideograph", "Ideographic"},
    138480: {"Unified_Ideograph", "Ideographic"},
    138481: {"Unified_Ideograph", "Ideographic"},
    138482: {"Unified_Ideograph", "Ideographic"},
    138483: {"Unified_Ideograph", "Ideographic"},
    138484: {"Unified_Ideograph", "Ideographic"},
    138485: {"Unified_Ideograph", "Ideographic"},
    138486: {"Unified_Ideograph", "Ideographic"},
    138487: {"Unified_Ideograph", "Ideographic"},
    138488: {"Unified_Ideograph", "Ideographic"},
    138489: {"Unified_Ideograph", "Ideographic"},
    138490: {"Unified_Ideograph", "Ideographic"},
    138491: {"Unified_Ideograph", "Ideographic"},
    138492: {"Unified_Ideograph", "Ideographic"},
    138493: {"Unified_Ideograph", "Ideographic"},
    138494: {"Unified_Ideograph", "Ideographic"},
    138495: {"Unified_Ideograph", "Ideographic"},
    138496: {"Unified_Ideograph", "Ideographic"},
    138497: {"Unified_Ideograph", "Ideographic"},
    138498: {"Unified_Ideograph", "Ideographic"},
    138499: {"Unified_Ideograph", "Ideographic"},
    138500: {"Unified_Ideograph", "Ideographic"},
    138501: {"Unified_Ideograph", "Ideographic"},
    138502: {"Unified_Ideograph", "Ideographic"},
    138503: {"Unified_Ideograph", "Ideographic"},
    138504: {"Unified_Ideograph", "Ideographic"},
    138505: {"Unified_Ideograph", "Ideographic"},
    138506: {"Unified_Ideograph", "Ideographic"},
    138507: {"Unified_Ideograph", "Ideographic"},
    138508: {"Unified_Ideograph", "Ideographic"},
    138509: {"Unified_Ideograph", "Ideographic"},
    138510: {"Unified_Ideograph", "Ideographic"},
    138511: {"Unified_Ideograph", "Ideographic"},
    138512: {"Unified_Ideograph", "Ideographic"},
    138513: {"Unified_Ideograph", "Ideographic"},
    138514: {"Unified_Ideograph", "Ideographic"},
    138515: {"Unified_Ideograph", "Ideographic"},
    138516: {"Unified_Ideograph", "Ideographic"},
    138517: {"Unified_Ideograph", "Ideographic"},
    138518: {"Unified_Ideograph", "Ideographic"},
    138519: {"Unified_Ideograph", "Ideographic"},
    138520: {"Unified_Ideograph", "Ideographic"},
    138521: {"Unified_Ideograph", "Ideographic"},
    138522: {"Unified_Ideograph", "Ideographic"},
    138523: {"Unified_Ideograph", "Ideographic"},
    138524: {"Unified_Ideograph", "Ideographic"},
    138525: {"Unified_Ideograph", "Ideographic"},
    138526: {"Unified_Ideograph", "Ideographic"},
    138527: {"Unified_Ideograph", "Ideographic"},
    138528: {"Unified_Ideograph", "Ideographic"},
    138529: {"Unified_Ideograph", "Ideographic"},
    138530: {"Unified_Ideograph", "Ideographic"},
    138531: {"Unified_Ideograph", "Ideographic"},
    138532: {"Unified_Ideograph", "Ideographic"},
    138533: {"Unified_Ideograph", "Ideographic"},
    138534: {"Unified_Ideograph", "Ideographic"},
    138535: {"Unified_Ideograph", "Ideographic"},
    138536: {"Unified_Ideograph", "Ideographic"},
    138537: {"Unified_Ideograph", "Ideographic"},
    138538: {"Unified_Ideograph", "Ideographic"},
    138539: {"Unified_Ideograph", "Ideographic"},
    138540: {"Unified_Ideograph", "Ideographic"},
    138541: {"Unified_Ideograph", "Ideographic"},
    138542: {"Unified_Ideograph", "Ideographic"},
    138543: {"Unified_Ideograph", "Ideographic"},
    138544: {"Unified_Ideograph", "Ideographic"},
    138545: {"Unified_Ideograph", "Ideographic"},
    138546: {"Unified_Ideograph", "Ideographic"},
    138547: {"Unified_Ideograph", "Ideographic"},
    138548: {"Unified_Ideograph", "Ideographic"},
    138549: {"Unified_Ideograph", "Ideographic"},
    138550: {"Unified_Ideograph", "Ideographic"},
    138551: {"Unified_Ideograph", "Ideographic"},
    138552: {"Unified_Ideograph", "Ideographic"},
    138553: {"Unified_Ideograph", "Ideographic"},
    138554: {"Unified_Ideograph", "Ideographic"},
    138555: {"Unified_Ideograph", "Ideographic"},
    138556: {"Unified_Ideograph", "Ideographic"},
    138557: {"Unified_Ideograph", "Ideographic"},
    138558: {"Unified_Ideograph", "Ideographic"},
    138559: {"Unified_Ideograph", "Ideographic"},
    138560: {"Unified_Ideograph", "Ideographic"},
    138561: {"Unified_Ideograph", "Ideographic"},
    138562: {"Unified_Ideograph", "Ideographic"},
    138563: {"Unified_Ideograph", "Ideographic"},
    138564: {"Unified_Ideograph", "Ideographic"},
    138565: {"Unified_Ideograph", "Ideographic"},
    138566: {"Unified_Ideograph", "Ideographic"},
    138567: {"Unified_Ideograph", "Ideographic"},
    138568: {"Unified_Ideograph", "Ideographic"},
    138569: {"Unified_Ideograph", "Ideographic"},
    138570: {"Unified_Ideograph", "Ideographic"},
    138571: {"Unified_Ideograph", "Ideographic"},
    138572: {"Unified_Ideograph", "Ideographic"},
    138573: {"Unified_Ideograph", "Ideographic"},
    138574: {"Unified_Ideograph", "Ideographic"},
    138575: {"Unified_Ideograph", "Ideographic"},
    138576: {"Unified_Ideograph", "Ideographic"},
    138577: {"Unified_Ideograph", "Ideographic"},
    138578: {"Unified_Ideograph", "Ideographic"},
    138579: {"Unified_Ideograph", "Ideographic"},
    138580: {"Unified_Ideograph", "Ideographic"},
    138581: {"Unified_Ideograph", "Ideographic"},
    138582: {"Unified_Ideograph", "Ideographic"},
    138583: {"Unified_Ideograph", "Ideographic"},
    138584: {"Unified_Ideograph", "Ideographic"},
    138585: {"Unified_Ideograph", "Ideographic"},
    138586: {"Unified_Ideograph", "Ideographic"},
    138587: {"Unified_Ideograph", "Ideographic"},
    138588: {"Unified_Ideograph", "Ideographic"},
    138589: {"Unified_Ideograph", "Ideographic"},
    138590: {"Unified_Ideograph", "Ideographic"},
    138591: {"Unified_Ideograph", "Ideographic"},
    138592: {"Unified_Ideograph", "Ideographic"},
    138593: {"Unified_Ideograph", "Ideographic"},
    138594: {"Unified_Ideograph", "Ideographic"},
    138595: {"Unified_Ideograph", "Ideographic"},
    138596: {"Unified_Ideograph", "Ideographic"},
    138597: {"Unified_Ideograph", "Ideographic"},
    138598: {"Unified_Ideograph", "Ideographic"},
    138599: {"Unified_Ideograph", "Ideographic"},
    138600: {"Unified_Ideograph", "Ideographic"},
    138601: {"Unified_Ideograph", "Ideographic"},
    138602: {"Unified_Ideograph", "Ideographic"},
    138603: {"Unified_Ideograph", "Ideographic"},
    138604: {"Unified_Ideograph", "Ideographic"},
    138605: {"Unified_Ideograph", "Ideographic"},
    138606: {"Unified_Ideograph", "Ideographic"},
    138607: {"Unified_Ideograph", "Ideographic"},
    138608: {"Unified_Ideograph", "Ideographic"},
    138609: {"Unified_Ideograph", "Ideographic"},
    138610: {"Unified_Ideograph", "Ideographic"},
    138611: {"Unified_Ideograph", "Ideographic"},
    138612: {"Unified_Ideograph", "Ideographic"},
    138613: {"Unified_Ideograph", "Ideographic"},
    138614: {"Unified_Ideograph", "Ideographic"},
    138615: {"Unified_Ideograph", "Ideographic"},
    138616: {"Unified_Ideograph", "Ideographic"},
    138617: {"Unified_Ideograph", "Ideographic"},
    138618: {"Unified_Ideograph", "Ideographic"},
    138619: {"Unified_Ideograph", "Ideographic"},
    138620: {"Unified_Ideograph", "Ideographic"},
    138621: {"Unified_Ideograph", "Ideographic"},
    138622: {"Unified_Ideograph", "Ideographic"},
    138623: {"Unified_Ideograph", "Ideographic"},
    138624: {"Unified_Ideograph", "Ideographic"},
    138625: {"Unified_Ideograph", "Ideographic"},
    138626: {"Unified_Ideograph", "Ideographic"},
    138627: {"Unified_Ideograph", "Ideographic"},
    138628: {"Unified_Ideograph", "Ideographic"},
    138629: {"Unified_Ideograph", "Ideographic"},
    138630: {"Unified_Ideograph", "Ideographic"},
    138631: {"Unified_Ideograph", "Ideographic"},
    138632: {"Unified_Ideograph", "Ideographic"},
    138633: {"Unified_Ideograph", "Ideographic"},
    138634: {"Unified_Ideograph", "Ideographic"},
    138635: {"Unified_Ideograph", "Ideographic"},
    138636: {"Unified_Ideograph", "Ideographic"},
    138637: {"Unified_Ideograph", "Ideographic"},
    138638: {"Unified_Ideograph", "Ideographic"},
    138639: {"Unified_Ideograph", "Ideographic"},
    138640: {"Unified_Ideograph", "Ideographic"},
    138641: {"Unified_Ideograph", "Ideographic"},
    138642: {"Unified_Ideograph", "Ideographic"},
    138643: {"Unified_Ideograph", "Ideographic"},
    138644: {"Unified_Ideograph", "Ideographic"},
    138645: {"Unified_Ideograph", "Ideographic"},
    138646: {"Unified_Ideograph", "Ideographic"},
    138647: {"Unified_Ideograph", "Ideographic"},
    138648: {"Unified_Ideograph", "Ideographic"},
    138649: {"Unified_Ideograph", "Ideographic"},
    138650: {"Unified_Ideograph", "Ideographic"},
    138651: {"Unified_Ideograph", "Ideographic"},
    138652: {"Unified_Ideograph", "Ideographic"},
    138653: {"Unified_Ideograph", "Ideographic"},
    138654: {"Unified_Ideograph", "Ideographic"},
    138655: {"Unified_Ideograph", "Ideographic"},
    138656: {"Unified_Ideograph", "Ideographic"},
    138657: {"Unified_Ideograph", "Ideographic"},
    138658: {"Unified_Ideograph", "Ideographic"},
    138659: {"Unified_Ideograph", "Ideographic"},
    138660: {"Unified_Ideograph", "Ideographic"},
    138661: {"Unified_Ideograph", "Ideographic"},
    138662: {"Unified_Ideograph", "Ideographic"},
    138663: {"Unified_Ideograph", "Ideographic"},
    138664: {"Unified_Ideograph", "Ideographic"},
    138665: {"Unified_Ideograph", "Ideographic"},
    138666: {"Unified_Ideograph", "Ideographic"},
    138667: {"Unified_Ideograph", "Ideographic"},
    138668: {"Unified_Ideograph", "Ideographic"},
    138669: {"Unified_Ideograph", "Ideographic"},
    138670: {"Unified_Ideograph", "Ideographic"},
    138671: {"Unified_Ideograph", "Ideographic"},
    138672: {"Unified_Ideograph", "Ideographic"},
    138673: {"Unified_Ideograph", "Ideographic"},
    138674: {"Unified_Ideograph", "Ideographic"},
    138675: {"Unified_Ideograph", "Ideographic"},
    138676: {"Unified_Ideograph", "Ideographic"},
    138677: {"Unified_Ideograph", "Ideographic"},
    138678: {"Unified_Ideograph", "Ideographic"},
    138679: {"Unified_Ideograph", "Ideographic"},
    138680: {"Unified_Ideograph", "Ideographic"},
    138681: {"Unified_Ideograph", "Ideographic"},
    138682: {"Unified_Ideograph", "Ideographic"},
    138683: {"Unified_Ideograph", "Ideographic"},
    138684: {"Unified_Ideograph", "Ideographic"},
    138685: {"Unified_Ideograph", "Ideographic"},
    138686: {"Unified_Ideograph", "Ideographic"},
    138687: {"Unified_Ideograph", "Ideographic"},
    138688: {"Unified_Ideograph", "Ideographic"},
    138689: {"Unified_Ideograph", "Ideographic"},
    138690: {"Unified_Ideograph", "Ideographic"},
    138691: {"Unified_Ideograph", "Ideographic"},
    138692: {"Unified_Ideograph", "Ideographic"},
    138693: {"Unified_Ideograph", "Ideographic"},
    138694: {"Unified_Ideograph", "Ideographic"},
    138695: {"Unified_Ideograph", "Ideographic"},
    138696: {"Unified_Ideograph", "Ideographic"},
    138697: {"Unified_Ideograph", "Ideographic"},
    138698: {"Unified_Ideograph", "Ideographic"},
    138699: {"Unified_Ideograph", "Ideographic"},
    138700: {"Unified_Ideograph", "Ideographic"},
    138701: {"Unified_Ideograph", "Ideographic"},
    138702: {"Unified_Ideograph", "Ideographic"},
    138703: {"Unified_Ideograph", "Ideographic"},
    138704: {"Unified_Ideograph", "Ideographic"},
    138705: {"Unified_Ideograph", "Ideographic"},
    138706: {"Unified_Ideograph", "Ideographic"},
    138707: {"Unified_Ideograph", "Ideographic"},
    138708: {"Unified_Ideograph", "Ideographic"},
    138709: {"Unified_Ideograph", "Ideographic"},
    138710: {"Unified_Ideograph", "Ideographic"},
    138711: {"Unified_Ideograph", "Ideographic"},
    138712: {"Unified_Ideograph", "Ideographic"},
    138713: {"Unified_Ideograph", "Ideographic"},
    138714: {"Unified_Ideograph", "Ideographic"},
    138715: {"Unified_Ideograph", "Ideographic"},
    138716: {"Unified_Ideograph", "Ideographic"},
    138717: {"Unified_Ideograph", "Ideographic"},
    138718: {"Unified_Ideograph", "Ideographic"},
    138719: {"Unified_Ideograph", "Ideographic"},
    138720: {"Unified_Ideograph", "Ideographic"},
    138721: {"Unified_Ideograph", "Ideographic"},
    138722: {"Unified_Ideograph", "Ideographic"},
    138723: {"Unified_Ideograph", "Ideographic"},
    138724: {"Unified_Ideograph", "Ideographic"},
    138725: {"Unified_Ideograph", "Ideographic"},
    138726: {"Unified_Ideograph", "Ideographic"},
    138727: {"Unified_Ideograph", "Ideographic"},
    138728: {"Unified_Ideograph", "Ideographic"},
    138729: {"Unified_Ideograph", "Ideographic"},
    138730: {"Unified_Ideograph", "Ideographic"},
    138731: {"Unified_Ideograph", "Ideographic"},
    138732: {"Unified_Ideograph", "Ideographic"},
    138733: {"Unified_Ideograph", "Ideographic"},
    138734: {"Unified_Ideograph", "Ideographic"},
    138735: {"Unified_Ideograph", "Ideographic"},
    138736: {"Unified_Ideograph", "Ideographic"},
    138737: {"Unified_Ideograph", "Ideographic"},
    138738: {"Unified_Ideograph", "Ideographic"},
    138739: {"Unified_Ideograph", "Ideographic"},
    138740: {"Unified_Ideograph", "Ideographic"},
    138741: {"Unified_Ideograph", "Ideographic"},
    138742: {"Unified_Ideograph", "Ideographic"},
    138743: {"Unified_Ideograph", "Ideographic"},
    138744: {"Unified_Ideograph", "Ideographic"},
    138745: {"Unified_Ideograph", "Ideographic"},
    138746: {"Unified_Ideograph", "Ideographic"},
    138747: {"Unified_Ideograph", "Ideographic"},
    138748: {"Unified_Ideograph", "Ideographic"},
    138749: {"Unified_Ideograph", "Ideographic"},
    138750: {"Unified_Ideograph", "Ideographic"},
    138751: {"Unified_Ideograph", "Ideographic"},
    138752: {"Unified_Ideograph", "Ideographic"},
    138753: {"Unified_Ideograph", "Ideographic"},
    138754: {"Unified_Ideograph", "Ideographic"},
    138755: {"Unified_Ideograph", "Ideographic"},
    138756: {"Unified_Ideograph", "Ideographic"},
    138757: {"Unified_Ideograph", "Ideographic"},
    138758: {"Unified_Ideograph", "Ideographic"},
    138759: {"Unified_Ideograph", "Ideographic"},
    138760: {"Unified_Ideograph", "Ideographic"},
    138761: {"Unified_Ideograph", "Ideographic"},
    138762: {"Unified_Ideograph", "Ideographic"},
    138763: {"Unified_Ideograph", "Ideographic"},
    138764: {"Unified_Ideograph", "Ideographic"},
    138765: {"Unified_Ideograph", "Ideographic"},
    138766: {"Unified_Ideograph", "Ideographic"},
    138767: {"Unified_Ideograph", "Ideographic"},
    138768: {"Unified_Ideograph", "Ideographic"},
    138769: {"Unified_Ideograph", "Ideographic"},
    138770: {"Unified_Ideograph", "Ideographic"},
    138771: {"Unified_Ideograph", "Ideographic"},
    138772: {"Unified_Ideograph", "Ideographic"},
    138773: {"Unified_Ideograph", "Ideographic"},
    138774: {"Unified_Ideograph", "Ideographic"},
    138775: {"Unified_Ideograph", "Ideographic"},
    138776: {"Unified_Ideograph", "Ideographic"},
    138777: {"Unified_Ideograph", "Ideographic"},
    138778: {"Unified_Ideograph", "Ideographic"},
    138779: {"Unified_Ideograph", "Ideographic"},
    138780: {"Unified_Ideograph", "Ideographic"},
    138781: {"Unified_Ideograph", "Ideographic"},
    138782: {"Unified_Ideograph", "Ideographic"},
    138783: {"Unified_Ideograph", "Ideographic"},
    138784: {"Unified_Ideograph", "Ideographic"},
    138785: {"Unified_Ideograph", "Ideographic"},
    138786: {"Unified_Ideograph", "Ideographic"},
    138787: {"Unified_Ideograph", "Ideographic"},
    138788: {"Unified_Ideograph", "Ideographic"},
    138789: {"Unified_Ideograph", "Ideographic"},
    138790: {"Unified_Ideograph", "Ideographic"},
    138791: {"Unified_Ideograph", "Ideographic"},
    138792: {"Unified_Ideograph", "Ideographic"},
    138793: {"Unified_Ideograph", "Ideographic"},
    138794: {"Unified_Ideograph", "Ideographic"},
    138795: {"Unified_Ideograph", "Ideographic"},
    138796: {"Unified_Ideograph", "Ideographic"},
    138797: {"Unified_Ideograph", "Ideographic"},
    138798: {"Unified_Ideograph", "Ideographic"},
    138799: {"Unified_Ideograph", "Ideographic"},
    138800: {"Unified_Ideograph", "Ideographic"},
    138801: {"Unified_Ideograph", "Ideographic"},
    138802: {"Unified_Ideograph", "Ideographic"},
    138803: {"Unified_Ideograph", "Ideographic"},
    138804: {"Unified_Ideograph", "Ideographic"},
    138805: {"Unified_Ideograph", "Ideographic"},
    138806: {"Unified_Ideograph", "Ideographic"},
    138807: {"Unified_Ideograph", "Ideographic"},
    138808: {"Unified_Ideograph", "Ideographic"},
    138809: {"Unified_Ideograph", "Ideographic"},
    138810: {"Unified_Ideograph", "Ideographic"},
    138811: {"Unified_Ideograph", "Ideographic"},
    138812: {"Unified_Ideograph", "Ideographic"},
    138813: {"Unified_Ideograph", "Ideographic"},
    138814: {"Unified_Ideograph", "Ideographic"},
    138815: {"Unified_Ideograph", "Ideographic"},
    138816: {"Unified_Ideograph", "Ideographic"},
    138817: {"Unified_Ideograph", "Ideographic"},
    138818: {"Unified_Ideograph", "Ideographic"},
    138819: {"Unified_Ideograph", "Ideographic"},
    138820: {"Unified_Ideograph", "Ideographic"},
    138821: {"Unified_Ideograph", "Ideographic"},
    138822: {"Unified_Ideograph", "Ideographic"},
    138823: {"Unified_Ideograph", "Ideographic"},
    138824: {"Unified_Ideograph", "Ideographic"},
    138825: {"Unified_Ideograph", "Ideographic"},
    138826: {"Unified_Ideograph", "Ideographic"},
    138827: {"Unified_Ideograph", "Ideographic"},
    138828: {"Unified_Ideograph", "Ideographic"},
    138829: {"Unified_Ideograph", "Ideographic"},
    138830: {"Unified_Ideograph", "Ideographic"},
    138831: {"Unified_Ideograph", "Ideographic"},
    138832: {"Unified_Ideograph", "Ideographic"},
    138833: {"Unified_Ideograph", "Ideographic"},
    138834: {"Unified_Ideograph", "Ideographic"},
    138835: {"Unified_Ideograph", "Ideographic"},
    138836: {"Unified_Ideograph", "Ideographic"},
    138837: {"Unified_Ideograph", "Ideographic"},
    138838: {"Unified_Ideograph", "Ideographic"},
    138839: {"Unified_Ideograph", "Ideographic"},
    138840: {"Unified_Ideograph", "Ideographic"},
    138841: {"Unified_Ideograph", "Ideographic"},
    138842: {"Unified_Ideograph", "Ideographic"},
    138843: {"Unified_Ideograph", "Ideographic"},
    138844: {"Unified_Ideograph", "Ideographic"},
    138845: {"Unified_Ideograph", "Ideographic"},
    138846: {"Unified_Ideograph", "Ideographic"},
    138847: {"Unified_Ideograph", "Ideographic"},
    138848: {"Unified_Ideograph", "Ideographic"},
    138849: {"Unified_Ideograph", "Ideographic"},
    138850: {"Unified_Ideograph", "Ideographic"},
    138851: {"Unified_Ideograph", "Ideographic"},
    138852: {"Unified_Ideograph", "Ideographic"},
    138853: {"Unified_Ideograph", "Ideographic"},
    138854: {"Unified_Ideograph", "Ideographic"},
    138855: {"Unified_Ideograph", "Ideographic"},
    138856: {"Unified_Ideograph", "Ideographic"},
    138857: {"Unified_Ideograph", "Ideographic"},
    138858: {"Unified_Ideograph", "Ideographic"},
    138859: {"Unified_Ideograph", "Ideographic"},
    138860: {"Unified_Ideograph", "Ideographic"},
    138861: {"Unified_Ideograph", "Ideographic"},
    138862: {"Unified_Ideograph", "Ideographic"},
    138863: {"Unified_Ideograph", "Ideographic"},
    138864: {"Unified_Ideograph", "Ideographic"},
    138865: {"Unified_Ideograph", "Ideographic"},
    138866: {"Unified_Ideograph", "Ideographic"},
    138867: {"Unified_Ideograph", "Ideographic"},
    138868: {"Unified_Ideograph", "Ideographic"},
    138869: {"Unified_Ideograph", "Ideographic"},
    138870: {"Unified_Ideograph", "Ideographic"},
    138871: {"Unified_Ideograph", "Ideographic"},
    138872: {"Unified_Ideograph", "Ideographic"},
    138873: {"Unified_Ideograph", "Ideographic"},
    138874: {"Unified_Ideograph", "Ideographic"},
    138875: {"Unified_Ideograph", "Ideographic"},
    138876: {"Unified_Ideograph", "Ideographic"},
    138877: {"Unified_Ideograph", "Ideographic"},
    138878: {"Unified_Ideograph", "Ideographic"},
    138879: {"Unified_Ideograph", "Ideographic"},
    138880: {"Unified_Ideograph", "Ideographic"},
    138881: {"Unified_Ideograph", "Ideographic"},
    138882: {"Unified_Ideograph", "Ideographic"},
    138883: {"Unified_Ideograph", "Ideographic"},
    138884: {"Unified_Ideograph", "Ideographic"},
    138885: {"Unified_Ideograph", "Ideographic"},
    138886: {"Unified_Ideograph", "Ideographic"},
    138887: {"Unified_Ideograph", "Ideographic"},
    138888: {"Unified_Ideograph", "Ideographic"},
    138889: {"Unified_Ideograph", "Ideographic"},
    138890: {"Unified_Ideograph", "Ideographic"},
    138891: {"Unified_Ideograph", "Ideographic"},
    138892: {"Unified_Ideograph", "Ideographic"},
    138893: {"Unified_Ideograph", "Ideographic"},
    138894: {"Unified_Ideograph", "Ideographic"},
    138895: {"Unified_Ideograph", "Ideographic"},
    138896: {"Unified_Ideograph", "Ideographic"},
    138897: {"Unified_Ideograph", "Ideographic"},
    138898: {"Unified_Ideograph", "Ideographic"},
    138899: {"Unified_Ideograph", "Ideographic"},
    138900: {"Unified_Ideograph", "Ideographic"},
    138901: {"Unified_Ideograph", "Ideographic"},
    138902: {"Unified_Ideograph", "Ideographic"},
    138903: {"Unified_Ideograph", "Ideographic"},
    138904: {"Unified_Ideograph", "Ideographic"},
    138905: {"Unified_Ideograph", "Ideographic"},
    138906: {"Unified_Ideograph", "Ideographic"},
    138907: {"Unified_Ideograph", "Ideographic"},
    138908: {"Unified_Ideograph", "Ideographic"},
    138909: {"Unified_Ideograph", "Ideographic"},
    138910: {"Unified_Ideograph", "Ideographic"},
    138911: {"Unified_Ideograph", "Ideographic"},
    138912: {"Unified_Ideograph", "Ideographic"},
    138913: {"Unified_Ideograph", "Ideographic"},
    138914: {"Unified_Ideograph", "Ideographic"},
    138915: {"Unified_Ideograph", "Ideographic"},
    138916: {"Unified_Ideograph", "Ideographic"},
    138917: {"Unified_Ideograph", "Ideographic"},
    138918: {"Unified_Ideograph", "Ideographic"},
    138919: {"Unified_Ideograph", "Ideographic"},
    138920: {"Unified_Ideograph", "Ideographic"},
    138921: {"Unified_Ideograph", "Ideographic"},
    138922: {"Unified_Ideograph", "Ideographic"},
    138923: {"Unified_Ideograph", "Ideographic"},
    138924: {"Unified_Ideograph", "Ideographic"},
    138925: {"Unified_Ideograph", "Ideographic"},
    138926: {"Unified_Ideograph", "Ideographic"},
    138927: {"Unified_Ideograph", "Ideographic"},
    138928: {"Unified_Ideograph", "Ideographic"},
    138929: {"Unified_Ideograph", "Ideographic"},
    138930: {"Unified_Ideograph", "Ideographic"},
    138931: {"Unified_Ideograph", "Ideographic"},
    138932: {"Unified_Ideograph", "Ideographic"},
    138933: {"Unified_Ideograph", "Ideographic"},
    138934: {"Unified_Ideograph", "Ideographic"},
    138935: {"Unified_Ideograph", "Ideographic"},
    138936: {"Unified_Ideograph", "Ideographic"},
    138937: {"Unified_Ideograph", "Ideographic"},
    138938: {"Unified_Ideograph", "Ideographic"},
    138939: {"Unified_Ideograph", "Ideographic"},
    138940: {"Unified_Ideograph", "Ideographic"},
    138941: {"Unified_Ideograph", "Ideographic"},
    138942: {"Unified_Ideograph", "Ideographic"},
    138943: {"Unified_Ideograph", "Ideographic"},
    138944: {"Unified_Ideograph", "Ideographic"},
    138945: {"Unified_Ideograph", "Ideographic"},
    138946: {"Unified_Ideograph", "Ideographic"},
    138947: {"Unified_Ideograph", "Ideographic"},
    138948: {"Unified_Ideograph", "Ideographic"},
    138949: {"Unified_Ideograph", "Ideographic"},
    138950: {"Unified_Ideograph", "Ideographic"},
    138951: {"Unified_Ideograph", "Ideographic"},
    138952: {"Unified_Ideograph", "Ideographic"},
    138953: {"Unified_Ideograph", "Ideographic"},
    138954: {"Unified_Ideograph", "Ideographic"},
    138955: {"Unified_Ideograph", "Ideographic"},
    138956: {"Unified_Ideograph", "Ideographic"},
    138957: {"Unified_Ideograph", "Ideographic"},
    138958: {"Unified_Ideograph", "Ideographic"},
    138959: {"Unified_Ideograph", "Ideographic"},
    138960: {"Unified_Ideograph", "Ideographic"},
    138961: {"Unified_Ideograph", "Ideographic"},
    138962: {"Unified_Ideograph", "Ideographic"},
    138963: {"Unified_Ideograph", "Ideographic"},
    138964: {"Unified_Ideograph", "Ideographic"},
    138965: {"Unified_Ideograph", "Ideographic"},
    138966: {"Unified_Ideograph", "Ideographic"},
    138967: {"Unified_Ideograph", "Ideographic"},
    138968: {"Unified_Ideograph", "Ideographic"},
    138969: {"Unified_Ideograph", "Ideographic"},
    138970: {"Unified_Ideograph", "Ideographic"},
    138971: {"Unified_Ideograph", "Ideographic"},
    138972: {"Unified_Ideograph", "Ideographic"},
    138973: {"Unified_Ideograph", "Ideographic"},
    138974: {"Unified_Ideograph", "Ideographic"},
    138975: {"Unified_Ideograph", "Ideographic"},
    138976: {"Unified_Ideograph", "Ideographic"},
    138977: {"Unified_Ideograph", "Ideographic"},
    138978: {"Unified_Ideograph", "Ideographic"},
    138979: {"Unified_Ideograph", "Ideographic"},
    138980: {"Unified_Ideograph", "Ideographic"},
    138981: {"Unified_Ideograph", "Ideographic"},
    138982: {"Unified_Ideograph", "Ideographic"},
    138983: {"Unified_Ideograph", "Ideographic"},
    138984: {"Unified_Ideograph", "Ideographic"},
    138985: {"Unified_Ideograph", "Ideographic"},
    138986: {"Unified_Ideograph", "Ideographic"},
    138987: {"Unified_Ideograph", "Ideographic"},
    138988: {"Unified_Ideograph", "Ideographic"},
    138989: {"Unified_Ideograph", "Ideographic"},
    138990: {"Unified_Ideograph", "Ideographic"},
    138991: {"Unified_Ideograph", "Ideographic"},
    138992: {"Unified_Ideograph", "Ideographic"},
    138993: {"Unified_Ideograph", "Ideographic"},
    138994: {"Unified_Ideograph", "Ideographic"},
    138995: {"Unified_Ideograph", "Ideographic"},
    138996: {"Unified_Ideograph", "Ideographic"},
    138997: {"Unified_Ideograph", "Ideographic"},
    138998: {"Unified_Ideograph", "Ideographic"},
    138999: {"Unified_Ideograph", "Ideographic"},
    139000: {"Unified_Ideograph", "Ideographic"},
    139001: {"Unified_Ideograph", "Ideographic"},
    139002: {"Unified_Ideograph", "Ideographic"},
    139003: {"Unified_Ideograph", "Ideographic"},
    139004: {"Unified_Ideograph", "Ideographic"},
    139005: {"Unified_Ideograph", "Ideographic"},
    139006: {"Unified_Ideograph", "Ideographic"},
    139007: {"Unified_Ideograph", "Ideographic"},
    139008: {"Unified_Ideograph", "Ideographic"},
    139009: {"Unified_Ideograph", "Ideographic"},
    139010: {"Unified_Ideograph", "Ideographic"},
    139011: {"Unified_Ideograph", "Ideographic"},
    139012: {"Unified_Ideograph", "Ideographic"},
    139013: {"Unified_Ideograph", "Ideographic"},
    139014: {"Unified_Ideograph", "Ideographic"},
    139015: {"Unified_Ideograph", "Ideographic"},
    139016: {"Unified_Ideograph", "Ideographic"},
    139017: {"Unified_Ideograph", "Ideographic"},
    139018: {"Unified_Ideograph", "Ideographic"},
    139019: {"Unified_Ideograph", "Ideographic"},
    139020: {"Unified_Ideograph", "Ideographic"},
    139021: {"Unified_Ideograph", "Ideographic"},
    139022: {"Unified_Ideograph", "Ideographic"},
    139023: {"Unified_Ideograph", "Ideographic"},
    139024: {"Unified_Ideograph", "Ideographic"},
    139025: {"Unified_Ideograph", "Ideographic"},
    139026: {"Unified_Ideograph", "Ideographic"},
    139027: {"Unified_Ideograph", "Ideographic"},
    139028: {"Unified_Ideograph", "Ideographic"},
    139029: {"Unified_Ideograph", "Ideographic"},
    139030: {"Unified_Ideograph", "Ideographic"},
    139031: {"Unified_Ideograph", "Ideographic"},
    139032: {"Unified_Ideograph", "Ideographic"},
    139033: {"Unified_Ideograph", "Ideographic"},
    139034: {"Unified_Ideograph", "Ideographic"},
    139035: {"Unified_Ideograph", "Ideographic"},
    139036: {"Unified_Ideograph", "Ideographic"},
    139037: {"Unified_Ideograph", "Ideographic"},
    139038: {"Unified_Ideograph", "Ideographic"},
    139039: {"Unified_Ideograph", "Ideographic"},
    139040: {"Unified_Ideograph", "Ideographic"},
    139041: {"Unified_Ideograph", "Ideographic"},
    139042: {"Unified_Ideograph", "Ideographic"},
    139043: {"Unified_Ideograph", "Ideographic"},
    139044: {"Unified_Ideograph", "Ideographic"},
    139045: {"Unified_Ideograph", "Ideographic"},
    139046: {"Unified_Ideograph", "Ideographic"},
    139047: {"Unified_Ideograph", "Ideographic"},
    139048: {"Unified_Ideograph", "Ideographic"},
    139049: {"Unified_Ideograph", "Ideographic"},
    139050: {"Unified_Ideograph", "Ideographic"},
    139051: {"Unified_Ideograph", "Ideographic"},
    139052: {"Unified_Ideograph", "Ideographic"},
    139053: {"Unified_Ideograph", "Ideographic"},
    139054: {"Unified_Ideograph", "Ideographic"},
    139055: {"Unified_Ideograph", "Ideographic"},
    139056: {"Unified_Ideograph", "Ideographic"},
    139057: {"Unified_Ideograph", "Ideographic"},
    139058: {"Unified_Ideograph", "Ideographic"},
    139059: {"Unified_Ideograph", "Ideographic"},
    139060: {"Unified_Ideograph", "Ideographic"},
    139061: {"Unified_Ideograph", "Ideographic"},
    139062: {"Unified_Ideograph", "Ideographic"},
    139063: {"Unified_Ideograph", "Ideographic"},
    139064: {"Unified_Ideograph", "Ideographic"},
    139065: {"Unified_Ideograph", "Ideographic"},
    139066: {"Unified_Ideograph", "Ideographic"},
    139067: {"Unified_Ideograph", "Ideographic"},
    139068: {"Unified_Ideograph", "Ideographic"},
    139069: {"Unified_Ideograph", "Ideographic"},
    139070: {"Unified_Ideograph", "Ideographic"},
    139071: {"Unified_Ideograph", "Ideographic"},
    139072: {"Unified_Ideograph", "Ideographic"},
    139073: {"Unified_Ideograph", "Ideographic"},
    139074: {"Unified_Ideograph", "Ideographic"},
    139075: {"Unified_Ideograph", "Ideographic"},
    139076: {"Unified_Ideograph", "Ideographic"},
    139077: {"Unified_Ideograph", "Ideographic"},
    139078: {"Unified_Ideograph", "Ideographic"},
    139079: {"Unified_Ideograph", "Ideographic"},
    139080: {"Unified_Ideograph", "Ideographic"},
    139081: {"Unified_Ideograph", "Ideographic"},
    139082: {"Unified_Ideograph", "Ideographic"},
    139083: {"Unified_Ideograph", "Ideographic"},
    139084: {"Unified_Ideograph", "Ideographic"},
    139085: {"Unified_Ideograph", "Ideographic"},
    139086: {"Unified_Ideograph", "Ideographic"},
    139087: {"Unified_Ideograph", "Ideographic"},
    139088: {"Unified_Ideograph", "Ideographic"},
    139089: {"Unified_Ideograph", "Ideographic"},
    139090: {"Unified_Ideograph", "Ideographic"},
    139091: {"Unified_Ideograph", "Ideographic"},
    139092: {"Unified_Ideograph", "Ideographic"},
    139093: {"Unified_Ideograph", "Ideographic"},
    139094: {"Unified_Ideograph", "Ideographic"},
    139095: {"Unified_Ideograph", "Ideographic"},
    139096: {"Unified_Ideograph", "Ideographic"},
    139097: {"Unified_Ideograph", "Ideographic"},
    139098: {"Unified_Ideograph", "Ideographic"},
    139099: {"Unified_Ideograph", "Ideographic"},
    139100: {"Unified_Ideograph", "Ideographic"},
    139101: {"Unified_Ideograph", "Ideographic"},
    139102: {"Unified_Ideograph", "Ideographic"},
    139103: {"Unified_Ideograph", "Ideographic"},
    139104: {"Unified_Ideograph", "Ideographic"},
    139105: {"Unified_Ideograph", "Ideographic"},
    139106: {"Unified_Ideograph", "Ideographic"},
    139107: {"Unified_Ideograph", "Ideographic"},
    139108: {"Unified_Ideograph", "Ideographic"},
    139109: {"Unified_Ideograph", "Ideographic"},
    139110: {"Unified_Ideograph", "Ideographic"},
    139111: {"Unified_Ideograph", "Ideographic"},
    139112: {"Unified_Ideograph", "Ideographic"},
    139113: {"Unified_Ideograph", "Ideographic"},
    139114: {"Unified_Ideograph", "Ideographic"},
    139115: {"Unified_Ideograph", "Ideographic"},
    139116: {"Unified_Ideograph", "Ideographic"},
    139117: {"Unified_Ideograph", "Ideographic"},
    139118: {"Unified_Ideograph", "Ideographic"},
    139119: {"Unified_Ideograph", "Ideographic"},
    139120: {"Unified_Ideograph", "Ideographic"},
    139121: {"Unified_Ideograph", "Ideographic"},
    139122: {"Unified_Ideograph", "Ideographic"},
    139123: {"Unified_Ideograph", "Ideographic"},
    139124: {"Unified_Ideograph", "Ideographic"},
    139125: {"Unified_Ideograph", "Ideographic"},
    139126: {"Unified_Ideograph", "Ideographic"},
    139127: {"Unified_Ideograph", "Ideographic"},
    139128: {"Unified_Ideograph", "Ideographic"},
    139129: {"Unified_Ideograph", "Ideographic"},
    139130: {"Unified_Ideograph", "Ideographic"},
    139131: {"Unified_Ideograph", "Ideographic"},
    139132: {"Unified_Ideograph", "Ideographic"},
    139133: {"Unified_Ideograph", "Ideographic"},
    139134: {"Unified_Ideograph", "Ideographic"},
    139135: {"Unified_Ideograph", "Ideographic"},
    139136: {"Unified_Ideograph", "Ideographic"},
    139137: {"Unified_Ideograph", "Ideographic"},
    139138: {"Unified_Ideograph", "Ideographic"},
    139139: {"Unified_Ideograph", "Ideographic"},
    139140: {"Unified_Ideograph", "Ideographic"},
    139141: {"Unified_Ideograph", "Ideographic"},
    139142: {"Unified_Ideograph", "Ideographic"},
    139143: {"Unified_Ideograph", "Ideographic"},
    139144: {"Unified_Ideograph", "Ideographic"},
    139145: {"Unified_Ideograph", "Ideographic"},
    139146: {"Unified_Ideograph", "Ideographic"},
    139147: {"Unified_Ideograph", "Ideographic"},
    139148: {"Unified_Ideograph", "Ideographic"},
    139149: {"Unified_Ideograph", "Ideographic"},
    139150: {"Unified_Ideograph", "Ideographic"},
    139151: {"Unified_Ideograph", "Ideographic"},
    139152: {"Unified_Ideograph", "Ideographic"},
    139153: {"Unified_Ideograph", "Ideographic"},
    139154: {"Unified_Ideograph", "Ideographic"},
    139155: {"Unified_Ideograph", "Ideographic"},
    139156: {"Unified_Ideograph", "Ideographic"},
    139157: {"Unified_Ideograph", "Ideographic"},
    139158: {"Unified_Ideograph", "Ideographic"},
    139159: {"Unified_Ideograph", "Ideographic"},
    139160: {"Unified_Ideograph", "Ideographic"},
    139161: {"Unified_Ideograph", "Ideographic"},
    139162: {"Unified_Ideograph", "Ideographic"},
    139163: {"Unified_Ideograph", "Ideographic"},
    139164: {"Unified_Ideograph", "Ideographic"},
    139165: {"Unified_Ideograph", "Ideographic"},
    139166: {"Unified_Ideograph", "Ideographic"},
    139167: {"Unified_Ideograph", "Ideographic"},
    139168: {"Unified_Ideograph", "Ideographic"},
    139169: {"Unified_Ideograph", "Ideographic"},
    139170: {"Unified_Ideograph", "Ideographic"},
    139171: {"Unified_Ideograph", "Ideographic"},
    139172: {"Unified_Ideograph", "Ideographic"},
    139173: {"Unified_Ideograph", "Ideographic"},
    139174: {"Unified_Ideograph", "Ideographic"},
    139175: {"Unified_Ideograph", "Ideographic"},
    139176: {"Unified_Ideograph", "Ideographic"},
    139177: {"Unified_Ideograph", "Ideographic"},
    139178: {"Unified_Ideograph", "Ideographic"},
    139179: {"Unified_Ideograph", "Ideographic"},
    139180: {"Unified_Ideograph", "Ideographic"},
    139181: {"Unified_Ideograph", "Ideographic"},
    139182: {"Unified_Ideograph", "Ideographic"},
    139183: {"Unified_Ideograph", "Ideographic"},
    139184: {"Unified_Ideograph", "Ideographic"},
    139185: {"Unified_Ideograph", "Ideographic"},
    139186: {"Unified_Ideograph", "Ideographic"},
    139187: {"Unified_Ideograph", "Ideographic"},
    139188: {"Unified_Ideograph", "Ideographic"},
    139189: {"Unified_Ideograph", "Ideographic"},
    139190: {"Unified_Ideograph", "Ideographic"},
    139191: {"Unified_Ideograph", "Ideographic"},
    139192: {"Unified_Ideograph", "Ideographic"},
    139193: {"Unified_Ideograph", "Ideographic"},
    139194: {"Unified_Ideograph", "Ideographic"},
    139195: {"Unified_Ideograph", "Ideographic"},
    139196: {"Unified_Ideograph", "Ideographic"},
    139197: {"Unified_Ideograph", "Ideographic"},
    139198: {"Unified_Ideograph", "Ideographic"},
    139199: {"Unified_Ideograph", "Ideographic"},
    139200: {"Unified_Ideograph", "Ideographic"},
    139201: {"Unified_Ideograph", "Ideographic"},
    139202: {"Unified_Ideograph", "Ideographic"},
    139203: {"Unified_Ideograph", "Ideographic"},
    139204: {"Unified_Ideograph", "Ideographic"},
    139205: {"Unified_Ideograph", "Ideographic"},
    139206: {"Unified_Ideograph", "Ideographic"},
    139207: {"Unified_Ideograph", "Ideographic"},
    139208: {"Unified_Ideograph", "Ideographic"},
    139209: {"Unified_Ideograph", "Ideographic"},
    139210: {"Unified_Ideograph", "Ideographic"},
    139211: {"Unified_Ideograph", "Ideographic"},
    139212: {"Unified_Ideograph", "Ideographic"},
    139213: {"Unified_Ideograph", "Ideographic"},
    139214: {"Unified_Ideograph", "Ideographic"},
    139215: {"Unified_Ideograph", "Ideographic"},
    139216: {"Unified_Ideograph", "Ideographic"},
    139217: {"Unified_Ideograph", "Ideographic"},
    139218: {"Unified_Ideograph", "Ideographic"},
    139219: {"Unified_Ideograph", "Ideographic"},
    139220: {"Unified_Ideograph", "Ideographic"},
    139221: {"Unified_Ideograph", "Ideographic"},
    139222: {"Unified_Ideograph", "Ideographic"},
    139223: {"Unified_Ideograph", "Ideographic"},
    139224: {"Unified_Ideograph", "Ideographic"},
    139225: {"Unified_Ideograph", "Ideographic"},
    139226: {"Unified_Ideograph", "Ideographic"},
    139227: {"Unified_Ideograph", "Ideographic"},
    139228: {"Unified_Ideograph", "Ideographic"},
    139229: {"Unified_Ideograph", "Ideographic"},
    139230: {"Unified_Ideograph", "Ideographic"},
    139231: {"Unified_Ideograph", "Ideographic"},
    139232: {"Unified_Ideograph", "Ideographic"},
    139233: {"Unified_Ideograph", "Ideographic"},
    139234: {"Unified_Ideograph", "Ideographic"},
    139235: {"Unified_Ideograph", "Ideographic"},
    139236: {"Unified_Ideograph", "Ideographic"},
    139237: {"Unified_Ideograph", "Ideographic"},
    139238: {"Unified_Ideograph", "Ideographic"},
    139239: {"Unified_Ideograph", "Ideographic"},
    139240: {"Unified_Ideograph", "Ideographic"},
    139241: {"Unified_Ideograph", "Ideographic"},
    139242: {"Unified_Ideograph", "Ideographic"},
    139243: {"Unified_Ideograph", "Ideographic"},
    139244: {"Unified_Ideograph", "Ideographic"},
    139245: {"Unified_Ideograph", "Ideographic"},
    139246: {"Unified_Ideograph", "Ideographic"},
    139247: {"Unified_Ideograph", "Ideographic"},
    139248: {"Unified_Ideograph", "Ideographic"},
    139249: {"Unified_Ideograph", "Ideographic"},
    139250: {"Unified_Ideograph", "Ideographic"},
    139251: {"Unified_Ideograph", "Ideographic"},
    139252: {"Unified_Ideograph", "Ideographic"},
    139253: {"Unified_Ideograph", "Ideographic"},
    139254: {"Unified_Ideograph", "Ideographic"},
    139255: {"Unified_Ideograph", "Ideographic"},
    139256: {"Unified_Ideograph", "Ideographic"},
    139257: {"Unified_Ideograph", "Ideographic"},
    139258: {"Unified_Ideograph", "Ideographic"},
    139259: {"Unified_Ideograph", "Ideographic"},
    139260: {"Unified_Ideograph", "Ideographic"},
    139261: {"Unified_Ideograph", "Ideographic"},
    139262: {"Unified_Ideograph", "Ideographic"},
    139263: {"Unified_Ideograph", "Ideographic"},
    139264: {"Unified_Ideograph", "Ideographic"},
    139265: {"Unified_Ideograph", "Ideographic"},
    139266: {"Unified_Ideograph", "Ideographic"},
    139267: {"Unified_Ideograph", "Ideographic"},
    139268: {"Unified_Ideograph", "Ideographic"},
    139269: {"Unified_Ideograph", "Ideographic"},
    139270: {"Unified_Ideograph", "Ideographic"},
    139271: {"Unified_Ideograph", "Ideographic"},
    139272: {"Unified_Ideograph", "Ideographic"},
    139273: {"Unified_Ideograph", "Ideographic"},
    139274: {"Unified_Ideograph", "Ideographic"},
    139275: {"Unified_Ideograph", "Ideographic"},
    139276: {"Unified_Ideograph", "Ideographic"},
    139277: {"Unified_Ideograph", "Ideographic"},
    139278: {"Unified_Ideograph", "Ideographic"},
    139279: {"Unified_Ideograph", "Ideographic"},
    139280: {"Unified_Ideograph", "Ideographic"},
    139281: {"Unified_Ideograph", "Ideographic"},
    139282: {"Unified_Ideograph", "Ideographic"},
    139283: {"Unified_Ideograph", "Ideographic"},
    139284: {"Unified_Ideograph", "Ideographic"},
    139285: {"Unified_Ideograph", "Ideographic"},
    139286: {"Unified_Ideograph", "Ideographic"},
    139287: {"Unified_Ideograph", "Ideographic"},
    139288: {"Unified_Ideograph", "Ideographic"},
    139289: {"Unified_Ideograph", "Ideographic"},
    139290: {"Unified_Ideograph", "Ideographic"},
    139291: {"Unified_Ideograph", "Ideographic"},
    139292: {"Unified_Ideograph", "Ideographic"},
    139293: {"Unified_Ideograph", "Ideographic"},
    139294: {"Unified_Ideograph", "Ideographic"},
    139295: {"Unified_Ideograph", "Ideographic"},
    139296: {"Unified_Ideograph", "Ideographic"},
    139297: {"Unified_Ideograph", "Ideographic"},
    139298: {"Unified_Ideograph", "Ideographic"},
    139299: {"Unified_Ideograph", "Ideographic"},
    139300: {"Unified_Ideograph", "Ideographic"},
    139301: {"Unified_Ideograph", "Ideographic"},
    139302: {"Unified_Ideograph", "Ideographic"},
    139303: {"Unified_Ideograph", "Ideographic"},
    139304: {"Unified_Ideograph", "Ideographic"},
    139305: {"Unified_Ideograph", "Ideographic"},
    139306: {"Unified_Ideograph", "Ideographic"},
    139307: {"Unified_Ideograph", "Ideographic"},
    139308: {"Unified_Ideograph", "Ideographic"},
    139309: {"Unified_Ideograph", "Ideographic"},
    139310: {"Unified_Ideograph", "Ideographic"},
    139311: {"Unified_Ideograph", "Ideographic"},
    139312: {"Unified_Ideograph", "Ideographic"},
    139313: {"Unified_Ideograph", "Ideographic"},
    139314: {"Unified_Ideograph", "Ideographic"},
    139315: {"Unified_Ideograph", "Ideographic"},
    139316: {"Unified_Ideograph", "Ideographic"},
    139317: {"Unified_Ideograph", "Ideographic"},
    139318: {"Unified_Ideograph", "Ideographic"},
    139319: {"Unified_Ideograph", "Ideographic"},
    139320: {"Unified_Ideograph", "Ideographic"},
    139321: {"Unified_Ideograph", "Ideographic"},
    139322: {"Unified_Ideograph", "Ideographic"},
    139323: {"Unified_Ideograph", "Ideographic"},
    139324: {"Unified_Ideograph", "Ideographic"},
    139325: {"Unified_Ideograph", "Ideographic"},
    139326: {"Unified_Ideograph", "Ideographic"},
    139327: {"Unified_Ideograph", "Ideographic"},
    139328: {"Unified_Ideograph", "Ideographic"},
    139329: {"Unified_Ideograph", "Ideographic"},
    139330: {"Unified_Ideograph", "Ideographic"},
    139331: {"Unified_Ideograph", "Ideographic"},
    139332: {"Unified_Ideograph", "Ideographic"},
    139333: {"Unified_Ideograph", "Ideographic"},
    139334: {"Unified_Ideograph", "Ideographic"},
    139335: {"Unified_Ideograph", "Ideographic"},
    139336: {"Unified_Ideograph", "Ideographic"},
    139337: {"Unified_Ideograph", "Ideographic"},
    139338: {"Unified_Ideograph", "Ideographic"},
    139339: {"Unified_Ideograph", "Ideographic"},
    139340: {"Unified_Ideograph", "Ideographic"},
    139341: {"Unified_Ideograph", "Ideographic"},
    139342: {"Unified_Ideograph", "Ideographic"},
    139343: {"Unified_Ideograph", "Ideographic"},
    139344: {"Unified_Ideograph", "Ideographic"},
    139345: {"Unified_Ideograph", "Ideographic"},
    139346: {"Unified_Ideograph", "Ideographic"},
    139347: {"Unified_Ideograph", "Ideographic"},
    139348: {"Unified_Ideograph", "Ideographic"},
    139349: {"Unified_Ideograph", "Ideographic"},
    139350: {"Unified_Ideograph", "Ideographic"},
    139351: {"Unified_Ideograph", "Ideographic"},
    139352: {"Unified_Ideograph", "Ideographic"},
    139353: {"Unified_Ideograph", "Ideographic"},
    139354: {"Unified_Ideograph", "Ideographic"},
    139355: {"Unified_Ideograph", "Ideographic"},
    139356: {"Unified_Ideograph", "Ideographic"},
    139357: {"Unified_Ideograph", "Ideographic"},
    139358: {"Unified_Ideograph", "Ideographic"},
    139359: {"Unified_Ideograph", "Ideographic"},
    139360: {"Unified_Ideograph", "Ideographic"},
    139361: {"Unified_Ideograph", "Ideographic"},
    139362: {"Unified_Ideograph", "Ideographic"},
    139363: {"Unified_Ideograph", "Ideographic"},
    139364: {"Unified_Ideograph", "Ideographic"},
    139365: {"Unified_Ideograph", "Ideographic"},
    139366: {"Unified_Ideograph", "Ideographic"},
    139367: {"Unified_Ideograph", "Ideographic"},
    139368: {"Unified_Ideograph", "Ideographic"},
    139369: {"Unified_Ideograph", "Ideographic"},
    139370: {"Unified_Ideograph", "Ideographic"},
    139371: {"Unified_Ideograph", "Ideographic"},
    139372: {"Unified_Ideograph", "Ideographic"},
    139373: {"Unified_Ideograph", "Ideographic"},
    139374: {"Unified_Ideograph", "Ideographic"},
    139375: {"Unified_Ideograph", "Ideographic"},
    139376: {"Unified_Ideograph", "Ideographic"},
    139377: {"Unified_Ideograph", "Ideographic"},
    139378: {"Unified_Ideograph", "Ideographic"},
    139379: {"Unified_Ideograph", "Ideographic"},
    139380: {"Unified_Ideograph", "Ideographic"},
    139381: {"Unified_Ideograph", "Ideographic"},
    139382: {"Unified_Ideograph", "Ideographic"},
    139383: {"Unified_Ideograph", "Ideographic"},
    139384: {"Unified_Ideograph", "Ideographic"},
    139385: {"Unified_Ideograph", "Ideographic"},
    139386: {"Unified_Ideograph", "Ideographic"},
    139387: {"Unified_Ideograph", "Ideographic"},
    139388: {"Unified_Ideograph", "Ideographic"},
    139389: {"Unified_Ideograph", "Ideographic"},
    139390: {"Unified_Ideograph", "Ideographic"},
    139391: {"Unified_Ideograph", "Ideographic"},
    139392: {"Unified_Ideograph", "Ideographic"},
    139393: {"Unified_Ideograph", "Ideographic"},
    139394: {"Unified_Ideograph", "Ideographic"},
    139395: {"Unified_Ideograph", "Ideographic"},
    139396: {"Unified_Ideograph", "Ideographic"},
    139397: {"Unified_Ideograph", "Ideographic"},
    139398: {"Unified_Ideograph", "Ideographic"},
    139399: {"Unified_Ideograph", "Ideographic"},
    139400: {"Unified_Ideograph", "Ideographic"},
    139401: {"Unified_Ideograph", "Ideographic"},
    139402: {"Unified_Ideograph", "Ideographic"},
    139403: {"Unified_Ideograph", "Ideographic"},
    139404: {"Unified_Ideograph", "Ideographic"},
    139405: {"Unified_Ideograph", "Ideographic"},
    139406: {"Unified_Ideograph", "Ideographic"},
    139407: {"Unified_Ideograph", "Ideographic"},
    139408: {"Unified_Ideograph", "Ideographic"},
    139409: {"Unified_Ideograph", "Ideographic"},
    139410: {"Unified_Ideograph", "Ideographic"},
    139411: {"Unified_Ideograph", "Ideographic"},
    139412: {"Unified_Ideograph", "Ideographic"},
    139413: {"Unified_Ideograph", "Ideographic"},
    139414: {"Unified_Ideograph", "Ideographic"},
    139415: {"Unified_Ideograph", "Ideographic"},
    139416: {"Unified_Ideograph", "Ideographic"},
    139417: {"Unified_Ideograph", "Ideographic"},
    139418: {"Unified_Ideograph", "Ideographic"},
    139419: {"Unified_Ideograph", "Ideographic"},
    139420: {"Unified_Ideograph", "Ideographic"},
    139421: {"Unified_Ideograph", "Ideographic"},
    139422: {"Unified_Ideograph", "Ideographic"},
    139423: {"Unified_Ideograph", "Ideographic"},
    139424: {"Unified_Ideograph", "Ideographic"},
    139425: {"Unified_Ideograph", "Ideographic"},
    139426: {"Unified_Ideograph", "Ideographic"},
    139427: {"Unified_Ideograph", "Ideographic"},
    139428: {"Unified_Ideograph", "Ideographic"},
    139429: {"Unified_Ideograph", "Ideographic"},
    139430: {"Unified_Ideograph", "Ideographic"},
    139431: {"Unified_Ideograph", "Ideographic"},
    139432: {"Unified_Ideograph", "Ideographic"},
    139433: {"Unified_Ideograph", "Ideographic"},
    139434: {"Unified_Ideograph", "Ideographic"},
    139435: {"Unified_Ideograph", "Ideographic"},
    139436: {"Unified_Ideograph", "Ideographic"},
    139437: {"Unified_Ideograph", "Ideographic"},
    139438: {"Unified_Ideograph", "Ideographic"},
    139439: {"Unified_Ideograph", "Ideographic"},
    139440: {"Unified_Ideograph", "Ideographic"},
    139441: {"Unified_Ideograph", "Ideographic"},
    139442: {"Unified_Ideograph", "Ideographic"},
    139443: {"Unified_Ideograph", "Ideographic"},
    139444: {"Unified_Ideograph", "Ideographic"},
    139445: {"Unified_Ideograph", "Ideographic"},
    139446: {"Unified_Ideograph", "Ideographic"},
    139447: {"Unified_Ideograph", "Ideographic"},
    139448: {"Unified_Ideograph", "Ideographic"},
    139449: {"Unified_Ideograph", "Ideographic"},
    139450: {"Unified_Ideograph", "Ideographic"},
    139451: {"Unified_Ideograph", "Ideographic"},
    139452: {"Unified_Ideograph", "Ideographic"},
    139453: {"Unified_Ideograph", "Ideographic"},
    139454: {"Unified_Ideograph", "Ideographic"},
    139455: {"Unified_Ideograph", "Ideographic"},
    139456: {"Unified_Ideograph", "Ideographic"},
    139457: {"Unified_Ideograph", "Ideographic"},
    139458: {"Unified_Ideograph", "Ideographic"},
    139459: {"Unified_Ideograph", "Ideographic"},
    139460: {"Unified_Ideograph", "Ideographic"},
    139461: {"Unified_Ideograph", "Ideographic"},
    139462: {"Unified_Ideograph", "Ideographic"},
    139463: {"Unified_Ideograph", "Ideographic"},
    139464: {"Unified_Ideograph", "Ideographic"},
    139465: {"Unified_Ideograph", "Ideographic"},
    139466: {"Unified_Ideograph", "Ideographic"},
    139467: {"Unified_Ideograph", "Ideographic"},
    139468: {"Unified_Ideograph", "Ideographic"},
    139469: {"Unified_Ideograph", "Ideographic"},
    139470: {"Unified_Ideograph", "Ideographic"},
    139471: {"Unified_Ideograph", "Ideographic"},
    139472: {"Unified_Ideograph", "Ideographic"},
    139473: {"Unified_Ideograph", "Ideographic"},
    139474: {"Unified_Ideograph", "Ideographic"},
    139475: {"Unified_Ideograph", "Ideographic"},
    139476: {"Unified_Ideograph", "Ideographic"},
    139477: {"Unified_Ideograph", "Ideographic"},
    139478: {"Unified_Ideograph", "Ideographic"},
    139479: {"Unified_Ideograph", "Ideographic"},
    139480: {"Unified_Ideograph", "Ideographic"},
    139481: {"Unified_Ideograph", "Ideographic"},
    139482: {"Unified_Ideograph", "Ideographic"},
    139483: {"Unified_Ideograph", "Ideographic"},
    139484: {"Unified_Ideograph", "Ideographic"},
    139485: {"Unified_Ideograph", "Ideographic"},
    139486: {"Unified_Ideograph", "Ideographic"},
    139487: {"Unified_Ideograph", "Ideographic"},
    139488: {"Unified_Ideograph", "Ideographic"},
    139489: {"Unified_Ideograph", "Ideographic"},
    139490: {"Unified_Ideograph", "Ideographic"},
    139491: {"Unified_Ideograph", "Ideographic"},
    139492: {"Unified_Ideograph", "Ideographic"},
    139493: {"Unified_Ideograph", "Ideographic"},
    139494: {"Unified_Ideograph", "Ideographic"},
    139495: {"Unified_Ideograph", "Ideographic"},
    139496: {"Unified_Ideograph", "Ideographic"},
    139497: {"Unified_Ideograph", "Ideographic"},
    139498: {"Unified_Ideograph", "Ideographic"},
    139499: {"Unified_Ideograph", "Ideographic"},
    139500: {"Unified_Ideograph", "Ideographic"},
    139501: {"Unified_Ideograph", "Ideographic"},
    139502: {"Unified_Ideograph", "Ideographic"},
    139503: {"Unified_Ideograph", "Ideographic"},
    139504: {"Unified_Ideograph", "Ideographic"},
    139505: {"Unified_Ideograph", "Ideographic"},
    139506: {"Unified_Ideograph", "Ideographic"},
    139507: {"Unified_Ideograph", "Ideographic"},
    139508: {"Unified_Ideograph", "Ideographic"},
    139509: {"Unified_Ideograph", "Ideographic"},
    139510: {"Unified_Ideograph", "Ideographic"},
    139511: {"Unified_Ideograph", "Ideographic"},
    139512: {"Unified_Ideograph", "Ideographic"},
    139513: {"Unified_Ideograph", "Ideographic"},
    139514: {"Unified_Ideograph", "Ideographic"},
    139515: {"Unified_Ideograph", "Ideographic"},
    139516: {"Unified_Ideograph", "Ideographic"},
    139517: {"Unified_Ideograph", "Ideographic"},
    139518: {"Unified_Ideograph", "Ideographic"},
    139519: {"Unified_Ideograph", "Ideographic"},
    139520: {"Unified_Ideograph", "Ideographic"},
    139521: {"Unified_Ideograph", "Ideographic"},
    139522: {"Unified_Ideograph", "Ideographic"},
    139523: {"Unified_Ideograph", "Ideographic"},
    139524: {"Unified_Ideograph", "Ideographic"},
    139525: {"Unified_Ideograph", "Ideographic"},
    139526: {"Unified_Ideograph", "Ideographic"},
    139527: {"Unified_Ideograph", "Ideographic"},
    139528: {"Unified_Ideograph", "Ideographic"},
    139529: {"Unified_Ideograph", "Ideographic"},
    139530: {"Unified_Ideograph", "Ideographic"},
    139531: {"Unified_Ideograph", "Ideographic"},
    139532: {"Unified_Ideograph", "Ideographic"},
    139533: {"Unified_Ideograph", "Ideographic"},
    139534: {"Unified_Ideograph", "Ideographic"},
    139535: {"Unified_Ideograph", "Ideographic"},
    139536: {"Unified_Ideograph", "Ideographic"},
    139537: {"Unified_Ideograph", "Ideographic"},
    139538: {"Unified_Ideograph", "Ideographic"},
    139539: {"Unified_Ideograph", "Ideographic"},
    139540: {"Unified_Ideograph", "Ideographic"},
    139541: {"Unified_Ideograph", "Ideographic"},
    139542: {"Unified_Ideograph", "Ideographic"},
    139543: {"Unified_Ideograph", "Ideographic"},
    139544: {"Unified_Ideograph", "Ideographic"},
    139545: {"Unified_Ideograph", "Ideographic"},
    139546: {"Unified_Ideograph", "Ideographic"},
    139547: {"Unified_Ideograph", "Ideographic"},
    139548: {"Unified_Ideograph", "Ideographic"},
    139549: {"Unified_Ideograph", "Ideographic"},
    139550: {"Unified_Ideograph", "Ideographic"},
    139551: {"Unified_Ideograph", "Ideographic"},
    139552: {"Unified_Ideograph", "Ideographic"},
    139553: {"Unified_Ideograph", "Ideographic"},
    139554: {"Unified_Ideograph", "Ideographic"},
    139555: {"Unified_Ideograph", "Ideographic"},
    139556: {"Unified_Ideograph", "Ideographic"},
    139557: {"Unified_Ideograph", "Ideographic"},
    139558: {"Unified_Ideograph", "Ideographic"},
    139559: {"Unified_Ideograph", "Ideographic"},
    139560: {"Unified_Ideograph", "Ideographic"},
    139561: {"Unified_Ideograph", "Ideographic"},
    139562: {"Unified_Ideograph", "Ideographic"},
    139563: {"Unified_Ideograph", "Ideographic"},
    139564: {"Unified_Ideograph", "Ideographic"},
    139565: {"Unified_Ideograph", "Ideographic"},
    139566: {"Unified_Ideograph", "Ideographic"},
    139567: {"Unified_Ideograph", "Ideographic"},
    139568: {"Unified_Ideograph", "Ideographic"},
    139569: {"Unified_Ideograph", "Ideographic"},
    139570: {"Unified_Ideograph", "Ideographic"},
    139571: {"Unified_Ideograph", "Ideographic"},
    139572: {"Unified_Ideograph", "Ideographic"},
    139573: {"Unified_Ideograph", "Ideographic"},
    139574: {"Unified_Ideograph", "Ideographic"},
    139575: {"Unified_Ideograph", "Ideographic"},
    139576: {"Unified_Ideograph", "Ideographic"},
    139577: {"Unified_Ideograph", "Ideographic"},
    139578: {"Unified_Ideograph", "Ideographic"},
    139579: {"Unified_Ideograph", "Ideographic"},
    139580: {"Unified_Ideograph", "Ideographic"},
    139581: {"Unified_Ideograph", "Ideographic"},
    139582: {"Unified_Ideograph", "Ideographic"},
    139583: {"Unified_Ideograph", "Ideographic"},
    139584: {"Unified_Ideograph", "Ideographic"},
    139585: {"Unified_Ideograph", "Ideographic"},
    139586: {"Unified_Ideograph", "Ideographic"},
    139587: {"Unified_Ideograph", "Ideographic"},
    139588: {"Unified_Ideograph", "Ideographic"},
    139589: {"Unified_Ideograph", "Ideographic"},
    139590: {"Unified_Ideograph", "Ideographic"},
    139591: {"Unified_Ideograph", "Ideographic"},
    139592: {"Unified_Ideograph", "Ideographic"},
    139593: {"Unified_Ideograph", "Ideographic"},
    139594: {"Unified_Ideograph", "Ideographic"},
    139595: {"Unified_Ideograph", "Ideographic"},
    139596: {"Unified_Ideograph", "Ideographic"},
    139597: {"Unified_Ideograph", "Ideographic"},
    139598: {"Unified_Ideograph", "Ideographic"},
    139599: {"Unified_Ideograph", "Ideographic"},
    139600: {"Unified_Ideograph", "Ideographic"},
    139601: {"Unified_Ideograph", "Ideographic"},
    139602: {"Unified_Ideograph", "Ideographic"},
    139603: {"Unified_Ideograph", "Ideographic"},
    139604: {"Unified_Ideograph", "Ideographic"},
    139605: {"Unified_Ideograph", "Ideographic"},
    139606: {"Unified_Ideograph", "Ideographic"},
    139607: {"Unified_Ideograph", "Ideographic"},
    139608: {"Unified_Ideograph", "Ideographic"},
    139609: {"Unified_Ideograph", "Ideographic"},
    139610: {"Unified_Ideograph", "Ideographic"},
    139611: {"Unified_Ideograph", "Ideographic"},
    139612: {"Unified_Ideograph", "Ideographic"},
    139613: {"Unified_Ideograph", "Ideographic"},
    139614: {"Unified_Ideograph", "Ideographic"},
    139615: {"Unified_Ideograph", "Ideographic"},
    139616: {"Unified_Ideograph", "Ideographic"},
    139617: {"Unified_Ideograph", "Ideographic"},
    139618: {"Unified_Ideograph", "Ideographic"},
    139619: {"Unified_Ideograph", "Ideographic"},
    139620: {"Unified_Ideograph", "Ideographic"},
    139621: {"Unified_Ideograph", "Ideographic"},
    139622: {"Unified_Ideograph", "Ideographic"},
    139623: {"Unified_Ideograph", "Ideographic"},
    139624: {"Unified_Ideograph", "Ideographic"},
    139625: {"Unified_Ideograph", "Ideographic"},
    139626: {"Unified_Ideograph", "Ideographic"},
    139627: {"Unified_Ideograph", "Ideographic"},
    139628: {"Unified_Ideograph", "Ideographic"},
    139629: {"Unified_Ideograph", "Ideographic"},
    139630: {"Unified_Ideograph", "Ideographic"},
    139631: {"Unified_Ideograph", "Ideographic"},
    139632: {"Unified_Ideograph", "Ideographic"},
    139633: {"Unified_Ideograph", "Ideographic"},
    139634: {"Unified_Ideograph", "Ideographic"},
    139635: {"Unified_Ideograph", "Ideographic"},
    139636: {"Unified_Ideograph", "Ideographic"},
    139637: {"Unified_Ideograph", "Ideographic"},
    139638: {"Unified_Ideograph", "Ideographic"},
    139639: {"Unified_Ideograph", "Ideographic"},
    139640: {"Unified_Ideograph", "Ideographic"},
    139641: {"Unified_Ideograph", "Ideographic"},
    139642: {"Unified_Ideograph", "Ideographic"},
    139643: {"Unified_Ideograph", "Ideographic"},
    139644: {"Unified_Ideograph", "Ideographic"},
    139645: {"Unified_Ideograph", "Ideographic"},
    139646: {"Unified_Ideograph", "Ideographic"},
    139647: {"Unified_Ideograph", "Ideographic"},
    139648: {"Unified_Ideograph", "Ideographic"},
    139649: {"Unified_Ideograph", "Ideographic"},
    139650: {"Unified_Ideograph", "Ideographic"},
    139651: {"Unified_Ideograph", "Ideographic"},
    139652: {"Unified_Ideograph", "Ideographic"},
    139653: {"Unified_Ideograph", "Ideographic"},
    139654: {"Unified_Ideograph", "Ideographic"},
    139655: {"Unified_Ideograph", "Ideographic"},
    139656: {"Unified_Ideograph", "Ideographic"},
    139657: {"Unified_Ideograph", "Ideographic"},
    139658: {"Unified_Ideograph", "Ideographic"},
    139659: {"Unified_Ideograph", "Ideographic"},
    139660: {"Unified_Ideograph", "Ideographic"},
    139661: {"Unified_Ideograph", "Ideographic"},
    139662: {"Unified_Ideograph", "Ideographic"},
    139663: {"Unified_Ideograph", "Ideographic"},
    139664: {"Unified_Ideograph", "Ideographic"},
    139665: {"Unified_Ideograph", "Ideographic"},
    139666: {"Unified_Ideograph", "Ideographic"},
    139667: {"Unified_Ideograph", "Ideographic"},
    139668: {"Unified_Ideograph", "Ideographic"},
    139669: {"Unified_Ideograph", "Ideographic"},
    139670: {"Unified_Ideograph", "Ideographic"},
    139671: {"Unified_Ideograph", "Ideographic"},
    139672: {"Unified_Ideograph", "Ideographic"},
    139673: {"Unified_Ideograph", "Ideographic"},
    139674: {"Unified_Ideograph", "Ideographic"},
    139675: {"Unified_Ideograph", "Ideographic"},
    139676: {"Unified_Ideograph", "Ideographic"},
    139677: {"Unified_Ideograph", "Ideographic"},
    139678: {"Unified_Ideograph", "Ideographic"},
    139679: {"Unified_Ideograph", "Ideographic"},
    139680: {"Unified_Ideograph", "Ideographic"},
    139681: {"Unified_Ideograph", "Ideographic"},
    139682: {"Unified_Ideograph", "Ideographic"},
    139683: {"Unified_Ideograph", "Ideographic"},
    139684: {"Unified_Ideograph", "Ideographic"},
    139685: {"Unified_Ideograph", "Ideographic"},
    139686: {"Unified_Ideograph", "Ideographic"},
    139687: {"Unified_Ideograph", "Ideographic"},
    139688: {"Unified_Ideograph", "Ideographic"},
    139689: {"Unified_Ideograph", "Ideographic"},
    139690: {"Unified_Ideograph", "Ideographic"},
    139691: {"Unified_Ideograph", "Ideographic"},
    139692: {"Unified_Ideograph", "Ideographic"},
    139693: {"Unified_Ideograph", "Ideographic"},
    139694: {"Unified_Ideograph", "Ideographic"},
    139695: {"Unified_Ideograph", "Ideographic"},
    139696: {"Unified_Ideograph", "Ideographic"},
    139697: {"Unified_Ideograph", "Ideographic"},
    139698: {"Unified_Ideograph", "Ideographic"},
    139699: {"Unified_Ideograph", "Ideographic"},
    139700: {"Unified_Ideograph", "Ideographic"},
    139701: {"Unified_Ideograph", "Ideographic"},
    139702: {"Unified_Ideograph", "Ideographic"},
    139703: {"Unified_Ideograph", "Ideographic"},
    139704: {"Unified_Ideograph", "Ideographic"},
    139705: {"Unified_Ideograph", "Ideographic"},
    139706: {"Unified_Ideograph", "Ideographic"},
    139707: {"Unified_Ideograph", "Ideographic"},
    139708: {"Unified_Ideograph", "Ideographic"},
    139709: {"Unified_Ideograph", "Ideographic"},
    139710: {"Unified_Ideograph", "Ideographic"},
    139711: {"Unified_Ideograph", "Ideographic"},
    139712: {"Unified_Ideograph", "Ideographic"},
    139713: {"Unified_Ideograph", "Ideographic"},
    139714: {"Unified_Ideograph", "Ideographic"},
    139715: {"Unified_Ideograph", "Ideographic"},
    139716: {"Unified_Ideograph", "Ideographic"},
    139717: {"Unified_Ideograph", "Ideographic"},
    139718: {"Unified_Ideograph", "Ideographic"},
    139719: {"Unified_Ideograph", "Ideographic"},
    139720: {"Unified_Ideograph", "Ideographic"},
    139721: {"Unified_Ideograph", "Ideographic"},
    139722: {"Unified_Ideograph", "Ideographic"},
    139723: {"Unified_Ideograph", "Ideographic"},
    139724: {"Unified_Ideograph", "Ideographic"},
    139725: {"Unified_Ideograph", "Ideographic"},
    139726: {"Unified_Ideograph", "Ideographic"},
    139727: {"Unified_Ideograph", "Ideographic"},
    139728: {"Unified_Ideograph", "Ideographic"},
    139729: {"Unified_Ideograph", "Ideographic"},
    139730: {"Unified_Ideograph", "Ideographic"},
    139731: {"Unified_Ideograph", "Ideographic"},
    139732: {"Unified_Ideograph", "Ideographic"},
    139733: {"Unified_Ideograph", "Ideographic"},
    139734: {"Unified_Ideograph", "Ideographic"},
    139735: {"Unified_Ideograph", "Ideographic"},
    139736: {"Unified_Ideograph", "Ideographic"},
    139737: {"Unified_Ideograph", "Ideographic"},
    139738: {"Unified_Ideograph", "Ideographic"},
    139739: {"Unified_Ideograph", "Ideographic"},
    139740: {"Unified_Ideograph", "Ideographic"},
    139741: {"Unified_Ideograph", "Ideographic"},
    139742: {"Unified_Ideograph", "Ideographic"},
    139743: {"Unified_Ideograph", "Ideographic"},
    139744: {"Unified_Ideograph", "Ideographic"},
    139745: {"Unified_Ideograph", "Ideographic"},
    139746: {"Unified_Ideograph", "Ideographic"},
    139747: {"Unified_Ideograph", "Ideographic"},
    139748: {"Unified_Ideograph", "Ideographic"},
    139749: {"Unified_Ideograph", "Ideographic"},
    139750: {"Unified_Ideograph", "Ideographic"},
    139751: {"Unified_Ideograph", "Ideographic"},
    139752: {"Unified_Ideograph", "Ideographic"},
    139753: {"Unified_Ideograph", "Ideographic"},
    139754: {"Unified_Ideograph", "Ideographic"},
    139755: {"Unified_Ideograph", "Ideographic"},
    139756: {"Unified_Ideograph", "Ideographic"},
    139757: {"Unified_Ideograph", "Ideographic"},
    139758: {"Unified_Ideograph", "Ideographic"},
    139759: {"Unified_Ideograph", "Ideographic"},
    139760: {"Unified_Ideograph", "Ideographic"},
    139761: {"Unified_Ideograph", "Ideographic"},
    139762: {"Unified_Ideograph", "Ideographic"},
    139763: {"Unified_Ideograph", "Ideographic"},
    139764: {"Unified_Ideograph", "Ideographic"},
    139765: {"Unified_Ideograph", "Ideographic"},
    139766: {"Unified_Ideograph", "Ideographic"},
    139767: {"Unified_Ideograph", "Ideographic"},
    139768: {"Unified_Ideograph", "Ideographic"},
    139769: {"Unified_Ideograph", "Ideographic"},
    139770: {"Unified_Ideograph", "Ideographic"},
    139771: {"Unified_Ideograph", "Ideographic"},
    139772: {"Unified_Ideograph", "Ideographic"},
    139773: {"Unified_Ideograph", "Ideographic"},
    139774: {"Unified_Ideograph", "Ideographic"},
    139775: {"Unified_Ideograph", "Ideographic"},
    139776: {"Unified_Ideograph", "Ideographic"},
    139777: {"Unified_Ideograph", "Ideographic"},
    139778: {"Unified_Ideograph", "Ideographic"},
    139779: {"Unified_Ideograph", "Ideographic"},
    139780: {"Unified_Ideograph", "Ideographic"},
    139781: {"Unified_Ideograph", "Ideographic"},
    139782: {"Unified_Ideograph", "Ideographic"},
    139783: {"Unified_Ideograph", "Ideographic"},
    139784: {"Unified_Ideograph", "Ideographic"},
    139785: {"Unified_Ideograph", "Ideographic"},
    139786: {"Unified_Ideograph", "Ideographic"},
    139787: {"Unified_Ideograph", "Ideographic"},
    139788: {"Unified_Ideograph", "Ideographic"},
    139789: {"Unified_Ideograph", "Ideographic"},
    139790: {"Unified_Ideograph", "Ideographic"},
    139791: {"Unified_Ideograph", "Ideographic"},
    139792: {"Unified_Ideograph", "Ideographic"},
    139793: {"Unified_Ideograph", "Ideographic"},
    139794: {"Unified_Ideograph", "Ideographic"},
    139795: {"Unified_Ideograph", "Ideographic"},
    139796: {"Unified_Ideograph", "Ideographic"},
    139797: {"Unified_Ideograph", "Ideographic"},
    139798: {"Unified_Ideograph", "Ideographic"},
    139799: {"Unified_Ideograph", "Ideographic"},
    139800: {"Unified_Ideograph", "Ideographic"},
    139801: {"Unified_Ideograph", "Ideographic"},
    139802: {"Unified_Ideograph", "Ideographic"},
    139803: {"Unified_Ideograph", "Ideographic"},
    139804: {"Unified_Ideograph", "Ideographic"},
    139805: {"Unified_Ideograph", "Ideographic"},
    139806: {"Unified_Ideograph", "Ideographic"},
    139807: {"Unified_Ideograph", "Ideographic"},
    139808: {"Unified_Ideograph", "Ideographic"},
    139809: {"Unified_Ideograph", "Ideographic"},
    139810: {"Unified_Ideograph", "Ideographic"},
    139811: {"Unified_Ideograph", "Ideographic"},
    139812: {"Unified_Ideograph", "Ideographic"},
    139813: {"Unified_Ideograph", "Ideographic"},
    139814: {"Unified_Ideograph", "Ideographic"},
    139815: {"Unified_Ideograph", "Ideographic"},
    139816: {"Unified_Ideograph", "Ideographic"},
    139817: {"Unified_Ideograph", "Ideographic"},
    139818: {"Unified_Ideograph", "Ideographic"},
    139819: {"Unified_Ideograph", "Ideographic"},
    139820: {"Unified_Ideograph", "Ideographic"},
    139821: {"Unified_Ideograph", "Ideographic"},
    139822: {"Unified_Ideograph", "Ideographic"},
    139823: {"Unified_Ideograph", "Ideographic"},
    139824: {"Unified_Ideograph", "Ideographic"},
    139825: {"Unified_Ideograph", "Ideographic"},
    139826: {"Unified_Ideograph", "Ideographic"},
    139827: {"Unified_Ideograph", "Ideographic"},
    139828: {"Unified_Ideograph", "Ideographic"},
    139829: {"Unified_Ideograph", "Ideographic"},
    139830: {"Unified_Ideograph", "Ideographic"},
    139831: {"Unified_Ideograph", "Ideographic"},
    139832: {"Unified_Ideograph", "Ideographic"},
    139833: {"Unified_Ideograph", "Ideographic"},
    139834: {"Unified_Ideograph", "Ideographic"},
    139835: {"Unified_Ideograph", "Ideographic"},
    139836: {"Unified_Ideograph", "Ideographic"},
    139837: {"Unified_Ideograph", "Ideographic"},
    139838: {"Unified_Ideograph", "Ideographic"},
    139839: {"Unified_Ideograph", "Ideographic"},
    139840: {"Unified_Ideograph", "Ideographic"},
    139841: {"Unified_Ideograph", "Ideographic"},
    139842: {"Unified_Ideograph", "Ideographic"},
    139843: {"Unified_Ideograph", "Ideographic"},
    139844: {"Unified_Ideograph", "Ideographic"},
    139845: {"Unified_Ideograph", "Ideographic"},
    139846: {"Unified_Ideograph", "Ideographic"},
    139847: {"Unified_Ideograph", "Ideographic"},
    139848: {"Unified_Ideograph", "Ideographic"},
    139849: {"Unified_Ideograph", "Ideographic"},
    139850: {"Unified_Ideograph", "Ideographic"},
    139851: {"Unified_Ideograph", "Ideographic"},
    139852: {"Unified_Ideograph", "Ideographic"},
    139853: {"Unified_Ideograph", "Ideographic"},
    139854: {"Unified_Ideograph", "Ideographic"},
    139855: {"Unified_Ideograph", "Ideographic"},
    139856: {"Unified_Ideograph", "Ideographic"},
    139857: {"Unified_Ideograph", "Ideographic"},
    139858: {"Unified_Ideograph", "Ideographic"},
    139859: {"Unified_Ideograph", "Ideographic"},
    139860: {"Unified_Ideograph", "Ideographic"},
    139861: {"Unified_Ideograph", "Ideographic"},
    139862: {"Unified_Ideograph", "Ideographic"},
    139863: {"Unified_Ideograph", "Ideographic"},
    139864: {"Unified_Ideograph", "Ideographic"},
    139865: {"Unified_Ideograph", "Ideographic"},
    139866: {"Unified_Ideograph", "Ideographic"},
    139867: {"Unified_Ideograph", "Ideographic"},
    139868: {"Unified_Ideograph", "Ideographic"},
    139869: {"Unified_Ideograph", "Ideographic"},
    139870: {"Unified_Ideograph", "Ideographic"},
    139871: {"Unified_Ideograph", "Ideographic"},
    139872: {"Unified_Ideograph", "Ideographic"},
    139873: {"Unified_Ideograph", "Ideographic"},
    139874: {"Unified_Ideograph", "Ideographic"},
    139875: {"Unified_Ideograph", "Ideographic"},
    139876: {"Unified_Ideograph", "Ideographic"},
    139877: {"Unified_Ideograph", "Ideographic"},
    139878: {"Unified_Ideograph", "Ideographic"},
    139879: {"Unified_Ideograph", "Ideographic"},
    139880: {"Unified_Ideograph", "Ideographic"},
    139881: {"Unified_Ideograph", "Ideographic"},
    139882: {"Unified_Ideograph", "Ideographic"},
    139883: {"Unified_Ideograph", "Ideographic"},
    139884: {"Unified_Ideograph", "Ideographic"},
    139885: {"Unified_Ideograph", "Ideographic"},
    139886: {"Unified_Ideograph", "Ideographic"},
    139887: {"Unified_Ideograph", "Ideographic"},
    139888: {"Unified_Ideograph", "Ideographic"},
    139889: {"Unified_Ideograph", "Ideographic"},
    139890: {"Unified_Ideograph", "Ideographic"},
    139891: {"Unified_Ideograph", "Ideographic"},
    139892: {"Unified_Ideograph", "Ideographic"},
    139893: {"Unified_Ideograph", "Ideographic"},
    139894: {"Unified_Ideograph", "Ideographic"},
    139895: {"Unified_Ideograph", "Ideographic"},
    139896: {"Unified_Ideograph", "Ideographic"},
    139897: {"Unified_Ideograph", "Ideographic"},
    139898: {"Unified_Ideograph", "Ideographic"},
    139899: {"Unified_Ideograph", "Ideographic"},
    139900: {"Unified_Ideograph", "Ideographic"},
    139901: {"Unified_Ideograph", "Ideographic"},
    139902: {"Unified_Ideograph", "Ideographic"},
    139903: {"Unified_Ideograph", "Ideographic"},
    139904: {"Unified_Ideograph", "Ideographic"},
    139905: {"Unified_Ideograph", "Ideographic"},
    139906: {"Unified_Ideograph", "Ideographic"},
    139907: {"Unified_Ideograph", "Ideographic"},
    139908: {"Unified_Ideograph", "Ideographic"},
    139909: {"Unified_Ideograph", "Ideographic"},
    139910: {"Unified_Ideograph", "Ideographic"},
    139911: {"Unified_Ideograph", "Ideographic"},
    139912: {"Unified_Ideograph", "Ideographic"},
    139913: {"Unified_Ideograph", "Ideographic"},
    139914: {"Unified_Ideograph", "Ideographic"},
    139915: {"Unified_Ideograph", "Ideographic"},
    139916: {"Unified_Ideograph", "Ideographic"},
    139917: {"Unified_Ideograph", "Ideographic"},
    139918: {"Unified_Ideograph", "Ideographic"},
    139919: {"Unified_Ideograph", "Ideographic"},
    139920: {"Unified_Ideograph", "Ideographic"},
    139921: {"Unified_Ideograph", "Ideographic"},
    139922: {"Unified_Ideograph", "Ideographic"},
    139923: {"Unified_Ideograph", "Ideographic"},
    139924: {"Unified_Ideograph", "Ideographic"},
    139925: {"Unified_Ideograph", "Ideographic"},
    139926: {"Unified_Ideograph", "Ideographic"},
    139927: {"Unified_Ideograph", "Ideographic"},
    139928: {"Unified_Ideograph", "Ideographic"},
    139929: {"Unified_Ideograph", "Ideographic"},
    139930: {"Unified_Ideograph", "Ideographic"},
    139931: {"Unified_Ideograph", "Ideographic"},
    139932: {"Unified_Ideograph", "Ideographic"},
    139933: {"Unified_Ideograph", "Ideographic"},
    139934: {"Unified_Ideograph", "Ideographic"},
    139935: {"Unified_Ideograph", "Ideographic"},
    139936: {"Unified_Ideograph", "Ideographic"},
    139937: {"Unified_Ideograph", "Ideographic"},
    139938: {"Unified_Ideograph", "Ideographic"},
    139939: {"Unified_Ideograph", "Ideographic"},
    139940: {"Unified_Ideograph", "Ideographic"},
    139941: {"Unified_Ideograph", "Ideographic"},
    139942: {"Unified_Ideograph", "Ideographic"},
    139943: {"Unified_Ideograph", "Ideographic"},
    139944: {"Unified_Ideograph", "Ideographic"},
    139945: {"Unified_Ideograph", "Ideographic"},
    139946: {"Unified_Ideograph", "Ideographic"},
    139947: {"Unified_Ideograph", "Ideographic"},
    139948: {"Unified_Ideograph", "Ideographic"},
    139949: {"Unified_Ideograph", "Ideographic"},
    139950: {"Unified_Ideograph", "Ideographic"},
    139951: {"Unified_Ideograph", "Ideographic"},
    139952: {"Unified_Ideograph", "Ideographic"},
    139953: {"Unified_Ideograph", "Ideographic"},
    139954: {"Unified_Ideograph", "Ideographic"},
    139955: {"Unified_Ideograph", "Ideographic"},
    139956: {"Unified_Ideograph", "Ideographic"},
    139957: {"Unified_Ideograph", "Ideographic"},
    139958: {"Unified_Ideograph", "Ideographic"},
    139959: {"Unified_Ideograph", "Ideographic"},
    139960: {"Unified_Ideograph", "Ideographic"},
    139961: {"Unified_Ideograph", "Ideographic"},
    139962: {"Unified_Ideograph", "Ideographic"},
    139963: {"Unified_Ideograph", "Ideographic"},
    139964: {"Unified_Ideograph", "Ideographic"},
    139965: {"Unified_Ideograph", "Ideographic"},
    139966: {"Unified_Ideograph", "Ideographic"},
    139967: {"Unified_Ideograph", "Ideographic"},
    139968: {"Unified_Ideograph", "Ideographic"},
    139969: {"Unified_Ideograph", "Ideographic"},
    139970: {"Unified_Ideograph", "Ideographic"},
    139971: {"Unified_Ideograph", "Ideographic"},
    139972: {"Unified_Ideograph", "Ideographic"},
    139973: {"Unified_Ideograph", "Ideographic"},
    139974: {"Unified_Ideograph", "Ideographic"},
    139975: {"Unified_Ideograph", "Ideographic"},
    139976: {"Unified_Ideograph", "Ideographic"},
    139977: {"Unified_Ideograph", "Ideographic"},
    139978: {"Unified_Ideograph", "Ideographic"},
    139979: {"Unified_Ideograph", "Ideographic"},
    139980: {"Unified_Ideograph", "Ideographic"},
    139981: {"Unified_Ideograph", "Ideographic"},
    139982: {"Unified_Ideograph", "Ideographic"},
    139983: {"Unified_Ideograph", "Ideographic"},
    139984: {"Unified_Ideograph", "Ideographic"},
    139985: {"Unified_Ideograph", "Ideographic"},
    139986: {"Unified_Ideograph", "Ideographic"},
    139987: {"Unified_Ideograph", "Ideographic"},
    139988: {"Unified_Ideograph", "Ideographic"},
    139989: {"Unified_Ideograph", "Ideographic"},
    139990: {"Unified_Ideograph", "Ideographic"},
    139991: {"Unified_Ideograph", "Ideographic"},
    139992: {"Unified_Ideograph", "Ideographic"},
    139993: {"Unified_Ideograph", "Ideographic"},
    139994: {"Unified_Ideograph", "Ideographic"},
    139995: {"Unified_Ideograph", "Ideographic"},
    139996: {"Unified_Ideograph", "Ideographic"},
    139997: {"Unified_Ideograph", "Ideographic"},
    139998: {"Unified_Ideograph", "Ideographic"},
    139999: {"Unified_Ideograph", "Ideographic"},
    140000: {"Unified_Ideograph", "Ideographic"},
    140001: {"Unified_Ideograph", "Ideographic"},
    140002: {"Unified_Ideograph", "Ideographic"},
    140003: {"Unified_Ideograph", "Ideographic"},
    140004: {"Unified_Ideograph", "Ideographic"},
    140005: {"Unified_Ideograph", "Ideographic"},
    140006: {"Unified_Ideograph", "Ideographic"},
    140007: {"Unified_Ideograph", "Ideographic"},
    140008: {"Unified_Ideograph", "Ideographic"},
    140009: {"Unified_Ideograph", "Ideographic"},
    140010: {"Unified_Ideograph", "Ideographic"},
    140011: {"Unified_Ideograph", "Ideographic"},
    140012: {"Unified_Ideograph", "Ideographic"},
    140013: {"Unified_Ideograph", "Ideographic"},
    140014: {"Unified_Ideograph", "Ideographic"},
    140015: {"Unified_Ideograph", "Ideographic"},
    140016: {"Unified_Ideograph", "Ideographic"},
    140017: {"Unified_Ideograph", "Ideographic"},
    140018: {"Unified_Ideograph", "Ideographic"},
    140019: {"Unified_Ideograph", "Ideographic"},
    140020: {"Unified_Ideograph", "Ideographic"},
    140021: {"Unified_Ideograph", "Ideographic"},
    140022: {"Unified_Ideograph", "Ideographic"},
    140023: {"Unified_Ideograph", "Ideographic"},
    140024: {"Unified_Ideograph", "Ideographic"},
    140025: {"Unified_Ideograph", "Ideographic"},
    140026: {"Unified_Ideograph", "Ideographic"},
    140027: {"Unified_Ideograph", "Ideographic"},
    140028: {"Unified_Ideograph", "Ideographic"},
    140029: {"Unified_Ideograph", "Ideographic"},
    140030: {"Unified_Ideograph", "Ideographic"},
    140031: {"Unified_Ideograph", "Ideographic"},
    140032: {"Unified_Ideograph", "Ideographic"},
    140033: {"Unified_Ideograph", "Ideographic"},
    140034: {"Unified_Ideograph", "Ideographic"},
    140035: {"Unified_Ideograph", "Ideographic"},
    140036: {"Unified_Ideograph", "Ideographic"},
    140037: {"Unified_Ideograph", "Ideographic"},
    140038: {"Unified_Ideograph", "Ideographic"},
    140039: {"Unified_Ideograph", "Ideographic"},
    140040: {"Unified_Ideograph", "Ideographic"},
    140041: {"Unified_Ideograph", "Ideographic"},
    140042: {"Unified_Ideograph", "Ideographic"},
    140043: {"Unified_Ideograph", "Ideographic"},
    140044: {"Unified_Ideograph", "Ideographic"},
    140045: {"Unified_Ideograph", "Ideographic"},
    140046: {"Unified_Ideograph", "Ideographic"},
    140047: {"Unified_Ideograph", "Ideographic"},
    140048: {"Unified_Ideograph", "Ideographic"},
    140049: {"Unified_Ideograph", "Ideographic"},
    140050: {"Unified_Ideograph", "Ideographic"},
    140051: {"Unified_Ideograph", "Ideographic"},
    140052: {"Unified_Ideograph", "Ideographic"},
    140053: {"Unified_Ideograph", "Ideographic"},
    140054: {"Unified_Ideograph", "Ideographic"},
    140055: {"Unified_Ideograph", "Ideographic"},
    140056: {"Unified_Ideograph", "Ideographic"},
    140057: {"Unified_Ideograph", "Ideographic"},
    140058: {"Unified_Ideograph", "Ideographic"},
    140059: {"Unified_Ideograph", "Ideographic"},
    140060: {"Unified_Ideograph", "Ideographic"},
    140061: {"Unified_Ideograph", "Ideographic"},
    140062: {"Unified_Ideograph", "Ideographic"},
    140063: {"Unified_Ideograph", "Ideographic"},
    140064: {"Unified_Ideograph", "Ideographic"},
    140065: {"Unified_Ideograph", "Ideographic"},
    140066: {"Unified_Ideograph", "Ideographic"},
    140067: {"Unified_Ideograph", "Ideographic"},
    140068: {"Unified_Ideograph", "Ideographic"},
    140069: {"Unified_Ideograph", "Ideographic"},
    140070: {"Unified_Ideograph", "Ideographic"},
    140071: {"Unified_Ideograph", "Ideographic"},
    140072: {"Unified_Ideograph", "Ideographic"},
    140073: {"Unified_Ideograph", "Ideographic"},
    140074: {"Unified_Ideograph", "Ideographic"},
    140075: {"Unified_Ideograph", "Ideographic"},
    140076: {"Unified_Ideograph", "Ideographic"},
    140077: {"Unified_Ideograph", "Ideographic"},
    140078: {"Unified_Ideograph", "Ideographic"},
    140079: {"Unified_Ideograph", "Ideographic"},
    140080: {"Unified_Ideograph", "Ideographic"},
    140081: {"Unified_Ideograph", "Ideographic"},
    140082: {"Unified_Ideograph", "Ideographic"},
    140083: {"Unified_Ideograph", "Ideographic"},
    140084: {"Unified_Ideograph", "Ideographic"},
    140085: {"Unified_Ideograph", "Ideographic"},
    140086: {"Unified_Ideograph", "Ideographic"},
    140087: {"Unified_Ideograph", "Ideographic"},
    140088: {"Unified_Ideograph", "Ideographic"},
    140089: {"Unified_Ideograph", "Ideographic"},
    140090: {"Unified_Ideograph", "Ideographic"},
    140091: {"Unified_Ideograph", "Ideographic"},
    140092: {"Unified_Ideograph", "Ideographic"},
    140093: {"Unified_Ideograph", "Ideographic"},
    140094: {"Unified_Ideograph", "Ideographic"},
    140095: {"Unified_Ideograph", "Ideographic"},
    140096: {"Unified_Ideograph", "Ideographic"},
    140097: {"Unified_Ideograph", "Ideographic"},
    140098: {"Unified_Ideograph", "Ideographic"},
    140099: {"Unified_Ideograph", "Ideographic"},
    140100: {"Unified_Ideograph", "Ideographic"},
    140101: {"Unified_Ideograph", "Ideographic"},
    140102: {"Unified_Ideograph", "Ideographic"},
    140103: {"Unified_Ideograph", "Ideographic"},
    140104: {"Unified_Ideograph", "Ideographic"},
    140105: {"Unified_Ideograph", "Ideographic"},
    140106: {"Unified_Ideograph", "Ideographic"},
    140107: {"Unified_Ideograph", "Ideographic"},
    140108: {"Unified_Ideograph", "Ideographic"},
    140109: {"Unified_Ideograph", "Ideographic"},
    140110: {"Unified_Ideograph", "Ideographic"},
    140111: {"Unified_Ideograph", "Ideographic"},
    140112: {"Unified_Ideograph", "Ideographic"},
    140113: {"Unified_Ideograph", "Ideographic"},
    140114: {"Unified_Ideograph", "Ideographic"},
    140115: {"Unified_Ideograph", "Ideographic"},
    140116: {"Unified_Ideograph", "Ideographic"},
    140117: {"Unified_Ideograph", "Ideographic"},
    140118: {"Unified_Ideograph", "Ideographic"},
    140119: {"Unified_Ideograph", "Ideographic"},
    140120: {"Unified_Ideograph", "Ideographic"},
    140121: {"Unified_Ideograph", "Ideographic"},
    140122: {"Unified_Ideograph", "Ideographic"},
    140123: {"Unified_Ideograph", "Ideographic"},
    140124: {"Unified_Ideograph", "Ideographic"},
    140125: {"Unified_Ideograph", "Ideographic"},
    140126: {"Unified_Ideograph", "Ideographic"},
    140127: {"Unified_Ideograph", "Ideographic"},
    140128: {"Unified_Ideograph", "Ideographic"},
    140129: {"Unified_Ideograph", "Ideographic"},
    140130: {"Unified_Ideograph", "Ideographic"},
    140131: {"Unified_Ideograph", "Ideographic"},
    140132: {"Unified_Ideograph", "Ideographic"},
    140133: {"Unified_Ideograph", "Ideographic"},
    140134: {"Unified_Ideograph", "Ideographic"},
    140135: {"Unified_Ideograph", "Ideographic"},
    140136: {"Unified_Ideograph", "Ideographic"},
    140137: {"Unified_Ideograph", "Ideographic"},
    140138: {"Unified_Ideograph", "Ideographic"},
    140139: {"Unified_Ideograph", "Ideographic"},
    140140: {"Unified_Ideograph", "Ideographic"},
    140141: {"Unified_Ideograph", "Ideographic"},
    140142: {"Unified_Ideograph", "Ideographic"},
    140143: {"Unified_Ideograph", "Ideographic"},
    140144: {"Unified_Ideograph", "Ideographic"},
    140145: {"Unified_Ideograph", "Ideographic"},
    140146: {"Unified_Ideograph", "Ideographic"},
    140147: {"Unified_Ideograph", "Ideographic"},
    140148: {"Unified_Ideograph", "Ideographic"},
    140149: {"Unified_Ideograph", "Ideographic"},
    140150: {"Unified_Ideograph", "Ideographic"},
    140151: {"Unified_Ideograph", "Ideographic"},
    140152: {"Unified_Ideograph", "Ideographic"},
    140153: {"Unified_Ideograph", "Ideographic"},
    140154: {"Unified_Ideograph", "Ideographic"},
    140155: {"Unified_Ideograph", "Ideographic"},
    140156: {"Unified_Ideograph", "Ideographic"},
    140157: {"Unified_Ideograph", "Ideographic"},
    140158: {"Unified_Ideograph", "Ideographic"},
    140159: {"Unified_Ideograph", "Ideographic"},
    140160: {"Unified_Ideograph", "Ideographic"},
    140161: {"Unified_Ideograph", "Ideographic"},
    140162: {"Unified_Ideograph", "Ideographic"},
    140163: {"Unified_Ideograph", "Ideographic"},
    140164: {"Unified_Ideograph", "Ideographic"},
    140165: {"Unified_Ideograph", "Ideographic"},
    140166: {"Unified_Ideograph", "Ideographic"},
    140167: {"Unified_Ideograph", "Ideographic"},
    140168: {"Unified_Ideograph", "Ideographic"},
    140169: {"Unified_Ideograph", "Ideographic"},
    140170: {"Unified_Ideograph", "Ideographic"},
    140171: {"Unified_Ideograph", "Ideographic"},
    140172: {"Unified_Ideograph", "Ideographic"},
    140173: {"Unified_Ideograph", "Ideographic"},
    140174: {"Unified_Ideograph", "Ideographic"},
    140175: {"Unified_Ideograph", "Ideographic"},
    140176: {"Unified_Ideograph", "Ideographic"},
    140177: {"Unified_Ideograph", "Ideographic"},
    140178: {"Unified_Ideograph", "Ideographic"},
    140179: {"Unified_Ideograph", "Ideographic"},
    140180: {"Unified_Ideograph", "Ideographic"},
    140181: {"Unified_Ideograph", "Ideographic"},
    140182: {"Unified_Ideograph", "Ideographic"},
    140183: {"Unified_Ideograph", "Ideographic"},
    140184: {"Unified_Ideograph", "Ideographic"},
    140185: {"Unified_Ideograph", "Ideographic"},
    140186: {"Unified_Ideograph", "Ideographic"},
    140187: {"Unified_Ideograph", "Ideographic"},
    140188: {"Unified_Ideograph", "Ideographic"},
    140189: {"Unified_Ideograph", "Ideographic"},
    140190: {"Unified_Ideograph", "Ideographic"},
    140191: {"Unified_Ideograph", "Ideographic"},
    140192: {"Unified_Ideograph", "Ideographic"},
    140193: {"Unified_Ideograph", "Ideographic"},
    140194: {"Unified_Ideograph", "Ideographic"},
    140195: {"Unified_Ideograph", "Ideographic"},
    140196: {"Unified_Ideograph", "Ideographic"},
    140197: {"Unified_Ideograph", "Ideographic"},
    140198: {"Unified_Ideograph", "Ideographic"},
    140199: {"Unified_Ideograph", "Ideographic"},
    140200: {"Unified_Ideograph", "Ideographic"},
    140201: {"Unified_Ideograph", "Ideographic"},
    140202: {"Unified_Ideograph", "Ideographic"},
    140203: {"Unified_Ideograph", "Ideographic"},
    140204: {"Unified_Ideograph", "Ideographic"},
    140205: {"Unified_Ideograph", "Ideographic"},
    140206: {"Unified_Ideograph", "Ideographic"},
    140207: {"Unified_Ideograph", "Ideographic"},
    140208: {"Unified_Ideograph", "Ideographic"},
    140209: {"Unified_Ideograph", "Ideographic"},
    140210: {"Unified_Ideograph", "Ideographic"},
    140211: {"Unified_Ideograph", "Ideographic"},
    140212: {"Unified_Ideograph", "Ideographic"},
    140213: {"Unified_Ideograph", "Ideographic"},
    140214: {"Unified_Ideograph", "Ideographic"},
    140215: {"Unified_Ideograph", "Ideographic"},
    140216: {"Unified_Ideograph", "Ideographic"},
    140217: {"Unified_Ideograph", "Ideographic"},
    140218: {"Unified_Ideograph", "Ideographic"},
    140219: {"Unified_Ideograph", "Ideographic"},
    140220: {"Unified_Ideograph", "Ideographic"},
    140221: {"Unified_Ideograph", "Ideographic"},
    140222: {"Unified_Ideograph", "Ideographic"},
    140223: {"Unified_Ideograph", "Ideographic"},
    140224: {"Unified_Ideograph", "Ideographic"},
    140225: {"Unified_Ideograph", "Ideographic"},
    140226: {"Unified_Ideograph", "Ideographic"},
    140227: {"Unified_Ideograph", "Ideographic"},
    140228: {"Unified_Ideograph", "Ideographic"},
    140229: {"Unified_Ideograph", "Ideographic"},
    140230: {"Unified_Ideograph", "Ideographic"},
    140231: {"Unified_Ideograph", "Ideographic"},
    140232: {"Unified_Ideograph", "Ideographic"},
    140233: {"Unified_Ideograph", "Ideographic"},
    140234: {"Unified_Ideograph", "Ideographic"},
    140235: {"Unified_Ideograph", "Ideographic"},
    140236: {"Unified_Ideograph", "Ideographic"},
    140237: {"Unified_Ideograph", "Ideographic"},
    140238: {"Unified_Ideograph", "Ideographic"},
    140239: {"Unified_Ideograph", "Ideographic"},
    140240: {"Unified_Ideograph", "Ideographic"},
    140241: {"Unified_Ideograph", "Ideographic"},
    140242: {"Unified_Ideograph", "Ideographic"},
    140243: {"Unified_Ideograph", "Ideographic"},
    140244: {"Unified_Ideograph", "Ideographic"},
    140245: {"Unified_Ideograph", "Ideographic"},
    140246: {"Unified_Ideograph", "Ideographic"},
    140247: {"Unified_Ideograph", "Ideographic"},
    140248: {"Unified_Ideograph", "Ideographic"},
    140249: {"Unified_Ideograph", "Ideographic"},
    140250: {"Unified_Ideograph", "Ideographic"},
    140251: {"Unified_Ideograph", "Ideographic"},
    140252: {"Unified_Ideograph", "Ideographic"},
    140253: {"Unified_Ideograph", "Ideographic"},
    140254: {"Unified_Ideograph", "Ideographic"},
    140255: {"Unified_Ideograph", "Ideographic"},
    140256: {"Unified_Ideograph", "Ideographic"},
    140257: {"Unified_Ideograph", "Ideographic"},
    140258: {"Unified_Ideograph", "Ideographic"},
    140259: {"Unified_Ideograph", "Ideographic"},
    140260: {"Unified_Ideograph", "Ideographic"},
    140261: {"Unified_Ideograph", "Ideographic"},
    140262: {"Unified_Ideograph", "Ideographic"},
    140263: {"Unified_Ideograph", "Ideographic"},
    140264: {"Unified_Ideograph", "Ideographic"},
    140265: {"Unified_Ideograph", "Ideographic"},
    140266: {"Unified_Ideograph", "Ideographic"},
    140267: {"Unified_Ideograph", "Ideographic"},
    140268: {"Unified_Ideograph", "Ideographic"},
    140269: {"Unified_Ideograph", "Ideographic"},
    140270: {"Unified_Ideograph", "Ideographic"},
    140271: {"Unified_Ideograph", "Ideographic"},
    140272: {"Unified_Ideograph", "Ideographic"},
    140273: {"Unified_Ideograph", "Ideographic"},
    140274: {"Unified_Ideograph", "Ideographic"},
    140275: {"Unified_Ideograph", "Ideographic"},
    140276: {"Unified_Ideograph", "Ideographic"},
    140277: {"Unified_Ideograph", "Ideographic"},
    140278: {"Unified_Ideograph", "Ideographic"},
    140279: {"Unified_Ideograph", "Ideographic"},
    140280: {"Unified_Ideograph", "Ideographic"},
    140281: {"Unified_Ideograph", "Ideographic"},
    140282: {"Unified_Ideograph", "Ideographic"},
    140283: {"Unified_Ideograph", "Ideographic"},
    140284: {"Unified_Ideograph", "Ideographic"},
    140285: {"Unified_Ideograph", "Ideographic"},
    140286: {"Unified_Ideograph", "Ideographic"},
    140287: {"Unified_Ideograph", "Ideographic"},
    140288: {"Unified_Ideograph", "Ideographic"},
    140289: {"Unified_Ideograph", "Ideographic"},
    140290: {"Unified_Ideograph", "Ideographic"},
    140291: {"Unified_Ideograph", "Ideographic"},
    140292: {"Unified_Ideograph", "Ideographic"},
    140293: {"Unified_Ideograph", "Ideographic"},
    140294: {"Unified_Ideograph", "Ideographic"},
    140295: {"Unified_Ideograph", "Ideographic"},
    140296: {"Unified_Ideograph", "Ideographic"},
    140297: {"Unified_Ideograph", "Ideographic"},
    140298: {"Unified_Ideograph", "Ideographic"},
    140299: {"Unified_Ideograph", "Ideographic"},
    140300: {"Unified_Ideograph", "Ideographic"},
    140301: {"Unified_Ideograph", "Ideographic"},
    140302: {"Unified_Ideograph", "Ideographic"},
    140303: {"Unified_Ideograph", "Ideographic"},
    140304: {"Unified_Ideograph", "Ideographic"},
    140305: {"Unified_Ideograph", "Ideographic"},
    140306: {"Unified_Ideograph", "Ideographic"},
    140307: {"Unified_Ideograph", "Ideographic"},
    140308: {"Unified_Ideograph", "Ideographic"},
    140309: {"Unified_Ideograph", "Ideographic"},
    140310: {"Unified_Ideograph", "Ideographic"},
    140311: {"Unified_Ideograph", "Ideographic"},
    140312: {"Unified_Ideograph", "Ideographic"},
    140313: {"Unified_Ideograph", "Ideographic"},
    140314: {"Unified_Ideograph", "Ideographic"},
    140315: {"Unified_Ideograph", "Ideographic"},
    140316: {"Unified_Ideograph", "Ideographic"},
    140317: {"Unified_Ideograph", "Ideographic"},
    140318: {"Unified_Ideograph", "Ideographic"},
    140319: {"Unified_Ideograph", "Ideographic"},
    140320: {"Unified_Ideograph", "Ideographic"},
    140321: {"Unified_Ideograph", "Ideographic"},
    140322: {"Unified_Ideograph", "Ideographic"},
    140323: {"Unified_Ideograph", "Ideographic"},
    140324: {"Unified_Ideograph", "Ideographic"},
    140325: {"Unified_Ideograph", "Ideographic"},
    140326: {"Unified_Ideograph", "Ideographic"},
    140327: {"Unified_Ideograph", "Ideographic"},
    140328: {"Unified_Ideograph", "Ideographic"},
    140329: {"Unified_Ideograph", "Ideographic"},
    140330: {"Unified_Ideograph", "Ideographic"},
    140331: {"Unified_Ideograph", "Ideographic"},
    140332: {"Unified_Ideograph", "Ideographic"},
    140333: {"Unified_Ideograph", "Ideographic"},
    140334: {"Unified_Ideograph", "Ideographic"},
    140335: {"Unified_Ideograph", "Ideographic"},
    140336: {"Unified_Ideograph", "Ideographic"},
    140337: {"Unified_Ideograph", "Ideographic"},
    140338: {"Unified_Ideograph", "Ideographic"},
    140339: {"Unified_Ideograph", "Ideographic"},
    140340: {"Unified_Ideograph", "Ideographic"},
    140341: {"Unified_Ideograph", "Ideographic"},
    140342: {"Unified_Ideograph", "Ideographic"},
    140343: {"Unified_Ideograph", "Ideographic"},
    140344: {"Unified_Ideograph", "Ideographic"},
    140345: {"Unified_Ideograph", "Ideographic"},
    140346: {"Unified_Ideograph", "Ideographic"},
    140347: {"Unified_Ideograph", "Ideographic"},
    140348: {"Unified_Ideograph", "Ideographic"},
    140349: {"Unified_Ideograph", "Ideographic"},
    140350: {"Unified_Ideograph", "Ideographic"},
    140351: {"Unified_Ideograph", "Ideographic"},
    140352: {"Unified_Ideograph", "Ideographic"},
    140353: {"Unified_Ideograph", "Ideographic"},
    140354: {"Unified_Ideograph", "Ideographic"},
    140355: {"Unified_Ideograph", "Ideographic"},
    140356: {"Unified_Ideograph", "Ideographic"},
    140357: {"Unified_Ideograph", "Ideographic"},
    140358: {"Unified_Ideograph", "Ideographic"},
    140359: {"Unified_Ideograph", "Ideographic"},
    140360: {"Unified_Ideograph", "Ideographic"},
    140361: {"Unified_Ideograph", "Ideographic"},
    140362: {"Unified_Ideograph", "Ideographic"},
    140363: {"Unified_Ideograph", "Ideographic"},
    140364: {"Unified_Ideograph", "Ideographic"},
    140365: {"Unified_Ideograph", "Ideographic"},
    140366: {"Unified_Ideograph", "Ideographic"},
    140367: {"Unified_Ideograph", "Ideographic"},
    140368: {"Unified_Ideograph", "Ideographic"},
    140369: {"Unified_Ideograph", "Ideographic"},
    140370: {"Unified_Ideograph", "Ideographic"},
    140371: {"Unified_Ideograph", "Ideographic"},
    140372: {"Unified_Ideograph", "Ideographic"},
    140373: {"Unified_Ideograph", "Ideographic"},
    140374: {"Unified_Ideograph", "Ideographic"},
    140375: {"Unified_Ideograph", "Ideographic"},
    140376: {"Unified_Ideograph", "Ideographic"},
    140377: {"Unified_Ideograph", "Ideographic"},
    140378: {"Unified_Ideograph", "Ideographic"},
    140379: {"Unified_Ideograph", "Ideographic"},
    140380: {"Unified_Ideograph", "Ideographic"},
    140381: {"Unified_Ideograph", "Ideographic"},
    140382: {"Unified_Ideograph", "Ideographic"},
    140383: {"Unified_Ideograph", "Ideographic"},
    140384: {"Unified_Ideograph", "Ideographic"},
    140385: {"Unified_Ideograph", "Ideographic"},
    140386: {"Unified_Ideograph", "Ideographic"},
    140387: {"Unified_Ideograph", "Ideographic"},
    140388: {"Unified_Ideograph", "Ideographic"},
    140389: {"Unified_Ideograph", "Ideographic"},
    140390: {"Unified_Ideograph", "Ideographic"},
    140391: {"Unified_Ideograph", "Ideographic"},
    140392: {"Unified_Ideograph", "Ideographic"},
    140393: {"Unified_Ideograph", "Ideographic"},
    140394: {"Unified_Ideograph", "Ideographic"},
    140395: {"Unified_Ideograph", "Ideographic"},
    140396: {"Unified_Ideograph", "Ideographic"},
    140397: {"Unified_Ideograph", "Ideographic"},
    140398: {"Unified_Ideograph", "Ideographic"},
    140399: {"Unified_Ideograph", "Ideographic"},
    140400: {"Unified_Ideograph", "Ideographic"},
    140401: {"Unified_Ideograph", "Ideographic"},
    140402: {"Unified_Ideograph", "Ideographic"},
    140403: {"Unified_Ideograph", "Ideographic"},
    140404: {"Unified_Ideograph", "Ideographic"},
    140405: {"Unified_Ideograph", "Ideographic"},
    140406: {"Unified_Ideograph", "Ideographic"},
    140407: {"Unified_Ideograph", "Ideographic"},
    140408: {"Unified_Ideograph", "Ideographic"},
    140409: {"Unified_Ideograph", "Ideographic"},
    140410: {"Unified_Ideograph", "Ideographic"},
    140411: {"Unified_Ideograph", "Ideographic"},
    140412: {"Unified_Ideograph", "Ideographic"},
    140413: {"Unified_Ideograph", "Ideographic"},
    140414: {"Unified_Ideograph", "Ideographic"},
    140415: {"Unified_Ideograph", "Ideographic"},
    140416: {"Unified_Ideograph", "Ideographic"},
    140417: {"Unified_Ideograph", "Ideographic"},
    140418: {"Unified_Ideograph", "Ideographic"},
    140419: {"Unified_Ideograph", "Ideographic"},
    140420: {"Unified_Ideograph", "Ideographic"},
    140421: {"Unified_Ideograph", "Ideographic"},
    140422: {"Unified_Ideograph", "Ideographic"},
    140423: {"Unified_Ideograph", "Ideographic"},
    140424: {"Unified_Ideograph", "Ideographic"},
    140425: {"Unified_Ideograph", "Ideographic"},
    140426: {"Unified_Ideograph", "Ideographic"},
    140427: {"Unified_Ideograph", "Ideographic"},
    140428: {"Unified_Ideograph", "Ideographic"},
    140429: {"Unified_Ideograph", "Ideographic"},
    140430: {"Unified_Ideograph", "Ideographic"},
    140431: {"Unified_Ideograph", "Ideographic"},
    140432: {"Unified_Ideograph", "Ideographic"},
    140433: {"Unified_Ideograph", "Ideographic"},
    140434: {"Unified_Ideograph", "Ideographic"},
    140435: {"Unified_Ideograph", "Ideographic"},
    140436: {"Unified_Ideograph", "Ideographic"},
    140437: {"Unified_Ideograph", "Ideographic"},
    140438: {"Unified_Ideograph", "Ideographic"},
    140439: {"Unified_Ideograph", "Ideographic"},
    140440: {"Unified_Ideograph", "Ideographic"},
    140441: {"Unified_Ideograph", "Ideographic"},
    140442: {"Unified_Ideograph", "Ideographic"},
    140443: {"Unified_Ideograph", "Ideographic"},
    140444: {"Unified_Ideograph", "Ideographic"},
    140445: {"Unified_Ideograph", "Ideographic"},
    140446: {"Unified_Ideograph", "Ideographic"},
    140447: {"Unified_Ideograph", "Ideographic"},
    140448: {"Unified_Ideograph", "Ideographic"},
    140449: {"Unified_Ideograph", "Ideographic"},
    140450: {"Unified_Ideograph", "Ideographic"},
    140451: {"Unified_Ideograph", "Ideographic"},
    140452: {"Unified_Ideograph", "Ideographic"},
    140453: {"Unified_Ideograph", "Ideographic"},
    140454: {"Unified_Ideograph", "Ideographic"},
    140455: {"Unified_Ideograph", "Ideographic"},
    140456: {"Unified_Ideograph", "Ideographic"},
    140457: {"Unified_Ideograph", "Ideographic"},
    140458: {"Unified_Ideograph", "Ideographic"},
    140459: {"Unified_Ideograph", "Ideographic"},
    140460: {"Unified_Ideograph", "Ideographic"},
    140461: {"Unified_Ideograph", "Ideographic"},
    140462: {"Unified_Ideograph", "Ideographic"},
    140463: {"Unified_Ideograph", "Ideographic"},
    140464: {"Unified_Ideograph", "Ideographic"},
    140465: {"Unified_Ideograph", "Ideographic"},
    140466: {"Unified_Ideograph", "Ideographic"},
    140467: {"Unified_Ideograph", "Ideographic"},
    140468: {"Unified_Ideograph", "Ideographic"},
    140469: {"Unified_Ideograph", "Ideographic"},
    140470: {"Unified_Ideograph", "Ideographic"},
    140471: {"Unified_Ideograph", "Ideographic"},
    140472: {"Unified_Ideograph", "Ideographic"},
    140473: {"Unified_Ideograph", "Ideographic"},
    140474: {"Unified_Ideograph", "Ideographic"},
    140475: {"Unified_Ideograph", "Ideographic"},
    140476: {"Unified_Ideograph", "Ideographic"},
    140477: {"Unified_Ideograph", "Ideographic"},
    140478: {"Unified_Ideograph", "Ideographic"},
    140479: {"Unified_Ideograph", "Ideographic"},
    140480: {"Unified_Ideograph", "Ideographic"},
    140481: {"Unified_Ideograph", "Ideographic"},
    140482: {"Unified_Ideograph", "Ideographic"},
    140483: {"Unified_Ideograph", "Ideographic"},
    140484: {"Unified_Ideograph", "Ideographic"},
    140485: {"Unified_Ideograph", "Ideographic"},
    140486: {"Unified_Ideograph", "Ideographic"},
    140487: {"Unified_Ideograph", "Ideographic"},
    140488: {"Unified_Ideograph", "Ideographic"},
    140489: {"Unified_Ideograph", "Ideographic"},
    140490: {"Unified_Ideograph", "Ideographic"},
    140491: {"Unified_Ideograph", "Ideographic"},
    140492: {"Unified_Ideograph", "Ideographic"},
    140493: {"Unified_Ideograph", "Ideographic"},
    140494: {"Unified_Ideograph", "Ideographic"},
    140495: {"Unified_Ideograph", "Ideographic"},
    140496: {"Unified_Ideograph", "Ideographic"},
    140497: {"Unified_Ideograph", "Ideographic"},
    140498: {"Unified_Ideograph", "Ideographic"},
    140499: {"Unified_Ideograph", "Ideographic"},
    140500: {"Unified_Ideograph", "Ideographic"},
    140501: {"Unified_Ideograph", "Ideographic"},
    140502: {"Unified_Ideograph", "Ideographic"},
    140503: {"Unified_Ideograph", "Ideographic"},
    140504: {"Unified_Ideograph", "Ideographic"},
    140505: {"Unified_Ideograph", "Ideographic"},
    140506: {"Unified_Ideograph", "Ideographic"},
    140507: {"Unified_Ideograph", "Ideographic"},
    140508: {"Unified_Ideograph", "Ideographic"},
    140509: {"Unified_Ideograph", "Ideographic"},
    140510: {"Unified_Ideograph", "Ideographic"},
    140511: {"Unified_Ideograph", "Ideographic"},
    140512: {"Unified_Ideograph", "Ideographic"},
    140513: {"Unified_Ideograph", "Ideographic"},
    140514: {"Unified_Ideograph", "Ideographic"},
    140515: {"Unified_Ideograph", "Ideographic"},
    140516: {"Unified_Ideograph", "Ideographic"},
    140517: {"Unified_Ideograph", "Ideographic"},
    140518: {"Unified_Ideograph", "Ideographic"},
    140519: {"Unified_Ideograph", "Ideographic"},
    140520: {"Unified_Ideograph", "Ideographic"},
    140521: {"Unified_Ideograph", "Ideographic"},
    140522: {"Unified_Ideograph", "Ideographic"},
    140523: {"Unified_Ideograph", "Ideographic"},
    140524: {"Unified_Ideograph", "Ideographic"},
    140525: {"Unified_Ideograph", "Ideographic"},
    140526: {"Unified_Ideograph", "Ideographic"},
    140527: {"Unified_Ideograph", "Ideographic"},
    140528: {"Unified_Ideograph", "Ideographic"},
    140529: {"Unified_Ideograph", "Ideographic"},
    140530: {"Unified_Ideograph", "Ideographic"},
    140531: {"Unified_Ideograph", "Ideographic"},
    140532: {"Unified_Ideograph", "Ideographic"},
    140533: {"Unified_Ideograph", "Ideographic"},
    140534: {"Unified_Ideograph", "Ideographic"},
    140535: {"Unified_Ideograph", "Ideographic"},
    140536: {"Unified_Ideograph", "Ideographic"},
    140537: {"Unified_Ideograph", "Ideographic"},
    140538: {"Unified_Ideograph", "Ideographic"},
    140539: {"Unified_Ideograph", "Ideographic"},
    140540: {"Unified_Ideograph", "Ideographic"},
    140541: {"Unified_Ideograph", "Ideographic"},
    140542: {"Unified_Ideograph", "Ideographic"},
    140543: {"Unified_Ideograph", "Ideographic"},
    140544: {"Unified_Ideograph", "Ideographic"},
    140545: {"Unified_Ideograph", "Ideographic"},
    140546: {"Unified_Ideograph", "Ideographic"},
    140547: {"Unified_Ideograph", "Ideographic"},
    140548: {"Unified_Ideograph", "Ideographic"},
    140549: {"Unified_Ideograph", "Ideographic"},
    140550: {"Unified_Ideograph", "Ideographic"},
    140551: {"Unified_Ideograph", "Ideographic"},
    140552: {"Unified_Ideograph", "Ideographic"},
    140553: {"Unified_Ideograph", "Ideographic"},
    140554: {"Unified_Ideograph", "Ideographic"},
    140555: {"Unified_Ideograph", "Ideographic"},
    140556: {"Unified_Ideograph", "Ideographic"},
    140557: {"Unified_Ideograph", "Ideographic"},
    140558: {"Unified_Ideograph", "Ideographic"},
    140559: {"Unified_Ideograph", "Ideographic"},
    140560: {"Unified_Ideograph", "Ideographic"},
    140561: {"Unified_Ideograph", "Ideographic"},
    140562: {"Unified_Ideograph", "Ideographic"},
    140563: {"Unified_Ideograph", "Ideographic"},
    140564: {"Unified_Ideograph", "Ideographic"},
    140565: {"Unified_Ideograph", "Ideographic"},
    140566: {"Unified_Ideograph", "Ideographic"},
    140567: {"Unified_Ideograph", "Ideographic"},
    140568: {"Unified_Ideograph", "Ideographic"},
    140569: {"Unified_Ideograph", "Ideographic"},
    140570: {"Unified_Ideograph", "Ideographic"},
    140571: {"Unified_Ideograph", "Ideographic"},
    140572: {"Unified_Ideograph", "Ideographic"},
    140573: {"Unified_Ideograph", "Ideographic"},
    140574: {"Unified_Ideograph", "Ideographic"},
    140575: {"Unified_Ideograph", "Ideographic"},
    140576: {"Unified_Ideograph", "Ideographic"},
    140577: {"Unified_Ideograph", "Ideographic"},
    140578: {"Unified_Ideograph", "Ideographic"},
    140579: {"Unified_Ideograph", "Ideographic"},
    140580: {"Unified_Ideograph", "Ideographic"},
    140581: {"Unified_Ideograph", "Ideographic"},
    140582: {"Unified_Ideograph", "Ideographic"},
    140583: {"Unified_Ideograph", "Ideographic"},
    140584: {"Unified_Ideograph", "Ideographic"},
    140585: {"Unified_Ideograph", "Ideographic"},
    140586: {"Unified_Ideograph", "Ideographic"},
    140587: {"Unified_Ideograph", "Ideographic"},
    140588: {"Unified_Ideograph", "Ideographic"},
    140589: {"Unified_Ideograph", "Ideographic"},
    140590: {"Unified_Ideograph", "Ideographic"},
    140591: {"Unified_Ideograph", "Ideographic"},
    140592: {"Unified_Ideograph", "Ideographic"},
    140593: {"Unified_Ideograph", "Ideographic"},
    140594: {"Unified_Ideograph", "Ideographic"},
    140595: {"Unified_Ideograph", "Ideographic"},
    140596: {"Unified_Ideograph", "Ideographic"},
    140597: {"Unified_Ideograph", "Ideographic"},
    140598: {"Unified_Ideograph", "Ideographic"},
    140599: {"Unified_Ideograph", "Ideographic"},
    140600: {"Unified_Ideograph", "Ideographic"},
    140601: {"Unified_Ideograph", "Ideographic"},
    140602: {"Unified_Ideograph", "Ideographic"},
    140603: {"Unified_Ideograph", "Ideographic"},
    140604: {"Unified_Ideograph", "Ideographic"},
    140605: {"Unified_Ideograph", "Ideographic"},
    140606: {"Unified_Ideograph", "Ideographic"},
    140607: {"Unified_Ideograph", "Ideographic"},
    140608: {"Unified_Ideograph", "Ideographic"},
    140609: {"Unified_Ideograph", "Ideographic"},
    140610: {"Unified_Ideograph", "Ideographic"},
    140611: {"Unified_Ideograph", "Ideographic"},
    140612: {"Unified_Ideograph", "Ideographic"},
    140613: {"Unified_Ideograph", "Ideographic"},
    140614: {"Unified_Ideograph", "Ideographic"},
    140615: {"Unified_Ideograph", "Ideographic"},
    140616: {"Unified_Ideograph", "Ideographic"},
    140617: {"Unified_Ideograph", "Ideographic"},
    140618: {"Unified_Ideograph", "Ideographic"},
    140619: {"Unified_Ideograph", "Ideographic"},
    140620: {"Unified_Ideograph", "Ideographic"},
    140621: {"Unified_Ideograph", "Ideographic"},
    140622: {"Unified_Ideograph", "Ideographic"},
    140623: {"Unified_Ideograph", "Ideographic"},
    140624: {"Unified_Ideograph", "Ideographic"},
    140625: {"Unified_Ideograph", "Ideographic"},
    140626: {"Unified_Ideograph", "Ideographic"},
    140627: {"Unified_Ideograph", "Ideographic"},
    140628: {"Unified_Ideograph", "Ideographic"},
    140629: {"Unified_Ideograph", "Ideographic"},
    140630: {"Unified_Ideograph", "Ideographic"},
    140631: {"Unified_Ideograph", "Ideographic"},
    140632: {"Unified_Ideograph", "Ideographic"},
    140633: {"Unified_Ideograph", "Ideographic"},
    140634: {"Unified_Ideograph", "Ideographic"},
    140635: {"Unified_Ideograph", "Ideographic"},
    140636: {"Unified_Ideograph", "Ideographic"},
    140637: {"Unified_Ideograph", "Ideographic"},
    140638: {"Unified_Ideograph", "Ideographic"},
    140639: {"Unified_Ideograph", "Ideographic"},
    140640: {"Unified_Ideograph", "Ideographic"},
    140641: {"Unified_Ideograph", "Ideographic"},
    140642: {"Unified_Ideograph", "Ideographic"},
    140643: {"Unified_Ideograph", "Ideographic"},
    140644: {"Unified_Ideograph", "Ideographic"},
    140645: {"Unified_Ideograph", "Ideographic"},
    140646: {"Unified_Ideograph", "Ideographic"},
    140647: {"Unified_Ideograph", "Ideographic"},
    140648: {"Unified_Ideograph", "Ideographic"},
    140649: {"Unified_Ideograph", "Ideographic"},
    140650: {"Unified_Ideograph", "Ideographic"},
    140651: {"Unified_Ideograph", "Ideographic"},
    140652: {"Unified_Ideograph", "Ideographic"},
    140653: {"Unified_Ideograph", "Ideographic"},
    140654: {"Unified_Ideograph", "Ideographic"},
    140655: {"Unified_Ideograph", "Ideographic"},
    140656: {"Unified_Ideograph", "Ideographic"},
    140657: {"Unified_Ideograph", "Ideographic"},
    140658: {"Unified_Ideograph", "Ideographic"},
    140659: {"Unified_Ideograph", "Ideographic"},
    140660: {"Unified_Ideograph", "Ideographic"},
    140661: {"Unified_Ideograph", "Ideographic"},
    140662: {"Unified_Ideograph", "Ideographic"},
    140663: {"Unified_Ideograph", "Ideographic"},
    140664: {"Unified_Ideograph", "Ideographic"},
    140665: {"Unified_Ideograph", "Ideographic"},
    140666: {"Unified_Ideograph", "Ideographic"},
    140667: {"Unified_Ideograph", "Ideographic"},
    140668: {"Unified_Ideograph", "Ideographic"},
    140669: {"Unified_Ideograph", "Ideographic"},
    140670: {"Unified_Ideograph", "Ideographic"},
    140671: {"Unified_Ideograph", "Ideographic"},
    140672: {"Unified_Ideograph", "Ideographic"},
    140673: {"Unified_Ideograph", "Ideographic"},
    140674: {"Unified_Ideograph", "Ideographic"},
    140675: {"Unified_Ideograph", "Ideographic"},
    140676: {"Unified_Ideograph", "Ideographic"},
    140677: {"Unified_Ideograph", "Ideographic"},
    140678: {"Unified_Ideograph", "Ideographic"},
    140679: {"Unified_Ideograph", "Ideographic"},
    140680: {"Unified_Ideograph", "Ideographic"},
    140681: {"Unified_Ideograph", "Ideographic"},
    140682: {"Unified_Ideograph", "Ideographic"},
    140683: {"Unified_Ideograph", "Ideographic"},
    140684: {"Unified_Ideograph", "Ideographic"},
    140685: {"Unified_Ideograph", "Ideographic"},
    140686: {"Unified_Ideograph", "Ideographic"},
    140687: {"Unified_Ideograph", "Ideographic"},
    140688: {"Unified_Ideograph", "Ideographic"},
    140689: {"Unified_Ideograph", "Ideographic"},
    140690: {"Unified_Ideograph", "Ideographic"},
    140691: {"Unified_Ideograph", "Ideographic"},
    140692: {"Unified_Ideograph", "Ideographic"},
    140693: {"Unified_Ideograph", "Ideographic"},
    140694: {"Unified_Ideograph", "Ideographic"},
    140695: {"Unified_Ideograph", "Ideographic"},
    140696: {"Unified_Ideograph", "Ideographic"},
    140697: {"Unified_Ideograph", "Ideographic"},
    140698: {"Unified_Ideograph", "Ideographic"},
    140699: {"Unified_Ideograph", "Ideographic"},
    140700: {"Unified_Ideograph", "Ideographic"},
    140701: {"Unified_Ideograph", "Ideographic"},
    140702: {"Unified_Ideograph", "Ideographic"},
    140703: {"Unified_Ideograph", "Ideographic"},
    140704: {"Unified_Ideograph", "Ideographic"},
    140705: {"Unified_Ideograph", "Ideographic"},
    140706: {"Unified_Ideograph", "Ideographic"},
    140707: {"Unified_Ideograph", "Ideographic"},
    140708: {"Unified_Ideograph", "Ideographic"},
    140709: {"Unified_Ideograph", "Ideographic"},
    140710: {"Unified_Ideograph", "Ideographic"},
    140711: {"Unified_Ideograph", "Ideographic"},
    140712: {"Unified_Ideograph", "Ideographic"},
    140713: {"Unified_Ideograph", "Ideographic"},
    140714: {"Unified_Ideograph", "Ideographic"},
    140715: {"Unified_Ideograph", "Ideographic"},
    140716: {"Unified_Ideograph", "Ideographic"},
    140717: {"Unified_Ideograph", "Ideographic"},
    140718: {"Unified_Ideograph", "Ideographic"},
    140719: {"Unified_Ideograph", "Ideographic"},
    140720: {"Unified_Ideograph", "Ideographic"},
    140721: {"Unified_Ideograph", "Ideographic"},
    140722: {"Unified_Ideograph", "Ideographic"},
    140723: {"Unified_Ideograph", "Ideographic"},
    140724: {"Unified_Ideograph", "Ideographic"},
    140725: {"Unified_Ideograph", "Ideographic"},
    140726: {"Unified_Ideograph", "Ideographic"},
    140727: {"Unified_Ideograph", "Ideographic"},
    140728: {"Unified_Ideograph", "Ideographic"},
    140729: {"Unified_Ideograph", "Ideographic"},
    140730: {"Unified_Ideograph", "Ideographic"},
    140731: {"Unified_Ideograph", "Ideographic"},
    140732: {"Unified_Ideograph", "Ideographic"},
    140733: {"Unified_Ideograph", "Ideographic"},
    140734: {"Unified_Ideograph", "Ideographic"},
    140735: {"Unified_Ideograph", "Ideographic"},
    140736: {"Unified_Ideograph", "Ideographic"},
    140737: {"Unified_Ideograph", "Ideographic"},
    140738: {"Unified_Ideograph", "Ideographic"},
    140739: {"Unified_Ideograph", "Ideographic"},
    140740: {"Unified_Ideograph", "Ideographic"},
    140741: {"Unified_Ideograph", "Ideographic"},
    140742: {"Unified_Ideograph", "Ideographic"},
    140743: {"Unified_Ideograph", "Ideographic"},
    140744: {"Unified_Ideograph", "Ideographic"},
    140745: {"Unified_Ideograph", "Ideographic"},
    140746: {"Unified_Ideograph", "Ideographic"},
    140747: {"Unified_Ideograph", "Ideographic"},
    140748: {"Unified_Ideograph", "Ideographic"},
    140749: {"Unified_Ideograph", "Ideographic"},
    140750: {"Unified_Ideograph", "Ideographic"},
    140751: {"Unified_Ideograph", "Ideographic"},
    140752: {"Unified_Ideograph", "Ideographic"},
    140753: {"Unified_Ideograph", "Ideographic"},
    140754: {"Unified_Ideograph", "Ideographic"},
    140755: {"Unified_Ideograph", "Ideographic"},
    140756: {"Unified_Ideograph", "Ideographic"},
    140757: {"Unified_Ideograph", "Ideographic"},
    140758: {"Unified_Ideograph", "Ideographic"},
    140759: {"Unified_Ideograph", "Ideographic"},
    140760: {"Unified_Ideograph", "Ideographic"},
    140761: {"Unified_Ideograph", "Ideographic"},
    140762: {"Unified_Ideograph", "Ideographic"},
    140763: {"Unified_Ideograph", "Ideographic"},
    140764: {"Unified_Ideograph", "Ideographic"},
    140765: {"Unified_Ideograph", "Ideographic"},
    140766: {"Unified_Ideograph", "Ideographic"},
    140767: {"Unified_Ideograph", "Ideographic"},
    140768: {"Unified_Ideograph", "Ideographic"},
    140769: {"Unified_Ideograph", "Ideographic"},
    140770: {"Unified_Ideograph", "Ideographic"},
    140771: {"Unified_Ideograph", "Ideographic"},
    140772: {"Unified_Ideograph", "Ideographic"},
    140773: {"Unified_Ideograph", "Ideographic"},
    140774: {"Unified_Ideograph", "Ideographic"},
    140775: {"Unified_Ideograph", "Ideographic"},
    140776: {"Unified_Ideograph", "Ideographic"},
    140777: {"Unified_Ideograph", "Ideographic"},
    140778: {"Unified_Ideograph", "Ideographic"},
    140779: {"Unified_Ideograph", "Ideographic"},
    140780: {"Unified_Ideograph", "Ideographic"},
    140781: {"Unified_Ideograph", "Ideographic"},
    140782: {"Unified_Ideograph", "Ideographic"},
    140783: {"Unified_Ideograph", "Ideographic"},
    140784: {"Unified_Ideograph", "Ideographic"},
    140785: {"Unified_Ideograph", "Ideographic"},
    140786: {"Unified_Ideograph", "Ideographic"},
    140787: {"Unified_Ideograph", "Ideographic"},
    140788: {"Unified_Ideograph", "Ideographic"},
    140789: {"Unified_Ideograph", "Ideographic"},
    140790: {"Unified_Ideograph", "Ideographic"},
    140791: {"Unified_Ideograph", "Ideographic"},
    140792: {"Unified_Ideograph", "Ideographic"},
    140793: {"Unified_Ideograph", "Ideographic"},
    140794: {"Unified_Ideograph", "Ideographic"},
    140795: {"Unified_Ideograph", "Ideographic"},
    140796: {"Unified_Ideograph", "Ideographic"},
    140797: {"Unified_Ideograph", "Ideographic"},
    140798: {"Unified_Ideograph", "Ideographic"},
    140799: {"Unified_Ideograph", "Ideographic"},
    140800: {"Unified_Ideograph", "Ideographic"},
    140801: {"Unified_Ideograph", "Ideographic"},
    140802: {"Unified_Ideograph", "Ideographic"},
    140803: {"Unified_Ideograph", "Ideographic"},
    140804: {"Unified_Ideograph", "Ideographic"},
    140805: {"Unified_Ideograph", "Ideographic"},
    140806: {"Unified_Ideograph", "Ideographic"},
    140807: {"Unified_Ideograph", "Ideographic"},
    140808: {"Unified_Ideograph", "Ideographic"},
    140809: {"Unified_Ideograph", "Ideographic"},
    140810: {"Unified_Ideograph", "Ideographic"},
    140811: {"Unified_Ideograph", "Ideographic"},
    140812: {"Unified_Ideograph", "Ideographic"},
    140813: {"Unified_Ideograph", "Ideographic"},
    140814: {"Unified_Ideograph", "Ideographic"},
    140815: {"Unified_Ideograph", "Ideographic"},
    140816: {"Unified_Ideograph", "Ideographic"},
    140817: {"Unified_Ideograph", "Ideographic"},
    140818: {"Unified_Ideograph", "Ideographic"},
    140819: {"Unified_Ideograph", "Ideographic"},
    140820: {"Unified_Ideograph", "Ideographic"},
    140821: {"Unified_Ideograph", "Ideographic"},
    140822: {"Unified_Ideograph", "Ideographic"},
    140823: {"Unified_Ideograph", "Ideographic"},
    140824: {"Unified_Ideograph", "Ideographic"},
    140825: {"Unified_Ideograph", "Ideographic"},
    140826: {"Unified_Ideograph", "Ideographic"},
    140827: {"Unified_Ideograph", "Ideographic"},
    140828: {"Unified_Ideograph", "Ideographic"},
    140829: {"Unified_Ideograph", "Ideographic"},
    140830: {"Unified_Ideograph", "Ideographic"},
    140831: {"Unified_Ideograph", "Ideographic"},
    140832: {"Unified_Ideograph", "Ideographic"},
    140833: {"Unified_Ideograph", "Ideographic"},
    140834: {"Unified_Ideograph", "Ideographic"},
    140835: {"Unified_Ideograph", "Ideographic"},
    140836: {"Unified_Ideograph", "Ideographic"},
    140837: {"Unified_Ideograph", "Ideographic"},
    140838: {"Unified_Ideograph", "Ideographic"},
    140839: {"Unified_Ideograph", "Ideographic"},
    140840: {"Unified_Ideograph", "Ideographic"},
    140841: {"Unified_Ideograph", "Ideographic"},
    140842: {"Unified_Ideograph", "Ideographic"},
    140843: {"Unified_Ideograph", "Ideographic"},
    140844: {"Unified_Ideograph", "Ideographic"},
    140845: {"Unified_Ideograph", "Ideographic"},
    140846: {"Unified_Ideograph", "Ideographic"},
    140847: {"Unified_Ideograph", "Ideographic"},
    140848: {"Unified_Ideograph", "Ideographic"},
    140849: {"Unified_Ideograph", "Ideographic"},
    140850: {"Unified_Ideograph", "Ideographic"},
    140851: {"Unified_Ideograph", "Ideographic"},
    140852: {"Unified_Ideograph", "Ideographic"},
    140853: {"Unified_Ideograph", "Ideographic"},
    140854: {"Unified_Ideograph", "Ideographic"},
    140855: {"Unified_Ideograph", "Ideographic"},
    140856: {"Unified_Ideograph", "Ideographic"},
    140857: {"Unified_Ideograph", "Ideographic"},
    140858: {"Unified_Ideograph", "Ideographic"},
    140859: {"Unified_Ideograph", "Ideographic"},
    140860: {"Unified_Ideograph", "Ideographic"},
    140861: {"Unified_Ideograph", "Ideographic"},
    140862: {"Unified_Ideograph", "Ideographic"},
    140863: {"Unified_Ideograph", "Ideographic"},
    140864: {"Unified_Ideograph", "Ideographic"},
    140865: {"Unified_Ideograph", "Ideographic"},
    140866: {"Unified_Ideograph", "Ideographic"},
    140867: {"Unified_Ideograph", "Ideographic"},
    140868: {"Unified_Ideograph", "Ideographic"},
    140869: {"Unified_Ideograph", "Ideographic"},
    140870: {"Unified_Ideograph", "Ideographic"},
    140871: {"Unified_Ideograph", "Ideographic"},
    140872: {"Unified_Ideograph", "Ideographic"},
    140873: {"Unified_Ideograph", "Ideographic"},
    140874: {"Unified_Ideograph", "Ideographic"},
    140875: {"Unified_Ideograph", "Ideographic"},
    140876: {"Unified_Ideograph", "Ideographic"},
    140877: {"Unified_Ideograph", "Ideographic"},
    140878: {"Unified_Ideograph", "Ideographic"},
    140879: {"Unified_Ideograph", "Ideographic"},
    140880: {"Unified_Ideograph", "Ideographic"},
    140881: {"Unified_Ideograph", "Ideographic"},
    140882: {"Unified_Ideograph", "Ideographic"},
    140883: {"Unified_Ideograph", "Ideographic"},
    140884: {"Unified_Ideograph", "Ideographic"},
    140885: {"Unified_Ideograph", "Ideographic"},
    140886: {"Unified_Ideograph", "Ideographic"},
    140887: {"Unified_Ideograph", "Ideographic"},
    140888: {"Unified_Ideograph", "Ideographic"},
    140889: {"Unified_Ideograph", "Ideographic"},
    140890: {"Unified_Ideograph", "Ideographic"},
    140891: {"Unified_Ideograph", "Ideographic"},
    140892: {"Unified_Ideograph", "Ideographic"},
    140893: {"Unified_Ideograph", "Ideographic"},
    140894: {"Unified_Ideograph", "Ideographic"},
    140895: {"Unified_Ideograph", "Ideographic"},
    140896: {"Unified_Ideograph", "Ideographic"},
    140897: {"Unified_Ideograph", "Ideographic"},
    140898: {"Unified_Ideograph", "Ideographic"},
    140899: {"Unified_Ideograph", "Ideographic"},
    140900: {"Unified_Ideograph", "Ideographic"},
    140901: {"Unified_Ideograph", "Ideographic"},
    140902: {"Unified_Ideograph", "Ideographic"},
    140903: {"Unified_Ideograph", "Ideographic"},
    140904: {"Unified_Ideograph", "Ideographic"},
    140905: {"Unified_Ideograph", "Ideographic"},
    140906: {"Unified_Ideograph", "Ideographic"},
    140907: {"Unified_Ideograph", "Ideographic"},
    140908: {"Unified_Ideograph", "Ideographic"},
    140909: {"Unified_Ideograph", "Ideographic"},
    140910: {"Unified_Ideograph", "Ideographic"},
    140911: {"Unified_Ideograph", "Ideographic"},
    140912: {"Unified_Ideograph", "Ideographic"},
    140913: {"Unified_Ideograph", "Ideographic"},
    140914: {"Unified_Ideograph", "Ideographic"},
    140915: {"Unified_Ideograph", "Ideographic"},
    140916: {"Unified_Ideograph", "Ideographic"},
    140917: {"Unified_Ideograph", "Ideographic"},
    140918: {"Unified_Ideograph", "Ideographic"},
    140919: {"Unified_Ideograph", "Ideographic"},
    140920: {"Unified_Ideograph", "Ideographic"},
    140921: {"Unified_Ideograph", "Ideographic"},
    140922: {"Unified_Ideograph", "Ideographic"},
    140923: {"Unified_Ideograph", "Ideographic"},
    140924: {"Unified_Ideograph", "Ideographic"},
    140925: {"Unified_Ideograph", "Ideographic"},
    140926: {"Unified_Ideograph", "Ideographic"},
    140927: {"Unified_Ideograph", "Ideographic"},
    140928: {"Unified_Ideograph", "Ideographic"},
    140929: {"Unified_Ideograph", "Ideographic"},
    140930: {"Unified_Ideograph", "Ideographic"},
    140931: {"Unified_Ideograph", "Ideographic"},
    140932: {"Unified_Ideograph", "Ideographic"},
    140933: {"Unified_Ideograph", "Ideographic"},
    140934: {"Unified_Ideograph", "Ideographic"},
    140935: {"Unified_Ideograph", "Ideographic"},
    140936: {"Unified_Ideograph", "Ideographic"},
    140937: {"Unified_Ideograph", "Ideographic"},
    140938: {"Unified_Ideograph", "Ideographic"},
    140939: {"Unified_Ideograph", "Ideographic"},
    140940: {"Unified_Ideograph", "Ideographic"},
    140941: {"Unified_Ideograph", "Ideographic"},
    140942: {"Unified_Ideograph", "Ideographic"},
    140943: {"Unified_Ideograph", "Ideographic"},
    140944: {"Unified_Ideograph", "Ideographic"},
    140945: {"Unified_Ideograph", "Ideographic"},
    140946: {"Unified_Ideograph", "Ideographic"},
    140947: {"Unified_Ideograph", "Ideographic"},
    140948: {"Unified_Ideograph", "Ideographic"},
    140949: {"Unified_Ideograph", "Ideographic"},
    140950: {"Unified_Ideograph", "Ideographic"},
    140951: {"Unified_Ideograph", "Ideographic"},
    140952: {"Unified_Ideograph", "Ideographic"},
    140953: {"Unified_Ideograph", "Ideographic"},
    140954: {"Unified_Ideograph", "Ideographic"},
    140955: {"Unified_Ideograph", "Ideographic"},
    140956: {"Unified_Ideograph", "Ideographic"},
    140957: {"Unified_Ideograph", "Ideographic"},
    140958: {"Unified_Ideograph", "Ideographic"},
    140959: {"Unified_Ideograph", "Ideographic"},
    140960: {"Unified_Ideograph", "Ideographic"},
    140961: {"Unified_Ideograph", "Ideographic"},
    140962: {"Unified_Ideograph", "Ideographic"},
    140963: {"Unified_Ideograph", "Ideographic"},
    140964: {"Unified_Ideograph", "Ideographic"},
    140965: {"Unified_Ideograph", "Ideographic"},
    140966: {"Unified_Ideograph", "Ideographic"},
    140967: {"Unified_Ideograph", "Ideographic"},
    140968: {"Unified_Ideograph", "Ideographic"},
    140969: {"Unified_Ideograph", "Ideographic"},
    140970: {"Unified_Ideograph", "Ideographic"},
    140971: {"Unified_Ideograph", "Ideographic"},
    140972: {"Unified_Ideograph", "Ideographic"},
    140973: {"Unified_Ideograph", "Ideographic"},
    140974: {"Unified_Ideograph", "Ideographic"},
    140975: {"Unified_Ideograph", "Ideographic"},
    140976: {"Unified_Ideograph", "Ideographic"},
    140977: {"Unified_Ideograph", "Ideographic"},
    140978: {"Unified_Ideograph", "Ideographic"},
    140979: {"Unified_Ideograph", "Ideographic"},
    140980: {"Unified_Ideograph", "Ideographic"},
    140981: {"Unified_Ideograph", "Ideographic"},
    140982: {"Unified_Ideograph", "Ideographic"},
    140983: {"Unified_Ideograph", "Ideographic"},
    140984: {"Unified_Ideograph", "Ideographic"},
    140985: {"Unified_Ideograph", "Ideographic"},
    140986: {"Unified_Ideograph", "Ideographic"},
    140987: {"Unified_Ideograph", "Ideographic"},
    140988: {"Unified_Ideograph", "Ideographic"},
    140989: {"Unified_Ideograph", "Ideographic"},
    140990: {"Unified_Ideograph", "Ideographic"},
    140991: {"Unified_Ideograph", "Ideographic"},
    140992: {"Unified_Ideograph", "Ideographic"},
    140993: {"Unified_Ideograph", "Ideographic"},
    140994: {"Unified_Ideograph", "Ideographic"},
    140995: {"Unified_Ideograph", "Ideographic"},
    140996: {"Unified_Ideograph", "Ideographic"},
    140997: {"Unified_Ideograph", "Ideographic"},
    140998: {"Unified_Ideograph", "Ideographic"},
    140999: {"Unified_Ideograph", "Ideographic"},
    141000: {"Unified_Ideograph", "Ideographic"},
    141001: {"Unified_Ideograph", "Ideographic"},
    141002: {"Unified_Ideograph", "Ideographic"},
    141003: {"Unified_Ideograph", "Ideographic"},
    141004: {"Unified_Ideograph", "Ideographic"},
    141005: {"Unified_Ideograph", "Ideographic"},
    141006: {"Unified_Ideograph", "Ideographic"},
    141007: {"Unified_Ideograph", "Ideographic"},
    141008: {"Unified_Ideograph", "Ideographic"},
    141009: {"Unified_Ideograph", "Ideographic"},
    141010: {"Unified_Ideograph", "Ideographic"},
    141011: {"Unified_Ideograph", "Ideographic"},
    141012: {"Unified_Ideograph", "Ideographic"},
    141013: {"Unified_Ideograph", "Ideographic"},
    141014: {"Unified_Ideograph", "Ideographic"},
    141015: {"Unified_Ideograph", "Ideographic"},
    141016: {"Unified_Ideograph", "Ideographic"},
    141017: {"Unified_Ideograph", "Ideographic"},
    141018: {"Unified_Ideograph", "Ideographic"},
    141019: {"Unified_Ideograph", "Ideographic"},
    141020: {"Unified_Ideograph", "Ideographic"},
    141021: {"Unified_Ideograph", "Ideographic"},
    141022: {"Unified_Ideograph", "Ideographic"},
    141023: {"Unified_Ideograph", "Ideographic"},
    141024: {"Unified_Ideograph", "Ideographic"},
    141025: {"Unified_Ideograph", "Ideographic"},
    141026: {"Unified_Ideograph", "Ideographic"},
    141027: {"Unified_Ideograph", "Ideographic"},
    141028: {"Unified_Ideograph", "Ideographic"},
    141029: {"Unified_Ideograph", "Ideographic"},
    141030: {"Unified_Ideograph", "Ideographic"},
    141031: {"Unified_Ideograph", "Ideographic"},
    141032: {"Unified_Ideograph", "Ideographic"},
    141033: {"Unified_Ideograph", "Ideographic"},
    141034: {"Unified_Ideograph", "Ideographic"},
    141035: {"Unified_Ideograph", "Ideographic"},
    141036: {"Unified_Ideograph", "Ideographic"},
    141037: {"Unified_Ideograph", "Ideographic"},
    141038: {"Unified_Ideograph", "Ideographic"},
    141039: {"Unified_Ideograph", "Ideographic"},
    141040: {"Unified_Ideograph", "Ideographic"},
    141041: {"Unified_Ideograph", "Ideographic"},
    141042: {"Unified_Ideograph", "Ideographic"},
    141043: {"Unified_Ideograph", "Ideographic"},
    141044: {"Unified_Ideograph", "Ideographic"},
    141045: {"Unified_Ideograph", "Ideographic"},
    141046: {"Unified_Ideograph", "Ideographic"},
    141047: {"Unified_Ideograph", "Ideographic"},
    141048: {"Unified_Ideograph", "Ideographic"},
    141049: {"Unified_Ideograph", "Ideographic"},
    141050: {"Unified_Ideograph", "Ideographic"},
    141051: {"Unified_Ideograph", "Ideographic"},
    141052: {"Unified_Ideograph", "Ideographic"},
    141053: {"Unified_Ideograph", "Ideographic"},
    141054: {"Unified_Ideograph", "Ideographic"},
    141055: {"Unified_Ideograph", "Ideographic"},
    141056: {"Unified_Ideograph", "Ideographic"},
    141057: {"Unified_Ideograph", "Ideographic"},
    141058: {"Unified_Ideograph", "Ideographic"},
    141059: {"Unified_Ideograph", "Ideographic"},
    141060: {"Unified_Ideograph", "Ideographic"},
    141061: {"Unified_Ideograph", "Ideographic"},
    141062: {"Unified_Ideograph", "Ideographic"},
    141063: {"Unified_Ideograph", "Ideographic"},
    141064: {"Unified_Ideograph", "Ideographic"},
    141065: {"Unified_Ideograph", "Ideographic"},
    141066: {"Unified_Ideograph", "Ideographic"},
    141067: {"Unified_Ideograph", "Ideographic"},
    141068: {"Unified_Ideograph", "Ideographic"},
    141069: {"Unified_Ideograph", "Ideographic"},
    141070: {"Unified_Ideograph", "Ideographic"},
    141071: {"Unified_Ideograph", "Ideographic"},
    141072: {"Unified_Ideograph", "Ideographic"},
    141073: {"Unified_Ideograph", "Ideographic"},
    141074: {"Unified_Ideograph", "Ideographic"},
    141075: {"Unified_Ideograph", "Ideographic"},
    141076: {"Unified_Ideograph", "Ideographic"},
    141077: {"Unified_Ideograph", "Ideographic"},
    141078: {"Unified_Ideograph", "Ideographic"},
    141079: {"Unified_Ideograph", "Ideographic"},
    141080: {"Unified_Ideograph", "Ideographic"},
    141081: {"Unified_Ideograph", "Ideographic"},
    141082: {"Unified_Ideograph", "Ideographic"},
    141083: {"Unified_Ideograph", "Ideographic"},
    141084: {"Unified_Ideograph", "Ideographic"},
    141085: {"Unified_Ideograph", "Ideographic"},
    141086: {"Unified_Ideograph", "Ideographic"},
    141087: {"Unified_Ideograph", "Ideographic"},
    141088: {"Unified_Ideograph", "Ideographic"},
    141089: {"Unified_Ideograph", "Ideographic"},
    141090: {"Unified_Ideograph", "Ideographic"},
    141091: {"Unified_Ideograph", "Ideographic"},
    141092: {"Unified_Ideograph", "Ideographic"},
    141093: {"Unified_Ideograph", "Ideographic"},
    141094: {"Unified_Ideograph", "Ideographic"},
    141095: {"Unified_Ideograph", "Ideographic"},
    141096: {"Unified_Ideograph", "Ideographic"},
    141097: {"Unified_Ideograph", "Ideographic"},
    141098: {"Unified_Ideograph", "Ideographic"},
    141099: {"Unified_Ideograph", "Ideographic"},
    141100: {"Unified_Ideograph", "Ideographic"},
    141101: {"Unified_Ideograph", "Ideographic"},
    141102: {"Unified_Ideograph", "Ideographic"},
    141103: {"Unified_Ideograph", "Ideographic"},
    141104: {"Unified_Ideograph", "Ideographic"},
    141105: {"Unified_Ideograph", "Ideographic"},
    141106: {"Unified_Ideograph", "Ideographic"},
    141107: {"Unified_Ideograph", "Ideographic"},
    141108: {"Unified_Ideograph", "Ideographic"},
    141109: {"Unified_Ideograph", "Ideographic"},
    141110: {"Unified_Ideograph", "Ideographic"},
    141111: {"Unified_Ideograph", "Ideographic"},
    141112: {"Unified_Ideograph", "Ideographic"},
    141113: {"Unified_Ideograph", "Ideographic"},
    141114: {"Unified_Ideograph", "Ideographic"},
    141115: {"Unified_Ideograph", "Ideographic"},
    141116: {"Unified_Ideograph", "Ideographic"},
    141117: {"Unified_Ideograph", "Ideographic"},
    141118: {"Unified_Ideograph", "Ideographic"},
    141119: {"Unified_Ideograph", "Ideographic"},
    141120: {"Unified_Ideograph", "Ideographic"},
    141121: {"Unified_Ideograph", "Ideographic"},
    141122: {"Unified_Ideograph", "Ideographic"},
    141123: {"Unified_Ideograph", "Ideographic"},
    141124: {"Unified_Ideograph", "Ideographic"},
    141125: {"Unified_Ideograph", "Ideographic"},
    141126: {"Unified_Ideograph", "Ideographic"},
    141127: {"Unified_Ideograph", "Ideographic"},
    141128: {"Unified_Ideograph", "Ideographic"},
    141129: {"Unified_Ideograph", "Ideographic"},
    141130: {"Unified_Ideograph", "Ideographic"},
    141131: {"Unified_Ideograph", "Ideographic"},
    141132: {"Unified_Ideograph", "Ideographic"},
    141133: {"Unified_Ideograph", "Ideographic"},
    141134: {"Unified_Ideograph", "Ideographic"},
    141135: {"Unified_Ideograph", "Ideographic"},
    141136: {"Unified_Ideograph", "Ideographic"},
    141137: {"Unified_Ideograph", "Ideographic"},
    141138: {"Unified_Ideograph", "Ideographic"},
    141139: {"Unified_Ideograph", "Ideographic"},
    141140: {"Unified_Ideograph", "Ideographic"},
    141141: {"Unified_Ideograph", "Ideographic"},
    141142: {"Unified_Ideograph", "Ideographic"},
    141143: {"Unified_Ideograph", "Ideographic"},
    141144: {"Unified_Ideograph", "Ideographic"},
    141145: {"Unified_Ideograph", "Ideographic"},
    141146: {"Unified_Ideograph", "Ideographic"},
    141147: {"Unified_Ideograph", "Ideographic"},
    141148: {"Unified_Ideograph", "Ideographic"},
    141149: {"Unified_Ideograph", "Ideographic"},
    141150: {"Unified_Ideograph", "Ideographic"},
    141151: {"Unified_Ideograph", "Ideographic"},
    141152: {"Unified_Ideograph", "Ideographic"},
    141153: {"Unified_Ideograph", "Ideographic"},
    141154: {"Unified_Ideograph", "Ideographic"},
    141155: {"Unified_Ideograph", "Ideographic"},
    141156: {"Unified_Ideograph", "Ideographic"},
    141157: {"Unified_Ideograph", "Ideographic"},
    141158: {"Unified_Ideograph", "Ideographic"},
    141159: {"Unified_Ideograph", "Ideographic"},
    141160: {"Unified_Ideograph", "Ideographic"},
    141161: {"Unified_Ideograph", "Ideographic"},
    141162: {"Unified_Ideograph", "Ideographic"},
    141163: {"Unified_Ideograph", "Ideographic"},
    141164: {"Unified_Ideograph", "Ideographic"},
    141165: {"Unified_Ideograph", "Ideographic"},
    141166: {"Unified_Ideograph", "Ideographic"},
    141167: {"Unified_Ideograph", "Ideographic"},
    141168: {"Unified_Ideograph", "Ideographic"},
    141169: {"Unified_Ideograph", "Ideographic"},
    141170: {"Unified_Ideograph", "Ideographic"},
    141171: {"Unified_Ideograph", "Ideographic"},
    141172: {"Unified_Ideograph", "Ideographic"},
    141173: {"Unified_Ideograph", "Ideographic"},
    141174: {"Unified_Ideograph", "Ideographic"},
    141175: {"Unified_Ideograph", "Ideographic"},
    141176: {"Unified_Ideograph", "Ideographic"},
    141177: {"Unified_Ideograph", "Ideographic"},
    141178: {"Unified_Ideograph", "Ideographic"},
    141179: {"Unified_Ideograph", "Ideographic"},
    141180: {"Unified_Ideograph", "Ideographic"},
    141181: {"Unified_Ideograph", "Ideographic"},
    141182: {"Unified_Ideograph", "Ideographic"},
    141183: {"Unified_Ideograph", "Ideographic"},
    141184: {"Unified_Ideograph", "Ideographic"},
    141185: {"Unified_Ideograph", "Ideographic"},
    141186: {"Unified_Ideograph", "Ideographic"},
    141187: {"Unified_Ideograph", "Ideographic"},
    141188: {"Unified_Ideograph", "Ideographic"},
    141189: {"Unified_Ideograph", "Ideographic"},
    141190: {"Unified_Ideograph", "Ideographic"},
    141191: {"Unified_Ideograph", "Ideographic"},
    141192: {"Unified_Ideograph", "Ideographic"},
    141193: {"Unified_Ideograph", "Ideographic"},
    141194: {"Unified_Ideograph", "Ideographic"},
    141195: {"Unified_Ideograph", "Ideographic"},
    141196: {"Unified_Ideograph", "Ideographic"},
    141197: {"Unified_Ideograph", "Ideographic"},
    141198: {"Unified_Ideograph", "Ideographic"},
    141199: {"Unified_Ideograph", "Ideographic"},
    141200: {"Unified_Ideograph", "Ideographic"},
    141201: {"Unified_Ideograph", "Ideographic"},
    141202: {"Unified_Ideograph", "Ideographic"},
    141203: {"Unified_Ideograph", "Ideographic"},
    141204: {"Unified_Ideograph", "Ideographic"},
    141205: {"Unified_Ideograph", "Ideographic"},
    141206: {"Unified_Ideograph", "Ideographic"},
    141207: {"Unified_Ideograph", "Ideographic"},
    141208: {"Unified_Ideograph", "Ideographic"},
    141209: {"Unified_Ideograph", "Ideographic"},
    141210: {"Unified_Ideograph", "Ideographic"},
    141211: {"Unified_Ideograph", "Ideographic"},
    141212: {"Unified_Ideograph", "Ideographic"},
    141213: {"Unified_Ideograph", "Ideographic"},
    141214: {"Unified_Ideograph", "Ideographic"},
    141215: {"Unified_Ideograph", "Ideographic"},
    141216: {"Unified_Ideograph", "Ideographic"},
    141217: {"Unified_Ideograph", "Ideographic"},
    141218: {"Unified_Ideograph", "Ideographic"},
    141219: {"Unified_Ideograph", "Ideographic"},
    141220: {"Unified_Ideograph", "Ideographic"},
    141221: {"Unified_Ideograph", "Ideographic"},
    141222: {"Unified_Ideograph", "Ideographic"},
    141223: {"Unified_Ideograph", "Ideographic"},
    141224: {"Unified_Ideograph", "Ideographic"},
    141225: {"Unified_Ideograph", "Ideographic"},
    141226: {"Unified_Ideograph", "Ideographic"},
    141227: {"Unified_Ideograph", "Ideographic"},
    141228: {"Unified_Ideograph", "Ideographic"},
    141229: {"Unified_Ideograph", "Ideographic"},
    141230: {"Unified_Ideograph", "Ideographic"},
    141231: {"Unified_Ideograph", "Ideographic"},
    141232: {"Unified_Ideograph", "Ideographic"},
    141233: {"Unified_Ideograph", "Ideographic"},
    141234: {"Unified_Ideograph", "Ideographic"},
    141235: {"Unified_Ideograph", "Ideographic"},
    141236: {"Unified_Ideograph", "Ideographic"},
    141237: {"Unified_Ideograph", "Ideographic"},
    141238: {"Unified_Ideograph", "Ideographic"},
    141239: {"Unified_Ideograph", "Ideographic"},
    141240: {"Unified_Ideograph", "Ideographic"},
    141241: {"Unified_Ideograph", "Ideographic"},
    141242: {"Unified_Ideograph", "Ideographic"},
    141243: {"Unified_Ideograph", "Ideographic"},
    141244: {"Unified_Ideograph", "Ideographic"},
    141245: {"Unified_Ideograph", "Ideographic"},
    141246: {"Unified_Ideograph", "Ideographic"},
    141247: {"Unified_Ideograph", "Ideographic"},
    141248: {"Unified_Ideograph", "Ideographic"},
    141249: {"Unified_Ideograph", "Ideographic"},
    141250: {"Unified_Ideograph", "Ideographic"},
    141251: {"Unified_Ideograph", "Ideographic"},
    141252: {"Unified_Ideograph", "Ideographic"},
    141253: {"Unified_Ideograph", "Ideographic"},
    141254: {"Unified_Ideograph", "Ideographic"},
    141255: {"Unified_Ideograph", "Ideographic"},
    141256: {"Unified_Ideograph", "Ideographic"},
    141257: {"Unified_Ideograph", "Ideographic"},
    141258: {"Unified_Ideograph", "Ideographic"},
    141259: {"Unified_Ideograph", "Ideographic"},
    141260: {"Unified_Ideograph", "Ideographic"},
    141261: {"Unified_Ideograph", "Ideographic"},
    141262: {"Unified_Ideograph", "Ideographic"},
    141263: {"Unified_Ideograph", "Ideographic"},
    141264: {"Unified_Ideograph", "Ideographic"},
    141265: {"Unified_Ideograph", "Ideographic"},
    141266: {"Unified_Ideograph", "Ideographic"},
    141267: {"Unified_Ideograph", "Ideographic"},
    141268: {"Unified_Ideograph", "Ideographic"},
    141269: {"Unified_Ideograph", "Ideographic"},
    141270: {"Unified_Ideograph", "Ideographic"},
    141271: {"Unified_Ideograph", "Ideographic"},
    141272: {"Unified_Ideograph", "Ideographic"},
    141273: {"Unified_Ideograph", "Ideographic"},
    141274: {"Unified_Ideograph", "Ideographic"},
    141275: {"Unified_Ideograph", "Ideographic"},
    141276: {"Unified_Ideograph", "Ideographic"},
    141277: {"Unified_Ideograph", "Ideographic"},
    141278: {"Unified_Ideograph", "Ideographic"},
    141279: {"Unified_Ideograph", "Ideographic"},
    141280: {"Unified_Ideograph", "Ideographic"},
    141281: {"Unified_Ideograph", "Ideographic"},
    141282: {"Unified_Ideograph", "Ideographic"},
    141283: {"Unified_Ideograph", "Ideographic"},
    141284: {"Unified_Ideograph", "Ideographic"},
    141285: {"Unified_Ideograph", "Ideographic"},
    141286: {"Unified_Ideograph", "Ideographic"},
    141287: {"Unified_Ideograph", "Ideographic"},
    141288: {"Unified_Ideograph", "Ideographic"},
    141289: {"Unified_Ideograph", "Ideographic"},
    141290: {"Unified_Ideograph", "Ideographic"},
    141291: {"Unified_Ideograph", "Ideographic"},
    141292: {"Unified_Ideograph", "Ideographic"},
    141293: {"Unified_Ideograph", "Ideographic"},
    141294: {"Unified_Ideograph", "Ideographic"},
    141295: {"Unified_Ideograph", "Ideographic"},
    141296: {"Unified_Ideograph", "Ideographic"},
    141297: {"Unified_Ideograph", "Ideographic"},
    141298: {"Unified_Ideograph", "Ideographic"},
    141299: {"Unified_Ideograph", "Ideographic"},
    141300: {"Unified_Ideograph", "Ideographic"},
    141301: {"Unified_Ideograph", "Ideographic"},
    141302: {"Unified_Ideograph", "Ideographic"},
    141303: {"Unified_Ideograph", "Ideographic"},
    141304: {"Unified_Ideograph", "Ideographic"},
    141305: {"Unified_Ideograph", "Ideographic"},
    141306: {"Unified_Ideograph", "Ideographic"},
    141307: {"Unified_Ideograph", "Ideographic"},
    141308: {"Unified_Ideograph", "Ideographic"},
    141309: {"Unified_Ideograph", "Ideographic"},
    141310: {"Unified_Ideograph", "Ideographic"},
    141311: {"Unified_Ideograph", "Ideographic"},
    141312: {"Unified_Ideograph", "Ideographic"},
    141313: {"Unified_Ideograph", "Ideographic"},
    141314: {"Unified_Ideograph", "Ideographic"},
    141315: {"Unified_Ideograph", "Ideographic"},
    141316: {"Unified_Ideograph", "Ideographic"},
    141317: {"Unified_Ideograph", "Ideographic"},
    141318: {"Unified_Ideograph", "Ideographic"},
    141319: {"Unified_Ideograph", "Ideographic"},
    141320: {"Unified_Ideograph", "Ideographic"},
    141321: {"Unified_Ideograph", "Ideographic"},
    141322: {"Unified_Ideograph", "Ideographic"},
    141323: {"Unified_Ideograph", "Ideographic"},
    141324: {"Unified_Ideograph", "Ideographic"},
    141325: {"Unified_Ideograph", "Ideographic"},
    141326: {"Unified_Ideograph", "Ideographic"},
    141327: {"Unified_Ideograph", "Ideographic"},
    141328: {"Unified_Ideograph", "Ideographic"},
    141329: {"Unified_Ideograph", "Ideographic"},
    141330: {"Unified_Ideograph", "Ideographic"},
    141331: {"Unified_Ideograph", "Ideographic"},
    141332: {"Unified_Ideograph", "Ideographic"},
    141333: {"Unified_Ideograph", "Ideographic"},
    141334: {"Unified_Ideograph", "Ideographic"},
    141335: {"Unified_Ideograph", "Ideographic"},
    141336: {"Unified_Ideograph", "Ideographic"},
    141337: {"Unified_Ideograph", "Ideographic"},
    141338: {"Unified_Ideograph", "Ideographic"},
    141339: {"Unified_Ideograph", "Ideographic"},
    141340: {"Unified_Ideograph", "Ideographic"},
    141341: {"Unified_Ideograph", "Ideographic"},
    141342: {"Unified_Ideograph", "Ideographic"},
    141343: {"Unified_Ideograph", "Ideographic"},
    141344: {"Unified_Ideograph", "Ideographic"},
    141345: {"Unified_Ideograph", "Ideographic"},
    141346: {"Unified_Ideograph", "Ideographic"},
    141347: {"Unified_Ideograph", "Ideographic"},
    141348: {"Unified_Ideograph", "Ideographic"},
    141349: {"Unified_Ideograph", "Ideographic"},
    141350: {"Unified_Ideograph", "Ideographic"},
    141351: {"Unified_Ideograph", "Ideographic"},
    141352: {"Unified_Ideograph", "Ideographic"},
    141353: {"Unified_Ideograph", "Ideographic"},
    141354: {"Unified_Ideograph", "Ideographic"},
    141355: {"Unified_Ideograph", "Ideographic"},
    141356: {"Unified_Ideograph", "Ideographic"},
    141357: {"Unified_Ideograph", "Ideographic"},
    141358: {"Unified_Ideograph", "Ideographic"},
    141359: {"Unified_Ideograph", "Ideographic"},
    141360: {"Unified_Ideograph", "Ideographic"},
    141361: {"Unified_Ideograph", "Ideographic"},
    141362: {"Unified_Ideograph", "Ideographic"},
    141363: {"Unified_Ideograph", "Ideographic"},
    141364: {"Unified_Ideograph", "Ideographic"},
    141365: {"Unified_Ideograph", "Ideographic"},
    141366: {"Unified_Ideograph", "Ideographic"},
    141367: {"Unified_Ideograph", "Ideographic"},
    141368: {"Unified_Ideograph", "Ideographic"},
    141369: {"Unified_Ideograph", "Ideographic"},
    141370: {"Unified_Ideograph", "Ideographic"},
    141371: {"Unified_Ideograph", "Ideographic"},
    141372: {"Unified_Ideograph", "Ideographic"},
    141373: {"Unified_Ideograph", "Ideographic"},
    141374: {"Unified_Ideograph", "Ideographic"},
    141375: {"Unified_Ideograph", "Ideographic"},
    141376: {"Unified_Ideograph", "Ideographic"},
    141377: {"Unified_Ideograph", "Ideographic"},
    141378: {"Unified_Ideograph", "Ideographic"},
    141379: {"Unified_Ideograph", "Ideographic"},
    141380: {"Unified_Ideograph", "Ideographic"},
    141381: {"Unified_Ideograph", "Ideographic"},
    141382: {"Unified_Ideograph", "Ideographic"},
    141383: {"Unified_Ideograph", "Ideographic"},
    141384: {"Unified_Ideograph", "Ideographic"},
    141385: {"Unified_Ideograph", "Ideographic"},
    141386: {"Unified_Ideograph", "Ideographic"},
    141387: {"Unified_Ideograph", "Ideographic"},
    141388: {"Unified_Ideograph", "Ideographic"},
    141389: {"Unified_Ideograph", "Ideographic"},
    141390: {"Unified_Ideograph", "Ideographic"},
    141391: {"Unified_Ideograph", "Ideographic"},
    141392: {"Unified_Ideograph", "Ideographic"},
    141393: {"Unified_Ideograph", "Ideographic"},
    141394: {"Unified_Ideograph", "Ideographic"},
    141395: {"Unified_Ideograph", "Ideographic"},
    141396: {"Unified_Ideograph", "Ideographic"},
    141397: {"Unified_Ideograph", "Ideographic"},
    141398: {"Unified_Ideograph", "Ideographic"},
    141399: {"Unified_Ideograph", "Ideographic"},
    141400: {"Unified_Ideograph", "Ideographic"},
    141401: {"Unified_Ideograph", "Ideographic"},
    141402: {"Unified_Ideograph", "Ideographic"},
    141403: {"Unified_Ideograph", "Ideographic"},
    141404: {"Unified_Ideograph", "Ideographic"},
    141405: {"Unified_Ideograph", "Ideographic"},
    141406: {"Unified_Ideograph", "Ideographic"},
    141407: {"Unified_Ideograph", "Ideographic"},
    141408: {"Unified_Ideograph", "Ideographic"},
    141409: {"Unified_Ideograph", "Ideographic"},
    141410: {"Unified_Ideograph", "Ideographic"},
    141411: {"Unified_Ideograph", "Ideographic"},
    141412: {"Unified_Ideograph", "Ideographic"},
    141413: {"Unified_Ideograph", "Ideographic"},
    141414: {"Unified_Ideograph", "Ideographic"},
    141415: {"Unified_Ideograph", "Ideographic"},
    141416: {"Unified_Ideograph", "Ideographic"},
    141417: {"Unified_Ideograph", "Ideographic"},
    141418: {"Unified_Ideograph", "Ideographic"},
    141419: {"Unified_Ideograph", "Ideographic"},
    141420: {"Unified_Ideograph", "Ideographic"},
    141421: {"Unified_Ideograph", "Ideographic"},
    141422: {"Unified_Ideograph", "Ideographic"},
    141423: {"Unified_Ideograph", "Ideographic"},
    141424: {"Unified_Ideograph", "Ideographic"},
    141425: {"Unified_Ideograph", "Ideographic"},
    141426: {"Unified_Ideograph", "Ideographic"},
    141427: {"Unified_Ideograph", "Ideographic"},
    141428: {"Unified_Ideograph", "Ideographic"},
    141429: {"Unified_Ideograph", "Ideographic"},
    141430: {"Unified_Ideograph", "Ideographic"},
    141431: {"Unified_Ideograph", "Ideographic"},
    141432: {"Unified_Ideograph", "Ideographic"},
    141433: {"Unified_Ideograph", "Ideographic"},
    141434: {"Unified_Ideograph", "Ideographic"},
    141435: {"Unified_Ideograph", "Ideographic"},
    141436: {"Unified_Ideograph", "Ideographic"},
    141437: {"Unified_Ideograph", "Ideographic"},
    141438: {"Unified_Ideograph", "Ideographic"},
    141439: {"Unified_Ideograph", "Ideographic"},
    141440: {"Unified_Ideograph", "Ideographic"},
    141441: {"Unified_Ideograph", "Ideographic"},
    141442: {"Unified_Ideograph", "Ideographic"},
    141443: {"Unified_Ideograph", "Ideographic"},
    141444: {"Unified_Ideograph", "Ideographic"},
    141445: {"Unified_Ideograph", "Ideographic"},
    141446: {"Unified_Ideograph", "Ideographic"},
    141447: {"Unified_Ideograph", "Ideographic"},
    141448: {"Unified_Ideograph", "Ideographic"},
    141449: {"Unified_Ideograph", "Ideographic"},
    141450: {"Unified_Ideograph", "Ideographic"},
    141451: {"Unified_Ideograph", "Ideographic"},
    141452: {"Unified_Ideograph", "Ideographic"},
    141453: {"Unified_Ideograph", "Ideographic"},
    141454: {"Unified_Ideograph", "Ideographic"},
    141455: {"Unified_Ideograph", "Ideographic"},
    141456: {"Unified_Ideograph", "Ideographic"},
    141457: {"Unified_Ideograph", "Ideographic"},
    141458: {"Unified_Ideograph", "Ideographic"},
    141459: {"Unified_Ideograph", "Ideographic"},
    141460: {"Unified_Ideograph", "Ideographic"},
    141461: {"Unified_Ideograph", "Ideographic"},
    141462: {"Unified_Ideograph", "Ideographic"},
    141463: {"Unified_Ideograph", "Ideographic"},
    141464: {"Unified_Ideograph", "Ideographic"},
    141465: {"Unified_Ideograph", "Ideographic"},
    141466: {"Unified_Ideograph", "Ideographic"},
    141467: {"Unified_Ideograph", "Ideographic"},
    141468: {"Unified_Ideograph", "Ideographic"},
    141469: {"Unified_Ideograph", "Ideographic"},
    141470: {"Unified_Ideograph", "Ideographic"},
    141471: {"Unified_Ideograph", "Ideographic"},
    141472: {"Unified_Ideograph", "Ideographic"},
    141473: {"Unified_Ideograph", "Ideographic"},
    141474: {"Unified_Ideograph", "Ideographic"},
    141475: {"Unified_Ideograph", "Ideographic"},
    141476: {"Unified_Ideograph", "Ideographic"},
    141477: {"Unified_Ideograph", "Ideographic"},
    141478: {"Unified_Ideograph", "Ideographic"},
    141479: {"Unified_Ideograph", "Ideographic"},
    141480: {"Unified_Ideograph", "Ideographic"},
    141481: {"Unified_Ideograph", "Ideographic"},
    141482: {"Unified_Ideograph", "Ideographic"},
    141483: {"Unified_Ideograph", "Ideographic"},
    141484: {"Unified_Ideograph", "Ideographic"},
    141485: {"Unified_Ideograph", "Ideographic"},
    141486: {"Unified_Ideograph", "Ideographic"},
    141487: {"Unified_Ideograph", "Ideographic"},
    141488: {"Unified_Ideograph", "Ideographic"},
    141489: {"Unified_Ideograph", "Ideographic"},
    141490: {"Unified_Ideograph", "Ideographic"},
    141491: {"Unified_Ideograph", "Ideographic"},
    141492: {"Unified_Ideograph", "Ideographic"},
    141493: {"Unified_Ideograph", "Ideographic"},
    141494: {"Unified_Ideograph", "Ideographic"},
    141495: {"Unified_Ideograph", "Ideographic"},
    141496: {"Unified_Ideograph", "Ideographic"},
    141497: {"Unified_Ideograph", "Ideographic"},
    141498: {"Unified_Ideograph", "Ideographic"},
    141499: {"Unified_Ideograph", "Ideographic"},
    141500: {"Unified_Ideograph", "Ideographic"},
    141501: {"Unified_Ideograph", "Ideographic"},
    141502: {"Unified_Ideograph", "Ideographic"},
    141503: {"Unified_Ideograph", "Ideographic"},
    141504: {"Unified_Ideograph", "Ideographic"},
    141505: {"Unified_Ideograph", "Ideographic"},
    141506: {"Unified_Ideograph", "Ideographic"},
    141507: {"Unified_Ideograph", "Ideographic"},
    141508: {"Unified_Ideograph", "Ideographic"},
    141509: {"Unified_Ideograph", "Ideographic"},
    141510: {"Unified_Ideograph", "Ideographic"},
    141511: {"Unified_Ideograph", "Ideographic"},
    141512: {"Unified_Ideograph", "Ideographic"},
    141513: {"Unified_Ideograph", "Ideographic"},
    141514: {"Unified_Ideograph", "Ideographic"},
    141515: {"Unified_Ideograph", "Ideographic"},
    141516: {"Unified_Ideograph", "Ideographic"},
    141517: {"Unified_Ideograph", "Ideographic"},
    141518: {"Unified_Ideograph", "Ideographic"},
    141519: {"Unified_Ideograph", "Ideographic"},
    141520: {"Unified_Ideograph", "Ideographic"},
    141521: {"Unified_Ideograph", "Ideographic"},
    141522: {"Unified_Ideograph", "Ideographic"},
    141523: {"Unified_Ideograph", "Ideographic"},
    141524: {"Unified_Ideograph", "Ideographic"},
    141525: {"Unified_Ideograph", "Ideographic"},
    141526: {"Unified_Ideograph", "Ideographic"},
    141527: {"Unified_Ideograph", "Ideographic"},
    141528: {"Unified_Ideograph", "Ideographic"},
    141529: {"Unified_Ideograph", "Ideographic"},
    141530: {"Unified_Ideograph", "Ideographic"},
    141531: {"Unified_Ideograph", "Ideographic"},
    141532: {"Unified_Ideograph", "Ideographic"},
    141533: {"Unified_Ideograph", "Ideographic"},
    141534: {"Unified_Ideograph", "Ideographic"},
    141535: {"Unified_Ideograph", "Ideographic"},
    141536: {"Unified_Ideograph", "Ideographic"},
    141537: {"Unified_Ideograph", "Ideographic"},
    141538: {"Unified_Ideograph", "Ideographic"},
    141539: {"Unified_Ideograph", "Ideographic"},
    141540: {"Unified_Ideograph", "Ideographic"},
    141541: {"Unified_Ideograph", "Ideographic"},
    141542: {"Unified_Ideograph", "Ideographic"},
    141543: {"Unified_Ideograph", "Ideographic"},
    141544: {"Unified_Ideograph", "Ideographic"},
    141545: {"Unified_Ideograph", "Ideographic"},
    141546: {"Unified_Ideograph", "Ideographic"},
    141547: {"Unified_Ideograph", "Ideographic"},
    141548: {"Unified_Ideograph", "Ideographic"},
    141549: {"Unified_Ideograph", "Ideographic"},
    141550: {"Unified_Ideograph", "Ideographic"},
    141551: {"Unified_Ideograph", "Ideographic"},
    141552: {"Unified_Ideograph", "Ideographic"},
    141553: {"Unified_Ideograph", "Ideographic"},
    141554: {"Unified_Ideograph", "Ideographic"},
    141555: {"Unified_Ideograph", "Ideographic"},
    141556: {"Unified_Ideograph", "Ideographic"},
    141557: {"Unified_Ideograph", "Ideographic"},
    141558: {"Unified_Ideograph", "Ideographic"},
    141559: {"Unified_Ideograph", "Ideographic"},
    141560: {"Unified_Ideograph", "Ideographic"},
    141561: {"Unified_Ideograph", "Ideographic"},
    141562: {"Unified_Ideograph", "Ideographic"},
    141563: {"Unified_Ideograph", "Ideographic"},
    141564: {"Unified_Ideograph", "Ideographic"},
    141565: {"Unified_Ideograph", "Ideographic"},
    141566: {"Unified_Ideograph", "Ideographic"},
    141567: {"Unified_Ideograph", "Ideographic"},
    141568: {"Unified_Ideograph", "Ideographic"},
    141569: {"Unified_Ideograph", "Ideographic"},
    141570: {"Unified_Ideograph", "Ideographic"},
    141571: {"Unified_Ideograph", "Ideographic"},
    141572: {"Unified_Ideograph", "Ideographic"},
    141573: {"Unified_Ideograph", "Ideographic"},
    141574: {"Unified_Ideograph", "Ideographic"},
    141575: {"Unified_Ideograph", "Ideographic"},
    141576: {"Unified_Ideograph", "Ideographic"},
    141577: {"Unified_Ideograph", "Ideographic"},
    141578: {"Unified_Ideograph", "Ideographic"},
    141579: {"Unified_Ideograph", "Ideographic"},
    141580: {"Unified_Ideograph", "Ideographic"},
    141581: {"Unified_Ideograph", "Ideographic"},
    141582: {"Unified_Ideograph", "Ideographic"},
    141583: {"Unified_Ideograph", "Ideographic"},
    141584: {"Unified_Ideograph", "Ideographic"},
    141585: {"Unified_Ideograph", "Ideographic"},
    141586: {"Unified_Ideograph", "Ideographic"},
    141587: {"Unified_Ideograph", "Ideographic"},
    141588: {"Unified_Ideograph", "Ideographic"},
    141589: {"Unified_Ideograph", "Ideographic"},
    141590: {"Unified_Ideograph", "Ideographic"},
    141591: {"Unified_Ideograph", "Ideographic"},
    141592: {"Unified_Ideograph", "Ideographic"},
    141593: {"Unified_Ideograph", "Ideographic"},
    141594: {"Unified_Ideograph", "Ideographic"},
    141595: {"Unified_Ideograph", "Ideographic"},
    141596: {"Unified_Ideograph", "Ideographic"},
    141597: {"Unified_Ideograph", "Ideographic"},
    141598: {"Unified_Ideograph", "Ideographic"},
    141599: {"Unified_Ideograph", "Ideographic"},
    141600: {"Unified_Ideograph", "Ideographic"},
    141601: {"Unified_Ideograph", "Ideographic"},
    141602: {"Unified_Ideograph", "Ideographic"},
    141603: {"Unified_Ideograph", "Ideographic"},
    141604: {"Unified_Ideograph", "Ideographic"},
    141605: {"Unified_Ideograph", "Ideographic"},
    141606: {"Unified_Ideograph", "Ideographic"},
    141607: {"Unified_Ideograph", "Ideographic"},
    141608: {"Unified_Ideograph", "Ideographic"},
    141609: {"Unified_Ideograph", "Ideographic"},
    141610: {"Unified_Ideograph", "Ideographic"},
    141611: {"Unified_Ideograph", "Ideographic"},
    141612: {"Unified_Ideograph", "Ideographic"},
    141613: {"Unified_Ideograph", "Ideographic"},
    141614: {"Unified_Ideograph", "Ideographic"},
    141615: {"Unified_Ideograph", "Ideographic"},
    141616: {"Unified_Ideograph", "Ideographic"},
    141617: {"Unified_Ideograph", "Ideographic"},
    141618: {"Unified_Ideograph", "Ideographic"},
    141619: {"Unified_Ideograph", "Ideographic"},
    141620: {"Unified_Ideograph", "Ideographic"},
    141621: {"Unified_Ideograph", "Ideographic"},
    141622: {"Unified_Ideograph", "Ideographic"},
    141623: {"Unified_Ideograph", "Ideographic"},
    141624: {"Unified_Ideograph", "Ideographic"},
    141625: {"Unified_Ideograph", "Ideographic"},
    141626: {"Unified_Ideograph", "Ideographic"},
    141627: {"Unified_Ideograph", "Ideographic"},
    141628: {"Unified_Ideograph", "Ideographic"},
    141629: {"Unified_Ideograph", "Ideographic"},
    141630: {"Unified_Ideograph", "Ideographic"},
    141631: {"Unified_Ideograph", "Ideographic"},
    141632: {"Unified_Ideograph", "Ideographic"},
    141633: {"Unified_Ideograph", "Ideographic"},
    141634: {"Unified_Ideograph", "Ideographic"},
    141635: {"Unified_Ideograph", "Ideographic"},
    141636: {"Unified_Ideograph", "Ideographic"},
    141637: {"Unified_Ideograph", "Ideographic"},
    141638: {"Unified_Ideograph", "Ideographic"},
    141639: {"Unified_Ideograph", "Ideographic"},
    141640: {"Unified_Ideograph", "Ideographic"},
    141641: {"Unified_Ideograph", "Ideographic"},
    141642: {"Unified_Ideograph", "Ideographic"},
    141643: {"Unified_Ideograph", "Ideographic"},
    141644: {"Unified_Ideograph", "Ideographic"},
    141645: {"Unified_Ideograph", "Ideographic"},
    141646: {"Unified_Ideograph", "Ideographic"},
    141647: {"Unified_Ideograph", "Ideographic"},
    141648: {"Unified_Ideograph", "Ideographic"},
    141649: {"Unified_Ideograph", "Ideographic"},
    141650: {"Unified_Ideograph", "Ideographic"},
    141651: {"Unified_Ideograph", "Ideographic"},
    141652: {"Unified_Ideograph", "Ideographic"},
    141653: {"Unified_Ideograph", "Ideographic"},
    141654: {"Unified_Ideograph", "Ideographic"},
    141655: {"Unified_Ideograph", "Ideographic"},
    141656: {"Unified_Ideograph", "Ideographic"},
    141657: {"Unified_Ideograph", "Ideographic"},
    141658: {"Unified_Ideograph", "Ideographic"},
    141659: {"Unified_Ideograph", "Ideographic"},
    141660: {"Unified_Ideograph", "Ideographic"},
    141661: {"Unified_Ideograph", "Ideographic"},
    141662: {"Unified_Ideograph", "Ideographic"},
    141663: {"Unified_Ideograph", "Ideographic"},
    141664: {"Unified_Ideograph", "Ideographic"},
    141665: {"Unified_Ideograph", "Ideographic"},
    141666: {"Unified_Ideograph", "Ideographic"},
    141667: {"Unified_Ideograph", "Ideographic"},
    141668: {"Unified_Ideograph", "Ideographic"},
    141669: {"Unified_Ideograph", "Ideographic"},
    141670: {"Unified_Ideograph", "Ideographic"},
    141671: {"Unified_Ideograph", "Ideographic"},
    141672: {"Unified_Ideograph", "Ideographic"},
    141673: {"Unified_Ideograph", "Ideographic"},
    141674: {"Unified_Ideograph", "Ideographic"},
    141675: {"Unified_Ideograph", "Ideographic"},
    141676: {"Unified_Ideograph", "Ideographic"},
    141677: {"Unified_Ideograph", "Ideographic"},
    141678: {"Unified_Ideograph", "Ideographic"},
    141679: {"Unified_Ideograph", "Ideographic"},
    141680: {"Unified_Ideograph", "Ideographic"},
    141681: {"Unified_Ideograph", "Ideographic"},
    141682: {"Unified_Ideograph", "Ideographic"},
    141683: {"Unified_Ideograph", "Ideographic"},
    141684: {"Unified_Ideograph", "Ideographic"},
    141685: {"Unified_Ideograph", "Ideographic"},
    141686: {"Unified_Ideograph", "Ideographic"},
    141687: {"Unified_Ideograph", "Ideographic"},
    141688: {"Unified_Ideograph", "Ideographic"},
    141689: {"Unified_Ideograph", "Ideographic"},
    141690: {"Unified_Ideograph", "Ideographic"},
    141691: {"Unified_Ideograph", "Ideographic"},
    141692: {"Unified_Ideograph", "Ideographic"},
    141693: {"Unified_Ideograph", "Ideographic"},
    141694: {"Unified_Ideograph", "Ideographic"},
    141695: {"Unified_Ideograph", "Ideographic"},
    141696: {"Unified_Ideograph", "Ideographic"},
    141697: {"Unified_Ideograph", "Ideographic"},
    141698: {"Unified_Ideograph", "Ideographic"},
    141699: {"Unified_Ideograph", "Ideographic"},
    141700: {"Unified_Ideograph", "Ideographic"},
    141701: {"Unified_Ideograph", "Ideographic"},
    141702: {"Unified_Ideograph", "Ideographic"},
    141703: {"Unified_Ideograph", "Ideographic"},
    141704: {"Unified_Ideograph", "Ideographic"},
    141705: {"Unified_Ideograph", "Ideographic"},
    141706: {"Unified_Ideograph", "Ideographic"},
    141707: {"Unified_Ideograph", "Ideographic"},
    141708: {"Unified_Ideograph", "Ideographic"},
    141709: {"Unified_Ideograph", "Ideographic"},
    141710: {"Unified_Ideograph", "Ideographic"},
    141711: {"Unified_Ideograph", "Ideographic"},
    141712: {"Unified_Ideograph", "Ideographic"},
    141713: {"Unified_Ideograph", "Ideographic"},
    141714: {"Unified_Ideograph", "Ideographic"},
    141715: {"Unified_Ideograph", "Ideographic"},
    141716: {"Unified_Ideograph", "Ideographic"},
    141717: {"Unified_Ideograph", "Ideographic"},
    141718: {"Unified_Ideograph", "Ideographic"},
    141719: {"Unified_Ideograph", "Ideographic"},
    141720: {"Unified_Ideograph", "Ideographic"},
    141721: {"Unified_Ideograph", "Ideographic"},
    141722: {"Unified_Ideograph", "Ideographic"},
    141723: {"Unified_Ideograph", "Ideographic"},
    141724: {"Unified_Ideograph", "Ideographic"},
    141725: {"Unified_Ideograph", "Ideographic"},
    141726: {"Unified_Ideograph", "Ideographic"},
    141727: {"Unified_Ideograph", "Ideographic"},
    141728: {"Unified_Ideograph", "Ideographic"},
    141729: {"Unified_Ideograph", "Ideographic"},
    141730: {"Unified_Ideograph", "Ideographic"},
    141731: {"Unified_Ideograph", "Ideographic"},
    141732: {"Unified_Ideograph", "Ideographic"},
    141733: {"Unified_Ideograph", "Ideographic"},
    141734: {"Unified_Ideograph", "Ideographic"},
    141735: {"Unified_Ideograph", "Ideographic"},
    141736: {"Unified_Ideograph", "Ideographic"},
    141737: {"Unified_Ideograph", "Ideographic"},
    141738: {"Unified_Ideograph", "Ideographic"},
    141739: {"Unified_Ideograph", "Ideographic"},
    141740: {"Unified_Ideograph", "Ideographic"},
    141741: {"Unified_Ideograph", "Ideographic"},
    141742: {"Unified_Ideograph", "Ideographic"},
    141743: {"Unified_Ideograph", "Ideographic"},
    141744: {"Unified_Ideograph", "Ideographic"},
    141745: {"Unified_Ideograph", "Ideographic"},
    141746: {"Unified_Ideograph", "Ideographic"},
    141747: {"Unified_Ideograph", "Ideographic"},
    141748: {"Unified_Ideograph", "Ideographic"},
    141749: {"Unified_Ideograph", "Ideographic"},
    141750: {"Unified_Ideograph", "Ideographic"},
    141751: {"Unified_Ideograph", "Ideographic"},
    141752: {"Unified_Ideograph", "Ideographic"},
    141753: {"Unified_Ideograph", "Ideographic"},
    141754: {"Unified_Ideograph", "Ideographic"},
    141755: {"Unified_Ideograph", "Ideographic"},
    141756: {"Unified_Ideograph", "Ideographic"},
    141757: {"Unified_Ideograph", "Ideographic"},
    141758: {"Unified_Ideograph", "Ideographic"},
    141759: {"Unified_Ideograph", "Ideographic"},
    141760: {"Unified_Ideograph", "Ideographic"},
    141761: {"Unified_Ideograph", "Ideographic"},
    141762: {"Unified_Ideograph", "Ideographic"},
    141763: {"Unified_Ideograph", "Ideographic"},
    141764: {"Unified_Ideograph", "Ideographic"},
    141765: {"Unified_Ideograph", "Ideographic"},
    141766: {"Unified_Ideograph", "Ideographic"},
    141767: {"Unified_Ideograph", "Ideographic"},
    141768: {"Unified_Ideograph", "Ideographic"},
    141769: {"Unified_Ideograph", "Ideographic"},
    141770: {"Unified_Ideograph", "Ideographic"},
    141771: {"Unified_Ideograph", "Ideographic"},
    141772: {"Unified_Ideograph", "Ideographic"},
    141773: {"Unified_Ideograph", "Ideographic"},
    141774: {"Unified_Ideograph", "Ideographic"},
    141775: {"Unified_Ideograph", "Ideographic"},
    141776: {"Unified_Ideograph", "Ideographic"},
    141777: {"Unified_Ideograph", "Ideographic"},
    141778: {"Unified_Ideograph", "Ideographic"},
    141779: {"Unified_Ideograph", "Ideographic"},
    141780: {"Unified_Ideograph", "Ideographic"},
    141781: {"Unified_Ideograph", "Ideographic"},
    141782: {"Unified_Ideograph", "Ideographic"},
    141783: {"Unified_Ideograph", "Ideographic"},
    141784: {"Unified_Ideograph", "Ideographic"},
    141785: {"Unified_Ideograph", "Ideographic"},
    141786: {"Unified_Ideograph", "Ideographic"},
    141787: {"Unified_Ideograph", "Ideographic"},
    141788: {"Unified_Ideograph", "Ideographic"},
    141789: {"Unified_Ideograph", "Ideographic"},
    141790: {"Unified_Ideograph", "Ideographic"},
    141791: {"Unified_Ideograph", "Ideographic"},
    141792: {"Unified_Ideograph", "Ideographic"},
    141793: {"Unified_Ideograph", "Ideographic"},
    141794: {"Unified_Ideograph", "Ideographic"},
    141795: {"Unified_Ideograph", "Ideographic"},
    141796: {"Unified_Ideograph", "Ideographic"},
    141797: {"Unified_Ideograph", "Ideographic"},
    141798: {"Unified_Ideograph", "Ideographic"},
    141799: {"Unified_Ideograph", "Ideographic"},
    141800: {"Unified_Ideograph", "Ideographic"},
    141801: {"Unified_Ideograph", "Ideographic"},
    141802: {"Unified_Ideograph", "Ideographic"},
    141803: {"Unified_Ideograph", "Ideographic"},
    141804: {"Unified_Ideograph", "Ideographic"},
    141805: {"Unified_Ideograph", "Ideographic"},
    141806: {"Unified_Ideograph", "Ideographic"},
    141807: {"Unified_Ideograph", "Ideographic"},
    141808: {"Unified_Ideograph", "Ideographic"},
    141809: {"Unified_Ideograph", "Ideographic"},
    141810: {"Unified_Ideograph", "Ideographic"},
    141811: {"Unified_Ideograph", "Ideographic"},
    141812: {"Unified_Ideograph", "Ideographic"},
    141813: {"Unified_Ideograph", "Ideographic"},
    141814: {"Unified_Ideograph", "Ideographic"},
    141815: {"Unified_Ideograph", "Ideographic"},
    141816: {"Unified_Ideograph", "Ideographic"},
    141817: {"Unified_Ideograph", "Ideographic"},
    141818: {"Unified_Ideograph", "Ideographic"},
    141819: {"Unified_Ideograph", "Ideographic"},
    141820: {"Unified_Ideograph", "Ideographic"},
    141821: {"Unified_Ideograph", "Ideographic"},
    141822: {"Unified_Ideograph", "Ideographic"},
    141823: {"Unified_Ideograph", "Ideographic"},
    141824: {"Unified_Ideograph", "Ideographic"},
    141825: {"Unified_Ideograph", "Ideographic"},
    141826: {"Unified_Ideograph", "Ideographic"},
    141827: {"Unified_Ideograph", "Ideographic"},
    141828: {"Unified_Ideograph", "Ideographic"},
    141829: {"Unified_Ideograph", "Ideographic"},
    141830: {"Unified_Ideograph", "Ideographic"},
    141831: {"Unified_Ideograph", "Ideographic"},
    141832: {"Unified_Ideograph", "Ideographic"},
    141833: {"Unified_Ideograph", "Ideographic"},
    141834: {"Unified_Ideograph", "Ideographic"},
    141835: {"Unified_Ideograph", "Ideographic"},
    141836: {"Unified_Ideograph", "Ideographic"},
    141837: {"Unified_Ideograph", "Ideographic"},
    141838: {"Unified_Ideograph", "Ideographic"},
    141839: {"Unified_Ideograph", "Ideographic"},
    141840: {"Unified_Ideograph", "Ideographic"},
    141841: {"Unified_Ideograph", "Ideographic"},
    141842: {"Unified_Ideograph", "Ideographic"},
    141843: {"Unified_Ideograph", "Ideographic"},
    141844: {"Unified_Ideograph", "Ideographic"},
    141845: {"Unified_Ideograph", "Ideographic"},
    141846: {"Unified_Ideograph", "Ideographic"},
    141847: {"Unified_Ideograph", "Ideographic"},
    141848: {"Unified_Ideograph", "Ideographic"},
    141849: {"Unified_Ideograph", "Ideographic"},
    141850: {"Unified_Ideograph", "Ideographic"},
    141851: {"Unified_Ideograph", "Ideographic"},
    141852: {"Unified_Ideograph", "Ideographic"},
    141853: {"Unified_Ideograph", "Ideographic"},
    141854: {"Unified_Ideograph", "Ideographic"},
    141855: {"Unified_Ideograph", "Ideographic"},
    141856: {"Unified_Ideograph", "Ideographic"},
    141857: {"Unified_Ideograph", "Ideographic"},
    141858: {"Unified_Ideograph", "Ideographic"},
    141859: {"Unified_Ideograph", "Ideographic"},
    141860: {"Unified_Ideograph", "Ideographic"},
    141861: {"Unified_Ideograph", "Ideographic"},
    141862: {"Unified_Ideograph", "Ideographic"},
    141863: {"Unified_Ideograph", "Ideographic"},
    141864: {"Unified_Ideograph", "Ideographic"},
    141865: {"Unified_Ideograph", "Ideographic"},
    141866: {"Unified_Ideograph", "Ideographic"},
    141867: {"Unified_Ideograph", "Ideographic"},
    141868: {"Unified_Ideograph", "Ideographic"},
    141869: {"Unified_Ideograph", "Ideographic"},
    141870: {"Unified_Ideograph", "Ideographic"},
    141871: {"Unified_Ideograph", "Ideographic"},
    141872: {"Unified_Ideograph", "Ideographic"},
    141873: {"Unified_Ideograph", "Ideographic"},
    141874: {"Unified_Ideograph", "Ideographic"},
    141875: {"Unified_Ideograph", "Ideographic"},
    141876: {"Unified_Ideograph", "Ideographic"},
    141877: {"Unified_Ideograph", "Ideographic"},
    141878: {"Unified_Ideograph", "Ideographic"},
    141879: {"Unified_Ideograph", "Ideographic"},
    141880: {"Unified_Ideograph", "Ideographic"},
    141881: {"Unified_Ideograph", "Ideographic"},
    141882: {"Unified_Ideograph", "Ideographic"},
    141883: {"Unified_Ideograph", "Ideographic"},
    141884: {"Unified_Ideograph", "Ideographic"},
    141885: {"Unified_Ideograph", "Ideographic"},
    141886: {"Unified_Ideograph", "Ideographic"},
    141887: {"Unified_Ideograph", "Ideographic"},
    141888: {"Unified_Ideograph", "Ideographic"},
    141889: {"Unified_Ideograph", "Ideographic"},
    141890: {"Unified_Ideograph", "Ideographic"},
    141891: {"Unified_Ideograph", "Ideographic"},
    141892: {"Unified_Ideograph", "Ideographic"},
    141893: {"Unified_Ideograph", "Ideographic"},
    141894: {"Unified_Ideograph", "Ideographic"},
    141895: {"Unified_Ideograph", "Ideographic"},
    141896: {"Unified_Ideograph", "Ideographic"},
    141897: {"Unified_Ideograph", "Ideographic"},
    141898: {"Unified_Ideograph", "Ideographic"},
    141899: {"Unified_Ideograph", "Ideographic"},
    141900: {"Unified_Ideograph", "Ideographic"},
    141901: {"Unified_Ideograph", "Ideographic"},
    141902: {"Unified_Ideograph", "Ideographic"},
    141903: {"Unified_Ideograph", "Ideographic"},
    141904: {"Unified_Ideograph", "Ideographic"},
    141905: {"Unified_Ideograph", "Ideographic"},
    141906: {"Unified_Ideograph", "Ideographic"},
    141907: {"Unified_Ideograph", "Ideographic"},
    141908: {"Unified_Ideograph", "Ideographic"},
    141909: {"Unified_Ideograph", "Ideographic"},
    141910: {"Unified_Ideograph", "Ideographic"},
    141911: {"Unified_Ideograph", "Ideographic"},
    141912: {"Unified_Ideograph", "Ideographic"},
    141913: {"Unified_Ideograph", "Ideographic"},
    141914: {"Unified_Ideograph", "Ideographic"},
    141915: {"Unified_Ideograph", "Ideographic"},
    141916: {"Unified_Ideograph", "Ideographic"},
    141917: {"Unified_Ideograph", "Ideographic"},
    141918: {"Unified_Ideograph", "Ideographic"},
    141919: {"Unified_Ideograph", "Ideographic"},
    141920: {"Unified_Ideograph", "Ideographic"},
    141921: {"Unified_Ideograph", "Ideographic"},
    141922: {"Unified_Ideograph", "Ideographic"},
    141923: {"Unified_Ideograph", "Ideographic"},
    141924: {"Unified_Ideograph", "Ideographic"},
    141925: {"Unified_Ideograph", "Ideographic"},
    141926: {"Unified_Ideograph", "Ideographic"},
    141927: {"Unified_Ideograph", "Ideographic"},
    141928: {"Unified_Ideograph", "Ideographic"},
    141929: {"Unified_Ideograph", "Ideographic"},
    141930: {"Unified_Ideograph", "Ideographic"},
    141931: {"Unified_Ideograph", "Ideographic"},
    141932: {"Unified_Ideograph", "Ideographic"},
    141933: {"Unified_Ideograph", "Ideographic"},
    141934: {"Unified_Ideograph", "Ideographic"},
    141935: {"Unified_Ideograph", "Ideographic"},
    141936: {"Unified_Ideograph", "Ideographic"},
    141937: {"Unified_Ideograph", "Ideographic"},
    141938: {"Unified_Ideograph", "Ideographic"},
    141939: {"Unified_Ideograph", "Ideographic"},
    141940: {"Unified_Ideograph", "Ideographic"},
    141941: {"Unified_Ideograph", "Ideographic"},
    141942: {"Unified_Ideograph", "Ideographic"},
    141943: {"Unified_Ideograph", "Ideographic"},
    141944: {"Unified_Ideograph", "Ideographic"},
    141945: {"Unified_Ideograph", "Ideographic"},
    141946: {"Unified_Ideograph", "Ideographic"},
    141947: {"Unified_Ideograph", "Ideographic"},
    141948: {"Unified_Ideograph", "Ideographic"},
    141949: {"Unified_Ideograph", "Ideographic"},
    141950: {"Unified_Ideograph", "Ideographic"},
    141951: {"Unified_Ideograph", "Ideographic"},
    141952: {"Unified_Ideograph", "Ideographic"},
    141953: {"Unified_Ideograph", "Ideographic"},
    141954: {"Unified_Ideograph", "Ideographic"},
    141955: {"Unified_Ideograph", "Ideographic"},
    141956: {"Unified_Ideograph", "Ideographic"},
    141957: {"Unified_Ideograph", "Ideographic"},
    141958: {"Unified_Ideograph", "Ideographic"},
    141959: {"Unified_Ideograph", "Ideographic"},
    141960: {"Unified_Ideograph", "Ideographic"},
    141961: {"Unified_Ideograph", "Ideographic"},
    141962: {"Unified_Ideograph", "Ideographic"},
    141963: {"Unified_Ideograph", "Ideographic"},
    141964: {"Unified_Ideograph", "Ideographic"},
    141965: {"Unified_Ideograph", "Ideographic"},
    141966: {"Unified_Ideograph", "Ideographic"},
    141967: {"Unified_Ideograph", "Ideographic"},
    141968: {"Unified_Ideograph", "Ideographic"},
    141969: {"Unified_Ideograph", "Ideographic"},
    141970: {"Unified_Ideograph", "Ideographic"},
    141971: {"Unified_Ideograph", "Ideographic"},
    141972: {"Unified_Ideograph", "Ideographic"},
    141973: {"Unified_Ideograph", "Ideographic"},
    141974: {"Unified_Ideograph", "Ideographic"},
    141975: {"Unified_Ideograph", "Ideographic"},
    141976: {"Unified_Ideograph", "Ideographic"},
    141977: {"Unified_Ideograph", "Ideographic"},
    141978: {"Unified_Ideograph", "Ideographic"},
    141979: {"Unified_Ideograph", "Ideographic"},
    141980: {"Unified_Ideograph", "Ideographic"},
    141981: {"Unified_Ideograph", "Ideographic"},
    141982: {"Unified_Ideograph", "Ideographic"},
    141983: {"Unified_Ideograph", "Ideographic"},
    141984: {"Unified_Ideograph", "Ideographic"},
    141985: {"Unified_Ideograph", "Ideographic"},
    141986: {"Unified_Ideograph", "Ideographic"},
    141987: {"Unified_Ideograph", "Ideographic"},
    141988: {"Unified_Ideograph", "Ideographic"},
    141989: {"Unified_Ideograph", "Ideographic"},
    141990: {"Unified_Ideograph", "Ideographic"},
    141991: {"Unified_Ideograph", "Ideographic"},
    141992: {"Unified_Ideograph", "Ideographic"},
    141993: {"Unified_Ideograph", "Ideographic"},
    141994: {"Unified_Ideograph", "Ideographic"},
    141995: {"Unified_Ideograph", "Ideographic"},
    141996: {"Unified_Ideograph", "Ideographic"},
    141997: {"Unified_Ideograph", "Ideographic"},
    141998: {"Unified_Ideograph", "Ideographic"},
    141999: {"Unified_Ideograph", "Ideographic"},
    142000: {"Unified_Ideograph", "Ideographic"},
    142001: {"Unified_Ideograph", "Ideographic"},
    142002: {"Unified_Ideograph", "Ideographic"},
    142003: {"Unified_Ideograph", "Ideographic"},
    142004: {"Unified_Ideograph", "Ideographic"},
    142005: {"Unified_Ideograph", "Ideographic"},
    142006: {"Unified_Ideograph", "Ideographic"},
    142007: {"Unified_Ideograph", "Ideographic"},
    142008: {"Unified_Ideograph", "Ideographic"},
    142009: {"Unified_Ideograph", "Ideographic"},
    142010: {"Unified_Ideograph", "Ideographic"},
    142011: {"Unified_Ideograph", "Ideographic"},
    142012: {"Unified_Ideograph", "Ideographic"},
    142013: {"Unified_Ideograph", "Ideographic"},
    142014: {"Unified_Ideograph", "Ideographic"},
    142015: {"Unified_Ideograph", "Ideographic"},
    142016: {"Unified_Ideograph", "Ideographic"},
    142017: {"Unified_Ideograph", "Ideographic"},
    142018: {"Unified_Ideograph", "Ideographic"},
    142019: {"Unified_Ideograph", "Ideographic"},
    142020: {"Unified_Ideograph", "Ideographic"},
    142021: {"Unified_Ideograph", "Ideographic"},
    142022: {"Unified_Ideograph", "Ideographic"},
    142023: {"Unified_Ideograph", "Ideographic"},
    142024: {"Unified_Ideograph", "Ideographic"},
    142025: {"Unified_Ideograph", "Ideographic"},
    142026: {"Unified_Ideograph", "Ideographic"},
    142027: {"Unified_Ideograph", "Ideographic"},
    142028: {"Unified_Ideograph", "Ideographic"},
    142029: {"Unified_Ideograph", "Ideographic"},
    142030: {"Unified_Ideograph", "Ideographic"},
    142031: {"Unified_Ideograph", "Ideographic"},
    142032: {"Unified_Ideograph", "Ideographic"},
    142033: {"Unified_Ideograph", "Ideographic"},
    142034: {"Unified_Ideograph", "Ideographic"},
    142035: {"Unified_Ideograph", "Ideographic"},
    142036: {"Unified_Ideograph", "Ideographic"},
    142037: {"Unified_Ideograph", "Ideographic"},
    142038: {"Unified_Ideograph", "Ideographic"},
    142039: {"Unified_Ideograph", "Ideographic"},
    142040: {"Unified_Ideograph", "Ideographic"},
    142041: {"Unified_Ideograph", "Ideographic"},
    142042: {"Unified_Ideograph", "Ideographic"},
    142043: {"Unified_Ideograph", "Ideographic"},
    142044: {"Unified_Ideograph", "Ideographic"},
    142045: {"Unified_Ideograph", "Ideographic"},
    142046: {"Unified_Ideograph", "Ideographic"},
    142047: {"Unified_Ideograph", "Ideographic"},
    142048: {"Unified_Ideograph", "Ideographic"},
    142049: {"Unified_Ideograph", "Ideographic"},
    142050: {"Unified_Ideograph", "Ideographic"},
    142051: {"Unified_Ideograph", "Ideographic"},
    142052: {"Unified_Ideograph", "Ideographic"},
    142053: {"Unified_Ideograph", "Ideographic"},
    142054: {"Unified_Ideograph", "Ideographic"},
    142055: {"Unified_Ideograph", "Ideographic"},
    142056: {"Unified_Ideograph", "Ideographic"},
    142057: {"Unified_Ideograph", "Ideographic"},
    142058: {"Unified_Ideograph", "Ideographic"},
    142059: {"Unified_Ideograph", "Ideographic"},
    142060: {"Unified_Ideograph", "Ideographic"},
    142061: {"Unified_Ideograph", "Ideographic"},
    142062: {"Unified_Ideograph", "Ideographic"},
    142063: {"Unified_Ideograph", "Ideographic"},
    142064: {"Unified_Ideograph", "Ideographic"},
    142065: {"Unified_Ideograph", "Ideographic"},
    142066: {"Unified_Ideograph", "Ideographic"},
    142067: {"Unified_Ideograph", "Ideographic"},
    142068: {"Unified_Ideograph", "Ideographic"},
    142069: {"Unified_Ideograph", "Ideographic"},
    142070: {"Unified_Ideograph", "Ideographic"},
    142071: {"Unified_Ideograph", "Ideographic"},
    142072: {"Unified_Ideograph", "Ideographic"},
    142073: {"Unified_Ideograph", "Ideographic"},
    142074: {"Unified_Ideograph", "Ideographic"},
    142075: {"Unified_Ideograph", "Ideographic"},
    142076: {"Unified_Ideograph", "Ideographic"},
    142077: {"Unified_Ideograph", "Ideographic"},
    142078: {"Unified_Ideograph", "Ideographic"},
    142079: {"Unified_Ideograph", "Ideographic"},
    142080: {"Unified_Ideograph", "Ideographic"},
    142081: {"Unified_Ideograph", "Ideographic"},
    142082: {"Unified_Ideograph", "Ideographic"},
    142083: {"Unified_Ideograph", "Ideographic"},
    142084: {"Unified_Ideograph", "Ideographic"},
    142085: {"Unified_Ideograph", "Ideographic"},
    142086: {"Unified_Ideograph", "Ideographic"},
    142087: {"Unified_Ideograph", "Ideographic"},
    142088: {"Unified_Ideograph", "Ideographic"},
    142089: {"Unified_Ideograph", "Ideographic"},
    142090: {"Unified_Ideograph", "Ideographic"},
    142091: {"Unified_Ideograph", "Ideographic"},
    142092: {"Unified_Ideograph", "Ideographic"},
    142093: {"Unified_Ideograph", "Ideographic"},
    142094: {"Unified_Ideograph", "Ideographic"},
    142095: {"Unified_Ideograph", "Ideographic"},
    142096: {"Unified_Ideograph", "Ideographic"},
    142097: {"Unified_Ideograph", "Ideographic"},
    142098: {"Unified_Ideograph", "Ideographic"},
    142099: {"Unified_Ideograph", "Ideographic"},
    142100: {"Unified_Ideograph", "Ideographic"},
    142101: {"Unified_Ideograph", "Ideographic"},
    142102: {"Unified_Ideograph", "Ideographic"},
    142103: {"Unified_Ideograph", "Ideographic"},
    142104: {"Unified_Ideograph", "Ideographic"},
    142105: {"Unified_Ideograph", "Ideographic"},
    142106: {"Unified_Ideograph", "Ideographic"},
    142107: {"Unified_Ideograph", "Ideographic"},
    142108: {"Unified_Ideograph", "Ideographic"},
    142109: {"Unified_Ideograph", "Ideographic"},
    142110: {"Unified_Ideograph", "Ideographic"},
    142111: {"Unified_Ideograph", "Ideographic"},
    142112: {"Unified_Ideograph", "Ideographic"},
    142113: {"Unified_Ideograph", "Ideographic"},
    142114: {"Unified_Ideograph", "Ideographic"},
    142115: {"Unified_Ideograph", "Ideographic"},
    142116: {"Unified_Ideograph", "Ideographic"},
    142117: {"Unified_Ideograph", "Ideographic"},
    142118: {"Unified_Ideograph", "Ideographic"},
    142119: {"Unified_Ideograph", "Ideographic"},
    142120: {"Unified_Ideograph", "Ideographic"},
    142121: {"Unified_Ideograph", "Ideographic"},
    142122: {"Unified_Ideograph", "Ideographic"},
    142123: {"Unified_Ideograph", "Ideographic"},
    142124: {"Unified_Ideograph", "Ideographic"},
    142125: {"Unified_Ideograph", "Ideographic"},
    142126: {"Unified_Ideograph", "Ideographic"},
    142127: {"Unified_Ideograph", "Ideographic"},
    142128: {"Unified_Ideograph", "Ideographic"},
    142129: {"Unified_Ideograph", "Ideographic"},
    142130: {"Unified_Ideograph", "Ideographic"},
    142131: {"Unified_Ideograph", "Ideographic"},
    142132: {"Unified_Ideograph", "Ideographic"},
    142133: {"Unified_Ideograph", "Ideographic"},
    142134: {"Unified_Ideograph", "Ideographic"},
    142135: {"Unified_Ideograph", "Ideographic"},
    142136: {"Unified_Ideograph", "Ideographic"},
    142137: {"Unified_Ideograph", "Ideographic"},
    142138: {"Unified_Ideograph", "Ideographic"},
    142139: {"Unified_Ideograph", "Ideographic"},
    142140: {"Unified_Ideograph", "Ideographic"},
    142141: {"Unified_Ideograph", "Ideographic"},
    142142: {"Unified_Ideograph", "Ideographic"},
    142143: {"Unified_Ideograph", "Ideographic"},
    142144: {"Unified_Ideograph", "Ideographic"},
    142145: {"Unified_Ideograph", "Ideographic"},
    142146: {"Unified_Ideograph", "Ideographic"},
    142147: {"Unified_Ideograph", "Ideographic"},
    142148: {"Unified_Ideograph", "Ideographic"},
    142149: {"Unified_Ideograph", "Ideographic"},
    142150: {"Unified_Ideograph", "Ideographic"},
    142151: {"Unified_Ideograph", "Ideographic"},
    142152: {"Unified_Ideograph", "Ideographic"},
    142153: {"Unified_Ideograph", "Ideographic"},
    142154: {"Unified_Ideograph", "Ideographic"},
    142155: {"Unified_Ideograph", "Ideographic"},
    142156: {"Unified_Ideograph", "Ideographic"},
    142157: {"Unified_Ideograph", "Ideographic"},
    142158: {"Unified_Ideograph", "Ideographic"},
    142159: {"Unified_Ideograph", "Ideographic"},
    142160: {"Unified_Ideograph", "Ideographic"},
    142161: {"Unified_Ideograph", "Ideographic"},
    142162: {"Unified_Ideograph", "Ideographic"},
    142163: {"Unified_Ideograph", "Ideographic"},
    142164: {"Unified_Ideograph", "Ideographic"},
    142165: {"Unified_Ideograph", "Ideographic"},
    142166: {"Unified_Ideograph", "Ideographic"},
    142167: {"Unified_Ideograph", "Ideographic"},
    142168: {"Unified_Ideograph", "Ideographic"},
    142169: {"Unified_Ideograph", "Ideographic"},
    142170: {"Unified_Ideograph", "Ideographic"},
    142171: {"Unified_Ideograph", "Ideographic"},
    142172: {"Unified_Ideograph", "Ideographic"},
    142173: {"Unified_Ideograph", "Ideographic"},
    142174: {"Unified_Ideograph", "Ideographic"},
    142175: {"Unified_Ideograph", "Ideographic"},
    142176: {"Unified_Ideograph", "Ideographic"},
    142177: {"Unified_Ideograph", "Ideographic"},
    142178: {"Unified_Ideograph", "Ideographic"},
    142179: {"Unified_Ideograph", "Ideographic"},
    142180: {"Unified_Ideograph", "Ideographic"},
    142181: {"Unified_Ideograph", "Ideographic"},
    142182: {"Unified_Ideograph", "Ideographic"},
    142183: {"Unified_Ideograph", "Ideographic"},
    142184: {"Unified_Ideograph", "Ideographic"},
    142185: {"Unified_Ideograph", "Ideographic"},
    142186: {"Unified_Ideograph", "Ideographic"},
    142187: {"Unified_Ideograph", "Ideographic"},
    142188: {"Unified_Ideograph", "Ideographic"},
    142189: {"Unified_Ideograph", "Ideographic"},
    142190: {"Unified_Ideograph", "Ideographic"},
    142191: {"Unified_Ideograph", "Ideographic"},
    142192: {"Unified_Ideograph", "Ideographic"},
    142193: {"Unified_Ideograph", "Ideographic"},
    142194: {"Unified_Ideograph", "Ideographic"},
    142195: {"Unified_Ideograph", "Ideographic"},
    142196: {"Unified_Ideograph", "Ideographic"},
    142197: {"Unified_Ideograph", "Ideographic"},
    142198: {"Unified_Ideograph", "Ideographic"},
    142199: {"Unified_Ideograph", "Ideographic"},
    142200: {"Unified_Ideograph", "Ideographic"},
    142201: {"Unified_Ideograph", "Ideographic"},
    142202: {"Unified_Ideograph", "Ideographic"},
    142203: {"Unified_Ideograph", "Ideographic"},
    142204: {"Unified_Ideograph", "Ideographic"},
    142205: {"Unified_Ideograph", "Ideographic"},
    142206: {"Unified_Ideograph", "Ideographic"},
    142207: {"Unified_Ideograph", "Ideographic"},
    142208: {"Unified_Ideograph", "Ideographic"},
    142209: {"Unified_Ideograph", "Ideographic"},
    142210: {"Unified_Ideograph", "Ideographic"},
    142211: {"Unified_Ideograph", "Ideographic"},
    142212: {"Unified_Ideograph", "Ideographic"},
    142213: {"Unified_Ideograph", "Ideographic"},
    142214: {"Unified_Ideograph", "Ideographic"},
    142215: {"Unified_Ideograph", "Ideographic"},
    142216: {"Unified_Ideograph", "Ideographic"},
    142217: {"Unified_Ideograph", "Ideographic"},
    142218: {"Unified_Ideograph", "Ideographic"},
    142219: {"Unified_Ideograph", "Ideographic"},
    142220: {"Unified_Ideograph", "Ideographic"},
    142221: {"Unified_Ideograph", "Ideographic"},
    142222: {"Unified_Ideograph", "Ideographic"},
    142223: {"Unified_Ideograph", "Ideographic"},
    142224: {"Unified_Ideograph", "Ideographic"},
    142225: {"Unified_Ideograph", "Ideographic"},
    142226: {"Unified_Ideograph", "Ideographic"},
    142227: {"Unified_Ideograph", "Ideographic"},
    142228: {"Unified_Ideograph", "Ideographic"},
    142229: {"Unified_Ideograph", "Ideographic"},
    142230: {"Unified_Ideograph", "Ideographic"},
    142231: {"Unified_Ideograph", "Ideographic"},
    142232: {"Unified_Ideograph", "Ideographic"},
    142233: {"Unified_Ideograph", "Ideographic"},
    142234: {"Unified_Ideograph", "Ideographic"},
    142235: {"Unified_Ideograph", "Ideographic"},
    142236: {"Unified_Ideograph", "Ideographic"},
    142237: {"Unified_Ideograph", "Ideographic"},
    142238: {"Unified_Ideograph", "Ideographic"},
    142239: {"Unified_Ideograph", "Ideographic"},
    142240: {"Unified_Ideograph", "Ideographic"},
    142241: {"Unified_Ideograph", "Ideographic"},
    142242: {"Unified_Ideograph", "Ideographic"},
    142243: {"Unified_Ideograph", "Ideographic"},
    142244: {"Unified_Ideograph", "Ideographic"},
    142245: {"Unified_Ideograph", "Ideographic"},
    142246: {"Unified_Ideograph", "Ideographic"},
    142247: {"Unified_Ideograph", "Ideographic"},
    142248: {"Unified_Ideograph", "Ideographic"},
    142249: {"Unified_Ideograph", "Ideographic"},
    142250: {"Unified_Ideograph", "Ideographic"},
    142251: {"Unified_Ideograph", "Ideographic"},
    142252: {"Unified_Ideograph", "Ideographic"},
    142253: {"Unified_Ideograph", "Ideographic"},
    142254: {"Unified_Ideograph", "Ideographic"},
    142255: {"Unified_Ideograph", "Ideographic"},
    142256: {"Unified_Ideograph", "Ideographic"},
    142257: {"Unified_Ideograph", "Ideographic"},
    142258: {"Unified_Ideograph", "Ideographic"},
    142259: {"Unified_Ideograph", "Ideographic"},
    142260: {"Unified_Ideograph", "Ideographic"},
    142261: {"Unified_Ideograph", "Ideographic"},
    142262: {"Unified_Ideograph", "Ideographic"},
    142263: {"Unified_Ideograph", "Ideographic"},
    142264: {"Unified_Ideograph", "Ideographic"},
    142265: {"Unified_Ideograph", "Ideographic"},
    142266: {"Unified_Ideograph", "Ideographic"},
    142267: {"Unified_Ideograph", "Ideographic"},
    142268: {"Unified_Ideograph", "Ideographic"},
    142269: {"Unified_Ideograph", "Ideographic"},
    142270: {"Unified_Ideograph", "Ideographic"},
    142271: {"Unified_Ideograph", "Ideographic"},
    142272: {"Unified_Ideograph", "Ideographic"},
    142273: {"Unified_Ideograph", "Ideographic"},
    142274: {"Unified_Ideograph", "Ideographic"},
    142275: {"Unified_Ideograph", "Ideographic"},
    142276: {"Unified_Ideograph", "Ideographic"},
    142277: {"Unified_Ideograph", "Ideographic"},
    142278: {"Unified_Ideograph", "Ideographic"},
    142279: {"Unified_Ideograph", "Ideographic"},
    142280: {"Unified_Ideograph", "Ideographic"},
    142281: {"Unified_Ideograph", "Ideographic"},
    142282: {"Unified_Ideograph", "Ideographic"},
    142283: {"Unified_Ideograph", "Ideographic"},
    142284: {"Unified_Ideograph", "Ideographic"},
    142285: {"Unified_Ideograph", "Ideographic"},
    142286: {"Unified_Ideograph", "Ideographic"},
    142287: {"Unified_Ideograph", "Ideographic"},
    142288: {"Unified_Ideograph", "Ideographic"},
    142289: {"Unified_Ideograph", "Ideographic"},
    142290: {"Unified_Ideograph", "Ideographic"},
    142291: {"Unified_Ideograph", "Ideographic"},
    142292: {"Unified_Ideograph", "Ideographic"},
    142293: {"Unified_Ideograph", "Ideographic"},
    142294: {"Unified_Ideograph", "Ideographic"},
    142295: {"Unified_Ideograph", "Ideographic"},
    142296: {"Unified_Ideograph", "Ideographic"},
    142297: {"Unified_Ideograph", "Ideographic"},
    142298: {"Unified_Ideograph", "Ideographic"},
    142299: {"Unified_Ideograph", "Ideographic"},
    142300: {"Unified_Ideograph", "Ideographic"},
    142301: {"Unified_Ideograph", "Ideographic"},
    142302: {"Unified_Ideograph", "Ideographic"},
    142303: {"Unified_Ideograph", "Ideographic"},
    142304: {"Unified_Ideograph", "Ideographic"},
    142305: {"Unified_Ideograph", "Ideographic"},
    142306: {"Unified_Ideograph", "Ideographic"},
    142307: {"Unified_Ideograph", "Ideographic"},
    142308: {"Unified_Ideograph", "Ideographic"},
    142309: {"Unified_Ideograph", "Ideographic"},
    142310: {"Unified_Ideograph", "Ideographic"},
    142311: {"Unified_Ideograph", "Ideographic"},
    142312: {"Unified_Ideograph", "Ideographic"},
    142313: {"Unified_Ideograph", "Ideographic"},
    142314: {"Unified_Ideograph", "Ideographic"},
    142315: {"Unified_Ideograph", "Ideographic"},
    142316: {"Unified_Ideograph", "Ideographic"},
    142317: {"Unified_Ideograph", "Ideographic"},
    142318: {"Unified_Ideograph", "Ideographic"},
    142319: {"Unified_Ideograph", "Ideographic"},
    142320: {"Unified_Ideograph", "Ideographic"},
    142321: {"Unified_Ideograph", "Ideographic"},
    142322: {"Unified_Ideograph", "Ideographic"},
    142323: {"Unified_Ideograph", "Ideographic"},
    142324: {"Unified_Ideograph", "Ideographic"},
    142325: {"Unified_Ideograph", "Ideographic"},
    142326: {"Unified_Ideograph", "Ideographic"},
    142327: {"Unified_Ideograph", "Ideographic"},
    142328: {"Unified_Ideograph", "Ideographic"},
    142329: {"Unified_Ideograph", "Ideographic"},
    142330: {"Unified_Ideograph", "Ideographic"},
    142331: {"Unified_Ideograph", "Ideographic"},
    142332: {"Unified_Ideograph", "Ideographic"},
    142333: {"Unified_Ideograph", "Ideographic"},
    142334: {"Unified_Ideograph", "Ideographic"},
    142335: {"Unified_Ideograph", "Ideographic"},
    142336: {"Unified_Ideograph", "Ideographic"},
    142337: {"Unified_Ideograph", "Ideographic"},
    142338: {"Unified_Ideograph", "Ideographic"},
    142339: {"Unified_Ideograph", "Ideographic"},
    142340: {"Unified_Ideograph", "Ideographic"},
    142341: {"Unified_Ideograph", "Ideographic"},
    142342: {"Unified_Ideograph", "Ideographic"},
    142343: {"Unified_Ideograph", "Ideographic"},
    142344: {"Unified_Ideograph", "Ideographic"},
    142345: {"Unified_Ideograph", "Ideographic"},
    142346: {"Unified_Ideograph", "Ideographic"},
    142347: {"Unified_Ideograph", "Ideographic"},
    142348: {"Unified_Ideograph", "Ideographic"},
    142349: {"Unified_Ideograph", "Ideographic"},
    142350: {"Unified_Ideograph", "Ideographic"},
    142351: {"Unified_Ideograph", "Ideographic"},
    142352: {"Unified_Ideograph", "Ideographic"},
    142353: {"Unified_Ideograph", "Ideographic"},
    142354: {"Unified_Ideograph", "Ideographic"},
    142355: {"Unified_Ideograph", "Ideographic"},
    142356: {"Unified_Ideograph", "Ideographic"},
    142357: {"Unified_Ideograph", "Ideographic"},
    142358: {"Unified_Ideograph", "Ideographic"},
    142359: {"Unified_Ideograph", "Ideographic"},
    142360: {"Unified_Ideograph", "Ideographic"},
    142361: {"Unified_Ideograph", "Ideographic"},
    142362: {"Unified_Ideograph", "Ideographic"},
    142363: {"Unified_Ideograph", "Ideographic"},
    142364: {"Unified_Ideograph", "Ideographic"},
    142365: {"Unified_Ideograph", "Ideographic"},
    142366: {"Unified_Ideograph", "Ideographic"},
    142367: {"Unified_Ideograph", "Ideographic"},
    142368: {"Unified_Ideograph", "Ideographic"},
    142369: {"Unified_Ideograph", "Ideographic"},
    142370: {"Unified_Ideograph", "Ideographic"},
    142371: {"Unified_Ideograph", "Ideographic"},
    142372: {"Unified_Ideograph", "Ideographic"},
    142373: {"Unified_Ideograph", "Ideographic"},
    142374: {"Unified_Ideograph", "Ideographic"},
    142375: {"Unified_Ideograph", "Ideographic"},
    142376: {"Unified_Ideograph", "Ideographic"},
    142377: {"Unified_Ideograph", "Ideographic"},
    142378: {"Unified_Ideograph", "Ideographic"},
    142379: {"Unified_Ideograph", "Ideographic"},
    142380: {"Unified_Ideograph", "Ideographic"},
    142381: {"Unified_Ideograph", "Ideographic"},
    142382: {"Unified_Ideograph", "Ideographic"},
    142383: {"Unified_Ideograph", "Ideographic"},
    142384: {"Unified_Ideograph", "Ideographic"},
    142385: {"Unified_Ideograph", "Ideographic"},
    142386: {"Unified_Ideograph", "Ideographic"},
    142387: {"Unified_Ideograph", "Ideographic"},
    142388: {"Unified_Ideograph", "Ideographic"},
    142389: {"Unified_Ideograph", "Ideographic"},
    142390: {"Unified_Ideograph", "Ideographic"},
    142391: {"Unified_Ideograph", "Ideographic"},
    142392: {"Unified_Ideograph", "Ideographic"},
    142393: {"Unified_Ideograph", "Ideographic"},
    142394: {"Unified_Ideograph", "Ideographic"},
    142395: {"Unified_Ideograph", "Ideographic"},
    142396: {"Unified_Ideograph", "Ideographic"},
    142397: {"Unified_Ideograph", "Ideographic"},
    142398: {"Unified_Ideograph", "Ideographic"},
    142399: {"Unified_Ideograph", "Ideographic"},
    142400: {"Unified_Ideograph", "Ideographic"},
    142401: {"Unified_Ideograph", "Ideographic"},
    142402: {"Unified_Ideograph", "Ideographic"},
    142403: {"Unified_Ideograph", "Ideographic"},
    142404: {"Unified_Ideograph", "Ideographic"},
    142405: {"Unified_Ideograph", "Ideographic"},
    142406: {"Unified_Ideograph", "Ideographic"},
    142407: {"Unified_Ideograph", "Ideographic"},
    142408: {"Unified_Ideograph", "Ideographic"},
    142409: {"Unified_Ideograph", "Ideographic"},
    142410: {"Unified_Ideograph", "Ideographic"},
    142411: {"Unified_Ideograph", "Ideographic"},
    142412: {"Unified_Ideograph", "Ideographic"},
    142413: {"Unified_Ideograph", "Ideographic"},
    142414: {"Unified_Ideograph", "Ideographic"},
    142415: {"Unified_Ideograph", "Ideographic"},
    142416: {"Unified_Ideograph", "Ideographic"},
    142417: {"Unified_Ideograph", "Ideographic"},
    142418: {"Unified_Ideograph", "Ideographic"},
    142419: {"Unified_Ideograph", "Ideographic"},
    142420: {"Unified_Ideograph", "Ideographic"},
    142421: {"Unified_Ideograph", "Ideographic"},
    142422: {"Unified_Ideograph", "Ideographic"},
    142423: {"Unified_Ideograph", "Ideographic"},
    142424: {"Unified_Ideograph", "Ideographic"},
    142425: {"Unified_Ideograph", "Ideographic"},
    142426: {"Unified_Ideograph", "Ideographic"},
    142427: {"Unified_Ideograph", "Ideographic"},
    142428: {"Unified_Ideograph", "Ideographic"},
    142429: {"Unified_Ideograph", "Ideographic"},
    142430: {"Unified_Ideograph", "Ideographic"},
    142431: {"Unified_Ideograph", "Ideographic"},
    142432: {"Unified_Ideograph", "Ideographic"},
    142433: {"Unified_Ideograph", "Ideographic"},
    142434: {"Unified_Ideograph", "Ideographic"},
    142435: {"Unified_Ideograph", "Ideographic"},
    142436: {"Unified_Ideograph", "Ideographic"},
    142437: {"Unified_Ideograph", "Ideographic"},
    142438: {"Unified_Ideograph", "Ideographic"},
    142439: {"Unified_Ideograph", "Ideographic"},
    142440: {"Unified_Ideograph", "Ideographic"},
    142441: {"Unified_Ideograph", "Ideographic"},
    142442: {"Unified_Ideograph", "Ideographic"},
    142443: {"Unified_Ideograph", "Ideographic"},
    142444: {"Unified_Ideograph", "Ideographic"},
    142445: {"Unified_Ideograph", "Ideographic"},
    142446: {"Unified_Ideograph", "Ideographic"},
    142447: {"Unified_Ideograph", "Ideographic"},
    142448: {"Unified_Ideograph", "Ideographic"},
    142449: {"Unified_Ideograph", "Ideographic"},
    142450: {"Unified_Ideograph", "Ideographic"},
    142451: {"Unified_Ideograph", "Ideographic"},
    142452: {"Unified_Ideograph", "Ideographic"},
    142453: {"Unified_Ideograph", "Ideographic"},
    142454: {"Unified_Ideograph", "Ideographic"},
    142455: {"Unified_Ideograph", "Ideographic"},
    142456: {"Unified_Ideograph", "Ideographic"},
    142457: {"Unified_Ideograph", "Ideographic"},
    142458: {"Unified_Ideograph", "Ideographic"},
    142459: {"Unified_Ideograph", "Ideographic"},
    142460: {"Unified_Ideograph", "Ideographic"},
    142461: {"Unified_Ideograph", "Ideographic"},
    142462: {"Unified_Ideograph", "Ideographic"},
    142463: {"Unified_Ideograph", "Ideographic"},
    142464: {"Unified_Ideograph", "Ideographic"},
    142465: {"Unified_Ideograph", "Ideographic"},
    142466: {"Unified_Ideograph", "Ideographic"},
    142467: {"Unified_Ideograph", "Ideographic"},
    142468: {"Unified_Ideograph", "Ideographic"},
    142469: {"Unified_Ideograph", "Ideographic"},
    142470: {"Unified_Ideograph", "Ideographic"},
    142471: {"Unified_Ideograph", "Ideographic"},
    142472: {"Unified_Ideograph", "Ideographic"},
    142473: {"Unified_Ideograph", "Ideographic"},
    142474: {"Unified_Ideograph", "Ideographic"},
    142475: {"Unified_Ideograph", "Ideographic"},
    142476: {"Unified_Ideograph", "Ideographic"},
    142477: {"Unified_Ideograph", "Ideographic"},
    142478: {"Unified_Ideograph", "Ideographic"},
    142479: {"Unified_Ideograph", "Ideographic"},
    142480: {"Unified_Ideograph", "Ideographic"},
    142481: {"Unified_Ideograph", "Ideographic"},
    142482: {"Unified_Ideograph", "Ideographic"},
    142483: {"Unified_Ideograph", "Ideographic"},
    142484: {"Unified_Ideograph", "Ideographic"},
    142485: {"Unified_Ideograph", "Ideographic"},
    142486: {"Unified_Ideograph", "Ideographic"},
    142487: {"Unified_Ideograph", "Ideographic"},
    142488: {"Unified_Ideograph", "Ideographic"},
    142489: {"Unified_Ideograph", "Ideographic"},
    142490: {"Unified_Ideograph", "Ideographic"},
    142491: {"Unified_Ideograph", "Ideographic"},
    142492: {"Unified_Ideograph", "Ideographic"},
    142493: {"Unified_Ideograph", "Ideographic"},
    142494: {"Unified_Ideograph", "Ideographic"},
    142495: {"Unified_Ideograph", "Ideographic"},
    142496: {"Unified_Ideograph", "Ideographic"},
    142497: {"Unified_Ideograph", "Ideographic"},
    142498: {"Unified_Ideograph", "Ideographic"},
    142499: {"Unified_Ideograph", "Ideographic"},
    142500: {"Unified_Ideograph", "Ideographic"},
    142501: {"Unified_Ideograph", "Ideographic"},
    142502: {"Unified_Ideograph", "Ideographic"},
    142503: {"Unified_Ideograph", "Ideographic"},
    142504: {"Unified_Ideograph", "Ideographic"},
    142505: {"Unified_Ideograph", "Ideographic"},
    142506: {"Unified_Ideograph", "Ideographic"},
    142507: {"Unified_Ideograph", "Ideographic"},
    142508: {"Unified_Ideograph", "Ideographic"},
    142509: {"Unified_Ideograph", "Ideographic"},
    142510: {"Unified_Ideograph", "Ideographic"},
    142511: {"Unified_Ideograph", "Ideographic"},
    142512: {"Unified_Ideograph", "Ideographic"},
    142513: {"Unified_Ideograph", "Ideographic"},
    142514: {"Unified_Ideograph", "Ideographic"},
    142515: {"Unified_Ideograph", "Ideographic"},
    142516: {"Unified_Ideograph", "Ideographic"},
    142517: {"Unified_Ideograph", "Ideographic"},
    142518: {"Unified_Ideograph", "Ideographic"},
    142519: {"Unified_Ideograph", "Ideographic"},
    142520: {"Unified_Ideograph", "Ideographic"},
    142521: {"Unified_Ideograph", "Ideographic"},
    142522: {"Unified_Ideograph", "Ideographic"},
    142523: {"Unified_Ideograph", "Ideographic"},
    142524: {"Unified_Ideograph", "Ideographic"},
    142525: {"Unified_Ideograph", "Ideographic"},
    142526: {"Unified_Ideograph", "Ideographic"},
    142527: {"Unified_Ideograph", "Ideographic"},
    142528: {"Unified_Ideograph", "Ideographic"},
    142529: {"Unified_Ideograph", "Ideographic"},
    142530: {"Unified_Ideograph", "Ideographic"},
    142531: {"Unified_Ideograph", "Ideographic"},
    142532: {"Unified_Ideograph", "Ideographic"},
    142533: {"Unified_Ideograph", "Ideographic"},
    142534: {"Unified_Ideograph", "Ideographic"},
    142535: {"Unified_Ideograph", "Ideographic"},
    142536: {"Unified_Ideograph", "Ideographic"},
    142537: {"Unified_Ideograph", "Ideographic"},
    142538: {"Unified_Ideograph", "Ideographic"},
    142539: {"Unified_Ideograph", "Ideographic"},
    142540: {"Unified_Ideograph", "Ideographic"},
    142541: {"Unified_Ideograph", "Ideographic"},
    142542: {"Unified_Ideograph", "Ideographic"},
    142543: {"Unified_Ideograph", "Ideographic"},
    142544: {"Unified_Ideograph", "Ideographic"},
    142545: {"Unified_Ideograph", "Ideographic"},
    142546: {"Unified_Ideograph", "Ideographic"},
    142547: {"Unified_Ideograph", "Ideographic"},
    142548: {"Unified_Ideograph", "Ideographic"},
    142549: {"Unified_Ideograph", "Ideographic"},
    142550: {"Unified_Ideograph", "Ideographic"},
    142551: {"Unified_Ideograph", "Ideographic"},
    142552: {"Unified_Ideograph", "Ideographic"},
    142553: {"Unified_Ideograph", "Ideographic"},
    142554: {"Unified_Ideograph", "Ideographic"},
    142555: {"Unified_Ideograph", "Ideographic"},
    142556: {"Unified_Ideograph", "Ideographic"},
    142557: {"Unified_Ideograph", "Ideographic"},
    142558: {"Unified_Ideograph", "Ideographic"},
    142559: {"Unified_Ideograph", "Ideographic"},
    142560: {"Unified_Ideograph", "Ideographic"},
    142561: {"Unified_Ideograph", "Ideographic"},
    142562: {"Unified_Ideograph", "Ideographic"},
    142563: {"Unified_Ideograph", "Ideographic"},
    142564: {"Unified_Ideograph", "Ideographic"},
    142565: {"Unified_Ideograph", "Ideographic"},
    142566: {"Unified_Ideograph", "Ideographic"},
    142567: {"Unified_Ideograph", "Ideographic"},
    142568: {"Unified_Ideograph", "Ideographic"},
    142569: {"Unified_Ideograph", "Ideographic"},
    142570: {"Unified_Ideograph", "Ideographic"},
    142571: {"Unified_Ideograph", "Ideographic"},
    142572: {"Unified_Ideograph", "Ideographic"},
    142573: {"Unified_Ideograph", "Ideographic"},
    142574: {"Unified_Ideograph", "Ideographic"},
    142575: {"Unified_Ideograph", "Ideographic"},
    142576: {"Unified_Ideograph", "Ideographic"},
    142577: {"Unified_Ideograph", "Ideographic"},
    142578: {"Unified_Ideograph", "Ideographic"},
    142579: {"Unified_Ideograph", "Ideographic"},
    142580: {"Unified_Ideograph", "Ideographic"},
    142581: {"Unified_Ideograph", "Ideographic"},
    142582: {"Unified_Ideograph", "Ideographic"},
    142583: {"Unified_Ideograph", "Ideographic"},
    142584: {"Unified_Ideograph", "Ideographic"},
    142585: {"Unified_Ideograph", "Ideographic"},
    142586: {"Unified_Ideograph", "Ideographic"},
    142587: {"Unified_Ideograph", "Ideographic"},
    142588: {"Unified_Ideograph", "Ideographic"},
    142589: {"Unified_Ideograph", "Ideographic"},
    142590: {"Unified_Ideograph", "Ideographic"},
    142591: {"Unified_Ideograph", "Ideographic"},
    142592: {"Unified_Ideograph", "Ideographic"},
    142593: {"Unified_Ideograph", "Ideographic"},
    142594: {"Unified_Ideograph", "Ideographic"},
    142595: {"Unified_Ideograph", "Ideographic"},
    142596: {"Unified_Ideograph", "Ideographic"},
    142597: {"Unified_Ideograph", "Ideographic"},
    142598: {"Unified_Ideograph", "Ideographic"},
    142599: {"Unified_Ideograph", "Ideographic"},
    142600: {"Unified_Ideograph", "Ideographic"},
    142601: {"Unified_Ideograph", "Ideographic"},
    142602: {"Unified_Ideograph", "Ideographic"},
    142603: {"Unified_Ideograph", "Ideographic"},
    142604: {"Unified_Ideograph", "Ideographic"},
    142605: {"Unified_Ideograph", "Ideographic"},
    142606: {"Unified_Ideograph", "Ideographic"},
    142607: {"Unified_Ideograph", "Ideographic"},
    142608: {"Unified_Ideograph", "Ideographic"},
    142609: {"Unified_Ideograph", "Ideographic"},
    142610: {"Unified_Ideograph", "Ideographic"},
    142611: {"Unified_Ideograph", "Ideographic"},
    142612: {"Unified_Ideograph", "Ideographic"},
    142613: {"Unified_Ideograph", "Ideographic"},
    142614: {"Unified_Ideograph", "Ideographic"},
    142615: {"Unified_Ideograph", "Ideographic"},
    142616: {"Unified_Ideograph", "Ideographic"},
    142617: {"Unified_Ideograph", "Ideographic"},
    142618: {"Unified_Ideograph", "Ideographic"},
    142619: {"Unified_Ideograph", "Ideographic"},
    142620: {"Unified_Ideograph", "Ideographic"},
    142621: {"Unified_Ideograph", "Ideographic"},
    142622: {"Unified_Ideograph", "Ideographic"},
    142623: {"Unified_Ideograph", "Ideographic"},
    142624: {"Unified_Ideograph", "Ideographic"},
    142625: {"Unified_Ideograph", "Ideographic"},
    142626: {"Unified_Ideograph", "Ideographic"},
    142627: {"Unified_Ideograph", "Ideographic"},
    142628: {"Unified_Ideograph", "Ideographic"},
    142629: {"Unified_Ideograph", "Ideographic"},
    142630: {"Unified_Ideograph", "Ideographic"},
    142631: {"Unified_Ideograph", "Ideographic"},
    142632: {"Unified_Ideograph", "Ideographic"},
    142633: {"Unified_Ideograph", "Ideographic"},
    142634: {"Unified_Ideograph", "Ideographic"},
    142635: {"Unified_Ideograph", "Ideographic"},
    142636: {"Unified_Ideograph", "Ideographic"},
    142637: {"Unified_Ideograph", "Ideographic"},
    142638: {"Unified_Ideograph", "Ideographic"},
    142639: {"Unified_Ideograph", "Ideographic"},
    142640: {"Unified_Ideograph", "Ideographic"},
    142641: {"Unified_Ideograph", "Ideographic"},
    142642: {"Unified_Ideograph", "Ideographic"},
    142643: {"Unified_Ideograph", "Ideographic"},
    142644: {"Unified_Ideograph", "Ideographic"},
    142645: {"Unified_Ideograph", "Ideographic"},
    142646: {"Unified_Ideograph", "Ideographic"},
    142647: {"Unified_Ideograph", "Ideographic"},
    142648: {"Unified_Ideograph", "Ideographic"},
    142649: {"Unified_Ideograph", "Ideographic"},
    142650: {"Unified_Ideograph", "Ideographic"},
    142651: {"Unified_Ideograph", "Ideographic"},
    142652: {"Unified_Ideograph", "Ideographic"},
    142653: {"Unified_Ideograph", "Ideographic"},
    142654: {"Unified_Ideograph", "Ideographic"},
    142655: {"Unified_Ideograph", "Ideographic"},
    142656: {"Unified_Ideograph", "Ideographic"},
    142657: {"Unified_Ideograph", "Ideographic"},
    142658: {"Unified_Ideograph", "Ideographic"},
    142659: {"Unified_Ideograph", "Ideographic"},
    142660: {"Unified_Ideograph", "Ideographic"},
    142661: {"Unified_Ideograph", "Ideographic"},
    142662: {"Unified_Ideograph", "Ideographic"},
    142663: {"Unified_Ideograph", "Ideographic"},
    142664: {"Unified_Ideograph", "Ideographic"},
    142665: {"Unified_Ideograph", "Ideographic"},
    142666: {"Unified_Ideograph", "Ideographic"},
    142667: {"Unified_Ideograph", "Ideographic"},
    142668: {"Unified_Ideograph", "Ideographic"},
    142669: {"Unified_Ideograph", "Ideographic"},
    142670: {"Unified_Ideograph", "Ideographic"},
    142671: {"Unified_Ideograph", "Ideographic"},
    142672: {"Unified_Ideograph", "Ideographic"},
    142673: {"Unified_Ideograph", "Ideographic"},
    142674: {"Unified_Ideograph", "Ideographic"},
    142675: {"Unified_Ideograph", "Ideographic"},
    142676: {"Unified_Ideograph", "Ideographic"},
    142677: {"Unified_Ideograph", "Ideographic"},
    142678: {"Unified_Ideograph", "Ideographic"},
    142679: {"Unified_Ideograph", "Ideographic"},
    142680: {"Unified_Ideograph", "Ideographic"},
    142681: {"Unified_Ideograph", "Ideographic"},
    142682: {"Unified_Ideograph", "Ideographic"},
    142683: {"Unified_Ideograph", "Ideographic"},
    142684: {"Unified_Ideograph", "Ideographic"},
    142685: {"Unified_Ideograph", "Ideographic"},
    142686: {"Unified_Ideograph", "Ideographic"},
    142687: {"Unified_Ideograph", "Ideographic"},
    142688: {"Unified_Ideograph", "Ideographic"},
    142689: {"Unified_Ideograph", "Ideographic"},
    142690: {"Unified_Ideograph", "Ideographic"},
    142691: {"Unified_Ideograph", "Ideographic"},
    142692: {"Unified_Ideograph", "Ideographic"},
    142693: {"Unified_Ideograph", "Ideographic"},
    142694: {"Unified_Ideograph", "Ideographic"},
    142695: {"Unified_Ideograph", "Ideographic"},
    142696: {"Unified_Ideograph", "Ideographic"},
    142697: {"Unified_Ideograph", "Ideographic"},
    142698: {"Unified_Ideograph", "Ideographic"},
    142699: {"Unified_Ideograph", "Ideographic"},
    142700: {"Unified_Ideograph", "Ideographic"},
    142701: {"Unified_Ideograph", "Ideographic"},
    142702: {"Unified_Ideograph", "Ideographic"},
    142703: {"Unified_Ideograph", "Ideographic"},
    142704: {"Unified_Ideograph", "Ideographic"},
    142705: {"Unified_Ideograph", "Ideographic"},
    142706: {"Unified_Ideograph", "Ideographic"},
    142707: {"Unified_Ideograph", "Ideographic"},
    142708: {"Unified_Ideograph", "Ideographic"},
    142709: {"Unified_Ideograph", "Ideographic"},
    142710: {"Unified_Ideograph", "Ideographic"},
    142711: {"Unified_Ideograph", "Ideographic"},
    142712: {"Unified_Ideograph", "Ideographic"},
    142713: {"Unified_Ideograph", "Ideographic"},
    142714: {"Unified_Ideograph", "Ideographic"},
    142715: {"Unified_Ideograph", "Ideographic"},
    142716: {"Unified_Ideograph", "Ideographic"},
    142717: {"Unified_Ideograph", "Ideographic"},
    142718: {"Unified_Ideograph", "Ideographic"},
    142719: {"Unified_Ideograph", "Ideographic"},
    142720: {"Unified_Ideograph", "Ideographic"},
    142721: {"Unified_Ideograph", "Ideographic"},
    142722: {"Unified_Ideograph", "Ideographic"},
    142723: {"Unified_Ideograph", "Ideographic"},
    142724: {"Unified_Ideograph", "Ideographic"},
    142725: {"Unified_Ideograph", "Ideographic"},
    142726: {"Unified_Ideograph", "Ideographic"},
    142727: {"Unified_Ideograph", "Ideographic"},
    142728: {"Unified_Ideograph", "Ideographic"},
    142729: {"Unified_Ideograph", "Ideographic"},
    142730: {"Unified_Ideograph", "Ideographic"},
    142731: {"Unified_Ideograph", "Ideographic"},
    142732: {"Unified_Ideograph", "Ideographic"},
    142733: {"Unified_Ideograph", "Ideographic"},
    142734: {"Unified_Ideograph", "Ideographic"},
    142735: {"Unified_Ideograph", "Ideographic"},
    142736: {"Unified_Ideograph", "Ideographic"},
    142737: {"Unified_Ideograph", "Ideographic"},
    142738: {"Unified_Ideograph", "Ideographic"},
    142739: {"Unified_Ideograph", "Ideographic"},
    142740: {"Unified_Ideograph", "Ideographic"},
    142741: {"Unified_Ideograph", "Ideographic"},
    142742: {"Unified_Ideograph", "Ideographic"},
    142743: {"Unified_Ideograph", "Ideographic"},
    142744: {"Unified_Ideograph", "Ideographic"},
    142745: {"Unified_Ideograph", "Ideographic"},
    142746: {"Unified_Ideograph", "Ideographic"},
    142747: {"Unified_Ideograph", "Ideographic"},
    142748: {"Unified_Ideograph", "Ideographic"},
    142749: {"Unified_Ideograph", "Ideographic"},
    142750: {"Unified_Ideograph", "Ideographic"},
    142751: {"Unified_Ideograph", "Ideographic"},
    142752: {"Unified_Ideograph", "Ideographic"},
    142753: {"Unified_Ideograph", "Ideographic"},
    142754: {"Unified_Ideograph", "Ideographic"},
    142755: {"Unified_Ideograph", "Ideographic"},
    142756: {"Unified_Ideograph", "Ideographic"},
    142757: {"Unified_Ideograph", "Ideographic"},
    142758: {"Unified_Ideograph", "Ideographic"},
    142759: {"Unified_Ideograph", "Ideographic"},
    142760: {"Unified_Ideograph", "Ideographic"},
    142761: {"Unified_Ideograph", "Ideographic"},
    142762: {"Unified_Ideograph", "Ideographic"},
    142763: {"Unified_Ideograph", "Ideographic"},
    142764: {"Unified_Ideograph", "Ideographic"},
    142765: {"Unified_Ideograph", "Ideographic"},
    142766: {"Unified_Ideograph", "Ideographic"},
    142767: {"Unified_Ideograph", "Ideographic"},
    142768: {"Unified_Ideograph", "Ideographic"},
    142769: {"Unified_Ideograph", "Ideographic"},
    142770: {"Unified_Ideograph", "Ideographic"},
    142771: {"Unified_Ideograph", "Ideographic"},
    142772: {"Unified_Ideograph", "Ideographic"},
    142773: {"Unified_Ideograph", "Ideographic"},
    142774: {"Unified_Ideograph", "Ideographic"},
    142775: {"Unified_Ideograph", "Ideographic"},
    142776: {"Unified_Ideograph", "Ideographic"},
    142777: {"Unified_Ideograph", "Ideographic"},
    142778: {"Unified_Ideograph", "Ideographic"},
    142779: {"Unified_Ideograph", "Ideographic"},
    142780: {"Unified_Ideograph", "Ideographic"},
    142781: {"Unified_Ideograph", "Ideographic"},
    142782: {"Unified_Ideograph", "Ideographic"},
    142783: {"Unified_Ideograph", "Ideographic"},
    142784: {"Unified_Ideograph", "Ideographic"},
    142785: {"Unified_Ideograph", "Ideographic"},
    142786: {"Unified_Ideograph", "Ideographic"},
    142787: {"Unified_Ideograph", "Ideographic"},
    142788: {"Unified_Ideograph", "Ideographic"},
    142789: {"Unified_Ideograph", "Ideographic"},
    142790: {"Unified_Ideograph", "Ideographic"},
    142791: {"Unified_Ideograph", "Ideographic"},
    142792: {"Unified_Ideograph", "Ideographic"},
    142793: {"Unified_Ideograph", "Ideographic"},
    142794: {"Unified_Ideograph", "Ideographic"},
    142795: {"Unified_Ideograph", "Ideographic"},
    142796: {"Unified_Ideograph", "Ideographic"},
    142797: {"Unified_Ideograph", "Ideographic"},
    142798: {"Unified_Ideograph", "Ideographic"},
    142799: {"Unified_Ideograph", "Ideographic"},
    142800: {"Unified_Ideograph", "Ideographic"},
    142801: {"Unified_Ideograph", "Ideographic"},
    142802: {"Unified_Ideograph", "Ideographic"},
    142803: {"Unified_Ideograph", "Ideographic"},
    142804: {"Unified_Ideograph", "Ideographic"},
    142805: {"Unified_Ideograph", "Ideographic"},
    142806: {"Unified_Ideograph", "Ideographic"},
    142807: {"Unified_Ideograph", "Ideographic"},
    142808: {"Unified_Ideograph", "Ideographic"},
    142809: {"Unified_Ideograph", "Ideographic"},
    142810: {"Unified_Ideograph", "Ideographic"},
    142811: {"Unified_Ideograph", "Ideographic"},
    142812: {"Unified_Ideograph", "Ideographic"},
    142813: {"Unified_Ideograph", "Ideographic"},
    142814: {"Unified_Ideograph", "Ideographic"},
    142815: {"Unified_Ideograph", "Ideographic"},
    142816: {"Unified_Ideograph", "Ideographic"},
    142817: {"Unified_Ideograph", "Ideographic"},
    142818: {"Unified_Ideograph", "Ideographic"},
    142819: {"Unified_Ideograph", "Ideographic"},
    142820: {"Unified_Ideograph", "Ideographic"},
    142821: {"Unified_Ideograph", "Ideographic"},
    142822: {"Unified_Ideograph", "Ideographic"},
    142823: {"Unified_Ideograph", "Ideographic"},
    142824: {"Unified_Ideograph", "Ideographic"},
    142825: {"Unified_Ideograph", "Ideographic"},
    142826: {"Unified_Ideograph", "Ideographic"},
    142827: {"Unified_Ideograph", "Ideographic"},
    142828: {"Unified_Ideograph", "Ideographic"},
    142829: {"Unified_Ideograph", "Ideographic"},
    142830: {"Unified_Ideograph", "Ideographic"},
    142831: {"Unified_Ideograph", "Ideographic"},
    142832: {"Unified_Ideograph", "Ideographic"},
    142833: {"Unified_Ideograph", "Ideographic"},
    142834: {"Unified_Ideograph", "Ideographic"},
    142835: {"Unified_Ideograph", "Ideographic"},
    142836: {"Unified_Ideograph", "Ideographic"},
    142837: {"Unified_Ideograph", "Ideographic"},
    142838: {"Unified_Ideograph", "Ideographic"},
    142839: {"Unified_Ideograph", "Ideographic"},
    142840: {"Unified_Ideograph", "Ideographic"},
    142841: {"Unified_Ideograph", "Ideographic"},
    142842: {"Unified_Ideograph", "Ideographic"},
    142843: {"Unified_Ideograph", "Ideographic"},
    142844: {"Unified_Ideograph", "Ideographic"},
    142845: {"Unified_Ideograph", "Ideographic"},
    142846: {"Unified_Ideograph", "Ideographic"},
    142847: {"Unified_Ideograph", "Ideographic"},
    142848: {"Unified_Ideograph", "Ideographic"},
    142849: {"Unified_Ideograph", "Ideographic"},
    142850: {"Unified_Ideograph", "Ideographic"},
    142851: {"Unified_Ideograph", "Ideographic"},
    142852: {"Unified_Ideograph", "Ideographic"},
    142853: {"Unified_Ideograph", "Ideographic"},
    142854: {"Unified_Ideograph", "Ideographic"},
    142855: {"Unified_Ideograph", "Ideographic"},
    142856: {"Unified_Ideograph", "Ideographic"},
    142857: {"Unified_Ideograph", "Ideographic"},
    142858: {"Unified_Ideograph", "Ideographic"},
    142859: {"Unified_Ideograph", "Ideographic"},
    142860: {"Unified_Ideograph", "Ideographic"},
    142861: {"Unified_Ideograph", "Ideographic"},
    142862: {"Unified_Ideograph", "Ideographic"},
    142863: {"Unified_Ideograph", "Ideographic"},
    142864: {"Unified_Ideograph", "Ideographic"},
    142865: {"Unified_Ideograph", "Ideographic"},
    142866: {"Unified_Ideograph", "Ideographic"},
    142867: {"Unified_Ideograph", "Ideographic"},
    142868: {"Unified_Ideograph", "Ideographic"},
    142869: {"Unified_Ideograph", "Ideographic"},
    142870: {"Unified_Ideograph", "Ideographic"},
    142871: {"Unified_Ideograph", "Ideographic"},
    142872: {"Unified_Ideograph", "Ideographic"},
    142873: {"Unified_Ideograph", "Ideographic"},
    142874: {"Unified_Ideograph", "Ideographic"},
    142875: {"Unified_Ideograph", "Ideographic"},
    142876: {"Unified_Ideograph", "Ideographic"},
    142877: {"Unified_Ideograph", "Ideographic"},
    142878: {"Unified_Ideograph", "Ideographic"},
    142879: {"Unified_Ideograph", "Ideographic"},
    142880: {"Unified_Ideograph", "Ideographic"},
    142881: {"Unified_Ideograph", "Ideographic"},
    142882: {"Unified_Ideograph", "Ideographic"},
    142883: {"Unified_Ideograph", "Ideographic"},
    142884: {"Unified_Ideograph", "Ideographic"},
    142885: {"Unified_Ideograph", "Ideographic"},
    142886: {"Unified_Ideograph", "Ideographic"},
    142887: {"Unified_Ideograph", "Ideographic"},
    142888: {"Unified_Ideograph", "Ideographic"},
    142889: {"Unified_Ideograph", "Ideographic"},
    142890: {"Unified_Ideograph", "Ideographic"},
    142891: {"Unified_Ideograph", "Ideographic"},
    142892: {"Unified_Ideograph", "Ideographic"},
    142893: {"Unified_Ideograph", "Ideographic"},
    142894: {"Unified_Ideograph", "Ideographic"},
    142895: {"Unified_Ideograph", "Ideographic"},
    142896: {"Unified_Ideograph", "Ideographic"},
    142897: {"Unified_Ideograph", "Ideographic"},
    142898: {"Unified_Ideograph", "Ideographic"},
    142899: {"Unified_Ideograph", "Ideographic"},
    142900: {"Unified_Ideograph", "Ideographic"},
    142901: {"Unified_Ideograph", "Ideographic"},
    142902: {"Unified_Ideograph", "Ideographic"},
    142903: {"Unified_Ideograph", "Ideographic"},
    142904: {"Unified_Ideograph", "Ideographic"},
    142905: {"Unified_Ideograph", "Ideographic"},
    142906: {"Unified_Ideograph", "Ideographic"},
    142907: {"Unified_Ideograph", "Ideographic"},
    142908: {"Unified_Ideograph", "Ideographic"},
    142909: {"Unified_Ideograph", "Ideographic"},
    142910: {"Unified_Ideograph", "Ideographic"},
    142911: {"Unified_Ideograph", "Ideographic"},
    142912: {"Unified_Ideograph", "Ideographic"},
    142913: {"Unified_Ideograph", "Ideographic"},
    142914: {"Unified_Ideograph", "Ideographic"},
    142915: {"Unified_Ideograph", "Ideographic"},
    142916: {"Unified_Ideograph", "Ideographic"},
    142917: {"Unified_Ideograph", "Ideographic"},
    142918: {"Unified_Ideograph", "Ideographic"},
    142919: {"Unified_Ideograph", "Ideographic"},
    142920: {"Unified_Ideograph", "Ideographic"},
    142921: {"Unified_Ideograph", "Ideographic"},
    142922: {"Unified_Ideograph", "Ideographic"},
    142923: {"Unified_Ideograph", "Ideographic"},
    142924: {"Unified_Ideograph", "Ideographic"},
    142925: {"Unified_Ideograph", "Ideographic"},
    142926: {"Unified_Ideograph", "Ideographic"},
    142927: {"Unified_Ideograph", "Ideographic"},
    142928: {"Unified_Ideograph", "Ideographic"},
    142929: {"Unified_Ideograph", "Ideographic"},
    142930: {"Unified_Ideograph", "Ideographic"},
    142931: {"Unified_Ideograph", "Ideographic"},
    142932: {"Unified_Ideograph", "Ideographic"},
    142933: {"Unified_Ideograph", "Ideographic"},
    142934: {"Unified_Ideograph", "Ideographic"},
    142935: {"Unified_Ideograph", "Ideographic"},
    142936: {"Unified_Ideograph", "Ideographic"},
    142937: {"Unified_Ideograph", "Ideographic"},
    142938: {"Unified_Ideograph", "Ideographic"},
    142939: {"Unified_Ideograph", "Ideographic"},
    142940: {"Unified_Ideograph", "Ideographic"},
    142941: {"Unified_Ideograph", "Ideographic"},
    142942: {"Unified_Ideograph", "Ideographic"},
    142943: {"Unified_Ideograph", "Ideographic"},
    142944: {"Unified_Ideograph", "Ideographic"},
    142945: {"Unified_Ideograph", "Ideographic"},
    142946: {"Unified_Ideograph", "Ideographic"},
    142947: {"Unified_Ideograph", "Ideographic"},
    142948: {"Unified_Ideograph", "Ideographic"},
    142949: {"Unified_Ideograph", "Ideographic"},
    142950: {"Unified_Ideograph", "Ideographic"},
    142951: {"Unified_Ideograph", "Ideographic"},
    142952: {"Unified_Ideograph", "Ideographic"},
    142953: {"Unified_Ideograph", "Ideographic"},
    142954: {"Unified_Ideograph", "Ideographic"},
    142955: {"Unified_Ideograph", "Ideographic"},
    142956: {"Unified_Ideograph", "Ideographic"},
    142957: {"Unified_Ideograph", "Ideographic"},
    142958: {"Unified_Ideograph", "Ideographic"},
    142959: {"Unified_Ideograph", "Ideographic"},
    142960: {"Unified_Ideograph", "Ideographic"},
    142961: {"Unified_Ideograph", "Ideographic"},
    142962: {"Unified_Ideograph", "Ideographic"},
    142963: {"Unified_Ideograph", "Ideographic"},
    142964: {"Unified_Ideograph", "Ideographic"},
    142965: {"Unified_Ideograph", "Ideographic"},
    142966: {"Unified_Ideograph", "Ideographic"},
    142967: {"Unified_Ideograph", "Ideographic"},
    142968: {"Unified_Ideograph", "Ideographic"},
    142969: {"Unified_Ideograph", "Ideographic"},
    142970: {"Unified_Ideograph", "Ideographic"},
    142971: {"Unified_Ideograph", "Ideographic"},
    142972: {"Unified_Ideograph", "Ideographic"},
    142973: {"Unified_Ideograph", "Ideographic"},
    142974: {"Unified_Ideograph", "Ideographic"},
    142975: {"Unified_Ideograph", "Ideographic"},
    142976: {"Unified_Ideograph", "Ideographic"},
    142977: {"Unified_Ideograph", "Ideographic"},
    142978: {"Unified_Ideograph", "Ideographic"},
    142979: {"Unified_Ideograph", "Ideographic"},
    142980: {"Unified_Ideograph", "Ideographic"},
    142981: {"Unified_Ideograph", "Ideographic"},
    142982: {"Unified_Ideograph", "Ideographic"},
    142983: {"Unified_Ideograph", "Ideographic"},
    142984: {"Unified_Ideograph", "Ideographic"},
    142985: {"Unified_Ideograph", "Ideographic"},
    142986: {"Unified_Ideograph", "Ideographic"},
    142987: {"Unified_Ideograph", "Ideographic"},
    142988: {"Unified_Ideograph", "Ideographic"},
    142989: {"Unified_Ideograph", "Ideographic"},
    142990: {"Unified_Ideograph", "Ideographic"},
    142991: {"Unified_Ideograph", "Ideographic"},
    142992: {"Unified_Ideograph", "Ideographic"},
    142993: {"Unified_Ideograph", "Ideographic"},
    142994: {"Unified_Ideograph", "Ideographic"},
    142995: {"Unified_Ideograph", "Ideographic"},
    142996: {"Unified_Ideograph", "Ideographic"},
    142997: {"Unified_Ideograph", "Ideographic"},
    142998: {"Unified_Ideograph", "Ideographic"},
    142999: {"Unified_Ideograph", "Ideographic"},
    143000: {"Unified_Ideograph", "Ideographic"},
    143001: {"Unified_Ideograph", "Ideographic"},
    143002: {"Unified_Ideograph", "Ideographic"},
    143003: {"Unified_Ideograph", "Ideographic"},
    143004: {"Unified_Ideograph", "Ideographic"},
    143005: {"Unified_Ideograph", "Ideographic"},
    143006: {"Unified_Ideograph", "Ideographic"},
    143007: {"Unified_Ideograph", "Ideographic"},
    143008: {"Unified_Ideograph", "Ideographic"},
    143009: {"Unified_Ideograph", "Ideographic"},
    143010: {"Unified_Ideograph", "Ideographic"},
    143011: {"Unified_Ideograph", "Ideographic"},
    143012: {"Unified_Ideograph", "Ideographic"},
    143013: {"Unified_Ideograph", "Ideographic"},
    143014: {"Unified_Ideograph", "Ideographic"},
    143015: {"Unified_Ideograph", "Ideographic"},
    143016: {"Unified_Ideograph", "Ideographic"},
    143017: {"Unified_Ideograph", "Ideographic"},
    143018: {"Unified_Ideograph", "Ideographic"},
    143019: {"Unified_Ideograph", "Ideographic"},
    143020: {"Unified_Ideograph", "Ideographic"},
    143021: {"Unified_Ideograph", "Ideographic"},
    143022: {"Unified_Ideograph", "Ideographic"},
    143023: {"Unified_Ideograph", "Ideographic"},
    143024: {"Unified_Ideograph", "Ideographic"},
    143025: {"Unified_Ideograph", "Ideographic"},
    143026: {"Unified_Ideograph", "Ideographic"},
    143027: {"Unified_Ideograph", "Ideographic"},
    143028: {"Unified_Ideograph", "Ideographic"},
    143029: {"Unified_Ideograph", "Ideographic"},
    143030: {"Unified_Ideograph", "Ideographic"},
    143031: {"Unified_Ideograph", "Ideographic"},
    143032: {"Unified_Ideograph", "Ideographic"},
    143033: {"Unified_Ideograph", "Ideographic"},
    143034: {"Unified_Ideograph", "Ideographic"},
    143035: {"Unified_Ideograph", "Ideographic"},
    143036: {"Unified_Ideograph", "Ideographic"},
    143037: {"Unified_Ideograph", "Ideographic"},
    143038: {"Unified_Ideograph", "Ideographic"},
    143039: {"Unified_Ideograph", "Ideographic"},
    143040: {"Unified_Ideograph", "Ideographic"},
    143041: {"Unified_Ideograph", "Ideographic"},
    143042: {"Unified_Ideograph", "Ideographic"},
    143043: {"Unified_Ideograph", "Ideographic"},
    143044: {"Unified_Ideograph", "Ideographic"},
    143045: {"Unified_Ideograph", "Ideographic"},
    143046: {"Unified_Ideograph", "Ideographic"},
    143047: {"Unified_Ideograph", "Ideographic"},
    143048: {"Unified_Ideograph", "Ideographic"},
    143049: {"Unified_Ideograph", "Ideographic"},
    143050: {"Unified_Ideograph", "Ideographic"},
    143051: {"Unified_Ideograph", "Ideographic"},
    143052: {"Unified_Ideograph", "Ideographic"},
    143053: {"Unified_Ideograph", "Ideographic"},
    143054: {"Unified_Ideograph", "Ideographic"},
    143055: {"Unified_Ideograph", "Ideographic"},
    143056: {"Unified_Ideograph", "Ideographic"},
    143057: {"Unified_Ideograph", "Ideographic"},
    143058: {"Unified_Ideograph", "Ideographic"},
    143059: {"Unified_Ideograph", "Ideographic"},
    143060: {"Unified_Ideograph", "Ideographic"},
    143061: {"Unified_Ideograph", "Ideographic"},
    143062: {"Unified_Ideograph", "Ideographic"},
    143063: {"Unified_Ideograph", "Ideographic"},
    143064: {"Unified_Ideograph", "Ideographic"},
    143065: {"Unified_Ideograph", "Ideographic"},
    143066: {"Unified_Ideograph", "Ideographic"},
    143067: {"Unified_Ideograph", "Ideographic"},
    143068: {"Unified_Ideograph", "Ideographic"},
    143069: {"Unified_Ideograph", "Ideographic"},
    143070: {"Unified_Ideograph", "Ideographic"},
    143071: {"Unified_Ideograph", "Ideographic"},
    143072: {"Unified_Ideograph", "Ideographic"},
    143073: {"Unified_Ideograph", "Ideographic"},
    143074: {"Unified_Ideograph", "Ideographic"},
    143075: {"Unified_Ideograph", "Ideographic"},
    143076: {"Unified_Ideograph", "Ideographic"},
    143077: {"Unified_Ideograph", "Ideographic"},
    143078: {"Unified_Ideograph", "Ideographic"},
    143079: {"Unified_Ideograph", "Ideographic"},
    143080: {"Unified_Ideograph", "Ideographic"},
    143081: {"Unified_Ideograph", "Ideographic"},
    143082: {"Unified_Ideograph", "Ideographic"},
    143083: {"Unified_Ideograph", "Ideographic"},
    143084: {"Unified_Ideograph", "Ideographic"},
    143085: {"Unified_Ideograph", "Ideographic"},
    143086: {"Unified_Ideograph", "Ideographic"},
    143087: {"Unified_Ideograph", "Ideographic"},
    143088: {"Unified_Ideograph", "Ideographic"},
    143089: {"Unified_Ideograph", "Ideographic"},
    143090: {"Unified_Ideograph", "Ideographic"},
    143091: {"Unified_Ideograph", "Ideographic"},
    143092: {"Unified_Ideograph", "Ideographic"},
    143093: {"Unified_Ideograph", "Ideographic"},
    143094: {"Unified_Ideograph", "Ideographic"},
    143095: {"Unified_Ideograph", "Ideographic"},
    143096: {"Unified_Ideograph", "Ideographic"},
    143097: {"Unified_Ideograph", "Ideographic"},
    143098: {"Unified_Ideograph", "Ideographic"},
    143099: {"Unified_Ideograph", "Ideographic"},
    143100: {"Unified_Ideograph", "Ideographic"},
    143101: {"Unified_Ideograph", "Ideographic"},
    143102: {"Unified_Ideograph", "Ideographic"},
    143103: {"Unified_Ideograph", "Ideographic"},
    143104: {"Unified_Ideograph", "Ideographic"},
    143105: {"Unified_Ideograph", "Ideographic"},
    143106: {"Unified_Ideograph", "Ideographic"},
    143107: {"Unified_Ideograph", "Ideographic"},
    143108: {"Unified_Ideograph", "Ideographic"},
    143109: {"Unified_Ideograph", "Ideographic"},
    143110: {"Unified_Ideograph", "Ideographic"},
    143111: {"Unified_Ideograph", "Ideographic"},
    143112: {"Unified_Ideograph", "Ideographic"},
    143113: {"Unified_Ideograph", "Ideographic"},
    143114: {"Unified_Ideograph", "Ideographic"},
    143115: {"Unified_Ideograph", "Ideographic"},
    143116: {"Unified_Ideograph", "Ideographic"},
    143117: {"Unified_Ideograph", "Ideographic"},
    143118: {"Unified_Ideograph", "Ideographic"},
    143119: {"Unified_Ideograph", "Ideographic"},
    143120: {"Unified_Ideograph", "Ideographic"},
    143121: {"Unified_Ideograph", "Ideographic"},
    143122: {"Unified_Ideograph", "Ideographic"},
    143123: {"Unified_Ideograph", "Ideographic"},
    143124: {"Unified_Ideograph", "Ideographic"},
    143125: {"Unified_Ideograph", "Ideographic"},
    143126: {"Unified_Ideograph", "Ideographic"},
    143127: {"Unified_Ideograph", "Ideographic"},
    143128: {"Unified_Ideograph", "Ideographic"},
    143129: {"Unified_Ideograph", "Ideographic"},
    143130: {"Unified_Ideograph", "Ideographic"},
    143131: {"Unified_Ideograph", "Ideographic"},
    143132: {"Unified_Ideograph", "Ideographic"},
    143133: {"Unified_Ideograph", "Ideographic"},
    143134: {"Unified_Ideograph", "Ideographic"},
    143135: {"Unified_Ideograph", "Ideographic"},
    143136: {"Unified_Ideograph", "Ideographic"},
    143137: {"Unified_Ideograph", "Ideographic"},
    143138: {"Unified_Ideograph", "Ideographic"},
    143139: {"Unified_Ideograph", "Ideographic"},
    143140: {"Unified_Ideograph", "Ideographic"},
    143141: {"Unified_Ideograph", "Ideographic"},
    143142: {"Unified_Ideograph", "Ideographic"},
    143143: {"Unified_Ideograph", "Ideographic"},
    143144: {"Unified_Ideograph", "Ideographic"},
    143145: {"Unified_Ideograph", "Ideographic"},
    143146: {"Unified_Ideograph", "Ideographic"},
    143147: {"Unified_Ideograph", "Ideographic"},
    143148: {"Unified_Ideograph", "Ideographic"},
    143149: {"Unified_Ideograph", "Ideographic"},
    143150: {"Unified_Ideograph", "Ideographic"},
    143151: {"Unified_Ideograph", "Ideographic"},
    143152: {"Unified_Ideograph", "Ideographic"},
    143153: {"Unified_Ideograph", "Ideographic"},
    143154: {"Unified_Ideograph", "Ideographic"},
    143155: {"Unified_Ideograph", "Ideographic"},
    143156: {"Unified_Ideograph", "Ideographic"},
    143157: {"Unified_Ideograph", "Ideographic"},
    143158: {"Unified_Ideograph", "Ideographic"},
    143159: {"Unified_Ideograph", "Ideographic"},
    143160: {"Unified_Ideograph", "Ideographic"},
    143161: {"Unified_Ideograph", "Ideographic"},
    143162: {"Unified_Ideograph", "Ideographic"},
    143163: {"Unified_Ideograph", "Ideographic"},
    143164: {"Unified_Ideograph", "Ideographic"},
    143165: {"Unified_Ideograph", "Ideographic"},
    143166: {"Unified_Ideograph", "Ideographic"},
    143167: {"Unified_Ideograph", "Ideographic"},
    143168: {"Unified_Ideograph", "Ideographic"},
    143169: {"Unified_Ideograph", "Ideographic"},
    143170: {"Unified_Ideograph", "Ideographic"},
    143171: {"Unified_Ideograph", "Ideographic"},
    143172: {"Unified_Ideograph", "Ideographic"},
    143173: {"Unified_Ideograph", "Ideographic"},
    143174: {"Unified_Ideograph", "Ideographic"},
    143175: {"Unified_Ideograph", "Ideographic"},
    143176: {"Unified_Ideograph", "Ideographic"},
    143177: {"Unified_Ideograph", "Ideographic"},
    143178: {"Unified_Ideograph", "Ideographic"},
    143179: {"Unified_Ideograph", "Ideographic"},
    143180: {"Unified_Ideograph", "Ideographic"},
    143181: {"Unified_Ideograph", "Ideographic"},
    143182: {"Unified_Ideograph", "Ideographic"},
    143183: {"Unified_Ideograph", "Ideographic"},
    143184: {"Unified_Ideograph", "Ideographic"},
    143185: {"Unified_Ideograph", "Ideographic"},
    143186: {"Unified_Ideograph", "Ideographic"},
    143187: {"Unified_Ideograph", "Ideographic"},
    143188: {"Unified_Ideograph", "Ideographic"},
    143189: {"Unified_Ideograph", "Ideographic"},
    143190: {"Unified_Ideograph", "Ideographic"},
    143191: {"Unified_Ideograph", "Ideographic"},
    143192: {"Unified_Ideograph", "Ideographic"},
    143193: {"Unified_Ideograph", "Ideographic"},
    143194: {"Unified_Ideograph", "Ideographic"},
    143195: {"Unified_Ideograph", "Ideographic"},
    143196: {"Unified_Ideograph", "Ideographic"},
    143197: {"Unified_Ideograph", "Ideographic"},
    143198: {"Unified_Ideograph", "Ideographic"},
    143199: {"Unified_Ideograph", "Ideographic"},
    143200: {"Unified_Ideograph", "Ideographic"},
    143201: {"Unified_Ideograph", "Ideographic"},
    143202: {"Unified_Ideograph", "Ideographic"},
    143203: {"Unified_Ideograph", "Ideographic"},
    143204: {"Unified_Ideograph", "Ideographic"},
    143205: {"Unified_Ideograph", "Ideographic"},
    143206: {"Unified_Ideograph", "Ideographic"},
    143207: {"Unified_Ideograph", "Ideographic"},
    143208: {"Unified_Ideograph", "Ideographic"},
    143209: {"Unified_Ideograph", "Ideographic"},
    143210: {"Unified_Ideograph", "Ideographic"},
    143211: {"Unified_Ideograph", "Ideographic"},
    143212: {"Unified_Ideograph", "Ideographic"},
    143213: {"Unified_Ideograph", "Ideographic"},
    143214: {"Unified_Ideograph", "Ideographic"},
    143215: {"Unified_Ideograph", "Ideographic"},
    143216: {"Unified_Ideograph", "Ideographic"},
    143217: {"Unified_Ideograph", "Ideographic"},
    143218: {"Unified_Ideograph", "Ideographic"},
    143219: {"Unified_Ideograph", "Ideographic"},
    143220: {"Unified_Ideograph", "Ideographic"},
    143221: {"Unified_Ideograph", "Ideographic"},
    143222: {"Unified_Ideograph", "Ideographic"},
    143223: {"Unified_Ideograph", "Ideographic"},
    143224: {"Unified_Ideograph", "Ideographic"},
    143225: {"Unified_Ideograph", "Ideographic"},
    143226: {"Unified_Ideograph", "Ideographic"},
    143227: {"Unified_Ideograph", "Ideographic"},
    143228: {"Unified_Ideograph", "Ideographic"},
    143229: {"Unified_Ideograph", "Ideographic"},
    143230: {"Unified_Ideograph", "Ideographic"},
    143231: {"Unified_Ideograph", "Ideographic"},
    143232: {"Unified_Ideograph", "Ideographic"},
    143233: {"Unified_Ideograph", "Ideographic"},
    143234: {"Unified_Ideograph", "Ideographic"},
    143235: {"Unified_Ideograph", "Ideographic"},
    143236: {"Unified_Ideograph", "Ideographic"},
    143237: {"Unified_Ideograph", "Ideographic"},
    143238: {"Unified_Ideograph", "Ideographic"},
    143239: {"Unified_Ideograph", "Ideographic"},
    143240: {"Unified_Ideograph", "Ideographic"},
    143241: {"Unified_Ideograph", "Ideographic"},
    143242: {"Unified_Ideograph", "Ideographic"},
    143243: {"Unified_Ideograph", "Ideographic"},
    143244: {"Unified_Ideograph", "Ideographic"},
    143245: {"Unified_Ideograph", "Ideographic"},
    143246: {"Unified_Ideograph", "Ideographic"},
    143247: {"Unified_Ideograph", "Ideographic"},
    143248: {"Unified_Ideograph", "Ideographic"},
    143249: {"Unified_Ideograph", "Ideographic"},
    143250: {"Unified_Ideograph", "Ideographic"},
    143251: {"Unified_Ideograph", "Ideographic"},
    143252: {"Unified_Ideograph", "Ideographic"},
    143253: {"Unified_Ideograph", "Ideographic"},
    143254: {"Unified_Ideograph", "Ideographic"},
    143255: {"Unified_Ideograph", "Ideographic"},
    143256: {"Unified_Ideograph", "Ideographic"},
    143257: {"Unified_Ideograph", "Ideographic"},
    143258: {"Unified_Ideograph", "Ideographic"},
    143259: {"Unified_Ideograph", "Ideographic"},
    143260: {"Unified_Ideograph", "Ideographic"},
    143261: {"Unified_Ideograph", "Ideographic"},
    143262: {"Unified_Ideograph", "Ideographic"},
    143263: {"Unified_Ideograph", "Ideographic"},
    143264: {"Unified_Ideograph", "Ideographic"},
    143265: {"Unified_Ideograph", "Ideographic"},
    143266: {"Unified_Ideograph", "Ideographic"},
    143267: {"Unified_Ideograph", "Ideographic"},
    143268: {"Unified_Ideograph", "Ideographic"},
    143269: {"Unified_Ideograph", "Ideographic"},
    143270: {"Unified_Ideograph", "Ideographic"},
    143271: {"Unified_Ideograph", "Ideographic"},
    143272: {"Unified_Ideograph", "Ideographic"},
    143273: {"Unified_Ideograph", "Ideographic"},
    143274: {"Unified_Ideograph", "Ideographic"},
    143275: {"Unified_Ideograph", "Ideographic"},
    143276: {"Unified_Ideograph", "Ideographic"},
    143277: {"Unified_Ideograph", "Ideographic"},
    143278: {"Unified_Ideograph", "Ideographic"},
    143279: {"Unified_Ideograph", "Ideographic"},
    143280: {"Unified_Ideograph", "Ideographic"},
    143281: {"Unified_Ideograph", "Ideographic"},
    143282: {"Unified_Ideograph", "Ideographic"},
    143283: {"Unified_Ideograph", "Ideographic"},
    143284: {"Unified_Ideograph", "Ideographic"},
    143285: {"Unified_Ideograph", "Ideographic"},
    143286: {"Unified_Ideograph", "Ideographic"},
    143287: {"Unified_Ideograph", "Ideographic"},
    143288: {"Unified_Ideograph", "Ideographic"},
    143289: {"Unified_Ideograph", "Ideographic"},
    143290: {"Unified_Ideograph", "Ideographic"},
    143291: {"Unified_Ideograph", "Ideographic"},
    143292: {"Unified_Ideograph", "Ideographic"},
    143293: {"Unified_Ideograph", "Ideographic"},
    143294: {"Unified_Ideograph", "Ideographic"},
    143295: {"Unified_Ideograph", "Ideographic"},
    143296: {"Unified_Ideograph", "Ideographic"},
    143297: {"Unified_Ideograph", "Ideographic"},
    143298: {"Unified_Ideograph", "Ideographic"},
    143299: {"Unified_Ideograph", "Ideographic"},
    143300: {"Unified_Ideograph", "Ideographic"},
    143301: {"Unified_Ideograph", "Ideographic"},
    143302: {"Unified_Ideograph", "Ideographic"},
    143303: {"Unified_Ideograph", "Ideographic"},
    143304: {"Unified_Ideograph", "Ideographic"},
    143305: {"Unified_Ideograph", "Ideographic"},
    143306: {"Unified_Ideograph", "Ideographic"},
    143307: {"Unified_Ideograph", "Ideographic"},
    143308: {"Unified_Ideograph", "Ideographic"},
    143309: {"Unified_Ideograph", "Ideographic"},
    143310: {"Unified_Ideograph", "Ideographic"},
    143311: {"Unified_Ideograph", "Ideographic"},
    143312: {"Unified_Ideograph", "Ideographic"},
    143313: {"Unified_Ideograph", "Ideographic"},
    143314: {"Unified_Ideograph", "Ideographic"},
    143315: {"Unified_Ideograph", "Ideographic"},
    143316: {"Unified_Ideograph", "Ideographic"},
    143317: {"Unified_Ideograph", "Ideographic"},
    143318: {"Unified_Ideograph", "Ideographic"},
    143319: {"Unified_Ideograph", "Ideographic"},
    143320: {"Unified_Ideograph", "Ideographic"},
    143321: {"Unified_Ideograph", "Ideographic"},
    143322: {"Unified_Ideograph", "Ideographic"},
    143323: {"Unified_Ideograph", "Ideographic"},
    143324: {"Unified_Ideograph", "Ideographic"},
    143325: {"Unified_Ideograph", "Ideographic"},
    143326: {"Unified_Ideograph", "Ideographic"},
    143327: {"Unified_Ideograph", "Ideographic"},
    143328: {"Unified_Ideograph", "Ideographic"},
    143329: {"Unified_Ideograph", "Ideographic"},
    143330: {"Unified_Ideograph", "Ideographic"},
    143331: {"Unified_Ideograph", "Ideographic"},
    143332: {"Unified_Ideograph", "Ideographic"},
    143333: {"Unified_Ideograph", "Ideographic"},
    143334: {"Unified_Ideograph", "Ideographic"},
    143335: {"Unified_Ideograph", "Ideographic"},
    143336: {"Unified_Ideograph", "Ideographic"},
    143337: {"Unified_Ideograph", "Ideographic"},
    143338: {"Unified_Ideograph", "Ideographic"},
    143339: {"Unified_Ideograph", "Ideographic"},
    143340: {"Unified_Ideograph", "Ideographic"},
    143341: {"Unified_Ideograph", "Ideographic"},
    143342: {"Unified_Ideograph", "Ideographic"},
    143343: {"Unified_Ideograph", "Ideographic"},
    143344: {"Unified_Ideograph", "Ideographic"},
    143345: {"Unified_Ideograph", "Ideographic"},
    143346: {"Unified_Ideograph", "Ideographic"},
    143347: {"Unified_Ideograph", "Ideographic"},
    143348: {"Unified_Ideograph", "Ideographic"},
    143349: {"Unified_Ideograph", "Ideographic"},
    143350: {"Unified_Ideograph", "Ideographic"},
    143351: {"Unified_Ideograph", "Ideographic"},
    143352: {"Unified_Ideograph", "Ideographic"},
    143353: {"Unified_Ideograph", "Ideographic"},
    143354: {"Unified_Ideograph", "Ideographic"},
    143355: {"Unified_Ideograph", "Ideographic"},
    143356: {"Unified_Ideograph", "Ideographic"},
    143357: {"Unified_Ideograph", "Ideographic"},
    143358: {"Unified_Ideograph", "Ideographic"},
    143359: {"Unified_Ideograph", "Ideographic"},
    143360: {"Unified_Ideograph", "Ideographic"},
    143361: {"Unified_Ideograph", "Ideographic"},
    143362: {"Unified_Ideograph", "Ideographic"},
    143363: {"Unified_Ideograph", "Ideographic"},
    143364: {"Unified_Ideograph", "Ideographic"},
    143365: {"Unified_Ideograph", "Ideographic"},
    143366: {"Unified_Ideograph", "Ideographic"},
    143367: {"Unified_Ideograph", "Ideographic"},
    143368: {"Unified_Ideograph", "Ideographic"},
    143369: {"Unified_Ideograph", "Ideographic"},
    143370: {"Unified_Ideograph", "Ideographic"},
    143371: {"Unified_Ideograph", "Ideographic"},
    143372: {"Unified_Ideograph", "Ideographic"},
    143373: {"Unified_Ideograph", "Ideographic"},
    143374: {"Unified_Ideograph", "Ideographic"},
    143375: {"Unified_Ideograph", "Ideographic"},
    143376: {"Unified_Ideograph", "Ideographic"},
    143377: {"Unified_Ideograph", "Ideographic"},
    143378: {"Unified_Ideograph", "Ideographic"},
    143379: {"Unified_Ideograph", "Ideographic"},
    143380: {"Unified_Ideograph", "Ideographic"},
    143381: {"Unified_Ideograph", "Ideographic"},
    143382: {"Unified_Ideograph", "Ideographic"},
    143383: {"Unified_Ideograph", "Ideographic"},
    143384: {"Unified_Ideograph", "Ideographic"},
    143385: {"Unified_Ideograph", "Ideographic"},
    143386: {"Unified_Ideograph", "Ideographic"},
    143387: {"Unified_Ideograph", "Ideographic"},
    143388: {"Unified_Ideograph", "Ideographic"},
    143389: {"Unified_Ideograph", "Ideographic"},
    143390: {"Unified_Ideograph", "Ideographic"},
    143391: {"Unified_Ideograph", "Ideographic"},
    143392: {"Unified_Ideograph", "Ideographic"},
    143393: {"Unified_Ideograph", "Ideographic"},
    143394: {"Unified_Ideograph", "Ideographic"},
    143395: {"Unified_Ideograph", "Ideographic"},
    143396: {"Unified_Ideograph", "Ideographic"},
    143397: {"Unified_Ideograph", "Ideographic"},
    143398: {"Unified_Ideograph", "Ideographic"},
    143399: {"Unified_Ideograph", "Ideographic"},
    143400: {"Unified_Ideograph", "Ideographic"},
    143401: {"Unified_Ideograph", "Ideographic"},
    143402: {"Unified_Ideograph", "Ideographic"},
    143403: {"Unified_Ideograph", "Ideographic"},
    143404: {"Unified_Ideograph", "Ideographic"},
    143405: {"Unified_Ideograph", "Ideographic"},
    143406: {"Unified_Ideograph", "Ideographic"},
    143407: {"Unified_Ideograph", "Ideographic"},
    143408: {"Unified_Ideograph", "Ideographic"},
    143409: {"Unified_Ideograph", "Ideographic"},
    143410: {"Unified_Ideograph", "Ideographic"},
    143411: {"Unified_Ideograph", "Ideographic"},
    143412: {"Unified_Ideograph", "Ideographic"},
    143413: {"Unified_Ideograph", "Ideographic"},
    143414: {"Unified_Ideograph", "Ideographic"},
    143415: {"Unified_Ideograph", "Ideographic"},
    143416: {"Unified_Ideograph", "Ideographic"},
    143417: {"Unified_Ideograph", "Ideographic"},
    143418: {"Unified_Ideograph", "Ideographic"},
    143419: {"Unified_Ideograph", "Ideographic"},
    143420: {"Unified_Ideograph", "Ideographic"},
    143421: {"Unified_Ideograph", "Ideographic"},
    143422: {"Unified_Ideograph", "Ideographic"},
    143423: {"Unified_Ideograph", "Ideographic"},
    143424: {"Unified_Ideograph", "Ideographic"},
    143425: {"Unified_Ideograph", "Ideographic"},
    143426: {"Unified_Ideograph", "Ideographic"},
    143427: {"Unified_Ideograph", "Ideographic"},
    143428: {"Unified_Ideograph", "Ideographic"},
    143429: {"Unified_Ideograph", "Ideographic"},
    143430: {"Unified_Ideograph", "Ideographic"},
    143431: {"Unified_Ideograph", "Ideographic"},
    143432: {"Unified_Ideograph", "Ideographic"},
    143433: {"Unified_Ideograph", "Ideographic"},
    143434: {"Unified_Ideograph", "Ideographic"},
    143435: {"Unified_Ideograph", "Ideographic"},
    143436: {"Unified_Ideograph", "Ideographic"},
    143437: {"Unified_Ideograph", "Ideographic"},
    143438: {"Unified_Ideograph", "Ideographic"},
    143439: {"Unified_Ideograph", "Ideographic"},
    143440: {"Unified_Ideograph", "Ideographic"},
    143441: {"Unified_Ideograph", "Ideographic"},
    143442: {"Unified_Ideograph", "Ideographic"},
    143443: {"Unified_Ideograph", "Ideographic"},
    143444: {"Unified_Ideograph", "Ideographic"},
    143445: {"Unified_Ideograph", "Ideographic"},
    143446: {"Unified_Ideograph", "Ideographic"},
    143447: {"Unified_Ideograph", "Ideographic"},
    143448: {"Unified_Ideograph", "Ideographic"},
    143449: {"Unified_Ideograph", "Ideographic"},
    143450: {"Unified_Ideograph", "Ideographic"},
    143451: {"Unified_Ideograph", "Ideographic"},
    143452: {"Unified_Ideograph", "Ideographic"},
    143453: {"Unified_Ideograph", "Ideographic"},
    143454: {"Unified_Ideograph", "Ideographic"},
    143455: {"Unified_Ideograph", "Ideographic"},
    143456: {"Unified_Ideograph", "Ideographic"},
    143457: {"Unified_Ideograph", "Ideographic"},
    143458: {"Unified_Ideograph", "Ideographic"},
    143459: {"Unified_Ideograph", "Ideographic"},
    143460: {"Unified_Ideograph", "Ideographic"},
    143461: {"Unified_Ideograph", "Ideographic"},
    143462: {"Unified_Ideograph", "Ideographic"},
    143463: {"Unified_Ideograph", "Ideographic"},
    143464: {"Unified_Ideograph", "Ideographic"},
    143465: {"Unified_Ideograph", "Ideographic"},
    143466: {"Unified_Ideograph", "Ideographic"},
    143467: {"Unified_Ideograph", "Ideographic"},
    143468: {"Unified_Ideograph", "Ideographic"},
    143469: {"Unified_Ideograph", "Ideographic"},
    143470: {"Unified_Ideograph", "Ideographic"},
    143471: {"Unified_Ideograph", "Ideographic"},
    143472: {"Unified_Ideograph", "Ideographic"},
    143473: {"Unified_Ideograph", "Ideographic"},
    143474: {"Unified_Ideograph", "Ideographic"},
    143475: {"Unified_Ideograph", "Ideographic"},
    143476: {"Unified_Ideograph", "Ideographic"},
    143477: {"Unified_Ideograph", "Ideographic"},
    143478: {"Unified_Ideograph", "Ideographic"},
    143479: {"Unified_Ideograph", "Ideographic"},
    143480: {"Unified_Ideograph", "Ideographic"},
    143481: {"Unified_Ideograph", "Ideographic"},
    143482: {"Unified_Ideograph", "Ideographic"},
    143483: {"Unified_Ideograph", "Ideographic"},
    143484: {"Unified_Ideograph", "Ideographic"},
    143485: {"Unified_Ideograph", "Ideographic"},
    143486: {"Unified_Ideograph", "Ideographic"},
    143487: {"Unified_Ideograph", "Ideographic"},
    143488: {"Unified_Ideograph", "Ideographic"},
    143489: {"Unified_Ideograph", "Ideographic"},
    143490: {"Unified_Ideograph", "Ideographic"},
    143491: {"Unified_Ideograph", "Ideographic"},
    143492: {"Unified_Ideograph", "Ideographic"},
    143493: {"Unified_Ideograph", "Ideographic"},
    143494: {"Unified_Ideograph", "Ideographic"},
    143495: {"Unified_Ideograph", "Ideographic"},
    143496: {"Unified_Ideograph", "Ideographic"},
    143497: {"Unified_Ideograph", "Ideographic"},
    143498: {"Unified_Ideograph", "Ideographic"},
    143499: {"Unified_Ideograph", "Ideographic"},
    143500: {"Unified_Ideograph", "Ideographic"},
    143501: {"Unified_Ideograph", "Ideographic"},
    143502: {"Unified_Ideograph", "Ideographic"},
    143503: {"Unified_Ideograph", "Ideographic"},
    143504: {"Unified_Ideograph", "Ideographic"},
    143505: {"Unified_Ideograph", "Ideographic"},
    143506: {"Unified_Ideograph", "Ideographic"},
    143507: {"Unified_Ideograph", "Ideographic"},
    143508: {"Unified_Ideograph", "Ideographic"},
    143509: {"Unified_Ideograph", "Ideographic"},
    143510: {"Unified_Ideograph", "Ideographic"},
    143511: {"Unified_Ideograph", "Ideographic"},
    143512: {"Unified_Ideograph", "Ideographic"},
    143513: {"Unified_Ideograph", "Ideographic"},
    143514: {"Unified_Ideograph", "Ideographic"},
    143515: {"Unified_Ideograph", "Ideographic"},
    143516: {"Unified_Ideograph", "Ideographic"},
    143517: {"Unified_Ideograph", "Ideographic"},
    143518: {"Unified_Ideograph", "Ideographic"},
    143519: {"Unified_Ideograph", "Ideographic"},
    143520: {"Unified_Ideograph", "Ideographic"},
    143521: {"Unified_Ideograph", "Ideographic"},
    143522: {"Unified_Ideograph", "Ideographic"},
    143523: {"Unified_Ideograph", "Ideographic"},
    143524: {"Unified_Ideograph", "Ideographic"},
    143525: {"Unified_Ideograph", "Ideographic"},
    143526: {"Unified_Ideograph", "Ideographic"},
    143527: {"Unified_Ideograph", "Ideographic"},
    143528: {"Unified_Ideograph", "Ideographic"},
    143529: {"Unified_Ideograph", "Ideographic"},
    143530: {"Unified_Ideograph", "Ideographic"},
    143531: {"Unified_Ideograph", "Ideographic"},
    143532: {"Unified_Ideograph", "Ideographic"},
    143533: {"Unified_Ideograph", "Ideographic"},
    143534: {"Unified_Ideograph", "Ideographic"},
    143535: {"Unified_Ideograph", "Ideographic"},
    143536: {"Unified_Ideograph", "Ideographic"},
    143537: {"Unified_Ideograph", "Ideographic"},
    143538: {"Unified_Ideograph", "Ideographic"},
    143539: {"Unified_Ideograph", "Ideographic"},
    143540: {"Unified_Ideograph", "Ideographic"},
    143541: {"Unified_Ideograph", "Ideographic"},
    143542: {"Unified_Ideograph", "Ideographic"},
    143543: {"Unified_Ideograph", "Ideographic"},
    143544: {"Unified_Ideograph", "Ideographic"},
    143545: {"Unified_Ideograph", "Ideographic"},
    143546: {"Unified_Ideograph", "Ideographic"},
    143547: {"Unified_Ideograph", "Ideographic"},
    143548: {"Unified_Ideograph", "Ideographic"},
    143549: {"Unified_Ideograph", "Ideographic"},
    143550: {"Unified_Ideograph", "Ideographic"},
    143551: {"Unified_Ideograph", "Ideographic"},
    143552: {"Unified_Ideograph", "Ideographic"},
    143553: {"Unified_Ideograph", "Ideographic"},
    143554: {"Unified_Ideograph", "Ideographic"},
    143555: {"Unified_Ideograph", "Ideographic"},
    143556: {"Unified_Ideograph", "Ideographic"},
    143557: {"Unified_Ideograph", "Ideographic"},
    143558: {"Unified_Ideograph", "Ideographic"},
    143559: {"Unified_Ideograph", "Ideographic"},
    143560: {"Unified_Ideograph", "Ideographic"},
    143561: {"Unified_Ideograph", "Ideographic"},
    143562: {"Unified_Ideograph", "Ideographic"},
    143563: {"Unified_Ideograph", "Ideographic"},
    143564: {"Unified_Ideograph", "Ideographic"},
    143565: {"Unified_Ideograph", "Ideographic"},
    143566: {"Unified_Ideograph", "Ideographic"},
    143567: {"Unified_Ideograph", "Ideographic"},
    143568: {"Unified_Ideograph", "Ideographic"},
    143569: {"Unified_Ideograph", "Ideographic"},
    143570: {"Unified_Ideograph", "Ideographic"},
    143571: {"Unified_Ideograph", "Ideographic"},
    143572: {"Unified_Ideograph", "Ideographic"},
    143573: {"Unified_Ideograph", "Ideographic"},
    143574: {"Unified_Ideograph", "Ideographic"},
    143575: {"Unified_Ideograph", "Ideographic"},
    143576: {"Unified_Ideograph", "Ideographic"},
    143577: {"Unified_Ideograph", "Ideographic"},
    143578: {"Unified_Ideograph", "Ideographic"},
    143579: {"Unified_Ideograph", "Ideographic"},
    143580: {"Unified_Ideograph", "Ideographic"},
    143581: {"Unified_Ideograph", "Ideographic"},
    143582: {"Unified_Ideograph", "Ideographic"},
    143583: {"Unified_Ideograph", "Ideographic"},
    143584: {"Unified_Ideograph", "Ideographic"},
    143585: {"Unified_Ideograph", "Ideographic"},
    143586: {"Unified_Ideograph", "Ideographic"},
    143587: {"Unified_Ideograph", "Ideographic"},
    143588: {"Unified_Ideograph", "Ideographic"},
    143589: {"Unified_Ideograph", "Ideographic"},
    143590: {"Unified_Ideograph", "Ideographic"},
    143591: {"Unified_Ideograph", "Ideographic"},
    143592: {"Unified_Ideograph", "Ideographic"},
    143593: {"Unified_Ideograph", "Ideographic"},
    143594: {"Unified_Ideograph", "Ideographic"},
    143595: {"Unified_Ideograph", "Ideographic"},
    143596: {"Unified_Ideograph", "Ideographic"},
    143597: {"Unified_Ideograph", "Ideographic"},
    143598: {"Unified_Ideograph", "Ideographic"},
    143599: {"Unified_Ideograph", "Ideographic"},
    143600: {"Unified_Ideograph", "Ideographic"},
    143601: {"Unified_Ideograph", "Ideographic"},
    143602: {"Unified_Ideograph", "Ideographic"},
    143603: {"Unified_Ideograph", "Ideographic"},
    143604: {"Unified_Ideograph", "Ideographic"},
    143605: {"Unified_Ideograph", "Ideographic"},
    143606: {"Unified_Ideograph", "Ideographic"},
    143607: {"Unified_Ideograph", "Ideographic"},
    143608: {"Unified_Ideograph", "Ideographic"},
    143609: {"Unified_Ideograph", "Ideographic"},
    143610: {"Unified_Ideograph", "Ideographic"},
    143611: {"Unified_Ideograph", "Ideographic"},
    143612: {"Unified_Ideograph", "Ideographic"},
    143613: {"Unified_Ideograph", "Ideographic"},
    143614: {"Unified_Ideograph", "Ideographic"},
    143615: {"Unified_Ideograph", "Ideographic"},
    143616: {"Unified_Ideograph", "Ideographic"},
    143617: {"Unified_Ideograph", "Ideographic"},
    143618: {"Unified_Ideograph", "Ideographic"},
    143619: {"Unified_Ideograph", "Ideographic"},
    143620: {"Unified_Ideograph", "Ideographic"},
    143621: {"Unified_Ideograph", "Ideographic"},
    143622: {"Unified_Ideograph", "Ideographic"},
    143623: {"Unified_Ideograph", "Ideographic"},
    143624: {"Unified_Ideograph", "Ideographic"},
    143625: {"Unified_Ideograph", "Ideographic"},
    143626: {"Unified_Ideograph", "Ideographic"},
    143627: {"Unified_Ideograph", "Ideographic"},
    143628: {"Unified_Ideograph", "Ideographic"},
    143629: {"Unified_Ideograph", "Ideographic"},
    143630: {"Unified_Ideograph", "Ideographic"},
    143631: {"Unified_Ideograph", "Ideographic"},
    143632: {"Unified_Ideograph", "Ideographic"},
    143633: {"Unified_Ideograph", "Ideographic"},
    143634: {"Unified_Ideograph", "Ideographic"},
    143635: {"Unified_Ideograph", "Ideographic"},
    143636: {"Unified_Ideograph", "Ideographic"},
    143637: {"Unified_Ideograph", "Ideographic"},
    143638: {"Unified_Ideograph", "Ideographic"},
    143639: {"Unified_Ideograph", "Ideographic"},
    143640: {"Unified_Ideograph", "Ideographic"},
    143641: {"Unified_Ideograph", "Ideographic"},
    143642: {"Unified_Ideograph", "Ideographic"},
    143643: {"Unified_Ideograph", "Ideographic"},
    143644: {"Unified_Ideograph", "Ideographic"},
    143645: {"Unified_Ideograph", "Ideographic"},
    143646: {"Unified_Ideograph", "Ideographic"},
    143647: {"Unified_Ideograph", "Ideographic"},
    143648: {"Unified_Ideograph", "Ideographic"},
    143649: {"Unified_Ideograph", "Ideographic"},
    143650: {"Unified_Ideograph", "Ideographic"},
    143651: {"Unified_Ideograph", "Ideographic"},
    143652: {"Unified_Ideograph", "Ideographic"},
    143653: {"Unified_Ideograph", "Ideographic"},
    143654: {"Unified_Ideograph", "Ideographic"},
    143655: {"Unified_Ideograph", "Ideographic"},
    143656: {"Unified_Ideograph", "Ideographic"},
    143657: {"Unified_Ideograph", "Ideographic"},
    143658: {"Unified_Ideograph", "Ideographic"},
    143659: {"Unified_Ideograph", "Ideographic"},
    143660: {"Unified_Ideograph", "Ideographic"},
    143661: {"Unified_Ideograph", "Ideographic"},
    143662: {"Unified_Ideograph", "Ideographic"},
    143663: {"Unified_Ideograph", "Ideographic"},
    143664: {"Unified_Ideograph", "Ideographic"},
    143665: {"Unified_Ideograph", "Ideographic"},
    143666: {"Unified_Ideograph", "Ideographic"},
    143667: {"Unified_Ideograph", "Ideographic"},
    143668: {"Unified_Ideograph", "Ideographic"},
    143669: {"Unified_Ideograph", "Ideographic"},
    143670: {"Unified_Ideograph", "Ideographic"},
    143671: {"Unified_Ideograph", "Ideographic"},
    143672: {"Unified_Ideograph", "Ideographic"},
    143673: {"Unified_Ideograph", "Ideographic"},
    143674: {"Unified_Ideograph", "Ideographic"},
    143675: {"Unified_Ideograph", "Ideographic"},
    143676: {"Unified_Ideograph", "Ideographic"},
    143677: {"Unified_Ideograph", "Ideographic"},
    143678: {"Unified_Ideograph", "Ideographic"},
    143679: {"Unified_Ideograph", "Ideographic"},
    143680: {"Unified_Ideograph", "Ideographic"},
    143681: {"Unified_Ideograph", "Ideographic"},
    143682: {"Unified_Ideograph", "Ideographic"},
    143683: {"Unified_Ideograph", "Ideographic"},
    143684: {"Unified_Ideograph", "Ideographic"},
    143685: {"Unified_Ideograph", "Ideographic"},
    143686: {"Unified_Ideograph", "Ideographic"},
    143687: {"Unified_Ideograph", "Ideographic"},
    143688: {"Unified_Ideograph", "Ideographic"},
    143689: {"Unified_Ideograph", "Ideographic"},
    143690: {"Unified_Ideograph", "Ideographic"},
    143691: {"Unified_Ideograph", "Ideographic"},
    143692: {"Unified_Ideograph", "Ideographic"},
    143693: {"Unified_Ideograph", "Ideographic"},
    143694: {"Unified_Ideograph", "Ideographic"},
    143695: {"Unified_Ideograph", "Ideographic"},
    143696: {"Unified_Ideograph", "Ideographic"},
    143697: {"Unified_Ideograph", "Ideographic"},
    143698: {"Unified_Ideograph", "Ideographic"},
    143699: {"Unified_Ideograph", "Ideographic"},
    143700: {"Unified_Ideograph", "Ideographic"},
    143701: {"Unified_Ideograph", "Ideographic"},
    143702: {"Unified_Ideograph", "Ideographic"},
    143703: {"Unified_Ideograph", "Ideographic"},
    143704: {"Unified_Ideograph", "Ideographic"},
    143705: {"Unified_Ideograph", "Ideographic"},
    143706: {"Unified_Ideograph", "Ideographic"},
    143707: {"Unified_Ideograph", "Ideographic"},
    143708: {"Unified_Ideograph", "Ideographic"},
    143709: {"Unified_Ideograph", "Ideographic"},
    143710: {"Unified_Ideograph", "Ideographic"},
    143711: {"Unified_Ideograph", "Ideographic"},
    143712: {"Unified_Ideograph", "Ideographic"},
    143713: {"Unified_Ideograph", "Ideographic"},
    143714: {"Unified_Ideograph", "Ideographic"},
    143715: {"Unified_Ideograph", "Ideographic"},
    143716: {"Unified_Ideograph", "Ideographic"},
    143717: {"Unified_Ideograph", "Ideographic"},
    143718: {"Unified_Ideograph", "Ideographic"},
    143719: {"Unified_Ideograph", "Ideographic"},
    143720: {"Unified_Ideograph", "Ideographic"},
    143721: {"Unified_Ideograph", "Ideographic"},
    143722: {"Unified_Ideograph", "Ideographic"},
    143723: {"Unified_Ideograph", "Ideographic"},
    143724: {"Unified_Ideograph", "Ideographic"},
    143725: {"Unified_Ideograph", "Ideographic"},
    143726: {"Unified_Ideograph", "Ideographic"},
    143727: {"Unified_Ideograph", "Ideographic"},
    143728: {"Unified_Ideograph", "Ideographic"},
    143729: {"Unified_Ideograph", "Ideographic"},
    143730: {"Unified_Ideograph", "Ideographic"},
    143731: {"Unified_Ideograph", "Ideographic"},
    143732: {"Unified_Ideograph", "Ideographic"},
    143733: {"Unified_Ideograph", "Ideographic"},
    143734: {"Unified_Ideograph", "Ideographic"},
    143735: {"Unified_Ideograph", "Ideographic"},
    143736: {"Unified_Ideograph", "Ideographic"},
    143737: {"Unified_Ideograph", "Ideographic"},
    143738: {"Unified_Ideograph", "Ideographic"},
    143739: {"Unified_Ideograph", "Ideographic"},
    143740: {"Unified_Ideograph", "Ideographic"},
    143741: {"Unified_Ideograph", "Ideographic"},
    143742: {"Unified_Ideograph", "Ideographic"},
    143743: {"Unified_Ideograph", "Ideographic"},
    143744: {"Unified_Ideograph", "Ideographic"},
    143745: {"Unified_Ideograph", "Ideographic"},
    143746: {"Unified_Ideograph", "Ideographic"},
    143747: {"Unified_Ideograph", "Ideographic"},
    143748: {"Unified_Ideograph", "Ideographic"},
    143749: {"Unified_Ideograph", "Ideographic"},
    143750: {"Unified_Ideograph", "Ideographic"},
    143751: {"Unified_Ideograph", "Ideographic"},
    143752: {"Unified_Ideograph", "Ideographic"},
    143753: {"Unified_Ideograph", "Ideographic"},
    143754: {"Unified_Ideograph", "Ideographic"},
    143755: {"Unified_Ideograph", "Ideographic"},
    143756: {"Unified_Ideograph", "Ideographic"},
    143757: {"Unified_Ideograph", "Ideographic"},
    143758: {"Unified_Ideograph", "Ideographic"},
    143759: {"Unified_Ideograph", "Ideographic"},
    143760: {"Unified_Ideograph", "Ideographic"},
    143761: {"Unified_Ideograph", "Ideographic"},
    143762: {"Unified_Ideograph", "Ideographic"},
    143763: {"Unified_Ideograph", "Ideographic"},
    143764: {"Unified_Ideograph", "Ideographic"},
    143765: {"Unified_Ideograph", "Ideographic"},
    143766: {"Unified_Ideograph", "Ideographic"},
    143767: {"Unified_Ideograph", "Ideographic"},
    143768: {"Unified_Ideograph", "Ideographic"},
    143769: {"Unified_Ideograph", "Ideographic"},
    143770: {"Unified_Ideograph", "Ideographic"},
    143771: {"Unified_Ideograph", "Ideographic"},
    143772: {"Unified_Ideograph", "Ideographic"},
    143773: {"Unified_Ideograph", "Ideographic"},
    143774: {"Unified_Ideograph", "Ideographic"},
    143775: {"Unified_Ideograph", "Ideographic"},
    143776: {"Unified_Ideograph", "Ideographic"},
    143777: {"Unified_Ideograph", "Ideographic"},
    143778: {"Unified_Ideograph", "Ideographic"},
    143779: {"Unified_Ideograph", "Ideographic"},
    143780: {"Unified_Ideograph", "Ideographic"},
    143781: {"Unified_Ideograph", "Ideographic"},
    143782: {"Unified_Ideograph", "Ideographic"},
    143783: {"Unified_Ideograph", "Ideographic"},
    143784: {"Unified_Ideograph", "Ideographic"},
    143785: {"Unified_Ideograph", "Ideographic"},
    143786: {"Unified_Ideograph", "Ideographic"},
    143787: {"Unified_Ideograph", "Ideographic"},
    143788: {"Unified_Ideograph", "Ideographic"},
    143789: {"Unified_Ideograph", "Ideographic"},
    143790: {"Unified_Ideograph", "Ideographic"},
    143791: {"Unified_Ideograph", "Ideographic"},
    143792: {"Unified_Ideograph", "Ideographic"},
    143793: {"Unified_Ideograph", "Ideographic"},
    143794: {"Unified_Ideograph", "Ideographic"},
    143795: {"Unified_Ideograph", "Ideographic"},
    143796: {"Unified_Ideograph", "Ideographic"},
    143797: {"Unified_Ideograph", "Ideographic"},
    143798: {"Unified_Ideograph", "Ideographic"},
    143799: {"Unified_Ideograph", "Ideographic"},
    143800: {"Unified_Ideograph", "Ideographic"},
    143801: {"Unified_Ideograph", "Ideographic"},
    143802: {"Unified_Ideograph", "Ideographic"},
    143803: {"Unified_Ideograph", "Ideographic"},
    143804: {"Unified_Ideograph", "Ideographic"},
    143805: {"Unified_Ideograph", "Ideographic"},
    143806: {"Unified_Ideograph", "Ideographic"},
    143807: {"Unified_Ideograph", "Ideographic"},
    143808: {"Unified_Ideograph", "Ideographic"},
    143809: {"Unified_Ideograph", "Ideographic"},
    143810: {"Unified_Ideograph", "Ideographic"},
    143811: {"Unified_Ideograph", "Ideographic"},
    143812: {"Unified_Ideograph", "Ideographic"},
    143813: {"Unified_Ideograph", "Ideographic"},
    143814: {"Unified_Ideograph", "Ideographic"},
    143815: {"Unified_Ideograph", "Ideographic"},
    143816: {"Unified_Ideograph", "Ideographic"},
    143817: {"Unified_Ideograph", "Ideographic"},
    143818: {"Unified_Ideograph", "Ideographic"},
    143819: {"Unified_Ideograph", "Ideographic"},
    143820: {"Unified_Ideograph", "Ideographic"},
    143821: {"Unified_Ideograph", "Ideographic"},
    143822: {"Unified_Ideograph", "Ideographic"},
    143823: {"Unified_Ideograph", "Ideographic"},
    143824: {"Unified_Ideograph", "Ideographic"},
    143825: {"Unified_Ideograph", "Ideographic"},
    143826: {"Unified_Ideograph", "Ideographic"},
    143827: {"Unified_Ideograph", "Ideographic"},
    143828: {"Unified_Ideograph", "Ideographic"},
    143829: {"Unified_Ideograph", "Ideographic"},
    143830: {"Unified_Ideograph", "Ideographic"},
    143831: {"Unified_Ideograph", "Ideographic"},
    143832: {"Unified_Ideograph", "Ideographic"},
    143833: {"Unified_Ideograph", "Ideographic"},
    143834: {"Unified_Ideograph", "Ideographic"},
    143835: {"Unified_Ideograph", "Ideographic"},
    143836: {"Unified_Ideograph", "Ideographic"},
    143837: {"Unified_Ideograph", "Ideographic"},
    143838: {"Unified_Ideograph", "Ideographic"},
    143839: {"Unified_Ideograph", "Ideographic"},
    143840: {"Unified_Ideograph", "Ideographic"},
    143841: {"Unified_Ideograph", "Ideographic"},
    143842: {"Unified_Ideograph", "Ideographic"},
    143843: {"Unified_Ideograph", "Ideographic"},
    143844: {"Unified_Ideograph", "Ideographic"},
    143845: {"Unified_Ideograph", "Ideographic"},
    143846: {"Unified_Ideograph", "Ideographic"},
    143847: {"Unified_Ideograph", "Ideographic"},
    143848: {"Unified_Ideograph", "Ideographic"},
    143849: {"Unified_Ideograph", "Ideographic"},
    143850: {"Unified_Ideograph", "Ideographic"},
    143851: {"Unified_Ideograph", "Ideographic"},
    143852: {"Unified_Ideograph", "Ideographic"},
    143853: {"Unified_Ideograph", "Ideographic"},
    143854: {"Unified_Ideograph", "Ideographic"},
    143855: {"Unified_Ideograph", "Ideographic"},
    143856: {"Unified_Ideograph", "Ideographic"},
    143857: {"Unified_Ideograph", "Ideographic"},
    143858: {"Unified_Ideograph", "Ideographic"},
    143859: {"Unified_Ideograph", "Ideographic"},
    143860: {"Unified_Ideograph", "Ideographic"},
    143861: {"Unified_Ideograph", "Ideographic"},
    143862: {"Unified_Ideograph", "Ideographic"},
    143863: {"Unified_Ideograph", "Ideographic"},
    143864: {"Unified_Ideograph", "Ideographic"},
    143865: {"Unified_Ideograph", "Ideographic"},
    143866: {"Unified_Ideograph", "Ideographic"},
    143867: {"Unified_Ideograph", "Ideographic"},
    143868: {"Unified_Ideograph", "Ideographic"},
    143869: {"Unified_Ideograph", "Ideographic"},
    143870: {"Unified_Ideograph", "Ideographic"},
    143871: {"Unified_Ideograph", "Ideographic"},
    143872: {"Unified_Ideograph", "Ideographic"},
    143873: {"Unified_Ideograph", "Ideographic"},
    143874: {"Unified_Ideograph", "Ideographic"},
    143875: {"Unified_Ideograph", "Ideographic"},
    143876: {"Unified_Ideograph", "Ideographic"},
    143877: {"Unified_Ideograph", "Ideographic"},
    143878: {"Unified_Ideograph", "Ideographic"},
    143879: {"Unified_Ideograph", "Ideographic"},
    143880: {"Unified_Ideograph", "Ideographic"},
    143881: {"Unified_Ideograph", "Ideographic"},
    143882: {"Unified_Ideograph", "Ideographic"},
    143883: {"Unified_Ideograph", "Ideographic"},
    143884: {"Unified_Ideograph", "Ideographic"},
    143885: {"Unified_Ideograph", "Ideographic"},
    143886: {"Unified_Ideograph", "Ideographic"},
    143887: {"Unified_Ideograph", "Ideographic"},
    143888: {"Unified_Ideograph", "Ideographic"},
    143889: {"Unified_Ideograph", "Ideographic"},
    143890: {"Unified_Ideograph", "Ideographic"},
    143891: {"Unified_Ideograph", "Ideographic"},
    143892: {"Unified_Ideograph", "Ideographic"},
    143893: {"Unified_Ideograph", "Ideographic"},
    143894: {"Unified_Ideograph", "Ideographic"},
    143895: {"Unified_Ideograph", "Ideographic"},
    143896: {"Unified_Ideograph", "Ideographic"},
    143897: {"Unified_Ideograph", "Ideographic"},
    143898: {"Unified_Ideograph", "Ideographic"},
    143899: {"Unified_Ideograph", "Ideographic"},
    143900: {"Unified_Ideograph", "Ideographic"},
    143901: {"Unified_Ideograph", "Ideographic"},
    143902: {"Unified_Ideograph", "Ideographic"},
    143903: {"Unified_Ideograph", "Ideographic"},
    143904: {"Unified_Ideograph", "Ideographic"},
    143905: {"Unified_Ideograph", "Ideographic"},
    143906: {"Unified_Ideograph", "Ideographic"},
    143907: {"Unified_Ideograph", "Ideographic"},
    143908: {"Unified_Ideograph", "Ideographic"},
    143909: {"Unified_Ideograph", "Ideographic"},
    143910: {"Unified_Ideograph", "Ideographic"},
    143911: {"Unified_Ideograph", "Ideographic"},
    143912: {"Unified_Ideograph", "Ideographic"},
    143913: {"Unified_Ideograph", "Ideographic"},
    143914: {"Unified_Ideograph", "Ideographic"},
    143915: {"Unified_Ideograph", "Ideographic"},
    143916: {"Unified_Ideograph", "Ideographic"},
    143917: {"Unified_Ideograph", "Ideographic"},
    143918: {"Unified_Ideograph", "Ideographic"},
    143919: {"Unified_Ideograph", "Ideographic"},
    143920: {"Unified_Ideograph", "Ideographic"},
    143921: {"Unified_Ideograph", "Ideographic"},
    143922: {"Unified_Ideograph", "Ideographic"},
    143923: {"Unified_Ideograph", "Ideographic"},
    143924: {"Unified_Ideograph", "Ideographic"},
    143925: {"Unified_Ideograph", "Ideographic"},
    143926: {"Unified_Ideograph", "Ideographic"},
    143927: {"Unified_Ideograph", "Ideographic"},
    143928: {"Unified_Ideograph", "Ideographic"},
    143929: {"Unified_Ideograph", "Ideographic"},
    143930: {"Unified_Ideograph", "Ideographic"},
    143931: {"Unified_Ideograph", "Ideographic"},
    143932: {"Unified_Ideograph", "Ideographic"},
    143933: {"Unified_Ideograph", "Ideographic"},
    143934: {"Unified_Ideograph", "Ideographic"},
    143935: {"Unified_Ideograph", "Ideographic"},
    143936: {"Unified_Ideograph", "Ideographic"},
    143937: {"Unified_Ideograph", "Ideographic"},
    143938: {"Unified_Ideograph", "Ideographic"},
    143939: {"Unified_Ideograph", "Ideographic"},
    143940: {"Unified_Ideograph", "Ideographic"},
    143941: {"Unified_Ideograph", "Ideographic"},
    143942: {"Unified_Ideograph", "Ideographic"},
    143943: {"Unified_Ideograph", "Ideographic"},
    143944: {"Unified_Ideograph", "Ideographic"},
    143945: {"Unified_Ideograph", "Ideographic"},
    143946: {"Unified_Ideograph", "Ideographic"},
    143947: {"Unified_Ideograph", "Ideographic"},
    143948: {"Unified_Ideograph", "Ideographic"},
    143949: {"Unified_Ideograph", "Ideographic"},
    143950: {"Unified_Ideograph", "Ideographic"},
    143951: {"Unified_Ideograph", "Ideographic"},
    143952: {"Unified_Ideograph", "Ideographic"},
    143953: {"Unified_Ideograph", "Ideographic"},
    143954: {"Unified_Ideograph", "Ideographic"},
    143955: {"Unified_Ideograph", "Ideographic"},
    143956: {"Unified_Ideograph", "Ideographic"},
    143957: {"Unified_Ideograph", "Ideographic"},
    143958: {"Unified_Ideograph", "Ideographic"},
    143959: {"Unified_Ideograph", "Ideographic"},
    143960: {"Unified_Ideograph", "Ideographic"},
    143961: {"Unified_Ideograph", "Ideographic"},
    143962: {"Unified_Ideograph", "Ideographic"},
    143963: {"Unified_Ideograph", "Ideographic"},
    143964: {"Unified_Ideograph", "Ideographic"},
    143965: {"Unified_Ideograph", "Ideographic"},
    143966: {"Unified_Ideograph", "Ideographic"},
    143967: {"Unified_Ideograph", "Ideographic"},
    143968: {"Unified_Ideograph", "Ideographic"},
    143969: {"Unified_Ideograph", "Ideographic"},
    143970: {"Unified_Ideograph", "Ideographic"},
    143971: {"Unified_Ideograph", "Ideographic"},
    143972: {"Unified_Ideograph", "Ideographic"},
    143973: {"Unified_Ideograph", "Ideographic"},
    143974: {"Unified_Ideograph", "Ideographic"},
    143975: {"Unified_Ideograph", "Ideographic"},
    143976: {"Unified_Ideograph", "Ideographic"},
    143977: {"Unified_Ideograph", "Ideographic"},
    143978: {"Unified_Ideograph", "Ideographic"},
    143979: {"Unified_Ideograph", "Ideographic"},
    143980: {"Unified_Ideograph", "Ideographic"},
    143981: {"Unified_Ideograph", "Ideographic"},
    143982: {"Unified_Ideograph", "Ideographic"},
    143983: {"Unified_Ideograph", "Ideographic"},
    143984: {"Unified_Ideograph", "Ideographic"},
    143985: {"Unified_Ideograph", "Ideographic"},
    143986: {"Unified_Ideograph", "Ideographic"},
    143987: {"Unified_Ideograph", "Ideographic"},
    143988: {"Unified_Ideograph", "Ideographic"},
    143989: {"Unified_Ideograph", "Ideographic"},
    143990: {"Unified_Ideograph", "Ideographic"},
    143991: {"Unified_Ideograph", "Ideographic"},
    143992: {"Unified_Ideograph", "Ideographic"},
    143993: {"Unified_Ideograph", "Ideographic"},
    143994: {"Unified_Ideograph", "Ideographic"},
    143995: {"Unified_Ideograph", "Ideographic"},
    143996: {"Unified_Ideograph", "Ideographic"},
    143997: {"Unified_Ideograph", "Ideographic"},
    143998: {"Unified_Ideograph", "Ideographic"},
    143999: {"Unified_Ideograph", "Ideographic"},
    144000: {"Unified_Ideograph", "Ideographic"},
    144001: {"Unified_Ideograph", "Ideographic"},
    144002: {"Unified_Ideograph", "Ideographic"},
    144003: {"Unified_Ideograph", "Ideographic"},
    144004: {"Unified_Ideograph", "Ideographic"},
    144005: {"Unified_Ideograph", "Ideographic"},
    144006: {"Unified_Ideograph", "Ideographic"},
    144007: {"Unified_Ideograph", "Ideographic"},
    144008: {"Unified_Ideograph", "Ideographic"},
    144009: {"Unified_Ideograph", "Ideographic"},
    144010: {"Unified_Ideograph", "Ideographic"},
    144011: {"Unified_Ideograph", "Ideographic"},
    144012: {"Unified_Ideograph", "Ideographic"},
    144013: {"Unified_Ideograph", "Ideographic"},
    144014: {"Unified_Ideograph", "Ideographic"},
    144015: {"Unified_Ideograph", "Ideographic"},
    144016: {"Unified_Ideograph", "Ideographic"},
    144017: {"Unified_Ideograph", "Ideographic"},
    144018: {"Unified_Ideograph", "Ideographic"},
    144019: {"Unified_Ideograph", "Ideographic"},
    144020: {"Unified_Ideograph", "Ideographic"},
    144021: {"Unified_Ideograph", "Ideographic"},
    144022: {"Unified_Ideograph", "Ideographic"},
    144023: {"Unified_Ideograph", "Ideographic"},
    144024: {"Unified_Ideograph", "Ideographic"},
    144025: {"Unified_Ideograph", "Ideographic"},
    144026: {"Unified_Ideograph", "Ideographic"},
    144027: {"Unified_Ideograph", "Ideographic"},
    144028: {"Unified_Ideograph", "Ideographic"},
    144029: {"Unified_Ideograph", "Ideographic"},
    144030: {"Unified_Ideograph", "Ideographic"},
    144031: {"Unified_Ideograph", "Ideographic"},
    144032: {"Unified_Ideograph", "Ideographic"},
    144033: {"Unified_Ideograph", "Ideographic"},
    144034: {"Unified_Ideograph", "Ideographic"},
    144035: {"Unified_Ideograph", "Ideographic"},
    144036: {"Unified_Ideograph", "Ideographic"},
    144037: {"Unified_Ideograph", "Ideographic"},
    144038: {"Unified_Ideograph", "Ideographic"},
    144039: {"Unified_Ideograph", "Ideographic"},
    144040: {"Unified_Ideograph", "Ideographic"},
    144041: {"Unified_Ideograph", "Ideographic"},
    144042: {"Unified_Ideograph", "Ideographic"},
    144043: {"Unified_Ideograph", "Ideographic"},
    144044: {"Unified_Ideograph", "Ideographic"},
    144045: {"Unified_Ideograph", "Ideographic"},
    144046: {"Unified_Ideograph", "Ideographic"},
    144047: {"Unified_Ideograph", "Ideographic"},
    144048: {"Unified_Ideograph", "Ideographic"},
    144049: {"Unified_Ideograph", "Ideographic"},
    144050: {"Unified_Ideograph", "Ideographic"},
    144051: {"Unified_Ideograph", "Ideographic"},
    144052: {"Unified_Ideograph", "Ideographic"},
    144053: {"Unified_Ideograph", "Ideographic"},
    144054: {"Unified_Ideograph", "Ideographic"},
    144055: {"Unified_Ideograph", "Ideographic"},
    144056: {"Unified_Ideograph", "Ideographic"},
    144057: {"Unified_Ideograph", "Ideographic"},
    144058: {"Unified_Ideograph", "Ideographic"},
    144059: {"Unified_Ideograph", "Ideographic"},
    144060: {"Unified_Ideograph", "Ideographic"},
    144061: {"Unified_Ideograph", "Ideographic"},
    144062: {"Unified_Ideograph", "Ideographic"},
    144063: {"Unified_Ideograph", "Ideographic"},
    144064: {"Unified_Ideograph", "Ideographic"},
    144065: {"Unified_Ideograph", "Ideographic"},
    144066: {"Unified_Ideograph", "Ideographic"},
    144067: {"Unified_Ideograph", "Ideographic"},
    144068: {"Unified_Ideograph", "Ideographic"},
    144069: {"Unified_Ideograph", "Ideographic"},
    144070: {"Unified_Ideograph", "Ideographic"},
    144071: {"Unified_Ideograph", "Ideographic"},
    144072: {"Unified_Ideograph", "Ideographic"},
    144073: {"Unified_Ideograph", "Ideographic"},
    144074: {"Unified_Ideograph", "Ideographic"},
    144075: {"Unified_Ideograph", "Ideographic"},
    144076: {"Unified_Ideograph", "Ideographic"},
    144077: {"Unified_Ideograph", "Ideographic"},
    144078: {"Unified_Ideograph", "Ideographic"},
    144079: {"Unified_Ideograph", "Ideographic"},
    144080: {"Unified_Ideograph", "Ideographic"},
    144081: {"Unified_Ideograph", "Ideographic"},
    144082: {"Unified_Ideograph", "Ideographic"},
    144083: {"Unified_Ideograph", "Ideographic"},
    144084: {"Unified_Ideograph", "Ideographic"},
    144085: {"Unified_Ideograph", "Ideographic"},
    144086: {"Unified_Ideograph", "Ideographic"},
    144087: {"Unified_Ideograph", "Ideographic"},
    144088: {"Unified_Ideograph", "Ideographic"},
    144089: {"Unified_Ideograph", "Ideographic"},
    144090: {"Unified_Ideograph", "Ideographic"},
    144091: {"Unified_Ideograph", "Ideographic"},
    144092: {"Unified_Ideograph", "Ideographic"},
    144093: {"Unified_Ideograph", "Ideographic"},
    144094: {"Unified_Ideograph", "Ideographic"},
    144095: {"Unified_Ideograph", "Ideographic"},
    144096: {"Unified_Ideograph", "Ideographic"},
    144097: {"Unified_Ideograph", "Ideographic"},
    144098: {"Unified_Ideograph", "Ideographic"},
    144099: {"Unified_Ideograph", "Ideographic"},
    144100: {"Unified_Ideograph", "Ideographic"},
    144101: {"Unified_Ideograph", "Ideographic"},
    144102: {"Unified_Ideograph", "Ideographic"},
    144103: {"Unified_Ideograph", "Ideographic"},
    144104: {"Unified_Ideograph", "Ideographic"},
    144105: {"Unified_Ideograph", "Ideographic"},
    144106: {"Unified_Ideograph", "Ideographic"},
    144107: {"Unified_Ideograph", "Ideographic"},
    144108: {"Unified_Ideograph", "Ideographic"},
    144109: {"Unified_Ideograph", "Ideographic"},
    144110: {"Unified_Ideograph", "Ideographic"},
    144111: {"Unified_Ideograph", "Ideographic"},
    144112: {"Unified_Ideograph", "Ideographic"},
    144113: {"Unified_Ideograph", "Ideographic"},
    144114: {"Unified_Ideograph", "Ideographic"},
    144115: {"Unified_Ideograph", "Ideographic"},
    144116: {"Unified_Ideograph", "Ideographic"},
    144117: {"Unified_Ideograph", "Ideographic"},
    144118: {"Unified_Ideograph", "Ideographic"},
    144119: {"Unified_Ideograph", "Ideographic"},
    144120: {"Unified_Ideograph", "Ideographic"},
    144121: {"Unified_Ideograph", "Ideographic"},
    144122: {"Unified_Ideograph", "Ideographic"},
    144123: {"Unified_Ideograph", "Ideographic"},
    144124: {"Unified_Ideograph", "Ideographic"},
    144125: {"Unified_Ideograph", "Ideographic"},
    144126: {"Unified_Ideograph", "Ideographic"},
    144127: {"Unified_Ideograph", "Ideographic"},
    144128: {"Unified_Ideograph", "Ideographic"},
    144129: {"Unified_Ideograph", "Ideographic"},
    144130: {"Unified_Ideograph", "Ideographic"},
    144131: {"Unified_Ideograph", "Ideographic"},
    144132: {"Unified_Ideograph", "Ideographic"},
    144133: {"Unified_Ideograph", "Ideographic"},
    144134: {"Unified_Ideograph", "Ideographic"},
    144135: {"Unified_Ideograph", "Ideographic"},
    144136: {"Unified_Ideograph", "Ideographic"},
    144137: {"Unified_Ideograph", "Ideographic"},
    144138: {"Unified_Ideograph", "Ideographic"},
    144139: {"Unified_Ideograph", "Ideographic"},
    144140: {"Unified_Ideograph", "Ideographic"},
    144141: {"Unified_Ideograph", "Ideographic"},
    144142: {"Unified_Ideograph", "Ideographic"},
    144143: {"Unified_Ideograph", "Ideographic"},
    144144: {"Unified_Ideograph", "Ideographic"},
    144145: {"Unified_Ideograph", "Ideographic"},
    144146: {"Unified_Ideograph", "Ideographic"},
    144147: {"Unified_Ideograph", "Ideographic"},
    144148: {"Unified_Ideograph", "Ideographic"},
    144149: {"Unified_Ideograph", "Ideographic"},
    144150: {"Unified_Ideograph", "Ideographic"},
    144151: {"Unified_Ideograph", "Ideographic"},
    144152: {"Unified_Ideograph", "Ideographic"},
    144153: {"Unified_Ideograph", "Ideographic"},
    144154: {"Unified_Ideograph", "Ideographic"},
    144155: {"Unified_Ideograph", "Ideographic"},
    144156: {"Unified_Ideograph", "Ideographic"},
    144157: {"Unified_Ideograph", "Ideographic"},
    144158: {"Unified_Ideograph", "Ideographic"},
    144159: {"Unified_Ideograph", "Ideographic"},
    144160: {"Unified_Ideograph", "Ideographic"},
    144161: {"Unified_Ideograph", "Ideographic"},
    144162: {"Unified_Ideograph", "Ideographic"},
    144163: {"Unified_Ideograph", "Ideographic"},
    144164: {"Unified_Ideograph", "Ideographic"},
    144165: {"Unified_Ideograph", "Ideographic"},
    144166: {"Unified_Ideograph", "Ideographic"},
    144167: {"Unified_Ideograph", "Ideographic"},
    144168: {"Unified_Ideograph", "Ideographic"},
    144169: {"Unified_Ideograph", "Ideographic"},
    144170: {"Unified_Ideograph", "Ideographic"},
    144171: {"Unified_Ideograph", "Ideographic"},
    144172: {"Unified_Ideograph", "Ideographic"},
    144173: {"Unified_Ideograph", "Ideographic"},
    144174: {"Unified_Ideograph", "Ideographic"},
    144175: {"Unified_Ideograph", "Ideographic"},
    144176: {"Unified_Ideograph", "Ideographic"},
    144177: {"Unified_Ideograph", "Ideographic"},
    144178: {"Unified_Ideograph", "Ideographic"},
    144179: {"Unified_Ideograph", "Ideographic"},
    144180: {"Unified_Ideograph", "Ideographic"},
    144181: {"Unified_Ideograph", "Ideographic"},
    144182: {"Unified_Ideograph", "Ideographic"},
    144183: {"Unified_Ideograph", "Ideographic"},
    144184: {"Unified_Ideograph", "Ideographic"},
    144185: {"Unified_Ideograph", "Ideographic"},
    144186: {"Unified_Ideograph", "Ideographic"},
    144187: {"Unified_Ideograph", "Ideographic"},
    144188: {"Unified_Ideograph", "Ideographic"},
    144189: {"Unified_Ideograph", "Ideographic"},
    144190: {"Unified_Ideograph", "Ideographic"},
    144191: {"Unified_Ideograph", "Ideographic"},
    144192: {"Unified_Ideograph", "Ideographic"},
    144193: {"Unified_Ideograph", "Ideographic"},
    144194: {"Unified_Ideograph", "Ideographic"},
    144195: {"Unified_Ideograph", "Ideographic"},
    144196: {"Unified_Ideograph", "Ideographic"},
    144197: {"Unified_Ideograph", "Ideographic"},
    144198: {"Unified_Ideograph", "Ideographic"},
    144199: {"Unified_Ideograph", "Ideographic"},
    144200: {"Unified_Ideograph", "Ideographic"},
    144201: {"Unified_Ideograph", "Ideographic"},
    144202: {"Unified_Ideograph", "Ideographic"},
    144203: {"Unified_Ideograph", "Ideographic"},
    144204: {"Unified_Ideograph", "Ideographic"},
    144205: {"Unified_Ideograph", "Ideographic"},
    144206: {"Unified_Ideograph", "Ideographic"},
    144207: {"Unified_Ideograph", "Ideographic"},
    144208: {"Unified_Ideograph", "Ideographic"},
    144209: {"Unified_Ideograph", "Ideographic"},
    144210: {"Unified_Ideograph", "Ideographic"},
    144211: {"Unified_Ideograph", "Ideographic"},
    144212: {"Unified_Ideograph", "Ideographic"},
    144213: {"Unified_Ideograph", "Ideographic"},
    144214: {"Unified_Ideograph", "Ideographic"},
    144215: {"Unified_Ideograph", "Ideographic"},
    144216: {"Unified_Ideograph", "Ideographic"},
    144217: {"Unified_Ideograph", "Ideographic"},
    144218: {"Unified_Ideograph", "Ideographic"},
    144219: {"Unified_Ideograph", "Ideographic"},
    144220: {"Unified_Ideograph", "Ideographic"},
    144221: {"Unified_Ideograph", "Ideographic"},
    144222: {"Unified_Ideograph", "Ideographic"},
    144223: {"Unified_Ideograph", "Ideographic"},
    144224: {"Unified_Ideograph", "Ideographic"},
    144225: {"Unified_Ideograph", "Ideographic"},
    144226: {"Unified_Ideograph", "Ideographic"},
    144227: {"Unified_Ideograph", "Ideographic"},
    144228: {"Unified_Ideograph", "Ideographic"},
    144229: {"Unified_Ideograph", "Ideographic"},
    144230: {"Unified_Ideograph", "Ideographic"},
    144231: {"Unified_Ideograph", "Ideographic"},
    144232: {"Unified_Ideograph", "Ideographic"},
    144233: {"Unified_Ideograph", "Ideographic"},
    144234: {"Unified_Ideograph", "Ideographic"},
    144235: {"Unified_Ideograph", "Ideographic"},
    144236: {"Unified_Ideograph", "Ideographic"},
    144237: {"Unified_Ideograph", "Ideographic"},
    144238: {"Unified_Ideograph", "Ideographic"},
    144239: {"Unified_Ideograph", "Ideographic"},
    144240: {"Unified_Ideograph", "Ideographic"},
    144241: {"Unified_Ideograph", "Ideographic"},
    144242: {"Unified_Ideograph", "Ideographic"},
    144243: {"Unified_Ideograph", "Ideographic"},
    144244: {"Unified_Ideograph", "Ideographic"},
    144245: {"Unified_Ideograph", "Ideographic"},
    144246: {"Unified_Ideograph", "Ideographic"},
    144247: {"Unified_Ideograph", "Ideographic"},
    144248: {"Unified_Ideograph", "Ideographic"},
    144249: {"Unified_Ideograph", "Ideographic"},
    144250: {"Unified_Ideograph", "Ideographic"},
    144251: {"Unified_Ideograph", "Ideographic"},
    144252: {"Unified_Ideograph", "Ideographic"},
    144253: {"Unified_Ideograph", "Ideographic"},
    144254: {"Unified_Ideograph", "Ideographic"},
    144255: {"Unified_Ideograph", "Ideographic"},
    144256: {"Unified_Ideograph", "Ideographic"},
    144257: {"Unified_Ideograph", "Ideographic"},
    144258: {"Unified_Ideograph", "Ideographic"},
    144259: {"Unified_Ideograph", "Ideographic"},
    144260: {"Unified_Ideograph", "Ideographic"},
    144261: {"Unified_Ideograph", "Ideographic"},
    144262: {"Unified_Ideograph", "Ideographic"},
    144263: {"Unified_Ideograph", "Ideographic"},
    144264: {"Unified_Ideograph", "Ideographic"},
    144265: {"Unified_Ideograph", "Ideographic"},
    144266: {"Unified_Ideograph", "Ideographic"},
    144267: {"Unified_Ideograph", "Ideographic"},
    144268: {"Unified_Ideograph", "Ideographic"},
    144269: {"Unified_Ideograph", "Ideographic"},
    144270: {"Unified_Ideograph", "Ideographic"},
    144271: {"Unified_Ideograph", "Ideographic"},
    144272: {"Unified_Ideograph", "Ideographic"},
    144273: {"Unified_Ideograph", "Ideographic"},
    144274: {"Unified_Ideograph", "Ideographic"},
    144275: {"Unified_Ideograph", "Ideographic"},
    144276: {"Unified_Ideograph", "Ideographic"},
    144277: {"Unified_Ideograph", "Ideographic"},
    144278: {"Unified_Ideograph", "Ideographic"},
    144279: {"Unified_Ideograph", "Ideographic"},
    144280: {"Unified_Ideograph", "Ideographic"},
    144281: {"Unified_Ideograph", "Ideographic"},
    144282: {"Unified_Ideograph", "Ideographic"},
    144283: {"Unified_Ideograph", "Ideographic"},
    144284: {"Unified_Ideograph", "Ideographic"},
    144285: {"Unified_Ideograph", "Ideographic"},
    144286: {"Unified_Ideograph", "Ideographic"},
    144287: {"Unified_Ideograph", "Ideographic"},
    144288: {"Unified_Ideograph", "Ideographic"},
    144289: {"Unified_Ideograph", "Ideographic"},
    144290: {"Unified_Ideograph", "Ideographic"},
    144291: {"Unified_Ideograph", "Ideographic"},
    144292: {"Unified_Ideograph", "Ideographic"},
    144293: {"Unified_Ideograph", "Ideographic"},
    144294: {"Unified_Ideograph", "Ideographic"},
    144295: {"Unified_Ideograph", "Ideographic"},
    144296: {"Unified_Ideograph", "Ideographic"},
    144297: {"Unified_Ideograph", "Ideographic"},
    144298: {"Unified_Ideograph", "Ideographic"},
    144299: {"Unified_Ideograph", "Ideographic"},
    144300: {"Unified_Ideograph", "Ideographic"},
    144301: {"Unified_Ideograph", "Ideographic"},
    144302: {"Unified_Ideograph", "Ideographic"},
    144303: {"Unified_Ideograph", "Ideographic"},
    144304: {"Unified_Ideograph", "Ideographic"},
    144305: {"Unified_Ideograph", "Ideographic"},
    144306: {"Unified_Ideograph", "Ideographic"},
    144307: {"Unified_Ideograph", "Ideographic"},
    144308: {"Unified_Ideograph", "Ideographic"},
    144309: {"Unified_Ideograph", "Ideographic"},
    144310: {"Unified_Ideograph", "Ideographic"},
    144311: {"Unified_Ideograph", "Ideographic"},
    144312: {"Unified_Ideograph", "Ideographic"},
    144313: {"Unified_Ideograph", "Ideographic"},
    144314: {"Unified_Ideograph", "Ideographic"},
    144315: {"Unified_Ideograph", "Ideographic"},
    144316: {"Unified_Ideograph", "Ideographic"},
    144317: {"Unified_Ideograph", "Ideographic"},
    144318: {"Unified_Ideograph", "Ideographic"},
    144319: {"Unified_Ideograph", "Ideographic"},
    144320: {"Unified_Ideograph", "Ideographic"},
    144321: {"Unified_Ideograph", "Ideographic"},
    144322: {"Unified_Ideograph", "Ideographic"},
    144323: {"Unified_Ideograph", "Ideographic"},
    144324: {"Unified_Ideograph", "Ideographic"},
    144325: {"Unified_Ideograph", "Ideographic"},
    144326: {"Unified_Ideograph", "Ideographic"},
    144327: {"Unified_Ideograph", "Ideographic"},
    144328: {"Unified_Ideograph", "Ideographic"},
    144329: {"Unified_Ideograph", "Ideographic"},
    144330: {"Unified_Ideograph", "Ideographic"},
    144331: {"Unified_Ideograph", "Ideographic"},
    144332: {"Unified_Ideograph", "Ideographic"},
    144333: {"Unified_Ideograph", "Ideographic"},
    144334: {"Unified_Ideograph", "Ideographic"},
    144335: {"Unified_Ideograph", "Ideographic"},
    144336: {"Unified_Ideograph", "Ideographic"},
    144337: {"Unified_Ideograph", "Ideographic"},
    144338: {"Unified_Ideograph", "Ideographic"},
    144339: {"Unified_Ideograph", "Ideographic"},
    144340: {"Unified_Ideograph", "Ideographic"},
    144341: {"Unified_Ideograph", "Ideographic"},
    144342: {"Unified_Ideograph", "Ideographic"},
    144343: {"Unified_Ideograph", "Ideographic"},
    144344: {"Unified_Ideograph", "Ideographic"},
    144345: {"Unified_Ideograph", "Ideographic"},
    144346: {"Unified_Ideograph", "Ideographic"},
    144347: {"Unified_Ideograph", "Ideographic"},
    144348: {"Unified_Ideograph", "Ideographic"},
    144349: {"Unified_Ideograph", "Ideographic"},
    144350: {"Unified_Ideograph", "Ideographic"},
    144351: {"Unified_Ideograph", "Ideographic"},
    144352: {"Unified_Ideograph", "Ideographic"},
    144353: {"Unified_Ideograph", "Ideographic"},
    144354: {"Unified_Ideograph", "Ideographic"},
    144355: {"Unified_Ideograph", "Ideographic"},
    144356: {"Unified_Ideograph", "Ideographic"},
    144357: {"Unified_Ideograph", "Ideographic"},
    144358: {"Unified_Ideograph", "Ideographic"},
    144359: {"Unified_Ideograph", "Ideographic"},
    144360: {"Unified_Ideograph", "Ideographic"},
    144361: {"Unified_Ideograph", "Ideographic"},
    144362: {"Unified_Ideograph", "Ideographic"},
    144363: {"Unified_Ideograph", "Ideographic"},
    144364: {"Unified_Ideograph", "Ideographic"},
    144365: {"Unified_Ideograph", "Ideographic"},
    144366: {"Unified_Ideograph", "Ideographic"},
    144367: {"Unified_Ideograph", "Ideographic"},
    144368: {"Unified_Ideograph", "Ideographic"},
    144369: {"Unified_Ideograph", "Ideographic"},
    144370: {"Unified_Ideograph", "Ideographic"},
    144371: {"Unified_Ideograph", "Ideographic"},
    144372: {"Unified_Ideograph", "Ideographic"},
    144373: {"Unified_Ideograph", "Ideographic"},
    144374: {"Unified_Ideograph", "Ideographic"},
    144375: {"Unified_Ideograph", "Ideographic"},
    144376: {"Unified_Ideograph", "Ideographic"},
    144377: {"Unified_Ideograph", "Ideographic"},
    144378: {"Unified_Ideograph", "Ideographic"},
    144379: {"Unified_Ideograph", "Ideographic"},
    144380: {"Unified_Ideograph", "Ideographic"},
    144381: {"Unified_Ideograph", "Ideographic"},
    144382: {"Unified_Ideograph", "Ideographic"},
    144383: {"Unified_Ideograph", "Ideographic"},
    144384: {"Unified_Ideograph", "Ideographic"},
    144385: {"Unified_Ideograph", "Ideographic"},
    144386: {"Unified_Ideograph", "Ideographic"},
    144387: {"Unified_Ideograph", "Ideographic"},
    144388: {"Unified_Ideograph", "Ideographic"},
    144389: {"Unified_Ideograph", "Ideographic"},
    144390: {"Unified_Ideograph", "Ideographic"},
    144391: {"Unified_Ideograph", "Ideographic"},
    144392: {"Unified_Ideograph", "Ideographic"},
    144393: {"Unified_Ideograph", "Ideographic"},
    144394: {"Unified_Ideograph", "Ideographic"},
    144395: {"Unified_Ideograph", "Ideographic"},
    144396: {"Unified_Ideograph", "Ideographic"},
    144397: {"Unified_Ideograph", "Ideographic"},
    144398: {"Unified_Ideograph", "Ideographic"},
    144399: {"Unified_Ideograph", "Ideographic"},
    144400: {"Unified_Ideograph", "Ideographic"},
    144401: {"Unified_Ideograph", "Ideographic"},
    144402: {"Unified_Ideograph", "Ideographic"},
    144403: {"Unified_Ideograph", "Ideographic"},
    144404: {"Unified_Ideograph", "Ideographic"},
    144405: {"Unified_Ideograph", "Ideographic"},
    144406: {"Unified_Ideograph", "Ideographic"},
    144407: {"Unified_Ideograph", "Ideographic"},
    144408: {"Unified_Ideograph", "Ideographic"},
    144409: {"Unified_Ideograph", "Ideographic"},
    144410: {"Unified_Ideograph", "Ideographic"},
    144411: {"Unified_Ideograph", "Ideographic"},
    144412: {"Unified_Ideograph", "Ideographic"},
    144413: {"Unified_Ideograph", "Ideographic"},
    144414: {"Unified_Ideograph", "Ideographic"},
    144415: {"Unified_Ideograph", "Ideographic"},
    144416: {"Unified_Ideograph", "Ideographic"},
    144417: {"Unified_Ideograph", "Ideographic"},
    144418: {"Unified_Ideograph", "Ideographic"},
    144419: {"Unified_Ideograph", "Ideographic"},
    144420: {"Unified_Ideograph", "Ideographic"},
    144421: {"Unified_Ideograph", "Ideographic"},
    144422: {"Unified_Ideograph", "Ideographic"},
    144423: {"Unified_Ideograph", "Ideographic"},
    144424: {"Unified_Ideograph", "Ideographic"},
    144425: {"Unified_Ideograph", "Ideographic"},
    144426: {"Unified_Ideograph", "Ideographic"},
    144427: {"Unified_Ideograph", "Ideographic"},
    144428: {"Unified_Ideograph", "Ideographic"},
    144429: {"Unified_Ideograph", "Ideographic"},
    144430: {"Unified_Ideograph", "Ideographic"},
    144431: {"Unified_Ideograph", "Ideographic"},
    144432: {"Unified_Ideograph", "Ideographic"},
    144433: {"Unified_Ideograph", "Ideographic"},
    144434: {"Unified_Ideograph", "Ideographic"},
    144435: {"Unified_Ideograph", "Ideographic"},
    144436: {"Unified_Ideograph", "Ideographic"},
    144437: {"Unified_Ideograph", "Ideographic"},
    144438: {"Unified_Ideograph", "Ideographic"},
    144439: {"Unified_Ideograph", "Ideographic"},
    144440: {"Unified_Ideograph", "Ideographic"},
    144441: {"Unified_Ideograph", "Ideographic"},
    144442: {"Unified_Ideograph", "Ideographic"},
    144443: {"Unified_Ideograph", "Ideographic"},
    144444: {"Unified_Ideograph", "Ideographic"},
    144445: {"Unified_Ideograph", "Ideographic"},
    144446: {"Unified_Ideograph", "Ideographic"},
    144447: {"Unified_Ideograph", "Ideographic"},
    144448: {"Unified_Ideograph", "Ideographic"},
    144449: {"Unified_Ideograph", "Ideographic"},
    144450: {"Unified_Ideograph", "Ideographic"},
    144451: {"Unified_Ideograph", "Ideographic"},
    144452: {"Unified_Ideograph", "Ideographic"},
    144453: {"Unified_Ideograph", "Ideographic"},
    144454: {"Unified_Ideograph", "Ideographic"},
    144455: {"Unified_Ideograph", "Ideographic"},
    144456: {"Unified_Ideograph", "Ideographic"},
    144457: {"Unified_Ideograph", "Ideographic"},
    144458: {"Unified_Ideograph", "Ideographic"},
    144459: {"Unified_Ideograph", "Ideographic"},
    144460: {"Unified_Ideograph", "Ideographic"},
    144461: {"Unified_Ideograph", "Ideographic"},
    144462: {"Unified_Ideograph", "Ideographic"},
    144463: {"Unified_Ideograph", "Ideographic"},
    144464: {"Unified_Ideograph", "Ideographic"},
    144465: {"Unified_Ideograph", "Ideographic"},
    144466: {"Unified_Ideograph", "Ideographic"},
    144467: {"Unified_Ideograph", "Ideographic"},
    144468: {"Unified_Ideograph", "Ideographic"},
    144469: {"Unified_Ideograph", "Ideographic"},
    144470: {"Unified_Ideograph", "Ideographic"},
    144471: {"Unified_Ideograph", "Ideographic"},
    144472: {"Unified_Ideograph", "Ideographic"},
    144473: {"Unified_Ideograph", "Ideographic"},
    144474: {"Unified_Ideograph", "Ideographic"},
    144475: {"Unified_Ideograph", "Ideographic"},
    144476: {"Unified_Ideograph", "Ideographic"},
    144477: {"Unified_Ideograph", "Ideographic"},
    144478: {"Unified_Ideograph", "Ideographic"},
    144479: {"Unified_Ideograph", "Ideographic"},
    144480: {"Unified_Ideograph", "Ideographic"},
    144481: {"Unified_Ideograph", "Ideographic"},
    144482: {"Unified_Ideograph", "Ideographic"},
    144483: {"Unified_Ideograph", "Ideographic"},
    144484: {"Unified_Ideograph", "Ideographic"},
    144485: {"Unified_Ideograph", "Ideographic"},
    144486: {"Unified_Ideograph", "Ideographic"},
    144487: {"Unified_Ideograph", "Ideographic"},
    144488: {"Unified_Ideograph", "Ideographic"},
    144489: {"Unified_Ideograph", "Ideographic"},
    144490: {"Unified_Ideograph", "Ideographic"},
    144491: {"Unified_Ideograph", "Ideographic"},
    144492: {"Unified_Ideograph", "Ideographic"},
    144493: {"Unified_Ideograph", "Ideographic"},
    144494: {"Unified_Ideograph", "Ideographic"},
    144495: {"Unified_Ideograph", "Ideographic"},
    144496: {"Unified_Ideograph", "Ideographic"},
    144497: {"Unified_Ideograph", "Ideographic"},
    144498: {"Unified_Ideograph", "Ideographic"},
    144499: {"Unified_Ideograph", "Ideographic"},
    144500: {"Unified_Ideograph", "Ideographic"},
    144501: {"Unified_Ideograph", "Ideographic"},
    144502: {"Unified_Ideograph", "Ideographic"},
    144503: {"Unified_Ideograph", "Ideographic"},
    144504: {"Unified_Ideograph", "Ideographic"},
    144505: {"Unified_Ideograph", "Ideographic"},
    144506: {"Unified_Ideograph", "Ideographic"},
    144507: {"Unified_Ideograph", "Ideographic"},
    144508: {"Unified_Ideograph", "Ideographic"},
    144509: {"Unified_Ideograph", "Ideographic"},
    144510: {"Unified_Ideograph", "Ideographic"},
    144511: {"Unified_Ideograph", "Ideographic"},
    144512: {"Unified_Ideograph", "Ideographic"},
    144513: {"Unified_Ideograph", "Ideographic"},
    144514: {"Unified_Ideograph", "Ideographic"},
    144515: {"Unified_Ideograph", "Ideographic"},
    144516: {"Unified_Ideograph", "Ideographic"},
    144517: {"Unified_Ideograph", "Ideographic"},
    144518: {"Unified_Ideograph", "Ideographic"},
    144519: {"Unified_Ideograph", "Ideographic"},
    144520: {"Unified_Ideograph", "Ideographic"},
    144521: {"Unified_Ideograph", "Ideographic"},
    144522: {"Unified_Ideograph", "Ideographic"},
    144523: {"Unified_Ideograph", "Ideographic"},
    144524: {"Unified_Ideograph", "Ideographic"},
    144525: {"Unified_Ideograph", "Ideographic"},
    144526: {"Unified_Ideograph", "Ideographic"},
    144527: {"Unified_Ideograph", "Ideographic"},
    144528: {"Unified_Ideograph", "Ideographic"},
    144529: {"Unified_Ideograph", "Ideographic"},
    144530: {"Unified_Ideograph", "Ideographic"},
    144531: {"Unified_Ideograph", "Ideographic"},
    144532: {"Unified_Ideograph", "Ideographic"},
    144533: {"Unified_Ideograph", "Ideographic"},
    144534: {"Unified_Ideograph", "Ideographic"},
    144535: {"Unified_Ideograph", "Ideographic"},
    144536: {"Unified_Ideograph", "Ideographic"},
    144537: {"Unified_Ideograph", "Ideographic"},
    144538: {"Unified_Ideograph", "Ideographic"},
    144539: {"Unified_Ideograph", "Ideographic"},
    144540: {"Unified_Ideograph", "Ideographic"},
    144541: {"Unified_Ideograph", "Ideographic"},
    144542: {"Unified_Ideograph", "Ideographic"},
    144543: {"Unified_Ideograph", "Ideographic"},
    144544: {"Unified_Ideograph", "Ideographic"},
    144545: {"Unified_Ideograph", "Ideographic"},
    144546: {"Unified_Ideograph", "Ideographic"},
    144547: {"Unified_Ideograph", "Ideographic"},
    144548: {"Unified_Ideograph", "Ideographic"},
    144549: {"Unified_Ideograph", "Ideographic"},
    144550: {"Unified_Ideograph", "Ideographic"},
    144551: {"Unified_Ideograph", "Ideographic"},
    144552: {"Unified_Ideograph", "Ideographic"},
    144553: {"Unified_Ideograph", "Ideographic"},
    144554: {"Unified_Ideograph", "Ideographic"},
    144555: {"Unified_Ideograph", "Ideographic"},
    144556: {"Unified_Ideograph", "Ideographic"},
    144557: {"Unified_Ideograph", "Ideographic"},
    144558: {"Unified_Ideograph", "Ideographic"},
    144559: {"Unified_Ideograph", "Ideographic"},
    144560: {"Unified_Ideograph", "Ideographic"},
    144561: {"Unified_Ideograph", "Ideographic"},
    144562: {"Unified_Ideograph", "Ideographic"},
    144563: {"Unified_Ideograph", "Ideographic"},
    144564: {"Unified_Ideograph", "Ideographic"},
    144565: {"Unified_Ideograph", "Ideographic"},
    144566: {"Unified_Ideograph", "Ideographic"},
    144567: {"Unified_Ideograph", "Ideographic"},
    144568: {"Unified_Ideograph", "Ideographic"},
    144569: {"Unified_Ideograph", "Ideographic"},
    144570: {"Unified_Ideograph", "Ideographic"},
    144571: {"Unified_Ideograph", "Ideographic"},
    144572: {"Unified_Ideograph", "Ideographic"},
    144573: {"Unified_Ideograph", "Ideographic"},
    144574: {"Unified_Ideograph", "Ideographic"},
    144575: {"Unified_Ideograph", "Ideographic"},
    144576: {"Unified_Ideograph", "Ideographic"},
    144577: {"Unified_Ideograph", "Ideographic"},
    144578: {"Unified_Ideograph", "Ideographic"},
    144579: {"Unified_Ideograph", "Ideographic"},
    144580: {"Unified_Ideograph", "Ideographic"},
    144581: {"Unified_Ideograph", "Ideographic"},
    144582: {"Unified_Ideograph", "Ideographic"},
    144583: {"Unified_Ideograph", "Ideographic"},
    144584: {"Unified_Ideograph", "Ideographic"},
    144585: {"Unified_Ideograph", "Ideographic"},
    144586: {"Unified_Ideograph", "Ideographic"},
    144587: {"Unified_Ideograph", "Ideographic"},
    144588: {"Unified_Ideograph", "Ideographic"},
    144589: {"Unified_Ideograph", "Ideographic"},
    144590: {"Unified_Ideograph", "Ideographic"},
    144591: {"Unified_Ideograph", "Ideographic"},
    144592: {"Unified_Ideograph", "Ideographic"},
    144593: {"Unified_Ideograph", "Ideographic"},
    144594: {"Unified_Ideograph", "Ideographic"},
    144595: {"Unified_Ideograph", "Ideographic"},
    144596: {"Unified_Ideograph", "Ideographic"},
    144597: {"Unified_Ideograph", "Ideographic"},
    144598: {"Unified_Ideograph", "Ideographic"},
    144599: {"Unified_Ideograph", "Ideographic"},
    144600: {"Unified_Ideograph", "Ideographic"},
    144601: {"Unified_Ideograph", "Ideographic"},
    144602: {"Unified_Ideograph", "Ideographic"},
    144603: {"Unified_Ideograph", "Ideographic"},
    144604: {"Unified_Ideograph", "Ideographic"},
    144605: {"Unified_Ideograph", "Ideographic"},
    144606: {"Unified_Ideograph", "Ideographic"},
    144607: {"Unified_Ideograph", "Ideographic"},
    144608: {"Unified_Ideograph", "Ideographic"},
    144609: {"Unified_Ideograph", "Ideographic"},
    144610: {"Unified_Ideograph", "Ideographic"},
    144611: {"Unified_Ideograph", "Ideographic"},
    144612: {"Unified_Ideograph", "Ideographic"},
    144613: {"Unified_Ideograph", "Ideographic"},
    144614: {"Unified_Ideograph", "Ideographic"},
    144615: {"Unified_Ideograph", "Ideographic"},
    144616: {"Unified_Ideograph", "Ideographic"},
    144617: {"Unified_Ideograph", "Ideographic"},
    144618: {"Unified_Ideograph", "Ideographic"},
    144619: {"Unified_Ideograph", "Ideographic"},
    144620: {"Unified_Ideograph", "Ideographic"},
    144621: {"Unified_Ideograph", "Ideographic"},
    144622: {"Unified_Ideograph", "Ideographic"},
    144623: {"Unified_Ideograph", "Ideographic"},
    144624: {"Unified_Ideograph", "Ideographic"},
    144625: {"Unified_Ideograph", "Ideographic"},
    144626: {"Unified_Ideograph", "Ideographic"},
    144627: {"Unified_Ideograph", "Ideographic"},
    144628: {"Unified_Ideograph", "Ideographic"},
    144629: {"Unified_Ideograph", "Ideographic"},
    144630: {"Unified_Ideograph", "Ideographic"},
    144631: {"Unified_Ideograph", "Ideographic"},
    144632: {"Unified_Ideograph", "Ideographic"},
    144633: {"Unified_Ideograph", "Ideographic"},
    144634: {"Unified_Ideograph", "Ideographic"},
    144635: {"Unified_Ideograph", "Ideographic"},
    144636: {"Unified_Ideograph", "Ideographic"},
    144637: {"Unified_Ideograph", "Ideographic"},
    144638: {"Unified_Ideograph", "Ideographic"},
    144639: {"Unified_Ideograph", "Ideographic"},
    144640: {"Unified_Ideograph", "Ideographic"},
    144641: {"Unified_Ideograph", "Ideographic"},
    144642: {"Unified_Ideograph", "Ideographic"},
    144643: {"Unified_Ideograph", "Ideographic"},
    144644: {"Unified_Ideograph", "Ideographic"},
    144645: {"Unified_Ideograph", "Ideographic"},
    144646: {"Unified_Ideograph", "Ideographic"},
    144647: {"Unified_Ideograph", "Ideographic"},
    144648: {"Unified_Ideograph", "Ideographic"},
    144649: {"Unified_Ideograph", "Ideographic"},
    144650: {"Unified_Ideograph", "Ideographic"},
    144651: {"Unified_Ideograph", "Ideographic"},
    144652: {"Unified_Ideograph", "Ideographic"},
    144653: {"Unified_Ideograph", "Ideographic"},
    144654: {"Unified_Ideograph", "Ideographic"},
    144655: {"Unified_Ideograph", "Ideographic"},
    144656: {"Unified_Ideograph", "Ideographic"},
    144657: {"Unified_Ideograph", "Ideographic"},
    144658: {"Unified_Ideograph", "Ideographic"},
    144659: {"Unified_Ideograph", "Ideographic"},
    144660: {"Unified_Ideograph", "Ideographic"},
    144661: {"Unified_Ideograph", "Ideographic"},
    144662: {"Unified_Ideograph", "Ideographic"},
    144663: {"Unified_Ideograph", "Ideographic"},
    144664: {"Unified_Ideograph", "Ideographic"},
    144665: {"Unified_Ideograph", "Ideographic"},
    144666: {"Unified_Ideograph", "Ideographic"},
    144667: {"Unified_Ideograph", "Ideographic"},
    144668: {"Unified_Ideograph", "Ideographic"},
    144669: {"Unified_Ideograph", "Ideographic"},
    144670: {"Unified_Ideograph", "Ideographic"},
    144671: {"Unified_Ideograph", "Ideographic"},
    144672: {"Unified_Ideograph", "Ideographic"},
    144673: {"Unified_Ideograph", "Ideographic"},
    144674: {"Unified_Ideograph", "Ideographic"},
    144675: {"Unified_Ideograph", "Ideographic"},
    144676: {"Unified_Ideograph", "Ideographic"},
    144677: {"Unified_Ideograph", "Ideographic"},
    144678: {"Unified_Ideograph", "Ideographic"},
    144679: {"Unified_Ideograph", "Ideographic"},
    144680: {"Unified_Ideograph", "Ideographic"},
    144681: {"Unified_Ideograph", "Ideographic"},
    144682: {"Unified_Ideograph", "Ideographic"},
    144683: {"Unified_Ideograph", "Ideographic"},
    144684: {"Unified_Ideograph", "Ideographic"},
    144685: {"Unified_Ideograph", "Ideographic"},
    144686: {"Unified_Ideograph", "Ideographic"},
    144687: {"Unified_Ideograph", "Ideographic"},
    144688: {"Unified_Ideograph", "Ideographic"},
    144689: {"Unified_Ideograph", "Ideographic"},
    144690: {"Unified_Ideograph", "Ideographic"},
    144691: {"Unified_Ideograph", "Ideographic"},
    144692: {"Unified_Ideograph", "Ideographic"},
    144693: {"Unified_Ideograph", "Ideographic"},
    144694: {"Unified_Ideograph", "Ideographic"},
    144695: {"Unified_Ideograph", "Ideographic"},
    144696: {"Unified_Ideograph", "Ideographic"},
    144697: {"Unified_Ideograph", "Ideographic"},
    144698: {"Unified_Ideograph", "Ideographic"},
    144699: {"Unified_Ideograph", "Ideographic"},
    144700: {"Unified_Ideograph", "Ideographic"},
    144701: {"Unified_Ideograph", "Ideographic"},
    144702: {"Unified_Ideograph", "Ideographic"},
    144703: {"Unified_Ideograph", "Ideographic"},
    144704: {"Unified_Ideograph", "Ideographic"},
    144705: {"Unified_Ideograph", "Ideographic"},
    144706: {"Unified_Ideograph", "Ideographic"},
    144707: {"Unified_Ideograph", "Ideographic"},
    144708: {"Unified_Ideograph", "Ideographic"},
    144709: {"Unified_Ideograph", "Ideographic"},
    144710: {"Unified_Ideograph", "Ideographic"},
    144711: {"Unified_Ideograph", "Ideographic"},
    144712: {"Unified_Ideograph", "Ideographic"},
    144713: {"Unified_Ideograph", "Ideographic"},
    144714: {"Unified_Ideograph", "Ideographic"},
    144715: {"Unified_Ideograph", "Ideographic"},
    144716: {"Unified_Ideograph", "Ideographic"},
    144717: {"Unified_Ideograph", "Ideographic"},
    144718: {"Unified_Ideograph", "Ideographic"},
    144719: {"Unified_Ideograph", "Ideographic"},
    144720: {"Unified_Ideograph", "Ideographic"},
    144721: {"Unified_Ideograph", "Ideographic"},
    144722: {"Unified_Ideograph", "Ideographic"},
    144723: {"Unified_Ideograph", "Ideographic"},
    144724: {"Unified_Ideograph", "Ideographic"},
    144725: {"Unified_Ideograph", "Ideographic"},
    144726: {"Unified_Ideograph", "Ideographic"},
    144727: {"Unified_Ideograph", "Ideographic"},
    144728: {"Unified_Ideograph", "Ideographic"},
    144729: {"Unified_Ideograph", "Ideographic"},
    144730: {"Unified_Ideograph", "Ideographic"},
    144731: {"Unified_Ideograph", "Ideographic"},
    144732: {"Unified_Ideograph", "Ideographic"},
    144733: {"Unified_Ideograph", "Ideographic"},
    144734: {"Unified_Ideograph", "Ideographic"},
    144735: {"Unified_Ideograph", "Ideographic"},
    144736: {"Unified_Ideograph", "Ideographic"},
    144737: {"Unified_Ideograph", "Ideographic"},
    144738: {"Unified_Ideograph", "Ideographic"},
    144739: {"Unified_Ideograph", "Ideographic"},
    144740: {"Unified_Ideograph", "Ideographic"},
    144741: {"Unified_Ideograph", "Ideographic"},
    144742: {"Unified_Ideograph", "Ideographic"},
    144743: {"Unified_Ideograph", "Ideographic"},
    144744: {"Unified_Ideograph", "Ideographic"},
    144745: {"Unified_Ideograph", "Ideographic"},
    144746: {"Unified_Ideograph", "Ideographic"},
    144747: {"Unified_Ideograph", "Ideographic"},
    144748: {"Unified_Ideograph", "Ideographic"},
    144749: {"Unified_Ideograph", "Ideographic"},
    144750: {"Unified_Ideograph", "Ideographic"},
    144751: {"Unified_Ideograph", "Ideographic"},
    144752: {"Unified_Ideograph", "Ideographic"},
    144753: {"Unified_Ideograph", "Ideographic"},
    144754: {"Unified_Ideograph", "Ideographic"},
    144755: {"Unified_Ideograph", "Ideographic"},
    144756: {"Unified_Ideograph", "Ideographic"},
    144757: {"Unified_Ideograph", "Ideographic"},
    144758: {"Unified_Ideograph", "Ideographic"},
    144759: {"Unified_Ideograph", "Ideographic"},
    144760: {"Unified_Ideograph", "Ideographic"},
    144761: {"Unified_Ideograph", "Ideographic"},
    144762: {"Unified_Ideograph", "Ideographic"},
    144763: {"Unified_Ideograph", "Ideographic"},
    144764: {"Unified_Ideograph", "Ideographic"},
    144765: {"Unified_Ideograph", "Ideographic"},
    144766: {"Unified_Ideograph", "Ideographic"},
    144767: {"Unified_Ideograph", "Ideographic"},
    144768: {"Unified_Ideograph", "Ideographic"},
    144769: {"Unified_Ideograph", "Ideographic"},
    144770: {"Unified_Ideograph", "Ideographic"},
    144771: {"Unified_Ideograph", "Ideographic"},
    144772: {"Unified_Ideograph", "Ideographic"},
    144773: {"Unified_Ideograph", "Ideographic"},
    144774: {"Unified_Ideograph", "Ideographic"},
    144775: {"Unified_Ideograph", "Ideographic"},
    144776: {"Unified_Ideograph", "Ideographic"},
    144777: {"Unified_Ideograph", "Ideographic"},
    144778: {"Unified_Ideograph", "Ideographic"},
    144779: {"Unified_Ideograph", "Ideographic"},
    144780: {"Unified_Ideograph", "Ideographic"},
    144781: {"Unified_Ideograph", "Ideographic"},
    144782: {"Unified_Ideograph", "Ideographic"},
    144783: {"Unified_Ideograph", "Ideographic"},
    144784: {"Unified_Ideograph", "Ideographic"},
    144785: {"Unified_Ideograph", "Ideographic"},
    144786: {"Unified_Ideograph", "Ideographic"},
    144787: {"Unified_Ideograph", "Ideographic"},
    144788: {"Unified_Ideograph", "Ideographic"},
    144789: {"Unified_Ideograph", "Ideographic"},
    144790: {"Unified_Ideograph", "Ideographic"},
    144791: {"Unified_Ideograph", "Ideographic"},
    144792: {"Unified_Ideograph", "Ideographic"},
    144793: {"Unified_Ideograph", "Ideographic"},
    144794: {"Unified_Ideograph", "Ideographic"},
    144795: {"Unified_Ideograph", "Ideographic"},
    144796: {"Unified_Ideograph", "Ideographic"},
    144797: {"Unified_Ideograph", "Ideographic"},
    144798: {"Unified_Ideograph", "Ideographic"},
    144799: {"Unified_Ideograph", "Ideographic"},
    144800: {"Unified_Ideograph", "Ideographic"},
    144801: {"Unified_Ideograph", "Ideographic"},
    144802: {"Unified_Ideograph", "Ideographic"},
    144803: {"Unified_Ideograph", "Ideographic"},
    144804: {"Unified_Ideograph", "Ideographic"},
    144805: {"Unified_Ideograph", "Ideographic"},
    144806: {"Unified_Ideograph", "Ideographic"},
    144807: {"Unified_Ideograph", "Ideographic"},
    144808: {"Unified_Ideograph", "Ideographic"},
    144809: {"Unified_Ideograph", "Ideographic"},
    144810: {"Unified_Ideograph", "Ideographic"},
    144811: {"Unified_Ideograph", "Ideographic"},
    144812: {"Unified_Ideograph", "Ideographic"},
    144813: {"Unified_Ideograph", "Ideographic"},
    144814: {"Unified_Ideograph", "Ideographic"},
    144815: {"Unified_Ideograph", "Ideographic"},
    144816: {"Unified_Ideograph", "Ideographic"},
    144817: {"Unified_Ideograph", "Ideographic"},
    144818: {"Unified_Ideograph", "Ideographic"},
    144819: {"Unified_Ideograph", "Ideographic"},
    144820: {"Unified_Ideograph", "Ideographic"},
    144821: {"Unified_Ideograph", "Ideographic"},
    144822: {"Unified_Ideograph", "Ideographic"},
    144823: {"Unified_Ideograph", "Ideographic"},
    144824: {"Unified_Ideograph", "Ideographic"},
    144825: {"Unified_Ideograph", "Ideographic"},
    144826: {"Unified_Ideograph", "Ideographic"},
    144827: {"Unified_Ideograph", "Ideographic"},
    144828: {"Unified_Ideograph", "Ideographic"},
    144829: {"Unified_Ideograph", "Ideographic"},
    144830: {"Unified_Ideograph", "Ideographic"},
    144831: {"Unified_Ideograph", "Ideographic"},
    144832: {"Unified_Ideograph", "Ideographic"},
    144833: {"Unified_Ideograph", "Ideographic"},
    144834: {"Unified_Ideograph", "Ideographic"},
    144835: {"Unified_Ideograph", "Ideographic"},
    144836: {"Unified_Ideograph", "Ideographic"},
    144837: {"Unified_Ideograph", "Ideographic"},
    144838: {"Unified_Ideograph", "Ideographic"},
    144839: {"Unified_Ideograph", "Ideographic"},
    144840: {"Unified_Ideograph", "Ideographic"},
    144841: {"Unified_Ideograph", "Ideographic"},
    144842: {"Unified_Ideograph", "Ideographic"},
    144843: {"Unified_Ideograph", "Ideographic"},
    144844: {"Unified_Ideograph", "Ideographic"},
    144845: {"Unified_Ideograph", "Ideographic"},
    144846: {"Unified_Ideograph", "Ideographic"},
    144847: {"Unified_Ideograph", "Ideographic"},
    144848: {"Unified_Ideograph", "Ideographic"},
    144849: {"Unified_Ideograph", "Ideographic"},
    144850: {"Unified_Ideograph", "Ideographic"},
    144851: {"Unified_Ideograph", "Ideographic"},
    144852: {"Unified_Ideograph", "Ideographic"},
    144853: {"Unified_Ideograph", "Ideographic"},
    144854: {"Unified_Ideograph", "Ideographic"},
    144855: {"Unified_Ideograph", "Ideographic"},
    144856: {"Unified_Ideograph", "Ideographic"},
    144857: {"Unified_Ideograph", "Ideographic"},
    144858: {"Unified_Ideograph", "Ideographic"},
    144859: {"Unified_Ideograph", "Ideographic"},
    144860: {"Unified_Ideograph", "Ideographic"},
    144861: {"Unified_Ideograph", "Ideographic"},
    144862: {"Unified_Ideograph", "Ideographic"},
    144863: {"Unified_Ideograph", "Ideographic"},
    144864: {"Unified_Ideograph", "Ideographic"},
    144865: {"Unified_Ideograph", "Ideographic"},
    144866: {"Unified_Ideograph", "Ideographic"},
    144867: {"Unified_Ideograph", "Ideographic"},
    144868: {"Unified_Ideograph", "Ideographic"},
    144869: {"Unified_Ideograph", "Ideographic"},
    144870: {"Unified_Ideograph", "Ideographic"},
    144871: {"Unified_Ideograph", "Ideographic"},
    144872: {"Unified_Ideograph", "Ideographic"},
    144873: {"Unified_Ideograph", "Ideographic"},
    144874: {"Unified_Ideograph", "Ideographic"},
    144875: {"Unified_Ideograph", "Ideographic"},
    144876: {"Unified_Ideograph", "Ideographic"},
    144877: {"Unified_Ideograph", "Ideographic"},
    144878: {"Unified_Ideograph", "Ideographic"},
    144879: {"Unified_Ideograph", "Ideographic"},
    144880: {"Unified_Ideograph", "Ideographic"},
    144881: {"Unified_Ideograph", "Ideographic"},
    144882: {"Unified_Ideograph", "Ideographic"},
    144883: {"Unified_Ideograph", "Ideographic"},
    144884: {"Unified_Ideograph", "Ideographic"},
    144885: {"Unified_Ideograph", "Ideographic"},
    144886: {"Unified_Ideograph", "Ideographic"},
    144887: {"Unified_Ideograph", "Ideographic"},
    144888: {"Unified_Ideograph", "Ideographic"},
    144889: {"Unified_Ideograph", "Ideographic"},
    144890: {"Unified_Ideograph", "Ideographic"},
    144891: {"Unified_Ideograph", "Ideographic"},
    144892: {"Unified_Ideograph", "Ideographic"},
    144893: {"Unified_Ideograph", "Ideographic"},
    144894: {"Unified_Ideograph", "Ideographic"},
    144895: {"Unified_Ideograph", "Ideographic"},
    144896: {"Unified_Ideograph", "Ideographic"},
    144897: {"Unified_Ideograph", "Ideographic"},
    144898: {"Unified_Ideograph", "Ideographic"},
    144899: {"Unified_Ideograph", "Ideographic"},
    144900: {"Unified_Ideograph", "Ideographic"},
    144901: {"Unified_Ideograph", "Ideographic"},
    144902: {"Unified_Ideograph", "Ideographic"},
    144903: {"Unified_Ideograph", "Ideographic"},
    144904: {"Unified_Ideograph", "Ideographic"},
    144905: {"Unified_Ideograph", "Ideographic"},
    144906: {"Unified_Ideograph", "Ideographic"},
    144907: {"Unified_Ideograph", "Ideographic"},
    144908: {"Unified_Ideograph", "Ideographic"},
    144909: {"Unified_Ideograph", "Ideographic"},
    144910: {"Unified_Ideograph", "Ideographic"},
    144911: {"Unified_Ideograph", "Ideographic"},
    144912: {"Unified_Ideograph", "Ideographic"},
    144913: {"Unified_Ideograph", "Ideographic"},
    144914: {"Unified_Ideograph", "Ideographic"},
    144915: {"Unified_Ideograph", "Ideographic"},
    144916: {"Unified_Ideograph", "Ideographic"},
    144917: {"Unified_Ideograph", "Ideographic"},
    144918: {"Unified_Ideograph", "Ideographic"},
    144919: {"Unified_Ideograph", "Ideographic"},
    144920: {"Unified_Ideograph", "Ideographic"},
    144921: {"Unified_Ideograph", "Ideographic"},
    144922: {"Unified_Ideograph", "Ideographic"},
    144923: {"Unified_Ideograph", "Ideographic"},
    144924: {"Unified_Ideograph", "Ideographic"},
    144925: {"Unified_Ideograph", "Ideographic"},
    144926: {"Unified_Ideograph", "Ideographic"},
    144927: {"Unified_Ideograph", "Ideographic"},
    144928: {"Unified_Ideograph", "Ideographic"},
    144929: {"Unified_Ideograph", "Ideographic"},
    144930: {"Unified_Ideograph", "Ideographic"},
    144931: {"Unified_Ideograph", "Ideographic"},
    144932: {"Unified_Ideograph", "Ideographic"},
    144933: {"Unified_Ideograph", "Ideographic"},
    144934: {"Unified_Ideograph", "Ideographic"},
    144935: {"Unified_Ideograph", "Ideographic"},
    144936: {"Unified_Ideograph", "Ideographic"},
    144937: {"Unified_Ideograph", "Ideographic"},
    144938: {"Unified_Ideograph", "Ideographic"},
    144939: {"Unified_Ideograph", "Ideographic"},
    144940: {"Unified_Ideograph", "Ideographic"},
    144941: {"Unified_Ideograph", "Ideographic"},
    144942: {"Unified_Ideograph", "Ideographic"},
    144943: {"Unified_Ideograph", "Ideographic"},
    144944: {"Unified_Ideograph", "Ideographic"},
    144945: {"Unified_Ideograph", "Ideographic"},
    144946: {"Unified_Ideograph", "Ideographic"},
    144947: {"Unified_Ideograph", "Ideographic"},
    144948: {"Unified_Ideograph", "Ideographic"},
    144949: {"Unified_Ideograph", "Ideographic"},
    144950: {"Unified_Ideograph", "Ideographic"},
    144951: {"Unified_Ideograph", "Ideographic"},
    144952: {"Unified_Ideograph", "Ideographic"},
    144953: {"Unified_Ideograph", "Ideographic"},
    144954: {"Unified_Ideograph", "Ideographic"},
    144955: {"Unified_Ideograph", "Ideographic"},
    144956: {"Unified_Ideograph", "Ideographic"},
    144957: {"Unified_Ideograph", "Ideographic"},
    144958: {"Unified_Ideograph", "Ideographic"},
    144959: {"Unified_Ideograph", "Ideographic"},
    144960: {"Unified_Ideograph", "Ideographic"},
    144961: {"Unified_Ideograph", "Ideographic"},
    144962: {"Unified_Ideograph", "Ideographic"},
    144963: {"Unified_Ideograph", "Ideographic"},
    144964: {"Unified_Ideograph", "Ideographic"},
    144965: {"Unified_Ideograph", "Ideographic"},
    144966: {"Unified_Ideograph", "Ideographic"},
    144967: {"Unified_Ideograph", "Ideographic"},
    144968: {"Unified_Ideograph", "Ideographic"},
    144969: {"Unified_Ideograph", "Ideographic"},
    144970: {"Unified_Ideograph", "Ideographic"},
    144971: {"Unified_Ideograph", "Ideographic"},
    144972: {"Unified_Ideograph", "Ideographic"},
    144973: {"Unified_Ideograph", "Ideographic"},
    144974: {"Unified_Ideograph", "Ideographic"},
    144975: {"Unified_Ideograph", "Ideographic"},
    144976: {"Unified_Ideograph", "Ideographic"},
    144977: {"Unified_Ideograph", "Ideographic"},
    144978: {"Unified_Ideograph", "Ideographic"},
    144979: {"Unified_Ideograph", "Ideographic"},
    144980: {"Unified_Ideograph", "Ideographic"},
    144981: {"Unified_Ideograph", "Ideographic"},
    144982: {"Unified_Ideograph", "Ideographic"},
    144983: {"Unified_Ideograph", "Ideographic"},
    144984: {"Unified_Ideograph", "Ideographic"},
    144985: {"Unified_Ideograph", "Ideographic"},
    144986: {"Unified_Ideograph", "Ideographic"},
    144987: {"Unified_Ideograph", "Ideographic"},
    144988: {"Unified_Ideograph", "Ideographic"},
    144989: {"Unified_Ideograph", "Ideographic"},
    144990: {"Unified_Ideograph", "Ideographic"},
    144991: {"Unified_Ideograph", "Ideographic"},
    144992: {"Unified_Ideograph", "Ideographic"},
    144993: {"Unified_Ideograph", "Ideographic"},
    144994: {"Unified_Ideograph", "Ideographic"},
    144995: {"Unified_Ideograph", "Ideographic"},
    144996: {"Unified_Ideograph", "Ideographic"},
    144997: {"Unified_Ideograph", "Ideographic"},
    144998: {"Unified_Ideograph", "Ideographic"},
    144999: {"Unified_Ideograph", "Ideographic"},
    145000: {"Unified_Ideograph", "Ideographic"},
    145001: {"Unified_Ideograph", "Ideographic"},
    145002: {"Unified_Ideograph", "Ideographic"},
    145003: {"Unified_Ideograph", "Ideographic"},
    145004: {"Unified_Ideograph", "Ideographic"},
    145005: {"Unified_Ideograph", "Ideographic"},
    145006: {"Unified_Ideograph", "Ideographic"},
    145007: {"Unified_Ideograph", "Ideographic"},
    145008: {"Unified_Ideograph", "Ideographic"},
    145009: {"Unified_Ideograph", "Ideographic"},
    145010: {"Unified_Ideograph", "Ideographic"},
    145011: {"Unified_Ideograph", "Ideographic"},
    145012: {"Unified_Ideograph", "Ideographic"},
    145013: {"Unified_Ideograph", "Ideographic"},
    145014: {"Unified_Ideograph", "Ideographic"},
    145015: {"Unified_Ideograph", "Ideographic"},
    145016: {"Unified_Ideograph", "Ideographic"},
    145017: {"Unified_Ideograph", "Ideographic"},
    145018: {"Unified_Ideograph", "Ideographic"},
    145019: {"Unified_Ideograph", "Ideographic"},
    145020: {"Unified_Ideograph", "Ideographic"},
    145021: {"Unified_Ideograph", "Ideographic"},
    145022: {"Unified_Ideograph", "Ideographic"},
    145023: {"Unified_Ideograph", "Ideographic"},
    145024: {"Unified_Ideograph", "Ideographic"},
    145025: {"Unified_Ideograph", "Ideographic"},
    145026: {"Unified_Ideograph", "Ideographic"},
    145027: {"Unified_Ideograph", "Ideographic"},
    145028: {"Unified_Ideograph", "Ideographic"},
    145029: {"Unified_Ideograph", "Ideographic"},
    145030: {"Unified_Ideograph", "Ideographic"},
    145031: {"Unified_Ideograph", "Ideographic"},
    145032: {"Unified_Ideograph", "Ideographic"},
    145033: {"Unified_Ideograph", "Ideographic"},
    145034: {"Unified_Ideograph", "Ideographic"},
    145035: {"Unified_Ideograph", "Ideographic"},
    145036: {"Unified_Ideograph", "Ideographic"},
    145037: {"Unified_Ideograph", "Ideographic"},
    145038: {"Unified_Ideograph", "Ideographic"},
    145039: {"Unified_Ideograph", "Ideographic"},
    145040: {"Unified_Ideograph", "Ideographic"},
    145041: {"Unified_Ideograph", "Ideographic"},
    145042: {"Unified_Ideograph", "Ideographic"},
    145043: {"Unified_Ideograph", "Ideographic"},
    145044: {"Unified_Ideograph", "Ideographic"},
    145045: {"Unified_Ideograph", "Ideographic"},
    145046: {"Unified_Ideograph", "Ideographic"},
    145047: {"Unified_Ideograph", "Ideographic"},
    145048: {"Unified_Ideograph", "Ideographic"},
    145049: {"Unified_Ideograph", "Ideographic"},
    145050: {"Unified_Ideograph", "Ideographic"},
    145051: {"Unified_Ideograph", "Ideographic"},
    145052: {"Unified_Ideograph", "Ideographic"},
    145053: {"Unified_Ideograph", "Ideographic"},
    145054: {"Unified_Ideograph", "Ideographic"},
    145055: {"Unified_Ideograph", "Ideographic"},
    145056: {"Unified_Ideograph", "Ideographic"},
    145057: {"Unified_Ideograph", "Ideographic"},
    145058: {"Unified_Ideograph", "Ideographic"},
    145059: {"Unified_Ideograph", "Ideographic"},
    145060: {"Unified_Ideograph", "Ideographic"},
    145061: {"Unified_Ideograph", "Ideographic"},
    145062: {"Unified_Ideograph", "Ideographic"},
    145063: {"Unified_Ideograph", "Ideographic"},
    145064: {"Unified_Ideograph", "Ideographic"},
    145065: {"Unified_Ideograph", "Ideographic"},
    145066: {"Unified_Ideograph", "Ideographic"},
    145067: {"Unified_Ideograph", "Ideographic"},
    145068: {"Unified_Ideograph", "Ideographic"},
    145069: {"Unified_Ideograph", "Ideographic"},
    145070: {"Unified_Ideograph", "Ideographic"},
    145071: {"Unified_Ideograph", "Ideographic"},
    145072: {"Unified_Ideograph", "Ideographic"},
    145073: {"Unified_Ideograph", "Ideographic"},
    145074: {"Unified_Ideograph", "Ideographic"},
    145075: {"Unified_Ideograph", "Ideographic"},
    145076: {"Unified_Ideograph", "Ideographic"},
    145077: {"Unified_Ideograph", "Ideographic"},
    145078: {"Unified_Ideograph", "Ideographic"},
    145079: {"Unified_Ideograph", "Ideographic"},
    145080: {"Unified_Ideograph", "Ideographic"},
    145081: {"Unified_Ideograph", "Ideographic"},
    145082: {"Unified_Ideograph", "Ideographic"},
    145083: {"Unified_Ideograph", "Ideographic"},
    145084: {"Unified_Ideograph", "Ideographic"},
    145085: {"Unified_Ideograph", "Ideographic"},
    145086: {"Unified_Ideograph", "Ideographic"},
    145087: {"Unified_Ideograph", "Ideographic"},
    145088: {"Unified_Ideograph", "Ideographic"},
    145089: {"Unified_Ideograph", "Ideographic"},
    145090: {"Unified_Ideograph", "Ideographic"},
    145091: {"Unified_Ideograph", "Ideographic"},
    145092: {"Unified_Ideograph", "Ideographic"},
    145093: {"Unified_Ideograph", "Ideographic"},
    145094: {"Unified_Ideograph", "Ideographic"},
    145095: {"Unified_Ideograph", "Ideographic"},
    145096: {"Unified_Ideograph", "Ideographic"},
    145097: {"Unified_Ideograph", "Ideographic"},
    145098: {"Unified_Ideograph", "Ideographic"},
    145099: {"Unified_Ideograph", "Ideographic"},
    145100: {"Unified_Ideograph", "Ideographic"},
    145101: {"Unified_Ideograph", "Ideographic"},
    145102: {"Unified_Ideograph", "Ideographic"},
    145103: {"Unified_Ideograph", "Ideographic"},
    145104: {"Unified_Ideograph", "Ideographic"},
    145105: {"Unified_Ideograph", "Ideographic"},
    145106: {"Unified_Ideograph", "Ideographic"},
    145107: {"Unified_Ideograph", "Ideographic"},
    145108: {"Unified_Ideograph", "Ideographic"},
    145109: {"Unified_Ideograph", "Ideographic"},
    145110: {"Unified_Ideograph", "Ideographic"},
    145111: {"Unified_Ideograph", "Ideographic"},
    145112: {"Unified_Ideograph", "Ideographic"},
    145113: {"Unified_Ideograph", "Ideographic"},
    145114: {"Unified_Ideograph", "Ideographic"},
    145115: {"Unified_Ideograph", "Ideographic"},
    145116: {"Unified_Ideograph", "Ideographic"},
    145117: {"Unified_Ideograph", "Ideographic"},
    145118: {"Unified_Ideograph", "Ideographic"},
    145119: {"Unified_Ideograph", "Ideographic"},
    145120: {"Unified_Ideograph", "Ideographic"},
    145121: {"Unified_Ideograph", "Ideographic"},
    145122: {"Unified_Ideograph", "Ideographic"},
    145123: {"Unified_Ideograph", "Ideographic"},
    145124: {"Unified_Ideograph", "Ideographic"},
    145125: {"Unified_Ideograph", "Ideographic"},
    145126: {"Unified_Ideograph", "Ideographic"},
    145127: {"Unified_Ideograph", "Ideographic"},
    145128: {"Unified_Ideograph", "Ideographic"},
    145129: {"Unified_Ideograph", "Ideographic"},
    145130: {"Unified_Ideograph", "Ideographic"},
    145131: {"Unified_Ideograph", "Ideographic"},
    145132: {"Unified_Ideograph", "Ideographic"},
    145133: {"Unified_Ideograph", "Ideographic"},
    145134: {"Unified_Ideograph", "Ideographic"},
    145135: {"Unified_Ideograph", "Ideographic"},
    145136: {"Unified_Ideograph", "Ideographic"},
    145137: {"Unified_Ideograph", "Ideographic"},
    145138: {"Unified_Ideograph", "Ideographic"},
    145139: {"Unified_Ideograph", "Ideographic"},
    145140: {"Unified_Ideograph", "Ideographic"},
    145141: {"Unified_Ideograph", "Ideographic"},
    145142: {"Unified_Ideograph", "Ideographic"},
    145143: {"Unified_Ideograph", "Ideographic"},
    145144: {"Unified_Ideograph", "Ideographic"},
    145145: {"Unified_Ideograph", "Ideographic"},
    145146: {"Unified_Ideograph", "Ideographic"},
    145147: {"Unified_Ideograph", "Ideographic"},
    145148: {"Unified_Ideograph", "Ideographic"},
    145149: {"Unified_Ideograph", "Ideographic"},
    145150: {"Unified_Ideograph", "Ideographic"},
    145151: {"Unified_Ideograph", "Ideographic"},
    145152: {"Unified_Ideograph", "Ideographic"},
    145153: {"Unified_Ideograph", "Ideographic"},
    145154: {"Unified_Ideograph", "Ideographic"},
    145155: {"Unified_Ideograph", "Ideographic"},
    145156: {"Unified_Ideograph", "Ideographic"},
    145157: {"Unified_Ideograph", "Ideographic"},
    145158: {"Unified_Ideograph", "Ideographic"},
    145159: {"Unified_Ideograph", "Ideographic"},
    145160: {"Unified_Ideograph", "Ideographic"},
    145161: {"Unified_Ideograph", "Ideographic"},
    145162: {"Unified_Ideograph", "Ideographic"},
    145163: {"Unified_Ideograph", "Ideographic"},
    145164: {"Unified_Ideograph", "Ideographic"},
    145165: {"Unified_Ideograph", "Ideographic"},
    145166: {"Unified_Ideograph", "Ideographic"},
    145167: {"Unified_Ideograph", "Ideographic"},
    145168: {"Unified_Ideograph", "Ideographic"},
    145169: {"Unified_Ideograph", "Ideographic"},
    145170: {"Unified_Ideograph", "Ideographic"},
    145171: {"Unified_Ideograph", "Ideographic"},
    145172: {"Unified_Ideograph", "Ideographic"},
    145173: {"Unified_Ideograph", "Ideographic"},
    145174: {"Unified_Ideograph", "Ideographic"},
    145175: {"Unified_Ideograph", "Ideographic"},
    145176: {"Unified_Ideograph", "Ideographic"},
    145177: {"Unified_Ideograph", "Ideographic"},
    145178: {"Unified_Ideograph", "Ideographic"},
    145179: {"Unified_Ideograph", "Ideographic"},
    145180: {"Unified_Ideograph", "Ideographic"},
    145181: {"Unified_Ideograph", "Ideographic"},
    145182: {"Unified_Ideograph", "Ideographic"},
    145183: {"Unified_Ideograph", "Ideographic"},
    145184: {"Unified_Ideograph", "Ideographic"},
    145185: {"Unified_Ideograph", "Ideographic"},
    145186: {"Unified_Ideograph", "Ideographic"},
    145187: {"Unified_Ideograph", "Ideographic"},
    145188: {"Unified_Ideograph", "Ideographic"},
    145189: {"Unified_Ideograph", "Ideographic"},
    145190: {"Unified_Ideograph", "Ideographic"},
    145191: {"Unified_Ideograph", "Ideographic"},
    145192: {"Unified_Ideograph", "Ideographic"},
    145193: {"Unified_Ideograph", "Ideographic"},
    145194: {"Unified_Ideograph", "Ideographic"},
    145195: {"Unified_Ideograph", "Ideographic"},
    145196: {"Unified_Ideograph", "Ideographic"},
    145197: {"Unified_Ideograph", "Ideographic"},
    145198: {"Unified_Ideograph", "Ideographic"},
    145199: {"Unified_Ideograph", "Ideographic"},
    145200: {"Unified_Ideograph", "Ideographic"},
    145201: {"Unified_Ideograph", "Ideographic"},
    145202: {"Unified_Ideograph", "Ideographic"},
    145203: {"Unified_Ideograph", "Ideographic"},
    145204: {"Unified_Ideograph", "Ideographic"},
    145205: {"Unified_Ideograph", "Ideographic"},
    145206: {"Unified_Ideograph", "Ideographic"},
    145207: {"Unified_Ideograph", "Ideographic"},
    145208: {"Unified_Ideograph", "Ideographic"},
    145209: {"Unified_Ideograph", "Ideographic"},
    145210: {"Unified_Ideograph", "Ideographic"},
    145211: {"Unified_Ideograph", "Ideographic"},
    145212: {"Unified_Ideograph", "Ideographic"},
    145213: {"Unified_Ideograph", "Ideographic"},
    145214: {"Unified_Ideograph", "Ideographic"},
    145215: {"Unified_Ideograph", "Ideographic"},
    145216: {"Unified_Ideograph", "Ideographic"},
    145217: {"Unified_Ideograph", "Ideographic"},
    145218: {"Unified_Ideograph", "Ideographic"},
    145219: {"Unified_Ideograph", "Ideographic"},
    145220: {"Unified_Ideograph", "Ideographic"},
    145221: {"Unified_Ideograph", "Ideographic"},
    145222: {"Unified_Ideograph", "Ideographic"},
    145223: {"Unified_Ideograph", "Ideographic"},
    145224: {"Unified_Ideograph", "Ideographic"},
    145225: {"Unified_Ideograph", "Ideographic"},
    145226: {"Unified_Ideograph", "Ideographic"},
    145227: {"Unified_Ideograph", "Ideographic"},
    145228: {"Unified_Ideograph", "Ideographic"},
    145229: {"Unified_Ideograph", "Ideographic"},
    145230: {"Unified_Ideograph", "Ideographic"},
    145231: {"Unified_Ideograph", "Ideographic"},
    145232: {"Unified_Ideograph", "Ideographic"},
    145233: {"Unified_Ideograph", "Ideographic"},
    145234: {"Unified_Ideograph", "Ideographic"},
    145235: {"Unified_Ideograph", "Ideographic"},
    145236: {"Unified_Ideograph", "Ideographic"},
    145237: {"Unified_Ideograph", "Ideographic"},
    145238: {"Unified_Ideograph", "Ideographic"},
    145239: {"Unified_Ideograph", "Ideographic"},
    145240: {"Unified_Ideograph", "Ideographic"},
    145241: {"Unified_Ideograph", "Ideographic"},
    145242: {"Unified_Ideograph", "Ideographic"},
    145243: {"Unified_Ideograph", "Ideographic"},
    145244: {"Unified_Ideograph", "Ideographic"},
    145245: {"Unified_Ideograph", "Ideographic"},
    145246: {"Unified_Ideograph", "Ideographic"},
    145247: {"Unified_Ideograph", "Ideographic"},
    145248: {"Unified_Ideograph", "Ideographic"},
    145249: {"Unified_Ideograph", "Ideographic"},
    145250: {"Unified_Ideograph", "Ideographic"},
    145251: {"Unified_Ideograph", "Ideographic"},
    145252: {"Unified_Ideograph", "Ideographic"},
    145253: {"Unified_Ideograph", "Ideographic"},
    145254: {"Unified_Ideograph", "Ideographic"},
    145255: {"Unified_Ideograph", "Ideographic"},
    145256: {"Unified_Ideograph", "Ideographic"},
    145257: {"Unified_Ideograph", "Ideographic"},
    145258: {"Unified_Ideograph", "Ideographic"},
    145259: {"Unified_Ideograph", "Ideographic"},
    145260: {"Unified_Ideograph", "Ideographic"},
    145261: {"Unified_Ideograph", "Ideographic"},
    145262: {"Unified_Ideograph", "Ideographic"},
    145263: {"Unified_Ideograph", "Ideographic"},
    145264: {"Unified_Ideograph", "Ideographic"},
    145265: {"Unified_Ideograph", "Ideographic"},
    145266: {"Unified_Ideograph", "Ideographic"},
    145267: {"Unified_Ideograph", "Ideographic"},
    145268: {"Unified_Ideograph", "Ideographic"},
    145269: {"Unified_Ideograph", "Ideographic"},
    145270: {"Unified_Ideograph", "Ideographic"},
    145271: {"Unified_Ideograph", "Ideographic"},
    145272: {"Unified_Ideograph", "Ideographic"},
    145273: {"Unified_Ideograph", "Ideographic"},
    145274: {"Unified_Ideograph", "Ideographic"},
    145275: {"Unified_Ideograph", "Ideographic"},
    145276: {"Unified_Ideograph", "Ideographic"},
    145277: {"Unified_Ideograph", "Ideographic"},
    145278: {"Unified_Ideograph", "Ideographic"},
    145279: {"Unified_Ideograph", "Ideographic"},
    145280: {"Unified_Ideograph", "Ideographic"},
    145281: {"Unified_Ideograph", "Ideographic"},
    145282: {"Unified_Ideograph", "Ideographic"},
    145283: {"Unified_Ideograph", "Ideographic"},
    145284: {"Unified_Ideograph", "Ideographic"},
    145285: {"Unified_Ideograph", "Ideographic"},
    145286: {"Unified_Ideograph", "Ideographic"},
    145287: {"Unified_Ideograph", "Ideographic"},
    145288: {"Unified_Ideograph", "Ideographic"},
    145289: {"Unified_Ideograph", "Ideographic"},
    145290: {"Unified_Ideograph", "Ideographic"},
    145291: {"Unified_Ideograph", "Ideographic"},
    145292: {"Unified_Ideograph", "Ideographic"},
    145293: {"Unified_Ideograph", "Ideographic"},
    145294: {"Unified_Ideograph", "Ideographic"},
    145295: {"Unified_Ideograph", "Ideographic"},
    145296: {"Unified_Ideograph", "Ideographic"},
    145297: {"Unified_Ideograph", "Ideographic"},
    145298: {"Unified_Ideograph", "Ideographic"},
    145299: {"Unified_Ideograph", "Ideographic"},
    145300: {"Unified_Ideograph", "Ideographic"},
    145301: {"Unified_Ideograph", "Ideographic"},
    145302: {"Unified_Ideograph", "Ideographic"},
    145303: {"Unified_Ideograph", "Ideographic"},
    145304: {"Unified_Ideograph", "Ideographic"},
    145305: {"Unified_Ideograph", "Ideographic"},
    145306: {"Unified_Ideograph", "Ideographic"},
    145307: {"Unified_Ideograph", "Ideographic"},
    145308: {"Unified_Ideograph", "Ideographic"},
    145309: {"Unified_Ideograph", "Ideographic"},
    145310: {"Unified_Ideograph", "Ideographic"},
    145311: {"Unified_Ideograph", "Ideographic"},
    145312: {"Unified_Ideograph", "Ideographic"},
    145313: {"Unified_Ideograph", "Ideographic"},
    145314: {"Unified_Ideograph", "Ideographic"},
    145315: {"Unified_Ideograph", "Ideographic"},
    145316: {"Unified_Ideograph", "Ideographic"},
    145317: {"Unified_Ideograph", "Ideographic"},
    145318: {"Unified_Ideograph", "Ideographic"},
    145319: {"Unified_Ideograph", "Ideographic"},
    145320: {"Unified_Ideograph", "Ideographic"},
    145321: {"Unified_Ideograph", "Ideographic"},
    145322: {"Unified_Ideograph", "Ideographic"},
    145323: {"Unified_Ideograph", "Ideographic"},
    145324: {"Unified_Ideograph", "Ideographic"},
    145325: {"Unified_Ideograph", "Ideographic"},
    145326: {"Unified_Ideograph", "Ideographic"},
    145327: {"Unified_Ideograph", "Ideographic"},
    145328: {"Unified_Ideograph", "Ideographic"},
    145329: {"Unified_Ideograph", "Ideographic"},
    145330: {"Unified_Ideograph", "Ideographic"},
    145331: {"Unified_Ideograph", "Ideographic"},
    145332: {"Unified_Ideograph", "Ideographic"},
    145333: {"Unified_Ideograph", "Ideographic"},
    145334: {"Unified_Ideograph", "Ideographic"},
    145335: {"Unified_Ideograph", "Ideographic"},
    145336: {"Unified_Ideograph", "Ideographic"},
    145337: {"Unified_Ideograph", "Ideographic"},
    145338: {"Unified_Ideograph", "Ideographic"},
    145339: {"Unified_Ideograph", "Ideographic"},
    145340: {"Unified_Ideograph", "Ideographic"},
    145341: {"Unified_Ideograph", "Ideographic"},
    145342: {"Unified_Ideograph", "Ideographic"},
    145343: {"Unified_Ideograph", "Ideographic"},
    145344: {"Unified_Ideograph", "Ideographic"},
    145345: {"Unified_Ideograph", "Ideographic"},
    145346: {"Unified_Ideograph", "Ideographic"},
    145347: {"Unified_Ideograph", "Ideographic"},
    145348: {"Unified_Ideograph", "Ideographic"},
    145349: {"Unified_Ideograph", "Ideographic"},
    145350: {"Unified_Ideograph", "Ideographic"},
    145351: {"Unified_Ideograph", "Ideographic"},
    145352: {"Unified_Ideograph", "Ideographic"},
    145353: {"Unified_Ideograph", "Ideographic"},
    145354: {"Unified_Ideograph", "Ideographic"},
    145355: {"Unified_Ideograph", "Ideographic"},
    145356: {"Unified_Ideograph", "Ideographic"},
    145357: {"Unified_Ideograph", "Ideographic"},
    145358: {"Unified_Ideograph", "Ideographic"},
    145359: {"Unified_Ideograph", "Ideographic"},
    145360: {"Unified_Ideograph", "Ideographic"},
    145361: {"Unified_Ideograph", "Ideographic"},
    145362: {"Unified_Ideograph", "Ideographic"},
    145363: {"Unified_Ideograph", "Ideographic"},
    145364: {"Unified_Ideograph", "Ideographic"},
    145365: {"Unified_Ideograph", "Ideographic"},
    145366: {"Unified_Ideograph", "Ideographic"},
    145367: {"Unified_Ideograph", "Ideographic"},
    145368: {"Unified_Ideograph", "Ideographic"},
    145369: {"Unified_Ideograph", "Ideographic"},
    145370: {"Unified_Ideograph", "Ideographic"},
    145371: {"Unified_Ideograph", "Ideographic"},
    145372: {"Unified_Ideograph", "Ideographic"},
    145373: {"Unified_Ideograph", "Ideographic"},
    145374: {"Unified_Ideograph", "Ideographic"},
    145375: {"Unified_Ideograph", "Ideographic"},
    145376: {"Unified_Ideograph", "Ideographic"},
    145377: {"Unified_Ideograph", "Ideographic"},
    145378: {"Unified_Ideograph", "Ideographic"},
    145379: {"Unified_Ideograph", "Ideographic"},
    145380: {"Unified_Ideograph", "Ideographic"},
    145381: {"Unified_Ideograph", "Ideographic"},
    145382: {"Unified_Ideograph", "Ideographic"},
    145383: {"Unified_Ideograph", "Ideographic"},
    145384: {"Unified_Ideograph", "Ideographic"},
    145385: {"Unified_Ideograph", "Ideographic"},
    145386: {"Unified_Ideograph", "Ideographic"},
    145387: {"Unified_Ideograph", "Ideographic"},
    145388: {"Unified_Ideograph", "Ideographic"},
    145389: {"Unified_Ideograph", "Ideographic"},
    145390: {"Unified_Ideograph", "Ideographic"},
    145391: {"Unified_Ideograph", "Ideographic"},
    145392: {"Unified_Ideograph", "Ideographic"},
    145393: {"Unified_Ideograph", "Ideographic"},
    145394: {"Unified_Ideograph", "Ideographic"},
    145395: {"Unified_Ideograph", "Ideographic"},
    145396: {"Unified_Ideograph", "Ideographic"},
    145397: {"Unified_Ideograph", "Ideographic"},
    145398: {"Unified_Ideograph", "Ideographic"},
    145399: {"Unified_Ideograph", "Ideographic"},
    145400: {"Unified_Ideograph", "Ideographic"},
    145401: {"Unified_Ideograph", "Ideographic"},
    145402: {"Unified_Ideograph", "Ideographic"},
    145403: {"Unified_Ideograph", "Ideographic"},
    145404: {"Unified_Ideograph", "Ideographic"},
    145405: {"Unified_Ideograph", "Ideographic"},
    145406: {"Unified_Ideograph", "Ideographic"},
    145407: {"Unified_Ideograph", "Ideographic"},
    145408: {"Unified_Ideograph", "Ideographic"},
    145409: {"Unified_Ideograph", "Ideographic"},
    145410: {"Unified_Ideograph", "Ideographic"},
    145411: {"Unified_Ideograph", "Ideographic"},
    145412: {"Unified_Ideograph", "Ideographic"},
    145413: {"Unified_Ideograph", "Ideographic"},
    145414: {"Unified_Ideograph", "Ideographic"},
    145415: {"Unified_Ideograph", "Ideographic"},
    145416: {"Unified_Ideograph", "Ideographic"},
    145417: {"Unified_Ideograph", "Ideographic"},
    145418: {"Unified_Ideograph", "Ideographic"},
    145419: {"Unified_Ideograph", "Ideographic"},
    145420: {"Unified_Ideograph", "Ideographic"},
    145421: {"Unified_Ideograph", "Ideographic"},
    145422: {"Unified_Ideograph", "Ideographic"},
    145423: {"Unified_Ideograph", "Ideographic"},
    145424: {"Unified_Ideograph", "Ideographic"},
    145425: {"Unified_Ideograph", "Ideographic"},
    145426: {"Unified_Ideograph", "Ideographic"},
    145427: {"Unified_Ideograph", "Ideographic"},
    145428: {"Unified_Ideograph", "Ideographic"},
    145429: {"Unified_Ideograph", "Ideographic"},
    145430: {"Unified_Ideograph", "Ideographic"},
    145431: {"Unified_Ideograph", "Ideographic"},
    145432: {"Unified_Ideograph", "Ideographic"},
    145433: {"Unified_Ideograph", "Ideographic"},
    145434: {"Unified_Ideograph", "Ideographic"},
    145435: {"Unified_Ideograph", "Ideographic"},
    145436: {"Unified_Ideograph", "Ideographic"},
    145437: {"Unified_Ideograph", "Ideographic"},
    145438: {"Unified_Ideograph", "Ideographic"},
    145439: {"Unified_Ideograph", "Ideographic"},
    145440: {"Unified_Ideograph", "Ideographic"},
    145441: {"Unified_Ideograph", "Ideographic"},
    145442: {"Unified_Ideograph", "Ideographic"},
    145443: {"Unified_Ideograph", "Ideographic"},
    145444: {"Unified_Ideograph", "Ideographic"},
    145445: {"Unified_Ideograph", "Ideographic"},
    145446: {"Unified_Ideograph", "Ideographic"},
    145447: {"Unified_Ideograph", "Ideographic"},
    145448: {"Unified_Ideograph", "Ideographic"},
    145449: {"Unified_Ideograph", "Ideographic"},
    145450: {"Unified_Ideograph", "Ideographic"},
    145451: {"Unified_Ideograph", "Ideographic"},
    145452: {"Unified_Ideograph", "Ideographic"},
    145453: {"Unified_Ideograph", "Ideographic"},
    145454: {"Unified_Ideograph", "Ideographic"},
    145455: {"Unified_Ideograph", "Ideographic"},
    145456: {"Unified_Ideograph", "Ideographic"},
    145457: {"Unified_Ideograph", "Ideographic"},
    145458: {"Unified_Ideograph", "Ideographic"},
    145459: {"Unified_Ideograph", "Ideographic"},
    145460: {"Unified_Ideograph", "Ideographic"},
    145461: {"Unified_Ideograph", "Ideographic"},
    145462: {"Unified_Ideograph", "Ideographic"},
    145463: {"Unified_Ideograph", "Ideographic"},
    145464: {"Unified_Ideograph", "Ideographic"},
    145465: {"Unified_Ideograph", "Ideographic"},
    145466: {"Unified_Ideograph", "Ideographic"},
    145467: {"Unified_Ideograph", "Ideographic"},
    145468: {"Unified_Ideograph", "Ideographic"},
    145469: {"Unified_Ideograph", "Ideographic"},
    145470: {"Unified_Ideograph", "Ideographic"},
    145471: {"Unified_Ideograph", "Ideographic"},
    145472: {"Unified_Ideograph", "Ideographic"},
    145473: {"Unified_Ideograph", "Ideographic"},
    145474: {"Unified_Ideograph", "Ideographic"},
    145475: {"Unified_Ideograph", "Ideographic"},
    145476: {"Unified_Ideograph", "Ideographic"},
    145477: {"Unified_Ideograph", "Ideographic"},
    145478: {"Unified_Ideograph", "Ideographic"},
    145479: {"Unified_Ideograph", "Ideographic"},
    145480: {"Unified_Ideograph", "Ideographic"},
    145481: {"Unified_Ideograph", "Ideographic"},
    145482: {"Unified_Ideograph", "Ideographic"},
    145483: {"Unified_Ideograph", "Ideographic"},
    145484: {"Unified_Ideograph", "Ideographic"},
    145485: {"Unified_Ideograph", "Ideographic"},
    145486: {"Unified_Ideograph", "Ideographic"},
    145487: {"Unified_Ideograph", "Ideographic"},
    145488: {"Unified_Ideograph", "Ideographic"},
    145489: {"Unified_Ideograph", "Ideographic"},
    145490: {"Unified_Ideograph", "Ideographic"},
    145491: {"Unified_Ideograph", "Ideographic"},
    145492: {"Unified_Ideograph", "Ideographic"},
    145493: {"Unified_Ideograph", "Ideographic"},
    145494: {"Unified_Ideograph", "Ideographic"},
    145495: {"Unified_Ideograph", "Ideographic"},
    145496: {"Unified_Ideograph", "Ideographic"},
    145497: {"Unified_Ideograph", "Ideographic"},
    145498: {"Unified_Ideograph", "Ideographic"},
    145499: {"Unified_Ideograph", "Ideographic"},
    145500: {"Unified_Ideograph", "Ideographic"},
    145501: {"Unified_Ideograph", "Ideographic"},
    145502: {"Unified_Ideograph", "Ideographic"},
    145503: {"Unified_Ideograph", "Ideographic"},
    145504: {"Unified_Ideograph", "Ideographic"},
    145505: {"Unified_Ideograph", "Ideographic"},
    145506: {"Unified_Ideograph", "Ideographic"},
    145507: {"Unified_Ideograph", "Ideographic"},
    145508: {"Unified_Ideograph", "Ideographic"},
    145509: {"Unified_Ideograph", "Ideographic"},
    145510: {"Unified_Ideograph", "Ideographic"},
    145511: {"Unified_Ideograph", "Ideographic"},
    145512: {"Unified_Ideograph", "Ideographic"},
    145513: {"Unified_Ideograph", "Ideographic"},
    145514: {"Unified_Ideograph", "Ideographic"},
    145515: {"Unified_Ideograph", "Ideographic"},
    145516: {"Unified_Ideograph", "Ideographic"},
    145517: {"Unified_Ideograph", "Ideographic"},
    145518: {"Unified_Ideograph", "Ideographic"},
    145519: {"Unified_Ideograph", "Ideographic"},
    145520: {"Unified_Ideograph", "Ideographic"},
    145521: {"Unified_Ideograph", "Ideographic"},
    145522: {"Unified_Ideograph", "Ideographic"},
    145523: {"Unified_Ideograph", "Ideographic"},
    145524: {"Unified_Ideograph", "Ideographic"},
    145525: {"Unified_Ideograph", "Ideographic"},
    145526: {"Unified_Ideograph", "Ideographic"},
    145527: {"Unified_Ideograph", "Ideographic"},
    145528: {"Unified_Ideograph", "Ideographic"},
    145529: {"Unified_Ideograph", "Ideographic"},
    145530: {"Unified_Ideograph", "Ideographic"},
    145531: {"Unified_Ideograph", "Ideographic"},
    145532: {"Unified_Ideograph", "Ideographic"},
    145533: {"Unified_Ideograph", "Ideographic"},
    145534: {"Unified_Ideograph", "Ideographic"},
    145535: {"Unified_Ideograph", "Ideographic"},
    145536: {"Unified_Ideograph", "Ideographic"},
    145537: {"Unified_Ideograph", "Ideographic"},
    145538: {"Unified_Ideograph", "Ideographic"},
    145539: {"Unified_Ideograph", "Ideographic"},
    145540: {"Unified_Ideograph", "Ideographic"},
    145541: {"Unified_Ideograph", "Ideographic"},
    145542: {"Unified_Ideograph", "Ideographic"},
    145543: {"Unified_Ideograph", "Ideographic"},
    145544: {"Unified_Ideograph", "Ideographic"},
    145545: {"Unified_Ideograph", "Ideographic"},
    145546: {"Unified_Ideograph", "Ideographic"},
    145547: {"Unified_Ideograph", "Ideographic"},
    145548: {"Unified_Ideograph", "Ideographic"},
    145549: {"Unified_Ideograph", "Ideographic"},
    145550: {"Unified_Ideograph", "Ideographic"},
    145551: {"Unified_Ideograph", "Ideographic"},
    145552: {"Unified_Ideograph", "Ideographic"},
    145553: {"Unified_Ideograph", "Ideographic"},
    145554: {"Unified_Ideograph", "Ideographic"},
    145555: {"Unified_Ideograph", "Ideographic"},
    145556: {"Unified_Ideograph", "Ideographic"},
    145557: {"Unified_Ideograph", "Ideographic"},
    145558: {"Unified_Ideograph", "Ideographic"},
    145559: {"Unified_Ideograph", "Ideographic"},
    145560: {"Unified_Ideograph", "Ideographic"},
    145561: {"Unified_Ideograph", "Ideographic"},
    145562: {"Unified_Ideograph", "Ideographic"},
    145563: {"Unified_Ideograph", "Ideographic"},
    145564: {"Unified_Ideograph", "Ideographic"},
    145565: {"Unified_Ideograph", "Ideographic"},
    145566: {"Unified_Ideograph", "Ideographic"},
    145567: {"Unified_Ideograph", "Ideographic"},
    145568: {"Unified_Ideograph", "Ideographic"},
    145569: {"Unified_Ideograph", "Ideographic"},
    145570: {"Unified_Ideograph", "Ideographic"},
    145571: {"Unified_Ideograph", "Ideographic"},
    145572: {"Unified_Ideograph", "Ideographic"},
    145573: {"Unified_Ideograph", "Ideographic"},
    145574: {"Unified_Ideograph", "Ideographic"},
    145575: {"Unified_Ideograph", "Ideographic"},
    145576: {"Unified_Ideograph", "Ideographic"},
    145577: {"Unified_Ideograph", "Ideographic"},
    145578: {"Unified_Ideograph", "Ideographic"},
    145579: {"Unified_Ideograph", "Ideographic"},
    145580: {"Unified_Ideograph", "Ideographic"},
    145581: {"Unified_Ideograph", "Ideographic"},
    145582: {"Unified_Ideograph", "Ideographic"},
    145583: {"Unified_Ideograph", "Ideographic"},
    145584: {"Unified_Ideograph", "Ideographic"},
    145585: {"Unified_Ideograph", "Ideographic"},
    145586: {"Unified_Ideograph", "Ideographic"},
    145587: {"Unified_Ideograph", "Ideographic"},
    145588: {"Unified_Ideograph", "Ideographic"},
    145589: {"Unified_Ideograph", "Ideographic"},
    145590: {"Unified_Ideograph", "Ideographic"},
    145591: {"Unified_Ideograph", "Ideographic"},
    145592: {"Unified_Ideograph", "Ideographic"},
    145593: {"Unified_Ideograph", "Ideographic"},
    145594: {"Unified_Ideograph", "Ideographic"},
    145595: {"Unified_Ideograph", "Ideographic"},
    145596: {"Unified_Ideograph", "Ideographic"},
    145597: {"Unified_Ideograph", "Ideographic"},
    145598: {"Unified_Ideograph", "Ideographic"},
    145599: {"Unified_Ideograph", "Ideographic"},
    145600: {"Unified_Ideograph", "Ideographic"},
    145601: {"Unified_Ideograph", "Ideographic"},
    145602: {"Unified_Ideograph", "Ideographic"},
    145603: {"Unified_Ideograph", "Ideographic"},
    145604: {"Unified_Ideograph", "Ideographic"},
    145605: {"Unified_Ideograph", "Ideographic"},
    145606: {"Unified_Ideograph", "Ideographic"},
    145607: {"Unified_Ideograph", "Ideographic"},
    145608: {"Unified_Ideograph", "Ideographic"},
    145609: {"Unified_Ideograph", "Ideographic"},
    145610: {"Unified_Ideograph", "Ideographic"},
    145611: {"Unified_Ideograph", "Ideographic"},
    145612: {"Unified_Ideograph", "Ideographic"},
    145613: {"Unified_Ideograph", "Ideographic"},
    145614: {"Unified_Ideograph", "Ideographic"},
    145615: {"Unified_Ideograph", "Ideographic"},
    145616: {"Unified_Ideograph", "Ideographic"},
    145617: {"Unified_Ideograph", "Ideographic"},
    145618: {"Unified_Ideograph", "Ideographic"},
    145619: {"Unified_Ideograph", "Ideographic"},
    145620: {"Unified_Ideograph", "Ideographic"},
    145621: {"Unified_Ideograph", "Ideographic"},
    145622: {"Unified_Ideograph", "Ideographic"},
    145623: {"Unified_Ideograph", "Ideographic"},
    145624: {"Unified_Ideograph", "Ideographic"},
    145625: {"Unified_Ideograph", "Ideographic"},
    145626: {"Unified_Ideograph", "Ideographic"},
    145627: {"Unified_Ideograph", "Ideographic"},
    145628: {"Unified_Ideograph", "Ideographic"},
    145629: {"Unified_Ideograph", "Ideographic"},
    145630: {"Unified_Ideograph", "Ideographic"},
    145631: {"Unified_Ideograph", "Ideographic"},
    145632: {"Unified_Ideograph", "Ideographic"},
    145633: {"Unified_Ideograph", "Ideographic"},
    145634: {"Unified_Ideograph", "Ideographic"},
    145635: {"Unified_Ideograph", "Ideographic"},
    145636: {"Unified_Ideograph", "Ideographic"},
    145637: {"Unified_Ideograph", "Ideographic"},
    145638: {"Unified_Ideograph", "Ideographic"},
    145639: {"Unified_Ideograph", "Ideographic"},
    145640: {"Unified_Ideograph", "Ideographic"},
    145641: {"Unified_Ideograph", "Ideographic"},
    145642: {"Unified_Ideograph", "Ideographic"},
    145643: {"Unified_Ideograph", "Ideographic"},
    145644: {"Unified_Ideograph", "Ideographic"},
    145645: {"Unified_Ideograph", "Ideographic"},
    145646: {"Unified_Ideograph", "Ideographic"},
    145647: {"Unified_Ideograph", "Ideographic"},
    145648: {"Unified_Ideograph", "Ideographic"},
    145649: {"Unified_Ideograph", "Ideographic"},
    145650: {"Unified_Ideograph", "Ideographic"},
    145651: {"Unified_Ideograph", "Ideographic"},
    145652: {"Unified_Ideograph", "Ideographic"},
    145653: {"Unified_Ideograph", "Ideographic"},
    145654: {"Unified_Ideograph", "Ideographic"},
    145655: {"Unified_Ideograph", "Ideographic"},
    145656: {"Unified_Ideograph", "Ideographic"},
    145657: {"Unified_Ideograph", "Ideographic"},
    145658: {"Unified_Ideograph", "Ideographic"},
    145659: {"Unified_Ideograph", "Ideographic"},
    145660: {"Unified_Ideograph", "Ideographic"},
    145661: {"Unified_Ideograph", "Ideographic"},
    145662: {"Unified_Ideograph", "Ideographic"},
    145663: {"Unified_Ideograph", "Ideographic"},
    145664: {"Unified_Ideograph", "Ideographic"},
    145665: {"Unified_Ideograph", "Ideographic"},
    145666: {"Unified_Ideograph", "Ideographic"},
    145667: {"Unified_Ideograph", "Ideographic"},
    145668: {"Unified_Ideograph", "Ideographic"},
    145669: {"Unified_Ideograph", "Ideographic"},
    145670: {"Unified_Ideograph", "Ideographic"},
    145671: {"Unified_Ideograph", "Ideographic"},
    145672: {"Unified_Ideograph", "Ideographic"},
    145673: {"Unified_Ideograph", "Ideographic"},
    145674: {"Unified_Ideograph", "Ideographic"},
    145675: {"Unified_Ideograph", "Ideographic"},
    145676: {"Unified_Ideograph", "Ideographic"},
    145677: {"Unified_Ideograph", "Ideographic"},
    145678: {"Unified_Ideograph", "Ideographic"},
    145679: {"Unified_Ideograph", "Ideographic"},
    145680: {"Unified_Ideograph", "Ideographic"},
    145681: {"Unified_Ideograph", "Ideographic"},
    145682: {"Unified_Ideograph", "Ideographic"},
    145683: {"Unified_Ideograph", "Ideographic"},
    145684: {"Unified_Ideograph", "Ideographic"},
    145685: {"Unified_Ideograph", "Ideographic"},
    145686: {"Unified_Ideograph", "Ideographic"},
    145687: {"Unified_Ideograph", "Ideographic"},
    145688: {"Unified_Ideograph", "Ideographic"},
    145689: {"Unified_Ideograph", "Ideographic"},
    145690: {"Unified_Ideograph", "Ideographic"},
    145691: {"Unified_Ideograph", "Ideographic"},
    145692: {"Unified_Ideograph", "Ideographic"},
    145693: {"Unified_Ideograph", "Ideographic"},
    145694: {"Unified_Ideograph", "Ideographic"},
    145695: {"Unified_Ideograph", "Ideographic"},
    145696: {"Unified_Ideograph", "Ideographic"},
    145697: {"Unified_Ideograph", "Ideographic"},
    145698: {"Unified_Ideograph", "Ideographic"},
    145699: {"Unified_Ideograph", "Ideographic"},
    145700: {"Unified_Ideograph", "Ideographic"},
    145701: {"Unified_Ideograph", "Ideographic"},
    145702: {"Unified_Ideograph", "Ideographic"},
    145703: {"Unified_Ideograph", "Ideographic"},
    145704: {"Unified_Ideograph", "Ideographic"},
    145705: {"Unified_Ideograph", "Ideographic"},
    145706: {"Unified_Ideograph", "Ideographic"},
    145707: {"Unified_Ideograph", "Ideographic"},
    145708: {"Unified_Ideograph", "Ideographic"},
    145709: {"Unified_Ideograph", "Ideographic"},
    145710: {"Unified_Ideograph", "Ideographic"},
    145711: {"Unified_Ideograph", "Ideographic"},
    145712: {"Unified_Ideograph", "Ideographic"},
    145713: {"Unified_Ideograph", "Ideographic"},
    145714: {"Unified_Ideograph", "Ideographic"},
    145715: {"Unified_Ideograph", "Ideographic"},
    145716: {"Unified_Ideograph", "Ideographic"},
    145717: {"Unified_Ideograph", "Ideographic"},
    145718: {"Unified_Ideograph", "Ideographic"},
    145719: {"Unified_Ideograph", "Ideographic"},
    145720: {"Unified_Ideograph", "Ideographic"},
    145721: {"Unified_Ideograph", "Ideographic"},
    145722: {"Unified_Ideograph", "Ideographic"},
    145723: {"Unified_Ideograph", "Ideographic"},
    145724: {"Unified_Ideograph", "Ideographic"},
    145725: {"Unified_Ideograph", "Ideographic"},
    145726: {"Unified_Ideograph", "Ideographic"},
    145727: {"Unified_Ideograph", "Ideographic"},
    145728: {"Unified_Ideograph", "Ideographic"},
    145729: {"Unified_Ideograph", "Ideographic"},
    145730: {"Unified_Ideograph", "Ideographic"},
    145731: {"Unified_Ideograph", "Ideographic"},
    145732: {"Unified_Ideograph", "Ideographic"},
    145733: {"Unified_Ideograph", "Ideographic"},
    145734: {"Unified_Ideograph", "Ideographic"},
    145735: {"Unified_Ideograph", "Ideographic"},
    145736: {"Unified_Ideograph", "Ideographic"},
    145737: {"Unified_Ideograph", "Ideographic"},
    145738: {"Unified_Ideograph", "Ideographic"},
    145739: {"Unified_Ideograph", "Ideographic"},
    145740: {"Unified_Ideograph", "Ideographic"},
    145741: {"Unified_Ideograph", "Ideographic"},
    145742: {"Unified_Ideograph", "Ideographic"},
    145743: {"Unified_Ideograph", "Ideographic"},
    145744: {"Unified_Ideograph", "Ideographic"},
    145745: {"Unified_Ideograph", "Ideographic"},
    145746: {"Unified_Ideograph", "Ideographic"},
    145747: {"Unified_Ideograph", "Ideographic"},
    145748: {"Unified_Ideograph", "Ideographic"},
    145749: {"Unified_Ideograph", "Ideographic"},
    145750: {"Unified_Ideograph", "Ideographic"},
    145751: {"Unified_Ideograph", "Ideographic"},
    145752: {"Unified_Ideograph", "Ideographic"},
    145753: {"Unified_Ideograph", "Ideographic"},
    145754: {"Unified_Ideograph", "Ideographic"},
    145755: {"Unified_Ideograph", "Ideographic"},
    145756: {"Unified_Ideograph", "Ideographic"},
    145757: {"Unified_Ideograph", "Ideographic"},
    145758: {"Unified_Ideograph", "Ideographic"},
    145759: {"Unified_Ideograph", "Ideographic"},
    145760: {"Unified_Ideograph", "Ideographic"},
    145761: {"Unified_Ideograph", "Ideographic"},
    145762: {"Unified_Ideograph", "Ideographic"},
    145763: {"Unified_Ideograph", "Ideographic"},
    145764: {"Unified_Ideograph", "Ideographic"},
    145765: {"Unified_Ideograph", "Ideographic"},
    145766: {"Unified_Ideograph", "Ideographic"},
    145767: {"Unified_Ideograph", "Ideographic"},
    145768: {"Unified_Ideograph", "Ideographic"},
    145769: {"Unified_Ideograph", "Ideographic"},
    145770: {"Unified_Ideograph", "Ideographic"},
    145771: {"Unified_Ideograph", "Ideographic"},
    145772: {"Unified_Ideograph", "Ideographic"},
    145773: {"Unified_Ideograph", "Ideographic"},
    145774: {"Unified_Ideograph", "Ideographic"},
    145775: {"Unified_Ideograph", "Ideographic"},
    145776: {"Unified_Ideograph", "Ideographic"},
    145777: {"Unified_Ideograph", "Ideographic"},
    145778: {"Unified_Ideograph", "Ideographic"},
    145779: {"Unified_Ideograph", "Ideographic"},
    145780: {"Unified_Ideograph", "Ideographic"},
    145781: {"Unified_Ideograph", "Ideographic"},
    145782: {"Unified_Ideograph", "Ideographic"},
    145783: {"Unified_Ideograph", "Ideographic"},
    145784: {"Unified_Ideograph", "Ideographic"},
    145785: {"Unified_Ideograph", "Ideographic"},
    145786: {"Unified_Ideograph", "Ideographic"},
    145787: {"Unified_Ideograph", "Ideographic"},
    145788: {"Unified_Ideograph", "Ideographic"},
    145789: {"Unified_Ideograph", "Ideographic"},
    145790: {"Unified_Ideograph", "Ideographic"},
    145791: {"Unified_Ideograph", "Ideographic"},
    145792: {"Unified_Ideograph", "Ideographic"},
    145793: {"Unified_Ideograph", "Ideographic"},
    145794: {"Unified_Ideograph", "Ideographic"},
    145795: {"Unified_Ideograph", "Ideographic"},
    145796: {"Unified_Ideograph", "Ideographic"},
    145797: {"Unified_Ideograph", "Ideographic"},
    145798: {"Unified_Ideograph", "Ideographic"},
    145799: {"Unified_Ideograph", "Ideographic"},
    145800: {"Unified_Ideograph", "Ideographic"},
    145801: {"Unified_Ideograph", "Ideographic"},
    145802: {"Unified_Ideograph", "Ideographic"},
    145803: {"Unified_Ideograph", "Ideographic"},
    145804: {"Unified_Ideograph", "Ideographic"},
    145805: {"Unified_Ideograph", "Ideographic"},
    145806: {"Unified_Ideograph", "Ideographic"},
    145807: {"Unified_Ideograph", "Ideographic"},
    145808: {"Unified_Ideograph", "Ideographic"},
    145809: {"Unified_Ideograph", "Ideographic"},
    145810: {"Unified_Ideograph", "Ideographic"},
    145811: {"Unified_Ideograph", "Ideographic"},
    145812: {"Unified_Ideograph", "Ideographic"},
    145813: {"Unified_Ideograph", "Ideographic"},
    145814: {"Unified_Ideograph", "Ideographic"},
    145815: {"Unified_Ideograph", "Ideographic"},
    145816: {"Unified_Ideograph", "Ideographic"},
    145817: {"Unified_Ideograph", "Ideographic"},
    145818: {"Unified_Ideograph", "Ideographic"},
    145819: {"Unified_Ideograph", "Ideographic"},
    145820: {"Unified_Ideograph", "Ideographic"},
    145821: {"Unified_Ideograph", "Ideographic"},
    145822: {"Unified_Ideograph", "Ideographic"},
    145823: {"Unified_Ideograph", "Ideographic"},
    145824: {"Unified_Ideograph", "Ideographic"},
    145825: {"Unified_Ideograph", "Ideographic"},
    145826: {"Unified_Ideograph", "Ideographic"},
    145827: {"Unified_Ideograph", "Ideographic"},
    145828: {"Unified_Ideograph", "Ideographic"},
    145829: {"Unified_Ideograph", "Ideographic"},
    145830: {"Unified_Ideograph", "Ideographic"},
    145831: {"Unified_Ideograph", "Ideographic"},
    145832: {"Unified_Ideograph", "Ideographic"},
    145833: {"Unified_Ideograph", "Ideographic"},
    145834: {"Unified_Ideograph", "Ideographic"},
    145835: {"Unified_Ideograph", "Ideographic"},
    145836: {"Unified_Ideograph", "Ideographic"},
    145837: {"Unified_Ideograph", "Ideographic"},
    145838: {"Unified_Ideograph", "Ideographic"},
    145839: {"Unified_Ideograph", "Ideographic"},
    145840: {"Unified_Ideograph", "Ideographic"},
    145841: {"Unified_Ideograph", "Ideographic"},
    145842: {"Unified_Ideograph", "Ideographic"},
    145843: {"Unified_Ideograph", "Ideographic"},
    145844: {"Unified_Ideograph", "Ideographic"},
    145845: {"Unified_Ideograph", "Ideographic"},
    145846: {"Unified_Ideograph", "Ideographic"},
    145847: {"Unified_Ideograph", "Ideographic"},
    145848: {"Unified_Ideograph", "Ideographic"},
    145849: {"Unified_Ideograph", "Ideographic"},
    145850: {"Unified_Ideograph", "Ideographic"},
    145851: {"Unified_Ideograph", "Ideographic"},
    145852: {"Unified_Ideograph", "Ideographic"},
    145853: {"Unified_Ideograph", "Ideographic"},
    145854: {"Unified_Ideograph", "Ideographic"},
    145855: {"Unified_Ideograph", "Ideographic"},
    145856: {"Unified_Ideograph", "Ideographic"},
    145857: {"Unified_Ideograph", "Ideographic"},
    145858: {"Unified_Ideograph", "Ideographic"},
    145859: {"Unified_Ideograph", "Ideographic"},
    145860: {"Unified_Ideograph", "Ideographic"},
    145861: {"Unified_Ideograph", "Ideographic"},
    145862: {"Unified_Ideograph", "Ideographic"},
    145863: {"Unified_Ideograph", "Ideographic"},
    145864: {"Unified_Ideograph", "Ideographic"},
    145865: {"Unified_Ideograph", "Ideographic"},
    145866: {"Unified_Ideograph", "Ideographic"},
    145867: {"Unified_Ideograph", "Ideographic"},
    145868: {"Unified_Ideograph", "Ideographic"},
    145869: {"Unified_Ideograph", "Ideographic"},
    145870: {"Unified_Ideograph", "Ideographic"},
    145871: {"Unified_Ideograph", "Ideographic"},
    145872: {"Unified_Ideograph", "Ideographic"},
    145873: {"Unified_Ideograph", "Ideographic"},
    145874: {"Unified_Ideograph", "Ideographic"},
    145875: {"Unified_Ideograph", "Ideographic"},
    145876: {"Unified_Ideograph", "Ideographic"},
    145877: {"Unified_Ideograph", "Ideographic"},
    145878: {"Unified_Ideograph", "Ideographic"},
    145879: {"Unified_Ideograph", "Ideographic"},
    145880: {"Unified_Ideograph", "Ideographic"},
    145881: {"Unified_Ideograph", "Ideographic"},
    145882: {"Unified_Ideograph", "Ideographic"},
    145883: {"Unified_Ideograph", "Ideographic"},
    145884: {"Unified_Ideograph", "Ideographic"},
    145885: {"Unified_Ideograph", "Ideographic"},
    145886: {"Unified_Ideograph", "Ideographic"},
    145887: {"Unified_Ideograph", "Ideographic"},
    145888: {"Unified_Ideograph", "Ideographic"},
    145889: {"Unified_Ideograph", "Ideographic"},
    145890: {"Unified_Ideograph", "Ideographic"},
    145891: {"Unified_Ideograph", "Ideographic"},
    145892: {"Unified_Ideograph", "Ideographic"},
    145893: {"Unified_Ideograph", "Ideographic"},
    145894: {"Unified_Ideograph", "Ideographic"},
    145895: {"Unified_Ideograph", "Ideographic"},
    145896: {"Unified_Ideograph", "Ideographic"},
    145897: {"Unified_Ideograph", "Ideographic"},
    145898: {"Unified_Ideograph", "Ideographic"},
    145899: {"Unified_Ideograph", "Ideographic"},
    145900: {"Unified_Ideograph", "Ideographic"},
    145901: {"Unified_Ideograph", "Ideographic"},
    145902: {"Unified_Ideograph", "Ideographic"},
    145903: {"Unified_Ideograph", "Ideographic"},
    145904: {"Unified_Ideograph", "Ideographic"},
    145905: {"Unified_Ideograph", "Ideographic"},
    145906: {"Unified_Ideograph", "Ideographic"},
    145907: {"Unified_Ideograph", "Ideographic"},
    145908: {"Unified_Ideograph", "Ideographic"},
    145909: {"Unified_Ideograph", "Ideographic"},
    145910: {"Unified_Ideograph", "Ideographic"},
    145911: {"Unified_Ideograph", "Ideographic"},
    145912: {"Unified_Ideograph", "Ideographic"},
    145913: {"Unified_Ideograph", "Ideographic"},
    145914: {"Unified_Ideograph", "Ideographic"},
    145915: {"Unified_Ideograph", "Ideographic"},
    145916: {"Unified_Ideograph", "Ideographic"},
    145917: {"Unified_Ideograph", "Ideographic"},
    145918: {"Unified_Ideograph", "Ideographic"},
    145919: {"Unified_Ideograph", "Ideographic"},
    145920: {"Unified_Ideograph", "Ideographic"},
    145921: {"Unified_Ideograph", "Ideographic"},
    145922: {"Unified_Ideograph", "Ideographic"},
    145923: {"Unified_Ideograph", "Ideographic"},
    145924: {"Unified_Ideograph", "Ideographic"},
    145925: {"Unified_Ideograph", "Ideographic"},
    145926: {"Unified_Ideograph", "Ideographic"},
    145927: {"Unified_Ideograph", "Ideographic"},
    145928: {"Unified_Ideograph", "Ideographic"},
    145929: {"Unified_Ideograph", "Ideographic"},
    145930: {"Unified_Ideograph", "Ideographic"},
    145931: {"Unified_Ideograph", "Ideographic"},
    145932: {"Unified_Ideograph", "Ideographic"},
    145933: {"Unified_Ideograph", "Ideographic"},
    145934: {"Unified_Ideograph", "Ideographic"},
    145935: {"Unified_Ideograph", "Ideographic"},
    145936: {"Unified_Ideograph", "Ideographic"},
    145937: {"Unified_Ideograph", "Ideographic"},
    145938: {"Unified_Ideograph", "Ideographic"},
    145939: {"Unified_Ideograph", "Ideographic"},
    145940: {"Unified_Ideograph", "Ideographic"},
    145941: {"Unified_Ideograph", "Ideographic"},
    145942: {"Unified_Ideograph", "Ideographic"},
    145943: {"Unified_Ideograph", "Ideographic"},
    145944: {"Unified_Ideograph", "Ideographic"},
    145945: {"Unified_Ideograph", "Ideographic"},
    145946: {"Unified_Ideograph", "Ideographic"},
    145947: {"Unified_Ideograph", "Ideographic"},
    145948: {"Unified_Ideograph", "Ideographic"},
    145949: {"Unified_Ideograph", "Ideographic"},
    145950: {"Unified_Ideograph", "Ideographic"},
    145951: {"Unified_Ideograph", "Ideographic"},
    145952: {"Unified_Ideograph", "Ideographic"},
    145953: {"Unified_Ideograph", "Ideographic"},
    145954: {"Unified_Ideograph", "Ideographic"},
    145955: {"Unified_Ideograph", "Ideographic"},
    145956: {"Unified_Ideograph", "Ideographic"},
    145957: {"Unified_Ideograph", "Ideographic"},
    145958: {"Unified_Ideograph", "Ideographic"},
    145959: {"Unified_Ideograph", "Ideographic"},
    145960: {"Unified_Ideograph", "Ideographic"},
    145961: {"Unified_Ideograph", "Ideographic"},
    145962: {"Unified_Ideograph", "Ideographic"},
    145963: {"Unified_Ideograph", "Ideographic"},
    145964: {"Unified_Ideograph", "Ideographic"},
    145965: {"Unified_Ideograph", "Ideographic"},
    145966: {"Unified_Ideograph", "Ideographic"},
    145967: {"Unified_Ideograph", "Ideographic"},
    145968: {"Unified_Ideograph", "Ideographic"},
    145969: {"Unified_Ideograph", "Ideographic"},
    145970: {"Unified_Ideograph", "Ideographic"},
    145971: {"Unified_Ideograph", "Ideographic"},
    145972: {"Unified_Ideograph", "Ideographic"},
    145973: {"Unified_Ideograph", "Ideographic"},
    145974: {"Unified_Ideograph", "Ideographic"},
    145975: {"Unified_Ideograph", "Ideographic"},
    145976: {"Unified_Ideograph", "Ideographic"},
    145977: {"Unified_Ideograph", "Ideographic"},
    145978: {"Unified_Ideograph", "Ideographic"},
    145979: {"Unified_Ideograph", "Ideographic"},
    145980: {"Unified_Ideograph", "Ideographic"},
    145981: {"Unified_Ideograph", "Ideographic"},
    145982: {"Unified_Ideograph", "Ideographic"},
    145983: {"Unified_Ideograph", "Ideographic"},
    145984: {"Unified_Ideograph", "Ideographic"},
    145985: {"Unified_Ideograph", "Ideographic"},
    145986: {"Unified_Ideograph", "Ideographic"},
    145987: {"Unified_Ideograph", "Ideographic"},
    145988: {"Unified_Ideograph", "Ideographic"},
    145989: {"Unified_Ideograph", "Ideographic"},
    145990: {"Unified_Ideograph", "Ideographic"},
    145991: {"Unified_Ideograph", "Ideographic"},
    145992: {"Unified_Ideograph", "Ideographic"},
    145993: {"Unified_Ideograph", "Ideographic"},
    145994: {"Unified_Ideograph", "Ideographic"},
    145995: {"Unified_Ideograph", "Ideographic"},
    145996: {"Unified_Ideograph", "Ideographic"},
    145997: {"Unified_Ideograph", "Ideographic"},
    145998: {"Unified_Ideograph", "Ideographic"},
    145999: {"Unified_Ideograph", "Ideographic"},
    146000: {"Unified_Ideograph", "Ideographic"},
    146001: {"Unified_Ideograph", "Ideographic"},
    146002: {"Unified_Ideograph", "Ideographic"},
    146003: {"Unified_Ideograph", "Ideographic"},
    146004: {"Unified_Ideograph", "Ideographic"},
    146005: {"Unified_Ideograph", "Ideographic"},
    146006: {"Unified_Ideograph", "Ideographic"},
    146007: {"Unified_Ideograph", "Ideographic"},
    146008: {"Unified_Ideograph", "Ideographic"},
    146009: {"Unified_Ideograph", "Ideographic"},
    146010: {"Unified_Ideograph", "Ideographic"},
    146011: {"Unified_Ideograph", "Ideographic"},
    146012: {"Unified_Ideograph", "Ideographic"},
    146013: {"Unified_Ideograph", "Ideographic"},
    146014: {"Unified_Ideograph", "Ideographic"},
    146015: {"Unified_Ideograph", "Ideographic"},
    146016: {"Unified_Ideograph", "Ideographic"},
    146017: {"Unified_Ideograph", "Ideographic"},
    146018: {"Unified_Ideograph", "Ideographic"},
    146019: {"Unified_Ideograph", "Ideographic"},
    146020: {"Unified_Ideograph", "Ideographic"},
    146021: {"Unified_Ideograph", "Ideographic"},
    146022: {"Unified_Ideograph", "Ideographic"},
    146023: {"Unified_Ideograph", "Ideographic"},
    146024: {"Unified_Ideograph", "Ideographic"},
    146025: {"Unified_Ideograph", "Ideographic"},
    146026: {"Unified_Ideograph", "Ideographic"},
    146027: {"Unified_Ideograph", "Ideographic"},
    146028: {"Unified_Ideograph", "Ideographic"},
    146029: {"Unified_Ideograph", "Ideographic"},
    146030: {"Unified_Ideograph", "Ideographic"},
    146031: {"Unified_Ideograph", "Ideographic"},
    146032: {"Unified_Ideograph", "Ideographic"},
    146033: {"Unified_Ideograph", "Ideographic"},
    146034: {"Unified_Ideograph", "Ideographic"},
    146035: {"Unified_Ideograph", "Ideographic"},
    146036: {"Unified_Ideograph", "Ideographic"},
    146037: {"Unified_Ideograph", "Ideographic"},
    146038: {"Unified_Ideograph", "Ideographic"},
    146039: {"Unified_Ideograph", "Ideographic"},
    146040: {"Unified_Ideograph", "Ideographic"},
    146041: {"Unified_Ideograph", "Ideographic"},
    146042: {"Unified_Ideograph", "Ideographic"},
    146043: {"Unified_Ideograph", "Ideographic"},
    146044: {"Unified_Ideograph", "Ideographic"},
    146045: {"Unified_Ideograph", "Ideographic"},
    146046: {"Unified_Ideograph", "Ideographic"},
    146047: {"Unified_Ideograph", "Ideographic"},
    146048: {"Unified_Ideograph", "Ideographic"},
    146049: {"Unified_Ideograph", "Ideographic"},
    146050: {"Unified_Ideograph", "Ideographic"},
    146051: {"Unified_Ideograph", "Ideographic"},
    146052: {"Unified_Ideograph", "Ideographic"},
    146053: {"Unified_Ideograph", "Ideographic"},
    146054: {"Unified_Ideograph", "Ideographic"},
    146055: {"Unified_Ideograph", "Ideographic"},
    146056: {"Unified_Ideograph", "Ideographic"},
    146057: {"Unified_Ideograph", "Ideographic"},
    146058: {"Unified_Ideograph", "Ideographic"},
    146059: {"Unified_Ideograph", "Ideographic"},
    146060: {"Unified_Ideograph", "Ideographic"},
    146061: {"Unified_Ideograph", "Ideographic"},
    146062: {"Unified_Ideograph", "Ideographic"},
    146063: {"Unified_Ideograph", "Ideographic"},
    146064: {"Unified_Ideograph", "Ideographic"},
    146065: {"Unified_Ideograph", "Ideographic"},
    146066: {"Unified_Ideograph", "Ideographic"},
    146067: {"Unified_Ideograph", "Ideographic"},
    146068: {"Unified_Ideograph", "Ideographic"},
    146069: {"Unified_Ideograph", "Ideographic"},
    146070: {"Unified_Ideograph", "Ideographic"},
    146071: {"Unified_Ideograph", "Ideographic"},
    146072: {"Unified_Ideograph", "Ideographic"},
    146073: {"Unified_Ideograph", "Ideographic"},
    146074: {"Unified_Ideograph", "Ideographic"},
    146075: {"Unified_Ideograph", "Ideographic"},
    146076: {"Unified_Ideograph", "Ideographic"},
    146077: {"Unified_Ideograph", "Ideographic"},
    146078: {"Unified_Ideograph", "Ideographic"},
    146079: {"Unified_Ideograph", "Ideographic"},
    146080: {"Unified_Ideograph", "Ideographic"},
    146081: {"Unified_Ideograph", "Ideographic"},
    146082: {"Unified_Ideograph", "Ideographic"},
    146083: {"Unified_Ideograph", "Ideographic"},
    146084: {"Unified_Ideograph", "Ideographic"},
    146085: {"Unified_Ideograph", "Ideographic"},
    146086: {"Unified_Ideograph", "Ideographic"},
    146087: {"Unified_Ideograph", "Ideographic"},
    146088: {"Unified_Ideograph", "Ideographic"},
    146089: {"Unified_Ideograph", "Ideographic"},
    146090: {"Unified_Ideograph", "Ideographic"},
    146091: {"Unified_Ideograph", "Ideographic"},
    146092: {"Unified_Ideograph", "Ideographic"},
    146093: {"Unified_Ideograph", "Ideographic"},
    146094: {"Unified_Ideograph", "Ideographic"},
    146095: {"Unified_Ideograph", "Ideographic"},
    146096: {"Unified_Ideograph", "Ideographic"},
    146097: {"Unified_Ideograph", "Ideographic"},
    146098: {"Unified_Ideograph", "Ideographic"},
    146099: {"Unified_Ideograph", "Ideographic"},
    146100: {"Unified_Ideograph", "Ideographic"},
    146101: {"Unified_Ideograph", "Ideographic"},
    146102: {"Unified_Ideograph", "Ideographic"},
    146103: {"Unified_Ideograph", "Ideographic"},
    146104: {"Unified_Ideograph", "Ideographic"},
    146105: {"Unified_Ideograph", "Ideographic"},
    146106: {"Unified_Ideograph", "Ideographic"},
    146107: {"Unified_Ideograph", "Ideographic"},
    146108: {"Unified_Ideograph", "Ideographic"},
    146109: {"Unified_Ideograph", "Ideographic"},
    146110: {"Unified_Ideograph", "Ideographic"},
    146111: {"Unified_Ideograph", "Ideographic"},
    146112: {"Unified_Ideograph", "Ideographic"},
    146113: {"Unified_Ideograph", "Ideographic"},
    146114: {"Unified_Ideograph", "Ideographic"},
    146115: {"Unified_Ideograph", "Ideographic"},
    146116: {"Unified_Ideograph", "Ideographic"},
    146117: {"Unified_Ideograph", "Ideographic"},
    146118: {"Unified_Ideograph", "Ideographic"},
    146119: {"Unified_Ideograph", "Ideographic"},
    146120: {"Unified_Ideograph", "Ideographic"},
    146121: {"Unified_Ideograph", "Ideographic"},
    146122: {"Unified_Ideograph", "Ideographic"},
    146123: {"Unified_Ideograph", "Ideographic"},
    146124: {"Unified_Ideograph", "Ideographic"},
    146125: {"Unified_Ideograph", "Ideographic"},
    146126: {"Unified_Ideograph", "Ideographic"},
    146127: {"Unified_Ideograph", "Ideographic"},
    146128: {"Unified_Ideograph", "Ideographic"},
    146129: {"Unified_Ideograph", "Ideographic"},
    146130: {"Unified_Ideograph", "Ideographic"},
    146131: {"Unified_Ideograph", "Ideographic"},
    146132: {"Unified_Ideograph", "Ideographic"},
    146133: {"Unified_Ideograph", "Ideographic"},
    146134: {"Unified_Ideograph", "Ideographic"},
    146135: {"Unified_Ideograph", "Ideographic"},
    146136: {"Unified_Ideograph", "Ideographic"},
    146137: {"Unified_Ideograph", "Ideographic"},
    146138: {"Unified_Ideograph", "Ideographic"},
    146139: {"Unified_Ideograph", "Ideographic"},
    146140: {"Unified_Ideograph", "Ideographic"},
    146141: {"Unified_Ideograph", "Ideographic"},
    146142: {"Unified_Ideograph", "Ideographic"},
    146143: {"Unified_Ideograph", "Ideographic"},
    146144: {"Unified_Ideograph", "Ideographic"},
    146145: {"Unified_Ideograph", "Ideographic"},
    146146: {"Unified_Ideograph", "Ideographic"},
    146147: {"Unified_Ideograph", "Ideographic"},
    146148: {"Unified_Ideograph", "Ideographic"},
    146149: {"Unified_Ideograph", "Ideographic"},
    146150: {"Unified_Ideograph", "Ideographic"},
    146151: {"Unified_Ideograph", "Ideographic"},
    146152: {"Unified_Ideograph", "Ideographic"},
    146153: {"Unified_Ideograph", "Ideographic"},
    146154: {"Unified_Ideograph", "Ideographic"},
    146155: {"Unified_Ideograph", "Ideographic"},
    146156: {"Unified_Ideograph", "Ideographic"},
    146157: {"Unified_Ideograph", "Ideographic"},
    146158: {"Unified_Ideograph", "Ideographic"},
    146159: {"Unified_Ideograph", "Ideographic"},
    146160: {"Unified_Ideograph", "Ideographic"},
    146161: {"Unified_Ideograph", "Ideographic"},
    146162: {"Unified_Ideograph", "Ideographic"},
    146163: {"Unified_Ideograph", "Ideographic"},
    146164: {"Unified_Ideograph", "Ideographic"},
    146165: {"Unified_Ideograph", "Ideographic"},
    146166: {"Unified_Ideograph", "Ideographic"},
    146167: {"Unified_Ideograph", "Ideographic"},
    146168: {"Unified_Ideograph", "Ideographic"},
    146169: {"Unified_Ideograph", "Ideographic"},
    146170: {"Unified_Ideograph", "Ideographic"},
    146171: {"Unified_Ideograph", "Ideographic"},
    146172: {"Unified_Ideograph", "Ideographic"},
    146173: {"Unified_Ideograph", "Ideographic"},
    146174: {"Unified_Ideograph", "Ideographic"},
    146175: {"Unified_Ideograph", "Ideographic"},
    146176: {"Unified_Ideograph", "Ideographic"},
    146177: {"Unified_Ideograph", "Ideographic"},
    146178: {"Unified_Ideograph", "Ideographic"},
    146179: {"Unified_Ideograph", "Ideographic"},
    146180: {"Unified_Ideograph", "Ideographic"},
    146181: {"Unified_Ideograph", "Ideographic"},
    146182: {"Unified_Ideograph", "Ideographic"},
    146183: {"Unified_Ideograph", "Ideographic"},
    146184: {"Unified_Ideograph", "Ideographic"},
    146185: {"Unified_Ideograph", "Ideographic"},
    146186: {"Unified_Ideograph", "Ideographic"},
    146187: {"Unified_Ideograph", "Ideographic"},
    146188: {"Unified_Ideograph", "Ideographic"},
    146189: {"Unified_Ideograph", "Ideographic"},
    146190: {"Unified_Ideograph", "Ideographic"},
    146191: {"Unified_Ideograph", "Ideographic"},
    146192: {"Unified_Ideograph", "Ideographic"},
    146193: {"Unified_Ideograph", "Ideographic"},
    146194: {"Unified_Ideograph", "Ideographic"},
    146195: {"Unified_Ideograph", "Ideographic"},
    146196: {"Unified_Ideograph", "Ideographic"},
    146197: {"Unified_Ideograph", "Ideographic"},
    146198: {"Unified_Ideograph", "Ideographic"},
    146199: {"Unified_Ideograph", "Ideographic"},
    146200: {"Unified_Ideograph", "Ideographic"},
    146201: {"Unified_Ideograph", "Ideographic"},
    146202: {"Unified_Ideograph", "Ideographic"},
    146203: {"Unified_Ideograph", "Ideographic"},
    146204: {"Unified_Ideograph", "Ideographic"},
    146205: {"Unified_Ideograph", "Ideographic"},
    146206: {"Unified_Ideograph", "Ideographic"},
    146207: {"Unified_Ideograph", "Ideographic"},
    146208: {"Unified_Ideograph", "Ideographic"},
    146209: {"Unified_Ideograph", "Ideographic"},
    146210: {"Unified_Ideograph", "Ideographic"},
    146211: {"Unified_Ideograph", "Ideographic"},
    146212: {"Unified_Ideograph", "Ideographic"},
    146213: {"Unified_Ideograph", "Ideographic"},
    146214: {"Unified_Ideograph", "Ideographic"},
    146215: {"Unified_Ideograph", "Ideographic"},
    146216: {"Unified_Ideograph", "Ideographic"},
    146217: {"Unified_Ideograph", "Ideographic"},
    146218: {"Unified_Ideograph", "Ideographic"},
    146219: {"Unified_Ideograph", "Ideographic"},
    146220: {"Unified_Ideograph", "Ideographic"},
    146221: {"Unified_Ideograph", "Ideographic"},
    146222: {"Unified_Ideograph", "Ideographic"},
    146223: {"Unified_Ideograph", "Ideographic"},
    146224: {"Unified_Ideograph", "Ideographic"},
    146225: {"Unified_Ideograph", "Ideographic"},
    146226: {"Unified_Ideograph", "Ideographic"},
    146227: {"Unified_Ideograph", "Ideographic"},
    146228: {"Unified_Ideograph", "Ideographic"},
    146229: {"Unified_Ideograph", "Ideographic"},
    146230: {"Unified_Ideograph", "Ideographic"},
    146231: {"Unified_Ideograph", "Ideographic"},
    146232: {"Unified_Ideograph", "Ideographic"},
    146233: {"Unified_Ideograph", "Ideographic"},
    146234: {"Unified_Ideograph", "Ideographic"},
    146235: {"Unified_Ideograph", "Ideographic"},
    146236: {"Unified_Ideograph", "Ideographic"},
    146237: {"Unified_Ideograph", "Ideographic"},
    146238: {"Unified_Ideograph", "Ideographic"},
    146239: {"Unified_Ideograph", "Ideographic"},
    146240: {"Unified_Ideograph", "Ideographic"},
    146241: {"Unified_Ideograph", "Ideographic"},
    146242: {"Unified_Ideograph", "Ideographic"},
    146243: {"Unified_Ideograph", "Ideographic"},
    146244: {"Unified_Ideograph", "Ideographic"},
    146245: {"Unified_Ideograph", "Ideographic"},
    146246: {"Unified_Ideograph", "Ideographic"},
    146247: {"Unified_Ideograph", "Ideographic"},
    146248: {"Unified_Ideograph", "Ideographic"},
    146249: {"Unified_Ideograph", "Ideographic"},
    146250: {"Unified_Ideograph", "Ideographic"},
    146251: {"Unified_Ideograph", "Ideographic"},
    146252: {"Unified_Ideograph", "Ideographic"},
    146253: {"Unified_Ideograph", "Ideographic"},
    146254: {"Unified_Ideograph", "Ideographic"},
    146255: {"Unified_Ideograph", "Ideographic"},
    146256: {"Unified_Ideograph", "Ideographic"},
    146257: {"Unified_Ideograph", "Ideographic"},
    146258: {"Unified_Ideograph", "Ideographic"},
    146259: {"Unified_Ideograph", "Ideographic"},
    146260: {"Unified_Ideograph", "Ideographic"},
    146261: {"Unified_Ideograph", "Ideographic"},
    146262: {"Unified_Ideograph", "Ideographic"},
    146263: {"Unified_Ideograph", "Ideographic"},
    146264: {"Unified_Ideograph", "Ideographic"},
    146265: {"Unified_Ideograph", "Ideographic"},
    146266: {"Unified_Ideograph", "Ideographic"},
    146267: {"Unified_Ideograph", "Ideographic"},
    146268: {"Unified_Ideograph", "Ideographic"},
    146269: {"Unified_Ideograph", "Ideographic"},
    146270: {"Unified_Ideograph", "Ideographic"},
    146271: {"Unified_Ideograph", "Ideographic"},
    146272: {"Unified_Ideograph", "Ideographic"},
    146273: {"Unified_Ideograph", "Ideographic"},
    146274: {"Unified_Ideograph", "Ideographic"},
    146275: {"Unified_Ideograph", "Ideographic"},
    146276: {"Unified_Ideograph", "Ideographic"},
    146277: {"Unified_Ideograph", "Ideographic"},
    146278: {"Unified_Ideograph", "Ideographic"},
    146279: {"Unified_Ideograph", "Ideographic"},
    146280: {"Unified_Ideograph", "Ideographic"},
    146281: {"Unified_Ideograph", "Ideographic"},
    146282: {"Unified_Ideograph", "Ideographic"},
    146283: {"Unified_Ideograph", "Ideographic"},
    146284: {"Unified_Ideograph", "Ideographic"},
    146285: {"Unified_Ideograph", "Ideographic"},
    146286: {"Unified_Ideograph", "Ideographic"},
    146287: {"Unified_Ideograph", "Ideographic"},
    146288: {"Unified_Ideograph", "Ideographic"},
    146289: {"Unified_Ideograph", "Ideographic"},
    146290: {"Unified_Ideograph", "Ideographic"},
    146291: {"Unified_Ideograph", "Ideographic"},
    146292: {"Unified_Ideograph", "Ideographic"},
    146293: {"Unified_Ideograph", "Ideographic"},
    146294: {"Unified_Ideograph", "Ideographic"},
    146295: {"Unified_Ideograph", "Ideographic"},
    146296: {"Unified_Ideograph", "Ideographic"},
    146297: {"Unified_Ideograph", "Ideographic"},
    146298: {"Unified_Ideograph", "Ideographic"},
    146299: {"Unified_Ideograph", "Ideographic"},
    146300: {"Unified_Ideograph", "Ideographic"},
    146301: {"Unified_Ideograph", "Ideographic"},
    146302: {"Unified_Ideograph", "Ideographic"},
    146303: {"Unified_Ideograph", "Ideographic"},
    146304: {"Unified_Ideograph", "Ideographic"},
    146305: {"Unified_Ideograph", "Ideographic"},
    146306: {"Unified_Ideograph", "Ideographic"},
    146307: {"Unified_Ideograph", "Ideographic"},
    146308: {"Unified_Ideograph", "Ideographic"},
    146309: {"Unified_Ideograph", "Ideographic"},
    146310: {"Unified_Ideograph", "Ideographic"},
    146311: {"Unified_Ideograph", "Ideographic"},
    146312: {"Unified_Ideograph", "Ideographic"},
    146313: {"Unified_Ideograph", "Ideographic"},
    146314: {"Unified_Ideograph", "Ideographic"},
    146315: {"Unified_Ideograph", "Ideographic"},
    146316: {"Unified_Ideograph", "Ideographic"},
    146317: {"Unified_Ideograph", "Ideographic"},
    146318: {"Unified_Ideograph", "Ideographic"},
    146319: {"Unified_Ideograph", "Ideographic"},
    146320: {"Unified_Ideograph", "Ideographic"},
    146321: {"Unified_Ideograph", "Ideographic"},
    146322: {"Unified_Ideograph", "Ideographic"},
    146323: {"Unified_Ideograph", "Ideographic"},
    146324: {"Unified_Ideograph", "Ideographic"},
    146325: {"Unified_Ideograph", "Ideographic"},
    146326: {"Unified_Ideograph", "Ideographic"},
    146327: {"Unified_Ideograph", "Ideographic"},
    146328: {"Unified_Ideograph", "Ideographic"},
    146329: {"Unified_Ideograph", "Ideographic"},
    146330: {"Unified_Ideograph", "Ideographic"},
    146331: {"Unified_Ideograph", "Ideographic"},
    146332: {"Unified_Ideograph", "Ideographic"},
    146333: {"Unified_Ideograph", "Ideographic"},
    146334: {"Unified_Ideograph", "Ideographic"},
    146335: {"Unified_Ideograph", "Ideographic"},
    146336: {"Unified_Ideograph", "Ideographic"},
    146337: {"Unified_Ideograph", "Ideographic"},
    146338: {"Unified_Ideograph", "Ideographic"},
    146339: {"Unified_Ideograph", "Ideographic"},
    146340: {"Unified_Ideograph", "Ideographic"},
    146341: {"Unified_Ideograph", "Ideographic"},
    146342: {"Unified_Ideograph", "Ideographic"},
    146343: {"Unified_Ideograph", "Ideographic"},
    146344: {"Unified_Ideograph", "Ideographic"},
    146345: {"Unified_Ideograph", "Ideographic"},
    146346: {"Unified_Ideograph", "Ideographic"},
    146347: {"Unified_Ideograph", "Ideographic"},
    146348: {"Unified_Ideograph", "Ideographic"},
    146349: {"Unified_Ideograph", "Ideographic"},
    146350: {"Unified_Ideograph", "Ideographic"},
    146351: {"Unified_Ideograph", "Ideographic"},
    146352: {"Unified_Ideograph", "Ideographic"},
    146353: {"Unified_Ideograph", "Ideographic"},
    146354: {"Unified_Ideograph", "Ideographic"},
    146355: {"Unified_Ideograph", "Ideographic"},
    146356: {"Unified_Ideograph", "Ideographic"},
    146357: {"Unified_Ideograph", "Ideographic"},
    146358: {"Unified_Ideograph", "Ideographic"},
    146359: {"Unified_Ideograph", "Ideographic"},
    146360: {"Unified_Ideograph", "Ideographic"},
    146361: {"Unified_Ideograph", "Ideographic"},
    146362: {"Unified_Ideograph", "Ideographic"},
    146363: {"Unified_Ideograph", "Ideographic"},
    146364: {"Unified_Ideograph", "Ideographic"},
    146365: {"Unified_Ideograph", "Ideographic"},
    146366: {"Unified_Ideograph", "Ideographic"},
    146367: {"Unified_Ideograph", "Ideographic"},
    146368: {"Unified_Ideograph", "Ideographic"},
    146369: {"Unified_Ideograph", "Ideographic"},
    146370: {"Unified_Ideograph", "Ideographic"},
    146371: {"Unified_Ideograph", "Ideographic"},
    146372: {"Unified_Ideograph", "Ideographic"},
    146373: {"Unified_Ideograph", "Ideographic"},
    146374: {"Unified_Ideograph", "Ideographic"},
    146375: {"Unified_Ideograph", "Ideographic"},
    146376: {"Unified_Ideograph", "Ideographic"},
    146377: {"Unified_Ideograph", "Ideographic"},
    146378: {"Unified_Ideograph", "Ideographic"},
    146379: {"Unified_Ideograph", "Ideographic"},
    146380: {"Unified_Ideograph", "Ideographic"},
    146381: {"Unified_Ideograph", "Ideographic"},
    146382: {"Unified_Ideograph", "Ideographic"},
    146383: {"Unified_Ideograph", "Ideographic"},
    146384: {"Unified_Ideograph", "Ideographic"},
    146385: {"Unified_Ideograph", "Ideographic"},
    146386: {"Unified_Ideograph", "Ideographic"},
    146387: {"Unified_Ideograph", "Ideographic"},
    146388: {"Unified_Ideograph", "Ideographic"},
    146389: {"Unified_Ideograph", "Ideographic"},
    146390: {"Unified_Ideograph", "Ideographic"},
    146391: {"Unified_Ideograph", "Ideographic"},
    146392: {"Unified_Ideograph", "Ideographic"},
    146393: {"Unified_Ideograph", "Ideographic"},
    146394: {"Unified_Ideograph", "Ideographic"},
    146395: {"Unified_Ideograph", "Ideographic"},
    146396: {"Unified_Ideograph", "Ideographic"},
    146397: {"Unified_Ideograph", "Ideographic"},
    146398: {"Unified_Ideograph", "Ideographic"},
    146399: {"Unified_Ideograph", "Ideographic"},
    146400: {"Unified_Ideograph", "Ideographic"},
    146401: {"Unified_Ideograph", "Ideographic"},
    146402: {"Unified_Ideograph", "Ideographic"},
    146403: {"Unified_Ideograph", "Ideographic"},
    146404: {"Unified_Ideograph", "Ideographic"},
    146405: {"Unified_Ideograph", "Ideographic"},
    146406: {"Unified_Ideograph", "Ideographic"},
    146407: {"Unified_Ideograph", "Ideographic"},
    146408: {"Unified_Ideograph", "Ideographic"},
    146409: {"Unified_Ideograph", "Ideographic"},
    146410: {"Unified_Ideograph", "Ideographic"},
    146411: {"Unified_Ideograph", "Ideographic"},
    146412: {"Unified_Ideograph", "Ideographic"},
    146413: {"Unified_Ideograph", "Ideographic"},
    146414: {"Unified_Ideograph", "Ideographic"},
    146415: {"Unified_Ideograph", "Ideographic"},
    146416: {"Unified_Ideograph", "Ideographic"},
    146417: {"Unified_Ideograph", "Ideographic"},
    146418: {"Unified_Ideograph", "Ideographic"},
    146419: {"Unified_Ideograph", "Ideographic"},
    146420: {"Unified_Ideograph", "Ideographic"},
    146421: {"Unified_Ideograph", "Ideographic"},
    146422: {"Unified_Ideograph", "Ideographic"},
    146423: {"Unified_Ideograph", "Ideographic"},
    146424: {"Unified_Ideograph", "Ideographic"},
    146425: {"Unified_Ideograph", "Ideographic"},
    146426: {"Unified_Ideograph", "Ideographic"},
    146427: {"Unified_Ideograph", "Ideographic"},
    146428: {"Unified_Ideograph", "Ideographic"},
    146429: {"Unified_Ideograph", "Ideographic"},
    146430: {"Unified_Ideograph", "Ideographic"},
    146431: {"Unified_Ideograph", "Ideographic"},
    146432: {"Unified_Ideograph", "Ideographic"},
    146433: {"Unified_Ideograph", "Ideographic"},
    146434: {"Unified_Ideograph", "Ideographic"},
    146435: {"Unified_Ideograph", "Ideographic"},
    146436: {"Unified_Ideograph", "Ideographic"},
    146437: {"Unified_Ideograph", "Ideographic"},
    146438: {"Unified_Ideograph", "Ideographic"},
    146439: {"Unified_Ideograph", "Ideographic"},
    146440: {"Unified_Ideograph", "Ideographic"},
    146441: {"Unified_Ideograph", "Ideographic"},
    146442: {"Unified_Ideograph", "Ideographic"},
    146443: {"Unified_Ideograph", "Ideographic"},
    146444: {"Unified_Ideograph", "Ideographic"},
    146445: {"Unified_Ideograph", "Ideographic"},
    146446: {"Unified_Ideograph", "Ideographic"},
    146447: {"Unified_Ideograph", "Ideographic"},
    146448: {"Unified_Ideograph", "Ideographic"},
    146449: {"Unified_Ideograph", "Ideographic"},
    146450: {"Unified_Ideograph", "Ideographic"},
    146451: {"Unified_Ideograph", "Ideographic"},
    146452: {"Unified_Ideograph", "Ideographic"},
    146453: {"Unified_Ideograph", "Ideographic"},
    146454: {"Unified_Ideograph", "Ideographic"},
    146455: {"Unified_Ideograph", "Ideographic"},
    146456: {"Unified_Ideograph", "Ideographic"},
    146457: {"Unified_Ideograph", "Ideographic"},
    146458: {"Unified_Ideograph", "Ideographic"},
    146459: {"Unified_Ideograph", "Ideographic"},
    146460: {"Unified_Ideograph", "Ideographic"},
    146461: {"Unified_Ideograph", "Ideographic"},
    146462: {"Unified_Ideograph", "Ideographic"},
    146463: {"Unified_Ideograph", "Ideographic"},
    146464: {"Unified_Ideograph", "Ideographic"},
    146465: {"Unified_Ideograph", "Ideographic"},
    146466: {"Unified_Ideograph", "Ideographic"},
    146467: {"Unified_Ideograph", "Ideographic"},
    146468: {"Unified_Ideograph", "Ideographic"},
    146469: {"Unified_Ideograph", "Ideographic"},
    146470: {"Unified_Ideograph", "Ideographic"},
    146471: {"Unified_Ideograph", "Ideographic"},
    146472: {"Unified_Ideograph", "Ideographic"},
    146473: {"Unified_Ideograph", "Ideographic"},
    146474: {"Unified_Ideograph", "Ideographic"},
    146475: {"Unified_Ideograph", "Ideographic"},
    146476: {"Unified_Ideograph", "Ideographic"},
    146477: {"Unified_Ideograph", "Ideographic"},
    146478: {"Unified_Ideograph", "Ideographic"},
    146479: {"Unified_Ideograph", "Ideographic"},
    146480: {"Unified_Ideograph", "Ideographic"},
    146481: {"Unified_Ideograph", "Ideographic"},
    146482: {"Unified_Ideograph", "Ideographic"},
    146483: {"Unified_Ideograph", "Ideographic"},
    146484: {"Unified_Ideograph", "Ideographic"},
    146485: {"Unified_Ideograph", "Ideographic"},
    146486: {"Unified_Ideograph", "Ideographic"},
    146487: {"Unified_Ideograph", "Ideographic"},
    146488: {"Unified_Ideograph", "Ideographic"},
    146489: {"Unified_Ideograph", "Ideographic"},
    146490: {"Unified_Ideograph", "Ideographic"},
    146491: {"Unified_Ideograph", "Ideographic"},
    146492: {"Unified_Ideograph", "Ideographic"},
    146493: {"Unified_Ideograph", "Ideographic"},
    146494: {"Unified_Ideograph", "Ideographic"},
    146495: {"Unified_Ideograph", "Ideographic"},
    146496: {"Unified_Ideograph", "Ideographic"},
    146497: {"Unified_Ideograph", "Ideographic"},
    146498: {"Unified_Ideograph", "Ideographic"},
    146499: {"Unified_Ideograph", "Ideographic"},
    146500: {"Unified_Ideograph", "Ideographic"},
    146501: {"Unified_Ideograph", "Ideographic"},
    146502: {"Unified_Ideograph", "Ideographic"},
    146503: {"Unified_Ideograph", "Ideographic"},
    146504: {"Unified_Ideograph", "Ideographic"},
    146505: {"Unified_Ideograph", "Ideographic"},
    146506: {"Unified_Ideograph", "Ideographic"},
    146507: {"Unified_Ideograph", "Ideographic"},
    146508: {"Unified_Ideograph", "Ideographic"},
    146509: {"Unified_Ideograph", "Ideographic"},
    146510: {"Unified_Ideograph", "Ideographic"},
    146511: {"Unified_Ideograph", "Ideographic"},
    146512: {"Unified_Ideograph", "Ideographic"},
    146513: {"Unified_Ideograph", "Ideographic"},
    146514: {"Unified_Ideograph", "Ideographic"},
    146515: {"Unified_Ideograph", "Ideographic"},
    146516: {"Unified_Ideograph", "Ideographic"},
    146517: {"Unified_Ideograph", "Ideographic"},
    146518: {"Unified_Ideograph", "Ideographic"},
    146519: {"Unified_Ideograph", "Ideographic"},
    146520: {"Unified_Ideograph", "Ideographic"},
    146521: {"Unified_Ideograph", "Ideographic"},
    146522: {"Unified_Ideograph", "Ideographic"},
    146523: {"Unified_Ideograph", "Ideographic"},
    146524: {"Unified_Ideograph", "Ideographic"},
    146525: {"Unified_Ideograph", "Ideographic"},
    146526: {"Unified_Ideograph", "Ideographic"},
    146527: {"Unified_Ideograph", "Ideographic"},
    146528: {"Unified_Ideograph", "Ideographic"},
    146529: {"Unified_Ideograph", "Ideographic"},
    146530: {"Unified_Ideograph", "Ideographic"},
    146531: {"Unified_Ideograph", "Ideographic"},
    146532: {"Unified_Ideograph", "Ideographic"},
    146533: {"Unified_Ideograph", "Ideographic"},
    146534: {"Unified_Ideograph", "Ideographic"},
    146535: {"Unified_Ideograph", "Ideographic"},
    146536: {"Unified_Ideograph", "Ideographic"},
    146537: {"Unified_Ideograph", "Ideographic"},
    146538: {"Unified_Ideograph", "Ideographic"},
    146539: {"Unified_Ideograph", "Ideographic"},
    146540: {"Unified_Ideograph", "Ideographic"},
    146541: {"Unified_Ideograph", "Ideographic"},
    146542: {"Unified_Ideograph", "Ideographic"},
    146543: {"Unified_Ideograph", "Ideographic"},
    146544: {"Unified_Ideograph", "Ideographic"},
    146545: {"Unified_Ideograph", "Ideographic"},
    146546: {"Unified_Ideograph", "Ideographic"},
    146547: {"Unified_Ideograph", "Ideographic"},
    146548: {"Unified_Ideograph", "Ideographic"},
    146549: {"Unified_Ideograph", "Ideographic"},
    146550: {"Unified_Ideograph", "Ideographic"},
    146551: {"Unified_Ideograph", "Ideographic"},
    146552: {"Unified_Ideograph", "Ideographic"},
    146553: {"Unified_Ideograph", "Ideographic"},
    146554: {"Unified_Ideograph", "Ideographic"},
    146555: {"Unified_Ideograph", "Ideographic"},
    146556: {"Unified_Ideograph", "Ideographic"},
    146557: {"Unified_Ideograph", "Ideographic"},
    146558: {"Unified_Ideograph", "Ideographic"},
    146559: {"Unified_Ideograph", "Ideographic"},
    146560: {"Unified_Ideograph", "Ideographic"},
    146561: {"Unified_Ideograph", "Ideographic"},
    146562: {"Unified_Ideograph", "Ideographic"},
    146563: {"Unified_Ideograph", "Ideographic"},
    146564: {"Unified_Ideograph", "Ideographic"},
    146565: {"Unified_Ideograph", "Ideographic"},
    146566: {"Unified_Ideograph", "Ideographic"},
    146567: {"Unified_Ideograph", "Ideographic"},
    146568: {"Unified_Ideograph", "Ideographic"},
    146569: {"Unified_Ideograph", "Ideographic"},
    146570: {"Unified_Ideograph", "Ideographic"},
    146571: {"Unified_Ideograph", "Ideographic"},
    146572: {"Unified_Ideograph", "Ideographic"},
    146573: {"Unified_Ideograph", "Ideographic"},
    146574: {"Unified_Ideograph", "Ideographic"},
    146575: {"Unified_Ideograph", "Ideographic"},
    146576: {"Unified_Ideograph", "Ideographic"},
    146577: {"Unified_Ideograph", "Ideographic"},
    146578: {"Unified_Ideograph", "Ideographic"},
    146579: {"Unified_Ideograph", "Ideographic"},
    146580: {"Unified_Ideograph", "Ideographic"},
    146581: {"Unified_Ideograph", "Ideographic"},
    146582: {"Unified_Ideograph", "Ideographic"},
    146583: {"Unified_Ideograph", "Ideographic"},
    146584: {"Unified_Ideograph", "Ideographic"},
    146585: {"Unified_Ideograph", "Ideographic"},
    146586: {"Unified_Ideograph", "Ideographic"},
    146587: {"Unified_Ideograph", "Ideographic"},
    146588: {"Unified_Ideograph", "Ideographic"},
    146589: {"Unified_Ideograph", "Ideographic"},
    146590: {"Unified_Ideograph", "Ideographic"},
    146591: {"Unified_Ideograph", "Ideographic"},
    146592: {"Unified_Ideograph", "Ideographic"},
    146593: {"Unified_Ideograph", "Ideographic"},
    146594: {"Unified_Ideograph", "Ideographic"},
    146595: {"Unified_Ideograph", "Ideographic"},
    146596: {"Unified_Ideograph", "Ideographic"},
    146597: {"Unified_Ideograph", "Ideographic"},
    146598: {"Unified_Ideograph", "Ideographic"},
    146599: {"Unified_Ideograph", "Ideographic"},
    146600: {"Unified_Ideograph", "Ideographic"},
    146601: {"Unified_Ideograph", "Ideographic"},
    146602: {"Unified_Ideograph", "Ideographic"},
    146603: {"Unified_Ideograph", "Ideographic"},
    146604: {"Unified_Ideograph", "Ideographic"},
    146605: {"Unified_Ideograph", "Ideographic"},
    146606: {"Unified_Ideograph", "Ideographic"},
    146607: {"Unified_Ideograph", "Ideographic"},
    146608: {"Unified_Ideograph", "Ideographic"},
    146609: {"Unified_Ideograph", "Ideographic"},
    146610: {"Unified_Ideograph", "Ideographic"},
    146611: {"Unified_Ideograph", "Ideographic"},
    146612: {"Unified_Ideograph", "Ideographic"},
    146613: {"Unified_Ideograph", "Ideographic"},
    146614: {"Unified_Ideograph", "Ideographic"},
    146615: {"Unified_Ideograph", "Ideographic"},
    146616: {"Unified_Ideograph", "Ideographic"},
    146617: {"Unified_Ideograph", "Ideographic"},
    146618: {"Unified_Ideograph", "Ideographic"},
    146619: {"Unified_Ideograph", "Ideographic"},
    146620: {"Unified_Ideograph", "Ideographic"},
    146621: {"Unified_Ideograph", "Ideographic"},
    146622: {"Unified_Ideograph", "Ideographic"},
    146623: {"Unified_Ideograph", "Ideographic"},
    146624: {"Unified_Ideograph", "Ideographic"},
    146625: {"Unified_Ideograph", "Ideographic"},
    146626: {"Unified_Ideograph", "Ideographic"},
    146627: {"Unified_Ideograph", "Ideographic"},
    146628: {"Unified_Ideograph", "Ideographic"},
    146629: {"Unified_Ideograph", "Ideographic"},
    146630: {"Unified_Ideograph", "Ideographic"},
    146631: {"Unified_Ideograph", "Ideographic"},
    146632: {"Unified_Ideograph", "Ideographic"},
    146633: {"Unified_Ideograph", "Ideographic"},
    146634: {"Unified_Ideograph", "Ideographic"},
    146635: {"Unified_Ideograph", "Ideographic"},
    146636: {"Unified_Ideograph", "Ideographic"},
    146637: {"Unified_Ideograph", "Ideographic"},
    146638: {"Unified_Ideograph", "Ideographic"},
    146639: {"Unified_Ideograph", "Ideographic"},
    146640: {"Unified_Ideograph", "Ideographic"},
    146641: {"Unified_Ideograph", "Ideographic"},
    146642: {"Unified_Ideograph", "Ideographic"},
    146643: {"Unified_Ideograph", "Ideographic"},
    146644: {"Unified_Ideograph", "Ideographic"},
    146645: {"Unified_Ideograph", "Ideographic"},
    146646: {"Unified_Ideograph", "Ideographic"},
    146647: {"Unified_Ideograph", "Ideographic"},
    146648: {"Unified_Ideograph", "Ideographic"},
    146649: {"Unified_Ideograph", "Ideographic"},
    146650: {"Unified_Ideograph", "Ideographic"},
    146651: {"Unified_Ideograph", "Ideographic"},
    146652: {"Unified_Ideograph", "Ideographic"},
    146653: {"Unified_Ideograph", "Ideographic"},
    146654: {"Unified_Ideograph", "Ideographic"},
    146655: {"Unified_Ideograph", "Ideographic"},
    146656: {"Unified_Ideograph", "Ideographic"},
    146657: {"Unified_Ideograph", "Ideographic"},
    146658: {"Unified_Ideograph", "Ideographic"},
    146659: {"Unified_Ideograph", "Ideographic"},
    146660: {"Unified_Ideograph", "Ideographic"},
    146661: {"Unified_Ideograph", "Ideographic"},
    146662: {"Unified_Ideograph", "Ideographic"},
    146663: {"Unified_Ideograph", "Ideographic"},
    146664: {"Unified_Ideograph", "Ideographic"},
    146665: {"Unified_Ideograph", "Ideographic"},
    146666: {"Unified_Ideograph", "Ideographic"},
    146667: {"Unified_Ideograph", "Ideographic"},
    146668: {"Unified_Ideograph", "Ideographic"},
    146669: {"Unified_Ideograph", "Ideographic"},
    146670: {"Unified_Ideograph", "Ideographic"},
    146671: {"Unified_Ideograph", "Ideographic"},
    146672: {"Unified_Ideograph", "Ideographic"},
    146673: {"Unified_Ideograph", "Ideographic"},
    146674: {"Unified_Ideograph", "Ideographic"},
    146675: {"Unified_Ideograph", "Ideographic"},
    146676: {"Unified_Ideograph", "Ideographic"},
    146677: {"Unified_Ideograph", "Ideographic"},
    146678: {"Unified_Ideograph", "Ideographic"},
    146679: {"Unified_Ideograph", "Ideographic"},
    146680: {"Unified_Ideograph", "Ideographic"},
    146681: {"Unified_Ideograph", "Ideographic"},
    146682: {"Unified_Ideograph", "Ideographic"},
    146683: {"Unified_Ideograph", "Ideographic"},
    146684: {"Unified_Ideograph", "Ideographic"},
    146685: {"Unified_Ideograph", "Ideographic"},
    146686: {"Unified_Ideograph", "Ideographic"},
    146687: {"Unified_Ideograph", "Ideographic"},
    146688: {"Unified_Ideograph", "Ideographic"},
    146689: {"Unified_Ideograph", "Ideographic"},
    146690: {"Unified_Ideograph", "Ideographic"},
    146691: {"Unified_Ideograph", "Ideographic"},
    146692: {"Unified_Ideograph", "Ideographic"},
    146693: {"Unified_Ideograph", "Ideographic"},
    146694: {"Unified_Ideograph", "Ideographic"},
    146695: {"Unified_Ideograph", "Ideographic"},
    146696: {"Unified_Ideograph", "Ideographic"},
    146697: {"Unified_Ideograph", "Ideographic"},
    146698: {"Unified_Ideograph", "Ideographic"},
    146699: {"Unified_Ideograph", "Ideographic"},
    146700: {"Unified_Ideograph", "Ideographic"},
    146701: {"Unified_Ideograph", "Ideographic"},
    146702: {"Unified_Ideograph", "Ideographic"},
    146703: {"Unified_Ideograph", "Ideographic"},
    146704: {"Unified_Ideograph", "Ideographic"},
    146705: {"Unified_Ideograph", "Ideographic"},
    146706: {"Unified_Ideograph", "Ideographic"},
    146707: {"Unified_Ideograph", "Ideographic"},
    146708: {"Unified_Ideograph", "Ideographic"},
    146709: {"Unified_Ideograph", "Ideographic"},
    146710: {"Unified_Ideograph", "Ideographic"},
    146711: {"Unified_Ideograph", "Ideographic"},
    146712: {"Unified_Ideograph", "Ideographic"},
    146713: {"Unified_Ideograph", "Ideographic"},
    146714: {"Unified_Ideograph", "Ideographic"},
    146715: {"Unified_Ideograph", "Ideographic"},
    146716: {"Unified_Ideograph", "Ideographic"},
    146717: {"Unified_Ideograph", "Ideographic"},
    146718: {"Unified_Ideograph", "Ideographic"},
    146719: {"Unified_Ideograph", "Ideographic"},
    146720: {"Unified_Ideograph", "Ideographic"},
    146721: {"Unified_Ideograph", "Ideographic"},
    146722: {"Unified_Ideograph", "Ideographic"},
    146723: {"Unified_Ideograph", "Ideographic"},
    146724: {"Unified_Ideograph", "Ideographic"},
    146725: {"Unified_Ideograph", "Ideographic"},
    146726: {"Unified_Ideograph", "Ideographic"},
    146727: {"Unified_Ideograph", "Ideographic"},
    146728: {"Unified_Ideograph", "Ideographic"},
    146729: {"Unified_Ideograph", "Ideographic"},
    146730: {"Unified_Ideograph", "Ideographic"},
    146731: {"Unified_Ideograph", "Ideographic"},
    146732: {"Unified_Ideograph", "Ideographic"},
    146733: {"Unified_Ideograph", "Ideographic"},
    146734: {"Unified_Ideograph", "Ideographic"},
    146735: {"Unified_Ideograph", "Ideographic"},
    146736: {"Unified_Ideograph", "Ideographic"},
    146737: {"Unified_Ideograph", "Ideographic"},
    146738: {"Unified_Ideograph", "Ideographic"},
    146739: {"Unified_Ideograph", "Ideographic"},
    146740: {"Unified_Ideograph", "Ideographic"},
    146741: {"Unified_Ideograph", "Ideographic"},
    146742: {"Unified_Ideograph", "Ideographic"},
    146743: {"Unified_Ideograph", "Ideographic"},
    146744: {"Unified_Ideograph", "Ideographic"},
    146745: {"Unified_Ideograph", "Ideographic"},
    146746: {"Unified_Ideograph", "Ideographic"},
    146747: {"Unified_Ideograph", "Ideographic"},
    146748: {"Unified_Ideograph", "Ideographic"},
    146749: {"Unified_Ideograph", "Ideographic"},
    146750: {"Unified_Ideograph", "Ideographic"},
    146751: {"Unified_Ideograph", "Ideographic"},
    146752: {"Unified_Ideograph", "Ideographic"},
    146753: {"Unified_Ideograph", "Ideographic"},
    146754: {"Unified_Ideograph", "Ideographic"},
    146755: {"Unified_Ideograph", "Ideographic"},
    146756: {"Unified_Ideograph", "Ideographic"},
    146757: {"Unified_Ideograph", "Ideographic"},
    146758: {"Unified_Ideograph", "Ideographic"},
    146759: {"Unified_Ideograph", "Ideographic"},
    146760: {"Unified_Ideograph", "Ideographic"},
    146761: {"Unified_Ideograph", "Ideographic"},
    146762: {"Unified_Ideograph", "Ideographic"},
    146763: {"Unified_Ideograph", "Ideographic"},
    146764: {"Unified_Ideograph", "Ideographic"},
    146765: {"Unified_Ideograph", "Ideographic"},
    146766: {"Unified_Ideograph", "Ideographic"},
    146767: {"Unified_Ideograph", "Ideographic"},
    146768: {"Unified_Ideograph", "Ideographic"},
    146769: {"Unified_Ideograph", "Ideographic"},
    146770: {"Unified_Ideograph", "Ideographic"},
    146771: {"Unified_Ideograph", "Ideographic"},
    146772: {"Unified_Ideograph", "Ideographic"},
    146773: {"Unified_Ideograph", "Ideographic"},
    146774: {"Unified_Ideograph", "Ideographic"},
    146775: {"Unified_Ideograph", "Ideographic"},
    146776: {"Unified_Ideograph", "Ideographic"},
    146777: {"Unified_Ideograph", "Ideographic"},
    146778: {"Unified_Ideograph", "Ideographic"},
    146779: {"Unified_Ideograph", "Ideographic"},
    146780: {"Unified_Ideograph", "Ideographic"},
    146781: {"Unified_Ideograph", "Ideographic"},
    146782: {"Unified_Ideograph", "Ideographic"},
    146783: {"Unified_Ideograph", "Ideographic"},
    146784: {"Unified_Ideograph", "Ideographic"},
    146785: {"Unified_Ideograph", "Ideographic"},
    146786: {"Unified_Ideograph", "Ideographic"},
    146787: {"Unified_Ideograph", "Ideographic"},
    146788: {"Unified_Ideograph", "Ideographic"},
    146789: {"Unified_Ideograph", "Ideographic"},
    146790: {"Unified_Ideograph", "Ideographic"},
    146791: {"Unified_Ideograph", "Ideographic"},
    146792: {"Unified_Ideograph", "Ideographic"},
    146793: {"Unified_Ideograph", "Ideographic"},
    146794: {"Unified_Ideograph", "Ideographic"},
    146795: {"Unified_Ideograph", "Ideographic"},
    146796: {"Unified_Ideograph", "Ideographic"},
    146797: {"Unified_Ideograph", "Ideographic"},
    146798: {"Unified_Ideograph", "Ideographic"},
    146799: {"Unified_Ideograph", "Ideographic"},
    146800: {"Unified_Ideograph", "Ideographic"},
    146801: {"Unified_Ideograph", "Ideographic"},
    146802: {"Unified_Ideograph", "Ideographic"},
    146803: {"Unified_Ideograph", "Ideographic"},
    146804: {"Unified_Ideograph", "Ideographic"},
    146805: {"Unified_Ideograph", "Ideographic"},
    146806: {"Unified_Ideograph", "Ideographic"},
    146807: {"Unified_Ideograph", "Ideographic"},
    146808: {"Unified_Ideograph", "Ideographic"},
    146809: {"Unified_Ideograph", "Ideographic"},
    146810: {"Unified_Ideograph", "Ideographic"},
    146811: {"Unified_Ideograph", "Ideographic"},
    146812: {"Unified_Ideograph", "Ideographic"},
    146813: {"Unified_Ideograph", "Ideographic"},
    146814: {"Unified_Ideograph", "Ideographic"},
    146815: {"Unified_Ideograph", "Ideographic"},
    146816: {"Unified_Ideograph", "Ideographic"},
    146817: {"Unified_Ideograph", "Ideographic"},
    146818: {"Unified_Ideograph", "Ideographic"},
    146819: {"Unified_Ideograph", "Ideographic"},
    146820: {"Unified_Ideograph", "Ideographic"},
    146821: {"Unified_Ideograph", "Ideographic"},
    146822: {"Unified_Ideograph", "Ideographic"},
    146823: {"Unified_Ideograph", "Ideographic"},
    146824: {"Unified_Ideograph", "Ideographic"},
    146825: {"Unified_Ideograph", "Ideographic"},
    146826: {"Unified_Ideograph", "Ideographic"},
    146827: {"Unified_Ideograph", "Ideographic"},
    146828: {"Unified_Ideograph", "Ideographic"},
    146829: {"Unified_Ideograph", "Ideographic"},
    146830: {"Unified_Ideograph", "Ideographic"},
    146831: {"Unified_Ideograph", "Ideographic"},
    146832: {"Unified_Ideograph", "Ideographic"},
    146833: {"Unified_Ideograph", "Ideographic"},
    146834: {"Unified_Ideograph", "Ideographic"},
    146835: {"Unified_Ideograph", "Ideographic"},
    146836: {"Unified_Ideograph", "Ideographic"},
    146837: {"Unified_Ideograph", "Ideographic"},
    146838: {"Unified_Ideograph", "Ideographic"},
    146839: {"Unified_Ideograph", "Ideographic"},
    146840: {"Unified_Ideograph", "Ideographic"},
    146841: {"Unified_Ideograph", "Ideographic"},
    146842: {"Unified_Ideograph", "Ideographic"},
    146843: {"Unified_Ideograph", "Ideographic"},
    146844: {"Unified_Ideograph", "Ideographic"},
    146845: {"Unified_Ideograph", "Ideographic"},
    146846: {"Unified_Ideograph", "Ideographic"},
    146847: {"Unified_Ideograph", "Ideographic"},
    146848: {"Unified_Ideograph", "Ideographic"},
    146849: {"Unified_Ideograph", "Ideographic"},
    146850: {"Unified_Ideograph", "Ideographic"},
    146851: {"Unified_Ideograph", "Ideographic"},
    146852: {"Unified_Ideograph", "Ideographic"},
    146853: {"Unified_Ideograph", "Ideographic"},
    146854: {"Unified_Ideograph", "Ideographic"},
    146855: {"Unified_Ideograph", "Ideographic"},
    146856: {"Unified_Ideograph", "Ideographic"},
    146857: {"Unified_Ideograph", "Ideographic"},
    146858: {"Unified_Ideograph", "Ideographic"},
    146859: {"Unified_Ideograph", "Ideographic"},
    146860: {"Unified_Ideograph", "Ideographic"},
    146861: {"Unified_Ideograph", "Ideographic"},
    146862: {"Unified_Ideograph", "Ideographic"},
    146863: {"Unified_Ideograph", "Ideographic"},
    146864: {"Unified_Ideograph", "Ideographic"},
    146865: {"Unified_Ideograph", "Ideographic"},
    146866: {"Unified_Ideograph", "Ideographic"},
    146867: {"Unified_Ideograph", "Ideographic"},
    146868: {"Unified_Ideograph", "Ideographic"},
    146869: {"Unified_Ideograph", "Ideographic"},
    146870: {"Unified_Ideograph", "Ideographic"},
    146871: {"Unified_Ideograph", "Ideographic"},
    146872: {"Unified_Ideograph", "Ideographic"},
    146873: {"Unified_Ideograph", "Ideographic"},
    146874: {"Unified_Ideograph", "Ideographic"},
    146875: {"Unified_Ideograph", "Ideographic"},
    146876: {"Unified_Ideograph", "Ideographic"},
    146877: {"Unified_Ideograph", "Ideographic"},
    146878: {"Unified_Ideograph", "Ideographic"},
    146879: {"Unified_Ideograph", "Ideographic"},
    146880: {"Unified_Ideograph", "Ideographic"},
    146881: {"Unified_Ideograph", "Ideographic"},
    146882: {"Unified_Ideograph", "Ideographic"},
    146883: {"Unified_Ideograph", "Ideographic"},
    146884: {"Unified_Ideograph", "Ideographic"},
    146885: {"Unified_Ideograph", "Ideographic"},
    146886: {"Unified_Ideograph", "Ideographic"},
    146887: {"Unified_Ideograph", "Ideographic"},
    146888: {"Unified_Ideograph", "Ideographic"},
    146889: {"Unified_Ideograph", "Ideographic"},
    146890: {"Unified_Ideograph", "Ideographic"},
    146891: {"Unified_Ideograph", "Ideographic"},
    146892: {"Unified_Ideograph", "Ideographic"},
    146893: {"Unified_Ideograph", "Ideographic"},
    146894: {"Unified_Ideograph", "Ideographic"},
    146895: {"Unified_Ideograph", "Ideographic"},
    146896: {"Unified_Ideograph", "Ideographic"},
    146897: {"Unified_Ideograph", "Ideographic"},
    146898: {"Unified_Ideograph", "Ideographic"},
    146899: {"Unified_Ideograph", "Ideographic"},
    146900: {"Unified_Ideograph", "Ideographic"},
    146901: {"Unified_Ideograph", "Ideographic"},
    146902: {"Unified_Ideograph", "Ideographic"},
    146903: {"Unified_Ideograph", "Ideographic"},
    146904: {"Unified_Ideograph", "Ideographic"},
    146905: {"Unified_Ideograph", "Ideographic"},
    146906: {"Unified_Ideograph", "Ideographic"},
    146907: {"Unified_Ideograph", "Ideographic"},
    146908: {"Unified_Ideograph", "Ideographic"},
    146909: {"Unified_Ideograph", "Ideographic"},
    146910: {"Unified_Ideograph", "Ideographic"},
    146911: {"Unified_Ideograph", "Ideographic"},
    146912: {"Unified_Ideograph", "Ideographic"},
    146913: {"Unified_Ideograph", "Ideographic"},
    146914: {"Unified_Ideograph", "Ideographic"},
    146915: {"Unified_Ideograph", "Ideographic"},
    146916: {"Unified_Ideograph", "Ideographic"},
    146917: {"Unified_Ideograph", "Ideographic"},
    146918: {"Unified_Ideograph", "Ideographic"},
    146919: {"Unified_Ideograph", "Ideographic"},
    146920: {"Unified_Ideograph", "Ideographic"},
    146921: {"Unified_Ideograph", "Ideographic"},
    146922: {"Unified_Ideograph", "Ideographic"},
    146923: {"Unified_Ideograph", "Ideographic"},
    146924: {"Unified_Ideograph", "Ideographic"},
    146925: {"Unified_Ideograph", "Ideographic"},
    146926: {"Unified_Ideograph", "Ideographic"},
    146927: {"Unified_Ideograph", "Ideographic"},
    146928: {"Unified_Ideograph", "Ideographic"},
    146929: {"Unified_Ideograph", "Ideographic"},
    146930: {"Unified_Ideograph", "Ideographic"},
    146931: {"Unified_Ideograph", "Ideographic"},
    146932: {"Unified_Ideograph", "Ideographic"},
    146933: {"Unified_Ideograph", "Ideographic"},
    146934: {"Unified_Ideograph", "Ideographic"},
    146935: {"Unified_Ideograph", "Ideographic"},
    146936: {"Unified_Ideograph", "Ideographic"},
    146937: {"Unified_Ideograph", "Ideographic"},
    146938: {"Unified_Ideograph", "Ideographic"},
    146939: {"Unified_Ideograph", "Ideographic"},
    146940: {"Unified_Ideograph", "Ideographic"},
    146941: {"Unified_Ideograph", "Ideographic"},
    146942: {"Unified_Ideograph", "Ideographic"},
    146943: {"Unified_Ideograph", "Ideographic"},
    146944: {"Unified_Ideograph", "Ideographic"},
    146945: {"Unified_Ideograph", "Ideographic"},
    146946: {"Unified_Ideograph", "Ideographic"},
    146947: {"Unified_Ideograph", "Ideographic"},
    146948: {"Unified_Ideograph", "Ideographic"},
    146949: {"Unified_Ideograph", "Ideographic"},
    146950: {"Unified_Ideograph", "Ideographic"},
    146951: {"Unified_Ideograph", "Ideographic"},
    146952: {"Unified_Ideograph", "Ideographic"},
    146953: {"Unified_Ideograph", "Ideographic"},
    146954: {"Unified_Ideograph", "Ideographic"},
    146955: {"Unified_Ideograph", "Ideographic"},
    146956: {"Unified_Ideograph", "Ideographic"},
    146957: {"Unified_Ideograph", "Ideographic"},
    146958: {"Unified_Ideograph", "Ideographic"},
    146959: {"Unified_Ideograph", "Ideographic"},
    146960: {"Unified_Ideograph", "Ideographic"},
    146961: {"Unified_Ideograph", "Ideographic"},
    146962: {"Unified_Ideograph", "Ideographic"},
    146963: {"Unified_Ideograph", "Ideographic"},
    146964: {"Unified_Ideograph", "Ideographic"},
    146965: {"Unified_Ideograph", "Ideographic"},
    146966: {"Unified_Ideograph", "Ideographic"},
    146967: {"Unified_Ideograph", "Ideographic"},
    146968: {"Unified_Ideograph", "Ideographic"},
    146969: {"Unified_Ideograph", "Ideographic"},
    146970: {"Unified_Ideograph", "Ideographic"},
    146971: {"Unified_Ideograph", "Ideographic"},
    146972: {"Unified_Ideograph", "Ideographic"},
    146973: {"Unified_Ideograph", "Ideographic"},
    146974: {"Unified_Ideograph", "Ideographic"},
    146975: {"Unified_Ideograph", "Ideographic"},
    146976: {"Unified_Ideograph", "Ideographic"},
    146977: {"Unified_Ideograph", "Ideographic"},
    146978: {"Unified_Ideograph", "Ideographic"},
    146979: {"Unified_Ideograph", "Ideographic"},
    146980: {"Unified_Ideograph", "Ideographic"},
    146981: {"Unified_Ideograph", "Ideographic"},
    146982: {"Unified_Ideograph", "Ideographic"},
    146983: {"Unified_Ideograph", "Ideographic"},
    146984: {"Unified_Ideograph", "Ideographic"},
    146985: {"Unified_Ideograph", "Ideographic"},
    146986: {"Unified_Ideograph", "Ideographic"},
    146987: {"Unified_Ideograph", "Ideographic"},
    146988: {"Unified_Ideograph", "Ideographic"},
    146989: {"Unified_Ideograph", "Ideographic"},
    146990: {"Unified_Ideograph", "Ideographic"},
    146991: {"Unified_Ideograph", "Ideographic"},
    146992: {"Unified_Ideograph", "Ideographic"},
    146993: {"Unified_Ideograph", "Ideographic"},
    146994: {"Unified_Ideograph", "Ideographic"},
    146995: {"Unified_Ideograph", "Ideographic"},
    146996: {"Unified_Ideograph", "Ideographic"},
    146997: {"Unified_Ideograph", "Ideographic"},
    146998: {"Unified_Ideograph", "Ideographic"},
    146999: {"Unified_Ideograph", "Ideographic"},
    147000: {"Unified_Ideograph", "Ideographic"},
    147001: {"Unified_Ideograph", "Ideographic"},
    147002: {"Unified_Ideograph", "Ideographic"},
    147003: {"Unified_Ideograph", "Ideographic"},
    147004: {"Unified_Ideograph", "Ideographic"},
    147005: {"Unified_Ideograph", "Ideographic"},
    147006: {"Unified_Ideograph", "Ideographic"},
    147007: {"Unified_Ideograph", "Ideographic"},
    147008: {"Unified_Ideograph", "Ideographic"},
    147009: {"Unified_Ideograph", "Ideographic"},
    147010: {"Unified_Ideograph", "Ideographic"},
    147011: {"Unified_Ideograph", "Ideographic"},
    147012: {"Unified_Ideograph", "Ideographic"},
    147013: {"Unified_Ideograph", "Ideographic"},
    147014: {"Unified_Ideograph", "Ideographic"},
    147015: {"Unified_Ideograph", "Ideographic"},
    147016: {"Unified_Ideograph", "Ideographic"},
    147017: {"Unified_Ideograph", "Ideographic"},
    147018: {"Unified_Ideograph", "Ideographic"},
    147019: {"Unified_Ideograph", "Ideographic"},
    147020: {"Unified_Ideograph", "Ideographic"},
    147021: {"Unified_Ideograph", "Ideographic"},
    147022: {"Unified_Ideograph", "Ideographic"},
    147023: {"Unified_Ideograph", "Ideographic"},
    147024: {"Unified_Ideograph", "Ideographic"},
    147025: {"Unified_Ideograph", "Ideographic"},
    147026: {"Unified_Ideograph", "Ideographic"},
    147027: {"Unified_Ideograph", "Ideographic"},
    147028: {"Unified_Ideograph", "Ideographic"},
    147029: {"Unified_Ideograph", "Ideographic"},
    147030: {"Unified_Ideograph", "Ideographic"},
    147031: {"Unified_Ideograph", "Ideographic"},
    147032: {"Unified_Ideograph", "Ideographic"},
    147033: {"Unified_Ideograph", "Ideographic"},
    147034: {"Unified_Ideograph", "Ideographic"},
    147035: {"Unified_Ideograph", "Ideographic"},
    147036: {"Unified_Ideograph", "Ideographic"},
    147037: {"Unified_Ideograph", "Ideographic"},
    147038: {"Unified_Ideograph", "Ideographic"},
    147039: {"Unified_Ideograph", "Ideographic"},
    147040: {"Unified_Ideograph", "Ideographic"},
    147041: {"Unified_Ideograph", "Ideographic"},
    147042: {"Unified_Ideograph", "Ideographic"},
    147043: {"Unified_Ideograph", "Ideographic"},
    147044: {"Unified_Ideograph", "Ideographic"},
    147045: {"Unified_Ideograph", "Ideographic"},
    147046: {"Unified_Ideograph", "Ideographic"},
    147047: {"Unified_Ideograph", "Ideographic"},
    147048: {"Unified_Ideograph", "Ideographic"},
    147049: {"Unified_Ideograph", "Ideographic"},
    147050: {"Unified_Ideograph", "Ideographic"},
    147051: {"Unified_Ideograph", "Ideographic"},
    147052: {"Unified_Ideograph", "Ideographic"},
    147053: {"Unified_Ideograph", "Ideographic"},
    147054: {"Unified_Ideograph", "Ideographic"},
    147055: {"Unified_Ideograph", "Ideographic"},
    147056: {"Unified_Ideograph", "Ideographic"},
    147057: {"Unified_Ideograph", "Ideographic"},
    147058: {"Unified_Ideograph", "Ideographic"},
    147059: {"Unified_Ideograph", "Ideographic"},
    147060: {"Unified_Ideograph", "Ideographic"},
    147061: {"Unified_Ideograph", "Ideographic"},
    147062: {"Unified_Ideograph", "Ideographic"},
    147063: {"Unified_Ideograph", "Ideographic"},
    147064: {"Unified_Ideograph", "Ideographic"},
    147065: {"Unified_Ideograph", "Ideographic"},
    147066: {"Unified_Ideograph", "Ideographic"},
    147067: {"Unified_Ideograph", "Ideographic"},
    147068: {"Unified_Ideograph", "Ideographic"},
    147069: {"Unified_Ideograph", "Ideographic"},
    147070: {"Unified_Ideograph", "Ideographic"},
    147071: {"Unified_Ideograph", "Ideographic"},
    147072: {"Unified_Ideograph", "Ideographic"},
    147073: {"Unified_Ideograph", "Ideographic"},
    147074: {"Unified_Ideograph", "Ideographic"},
    147075: {"Unified_Ideograph", "Ideographic"},
    147076: {"Unified_Ideograph", "Ideographic"},
    147077: {"Unified_Ideograph", "Ideographic"},
    147078: {"Unified_Ideograph", "Ideographic"},
    147079: {"Unified_Ideograph", "Ideographic"},
    147080: {"Unified_Ideograph", "Ideographic"},
    147081: {"Unified_Ideograph", "Ideographic"},
    147082: {"Unified_Ideograph", "Ideographic"},
    147083: {"Unified_Ideograph", "Ideographic"},
    147084: {"Unified_Ideograph", "Ideographic"},
    147085: {"Unified_Ideograph", "Ideographic"},
    147086: {"Unified_Ideograph", "Ideographic"},
    147087: {"Unified_Ideograph", "Ideographic"},
    147088: {"Unified_Ideograph", "Ideographic"},
    147089: {"Unified_Ideograph", "Ideographic"},
    147090: {"Unified_Ideograph", "Ideographic"},
    147091: {"Unified_Ideograph", "Ideographic"},
    147092: {"Unified_Ideograph", "Ideographic"},
    147093: {"Unified_Ideograph", "Ideographic"},
    147094: {"Unified_Ideograph", "Ideographic"},
    147095: {"Unified_Ideograph", "Ideographic"},
    147096: {"Unified_Ideograph", "Ideographic"},
    147097: {"Unified_Ideograph", "Ideographic"},
    147098: {"Unified_Ideograph", "Ideographic"},
    147099: {"Unified_Ideograph", "Ideographic"},
    147100: {"Unified_Ideograph", "Ideographic"},
    147101: {"Unified_Ideograph", "Ideographic"},
    147102: {"Unified_Ideograph", "Ideographic"},
    147103: {"Unified_Ideograph", "Ideographic"},
    147104: {"Unified_Ideograph", "Ideographic"},
    147105: {"Unified_Ideograph", "Ideographic"},
    147106: {"Unified_Ideograph", "Ideographic"},
    147107: {"Unified_Ideograph", "Ideographic"},
    147108: {"Unified_Ideograph", "Ideographic"},
    147109: {"Unified_Ideograph", "Ideographic"},
    147110: {"Unified_Ideograph", "Ideographic"},
    147111: {"Unified_Ideograph", "Ideographic"},
    147112: {"Unified_Ideograph", "Ideographic"},
    147113: {"Unified_Ideograph", "Ideographic"},
    147114: {"Unified_Ideograph", "Ideographic"},
    147115: {"Unified_Ideograph", "Ideographic"},
    147116: {"Unified_Ideograph", "Ideographic"},
    147117: {"Unified_Ideograph", "Ideographic"},
    147118: {"Unified_Ideograph", "Ideographic"},
    147119: {"Unified_Ideograph", "Ideographic"},
    147120: {"Unified_Ideograph", "Ideographic"},
    147121: {"Unified_Ideograph", "Ideographic"},
    147122: {"Unified_Ideograph", "Ideographic"},
    147123: {"Unified_Ideograph", "Ideographic"},
    147124: {"Unified_Ideograph", "Ideographic"},
    147125: {"Unified_Ideograph", "Ideographic"},
    147126: {"Unified_Ideograph", "Ideographic"},
    147127: {"Unified_Ideograph", "Ideographic"},
    147128: {"Unified_Ideograph", "Ideographic"},
    147129: {"Unified_Ideograph", "Ideographic"},
    147130: {"Unified_Ideograph", "Ideographic"},
    147131: {"Unified_Ideograph", "Ideographic"},
    147132: {"Unified_Ideograph", "Ideographic"},
    147133: {"Unified_Ideograph", "Ideographic"},
    147134: {"Unified_Ideograph", "Ideographic"},
    147135: {"Unified_Ideograph", "Ideographic"},
    147136: {"Unified_Ideograph", "Ideographic"},
    147137: {"Unified_Ideograph", "Ideographic"},
    147138: {"Unified_Ideograph", "Ideographic"},
    147139: {"Unified_Ideograph", "Ideographic"},
    147140: {"Unified_Ideograph", "Ideographic"},
    147141: {"Unified_Ideograph", "Ideographic"},
    147142: {"Unified_Ideograph", "Ideographic"},
    147143: {"Unified_Ideograph", "Ideographic"},
    147144: {"Unified_Ideograph", "Ideographic"},
    147145: {"Unified_Ideograph", "Ideographic"},
    147146: {"Unified_Ideograph", "Ideographic"},
    147147: {"Unified_Ideograph", "Ideographic"},
    147148: {"Unified_Ideograph", "Ideographic"},
    147149: {"Unified_Ideograph", "Ideographic"},
    147150: {"Unified_Ideograph", "Ideographic"},
    147151: {"Unified_Ideograph", "Ideographic"},
    147152: {"Unified_Ideograph", "Ideographic"},
    147153: {"Unified_Ideograph", "Ideographic"},
    147154: {"Unified_Ideograph", "Ideographic"},
    147155: {"Unified_Ideograph", "Ideographic"},
    147156: {"Unified_Ideograph", "Ideographic"},
    147157: {"Unified_Ideograph", "Ideographic"},
    147158: {"Unified_Ideograph", "Ideographic"},
    147159: {"Unified_Ideograph", "Ideographic"},
    147160: {"Unified_Ideograph", "Ideographic"},
    147161: {"Unified_Ideograph", "Ideographic"},
    147162: {"Unified_Ideograph", "Ideographic"},
    147163: {"Unified_Ideograph", "Ideographic"},
    147164: {"Unified_Ideograph", "Ideographic"},
    147165: {"Unified_Ideograph", "Ideographic"},
    147166: {"Unified_Ideograph", "Ideographic"},
    147167: {"Unified_Ideograph", "Ideographic"},
    147168: {"Unified_Ideograph", "Ideographic"},
    147169: {"Unified_Ideograph", "Ideographic"},
    147170: {"Unified_Ideograph", "Ideographic"},
    147171: {"Unified_Ideograph", "Ideographic"},
    147172: {"Unified_Ideograph", "Ideographic"},
    147173: {"Unified_Ideograph", "Ideographic"},
    147174: {"Unified_Ideograph", "Ideographic"},
    147175: {"Unified_Ideograph", "Ideographic"},
    147176: {"Unified_Ideograph", "Ideographic"},
    147177: {"Unified_Ideograph", "Ideographic"},
    147178: {"Unified_Ideograph", "Ideographic"},
    147179: {"Unified_Ideograph", "Ideographic"},
    147180: {"Unified_Ideograph", "Ideographic"},
    147181: {"Unified_Ideograph", "Ideographic"},
    147182: {"Unified_Ideograph", "Ideographic"},
    147183: {"Unified_Ideograph", "Ideographic"},
    147184: {"Unified_Ideograph", "Ideographic"},
    147185: {"Unified_Ideograph", "Ideographic"},
    147186: {"Unified_Ideograph", "Ideographic"},
    147187: {"Unified_Ideograph", "Ideographic"},
    147188: {"Unified_Ideograph", "Ideographic"},
    147189: {"Unified_Ideograph", "Ideographic"},
    147190: {"Unified_Ideograph", "Ideographic"},
    147191: {"Unified_Ideograph", "Ideographic"},
    147192: {"Unified_Ideograph", "Ideographic"},
    147193: {"Unified_Ideograph", "Ideographic"},
    147194: {"Unified_Ideograph", "Ideographic"},
    147195: {"Unified_Ideograph", "Ideographic"},
    147196: {"Unified_Ideograph", "Ideographic"},
    147197: {"Unified_Ideograph", "Ideographic"},
    147198: {"Unified_Ideograph", "Ideographic"},
    147199: {"Unified_Ideograph", "Ideographic"},
    147200: {"Unified_Ideograph", "Ideographic"},
    147201: {"Unified_Ideograph", "Ideographic"},
    147202: {"Unified_Ideograph", "Ideographic"},
    147203: {"Unified_Ideograph", "Ideographic"},
    147204: {"Unified_Ideograph", "Ideographic"},
    147205: {"Unified_Ideograph", "Ideographic"},
    147206: {"Unified_Ideograph", "Ideographic"},
    147207: {"Unified_Ideograph", "Ideographic"},
    147208: {"Unified_Ideograph", "Ideographic"},
    147209: {"Unified_Ideograph", "Ideographic"},
    147210: {"Unified_Ideograph", "Ideographic"},
    147211: {"Unified_Ideograph", "Ideographic"},
    147212: {"Unified_Ideograph", "Ideographic"},
    147213: {"Unified_Ideograph", "Ideographic"},
    147214: {"Unified_Ideograph", "Ideographic"},
    147215: {"Unified_Ideograph", "Ideographic"},
    147216: {"Unified_Ideograph", "Ideographic"},
    147217: {"Unified_Ideograph", "Ideographic"},
    147218: {"Unified_Ideograph", "Ideographic"},
    147219: {"Unified_Ideograph", "Ideographic"},
    147220: {"Unified_Ideograph", "Ideographic"},
    147221: {"Unified_Ideograph", "Ideographic"},
    147222: {"Unified_Ideograph", "Ideographic"},
    147223: {"Unified_Ideograph", "Ideographic"},
    147224: {"Unified_Ideograph", "Ideographic"},
    147225: {"Unified_Ideograph", "Ideographic"},
    147226: {"Unified_Ideograph", "Ideographic"},
    147227: {"Unified_Ideograph", "Ideographic"},
    147228: {"Unified_Ideograph", "Ideographic"},
    147229: {"Unified_Ideograph", "Ideographic"},
    147230: {"Unified_Ideograph", "Ideographic"},
    147231: {"Unified_Ideograph", "Ideographic"},
    147232: {"Unified_Ideograph", "Ideographic"},
    147233: {"Unified_Ideograph", "Ideographic"},
    147234: {"Unified_Ideograph", "Ideographic"},
    147235: {"Unified_Ideograph", "Ideographic"},
    147236: {"Unified_Ideograph", "Ideographic"},
    147237: {"Unified_Ideograph", "Ideographic"},
    147238: {"Unified_Ideograph", "Ideographic"},
    147239: {"Unified_Ideograph", "Ideographic"},
    147240: {"Unified_Ideograph", "Ideographic"},
    147241: {"Unified_Ideograph", "Ideographic"},
    147242: {"Unified_Ideograph", "Ideographic"},
    147243: {"Unified_Ideograph", "Ideographic"},
    147244: {"Unified_Ideograph", "Ideographic"},
    147245: {"Unified_Ideograph", "Ideographic"},
    147246: {"Unified_Ideograph", "Ideographic"},
    147247: {"Unified_Ideograph", "Ideographic"},
    147248: {"Unified_Ideograph", "Ideographic"},
    147249: {"Unified_Ideograph", "Ideographic"},
    147250: {"Unified_Ideograph", "Ideographic"},
    147251: {"Unified_Ideograph", "Ideographic"},
    147252: {"Unified_Ideograph", "Ideographic"},
    147253: {"Unified_Ideograph", "Ideographic"},
    147254: {"Unified_Ideograph", "Ideographic"},
    147255: {"Unified_Ideograph", "Ideographic"},
    147256: {"Unified_Ideograph", "Ideographic"},
    147257: {"Unified_Ideograph", "Ideographic"},
    147258: {"Unified_Ideograph", "Ideographic"},
    147259: {"Unified_Ideograph", "Ideographic"},
    147260: {"Unified_Ideograph", "Ideographic"},
    147261: {"Unified_Ideograph", "Ideographic"},
    147262: {"Unified_Ideograph", "Ideographic"},
    147263: {"Unified_Ideograph", "Ideographic"},
    147264: {"Unified_Ideograph", "Ideographic"},
    147265: {"Unified_Ideograph", "Ideographic"},
    147266: {"Unified_Ideograph", "Ideographic"},
    147267: {"Unified_Ideograph", "Ideographic"},
    147268: {"Unified_Ideograph", "Ideographic"},
    147269: {"Unified_Ideograph", "Ideographic"},
    147270: {"Unified_Ideograph", "Ideographic"},
    147271: {"Unified_Ideograph", "Ideographic"},
    147272: {"Unified_Ideograph", "Ideographic"},
    147273: {"Unified_Ideograph", "Ideographic"},
    147274: {"Unified_Ideograph", "Ideographic"},
    147275: {"Unified_Ideograph", "Ideographic"},
    147276: {"Unified_Ideograph", "Ideographic"},
    147277: {"Unified_Ideograph", "Ideographic"},
    147278: {"Unified_Ideograph", "Ideographic"},
    147279: {"Unified_Ideograph", "Ideographic"},
    147280: {"Unified_Ideograph", "Ideographic"},
    147281: {"Unified_Ideograph", "Ideographic"},
    147282: {"Unified_Ideograph", "Ideographic"},
    147283: {"Unified_Ideograph", "Ideographic"},
    147284: {"Unified_Ideograph", "Ideographic"},
    147285: {"Unified_Ideograph", "Ideographic"},
    147286: {"Unified_Ideograph", "Ideographic"},
    147287: {"Unified_Ideograph", "Ideographic"},
    147288: {"Unified_Ideograph", "Ideographic"},
    147289: {"Unified_Ideograph", "Ideographic"},
    147290: {"Unified_Ideograph", "Ideographic"},
    147291: {"Unified_Ideograph", "Ideographic"},
    147292: {"Unified_Ideograph", "Ideographic"},
    147293: {"Unified_Ideograph", "Ideographic"},
    147294: {"Unified_Ideograph", "Ideographic"},
    147295: {"Unified_Ideograph", "Ideographic"},
    147296: {"Unified_Ideograph", "Ideographic"},
    147297: {"Unified_Ideograph", "Ideographic"},
    147298: {"Unified_Ideograph", "Ideographic"},
    147299: {"Unified_Ideograph", "Ideographic"},
    147300: {"Unified_Ideograph", "Ideographic"},
    147301: {"Unified_Ideograph", "Ideographic"},
    147302: {"Unified_Ideograph", "Ideographic"},
    147303: {"Unified_Ideograph", "Ideographic"},
    147304: {"Unified_Ideograph", "Ideographic"},
    147305: {"Unified_Ideograph", "Ideographic"},
    147306: {"Unified_Ideograph", "Ideographic"},
    147307: {"Unified_Ideograph", "Ideographic"},
    147308: {"Unified_Ideograph", "Ideographic"},
    147309: {"Unified_Ideograph", "Ideographic"},
    147310: {"Unified_Ideograph", "Ideographic"},
    147311: {"Unified_Ideograph", "Ideographic"},
    147312: {"Unified_Ideograph", "Ideographic"},
    147313: {"Unified_Ideograph", "Ideographic"},
    147314: {"Unified_Ideograph", "Ideographic"},
    147315: {"Unified_Ideograph", "Ideographic"},
    147316: {"Unified_Ideograph", "Ideographic"},
    147317: {"Unified_Ideograph", "Ideographic"},
    147318: {"Unified_Ideograph", "Ideographic"},
    147319: {"Unified_Ideograph", "Ideographic"},
    147320: {"Unified_Ideograph", "Ideographic"},
    147321: {"Unified_Ideograph", "Ideographic"},
    147322: {"Unified_Ideograph", "Ideographic"},
    147323: {"Unified_Ideograph", "Ideographic"},
    147324: {"Unified_Ideograph", "Ideographic"},
    147325: {"Unified_Ideograph", "Ideographic"},
    147326: {"Unified_Ideograph", "Ideographic"},
    147327: {"Unified_Ideograph", "Ideographic"},
    147328: {"Unified_Ideograph", "Ideographic"},
    147329: {"Unified_Ideograph", "Ideographic"},
    147330: {"Unified_Ideograph", "Ideographic"},
    147331: {"Unified_Ideograph", "Ideographic"},
    147332: {"Unified_Ideograph", "Ideographic"},
    147333: {"Unified_Ideograph", "Ideographic"},
    147334: {"Unified_Ideograph", "Ideographic"},
    147335: {"Unified_Ideograph", "Ideographic"},
    147336: {"Unified_Ideograph", "Ideographic"},
    147337: {"Unified_Ideograph", "Ideographic"},
    147338: {"Unified_Ideograph", "Ideographic"},
    147339: {"Unified_Ideograph", "Ideographic"},
    147340: {"Unified_Ideograph", "Ideographic"},
    147341: {"Unified_Ideograph", "Ideographic"},
    147342: {"Unified_Ideograph", "Ideographic"},
    147343: {"Unified_Ideograph", "Ideographic"},
    147344: {"Unified_Ideograph", "Ideographic"},
    147345: {"Unified_Ideograph", "Ideographic"},
    147346: {"Unified_Ideograph", "Ideographic"},
    147347: {"Unified_Ideograph", "Ideographic"},
    147348: {"Unified_Ideograph", "Ideographic"},
    147349: {"Unified_Ideograph", "Ideographic"},
    147350: {"Unified_Ideograph", "Ideographic"},
    147351: {"Unified_Ideograph", "Ideographic"},
    147352: {"Unified_Ideograph", "Ideographic"},
    147353: {"Unified_Ideograph", "Ideographic"},
    147354: {"Unified_Ideograph", "Ideographic"},
    147355: {"Unified_Ideograph", "Ideographic"},
    147356: {"Unified_Ideograph", "Ideographic"},
    147357: {"Unified_Ideograph", "Ideographic"},
    147358: {"Unified_Ideograph", "Ideographic"},
    147359: {"Unified_Ideograph", "Ideographic"},
    147360: {"Unified_Ideograph", "Ideographic"},
    147361: {"Unified_Ideograph", "Ideographic"},
    147362: {"Unified_Ideograph", "Ideographic"},
    147363: {"Unified_Ideograph", "Ideographic"},
    147364: {"Unified_Ideograph", "Ideographic"},
    147365: {"Unified_Ideograph", "Ideographic"},
    147366: {"Unified_Ideograph", "Ideographic"},
    147367: {"Unified_Ideograph", "Ideographic"},
    147368: {"Unified_Ideograph", "Ideographic"},
    147369: {"Unified_Ideograph", "Ideographic"},
    147370: {"Unified_Ideograph", "Ideographic"},
    147371: {"Unified_Ideograph", "Ideographic"},
    147372: {"Unified_Ideograph", "Ideographic"},
    147373: {"Unified_Ideograph", "Ideographic"},
    147374: {"Unified_Ideograph", "Ideographic"},
    147375: {"Unified_Ideograph", "Ideographic"},
    147376: {"Unified_Ideograph", "Ideographic"},
    147377: {"Unified_Ideograph", "Ideographic"},
    147378: {"Unified_Ideograph", "Ideographic"},
    147379: {"Unified_Ideograph", "Ideographic"},
    147380: {"Unified_Ideograph", "Ideographic"},
    147381: {"Unified_Ideograph", "Ideographic"},
    147382: {"Unified_Ideograph", "Ideographic"},
    147383: {"Unified_Ideograph", "Ideographic"},
    147384: {"Unified_Ideograph", "Ideographic"},
    147385: {"Unified_Ideograph", "Ideographic"},
    147386: {"Unified_Ideograph", "Ideographic"},
    147387: {"Unified_Ideograph", "Ideographic"},
    147388: {"Unified_Ideograph", "Ideographic"},
    147389: {"Unified_Ideograph", "Ideographic"},
    147390: {"Unified_Ideograph", "Ideographic"},
    147391: {"Unified_Ideograph", "Ideographic"},
    147392: {"Unified_Ideograph", "Ideographic"},
    147393: {"Unified_Ideograph", "Ideographic"},
    147394: {"Unified_Ideograph", "Ideographic"},
    147395: {"Unified_Ideograph", "Ideographic"},
    147396: {"Unified_Ideograph", "Ideographic"},
    147397: {"Unified_Ideograph", "Ideographic"},
    147398: {"Unified_Ideograph", "Ideographic"},
    147399: {"Unified_Ideograph", "Ideographic"},
    147400: {"Unified_Ideograph", "Ideographic"},
    147401: {"Unified_Ideograph", "Ideographic"},
    147402: {"Unified_Ideograph", "Ideographic"},
    147403: {"Unified_Ideograph", "Ideographic"},
    147404: {"Unified_Ideograph", "Ideographic"},
    147405: {"Unified_Ideograph", "Ideographic"},
    147406: {"Unified_Ideograph", "Ideographic"},
    147407: {"Unified_Ideograph", "Ideographic"},
    147408: {"Unified_Ideograph", "Ideographic"},
    147409: {"Unified_Ideograph", "Ideographic"},
    147410: {"Unified_Ideograph", "Ideographic"},
    147411: {"Unified_Ideograph", "Ideographic"},
    147412: {"Unified_Ideograph", "Ideographic"},
    147413: {"Unified_Ideograph", "Ideographic"},
    147414: {"Unified_Ideograph", "Ideographic"},
    147415: {"Unified_Ideograph", "Ideographic"},
    147416: {"Unified_Ideograph", "Ideographic"},
    147417: {"Unified_Ideograph", "Ideographic"},
    147418: {"Unified_Ideograph", "Ideographic"},
    147419: {"Unified_Ideograph", "Ideographic"},
    147420: {"Unified_Ideograph", "Ideographic"},
    147421: {"Unified_Ideograph", "Ideographic"},
    147422: {"Unified_Ideograph", "Ideographic"},
    147423: {"Unified_Ideograph", "Ideographic"},
    147424: {"Unified_Ideograph", "Ideographic"},
    147425: {"Unified_Ideograph", "Ideographic"},
    147426: {"Unified_Ideograph", "Ideographic"},
    147427: {"Unified_Ideograph", "Ideographic"},
    147428: {"Unified_Ideograph", "Ideographic"},
    147429: {"Unified_Ideograph", "Ideographic"},
    147430: {"Unified_Ideograph", "Ideographic"},
    147431: {"Unified_Ideograph", "Ideographic"},
    147432: {"Unified_Ideograph", "Ideographic"},
    147433: {"Unified_Ideograph", "Ideographic"},
    147434: {"Unified_Ideograph", "Ideographic"},
    147435: {"Unified_Ideograph", "Ideographic"},
    147436: {"Unified_Ideograph", "Ideographic"},
    147437: {"Unified_Ideograph", "Ideographic"},
    147438: {"Unified_Ideograph", "Ideographic"},
    147439: {"Unified_Ideograph", "Ideographic"},
    147440: {"Unified_Ideograph", "Ideographic"},
    147441: {"Unified_Ideograph", "Ideographic"},
    147442: {"Unified_Ideograph", "Ideographic"},
    147443: {"Unified_Ideograph", "Ideographic"},
    147444: {"Unified_Ideograph", "Ideographic"},
    147445: {"Unified_Ideograph", "Ideographic"},
    147446: {"Unified_Ideograph", "Ideographic"},
    147447: {"Unified_Ideograph", "Ideographic"},
    147448: {"Unified_Ideograph", "Ideographic"},
    147449: {"Unified_Ideograph", "Ideographic"},
    147450: {"Unified_Ideograph", "Ideographic"},
    147451: {"Unified_Ideograph", "Ideographic"},
    147452: {"Unified_Ideograph", "Ideographic"},
    147453: {"Unified_Ideograph", "Ideographic"},
    147454: {"Unified_Ideograph", "Ideographic"},
    147455: {"Unified_Ideograph", "Ideographic"},
    147456: {"Unified_Ideograph", "Ideographic"},
    147457: {"Unified_Ideograph", "Ideographic"},
    147458: {"Unified_Ideograph", "Ideographic"},
    147459: {"Unified_Ideograph", "Ideographic"},
    147460: {"Unified_Ideograph", "Ideographic"},
    147461: {"Unified_Ideograph", "Ideographic"},
    147462: {"Unified_Ideograph", "Ideographic"},
    147463: {"Unified_Ideograph", "Ideographic"},
    147464: {"Unified_Ideograph", "Ideographic"},
    147465: {"Unified_Ideograph", "Ideographic"},
    147466: {"Unified_Ideograph", "Ideographic"},
    147467: {"Unified_Ideograph", "Ideographic"},
    147468: {"Unified_Ideograph", "Ideographic"},
    147469: {"Unified_Ideograph", "Ideographic"},
    147470: {"Unified_Ideograph", "Ideographic"},
    147471: {"Unified_Ideograph", "Ideographic"},
    147472: {"Unified_Ideograph", "Ideographic"},
    147473: {"Unified_Ideograph", "Ideographic"},
    147474: {"Unified_Ideograph", "Ideographic"},
    147475: {"Unified_Ideograph", "Ideographic"},
    147476: {"Unified_Ideograph", "Ideographic"},
    147477: {"Unified_Ideograph", "Ideographic"},
    147478: {"Unified_Ideograph", "Ideographic"},
    147479: {"Unified_Ideograph", "Ideographic"},
    147480: {"Unified_Ideograph", "Ideographic"},
    147481: {"Unified_Ideograph", "Ideographic"},
    147482: {"Unified_Ideograph", "Ideographic"},
    147483: {"Unified_Ideograph", "Ideographic"},
    147484: {"Unified_Ideograph", "Ideographic"},
    147485: {"Unified_Ideograph", "Ideographic"},
    147486: {"Unified_Ideograph", "Ideographic"},
    147487: {"Unified_Ideograph", "Ideographic"},
    147488: {"Unified_Ideograph", "Ideographic"},
    147489: {"Unified_Ideograph", "Ideographic"},
    147490: {"Unified_Ideograph", "Ideographic"},
    147491: {"Unified_Ideograph", "Ideographic"},
    147492: {"Unified_Ideograph", "Ideographic"},
    147493: {"Unified_Ideograph", "Ideographic"},
    147494: {"Unified_Ideograph", "Ideographic"},
    147495: {"Unified_Ideograph", "Ideographic"},
    147496: {"Unified_Ideograph", "Ideographic"},
    147497: {"Unified_Ideograph", "Ideographic"},
    147498: {"Unified_Ideograph", "Ideographic"},
    147499: {"Unified_Ideograph", "Ideographic"},
    147500: {"Unified_Ideograph", "Ideographic"},
    147501: {"Unified_Ideograph", "Ideographic"},
    147502: {"Unified_Ideograph", "Ideographic"},
    147503: {"Unified_Ideograph", "Ideographic"},
    147504: {"Unified_Ideograph", "Ideographic"},
    147505: {"Unified_Ideograph", "Ideographic"},
    147506: {"Unified_Ideograph", "Ideographic"},
    147507: {"Unified_Ideograph", "Ideographic"},
    147508: {"Unified_Ideograph", "Ideographic"},
    147509: {"Unified_Ideograph", "Ideographic"},
    147510: {"Unified_Ideograph", "Ideographic"},
    147511: {"Unified_Ideograph", "Ideographic"},
    147512: {"Unified_Ideograph", "Ideographic"},
    147513: {"Unified_Ideograph", "Ideographic"},
    147514: {"Unified_Ideograph", "Ideographic"},
    147515: {"Unified_Ideograph", "Ideographic"},
    147516: {"Unified_Ideograph", "Ideographic"},
    147517: {"Unified_Ideograph", "Ideographic"},
    147518: {"Unified_Ideograph", "Ideographic"},
    147519: {"Unified_Ideograph", "Ideographic"},
    147520: {"Unified_Ideograph", "Ideographic"},
    147521: {"Unified_Ideograph", "Ideographic"},
    147522: {"Unified_Ideograph", "Ideographic"},
    147523: {"Unified_Ideograph", "Ideographic"},
    147524: {"Unified_Ideograph", "Ideographic"},
    147525: {"Unified_Ideograph", "Ideographic"},
    147526: {"Unified_Ideograph", "Ideographic"},
    147527: {"Unified_Ideograph", "Ideographic"},
    147528: {"Unified_Ideograph", "Ideographic"},
    147529: {"Unified_Ideograph", "Ideographic"},
    147530: {"Unified_Ideograph", "Ideographic"},
    147531: {"Unified_Ideograph", "Ideographic"},
    147532: {"Unified_Ideograph", "Ideographic"},
    147533: {"Unified_Ideograph", "Ideographic"},
    147534: {"Unified_Ideograph", "Ideographic"},
    147535: {"Unified_Ideograph", "Ideographic"},
    147536: {"Unified_Ideograph", "Ideographic"},
    147537: {"Unified_Ideograph", "Ideographic"},
    147538: {"Unified_Ideograph", "Ideographic"},
    147539: {"Unified_Ideograph", "Ideographic"},
    147540: {"Unified_Ideograph", "Ideographic"},
    147541: {"Unified_Ideograph", "Ideographic"},
    147542: {"Unified_Ideograph", "Ideographic"},
    147543: {"Unified_Ideograph", "Ideographic"},
    147544: {"Unified_Ideograph", "Ideographic"},
    147545: {"Unified_Ideograph", "Ideographic"},
    147546: {"Unified_Ideograph", "Ideographic"},
    147547: {"Unified_Ideograph", "Ideographic"},
    147548: {"Unified_Ideograph", "Ideographic"},
    147549: {"Unified_Ideograph", "Ideographic"},
    147550: {"Unified_Ideograph", "Ideographic"},
    147551: {"Unified_Ideograph", "Ideographic"},
    147552: {"Unified_Ideograph", "Ideographic"},
    147553: {"Unified_Ideograph", "Ideographic"},
    147554: {"Unified_Ideograph", "Ideographic"},
    147555: {"Unified_Ideograph", "Ideographic"},
    147556: {"Unified_Ideograph", "Ideographic"},
    147557: {"Unified_Ideograph", "Ideographic"},
    147558: {"Unified_Ideograph", "Ideographic"},
    147559: {"Unified_Ideograph", "Ideographic"},
    147560: {"Unified_Ideograph", "Ideographic"},
    147561: {"Unified_Ideograph", "Ideographic"},
    147562: {"Unified_Ideograph", "Ideographic"},
    147563: {"Unified_Ideograph", "Ideographic"},
    147564: {"Unified_Ideograph", "Ideographic"},
    147565: {"Unified_Ideograph", "Ideographic"},
    147566: {"Unified_Ideograph", "Ideographic"},
    147567: {"Unified_Ideograph", "Ideographic"},
    147568: {"Unified_Ideograph", "Ideographic"},
    147569: {"Unified_Ideograph", "Ideographic"},
    147570: {"Unified_Ideograph", "Ideographic"},
    147571: {"Unified_Ideograph", "Ideographic"},
    147572: {"Unified_Ideograph", "Ideographic"},
    147573: {"Unified_Ideograph", "Ideographic"},
    147574: {"Unified_Ideograph", "Ideographic"},
    147575: {"Unified_Ideograph", "Ideographic"},
    147576: {"Unified_Ideograph", "Ideographic"},
    147577: {"Unified_Ideograph", "Ideographic"},
    147578: {"Unified_Ideograph", "Ideographic"},
    147579: {"Unified_Ideograph", "Ideographic"},
    147580: {"Unified_Ideograph", "Ideographic"},
    147581: {"Unified_Ideograph", "Ideographic"},
    147582: {"Unified_Ideograph", "Ideographic"},
    147583: {"Unified_Ideograph", "Ideographic"},
    147584: {"Unified_Ideograph", "Ideographic"},
    147585: {"Unified_Ideograph", "Ideographic"},
    147586: {"Unified_Ideograph", "Ideographic"},
    147587: {"Unified_Ideograph", "Ideographic"},
    147588: {"Unified_Ideograph", "Ideographic"},
    147589: {"Unified_Ideograph", "Ideographic"},
    147590: {"Unified_Ideograph", "Ideographic"},
    147591: {"Unified_Ideograph", "Ideographic"},
    147592: {"Unified_Ideograph", "Ideographic"},
    147593: {"Unified_Ideograph", "Ideographic"},
    147594: {"Unified_Ideograph", "Ideographic"},
    147595: {"Unified_Ideograph", "Ideographic"},
    147596: {"Unified_Ideograph", "Ideographic"},
    147597: {"Unified_Ideograph", "Ideographic"},
    147598: {"Unified_Ideograph", "Ideographic"},
    147599: {"Unified_Ideograph", "Ideographic"},
    147600: {"Unified_Ideograph", "Ideographic"},
    147601: {"Unified_Ideograph", "Ideographic"},
    147602: {"Unified_Ideograph", "Ideographic"},
    147603: {"Unified_Ideograph", "Ideographic"},
    147604: {"Unified_Ideograph", "Ideographic"},
    147605: {"Unified_Ideograph", "Ideographic"},
    147606: {"Unified_Ideograph", "Ideographic"},
    147607: {"Unified_Ideograph", "Ideographic"},
    147608: {"Unified_Ideograph", "Ideographic"},
    147609: {"Unified_Ideograph", "Ideographic"},
    147610: {"Unified_Ideograph", "Ideographic"},
    147611: {"Unified_Ideograph", "Ideographic"},
    147612: {"Unified_Ideograph", "Ideographic"},
    147613: {"Unified_Ideograph", "Ideographic"},
    147614: {"Unified_Ideograph", "Ideographic"},
    147615: {"Unified_Ideograph", "Ideographic"},
    147616: {"Unified_Ideograph", "Ideographic"},
    147617: {"Unified_Ideograph", "Ideographic"},
    147618: {"Unified_Ideograph", "Ideographic"},
    147619: {"Unified_Ideograph", "Ideographic"},
    147620: {"Unified_Ideograph", "Ideographic"},
    147621: {"Unified_Ideograph", "Ideographic"},
    147622: {"Unified_Ideograph", "Ideographic"},
    147623: {"Unified_Ideograph", "Ideographic"},
    147624: {"Unified_Ideograph", "Ideographic"},
    147625: {"Unified_Ideograph", "Ideographic"},
    147626: {"Unified_Ideograph", "Ideographic"},
    147627: {"Unified_Ideograph", "Ideographic"},
    147628: {"Unified_Ideograph", "Ideographic"},
    147629: {"Unified_Ideograph", "Ideographic"},
    147630: {"Unified_Ideograph", "Ideographic"},
    147631: {"Unified_Ideograph", "Ideographic"},
    147632: {"Unified_Ideograph", "Ideographic"},
    147633: {"Unified_Ideograph", "Ideographic"},
    147634: {"Unified_Ideograph", "Ideographic"},
    147635: {"Unified_Ideograph", "Ideographic"},
    147636: {"Unified_Ideograph", "Ideographic"},
    147637: {"Unified_Ideograph", "Ideographic"},
    147638: {"Unified_Ideograph", "Ideographic"},
    147639: {"Unified_Ideograph", "Ideographic"},
    147640: {"Unified_Ideograph", "Ideographic"},
    147641: {"Unified_Ideograph", "Ideographic"},
    147642: {"Unified_Ideograph", "Ideographic"},
    147643: {"Unified_Ideograph", "Ideographic"},
    147644: {"Unified_Ideograph", "Ideographic"},
    147645: {"Unified_Ideograph", "Ideographic"},
    147646: {"Unified_Ideograph", "Ideographic"},
    147647: {"Unified_Ideograph", "Ideographic"},
    147648: {"Unified_Ideograph", "Ideographic"},
    147649: {"Unified_Ideograph", "Ideographic"},
    147650: {"Unified_Ideograph", "Ideographic"},
    147651: {"Unified_Ideograph", "Ideographic"},
    147652: {"Unified_Ideograph", "Ideographic"},
    147653: {"Unified_Ideograph", "Ideographic"},
    147654: {"Unified_Ideograph", "Ideographic"},
    147655: {"Unified_Ideograph", "Ideographic"},
    147656: {"Unified_Ideograph", "Ideographic"},
    147657: {"Unified_Ideograph", "Ideographic"},
    147658: {"Unified_Ideograph", "Ideographic"},
    147659: {"Unified_Ideograph", "Ideographic"},
    147660: {"Unified_Ideograph", "Ideographic"},
    147661: {"Unified_Ideograph", "Ideographic"},
    147662: {"Unified_Ideograph", "Ideographic"},
    147663: {"Unified_Ideograph", "Ideographic"},
    147664: {"Unified_Ideograph", "Ideographic"},
    147665: {"Unified_Ideograph", "Ideographic"},
    147666: {"Unified_Ideograph", "Ideographic"},
    147667: {"Unified_Ideograph", "Ideographic"},
    147668: {"Unified_Ideograph", "Ideographic"},
    147669: {"Unified_Ideograph", "Ideographic"},
    147670: {"Unified_Ideograph", "Ideographic"},
    147671: {"Unified_Ideograph", "Ideographic"},
    147672: {"Unified_Ideograph", "Ideographic"},
    147673: {"Unified_Ideograph", "Ideographic"},
    147674: {"Unified_Ideograph", "Ideographic"},
    147675: {"Unified_Ideograph", "Ideographic"},
    147676: {"Unified_Ideograph", "Ideographic"},
    147677: {"Unified_Ideograph", "Ideographic"},
    147678: {"Unified_Ideograph", "Ideographic"},
    147679: {"Unified_Ideograph", "Ideographic"},
    147680: {"Unified_Ideograph", "Ideographic"},
    147681: {"Unified_Ideograph", "Ideographic"},
    147682: {"Unified_Ideograph", "Ideographic"},
    147683: {"Unified_Ideograph", "Ideographic"},
    147684: {"Unified_Ideograph", "Ideographic"},
    147685: {"Unified_Ideograph", "Ideographic"},
    147686: {"Unified_Ideograph", "Ideographic"},
    147687: {"Unified_Ideograph", "Ideographic"},
    147688: {"Unified_Ideograph", "Ideographic"},
    147689: {"Unified_Ideograph", "Ideographic"},
    147690: {"Unified_Ideograph", "Ideographic"},
    147691: {"Unified_Ideograph", "Ideographic"},
    147692: {"Unified_Ideograph", "Ideographic"},
    147693: {"Unified_Ideograph", "Ideographic"},
    147694: {"Unified_Ideograph", "Ideographic"},
    147695: {"Unified_Ideograph", "Ideographic"},
    147696: {"Unified_Ideograph", "Ideographic"},
    147697: {"Unified_Ideograph", "Ideographic"},
    147698: {"Unified_Ideograph", "Ideographic"},
    147699: {"Unified_Ideograph", "Ideographic"},
    147700: {"Unified_Ideograph", "Ideographic"},
    147701: {"Unified_Ideograph", "Ideographic"},
    147702: {"Unified_Ideograph", "Ideographic"},
    147703: {"Unified_Ideograph", "Ideographic"},
    147704: {"Unified_Ideograph", "Ideographic"},
    147705: {"Unified_Ideograph", "Ideographic"},
    147706: {"Unified_Ideograph", "Ideographic"},
    147707: {"Unified_Ideograph", "Ideographic"},
    147708: {"Unified_Ideograph", "Ideographic"},
    147709: {"Unified_Ideograph", "Ideographic"},
    147710: {"Unified_Ideograph", "Ideographic"},
    147711: {"Unified_Ideograph", "Ideographic"},
    147712: {"Unified_Ideograph", "Ideographic"},
    147713: {"Unified_Ideograph", "Ideographic"},
    147714: {"Unified_Ideograph", "Ideographic"},
    147715: {"Unified_Ideograph", "Ideographic"},
    147716: {"Unified_Ideograph", "Ideographic"},
    147717: {"Unified_Ideograph", "Ideographic"},
    147718: {"Unified_Ideograph", "Ideographic"},
    147719: {"Unified_Ideograph", "Ideographic"},
    147720: {"Unified_Ideograph", "Ideographic"},
    147721: {"Unified_Ideograph", "Ideographic"},
    147722: {"Unified_Ideograph", "Ideographic"},
    147723: {"Unified_Ideograph", "Ideographic"},
    147724: {"Unified_Ideograph", "Ideographic"},
    147725: {"Unified_Ideograph", "Ideographic"},
    147726: {"Unified_Ideograph", "Ideographic"},
    147727: {"Unified_Ideograph", "Ideographic"},
    147728: {"Unified_Ideograph", "Ideographic"},
    147729: {"Unified_Ideograph", "Ideographic"},
    147730: {"Unified_Ideograph", "Ideographic"},
    147731: {"Unified_Ideograph", "Ideographic"},
    147732: {"Unified_Ideograph", "Ideographic"},
    147733: {"Unified_Ideograph", "Ideographic"},
    147734: {"Unified_Ideograph", "Ideographic"},
    147735: {"Unified_Ideograph", "Ideographic"},
    147736: {"Unified_Ideograph", "Ideographic"},
    147737: {"Unified_Ideograph", "Ideographic"},
    147738: {"Unified_Ideograph", "Ideographic"},
    147739: {"Unified_Ideograph", "Ideographic"},
    147740: {"Unified_Ideograph", "Ideographic"},
    147741: {"Unified_Ideograph", "Ideographic"},
    147742: {"Unified_Ideograph", "Ideographic"},
    147743: {"Unified_Ideograph", "Ideographic"},
    147744: {"Unified_Ideograph", "Ideographic"},
    147745: {"Unified_Ideograph", "Ideographic"},
    147746: {"Unified_Ideograph", "Ideographic"},
    147747: {"Unified_Ideograph", "Ideographic"},
    147748: {"Unified_Ideograph", "Ideographic"},
    147749: {"Unified_Ideograph", "Ideographic"},
    147750: {"Unified_Ideograph", "Ideographic"},
    147751: {"Unified_Ideograph", "Ideographic"},
    147752: {"Unified_Ideograph", "Ideographic"},
    147753: {"Unified_Ideograph", "Ideographic"},
    147754: {"Unified_Ideograph", "Ideographic"},
    147755: {"Unified_Ideograph", "Ideographic"},
    147756: {"Unified_Ideograph", "Ideographic"},
    147757: {"Unified_Ideograph", "Ideographic"},
    147758: {"Unified_Ideograph", "Ideographic"},
    147759: {"Unified_Ideograph", "Ideographic"},
    147760: {"Unified_Ideograph", "Ideographic"},
    147761: {"Unified_Ideograph", "Ideographic"},
    147762: {"Unified_Ideograph", "Ideographic"},
    147763: {"Unified_Ideograph", "Ideographic"},
    147764: {"Unified_Ideograph", "Ideographic"},
    147765: {"Unified_Ideograph", "Ideographic"},
    147766: {"Unified_Ideograph", "Ideographic"},
    147767: {"Unified_Ideograph", "Ideographic"},
    147768: {"Unified_Ideograph", "Ideographic"},
    147769: {"Unified_Ideograph", "Ideographic"},
    147770: {"Unified_Ideograph", "Ideographic"},
    147771: {"Unified_Ideograph", "Ideographic"},
    147772: {"Unified_Ideograph", "Ideographic"},
    147773: {"Unified_Ideograph", "Ideographic"},
    147774: {"Unified_Ideograph", "Ideographic"},
    147775: {"Unified_Ideograph", "Ideographic"},
    147776: {"Unified_Ideograph", "Ideographic"},
    147777: {"Unified_Ideograph", "Ideographic"},
    147778: {"Unified_Ideograph", "Ideographic"},
    147779: {"Unified_Ideograph", "Ideographic"},
    147780: {"Unified_Ideograph", "Ideographic"},
    147781: {"Unified_Ideograph", "Ideographic"},
    147782: {"Unified_Ideograph", "Ideographic"},
    147783: {"Unified_Ideograph", "Ideographic"},
    147784: {"Unified_Ideograph", "Ideographic"},
    147785: {"Unified_Ideograph", "Ideographic"},
    147786: {"Unified_Ideograph", "Ideographic"},
    147787: {"Unified_Ideograph", "Ideographic"},
    147788: {"Unified_Ideograph", "Ideographic"},
    147789: {"Unified_Ideograph", "Ideographic"},
    147790: {"Unified_Ideograph", "Ideographic"},
    147791: {"Unified_Ideograph", "Ideographic"},
    147792: {"Unified_Ideograph", "Ideographic"},
    147793: {"Unified_Ideograph", "Ideographic"},
    147794: {"Unified_Ideograph", "Ideographic"},
    147795: {"Unified_Ideograph", "Ideographic"},
    147796: {"Unified_Ideograph", "Ideographic"},
    147797: {"Unified_Ideograph", "Ideographic"},
    147798: {"Unified_Ideograph", "Ideographic"},
    147799: {"Unified_Ideograph", "Ideographic"},
    147800: {"Unified_Ideograph", "Ideographic"},
    147801: {"Unified_Ideograph", "Ideographic"},
    147802: {"Unified_Ideograph", "Ideographic"},
    147803: {"Unified_Ideograph", "Ideographic"},
    147804: {"Unified_Ideograph", "Ideographic"},
    147805: {"Unified_Ideograph", "Ideographic"},
    147806: {"Unified_Ideograph", "Ideographic"},
    147807: {"Unified_Ideograph", "Ideographic"},
    147808: {"Unified_Ideograph", "Ideographic"},
    147809: {"Unified_Ideograph", "Ideographic"},
    147810: {"Unified_Ideograph", "Ideographic"},
    147811: {"Unified_Ideograph", "Ideographic"},
    147812: {"Unified_Ideograph", "Ideographic"},
    147813: {"Unified_Ideograph", "Ideographic"},
    147814: {"Unified_Ideograph", "Ideographic"},
    147815: {"Unified_Ideograph", "Ideographic"},
    147816: {"Unified_Ideograph", "Ideographic"},
    147817: {"Unified_Ideograph", "Ideographic"},
    147818: {"Unified_Ideograph", "Ideographic"},
    147819: {"Unified_Ideograph", "Ideographic"},
    147820: {"Unified_Ideograph", "Ideographic"},
    147821: {"Unified_Ideograph", "Ideographic"},
    147822: {"Unified_Ideograph", "Ideographic"},
    147823: {"Unified_Ideograph", "Ideographic"},
    147824: {"Unified_Ideograph", "Ideographic"},
    147825: {"Unified_Ideograph", "Ideographic"},
    147826: {"Unified_Ideograph", "Ideographic"},
    147827: {"Unified_Ideograph", "Ideographic"},
    147828: {"Unified_Ideograph", "Ideographic"},
    147829: {"Unified_Ideograph", "Ideographic"},
    147830: {"Unified_Ideograph", "Ideographic"},
    147831: {"Unified_Ideograph", "Ideographic"},
    147832: {"Unified_Ideograph", "Ideographic"},
    147833: {"Unified_Ideograph", "Ideographic"},
    147834: {"Unified_Ideograph", "Ideographic"},
    147835: {"Unified_Ideograph", "Ideographic"},
    147836: {"Unified_Ideograph", "Ideographic"},
    147837: {"Unified_Ideograph", "Ideographic"},
    147838: {"Unified_Ideograph", "Ideographic"},
    147839: {"Unified_Ideograph", "Ideographic"},
    147840: {"Unified_Ideograph", "Ideographic"},
    147841: {"Unified_Ideograph", "Ideographic"},
    147842: {"Unified_Ideograph", "Ideographic"},
    147843: {"Unified_Ideograph", "Ideographic"},
    147844: {"Unified_Ideograph", "Ideographic"},
    147845: {"Unified_Ideograph", "Ideographic"},
    147846: {"Unified_Ideograph", "Ideographic"},
    147847: {"Unified_Ideograph", "Ideographic"},
    147848: {"Unified_Ideograph", "Ideographic"},
    147849: {"Unified_Ideograph", "Ideographic"},
    147850: {"Unified_Ideograph", "Ideographic"},
    147851: {"Unified_Ideograph", "Ideographic"},
    147852: {"Unified_Ideograph", "Ideographic"},
    147853: {"Unified_Ideograph", "Ideographic"},
    147854: {"Unified_Ideograph", "Ideographic"},
    147855: {"Unified_Ideograph", "Ideographic"},
    147856: {"Unified_Ideograph", "Ideographic"},
    147857: {"Unified_Ideograph", "Ideographic"},
    147858: {"Unified_Ideograph", "Ideographic"},
    147859: {"Unified_Ideograph", "Ideographic"},
    147860: {"Unified_Ideograph", "Ideographic"},
    147861: {"Unified_Ideograph", "Ideographic"},
    147862: {"Unified_Ideograph", "Ideographic"},
    147863: {"Unified_Ideograph", "Ideographic"},
    147864: {"Unified_Ideograph", "Ideographic"},
    147865: {"Unified_Ideograph", "Ideographic"},
    147866: {"Unified_Ideograph", "Ideographic"},
    147867: {"Unified_Ideograph", "Ideographic"},
    147868: {"Unified_Ideograph", "Ideographic"},
    147869: {"Unified_Ideograph", "Ideographic"},
    147870: {"Unified_Ideograph", "Ideographic"},
    147871: {"Unified_Ideograph", "Ideographic"},
    147872: {"Unified_Ideograph", "Ideographic"},
    147873: {"Unified_Ideograph", "Ideographic"},
    147874: {"Unified_Ideograph", "Ideographic"},
    147875: {"Unified_Ideograph", "Ideographic"},
    147876: {"Unified_Ideograph", "Ideographic"},
    147877: {"Unified_Ideograph", "Ideographic"},
    147878: {"Unified_Ideograph", "Ideographic"},
    147879: {"Unified_Ideograph", "Ideographic"},
    147880: {"Unified_Ideograph", "Ideographic"},
    147881: {"Unified_Ideograph", "Ideographic"},
    147882: {"Unified_Ideograph", "Ideographic"},
    147883: {"Unified_Ideograph", "Ideographic"},
    147884: {"Unified_Ideograph", "Ideographic"},
    147885: {"Unified_Ideograph", "Ideographic"},
    147886: {"Unified_Ideograph", "Ideographic"},
    147887: {"Unified_Ideograph", "Ideographic"},
    147888: {"Unified_Ideograph", "Ideographic"},
    147889: {"Unified_Ideograph", "Ideographic"},
    147890: {"Unified_Ideograph", "Ideographic"},
    147891: {"Unified_Ideograph", "Ideographic"},
    147892: {"Unified_Ideograph", "Ideographic"},
    147893: {"Unified_Ideograph", "Ideographic"},
    147894: {"Unified_Ideograph", "Ideographic"},
    147895: {"Unified_Ideograph", "Ideographic"},
    147896: {"Unified_Ideograph", "Ideographic"},
    147897: {"Unified_Ideograph", "Ideographic"},
    147898: {"Unified_Ideograph", "Ideographic"},
    147899: {"Unified_Ideograph", "Ideographic"},
    147900: {"Unified_Ideograph", "Ideographic"},
    147901: {"Unified_Ideograph", "Ideographic"},
    147902: {"Unified_Ideograph", "Ideographic"},
    147903: {"Unified_Ideograph", "Ideographic"},
    147904: {"Unified_Ideograph", "Ideographic"},
    147905: {"Unified_Ideograph", "Ideographic"},
    147906: {"Unified_Ideograph", "Ideographic"},
    147907: {"Unified_Ideograph", "Ideographic"},
    147908: {"Unified_Ideograph", "Ideographic"},
    147909: {"Unified_Ideograph", "Ideographic"},
    147910: {"Unified_Ideograph", "Ideographic"},
    147911: {"Unified_Ideograph", "Ideographic"},
    147912: {"Unified_Ideograph", "Ideographic"},
    147913: {"Unified_Ideograph", "Ideographic"},
    147914: {"Unified_Ideograph", "Ideographic"},
    147915: {"Unified_Ideograph", "Ideographic"},
    147916: {"Unified_Ideograph", "Ideographic"},
    147917: {"Unified_Ideograph", "Ideographic"},
    147918: {"Unified_Ideograph", "Ideographic"},
    147919: {"Unified_Ideograph", "Ideographic"},
    147920: {"Unified_Ideograph", "Ideographic"},
    147921: {"Unified_Ideograph", "Ideographic"},
    147922: {"Unified_Ideograph", "Ideographic"},
    147923: {"Unified_Ideograph", "Ideographic"},
    147924: {"Unified_Ideograph", "Ideographic"},
    147925: {"Unified_Ideograph", "Ideographic"},
    147926: {"Unified_Ideograph", "Ideographic"},
    147927: {"Unified_Ideograph", "Ideographic"},
    147928: {"Unified_Ideograph", "Ideographic"},
    147929: {"Unified_Ideograph", "Ideographic"},
    147930: {"Unified_Ideograph", "Ideographic"},
    147931: {"Unified_Ideograph", "Ideographic"},
    147932: {"Unified_Ideograph", "Ideographic"},
    147933: {"Unified_Ideograph", "Ideographic"},
    147934: {"Unified_Ideograph", "Ideographic"},
    147935: {"Unified_Ideograph", "Ideographic"},
    147936: {"Unified_Ideograph", "Ideographic"},
    147937: {"Unified_Ideograph", "Ideographic"},
    147938: {"Unified_Ideograph", "Ideographic"},
    147939: {"Unified_Ideograph", "Ideographic"},
    147940: {"Unified_Ideograph", "Ideographic"},
    147941: {"Unified_Ideograph", "Ideographic"},
    147942: {"Unified_Ideograph", "Ideographic"},
    147943: {"Unified_Ideograph", "Ideographic"},
    147944: {"Unified_Ideograph", "Ideographic"},
    147945: {"Unified_Ideograph", "Ideographic"},
    147946: {"Unified_Ideograph", "Ideographic"},
    147947: {"Unified_Ideograph", "Ideographic"},
    147948: {"Unified_Ideograph", "Ideographic"},
    147949: {"Unified_Ideograph", "Ideographic"},
    147950: {"Unified_Ideograph", "Ideographic"},
    147951: {"Unified_Ideograph", "Ideographic"},
    147952: {"Unified_Ideograph", "Ideographic"},
    147953: {"Unified_Ideograph", "Ideographic"},
    147954: {"Unified_Ideograph", "Ideographic"},
    147955: {"Unified_Ideograph", "Ideographic"},
    147956: {"Unified_Ideograph", "Ideographic"},
    147957: {"Unified_Ideograph", "Ideographic"},
    147958: {"Unified_Ideograph", "Ideographic"},
    147959: {"Unified_Ideograph", "Ideographic"},
    147960: {"Unified_Ideograph", "Ideographic"},
    147961: {"Unified_Ideograph", "Ideographic"},
    147962: {"Unified_Ideograph", "Ideographic"},
    147963: {"Unified_Ideograph", "Ideographic"},
    147964: {"Unified_Ideograph", "Ideographic"},
    147965: {"Unified_Ideograph", "Ideographic"},
    147966: {"Unified_Ideograph", "Ideographic"},
    147967: {"Unified_Ideograph", "Ideographic"},
    147968: {"Unified_Ideograph", "Ideographic"},
    147969: {"Unified_Ideograph", "Ideographic"},
    147970: {"Unified_Ideograph", "Ideographic"},
    147971: {"Unified_Ideograph", "Ideographic"},
    147972: {"Unified_Ideograph", "Ideographic"},
    147973: {"Unified_Ideograph", "Ideographic"},
    147974: {"Unified_Ideograph", "Ideographic"},
    147975: {"Unified_Ideograph", "Ideographic"},
    147976: {"Unified_Ideograph", "Ideographic"},
    147977: {"Unified_Ideograph", "Ideographic"},
    147978: {"Unified_Ideograph", "Ideographic"},
    147979: {"Unified_Ideograph", "Ideographic"},
    147980: {"Unified_Ideograph", "Ideographic"},
    147981: {"Unified_Ideograph", "Ideographic"},
    147982: {"Unified_Ideograph", "Ideographic"},
    147983: {"Unified_Ideograph", "Ideographic"},
    147984: {"Unified_Ideograph", "Ideographic"},
    147985: {"Unified_Ideograph", "Ideographic"},
    147986: {"Unified_Ideograph", "Ideographic"},
    147987: {"Unified_Ideograph", "Ideographic"},
    147988: {"Unified_Ideograph", "Ideographic"},
    147989: {"Unified_Ideograph", "Ideographic"},
    147990: {"Unified_Ideograph", "Ideographic"},
    147991: {"Unified_Ideograph", "Ideographic"},
    147992: {"Unified_Ideograph", "Ideographic"},
    147993: {"Unified_Ideograph", "Ideographic"},
    147994: {"Unified_Ideograph", "Ideographic"},
    147995: {"Unified_Ideograph", "Ideographic"},
    147996: {"Unified_Ideograph", "Ideographic"},
    147997: {"Unified_Ideograph", "Ideographic"},
    147998: {"Unified_Ideograph", "Ideographic"},
    147999: {"Unified_Ideograph", "Ideographic"},
    148000: {"Unified_Ideograph", "Ideographic"},
    148001: {"Unified_Ideograph", "Ideographic"},
    148002: {"Unified_Ideograph", "Ideographic"},
    148003: {"Unified_Ideograph", "Ideographic"},
    148004: {"Unified_Ideograph", "Ideographic"},
    148005: {"Unified_Ideograph", "Ideographic"},
    148006: {"Unified_Ideograph", "Ideographic"},
    148007: {"Unified_Ideograph", "Ideographic"},
    148008: {"Unified_Ideograph", "Ideographic"},
    148009: {"Unified_Ideograph", "Ideographic"},
    148010: {"Unified_Ideograph", "Ideographic"},
    148011: {"Unified_Ideograph", "Ideographic"},
    148012: {"Unified_Ideograph", "Ideographic"},
    148013: {"Unified_Ideograph", "Ideographic"},
    148014: {"Unified_Ideograph", "Ideographic"},
    148015: {"Unified_Ideograph", "Ideographic"},
    148016: {"Unified_Ideograph", "Ideographic"},
    148017: {"Unified_Ideograph", "Ideographic"},
    148018: {"Unified_Ideograph", "Ideographic"},
    148019: {"Unified_Ideograph", "Ideographic"},
    148020: {"Unified_Ideograph", "Ideographic"},
    148021: {"Unified_Ideograph", "Ideographic"},
    148022: {"Unified_Ideograph", "Ideographic"},
    148023: {"Unified_Ideograph", "Ideographic"},
    148024: {"Unified_Ideograph", "Ideographic"},
    148025: {"Unified_Ideograph", "Ideographic"},
    148026: {"Unified_Ideograph", "Ideographic"},
    148027: {"Unified_Ideograph", "Ideographic"},
    148028: {"Unified_Ideograph", "Ideographic"},
    148029: {"Unified_Ideograph", "Ideographic"},
    148030: {"Unified_Ideograph", "Ideographic"},
    148031: {"Unified_Ideograph", "Ideographic"},
    148032: {"Unified_Ideograph", "Ideographic"},
    148033: {"Unified_Ideograph", "Ideographic"},
    148034: {"Unified_Ideograph", "Ideographic"},
    148035: {"Unified_Ideograph", "Ideographic"},
    148036: {"Unified_Ideograph", "Ideographic"},
    148037: {"Unified_Ideograph", "Ideographic"},
    148038: {"Unified_Ideograph", "Ideographic"},
    148039: {"Unified_Ideograph", "Ideographic"},
    148040: {"Unified_Ideograph", "Ideographic"},
    148041: {"Unified_Ideograph", "Ideographic"},
    148042: {"Unified_Ideograph", "Ideographic"},
    148043: {"Unified_Ideograph", "Ideographic"},
    148044: {"Unified_Ideograph", "Ideographic"},
    148045: {"Unified_Ideograph", "Ideographic"},
    148046: {"Unified_Ideograph", "Ideographic"},
    148047: {"Unified_Ideograph", "Ideographic"},
    148048: {"Unified_Ideograph", "Ideographic"},
    148049: {"Unified_Ideograph", "Ideographic"},
    148050: {"Unified_Ideograph", "Ideographic"},
    148051: {"Unified_Ideograph", "Ideographic"},
    148052: {"Unified_Ideograph", "Ideographic"},
    148053: {"Unified_Ideograph", "Ideographic"},
    148054: {"Unified_Ideograph", "Ideographic"},
    148055: {"Unified_Ideograph", "Ideographic"},
    148056: {"Unified_Ideograph", "Ideographic"},
    148057: {"Unified_Ideograph", "Ideographic"},
    148058: {"Unified_Ideograph", "Ideographic"},
    148059: {"Unified_Ideograph", "Ideographic"},
    148060: {"Unified_Ideograph", "Ideographic"},
    148061: {"Unified_Ideograph", "Ideographic"},
    148062: {"Unified_Ideograph", "Ideographic"},
    148063: {"Unified_Ideograph", "Ideographic"},
    148064: {"Unified_Ideograph", "Ideographic"},
    148065: {"Unified_Ideograph", "Ideographic"},
    148066: {"Unified_Ideograph", "Ideographic"},
    148067: {"Unified_Ideograph", "Ideographic"},
    148068: {"Unified_Ideograph", "Ideographic"},
    148069: {"Unified_Ideograph", "Ideographic"},
    148070: {"Unified_Ideograph", "Ideographic"},
    148071: {"Unified_Ideograph", "Ideographic"},
    148072: {"Unified_Ideograph", "Ideographic"},
    148073: {"Unified_Ideograph", "Ideographic"},
    148074: {"Unified_Ideograph", "Ideographic"},
    148075: {"Unified_Ideograph", "Ideographic"},
    148076: {"Unified_Ideograph", "Ideographic"},
    148077: {"Unified_Ideograph", "Ideographic"},
    148078: {"Unified_Ideograph", "Ideographic"},
    148079: {"Unified_Ideograph", "Ideographic"},
    148080: {"Unified_Ideograph", "Ideographic"},
    148081: {"Unified_Ideograph", "Ideographic"},
    148082: {"Unified_Ideograph", "Ideographic"},
    148083: {"Unified_Ideograph", "Ideographic"},
    148084: {"Unified_Ideograph", "Ideographic"},
    148085: {"Unified_Ideograph", "Ideographic"},
    148086: {"Unified_Ideograph", "Ideographic"},
    148087: {"Unified_Ideograph", "Ideographic"},
    148088: {"Unified_Ideograph", "Ideographic"},
    148089: {"Unified_Ideograph", "Ideographic"},
    148090: {"Unified_Ideograph", "Ideographic"},
    148091: {"Unified_Ideograph", "Ideographic"},
    148092: {"Unified_Ideograph", "Ideographic"},
    148093: {"Unified_Ideograph", "Ideographic"},
    148094: {"Unified_Ideograph", "Ideographic"},
    148095: {"Unified_Ideograph", "Ideographic"},
    148096: {"Unified_Ideograph", "Ideographic"},
    148097: {"Unified_Ideograph", "Ideographic"},
    148098: {"Unified_Ideograph", "Ideographic"},
    148099: {"Unified_Ideograph", "Ideographic"},
    148100: {"Unified_Ideograph", "Ideographic"},
    148101: {"Unified_Ideograph", "Ideographic"},
    148102: {"Unified_Ideograph", "Ideographic"},
    148103: {"Unified_Ideograph", "Ideographic"},
    148104: {"Unified_Ideograph", "Ideographic"},
    148105: {"Unified_Ideograph", "Ideographic"},
    148106: {"Unified_Ideograph", "Ideographic"},
    148107: {"Unified_Ideograph", "Ideographic"},
    148108: {"Unified_Ideograph", "Ideographic"},
    148109: {"Unified_Ideograph", "Ideographic"},
    148110: {"Unified_Ideograph", "Ideographic"},
    148111: {"Unified_Ideograph", "Ideographic"},
    148112: {"Unified_Ideograph", "Ideographic"},
    148113: {"Unified_Ideograph", "Ideographic"},
    148114: {"Unified_Ideograph", "Ideographic"},
    148115: {"Unified_Ideograph", "Ideographic"},
    148116: {"Unified_Ideograph", "Ideographic"},
    148117: {"Unified_Ideograph", "Ideographic"},
    148118: {"Unified_Ideograph", "Ideographic"},
    148119: {"Unified_Ideograph", "Ideographic"},
    148120: {"Unified_Ideograph", "Ideographic"},
    148121: {"Unified_Ideograph", "Ideographic"},
    148122: {"Unified_Ideograph", "Ideographic"},
    148123: {"Unified_Ideograph", "Ideographic"},
    148124: {"Unified_Ideograph", "Ideographic"},
    148125: {"Unified_Ideograph", "Ideographic"},
    148126: {"Unified_Ideograph", "Ideographic"},
    148127: {"Unified_Ideograph", "Ideographic"},
    148128: {"Unified_Ideograph", "Ideographic"},
    148129: {"Unified_Ideograph", "Ideographic"},
    148130: {"Unified_Ideograph", "Ideographic"},
    148131: {"Unified_Ideograph", "Ideographic"},
    148132: {"Unified_Ideograph", "Ideographic"},
    148133: {"Unified_Ideograph", "Ideographic"},
    148134: {"Unified_Ideograph", "Ideographic"},
    148135: {"Unified_Ideograph", "Ideographic"},
    148136: {"Unified_Ideograph", "Ideographic"},
    148137: {"Unified_Ideograph", "Ideographic"},
    148138: {"Unified_Ideograph", "Ideographic"},
    148139: {"Unified_Ideograph", "Ideographic"},
    148140: {"Unified_Ideograph", "Ideographic"},
    148141: {"Unified_Ideograph", "Ideographic"},
    148142: {"Unified_Ideograph", "Ideographic"},
    148143: {"Unified_Ideograph", "Ideographic"},
    148144: {"Unified_Ideograph", "Ideographic"},
    148145: {"Unified_Ideograph", "Ideographic"},
    148146: {"Unified_Ideograph", "Ideographic"},
    148147: {"Unified_Ideograph", "Ideographic"},
    148148: {"Unified_Ideograph", "Ideographic"},
    148149: {"Unified_Ideograph", "Ideographic"},
    148150: {"Unified_Ideograph", "Ideographic"},
    148151: {"Unified_Ideograph", "Ideographic"},
    148152: {"Unified_Ideograph", "Ideographic"},
    148153: {"Unified_Ideograph", "Ideographic"},
    148154: {"Unified_Ideograph", "Ideographic"},
    148155: {"Unified_Ideograph", "Ideographic"},
    148156: {"Unified_Ideograph", "Ideographic"},
    148157: {"Unified_Ideograph", "Ideographic"},
    148158: {"Unified_Ideograph", "Ideographic"},
    148159: {"Unified_Ideograph", "Ideographic"},
    148160: {"Unified_Ideograph", "Ideographic"},
    148161: {"Unified_Ideograph", "Ideographic"},
    148162: {"Unified_Ideograph", "Ideographic"},
    148163: {"Unified_Ideograph", "Ideographic"},
    148164: {"Unified_Ideograph", "Ideographic"},
    148165: {"Unified_Ideograph", "Ideographic"},
    148166: {"Unified_Ideograph", "Ideographic"},
    148167: {"Unified_Ideograph", "Ideographic"},
    148168: {"Unified_Ideograph", "Ideographic"},
    148169: {"Unified_Ideograph", "Ideographic"},
    148170: {"Unified_Ideograph", "Ideographic"},
    148171: {"Unified_Ideograph", "Ideographic"},
    148172: {"Unified_Ideograph", "Ideographic"},
    148173: {"Unified_Ideograph", "Ideographic"},
    148174: {"Unified_Ideograph", "Ideographic"},
    148175: {"Unified_Ideograph", "Ideographic"},
    148176: {"Unified_Ideograph", "Ideographic"},
    148177: {"Unified_Ideograph", "Ideographic"},
    148178: {"Unified_Ideograph", "Ideographic"},
    148179: {"Unified_Ideograph", "Ideographic"},
    148180: {"Unified_Ideograph", "Ideographic"},
    148181: {"Unified_Ideograph", "Ideographic"},
    148182: {"Unified_Ideograph", "Ideographic"},
    148183: {"Unified_Ideograph", "Ideographic"},
    148184: {"Unified_Ideograph", "Ideographic"},
    148185: {"Unified_Ideograph", "Ideographic"},
    148186: {"Unified_Ideograph", "Ideographic"},
    148187: {"Unified_Ideograph", "Ideographic"},
    148188: {"Unified_Ideograph", "Ideographic"},
    148189: {"Unified_Ideograph", "Ideographic"},
    148190: {"Unified_Ideograph", "Ideographic"},
    148191: {"Unified_Ideograph", "Ideographic"},
    148192: {"Unified_Ideograph", "Ideographic"},
    148193: {"Unified_Ideograph", "Ideographic"},
    148194: {"Unified_Ideograph", "Ideographic"},
    148195: {"Unified_Ideograph", "Ideographic"},
    148196: {"Unified_Ideograph", "Ideographic"},
    148197: {"Unified_Ideograph", "Ideographic"},
    148198: {"Unified_Ideograph", "Ideographic"},
    148199: {"Unified_Ideograph", "Ideographic"},
    148200: {"Unified_Ideograph", "Ideographic"},
    148201: {"Unified_Ideograph", "Ideographic"},
    148202: {"Unified_Ideograph", "Ideographic"},
    148203: {"Unified_Ideograph", "Ideographic"},
    148204: {"Unified_Ideograph", "Ideographic"},
    148205: {"Unified_Ideograph", "Ideographic"},
    148206: {"Unified_Ideograph", "Ideographic"},
    148207: {"Unified_Ideograph", "Ideographic"},
    148208: {"Unified_Ideograph", "Ideographic"},
    148209: {"Unified_Ideograph", "Ideographic"},
    148210: {"Unified_Ideograph", "Ideographic"},
    148211: {"Unified_Ideograph", "Ideographic"},
    148212: {"Unified_Ideograph", "Ideographic"},
    148213: {"Unified_Ideograph", "Ideographic"},
    148214: {"Unified_Ideograph", "Ideographic"},
    148215: {"Unified_Ideograph", "Ideographic"},
    148216: {"Unified_Ideograph", "Ideographic"},
    148217: {"Unified_Ideograph", "Ideographic"},
    148218: {"Unified_Ideograph", "Ideographic"},
    148219: {"Unified_Ideograph", "Ideographic"},
    148220: {"Unified_Ideograph", "Ideographic"},
    148221: {"Unified_Ideograph", "Ideographic"},
    148222: {"Unified_Ideograph", "Ideographic"},
    148223: {"Unified_Ideograph", "Ideographic"},
    148224: {"Unified_Ideograph", "Ideographic"},
    148225: {"Unified_Ideograph", "Ideographic"},
    148226: {"Unified_Ideograph", "Ideographic"},
    148227: {"Unified_Ideograph", "Ideographic"},
    148228: {"Unified_Ideograph", "Ideographic"},
    148229: {"Unified_Ideograph", "Ideographic"},
    148230: {"Unified_Ideograph", "Ideographic"},
    148231: {"Unified_Ideograph", "Ideographic"},
    148232: {"Unified_Ideograph", "Ideographic"},
    148233: {"Unified_Ideograph", "Ideographic"},
    148234: {"Unified_Ideograph", "Ideographic"},
    148235: {"Unified_Ideograph", "Ideographic"},
    148236: {"Unified_Ideograph", "Ideographic"},
    148237: {"Unified_Ideograph", "Ideographic"},
    148238: {"Unified_Ideograph", "Ideographic"},
    148239: {"Unified_Ideograph", "Ideographic"},
    148240: {"Unified_Ideograph", "Ideographic"},
    148241: {"Unified_Ideograph", "Ideographic"},
    148242: {"Unified_Ideograph", "Ideographic"},
    148243: {"Unified_Ideograph", "Ideographic"},
    148244: {"Unified_Ideograph", "Ideographic"},
    148245: {"Unified_Ideograph", "Ideographic"},
    148246: {"Unified_Ideograph", "Ideographic"},
    148247: {"Unified_Ideograph", "Ideographic"},
    148248: {"Unified_Ideograph", "Ideographic"},
    148249: {"Unified_Ideograph", "Ideographic"},
    148250: {"Unified_Ideograph", "Ideographic"},
    148251: {"Unified_Ideograph", "Ideographic"},
    148252: {"Unified_Ideograph", "Ideographic"},
    148253: {"Unified_Ideograph", "Ideographic"},
    148254: {"Unified_Ideograph", "Ideographic"},
    148255: {"Unified_Ideograph", "Ideographic"},
    148256: {"Unified_Ideograph", "Ideographic"},
    148257: {"Unified_Ideograph", "Ideographic"},
    148258: {"Unified_Ideograph", "Ideographic"},
    148259: {"Unified_Ideograph", "Ideographic"},
    148260: {"Unified_Ideograph", "Ideographic"},
    148261: {"Unified_Ideograph", "Ideographic"},
    148262: {"Unified_Ideograph", "Ideographic"},
    148263: {"Unified_Ideograph", "Ideographic"},
    148264: {"Unified_Ideograph", "Ideographic"},
    148265: {"Unified_Ideograph", "Ideographic"},
    148266: {"Unified_Ideograph", "Ideographic"},
    148267: {"Unified_Ideograph", "Ideographic"},
    148268: {"Unified_Ideograph", "Ideographic"},
    148269: {"Unified_Ideograph", "Ideographic"},
    148270: {"Unified_Ideograph", "Ideographic"},
    148271: {"Unified_Ideograph", "Ideographic"},
    148272: {"Unified_Ideograph", "Ideographic"},
    148273: {"Unified_Ideograph", "Ideographic"},
    148274: {"Unified_Ideograph", "Ideographic"},
    148275: {"Unified_Ideograph", "Ideographic"},
    148276: {"Unified_Ideograph", "Ideographic"},
    148277: {"Unified_Ideograph", "Ideographic"},
    148278: {"Unified_Ideograph", "Ideographic"},
    148279: {"Unified_Ideograph", "Ideographic"},
    148280: {"Unified_Ideograph", "Ideographic"},
    148281: {"Unified_Ideograph", "Ideographic"},
    148282: {"Unified_Ideograph", "Ideographic"},
    148283: {"Unified_Ideograph", "Ideographic"},
    148284: {"Unified_Ideograph", "Ideographic"},
    148285: {"Unified_Ideograph", "Ideographic"},
    148286: {"Unified_Ideograph", "Ideographic"},
    148287: {"Unified_Ideograph", "Ideographic"},
    148288: {"Unified_Ideograph", "Ideographic"},
    148289: {"Unified_Ideograph", "Ideographic"},
    148290: {"Unified_Ideograph", "Ideographic"},
    148291: {"Unified_Ideograph", "Ideographic"},
    148292: {"Unified_Ideograph", "Ideographic"},
    148293: {"Unified_Ideograph", "Ideographic"},
    148294: {"Unified_Ideograph", "Ideographic"},
    148295: {"Unified_Ideograph", "Ideographic"},
    148296: {"Unified_Ideograph", "Ideographic"},
    148297: {"Unified_Ideograph", "Ideographic"},
    148298: {"Unified_Ideograph", "Ideographic"},
    148299: {"Unified_Ideograph", "Ideographic"},
    148300: {"Unified_Ideograph", "Ideographic"},
    148301: {"Unified_Ideograph", "Ideographic"},
    148302: {"Unified_Ideograph", "Ideographic"},
    148303: {"Unified_Ideograph", "Ideographic"},
    148304: {"Unified_Ideograph", "Ideographic"},
    148305: {"Unified_Ideograph", "Ideographic"},
    148306: {"Unified_Ideograph", "Ideographic"},
    148307: {"Unified_Ideograph", "Ideographic"},
    148308: {"Unified_Ideograph", "Ideographic"},
    148309: {"Unified_Ideograph", "Ideographic"},
    148310: {"Unified_Ideograph", "Ideographic"},
    148311: {"Unified_Ideograph", "Ideographic"},
    148312: {"Unified_Ideograph", "Ideographic"},
    148313: {"Unified_Ideograph", "Ideographic"},
    148314: {"Unified_Ideograph", "Ideographic"},
    148315: {"Unified_Ideograph", "Ideographic"},
    148316: {"Unified_Ideograph", "Ideographic"},
    148317: {"Unified_Ideograph", "Ideographic"},
    148318: {"Unified_Ideograph", "Ideographic"},
    148319: {"Unified_Ideograph", "Ideographic"},
    148320: {"Unified_Ideograph", "Ideographic"},
    148321: {"Unified_Ideograph", "Ideographic"},
    148322: {"Unified_Ideograph", "Ideographic"},
    148323: {"Unified_Ideograph", "Ideographic"},
    148324: {"Unified_Ideograph", "Ideographic"},
    148325: {"Unified_Ideograph", "Ideographic"},
    148326: {"Unified_Ideograph", "Ideographic"},
    148327: {"Unified_Ideograph", "Ideographic"},
    148328: {"Unified_Ideograph", "Ideographic"},
    148329: {"Unified_Ideograph", "Ideographic"},
    148330: {"Unified_Ideograph", "Ideographic"},
    148331: {"Unified_Ideograph", "Ideographic"},
    148332: {"Unified_Ideograph", "Ideographic"},
    148333: {"Unified_Ideograph", "Ideographic"},
    148334: {"Unified_Ideograph", "Ideographic"},
    148335: {"Unified_Ideograph", "Ideographic"},
    148336: {"Unified_Ideograph", "Ideographic"},
    148337: {"Unified_Ideograph", "Ideographic"},
    148338: {"Unified_Ideograph", "Ideographic"},
    148339: {"Unified_Ideograph", "Ideographic"},
    148340: {"Unified_Ideograph", "Ideographic"},
    148341: {"Unified_Ideograph", "Ideographic"},
    148342: {"Unified_Ideograph", "Ideographic"},
    148343: {"Unified_Ideograph", "Ideographic"},
    148344: {"Unified_Ideograph", "Ideographic"},
    148345: {"Unified_Ideograph", "Ideographic"},
    148346: {"Unified_Ideograph", "Ideographic"},
    148347: {"Unified_Ideograph", "Ideographic"},
    148348: {"Unified_Ideograph", "Ideographic"},
    148349: {"Unified_Ideograph", "Ideographic"},
    148350: {"Unified_Ideograph", "Ideographic"},
    148351: {"Unified_Ideograph", "Ideographic"},
    148352: {"Unified_Ideograph", "Ideographic"},
    148353: {"Unified_Ideograph", "Ideographic"},
    148354: {"Unified_Ideograph", "Ideographic"},
    148355: {"Unified_Ideograph", "Ideographic"},
    148356: {"Unified_Ideograph", "Ideographic"},
    148357: {"Unified_Ideograph", "Ideographic"},
    148358: {"Unified_Ideograph", "Ideographic"},
    148359: {"Unified_Ideograph", "Ideographic"},
    148360: {"Unified_Ideograph", "Ideographic"},
    148361: {"Unified_Ideograph", "Ideographic"},
    148362: {"Unified_Ideograph", "Ideographic"},
    148363: {"Unified_Ideograph", "Ideographic"},
    148364: {"Unified_Ideograph", "Ideographic"},
    148365: {"Unified_Ideograph", "Ideographic"},
    148366: {"Unified_Ideograph", "Ideographic"},
    148367: {"Unified_Ideograph", "Ideographic"},
    148368: {"Unified_Ideograph", "Ideographic"},
    148369: {"Unified_Ideograph", "Ideographic"},
    148370: {"Unified_Ideograph", "Ideographic"},
    148371: {"Unified_Ideograph", "Ideographic"},
    148372: {"Unified_Ideograph", "Ideographic"},
    148373: {"Unified_Ideograph", "Ideographic"},
    148374: {"Unified_Ideograph", "Ideographic"},
    148375: {"Unified_Ideograph", "Ideographic"},
    148376: {"Unified_Ideograph", "Ideographic"},
    148377: {"Unified_Ideograph", "Ideographic"},
    148378: {"Unified_Ideograph", "Ideographic"},
    148379: {"Unified_Ideograph", "Ideographic"},
    148380: {"Unified_Ideograph", "Ideographic"},
    148381: {"Unified_Ideograph", "Ideographic"},
    148382: {"Unified_Ideograph", "Ideographic"},
    148383: {"Unified_Ideograph", "Ideographic"},
    148384: {"Unified_Ideograph", "Ideographic"},
    148385: {"Unified_Ideograph", "Ideographic"},
    148386: {"Unified_Ideograph", "Ideographic"},
    148387: {"Unified_Ideograph", "Ideographic"},
    148388: {"Unified_Ideograph", "Ideographic"},
    148389: {"Unified_Ideograph", "Ideographic"},
    148390: {"Unified_Ideograph", "Ideographic"},
    148391: {"Unified_Ideograph", "Ideographic"},
    148392: {"Unified_Ideograph", "Ideographic"},
    148393: {"Unified_Ideograph", "Ideographic"},
    148394: {"Unified_Ideograph", "Ideographic"},
    148395: {"Unified_Ideograph", "Ideographic"},
    148396: {"Unified_Ideograph", "Ideographic"},
    148397: {"Unified_Ideograph", "Ideographic"},
    148398: {"Unified_Ideograph", "Ideographic"},
    148399: {"Unified_Ideograph", "Ideographic"},
    148400: {"Unified_Ideograph", "Ideographic"},
    148401: {"Unified_Ideograph", "Ideographic"},
    148402: {"Unified_Ideograph", "Ideographic"},
    148403: {"Unified_Ideograph", "Ideographic"},
    148404: {"Unified_Ideograph", "Ideographic"},
    148405: {"Unified_Ideograph", "Ideographic"},
    148406: {"Unified_Ideograph", "Ideographic"},
    148407: {"Unified_Ideograph", "Ideographic"},
    148408: {"Unified_Ideograph", "Ideographic"},
    148409: {"Unified_Ideograph", "Ideographic"},
    148410: {"Unified_Ideograph", "Ideographic"},
    148411: {"Unified_Ideograph", "Ideographic"},
    148412: {"Unified_Ideograph", "Ideographic"},
    148413: {"Unified_Ideograph", "Ideographic"},
    148414: {"Unified_Ideograph", "Ideographic"},
    148415: {"Unified_Ideograph", "Ideographic"},
    148416: {"Unified_Ideograph", "Ideographic"},
    148417: {"Unified_Ideograph", "Ideographic"},
    148418: {"Unified_Ideograph", "Ideographic"},
    148419: {"Unified_Ideograph", "Ideographic"},
    148420: {"Unified_Ideograph", "Ideographic"},
    148421: {"Unified_Ideograph", "Ideographic"},
    148422: {"Unified_Ideograph", "Ideographic"},
    148423: {"Unified_Ideograph", "Ideographic"},
    148424: {"Unified_Ideograph", "Ideographic"},
    148425: {"Unified_Ideograph", "Ideographic"},
    148426: {"Unified_Ideograph", "Ideographic"},
    148427: {"Unified_Ideograph", "Ideographic"},
    148428: {"Unified_Ideograph", "Ideographic"},
    148429: {"Unified_Ideograph", "Ideographic"},
    148430: {"Unified_Ideograph", "Ideographic"},
    148431: {"Unified_Ideograph", "Ideographic"},
    148432: {"Unified_Ideograph", "Ideographic"},
    148433: {"Unified_Ideograph", "Ideographic"},
    148434: {"Unified_Ideograph", "Ideographic"},
    148435: {"Unified_Ideograph", "Ideographic"},
    148436: {"Unified_Ideograph", "Ideographic"},
    148437: {"Unified_Ideograph", "Ideographic"},
    148438: {"Unified_Ideograph", "Ideographic"},
    148439: {"Unified_Ideograph", "Ideographic"},
    148440: {"Unified_Ideograph", "Ideographic"},
    148441: {"Unified_Ideograph", "Ideographic"},
    148442: {"Unified_Ideograph", "Ideographic"},
    148443: {"Unified_Ideograph", "Ideographic"},
    148444: {"Unified_Ideograph", "Ideographic"},
    148445: {"Unified_Ideograph", "Ideographic"},
    148446: {"Unified_Ideograph", "Ideographic"},
    148447: {"Unified_Ideograph", "Ideographic"},
    148448: {"Unified_Ideograph", "Ideographic"},
    148449: {"Unified_Ideograph", "Ideographic"},
    148450: {"Unified_Ideograph", "Ideographic"},
    148451: {"Unified_Ideograph", "Ideographic"},
    148452: {"Unified_Ideograph", "Ideographic"},
    148453: {"Unified_Ideograph", "Ideographic"},
    148454: {"Unified_Ideograph", "Ideographic"},
    148455: {"Unified_Ideograph", "Ideographic"},
    148456: {"Unified_Ideograph", "Ideographic"},
    148457: {"Unified_Ideograph", "Ideographic"},
    148458: {"Unified_Ideograph", "Ideographic"},
    148459: {"Unified_Ideograph", "Ideographic"},
    148460: {"Unified_Ideograph", "Ideographic"},
    148461: {"Unified_Ideograph", "Ideographic"},
    148462: {"Unified_Ideograph", "Ideographic"},
    148463: {"Unified_Ideograph", "Ideographic"},
    148464: {"Unified_Ideograph", "Ideographic"},
    148465: {"Unified_Ideograph", "Ideographic"},
    148466: {"Unified_Ideograph", "Ideographic"},
    148467: {"Unified_Ideograph", "Ideographic"},
    148468: {"Unified_Ideograph", "Ideographic"},
    148469: {"Unified_Ideograph", "Ideographic"},
    148470: {"Unified_Ideograph", "Ideographic"},
    148471: {"Unified_Ideograph", "Ideographic"},
    148472: {"Unified_Ideograph", "Ideographic"},
    148473: {"Unified_Ideograph", "Ideographic"},
    148474: {"Unified_Ideograph", "Ideographic"},
    148475: {"Unified_Ideograph", "Ideographic"},
    148476: {"Unified_Ideograph", "Ideographic"},
    148477: {"Unified_Ideograph", "Ideographic"},
    148478: {"Unified_Ideograph", "Ideographic"},
    148479: {"Unified_Ideograph", "Ideographic"},
    148480: {"Unified_Ideograph", "Ideographic"},
    148481: {"Unified_Ideograph", "Ideographic"},
    148482: {"Unified_Ideograph", "Ideographic"},
    148483: {"Unified_Ideograph", "Ideographic"},
    148484: {"Unified_Ideograph", "Ideographic"},
    148485: {"Unified_Ideograph", "Ideographic"},
    148486: {"Unified_Ideograph", "Ideographic"},
    148487: {"Unified_Ideograph", "Ideographic"},
    148488: {"Unified_Ideograph", "Ideographic"},
    148489: {"Unified_Ideograph", "Ideographic"},
    148490: {"Unified_Ideograph", "Ideographic"},
    148491: {"Unified_Ideograph", "Ideographic"},
    148492: {"Unified_Ideograph", "Ideographic"},
    148493: {"Unified_Ideograph", "Ideographic"},
    148494: {"Unified_Ideograph", "Ideographic"},
    148495: {"Unified_Ideograph", "Ideographic"},
    148496: {"Unified_Ideograph", "Ideographic"},
    148497: {"Unified_Ideograph", "Ideographic"},
    148498: {"Unified_Ideograph", "Ideographic"},
    148499: {"Unified_Ideograph", "Ideographic"},
    148500: {"Unified_Ideograph", "Ideographic"},
    148501: {"Unified_Ideograph", "Ideographic"},
    148502: {"Unified_Ideograph", "Ideographic"},
    148503: {"Unified_Ideograph", "Ideographic"},
    148504: {"Unified_Ideograph", "Ideographic"},
    148505: {"Unified_Ideograph", "Ideographic"},
    148506: {"Unified_Ideograph", "Ideographic"},
    148507: {"Unified_Ideograph", "Ideographic"},
    148508: {"Unified_Ideograph", "Ideographic"},
    148509: {"Unified_Ideograph", "Ideographic"},
    148510: {"Unified_Ideograph", "Ideographic"},
    148511: {"Unified_Ideograph", "Ideographic"},
    148512: {"Unified_Ideograph", "Ideographic"},
    148513: {"Unified_Ideograph", "Ideographic"},
    148514: {"Unified_Ideograph", "Ideographic"},
    148515: {"Unified_Ideograph", "Ideographic"},
    148516: {"Unified_Ideograph", "Ideographic"},
    148517: {"Unified_Ideograph", "Ideographic"},
    148518: {"Unified_Ideograph", "Ideographic"},
    148519: {"Unified_Ideograph", "Ideographic"},
    148520: {"Unified_Ideograph", "Ideographic"},
    148521: {"Unified_Ideograph", "Ideographic"},
    148522: {"Unified_Ideograph", "Ideographic"},
    148523: {"Unified_Ideograph", "Ideographic"},
    148524: {"Unified_Ideograph", "Ideographic"},
    148525: {"Unified_Ideograph", "Ideographic"},
    148526: {"Unified_Ideograph", "Ideographic"},
    148527: {"Unified_Ideograph", "Ideographic"},
    148528: {"Unified_Ideograph", "Ideographic"},
    148529: {"Unified_Ideograph", "Ideographic"},
    148530: {"Unified_Ideograph", "Ideographic"},
    148531: {"Unified_Ideograph", "Ideographic"},
    148532: {"Unified_Ideograph", "Ideographic"},
    148533: {"Unified_Ideograph", "Ideographic"},
    148534: {"Unified_Ideograph", "Ideographic"},
    148535: {"Unified_Ideograph", "Ideographic"},
    148536: {"Unified_Ideograph", "Ideographic"},
    148537: {"Unified_Ideograph", "Ideographic"},
    148538: {"Unified_Ideograph", "Ideographic"},
    148539: {"Unified_Ideograph", "Ideographic"},
    148540: {"Unified_Ideograph", "Ideographic"},
    148541: {"Unified_Ideograph", "Ideographic"},
    148542: {"Unified_Ideograph", "Ideographic"},
    148543: {"Unified_Ideograph", "Ideographic"},
    148544: {"Unified_Ideograph", "Ideographic"},
    148545: {"Unified_Ideograph", "Ideographic"},
    148546: {"Unified_Ideograph", "Ideographic"},
    148547: {"Unified_Ideograph", "Ideographic"},
    148548: {"Unified_Ideograph", "Ideographic"},
    148549: {"Unified_Ideograph", "Ideographic"},
    148550: {"Unified_Ideograph", "Ideographic"},
    148551: {"Unified_Ideograph", "Ideographic"},
    148552: {"Unified_Ideograph", "Ideographic"},
    148553: {"Unified_Ideograph", "Ideographic"},
    148554: {"Unified_Ideograph", "Ideographic"},
    148555: {"Unified_Ideograph", "Ideographic"},
    148556: {"Unified_Ideograph", "Ideographic"},
    148557: {"Unified_Ideograph", "Ideographic"},
    148558: {"Unified_Ideograph", "Ideographic"},
    148559: {"Unified_Ideograph", "Ideographic"},
    148560: {"Unified_Ideograph", "Ideographic"},
    148561: {"Unified_Ideograph", "Ideographic"},
    148562: {"Unified_Ideograph", "Ideographic"},
    148563: {"Unified_Ideograph", "Ideographic"},
    148564: {"Unified_Ideograph", "Ideographic"},
    148565: {"Unified_Ideograph", "Ideographic"},
    148566: {"Unified_Ideograph", "Ideographic"},
    148567: {"Unified_Ideograph", "Ideographic"},
    148568: {"Unified_Ideograph", "Ideographic"},
    148569: {"Unified_Ideograph", "Ideographic"},
    148570: {"Unified_Ideograph", "Ideographic"},
    148571: {"Unified_Ideograph", "Ideographic"},
    148572: {"Unified_Ideograph", "Ideographic"},
    148573: {"Unified_Ideograph", "Ideographic"},
    148574: {"Unified_Ideograph", "Ideographic"},
    148575: {"Unified_Ideograph", "Ideographic"},
    148576: {"Unified_Ideograph", "Ideographic"},
    148577: {"Unified_Ideograph", "Ideographic"},
    148578: {"Unified_Ideograph", "Ideographic"},
    148579: {"Unified_Ideograph", "Ideographic"},
    148580: {"Unified_Ideograph", "Ideographic"},
    148581: {"Unified_Ideograph", "Ideographic"},
    148582: {"Unified_Ideograph", "Ideographic"},
    148583: {"Unified_Ideograph", "Ideographic"},
    148584: {"Unified_Ideograph", "Ideographic"},
    148585: {"Unified_Ideograph", "Ideographic"},
    148586: {"Unified_Ideograph", "Ideographic"},
    148587: {"Unified_Ideograph", "Ideographic"},
    148588: {"Unified_Ideograph", "Ideographic"},
    148589: {"Unified_Ideograph", "Ideographic"},
    148590: {"Unified_Ideograph", "Ideographic"},
    148591: {"Unified_Ideograph", "Ideographic"},
    148592: {"Unified_Ideograph", "Ideographic"},
    148593: {"Unified_Ideograph", "Ideographic"},
    148594: {"Unified_Ideograph", "Ideographic"},
    148595: {"Unified_Ideograph", "Ideographic"},
    148596: {"Unified_Ideograph", "Ideographic"},
    148597: {"Unified_Ideograph", "Ideographic"},
    148598: {"Unified_Ideograph", "Ideographic"},
    148599: {"Unified_Ideograph", "Ideographic"},
    148600: {"Unified_Ideograph", "Ideographic"},
    148601: {"Unified_Ideograph", "Ideographic"},
    148602: {"Unified_Ideograph", "Ideographic"},
    148603: {"Unified_Ideograph", "Ideographic"},
    148604: {"Unified_Ideograph", "Ideographic"},
    148605: {"Unified_Ideograph", "Ideographic"},
    148606: {"Unified_Ideograph", "Ideographic"},
    148607: {"Unified_Ideograph", "Ideographic"},
    148608: {"Unified_Ideograph", "Ideographic"},
    148609: {"Unified_Ideograph", "Ideographic"},
    148610: {"Unified_Ideograph", "Ideographic"},
    148611: {"Unified_Ideograph", "Ideographic"},
    148612: {"Unified_Ideograph", "Ideographic"},
    148613: {"Unified_Ideograph", "Ideographic"},
    148614: {"Unified_Ideograph", "Ideographic"},
    148615: {"Unified_Ideograph", "Ideographic"},
    148616: {"Unified_Ideograph", "Ideographic"},
    148617: {"Unified_Ideograph", "Ideographic"},
    148618: {"Unified_Ideograph", "Ideographic"},
    148619: {"Unified_Ideograph", "Ideographic"},
    148620: {"Unified_Ideograph", "Ideographic"},
    148621: {"Unified_Ideograph", "Ideographic"},
    148622: {"Unified_Ideograph", "Ideographic"},
    148623: {"Unified_Ideograph", "Ideographic"},
    148624: {"Unified_Ideograph", "Ideographic"},
    148625: {"Unified_Ideograph", "Ideographic"},
    148626: {"Unified_Ideograph", "Ideographic"},
    148627: {"Unified_Ideograph", "Ideographic"},
    148628: {"Unified_Ideograph", "Ideographic"},
    148629: {"Unified_Ideograph", "Ideographic"},
    148630: {"Unified_Ideograph", "Ideographic"},
    148631: {"Unified_Ideograph", "Ideographic"},
    148632: {"Unified_Ideograph", "Ideographic"},
    148633: {"Unified_Ideograph", "Ideographic"},
    148634: {"Unified_Ideograph", "Ideographic"},
    148635: {"Unified_Ideograph", "Ideographic"},
    148636: {"Unified_Ideograph", "Ideographic"},
    148637: {"Unified_Ideograph", "Ideographic"},
    148638: {"Unified_Ideograph", "Ideographic"},
    148639: {"Unified_Ideograph", "Ideographic"},
    148640: {"Unified_Ideograph", "Ideographic"},
    148641: {"Unified_Ideograph", "Ideographic"},
    148642: {"Unified_Ideograph", "Ideographic"},
    148643: {"Unified_Ideograph", "Ideographic"},
    148644: {"Unified_Ideograph", "Ideographic"},
    148645: {"Unified_Ideograph", "Ideographic"},
    148646: {"Unified_Ideograph", "Ideographic"},
    148647: {"Unified_Ideograph", "Ideographic"},
    148648: {"Unified_Ideograph", "Ideographic"},
    148649: {"Unified_Ideograph", "Ideographic"},
    148650: {"Unified_Ideograph", "Ideographic"},
    148651: {"Unified_Ideograph", "Ideographic"},
    148652: {"Unified_Ideograph", "Ideographic"},
    148653: {"Unified_Ideograph", "Ideographic"},
    148654: {"Unified_Ideograph", "Ideographic"},
    148655: {"Unified_Ideograph", "Ideographic"},
    148656: {"Unified_Ideograph", "Ideographic"},
    148657: {"Unified_Ideograph", "Ideographic"},
    148658: {"Unified_Ideograph", "Ideographic"},
    148659: {"Unified_Ideograph", "Ideographic"},
    148660: {"Unified_Ideograph", "Ideographic"},
    148661: {"Unified_Ideograph", "Ideographic"},
    148662: {"Unified_Ideograph", "Ideographic"},
    148663: {"Unified_Ideograph", "Ideographic"},
    148664: {"Unified_Ideograph", "Ideographic"},
    148665: {"Unified_Ideograph", "Ideographic"},
    148666: {"Unified_Ideograph", "Ideographic"},
    148667: {"Unified_Ideograph", "Ideographic"},
    148668: {"Unified_Ideograph", "Ideographic"},
    148669: {"Unified_Ideograph", "Ideographic"},
    148670: {"Unified_Ideograph", "Ideographic"},
    148671: {"Unified_Ideograph", "Ideographic"},
    148672: {"Unified_Ideograph", "Ideographic"},
    148673: {"Unified_Ideograph", "Ideographic"},
    148674: {"Unified_Ideograph", "Ideographic"},
    148675: {"Unified_Ideograph", "Ideographic"},
    148676: {"Unified_Ideograph", "Ideographic"},
    148677: {"Unified_Ideograph", "Ideographic"},
    148678: {"Unified_Ideograph", "Ideographic"},
    148679: {"Unified_Ideograph", "Ideographic"},
    148680: {"Unified_Ideograph", "Ideographic"},
    148681: {"Unified_Ideograph", "Ideographic"},
    148682: {"Unified_Ideograph", "Ideographic"},
    148683: {"Unified_Ideograph", "Ideographic"},
    148684: {"Unified_Ideograph", "Ideographic"},
    148685: {"Unified_Ideograph", "Ideographic"},
    148686: {"Unified_Ideograph", "Ideographic"},
    148687: {"Unified_Ideograph", "Ideographic"},
    148688: {"Unified_Ideograph", "Ideographic"},
    148689: {"Unified_Ideograph", "Ideographic"},
    148690: {"Unified_Ideograph", "Ideographic"},
    148691: {"Unified_Ideograph", "Ideographic"},
    148692: {"Unified_Ideograph", "Ideographic"},
    148693: {"Unified_Ideograph", "Ideographic"},
    148694: {"Unified_Ideograph", "Ideographic"},
    148695: {"Unified_Ideograph", "Ideographic"},
    148696: {"Unified_Ideograph", "Ideographic"},
    148697: {"Unified_Ideograph", "Ideographic"},
    148698: {"Unified_Ideograph", "Ideographic"},
    148699: {"Unified_Ideograph", "Ideographic"},
    148700: {"Unified_Ideograph", "Ideographic"},
    148701: {"Unified_Ideograph", "Ideographic"},
    148702: {"Unified_Ideograph", "Ideographic"},
    148703: {"Unified_Ideograph", "Ideographic"},
    148704: {"Unified_Ideograph", "Ideographic"},
    148705: {"Unified_Ideograph", "Ideographic"},
    148706: {"Unified_Ideograph", "Ideographic"},
    148707: {"Unified_Ideograph", "Ideographic"},
    148708: {"Unified_Ideograph", "Ideographic"},
    148709: {"Unified_Ideograph", "Ideographic"},
    148710: {"Unified_Ideograph", "Ideographic"},
    148711: {"Unified_Ideograph", "Ideographic"},
    148712: {"Unified_Ideograph", "Ideographic"},
    148713: {"Unified_Ideograph", "Ideographic"},
    148714: {"Unified_Ideograph", "Ideographic"},
    148715: {"Unified_Ideograph", "Ideographic"},
    148716: {"Unified_Ideograph", "Ideographic"},
    148717: {"Unified_Ideograph", "Ideographic"},
    148718: {"Unified_Ideograph", "Ideographic"},
    148719: {"Unified_Ideograph", "Ideographic"},
    148720: {"Unified_Ideograph", "Ideographic"},
    148721: {"Unified_Ideograph", "Ideographic"},
    148722: {"Unified_Ideograph", "Ideographic"},
    148723: {"Unified_Ideograph", "Ideographic"},
    148724: {"Unified_Ideograph", "Ideographic"},
    148725: {"Unified_Ideograph", "Ideographic"},
    148726: {"Unified_Ideograph", "Ideographic"},
    148727: {"Unified_Ideograph", "Ideographic"},
    148728: {"Unified_Ideograph", "Ideographic"},
    148729: {"Unified_Ideograph", "Ideographic"},
    148730: {"Unified_Ideograph", "Ideographic"},
    148731: {"Unified_Ideograph", "Ideographic"},
    148732: {"Unified_Ideograph", "Ideographic"},
    148733: {"Unified_Ideograph", "Ideographic"},
    148734: {"Unified_Ideograph", "Ideographic"},
    148735: {"Unified_Ideograph", "Ideographic"},
    148736: {"Unified_Ideograph", "Ideographic"},
    148737: {"Unified_Ideograph", "Ideographic"},
    148738: {"Unified_Ideograph", "Ideographic"},
    148739: {"Unified_Ideograph", "Ideographic"},
    148740: {"Unified_Ideograph", "Ideographic"},
    148741: {"Unified_Ideograph", "Ideographic"},
    148742: {"Unified_Ideograph", "Ideographic"},
    148743: {"Unified_Ideograph", "Ideographic"},
    148744: {"Unified_Ideograph", "Ideographic"},
    148745: {"Unified_Ideograph", "Ideographic"},
    148746: {"Unified_Ideograph", "Ideographic"},
    148747: {"Unified_Ideograph", "Ideographic"},
    148748: {"Unified_Ideograph", "Ideographic"},
    148749: {"Unified_Ideograph", "Ideographic"},
    148750: {"Unified_Ideograph", "Ideographic"},
    148751: {"Unified_Ideograph", "Ideographic"},
    148752: {"Unified_Ideograph", "Ideographic"},
    148753: {"Unified_Ideograph", "Ideographic"},
    148754: {"Unified_Ideograph", "Ideographic"},
    148755: {"Unified_Ideograph", "Ideographic"},
    148756: {"Unified_Ideograph", "Ideographic"},
    148757: {"Unified_Ideograph", "Ideographic"},
    148758: {"Unified_Ideograph", "Ideographic"},
    148759: {"Unified_Ideograph", "Ideographic"},
    148760: {"Unified_Ideograph", "Ideographic"},
    148761: {"Unified_Ideograph", "Ideographic"},
    148762: {"Unified_Ideograph", "Ideographic"},
    148763: {"Unified_Ideograph", "Ideographic"},
    148764: {"Unified_Ideograph", "Ideographic"},
    148765: {"Unified_Ideograph", "Ideographic"},
    148766: {"Unified_Ideograph", "Ideographic"},
    148767: {"Unified_Ideograph", "Ideographic"},
    148768: {"Unified_Ideograph", "Ideographic"},
    148769: {"Unified_Ideograph", "Ideographic"},
    148770: {"Unified_Ideograph", "Ideographic"},
    148771: {"Unified_Ideograph", "Ideographic"},
    148772: {"Unified_Ideograph", "Ideographic"},
    148773: {"Unified_Ideograph", "Ideographic"},
    148774: {"Unified_Ideograph", "Ideographic"},
    148775: {"Unified_Ideograph", "Ideographic"},
    148776: {"Unified_Ideograph", "Ideographic"},
    148777: {"Unified_Ideograph", "Ideographic"},
    148778: {"Unified_Ideograph", "Ideographic"},
    148779: {"Unified_Ideograph", "Ideographic"},
    148780: {"Unified_Ideograph", "Ideographic"},
    148781: {"Unified_Ideograph", "Ideographic"},
    148782: {"Unified_Ideograph", "Ideographic"},
    148783: {"Unified_Ideograph", "Ideographic"},
    148784: {"Unified_Ideograph", "Ideographic"},
    148785: {"Unified_Ideograph", "Ideographic"},
    148786: {"Unified_Ideograph", "Ideographic"},
    148787: {"Unified_Ideograph", "Ideographic"},
    148788: {"Unified_Ideograph", "Ideographic"},
    148789: {"Unified_Ideograph", "Ideographic"},
    148790: {"Unified_Ideograph", "Ideographic"},
    148791: {"Unified_Ideograph", "Ideographic"},
    148792: {"Unified_Ideograph", "Ideographic"},
    148793: {"Unified_Ideograph", "Ideographic"},
    148794: {"Unified_Ideograph", "Ideographic"},
    148795: {"Unified_Ideograph", "Ideographic"},
    148796: {"Unified_Ideograph", "Ideographic"},
    148797: {"Unified_Ideograph", "Ideographic"},
    148798: {"Unified_Ideograph", "Ideographic"},
    148799: {"Unified_Ideograph", "Ideographic"},
    148800: {"Unified_Ideograph", "Ideographic"},
    148801: {"Unified_Ideograph", "Ideographic"},
    148802: {"Unified_Ideograph", "Ideographic"},
    148803: {"Unified_Ideograph", "Ideographic"},
    148804: {"Unified_Ideograph", "Ideographic"},
    148805: {"Unified_Ideograph", "Ideographic"},
    148806: {"Unified_Ideograph", "Ideographic"},
    148807: {"Unified_Ideograph", "Ideographic"},
    148808: {"Unified_Ideograph", "Ideographic"},
    148809: {"Unified_Ideograph", "Ideographic"},
    148810: {"Unified_Ideograph", "Ideographic"},
    148811: {"Unified_Ideograph", "Ideographic"},
    148812: {"Unified_Ideograph", "Ideographic"},
    148813: {"Unified_Ideograph", "Ideographic"},
    148814: {"Unified_Ideograph", "Ideographic"},
    148815: {"Unified_Ideograph", "Ideographic"},
    148816: {"Unified_Ideograph", "Ideographic"},
    148817: {"Unified_Ideograph", "Ideographic"},
    148818: {"Unified_Ideograph", "Ideographic"},
    148819: {"Unified_Ideograph", "Ideographic"},
    148820: {"Unified_Ideograph", "Ideographic"},
    148821: {"Unified_Ideograph", "Ideographic"},
    148822: {"Unified_Ideograph", "Ideographic"},
    148823: {"Unified_Ideograph", "Ideographic"},
    148824: {"Unified_Ideograph", "Ideographic"},
    148825: {"Unified_Ideograph", "Ideographic"},
    148826: {"Unified_Ideograph", "Ideographic"},
    148827: {"Unified_Ideograph", "Ideographic"},
    148828: {"Unified_Ideograph", "Ideographic"},
    148829: {"Unified_Ideograph", "Ideographic"},
    148830: {"Unified_Ideograph", "Ideographic"},
    148831: {"Unified_Ideograph", "Ideographic"},
    148832: {"Unified_Ideograph", "Ideographic"},
    148833: {"Unified_Ideograph", "Ideographic"},
    148834: {"Unified_Ideograph", "Ideographic"},
    148835: {"Unified_Ideograph", "Ideographic"},
    148836: {"Unified_Ideograph", "Ideographic"},
    148837: {"Unified_Ideograph", "Ideographic"},
    148838: {"Unified_Ideograph", "Ideographic"},
    148839: {"Unified_Ideograph", "Ideographic"},
    148840: {"Unified_Ideograph", "Ideographic"},
    148841: {"Unified_Ideograph", "Ideographic"},
    148842: {"Unified_Ideograph", "Ideographic"},
    148843: {"Unified_Ideograph", "Ideographic"},
    148844: {"Unified_Ideograph", "Ideographic"},
    148845: {"Unified_Ideograph", "Ideographic"},
    148846: {"Unified_Ideograph", "Ideographic"},
    148847: {"Unified_Ideograph", "Ideographic"},
    148848: {"Unified_Ideograph", "Ideographic"},
    148849: {"Unified_Ideograph", "Ideographic"},
    148850: {"Unified_Ideograph", "Ideographic"},
    148851: {"Unified_Ideograph", "Ideographic"},
    148852: {"Unified_Ideograph", "Ideographic"},
    148853: {"Unified_Ideograph", "Ideographic"},
    148854: {"Unified_Ideograph", "Ideographic"},
    148855: {"Unified_Ideograph", "Ideographic"},
    148856: {"Unified_Ideograph", "Ideographic"},
    148857: {"Unified_Ideograph", "Ideographic"},
    148858: {"Unified_Ideograph", "Ideographic"},
    148859: {"Unified_Ideograph", "Ideographic"},
    148860: {"Unified_Ideograph", "Ideographic"},
    148861: {"Unified_Ideograph", "Ideographic"},
    148862: {"Unified_Ideograph", "Ideographic"},
    148863: {"Unified_Ideograph", "Ideographic"},
    148864: {"Unified_Ideograph", "Ideographic"},
    148865: {"Unified_Ideograph", "Ideographic"},
    148866: {"Unified_Ideograph", "Ideographic"},
    148867: {"Unified_Ideograph", "Ideographic"},
    148868: {"Unified_Ideograph", "Ideographic"},
    148869: {"Unified_Ideograph", "Ideographic"},
    148870: {"Unified_Ideograph", "Ideographic"},
    148871: {"Unified_Ideograph", "Ideographic"},
    148872: {"Unified_Ideograph", "Ideographic"},
    148873: {"Unified_Ideograph", "Ideographic"},
    148874: {"Unified_Ideograph", "Ideographic"},
    148875: {"Unified_Ideograph", "Ideographic"},
    148876: {"Unified_Ideograph", "Ideographic"},
    148877: {"Unified_Ideograph", "Ideographic"},
    148878: {"Unified_Ideograph", "Ideographic"},
    148879: {"Unified_Ideograph", "Ideographic"},
    148880: {"Unified_Ideograph", "Ideographic"},
    148881: {"Unified_Ideograph", "Ideographic"},
    148882: {"Unified_Ideograph", "Ideographic"},
    148883: {"Unified_Ideograph", "Ideographic"},
    148884: {"Unified_Ideograph", "Ideographic"},
    148885: {"Unified_Ideograph", "Ideographic"},
    148886: {"Unified_Ideograph", "Ideographic"},
    148887: {"Unified_Ideograph", "Ideographic"},
    148888: {"Unified_Ideograph", "Ideographic"},
    148889: {"Unified_Ideograph", "Ideographic"},
    148890: {"Unified_Ideograph", "Ideographic"},
    148891: {"Unified_Ideograph", "Ideographic"},
    148892: {"Unified_Ideograph", "Ideographic"},
    148893: {"Unified_Ideograph", "Ideographic"},
    148894: {"Unified_Ideograph", "Ideographic"},
    148895: {"Unified_Ideograph", "Ideographic"},
    148896: {"Unified_Ideograph", "Ideographic"},
    148897: {"Unified_Ideograph", "Ideographic"},
    148898: {"Unified_Ideograph", "Ideographic"},
    148899: {"Unified_Ideograph", "Ideographic"},
    148900: {"Unified_Ideograph", "Ideographic"},
    148901: {"Unified_Ideograph", "Ideographic"},
    148902: {"Unified_Ideograph", "Ideographic"},
    148903: {"Unified_Ideograph", "Ideographic"},
    148904: {"Unified_Ideograph", "Ideographic"},
    148905: {"Unified_Ideograph", "Ideographic"},
    148906: {"Unified_Ideograph", "Ideographic"},
    148907: {"Unified_Ideograph", "Ideographic"},
    148908: {"Unified_Ideograph", "Ideographic"},
    148909: {"Unified_Ideograph", "Ideographic"},
    148910: {"Unified_Ideograph", "Ideographic"},
    148911: {"Unified_Ideograph", "Ideographic"},
    148912: {"Unified_Ideograph", "Ideographic"},
    148913: {"Unified_Ideograph", "Ideographic"},
    148914: {"Unified_Ideograph", "Ideographic"},
    148915: {"Unified_Ideograph", "Ideographic"},
    148916: {"Unified_Ideograph", "Ideographic"},
    148917: {"Unified_Ideograph", "Ideographic"},
    148918: {"Unified_Ideograph", "Ideographic"},
    148919: {"Unified_Ideograph", "Ideographic"},
    148920: {"Unified_Ideograph", "Ideographic"},
    148921: {"Unified_Ideograph", "Ideographic"},
    148922: {"Unified_Ideograph", "Ideographic"},
    148923: {"Unified_Ideograph", "Ideographic"},
    148924: {"Unified_Ideograph", "Ideographic"},
    148925: {"Unified_Ideograph", "Ideographic"},
    148926: {"Unified_Ideograph", "Ideographic"},
    148927: {"Unified_Ideograph", "Ideographic"},
    148928: {"Unified_Ideograph", "Ideographic"},
    148929: {"Unified_Ideograph", "Ideographic"},
    148930: {"Unified_Ideograph", "Ideographic"},
    148931: {"Unified_Ideograph", "Ideographic"},
    148932: {"Unified_Ideograph", "Ideographic"},
    148933: {"Unified_Ideograph", "Ideographic"},
    148934: {"Unified_Ideograph", "Ideographic"},
    148935: {"Unified_Ideograph", "Ideographic"},
    148936: {"Unified_Ideograph", "Ideographic"},
    148937: {"Unified_Ideograph", "Ideographic"},
    148938: {"Unified_Ideograph", "Ideographic"},
    148939: {"Unified_Ideograph", "Ideographic"},
    148940: {"Unified_Ideograph", "Ideographic"},
    148941: {"Unified_Ideograph", "Ideographic"},
    148942: {"Unified_Ideograph", "Ideographic"},
    148943: {"Unified_Ideograph", "Ideographic"},
    148944: {"Unified_Ideograph", "Ideographic"},
    148945: {"Unified_Ideograph", "Ideographic"},
    148946: {"Unified_Ideograph", "Ideographic"},
    148947: {"Unified_Ideograph", "Ideographic"},
    148948: {"Unified_Ideograph", "Ideographic"},
    148949: {"Unified_Ideograph", "Ideographic"},
    148950: {"Unified_Ideograph", "Ideographic"},
    148951: {"Unified_Ideograph", "Ideographic"},
    148952: {"Unified_Ideograph", "Ideographic"},
    148953: {"Unified_Ideograph", "Ideographic"},
    148954: {"Unified_Ideograph", "Ideographic"},
    148955: {"Unified_Ideograph", "Ideographic"},
    148956: {"Unified_Ideograph", "Ideographic"},
    148957: {"Unified_Ideograph", "Ideographic"},
    148958: {"Unified_Ideograph", "Ideographic"},
    148959: {"Unified_Ideograph", "Ideographic"},
    148960: {"Unified_Ideograph", "Ideographic"},
    148961: {"Unified_Ideograph", "Ideographic"},
    148962: {"Unified_Ideograph", "Ideographic"},
    148963: {"Unified_Ideograph", "Ideographic"},
    148964: {"Unified_Ideograph", "Ideographic"},
    148965: {"Unified_Ideograph", "Ideographic"},
    148966: {"Unified_Ideograph", "Ideographic"},
    148967: {"Unified_Ideograph", "Ideographic"},
    148968: {"Unified_Ideograph", "Ideographic"},
    148969: {"Unified_Ideograph", "Ideographic"},
    148970: {"Unified_Ideograph", "Ideographic"},
    148971: {"Unified_Ideograph", "Ideographic"},
    148972: {"Unified_Ideograph", "Ideographic"},
    148973: {"Unified_Ideograph", "Ideographic"},
    148974: {"Unified_Ideograph", "Ideographic"},
    148975: {"Unified_Ideograph", "Ideographic"},
    148976: {"Unified_Ideograph", "Ideographic"},
    148977: {"Unified_Ideograph", "Ideographic"},
    148978: {"Unified_Ideograph", "Ideographic"},
    148979: {"Unified_Ideograph", "Ideographic"},
    148980: {"Unified_Ideograph", "Ideographic"},
    148981: {"Unified_Ideograph", "Ideographic"},
    148982: {"Unified_Ideograph", "Ideographic"},
    148983: {"Unified_Ideograph", "Ideographic"},
    148984: {"Unified_Ideograph", "Ideographic"},
    148985: {"Unified_Ideograph", "Ideographic"},
    148986: {"Unified_Ideograph", "Ideographic"},
    148987: {"Unified_Ideograph", "Ideographic"},
    148988: {"Unified_Ideograph", "Ideographic"},
    148989: {"Unified_Ideograph", "Ideographic"},
    148990: {"Unified_Ideograph", "Ideographic"},
    148991: {"Unified_Ideograph", "Ideographic"},
    148992: {"Unified_Ideograph", "Ideographic"},
    148993: {"Unified_Ideograph", "Ideographic"},
    148994: {"Unified_Ideograph", "Ideographic"},
    148995: {"Unified_Ideograph", "Ideographic"},
    148996: {"Unified_Ideograph", "Ideographic"},
    148997: {"Unified_Ideograph", "Ideographic"},
    148998: {"Unified_Ideograph", "Ideographic"},
    148999: {"Unified_Ideograph", "Ideographic"},
    149000: {"Unified_Ideograph", "Ideographic"},
    149001: {"Unified_Ideograph", "Ideographic"},
    149002: {"Unified_Ideograph", "Ideographic"},
    149003: {"Unified_Ideograph", "Ideographic"},
    149004: {"Unified_Ideograph", "Ideographic"},
    149005: {"Unified_Ideograph", "Ideographic"},
    149006: {"Unified_Ideograph", "Ideographic"},
    149007: {"Unified_Ideograph", "Ideographic"},
    149008: {"Unified_Ideograph", "Ideographic"},
    149009: {"Unified_Ideograph", "Ideographic"},
    149010: {"Unified_Ideograph", "Ideographic"},
    149011: {"Unified_Ideograph", "Ideographic"},
    149012: {"Unified_Ideograph", "Ideographic"},
    149013: {"Unified_Ideograph", "Ideographic"},
    149014: {"Unified_Ideograph", "Ideographic"},
    149015: {"Unified_Ideograph", "Ideographic"},
    149016: {"Unified_Ideograph", "Ideographic"},
    149017: {"Unified_Ideograph", "Ideographic"},
    149018: {"Unified_Ideograph", "Ideographic"},
    149019: {"Unified_Ideograph", "Ideographic"},
    149020: {"Unified_Ideograph", "Ideographic"},
    149021: {"Unified_Ideograph", "Ideographic"},
    149022: {"Unified_Ideograph", "Ideographic"},
    149023: {"Unified_Ideograph", "Ideographic"},
    149024: {"Unified_Ideograph", "Ideographic"},
    149025: {"Unified_Ideograph", "Ideographic"},
    149026: {"Unified_Ideograph", "Ideographic"},
    149027: {"Unified_Ideograph", "Ideographic"},
    149028: {"Unified_Ideograph", "Ideographic"},
    149029: {"Unified_Ideograph", "Ideographic"},
    149030: {"Unified_Ideograph", "Ideographic"},
    149031: {"Unified_Ideograph", "Ideographic"},
    149032: {"Unified_Ideograph", "Ideographic"},
    149033: {"Unified_Ideograph", "Ideographic"},
    149034: {"Unified_Ideograph", "Ideographic"},
    149035: {"Unified_Ideograph", "Ideographic"},
    149036: {"Unified_Ideograph", "Ideographic"},
    149037: {"Unified_Ideograph", "Ideographic"},
    149038: {"Unified_Ideograph", "Ideographic"},
    149039: {"Unified_Ideograph", "Ideographic"},
    149040: {"Unified_Ideograph", "Ideographic"},
    149041: {"Unified_Ideograph", "Ideographic"},
    149042: {"Unified_Ideograph", "Ideographic"},
    149043: {"Unified_Ideograph", "Ideographic"},
    149044: {"Unified_Ideograph", "Ideographic"},
    149045: {"Unified_Ideograph", "Ideographic"},
    149046: {"Unified_Ideograph", "Ideographic"},
    149047: {"Unified_Ideograph", "Ideographic"},
    149048: {"Unified_Ideograph", "Ideographic"},
    149049: {"Unified_Ideograph", "Ideographic"},
    149050: {"Unified_Ideograph", "Ideographic"},
    149051: {"Unified_Ideograph", "Ideographic"},
    149052: {"Unified_Ideograph", "Ideographic"},
    149053: {"Unified_Ideograph", "Ideographic"},
    149054: {"Unified_Ideograph", "Ideographic"},
    149055: {"Unified_Ideograph", "Ideographic"},
    149056: {"Unified_Ideograph", "Ideographic"},
    149057: {"Unified_Ideograph", "Ideographic"},
    149058: {"Unified_Ideograph", "Ideographic"},
    149059: {"Unified_Ideograph", "Ideographic"},
    149060: {"Unified_Ideograph", "Ideographic"},
    149061: {"Unified_Ideograph", "Ideographic"},
    149062: {"Unified_Ideograph", "Ideographic"},
    149063: {"Unified_Ideograph", "Ideographic"},
    149064: {"Unified_Ideograph", "Ideographic"},
    149065: {"Unified_Ideograph", "Ideographic"},
    149066: {"Unified_Ideograph", "Ideographic"},
    149067: {"Unified_Ideograph", "Ideographic"},
    149068: {"Unified_Ideograph", "Ideographic"},
    149069: {"Unified_Ideograph", "Ideographic"},
    149070: {"Unified_Ideograph", "Ideographic"},
    149071: {"Unified_Ideograph", "Ideographic"},
    149072: {"Unified_Ideograph", "Ideographic"},
    149073: {"Unified_Ideograph", "Ideographic"},
    149074: {"Unified_Ideograph", "Ideographic"},
    149075: {"Unified_Ideograph", "Ideographic"},
    149076: {"Unified_Ideograph", "Ideographic"},
    149077: {"Unified_Ideograph", "Ideographic"},
    149078: {"Unified_Ideograph", "Ideographic"},
    149079: {"Unified_Ideograph", "Ideographic"},
    149080: {"Unified_Ideograph", "Ideographic"},
    149081: {"Unified_Ideograph", "Ideographic"},
    149082: {"Unified_Ideograph", "Ideographic"},
    149083: {"Unified_Ideograph", "Ideographic"},
    149084: {"Unified_Ideograph", "Ideographic"},
    149085: {"Unified_Ideograph", "Ideographic"},
    149086: {"Unified_Ideograph", "Ideographic"},
    149087: {"Unified_Ideograph", "Ideographic"},
    149088: {"Unified_Ideograph", "Ideographic"},
    149089: {"Unified_Ideograph", "Ideographic"},
    149090: {"Unified_Ideograph", "Ideographic"},
    149091: {"Unified_Ideograph", "Ideographic"},
    149092: {"Unified_Ideograph", "Ideographic"},
    149093: {"Unified_Ideograph", "Ideographic"},
    149094: {"Unified_Ideograph", "Ideographic"},
    149095: {"Unified_Ideograph", "Ideographic"},
    149096: {"Unified_Ideograph", "Ideographic"},
    149097: {"Unified_Ideograph", "Ideographic"},
    149098: {"Unified_Ideograph", "Ideographic"},
    149099: {"Unified_Ideograph", "Ideographic"},
    149100: {"Unified_Ideograph", "Ideographic"},
    149101: {"Unified_Ideograph", "Ideographic"},
    149102: {"Unified_Ideograph", "Ideographic"},
    149103: {"Unified_Ideograph", "Ideographic"},
    149104: {"Unified_Ideograph", "Ideographic"},
    149105: {"Unified_Ideograph", "Ideographic"},
    149106: {"Unified_Ideograph", "Ideographic"},
    149107: {"Unified_Ideograph", "Ideographic"},
    149108: {"Unified_Ideograph", "Ideographic"},
    149109: {"Unified_Ideograph", "Ideographic"},
    149110: {"Unified_Ideograph", "Ideographic"},
    149111: {"Unified_Ideograph", "Ideographic"},
    149112: {"Unified_Ideograph", "Ideographic"},
    149113: {"Unified_Ideograph", "Ideographic"},
    149114: {"Unified_Ideograph", "Ideographic"},
    149115: {"Unified_Ideograph", "Ideographic"},
    149116: {"Unified_Ideograph", "Ideographic"},
    149117: {"Unified_Ideograph", "Ideographic"},
    149118: {"Unified_Ideograph", "Ideographic"},
    149119: {"Unified_Ideograph", "Ideographic"},
    149120: {"Unified_Ideograph", "Ideographic"},
    149121: {"Unified_Ideograph", "Ideographic"},
    149122: {"Unified_Ideograph", "Ideographic"},
    149123: {"Unified_Ideograph", "Ideographic"},
    149124: {"Unified_Ideograph", "Ideographic"},
    149125: {"Unified_Ideograph", "Ideographic"},
    149126: {"Unified_Ideograph", "Ideographic"},
    149127: {"Unified_Ideograph", "Ideographic"},
    149128: {"Unified_Ideograph", "Ideographic"},
    149129: {"Unified_Ideograph", "Ideographic"},
    149130: {"Unified_Ideograph", "Ideographic"},
    149131: {"Unified_Ideograph", "Ideographic"},
    149132: {"Unified_Ideograph", "Ideographic"},
    149133: {"Unified_Ideograph", "Ideographic"},
    149134: {"Unified_Ideograph", "Ideographic"},
    149135: {"Unified_Ideograph", "Ideographic"},
    149136: {"Unified_Ideograph", "Ideographic"},
    149137: {"Unified_Ideograph", "Ideographic"},
    149138: {"Unified_Ideograph", "Ideographic"},
    149139: {"Unified_Ideograph", "Ideographic"},
    149140: {"Unified_Ideograph", "Ideographic"},
    149141: {"Unified_Ideograph", "Ideographic"},
    149142: {"Unified_Ideograph", "Ideographic"},
    149143: {"Unified_Ideograph", "Ideographic"},
    149144: {"Unified_Ideograph", "Ideographic"},
    149145: {"Unified_Ideograph", "Ideographic"},
    149146: {"Unified_Ideograph", "Ideographic"},
    149147: {"Unified_Ideograph", "Ideographic"},
    149148: {"Unified_Ideograph", "Ideographic"},
    149149: {"Unified_Ideograph", "Ideographic"},
    149150: {"Unified_Ideograph", "Ideographic"},
    149151: {"Unified_Ideograph", "Ideographic"},
    149152: {"Unified_Ideograph", "Ideographic"},
    149153: {"Unified_Ideograph", "Ideographic"},
    149154: {"Unified_Ideograph", "Ideographic"},
    149155: {"Unified_Ideograph", "Ideographic"},
    149156: {"Unified_Ideograph", "Ideographic"},
    149157: {"Unified_Ideograph", "Ideographic"},
    149158: {"Unified_Ideograph", "Ideographic"},
    149159: {"Unified_Ideograph", "Ideographic"},
    149160: {"Unified_Ideograph", "Ideographic"},
    149161: {"Unified_Ideograph", "Ideographic"},
    149162: {"Unified_Ideograph", "Ideographic"},
    149163: {"Unified_Ideograph", "Ideographic"},
    149164: {"Unified_Ideograph", "Ideographic"},
    149165: {"Unified_Ideograph", "Ideographic"},
    149166: {"Unified_Ideograph", "Ideographic"},
    149167: {"Unified_Ideograph", "Ideographic"},
    149168: {"Unified_Ideograph", "Ideographic"},
    149169: {"Unified_Ideograph", "Ideographic"},
    149170: {"Unified_Ideograph", "Ideographic"},
    149171: {"Unified_Ideograph", "Ideographic"},
    149172: {"Unified_Ideograph", "Ideographic"},
    149173: {"Unified_Ideograph", "Ideographic"},
    149174: {"Unified_Ideograph", "Ideographic"},
    149175: {"Unified_Ideograph", "Ideographic"},
    149176: {"Unified_Ideograph", "Ideographic"},
    149177: {"Unified_Ideograph", "Ideographic"},
    149178: {"Unified_Ideograph", "Ideographic"},
    149179: {"Unified_Ideograph", "Ideographic"},
    149180: {"Unified_Ideograph", "Ideographic"},
    149181: {"Unified_Ideograph", "Ideographic"},
    149182: {"Unified_Ideograph", "Ideographic"},
    149183: {"Unified_Ideograph", "Ideographic"},
    149184: {"Unified_Ideograph", "Ideographic"},
    149185: {"Unified_Ideograph", "Ideographic"},
    149186: {"Unified_Ideograph", "Ideographic"},
    149187: {"Unified_Ideograph", "Ideographic"},
    149188: {"Unified_Ideograph", "Ideographic"},
    149189: {"Unified_Ideograph", "Ideographic"},
    149190: {"Unified_Ideograph", "Ideographic"},
    149191: {"Unified_Ideograph", "Ideographic"},
    149192: {"Unified_Ideograph", "Ideographic"},
    149193: {"Unified_Ideograph", "Ideographic"},
    149194: {"Unified_Ideograph", "Ideographic"},
    149195: {"Unified_Ideograph", "Ideographic"},
    149196: {"Unified_Ideograph", "Ideographic"},
    149197: {"Unified_Ideograph", "Ideographic"},
    149198: {"Unified_Ideograph", "Ideographic"},
    149199: {"Unified_Ideograph", "Ideographic"},
    149200: {"Unified_Ideograph", "Ideographic"},
    149201: {"Unified_Ideograph", "Ideographic"},
    149202: {"Unified_Ideograph", "Ideographic"},
    149203: {"Unified_Ideograph", "Ideographic"},
    149204: {"Unified_Ideograph", "Ideographic"},
    149205: {"Unified_Ideograph", "Ideographic"},
    149206: {"Unified_Ideograph", "Ideographic"},
    149207: {"Unified_Ideograph", "Ideographic"},
    149208: {"Unified_Ideograph", "Ideographic"},
    149209: {"Unified_Ideograph", "Ideographic"},
    149210: {"Unified_Ideograph", "Ideographic"},
    149211: {"Unified_Ideograph", "Ideographic"},
    149212: {"Unified_Ideograph", "Ideographic"},
    149213: {"Unified_Ideograph", "Ideographic"},
    149214: {"Unified_Ideograph", "Ideographic"},
    149215: {"Unified_Ideograph", "Ideographic"},
    149216: {"Unified_Ideograph", "Ideographic"},
    149217: {"Unified_Ideograph", "Ideographic"},
    149218: {"Unified_Ideograph", "Ideographic"},
    149219: {"Unified_Ideograph", "Ideographic"},
    149220: {"Unified_Ideograph", "Ideographic"},
    149221: {"Unified_Ideograph", "Ideographic"},
    149222: {"Unified_Ideograph", "Ideographic"},
    149223: {"Unified_Ideograph", "Ideographic"},
    149224: {"Unified_Ideograph", "Ideographic"},
    149225: {"Unified_Ideograph", "Ideographic"},
    149226: {"Unified_Ideograph", "Ideographic"},
    149227: {"Unified_Ideograph", "Ideographic"},
    149228: {"Unified_Ideograph", "Ideographic"},
    149229: {"Unified_Ideograph", "Ideographic"},
    149230: {"Unified_Ideograph", "Ideographic"},
    149231: {"Unified_Ideograph", "Ideographic"},
    149232: {"Unified_Ideograph", "Ideographic"},
    149233: {"Unified_Ideograph", "Ideographic"},
    149234: {"Unified_Ideograph", "Ideographic"},
    149235: {"Unified_Ideograph", "Ideographic"},
    149236: {"Unified_Ideograph", "Ideographic"},
    149237: {"Unified_Ideograph", "Ideographic"},
    149238: {"Unified_Ideograph", "Ideographic"},
    149239: {"Unified_Ideograph", "Ideographic"},
    149240: {"Unified_Ideograph", "Ideographic"},
    149241: {"Unified_Ideograph", "Ideographic"},
    149242: {"Unified_Ideograph", "Ideographic"},
    149243: {"Unified_Ideograph", "Ideographic"},
    149244: {"Unified_Ideograph", "Ideographic"},
    149245: {"Unified_Ideograph", "Ideographic"},
    149246: {"Unified_Ideograph", "Ideographic"},
    149247: {"Unified_Ideograph", "Ideographic"},
    149248: {"Unified_Ideograph", "Ideographic"},
    149249: {"Unified_Ideograph", "Ideographic"},
    149250: {"Unified_Ideograph", "Ideographic"},
    149251: {"Unified_Ideograph", "Ideographic"},
    149252: {"Unified_Ideograph", "Ideographic"},
    149253: {"Unified_Ideograph", "Ideographic"},
    149254: {"Unified_Ideograph", "Ideographic"},
    149255: {"Unified_Ideograph", "Ideographic"},
    149256: {"Unified_Ideograph", "Ideographic"},
    149257: {"Unified_Ideograph", "Ideographic"},
    149258: {"Unified_Ideograph", "Ideographic"},
    149259: {"Unified_Ideograph", "Ideographic"},
    149260: {"Unified_Ideograph", "Ideographic"},
    149261: {"Unified_Ideograph", "Ideographic"},
    149262: {"Unified_Ideograph", "Ideographic"},
    149263: {"Unified_Ideograph", "Ideographic"},
    149264: {"Unified_Ideograph", "Ideographic"},
    149265: {"Unified_Ideograph", "Ideographic"},
    149266: {"Unified_Ideograph", "Ideographic"},
    149267: {"Unified_Ideograph", "Ideographic"},
    149268: {"Unified_Ideograph", "Ideographic"},
    149269: {"Unified_Ideograph", "Ideographic"},
    149270: {"Unified_Ideograph", "Ideographic"},
    149271: {"Unified_Ideograph", "Ideographic"},
    149272: {"Unified_Ideograph", "Ideographic"},
    149273: {"Unified_Ideograph", "Ideographic"},
    149274: {"Unified_Ideograph", "Ideographic"},
    149275: {"Unified_Ideograph", "Ideographic"},
    149276: {"Unified_Ideograph", "Ideographic"},
    149277: {"Unified_Ideograph", "Ideographic"},
    149278: {"Unified_Ideograph", "Ideographic"},
    149279: {"Unified_Ideograph", "Ideographic"},
    149280: {"Unified_Ideograph", "Ideographic"},
    149281: {"Unified_Ideograph", "Ideographic"},
    149282: {"Unified_Ideograph", "Ideographic"},
    149283: {"Unified_Ideograph", "Ideographic"},
    149284: {"Unified_Ideograph", "Ideographic"},
    149285: {"Unified_Ideograph", "Ideographic"},
    149286: {"Unified_Ideograph", "Ideographic"},
    149287: {"Unified_Ideograph", "Ideographic"},
    149288: {"Unified_Ideograph", "Ideographic"},
    149289: {"Unified_Ideograph", "Ideographic"},
    149290: {"Unified_Ideograph", "Ideographic"},
    149291: {"Unified_Ideograph", "Ideographic"},
    149292: {"Unified_Ideograph", "Ideographic"},
    149293: {"Unified_Ideograph", "Ideographic"},
    149294: {"Unified_Ideograph", "Ideographic"},
    149295: {"Unified_Ideograph", "Ideographic"},
    149296: {"Unified_Ideograph", "Ideographic"},
    149297: {"Unified_Ideograph", "Ideographic"},
    149298: {"Unified_Ideograph", "Ideographic"},
    149299: {"Unified_Ideograph", "Ideographic"},
    149300: {"Unified_Ideograph", "Ideographic"},
    149301: {"Unified_Ideograph", "Ideographic"},
    149302: {"Unified_Ideograph", "Ideographic"},
    149303: {"Unified_Ideograph", "Ideographic"},
    149304: {"Unified_Ideograph", "Ideographic"},
    149305: {"Unified_Ideograph", "Ideographic"},
    149306: {"Unified_Ideograph", "Ideographic"},
    149307: {"Unified_Ideograph", "Ideographic"},
    149308: {"Unified_Ideograph", "Ideographic"},
    149309: {"Unified_Ideograph", "Ideographic"},
    149310: {"Unified_Ideograph", "Ideographic"},
    149311: {"Unified_Ideograph", "Ideographic"},
    149312: {"Unified_Ideograph", "Ideographic"},
    149313: {"Unified_Ideograph", "Ideographic"},
    149314: {"Unified_Ideograph", "Ideographic"},
    149315: {"Unified_Ideograph", "Ideographic"},
    149316: {"Unified_Ideograph", "Ideographic"},
    149317: {"Unified_Ideograph", "Ideographic"},
    149318: {"Unified_Ideograph", "Ideographic"},
    149319: {"Unified_Ideograph", "Ideographic"},
    149320: {"Unified_Ideograph", "Ideographic"},
    149321: {"Unified_Ideograph", "Ideographic"},
    149322: {"Unified_Ideograph", "Ideographic"},
    149323: {"Unified_Ideograph", "Ideographic"},
    149324: {"Unified_Ideograph", "Ideographic"},
    149325: {"Unified_Ideograph", "Ideographic"},
    149326: {"Unified_Ideograph", "Ideographic"},
    149327: {"Unified_Ideograph", "Ideographic"},
    149328: {"Unified_Ideograph", "Ideographic"},
    149329: {"Unified_Ideograph", "Ideographic"},
    149330: {"Unified_Ideograph", "Ideographic"},
    149331: {"Unified_Ideograph", "Ideographic"},
    149332: {"Unified_Ideograph", "Ideographic"},
    149333: {"Unified_Ideograph", "Ideographic"},
    149334: {"Unified_Ideograph", "Ideographic"},
    149335: {"Unified_Ideograph", "Ideographic"},
    149336: {"Unified_Ideograph", "Ideographic"},
    149337: {"Unified_Ideograph", "Ideographic"},
    149338: {"Unified_Ideograph", "Ideographic"},
    149339: {"Unified_Ideograph", "Ideographic"},
    149340: {"Unified_Ideograph", "Ideographic"},
    149341: {"Unified_Ideograph", "Ideographic"},
    149342: {"Unified_Ideograph", "Ideographic"},
    149343: {"Unified_Ideograph", "Ideographic"},
    149344: {"Unified_Ideograph", "Ideographic"},
    149345: {"Unified_Ideograph", "Ideographic"},
    149346: {"Unified_Ideograph", "Ideographic"},
    149347: {"Unified_Ideograph", "Ideographic"},
    149348: {"Unified_Ideograph", "Ideographic"},
    149349: {"Unified_Ideograph", "Ideographic"},
    149350: {"Unified_Ideograph", "Ideographic"},
    149351: {"Unified_Ideograph", "Ideographic"},
    149352: {"Unified_Ideograph", "Ideographic"},
    149353: {"Unified_Ideograph", "Ideographic"},
    149354: {"Unified_Ideograph", "Ideographic"},
    149355: {"Unified_Ideograph", "Ideographic"},
    149356: {"Unified_Ideograph", "Ideographic"},
    149357: {"Unified_Ideograph", "Ideographic"},
    149358: {"Unified_Ideograph", "Ideographic"},
    149359: {"Unified_Ideograph", "Ideographic"},
    149360: {"Unified_Ideograph", "Ideographic"},
    149361: {"Unified_Ideograph", "Ideographic"},
    149362: {"Unified_Ideograph", "Ideographic"},
    149363: {"Unified_Ideograph", "Ideographic"},
    149364: {"Unified_Ideograph", "Ideographic"},
    149365: {"Unified_Ideograph", "Ideographic"},
    149366: {"Unified_Ideograph", "Ideographic"},
    149367: {"Unified_Ideograph", "Ideographic"},
    149368: {"Unified_Ideograph", "Ideographic"},
    149369: {"Unified_Ideograph", "Ideographic"},
    149370: {"Unified_Ideograph", "Ideographic"},
    149371: {"Unified_Ideograph", "Ideographic"},
    149372: {"Unified_Ideograph", "Ideographic"},
    149373: {"Unified_Ideograph", "Ideographic"},
    149374: {"Unified_Ideograph", "Ideographic"},
    149375: {"Unified_Ideograph", "Ideographic"},
    149376: {"Unified_Ideograph", "Ideographic"},
    149377: {"Unified_Ideograph", "Ideographic"},
    149378: {"Unified_Ideograph", "Ideographic"},
    149379: {"Unified_Ideograph", "Ideographic"},
    149380: {"Unified_Ideograph", "Ideographic"},
    149381: {"Unified_Ideograph", "Ideographic"},
    149382: {"Unified_Ideograph", "Ideographic"},
    149383: {"Unified_Ideograph", "Ideographic"},
    149384: {"Unified_Ideograph", "Ideographic"},
    149385: {"Unified_Ideograph", "Ideographic"},
    149386: {"Unified_Ideograph", "Ideographic"},
    149387: {"Unified_Ideograph", "Ideographic"},
    149388: {"Unified_Ideograph", "Ideographic"},
    149389: {"Unified_Ideograph", "Ideographic"},
    149390: {"Unified_Ideograph", "Ideographic"},
    149391: {"Unified_Ideograph", "Ideographic"},
    149392: {"Unified_Ideograph", "Ideographic"},
    149393: {"Unified_Ideograph", "Ideographic"},
    149394: {"Unified_Ideograph", "Ideographic"},
    149395: {"Unified_Ideograph", "Ideographic"},
    149396: {"Unified_Ideograph", "Ideographic"},
    149397: {"Unified_Ideograph", "Ideographic"},
    149398: {"Unified_Ideograph", "Ideographic"},
    149399: {"Unified_Ideograph", "Ideographic"},
    149400: {"Unified_Ideograph", "Ideographic"},
    149401: {"Unified_Ideograph", "Ideographic"},
    149402: {"Unified_Ideograph", "Ideographic"},
    149403: {"Unified_Ideograph", "Ideographic"},
    149404: {"Unified_Ideograph", "Ideographic"},
    149405: {"Unified_Ideograph", "Ideographic"},
    149406: {"Unified_Ideograph", "Ideographic"},
    149407: {"Unified_Ideograph", "Ideographic"},
    149408: {"Unified_Ideograph", "Ideographic"},
    149409: {"Unified_Ideograph", "Ideographic"},
    149410: {"Unified_Ideograph", "Ideographic"},
    149411: {"Unified_Ideograph", "Ideographic"},
    149412: {"Unified_Ideograph", "Ideographic"},
    149413: {"Unified_Ideograph", "Ideographic"},
    149414: {"Unified_Ideograph", "Ideographic"},
    149415: {"Unified_Ideograph", "Ideographic"},
    149416: {"Unified_Ideograph", "Ideographic"},
    149417: {"Unified_Ideograph", "Ideographic"},
    149418: {"Unified_Ideograph", "Ideographic"},
    149419: {"Unified_Ideograph", "Ideographic"},
    149420: {"Unified_Ideograph", "Ideographic"},
    149421: {"Unified_Ideograph", "Ideographic"},
    149422: {"Unified_Ideograph", "Ideographic"},
    149423: {"Unified_Ideograph", "Ideographic"},
    149424: {"Unified_Ideograph", "Ideographic"},
    149425: {"Unified_Ideograph", "Ideographic"},
    149426: {"Unified_Ideograph", "Ideographic"},
    149427: {"Unified_Ideograph", "Ideographic"},
    149428: {"Unified_Ideograph", "Ideographic"},
    149429: {"Unified_Ideograph", "Ideographic"},
    149430: {"Unified_Ideograph", "Ideographic"},
    149431: {"Unified_Ideograph", "Ideographic"},
    149432: {"Unified_Ideograph", "Ideographic"},
    149433: {"Unified_Ideograph", "Ideographic"},
    149434: {"Unified_Ideograph", "Ideographic"},
    149435: {"Unified_Ideograph", "Ideographic"},
    149436: {"Unified_Ideograph", "Ideographic"},
    149437: {"Unified_Ideograph", "Ideographic"},
    149438: {"Unified_Ideograph", "Ideographic"},
    149439: {"Unified_Ideograph", "Ideographic"},
    149440: {"Unified_Ideograph", "Ideographic"},
    149441: {"Unified_Ideograph", "Ideographic"},
    149442: {"Unified_Ideograph", "Ideographic"},
    149443: {"Unified_Ideograph", "Ideographic"},
    149444: {"Unified_Ideograph", "Ideographic"},
    149445: {"Unified_Ideograph", "Ideographic"},
    149446: {"Unified_Ideograph", "Ideographic"},
    149447: {"Unified_Ideograph", "Ideographic"},
    149448: {"Unified_Ideograph", "Ideographic"},
    149449: {"Unified_Ideograph", "Ideographic"},
    149450: {"Unified_Ideograph", "Ideographic"},
    149451: {"Unified_Ideograph", "Ideographic"},
    149452: {"Unified_Ideograph", "Ideographic"},
    149453: {"Unified_Ideograph", "Ideographic"},
    149454: {"Unified_Ideograph", "Ideographic"},
    149455: {"Unified_Ideograph", "Ideographic"},
    149456: {"Unified_Ideograph", "Ideographic"},
    149457: {"Unified_Ideograph", "Ideographic"},
    149458: {"Unified_Ideograph", "Ideographic"},
    149459: {"Unified_Ideograph", "Ideographic"},
    149460: {"Unified_Ideograph", "Ideographic"},
    149461: {"Unified_Ideograph", "Ideographic"},
    149462: {"Unified_Ideograph", "Ideographic"},
    149463: {"Unified_Ideograph", "Ideographic"},
    149464: {"Unified_Ideograph", "Ideographic"},
    149465: {"Unified_Ideograph", "Ideographic"},
    149466: {"Unified_Ideograph", "Ideographic"},
    149467: {"Unified_Ideograph", "Ideographic"},
    149468: {"Unified_Ideograph", "Ideographic"},
    149469: {"Unified_Ideograph", "Ideographic"},
    149470: {"Unified_Ideograph", "Ideographic"},
    149471: {"Unified_Ideograph", "Ideographic"},
    149472: {"Unified_Ideograph", "Ideographic"},
    149473: {"Unified_Ideograph", "Ideographic"},
    149474: {"Unified_Ideograph", "Ideographic"},
    149475: {"Unified_Ideograph", "Ideographic"},
    149476: {"Unified_Ideograph", "Ideographic"},
    149477: {"Unified_Ideograph", "Ideographic"},
    149478: {"Unified_Ideograph", "Ideographic"},
    149479: {"Unified_Ideograph", "Ideographic"},
    149480: {"Unified_Ideograph", "Ideographic"},
    149481: {"Unified_Ideograph", "Ideographic"},
    149482: {"Unified_Ideograph", "Ideographic"},
    149483: {"Unified_Ideograph", "Ideographic"},
    149484: {"Unified_Ideograph", "Ideographic"},
    149485: {"Unified_Ideograph", "Ideographic"},
    149486: {"Unified_Ideograph", "Ideographic"},
    149487: {"Unified_Ideograph", "Ideographic"},
    149488: {"Unified_Ideograph", "Ideographic"},
    149489: {"Unified_Ideograph", "Ideographic"},
    149490: {"Unified_Ideograph", "Ideographic"},
    149491: {"Unified_Ideograph", "Ideographic"},
    149492: {"Unified_Ideograph", "Ideographic"},
    149493: {"Unified_Ideograph", "Ideographic"},
    149494: {"Unified_Ideograph", "Ideographic"},
    149495: {"Unified_Ideograph", "Ideographic"},
    149496: {"Unified_Ideograph", "Ideographic"},
    149497: {"Unified_Ideograph", "Ideographic"},
    149498: {"Unified_Ideograph", "Ideographic"},
    149499: {"Unified_Ideograph", "Ideographic"},
    149500: {"Unified_Ideograph", "Ideographic"},
    149501: {"Unified_Ideograph", "Ideographic"},
    149502: {"Unified_Ideograph", "Ideographic"},
    149503: {"Unified_Ideograph", "Ideographic"},
    149504: {"Unified_Ideograph", "Ideographic"},
    149505: {"Unified_Ideograph", "Ideographic"},
    149506: {"Unified_Ideograph", "Ideographic"},
    149507: {"Unified_Ideograph", "Ideographic"},
    149508: {"Unified_Ideograph", "Ideographic"},
    149509: {"Unified_Ideograph", "Ideographic"},
    149510: {"Unified_Ideograph", "Ideographic"},
    149511: {"Unified_Ideograph", "Ideographic"},
    149512: {"Unified_Ideograph", "Ideographic"},
    149513: {"Unified_Ideograph", "Ideographic"},
    149514: {"Unified_Ideograph", "Ideographic"},
    149515: {"Unified_Ideograph", "Ideographic"},
    149516: {"Unified_Ideograph", "Ideographic"},
    149517: {"Unified_Ideograph", "Ideographic"},
    149518: {"Unified_Ideograph", "Ideographic"},
    149519: {"Unified_Ideograph", "Ideographic"},
    149520: {"Unified_Ideograph", "Ideographic"},
    149521: {"Unified_Ideograph", "Ideographic"},
    149522: {"Unified_Ideograph", "Ideographic"},
    149523: {"Unified_Ideograph", "Ideographic"},
    149524: {"Unified_Ideograph", "Ideographic"},
    149525: {"Unified_Ideograph", "Ideographic"},
    149526: {"Unified_Ideograph", "Ideographic"},
    149527: {"Unified_Ideograph", "Ideographic"},
    149528: {"Unified_Ideograph", "Ideographic"},
    149529: {"Unified_Ideograph", "Ideographic"},
    149530: {"Unified_Ideograph", "Ideographic"},
    149531: {"Unified_Ideograph", "Ideographic"},
    149532: {"Unified_Ideograph", "Ideographic"},
    149533: {"Unified_Ideograph", "Ideographic"},
    149534: {"Unified_Ideograph", "Ideographic"},
    149535: {"Unified_Ideograph", "Ideographic"},
    149536: {"Unified_Ideograph", "Ideographic"},
    149537: {"Unified_Ideograph", "Ideographic"},
    149538: {"Unified_Ideograph", "Ideographic"},
    149539: {"Unified_Ideograph", "Ideographic"},
    149540: {"Unified_Ideograph", "Ideographic"},
    149541: {"Unified_Ideograph", "Ideographic"},
    149542: {"Unified_Ideograph", "Ideographic"},
    149543: {"Unified_Ideograph", "Ideographic"},
    149544: {"Unified_Ideograph", "Ideographic"},
    149545: {"Unified_Ideograph", "Ideographic"},
    149546: {"Unified_Ideograph", "Ideographic"},
    149547: {"Unified_Ideograph", "Ideographic"},
    149548: {"Unified_Ideograph", "Ideographic"},
    149549: {"Unified_Ideograph", "Ideographic"},
    149550: {"Unified_Ideograph", "Ideographic"},
    149551: {"Unified_Ideograph", "Ideographic"},
    149552: {"Unified_Ideograph", "Ideographic"},
    149553: {"Unified_Ideograph", "Ideographic"},
    149554: {"Unified_Ideograph", "Ideographic"},
    149555: {"Unified_Ideograph", "Ideographic"},
    149556: {"Unified_Ideograph", "Ideographic"},
    149557: {"Unified_Ideograph", "Ideographic"},
    149558: {"Unified_Ideograph", "Ideographic"},
    149559: {"Unified_Ideograph", "Ideographic"},
    149560: {"Unified_Ideograph", "Ideographic"},
    149561: {"Unified_Ideograph", "Ideographic"},
    149562: {"Unified_Ideograph", "Ideographic"},
    149563: {"Unified_Ideograph", "Ideographic"},
    149564: {"Unified_Ideograph", "Ideographic"},
    149565: {"Unified_Ideograph", "Ideographic"},
    149566: {"Unified_Ideograph", "Ideographic"},
    149567: {"Unified_Ideograph", "Ideographic"},
    149568: {"Unified_Ideograph", "Ideographic"},
    149569: {"Unified_Ideograph", "Ideographic"},
    149570: {"Unified_Ideograph", "Ideographic"},
    149571: {"Unified_Ideograph", "Ideographic"},
    149572: {"Unified_Ideograph", "Ideographic"},
    149573: {"Unified_Ideograph", "Ideographic"},
    149574: {"Unified_Ideograph", "Ideographic"},
    149575: {"Unified_Ideograph", "Ideographic"},
    149576: {"Unified_Ideograph", "Ideographic"},
    149577: {"Unified_Ideograph", "Ideographic"},
    149578: {"Unified_Ideograph", "Ideographic"},
    149579: {"Unified_Ideograph", "Ideographic"},
    149580: {"Unified_Ideograph", "Ideographic"},
    149581: {"Unified_Ideograph", "Ideographic"},
    149582: {"Unified_Ideograph", "Ideographic"},
    149583: {"Unified_Ideograph", "Ideographic"},
    149584: {"Unified_Ideograph", "Ideographic"},
    149585: {"Unified_Ideograph", "Ideographic"},
    149586: {"Unified_Ideograph", "Ideographic"},
    149587: {"Unified_Ideograph", "Ideographic"},
    149588: {"Unified_Ideograph", "Ideographic"},
    149589: {"Unified_Ideograph", "Ideographic"},
    149590: {"Unified_Ideograph", "Ideographic"},
    149591: {"Unified_Ideograph", "Ideographic"},
    149592: {"Unified_Ideograph", "Ideographic"},
    149593: {"Unified_Ideograph", "Ideographic"},
    149594: {"Unified_Ideograph", "Ideographic"},
    149595: {"Unified_Ideograph", "Ideographic"},
    149596: {"Unified_Ideograph", "Ideographic"},
    149597: {"Unified_Ideograph", "Ideographic"},
    149598: {"Unified_Ideograph", "Ideographic"},
    149599: {"Unified_Ideograph", "Ideographic"},
    149600: {"Unified_Ideograph", "Ideographic"},
    149601: {"Unified_Ideograph", "Ideographic"},
    149602: {"Unified_Ideograph", "Ideographic"},
    149603: {"Unified_Ideograph", "Ideographic"},
    149604: {"Unified_Ideograph", "Ideographic"},
    149605: {"Unified_Ideograph", "Ideographic"},
    149606: {"Unified_Ideograph", "Ideographic"},
    149607: {"Unified_Ideograph", "Ideographic"},
    149608: {"Unified_Ideograph", "Ideographic"},
    149609: {"Unified_Ideograph", "Ideographic"},
    149610: {"Unified_Ideograph", "Ideographic"},
    149611: {"Unified_Ideograph", "Ideographic"},
    149612: {"Unified_Ideograph", "Ideographic"},
    149613: {"Unified_Ideograph", "Ideographic"},
    149614: {"Unified_Ideograph", "Ideographic"},
    149615: {"Unified_Ideograph", "Ideographic"},
    149616: {"Unified_Ideograph", "Ideographic"},
    149617: {"Unified_Ideograph", "Ideographic"},
    149618: {"Unified_Ideograph", "Ideographic"},
    149619: {"Unified_Ideograph", "Ideographic"},
    149620: {"Unified_Ideograph", "Ideographic"},
    149621: {"Unified_Ideograph", "Ideographic"},
    149622: {"Unified_Ideograph", "Ideographic"},
    149623: {"Unified_Ideograph", "Ideographic"},
    149624: {"Unified_Ideograph", "Ideographic"},
    149625: {"Unified_Ideograph", "Ideographic"},
    149626: {"Unified_Ideograph", "Ideographic"},
    149627: {"Unified_Ideograph", "Ideographic"},
    149628: {"Unified_Ideograph", "Ideographic"},
    149629: {"Unified_Ideograph", "Ideographic"},
    149630: {"Unified_Ideograph", "Ideographic"},
    149631: {"Unified_Ideograph", "Ideographic"},
    149632: {"Unified_Ideograph", "Ideographic"},
    149633: {"Unified_Ideograph", "Ideographic"},
    149634: {"Unified_Ideograph", "Ideographic"},
    149635: {"Unified_Ideograph", "Ideographic"},
    149636: {"Unified_Ideograph", "Ideographic"},
    149637: {"Unified_Ideograph", "Ideographic"},
    149638: {"Unified_Ideograph", "Ideographic"},
    149639: {"Unified_Ideograph", "Ideographic"},
    149640: {"Unified_Ideograph", "Ideographic"},
    149641: {"Unified_Ideograph", "Ideographic"},
    149642: {"Unified_Ideograph", "Ideographic"},
    149643: {"Unified_Ideograph", "Ideographic"},
    149644: {"Unified_Ideograph", "Ideographic"},
    149645: {"Unified_Ideograph", "Ideographic"},
    149646: {"Unified_Ideograph", "Ideographic"},
    149647: {"Unified_Ideograph", "Ideographic"},
    149648: {"Unified_Ideograph", "Ideographic"},
    149649: {"Unified_Ideograph", "Ideographic"},
    149650: {"Unified_Ideograph", "Ideographic"},
    149651: {"Unified_Ideograph", "Ideographic"},
    149652: {"Unified_Ideograph", "Ideographic"},
    149653: {"Unified_Ideograph", "Ideographic"},
    149654: {"Unified_Ideograph", "Ideographic"},
    149655: {"Unified_Ideograph", "Ideographic"},
    149656: {"Unified_Ideograph", "Ideographic"},
    149657: {"Unified_Ideograph", "Ideographic"},
    149658: {"Unified_Ideograph", "Ideographic"},
    149659: {"Unified_Ideograph", "Ideographic"},
    149660: {"Unified_Ideograph", "Ideographic"},
    149661: {"Unified_Ideograph", "Ideographic"},
    149662: {"Unified_Ideograph", "Ideographic"},
    149663: {"Unified_Ideograph", "Ideographic"},
    149664: {"Unified_Ideograph", "Ideographic"},
    149665: {"Unified_Ideograph", "Ideographic"},
    149666: {"Unified_Ideograph", "Ideographic"},
    149667: {"Unified_Ideograph", "Ideographic"},
    149668: {"Unified_Ideograph", "Ideographic"},
    149669: {"Unified_Ideograph", "Ideographic"},
    149670: {"Unified_Ideograph", "Ideographic"},
    149671: {"Unified_Ideograph", "Ideographic"},
    149672: {"Unified_Ideograph", "Ideographic"},
    149673: {"Unified_Ideograph", "Ideographic"},
    149674: {"Unified_Ideograph", "Ideographic"},
    149675: {"Unified_Ideograph", "Ideographic"},
    149676: {"Unified_Ideograph", "Ideographic"},
    149677: {"Unified_Ideograph", "Ideographic"},
    149678: {"Unified_Ideograph", "Ideographic"},
    149679: {"Unified_Ideograph", "Ideographic"},
    149680: {"Unified_Ideograph", "Ideographic"},
    149681: {"Unified_Ideograph", "Ideographic"},
    149682: {"Unified_Ideograph", "Ideographic"},
    149683: {"Unified_Ideograph", "Ideographic"},
    149684: {"Unified_Ideograph", "Ideographic"},
    149685: {"Unified_Ideograph", "Ideographic"},
    149686: {"Unified_Ideograph", "Ideographic"},
    149687: {"Unified_Ideograph", "Ideographic"},
    149688: {"Unified_Ideograph", "Ideographic"},
    149689: {"Unified_Ideograph", "Ideographic"},
    149690: {"Unified_Ideograph", "Ideographic"},
    149691: {"Unified_Ideograph", "Ideographic"},
    149692: {"Unified_Ideograph", "Ideographic"},
    149693: {"Unified_Ideograph", "Ideographic"},
    149694: {"Unified_Ideograph", "Ideographic"},
    149695: {"Unified_Ideograph", "Ideographic"},
    149696: {"Unified_Ideograph", "Ideographic"},
    149697: {"Unified_Ideograph", "Ideographic"},
    149698: {"Unified_Ideograph", "Ideographic"},
    149699: {"Unified_Ideograph", "Ideographic"},
    149700: {"Unified_Ideograph", "Ideographic"},
    149701: {"Unified_Ideograph", "Ideographic"},
    149702: {"Unified_Ideograph", "Ideographic"},
    149703: {"Unified_Ideograph", "Ideographic"},
    149704: {"Unified_Ideograph", "Ideographic"},
    149705: {"Unified_Ideograph", "Ideographic"},
    149706: {"Unified_Ideograph", "Ideographic"},
    149707: {"Unified_Ideograph", "Ideographic"},
    149708: {"Unified_Ideograph", "Ideographic"},
    149709: {"Unified_Ideograph", "Ideographic"},
    149710: {"Unified_Ideograph", "Ideographic"},
    149711: {"Unified_Ideograph", "Ideographic"},
    149712: {"Unified_Ideograph", "Ideographic"},
    149713: {"Unified_Ideograph", "Ideographic"},
    149714: {"Unified_Ideograph", "Ideographic"},
    149715: {"Unified_Ideograph", "Ideographic"},
    149716: {"Unified_Ideograph", "Ideographic"},
    149717: {"Unified_Ideograph", "Ideographic"},
    149718: {"Unified_Ideograph", "Ideographic"},
    149719: {"Unified_Ideograph", "Ideographic"},
    149720: {"Unified_Ideograph", "Ideographic"},
    149721: {"Unified_Ideograph", "Ideographic"},
    149722: {"Unified_Ideograph", "Ideographic"},
    149723: {"Unified_Ideograph", "Ideographic"},
    149724: {"Unified_Ideograph", "Ideographic"},
    149725: {"Unified_Ideograph", "Ideographic"},
    149726: {"Unified_Ideograph", "Ideographic"},
    149727: {"Unified_Ideograph", "Ideographic"},
    149728: {"Unified_Ideograph", "Ideographic"},
    149729: {"Unified_Ideograph", "Ideographic"},
    149730: {"Unified_Ideograph", "Ideographic"},
    149731: {"Unified_Ideograph", "Ideographic"},
    149732: {"Unified_Ideograph", "Ideographic"},
    149733: {"Unified_Ideograph", "Ideographic"},
    149734: {"Unified_Ideograph", "Ideographic"},
    149735: {"Unified_Ideograph", "Ideographic"},
    149736: {"Unified_Ideograph", "Ideographic"},
    149737: {"Unified_Ideograph", "Ideographic"},
    149738: {"Unified_Ideograph", "Ideographic"},
    149739: {"Unified_Ideograph", "Ideographic"},
    149740: {"Unified_Ideograph", "Ideographic"},
    149741: {"Unified_Ideograph", "Ideographic"},
    149742: {"Unified_Ideograph", "Ideographic"},
    149743: {"Unified_Ideograph", "Ideographic"},
    149744: {"Unified_Ideograph", "Ideographic"},
    149745: {"Unified_Ideograph", "Ideographic"},
    149746: {"Unified_Ideograph", "Ideographic"},
    149747: {"Unified_Ideograph", "Ideographic"},
    149748: {"Unified_Ideograph", "Ideographic"},
    149749: {"Unified_Ideograph", "Ideographic"},
    149750: {"Unified_Ideograph", "Ideographic"},
    149751: {"Unified_Ideograph", "Ideographic"},
    149752: {"Unified_Ideograph", "Ideographic"},
    149753: {"Unified_Ideograph", "Ideographic"},
    149754: {"Unified_Ideograph", "Ideographic"},
    149755: {"Unified_Ideograph", "Ideographic"},
    149756: {"Unified_Ideograph", "Ideographic"},
    149757: {"Unified_Ideograph", "Ideographic"},
    149758: {"Unified_Ideograph", "Ideographic"},
    149759: {"Unified_Ideograph", "Ideographic"},
    149760: {"Unified_Ideograph", "Ideographic"},
    149761: {"Unified_Ideograph", "Ideographic"},
    149762: {"Unified_Ideograph", "Ideographic"},
    149763: {"Unified_Ideograph", "Ideographic"},
    149764: {"Unified_Ideograph", "Ideographic"},
    149765: {"Unified_Ideograph", "Ideographic"},
    149766: {"Unified_Ideograph", "Ideographic"},
    149767: {"Unified_Ideograph", "Ideographic"},
    149768: {"Unified_Ideograph", "Ideographic"},
    149769: {"Unified_Ideograph", "Ideographic"},
    149770: {"Unified_Ideograph", "Ideographic"},
    149771: {"Unified_Ideograph", "Ideographic"},
    149772: {"Unified_Ideograph", "Ideographic"},
    149773: {"Unified_Ideograph", "Ideographic"},
    149774: {"Unified_Ideograph", "Ideographic"},
    149775: {"Unified_Ideograph", "Ideographic"},
    149776: {"Unified_Ideograph", "Ideographic"},
    149777: {"Unified_Ideograph", "Ideographic"},
    149778: {"Unified_Ideograph", "Ideographic"},
    149779: {"Unified_Ideograph", "Ideographic"},
    149780: {"Unified_Ideograph", "Ideographic"},
    149781: {"Unified_Ideograph", "Ideographic"},
    149782: {"Unified_Ideograph", "Ideographic"},
    149783: {"Unified_Ideograph", "Ideographic"},
    149784: {"Unified_Ideograph", "Ideographic"},
    149785: {"Unified_Ideograph", "Ideographic"},
    149786: {"Unified_Ideograph", "Ideographic"},
    149787: {"Unified_Ideograph", "Ideographic"},
    149788: {"Unified_Ideograph", "Ideographic"},
    149789: {"Unified_Ideograph", "Ideographic"},
    149790: {"Unified_Ideograph", "Ideographic"},
    149791: {"Unified_Ideograph", "Ideographic"},
    149792: {"Unified_Ideograph", "Ideographic"},
    149793: {"Unified_Ideograph", "Ideographic"},
    149794: {"Unified_Ideograph", "Ideographic"},
    149795: {"Unified_Ideograph", "Ideographic"},
    149796: {"Unified_Ideograph", "Ideographic"},
    149797: {"Unified_Ideograph", "Ideographic"},
    149798: {"Unified_Ideograph", "Ideographic"},
    149799: {"Unified_Ideograph", "Ideographic"},
    149800: {"Unified_Ideograph", "Ideographic"},
    149801: {"Unified_Ideograph", "Ideographic"},
    149802: {"Unified_Ideograph", "Ideographic"},
    149803: {"Unified_Ideograph", "Ideographic"},
    149804: {"Unified_Ideograph", "Ideographic"},
    149805: {"Unified_Ideograph", "Ideographic"},
    149806: {"Unified_Ideograph", "Ideographic"},
    149807: {"Unified_Ideograph", "Ideographic"},
    149808: {"Unified_Ideograph", "Ideographic"},
    149809: {"Unified_Ideograph", "Ideographic"},
    149810: {"Unified_Ideograph", "Ideographic"},
    149811: {"Unified_Ideograph", "Ideographic"},
    149812: {"Unified_Ideograph", "Ideographic"},
    149813: {"Unified_Ideograph", "Ideographic"},
    149814: {"Unified_Ideograph", "Ideographic"},
    149815: {"Unified_Ideograph", "Ideographic"},
    149816: {"Unified_Ideograph", "Ideographic"},
    149817: {"Unified_Ideograph", "Ideographic"},
    149818: {"Unified_Ideograph", "Ideographic"},
    149819: {"Unified_Ideograph", "Ideographic"},
    149820: {"Unified_Ideograph", "Ideographic"},
    149821: {"Unified_Ideograph", "Ideographic"},
    149822: {"Unified_Ideograph", "Ideographic"},
    149823: {"Unified_Ideograph", "Ideographic"},
    149824: {"Unified_Ideograph", "Ideographic"},
    149825: {"Unified_Ideograph", "Ideographic"},
    149826: {"Unified_Ideograph", "Ideographic"},
    149827: {"Unified_Ideograph", "Ideographic"},
    149828: {"Unified_Ideograph", "Ideographic"},
    149829: {"Unified_Ideograph", "Ideographic"},
    149830: {"Unified_Ideograph", "Ideographic"},
    149831: {"Unified_Ideograph", "Ideographic"},
    149832: {"Unified_Ideograph", "Ideographic"},
    149833: {"Unified_Ideograph", "Ideographic"},
    149834: {"Unified_Ideograph", "Ideographic"},
    149835: {"Unified_Ideograph", "Ideographic"},
    149836: {"Unified_Ideograph", "Ideographic"},
    149837: {"Unified_Ideograph", "Ideographic"},
    149838: {"Unified_Ideograph", "Ideographic"},
    149839: {"Unified_Ideograph", "Ideographic"},
    149840: {"Unified_Ideograph", "Ideographic"},
    149841: {"Unified_Ideograph", "Ideographic"},
    149842: {"Unified_Ideograph", "Ideographic"},
    149843: {"Unified_Ideograph", "Ideographic"},
    149844: {"Unified_Ideograph", "Ideographic"},
    149845: {"Unified_Ideograph", "Ideographic"},
    149846: {"Unified_Ideograph", "Ideographic"},
    149847: {"Unified_Ideograph", "Ideographic"},
    149848: {"Unified_Ideograph", "Ideographic"},
    149849: {"Unified_Ideograph", "Ideographic"},
    149850: {"Unified_Ideograph", "Ideographic"},
    149851: {"Unified_Ideograph", "Ideographic"},
    149852: {"Unified_Ideograph", "Ideographic"},
    149853: {"Unified_Ideograph", "Ideographic"},
    149854: {"Unified_Ideograph", "Ideographic"},
    149855: {"Unified_Ideograph", "Ideographic"},
    149856: {"Unified_Ideograph", "Ideographic"},
    149857: {"Unified_Ideograph", "Ideographic"},
    149858: {"Unified_Ideograph", "Ideographic"},
    149859: {"Unified_Ideograph", "Ideographic"},
    149860: {"Unified_Ideograph", "Ideographic"},
    149861: {"Unified_Ideograph", "Ideographic"},
    149862: {"Unified_Ideograph", "Ideographic"},
    149863: {"Unified_Ideograph", "Ideographic"},
    149864: {"Unified_Ideograph", "Ideographic"},
    149865: {"Unified_Ideograph", "Ideographic"},
    149866: {"Unified_Ideograph", "Ideographic"},
    149867: {"Unified_Ideograph", "Ideographic"},
    149868: {"Unified_Ideograph", "Ideographic"},
    149869: {"Unified_Ideograph", "Ideographic"},
    149870: {"Unified_Ideograph", "Ideographic"},
    149871: {"Unified_Ideograph", "Ideographic"},
    149872: {"Unified_Ideograph", "Ideographic"},
    149873: {"Unified_Ideograph", "Ideographic"},
    149874: {"Unified_Ideograph", "Ideographic"},
    149875: {"Unified_Ideograph", "Ideographic"},
    149876: {"Unified_Ideograph", "Ideographic"},
    149877: {"Unified_Ideograph", "Ideographic"},
    149878: {"Unified_Ideograph", "Ideographic"},
    149879: {"Unified_Ideograph", "Ideographic"},
    149880: {"Unified_Ideograph", "Ideographic"},
    149881: {"Unified_Ideograph", "Ideographic"},
    149882: {"Unified_Ideograph", "Ideographic"},
    149883: {"Unified_Ideograph", "Ideographic"},
    149884: {"Unified_Ideograph", "Ideographic"},
    149885: {"Unified_Ideograph", "Ideographic"},
    149886: {"Unified_Ideograph", "Ideographic"},
    149887: {"Unified_Ideograph", "Ideographic"},
    149888: {"Unified_Ideograph", "Ideographic"},
    149889: {"Unified_Ideograph", "Ideographic"},
    149890: {"Unified_Ideograph", "Ideographic"},
    149891: {"Unified_Ideograph", "Ideographic"},
    149892: {"Unified_Ideograph", "Ideographic"},
    149893: {"Unified_Ideograph", "Ideographic"},
    149894: {"Unified_Ideograph", "Ideographic"},
    149895: {"Unified_Ideograph", "Ideographic"},
    149896: {"Unified_Ideograph", "Ideographic"},
    149897: {"Unified_Ideograph", "Ideographic"},
    149898: {"Unified_Ideograph", "Ideographic"},
    149899: {"Unified_Ideograph", "Ideographic"},
    149900: {"Unified_Ideograph", "Ideographic"},
    149901: {"Unified_Ideograph", "Ideographic"},
    149902: {"Unified_Ideograph", "Ideographic"},
    149903: {"Unified_Ideograph", "Ideographic"},
    149904: {"Unified_Ideograph", "Ideographic"},
    149905: {"Unified_Ideograph", "Ideographic"},
    149906: {"Unified_Ideograph", "Ideographic"},
    149907: {"Unified_Ideograph", "Ideographic"},
    149908: {"Unified_Ideograph", "Ideographic"},
    149909: {"Unified_Ideograph", "Ideographic"},
    149910: {"Unified_Ideograph", "Ideographic"},
    149911: {"Unified_Ideograph", "Ideographic"},
    149912: {"Unified_Ideograph", "Ideographic"},
    149913: {"Unified_Ideograph", "Ideographic"},
    149914: {"Unified_Ideograph", "Ideographic"},
    149915: {"Unified_Ideograph", "Ideographic"},
    149916: {"Unified_Ideograph", "Ideographic"},
    149917: {"Unified_Ideograph", "Ideographic"},
    149918: {"Unified_Ideograph", "Ideographic"},
    149919: {"Unified_Ideograph", "Ideographic"},
    149920: {"Unified_Ideograph", "Ideographic"},
    149921: {"Unified_Ideograph", "Ideographic"},
    149922: {"Unified_Ideograph", "Ideographic"},
    149923: {"Unified_Ideograph", "Ideographic"},
    149924: {"Unified_Ideograph", "Ideographic"},
    149925: {"Unified_Ideograph", "Ideographic"},
    149926: {"Unified_Ideograph", "Ideographic"},
    149927: {"Unified_Ideograph", "Ideographic"},
    149928: {"Unified_Ideograph", "Ideographic"},
    149929: {"Unified_Ideograph", "Ideographic"},
    149930: {"Unified_Ideograph", "Ideographic"},
    149931: {"Unified_Ideograph", "Ideographic"},
    149932: {"Unified_Ideograph", "Ideographic"},
    149933: {"Unified_Ideograph", "Ideographic"},
    149934: {"Unified_Ideograph", "Ideographic"},
    149935: {"Unified_Ideograph", "Ideographic"},
    149936: {"Unified_Ideograph", "Ideographic"},
    149937: {"Unified_Ideograph", "Ideographic"},
    149938: {"Unified_Ideograph", "Ideographic"},
    149939: {"Unified_Ideograph", "Ideographic"},
    149940: {"Unified_Ideograph", "Ideographic"},
    149941: {"Unified_Ideograph", "Ideographic"},
    149942: {"Unified_Ideograph", "Ideographic"},
    149943: {"Unified_Ideograph", "Ideographic"},
    149944: {"Unified_Ideograph", "Ideographic"},
    149945: {"Unified_Ideograph", "Ideographic"},
    149946: {"Unified_Ideograph", "Ideographic"},
    149947: {"Unified_Ideograph", "Ideographic"},
    149948: {"Unified_Ideograph", "Ideographic"},
    149949: {"Unified_Ideograph", "Ideographic"},
    149950: {"Unified_Ideograph", "Ideographic"},
    149951: {"Unified_Ideograph", "Ideographic"},
    149952: {"Unified_Ideograph", "Ideographic"},
    149953: {"Unified_Ideograph", "Ideographic"},
    149954: {"Unified_Ideograph", "Ideographic"},
    149955: {"Unified_Ideograph", "Ideographic"},
    149956: {"Unified_Ideograph", "Ideographic"},
    149957: {"Unified_Ideograph", "Ideographic"},
    149958: {"Unified_Ideograph", "Ideographic"},
    149959: {"Unified_Ideograph", "Ideographic"},
    149960: {"Unified_Ideograph", "Ideographic"},
    149961: {"Unified_Ideograph", "Ideographic"},
    149962: {"Unified_Ideograph", "Ideographic"},
    149963: {"Unified_Ideograph", "Ideographic"},
    149964: {"Unified_Ideograph", "Ideographic"},
    149965: {"Unified_Ideograph", "Ideographic"},
    149966: {"Unified_Ideograph", "Ideographic"},
    149967: {"Unified_Ideograph", "Ideographic"},
    149968: {"Unified_Ideograph", "Ideographic"},
    149969: {"Unified_Ideograph", "Ideographic"},
    149970: {"Unified_Ideograph", "Ideographic"},
    149971: {"Unified_Ideograph", "Ideographic"},
    149972: {"Unified_Ideograph", "Ideographic"},
    149973: {"Unified_Ideograph", "Ideographic"},
    149974: {"Unified_Ideograph", "Ideographic"},
    149975: {"Unified_Ideograph", "Ideographic"},
    149976: {"Unified_Ideograph", "Ideographic"},
    149977: {"Unified_Ideograph", "Ideographic"},
    149978: {"Unified_Ideograph", "Ideographic"},
    149979: {"Unified_Ideograph", "Ideographic"},
    149980: {"Unified_Ideograph", "Ideographic"},
    149981: {"Unified_Ideograph", "Ideographic"},
    149982: {"Unified_Ideograph", "Ideographic"},
    149983: {"Unified_Ideograph", "Ideographic"},
    149984: {"Unified_Ideograph", "Ideographic"},
    149985: {"Unified_Ideograph", "Ideographic"},
    149986: {"Unified_Ideograph", "Ideographic"},
    149987: {"Unified_Ideograph", "Ideographic"},
    149988: {"Unified_Ideograph", "Ideographic"},
    149989: {"Unified_Ideograph", "Ideographic"},
    149990: {"Unified_Ideograph", "Ideographic"},
    149991: {"Unified_Ideograph", "Ideographic"},
    149992: {"Unified_Ideograph", "Ideographic"},
    149993: {"Unified_Ideograph", "Ideographic"},
    149994: {"Unified_Ideograph", "Ideographic"},
    149995: {"Unified_Ideograph", "Ideographic"},
    149996: {"Unified_Ideograph", "Ideographic"},
    149997: {"Unified_Ideograph", "Ideographic"},
    149998: {"Unified_Ideograph", "Ideographic"},
    149999: {"Unified_Ideograph", "Ideographic"},
    150000: {"Unified_Ideograph", "Ideographic"},
    150001: {"Unified_Ideograph", "Ideographic"},
    150002: {"Unified_Ideograph", "Ideographic"},
    150003: {"Unified_Ideograph", "Ideographic"},
    150004: {"Unified_Ideograph", "Ideographic"},
    150005: {"Unified_Ideograph", "Ideographic"},
    150006: {"Unified_Ideograph", "Ideographic"},
    150007: {"Unified_Ideograph", "Ideographic"},
    150008: {"Unified_Ideograph", "Ideographic"},
    150009: {"Unified_Ideograph", "Ideographic"},
    150010: {"Unified_Ideograph", "Ideographic"},
    150011: {"Unified_Ideograph", "Ideographic"},
    150012: {"Unified_Ideograph", "Ideographic"},
    150013: {"Unified_Ideograph", "Ideographic"},
    150014: {"Unified_Ideograph", "Ideographic"},
    150015: {"Unified_Ideograph", "Ideographic"},
    150016: {"Unified_Ideograph", "Ideographic"},
    150017: {"Unified_Ideograph", "Ideographic"},
    150018: {"Unified_Ideograph", "Ideographic"},
    150019: {"Unified_Ideograph", "Ideographic"},
    150020: {"Unified_Ideograph", "Ideographic"},
    150021: {"Unified_Ideograph", "Ideographic"},
    150022: {"Unified_Ideograph", "Ideographic"},
    150023: {"Unified_Ideograph", "Ideographic"},
    150024: {"Unified_Ideograph", "Ideographic"},
    150025: {"Unified_Ideograph", "Ideographic"},
    150026: {"Unified_Ideograph", "Ideographic"},
    150027: {"Unified_Ideograph", "Ideographic"},
    150028: {"Unified_Ideograph", "Ideographic"},
    150029: {"Unified_Ideograph", "Ideographic"},
    150030: {"Unified_Ideograph", "Ideographic"},
    150031: {"Unified_Ideograph", "Ideographic"},
    150032: {"Unified_Ideograph", "Ideographic"},
    150033: {"Unified_Ideograph", "Ideographic"},
    150034: {"Unified_Ideograph", "Ideographic"},
    150035: {"Unified_Ideograph", "Ideographic"},
    150036: {"Unified_Ideograph", "Ideographic"},
    150037: {"Unified_Ideograph", "Ideographic"},
    150038: {"Unified_Ideograph", "Ideographic"},
    150039: {"Unified_Ideograph", "Ideographic"},
    150040: {"Unified_Ideograph", "Ideographic"},
    150041: {"Unified_Ideograph", "Ideographic"},
    150042: {"Unified_Ideograph", "Ideographic"},
    150043: {"Unified_Ideograph", "Ideographic"},
    150044: {"Unified_Ideograph", "Ideographic"},
    150045: {"Unified_Ideograph", "Ideographic"},
    150046: {"Unified_Ideograph", "Ideographic"},
    150047: {"Unified_Ideograph", "Ideographic"},
    150048: {"Unified_Ideograph", "Ideographic"},
    150049: {"Unified_Ideograph", "Ideographic"},
    150050: {"Unified_Ideograph", "Ideographic"},
    150051: {"Unified_Ideograph", "Ideographic"},
    150052: {"Unified_Ideograph", "Ideographic"},
    150053: {"Unified_Ideograph", "Ideographic"},
    150054: {"Unified_Ideograph", "Ideographic"},
    150055: {"Unified_Ideograph", "Ideographic"},
    150056: {"Unified_Ideograph", "Ideographic"},
    150057: {"Unified_Ideograph", "Ideographic"},
    150058: {"Unified_Ideograph", "Ideographic"},
    150059: {"Unified_Ideograph", "Ideographic"},
    150060: {"Unified_Ideograph", "Ideographic"},
    150061: {"Unified_Ideograph", "Ideographic"},
    150062: {"Unified_Ideograph", "Ideographic"},
    150063: {"Unified_Ideograph", "Ideographic"},
    150064: {"Unified_Ideograph", "Ideographic"},
    150065: {"Unified_Ideograph", "Ideographic"},
    150066: {"Unified_Ideograph", "Ideographic"},
    150067: {"Unified_Ideograph", "Ideographic"},
    150068: {"Unified_Ideograph", "Ideographic"},
    150069: {"Unified_Ideograph", "Ideographic"},
    150070: {"Unified_Ideograph", "Ideographic"},
    150071: {"Unified_Ideograph", "Ideographic"},
    150072: {"Unified_Ideograph", "Ideographic"},
    150073: {"Unified_Ideograph", "Ideographic"},
    150074: {"Unified_Ideograph", "Ideographic"},
    150075: {"Unified_Ideograph", "Ideographic"},
    150076: {"Unified_Ideograph", "Ideographic"},
    150077: {"Unified_Ideograph", "Ideographic"},
    150078: {"Unified_Ideograph", "Ideographic"},
    150079: {"Unified_Ideograph", "Ideographic"},
    150080: {"Unified_Ideograph", "Ideographic"},
    150081: {"Unified_Ideograph", "Ideographic"},
    150082: {"Unified_Ideograph", "Ideographic"},
    150083: {"Unified_Ideograph", "Ideographic"},
    150084: {"Unified_Ideograph", "Ideographic"},
    150085: {"Unified_Ideograph", "Ideographic"},
    150086: {"Unified_Ideograph", "Ideographic"},
    150087: {"Unified_Ideograph", "Ideographic"},
    150088: {"Unified_Ideograph", "Ideographic"},
    150089: {"Unified_Ideograph", "Ideographic"},
    150090: {"Unified_Ideograph", "Ideographic"},
    150091: {"Unified_Ideograph", "Ideographic"},
    150092: {"Unified_Ideograph", "Ideographic"},
    150093: {"Unified_Ideograph", "Ideographic"},
    150094: {"Unified_Ideograph", "Ideographic"},
    150095: {"Unified_Ideograph", "Ideographic"},
    150096: {"Unified_Ideograph", "Ideographic"},
    150097: {"Unified_Ideograph", "Ideographic"},
    150098: {"Unified_Ideograph", "Ideographic"},
    150099: {"Unified_Ideograph", "Ideographic"},
    150100: {"Unified_Ideograph", "Ideographic"},
    150101: {"Unified_Ideograph", "Ideographic"},
    150102: {"Unified_Ideograph", "Ideographic"},
    150103: {"Unified_Ideograph", "Ideographic"},
    150104: {"Unified_Ideograph", "Ideographic"},
    150105: {"Unified_Ideograph", "Ideographic"},
    150106: {"Unified_Ideograph", "Ideographic"},
    150107: {"Unified_Ideograph", "Ideographic"},
    150108: {"Unified_Ideograph", "Ideographic"},
    150109: {"Unified_Ideograph", "Ideographic"},
    150110: {"Unified_Ideograph", "Ideographic"},
    150111: {"Unified_Ideograph", "Ideographic"},
    150112: {"Unified_Ideograph", "Ideographic"},
    150113: {"Unified_Ideograph", "Ideographic"},
    150114: {"Unified_Ideograph", "Ideographic"},
    150115: {"Unified_Ideograph", "Ideographic"},
    150116: {"Unified_Ideograph", "Ideographic"},
    150117: {"Unified_Ideograph", "Ideographic"},
    150118: {"Unified_Ideograph", "Ideographic"},
    150119: {"Unified_Ideograph", "Ideographic"},
    150120: {"Unified_Ideograph", "Ideographic"},
    150121: {"Unified_Ideograph", "Ideographic"},
    150122: {"Unified_Ideograph", "Ideographic"},
    150123: {"Unified_Ideograph", "Ideographic"},
    150124: {"Unified_Ideograph", "Ideographic"},
    150125: {"Unified_Ideograph", "Ideographic"},
    150126: {"Unified_Ideograph", "Ideographic"},
    150127: {"Unified_Ideograph", "Ideographic"},
    150128: {"Unified_Ideograph", "Ideographic"},
    150129: {"Unified_Ideograph", "Ideographic"},
    150130: {"Unified_Ideograph", "Ideographic"},
    150131: {"Unified_Ideograph", "Ideographic"},
    150132: {"Unified_Ideograph", "Ideographic"},
    150133: {"Unified_Ideograph", "Ideographic"},
    150134: {"Unified_Ideograph", "Ideographic"},
    150135: {"Unified_Ideograph", "Ideographic"},
    150136: {"Unified_Ideograph", "Ideographic"},
    150137: {"Unified_Ideograph", "Ideographic"},
    150138: {"Unified_Ideograph", "Ideographic"},
    150139: {"Unified_Ideograph", "Ideographic"},
    150140: {"Unified_Ideograph", "Ideographic"},
    150141: {"Unified_Ideograph", "Ideographic"},
    150142: {"Unified_Ideograph", "Ideographic"},
    150143: {"Unified_Ideograph", "Ideographic"},
    150144: {"Unified_Ideograph", "Ideographic"},
    150145: {"Unified_Ideograph", "Ideographic"},
    150146: {"Unified_Ideograph", "Ideographic"},
    150147: {"Unified_Ideograph", "Ideographic"},
    150148: {"Unified_Ideograph", "Ideographic"},
    150149: {"Unified_Ideograph", "Ideographic"},
    150150: {"Unified_Ideograph", "Ideographic"},
    150151: {"Unified_Ideograph", "Ideographic"},
    150152: {"Unified_Ideograph", "Ideographic"},
    150153: {"Unified_Ideograph", "Ideographic"},
    150154: {"Unified_Ideograph", "Ideographic"},
    150155: {"Unified_Ideograph", "Ideographic"},
    150156: {"Unified_Ideograph", "Ideographic"},
    150157: {"Unified_Ideograph", "Ideographic"},
    150158: {"Unified_Ideograph", "Ideographic"},
    150159: {"Unified_Ideograph", "Ideographic"},
    150160: {"Unified_Ideograph", "Ideographic"},
    150161: {"Unified_Ideograph", "Ideographic"},
    150162: {"Unified_Ideograph", "Ideographic"},
    150163: {"Unified_Ideograph", "Ideographic"},
    150164: {"Unified_Ideograph", "Ideographic"},
    150165: {"Unified_Ideograph", "Ideographic"},
    150166: {"Unified_Ideograph", "Ideographic"},
    150167: {"Unified_Ideograph", "Ideographic"},
    150168: {"Unified_Ideograph", "Ideographic"},
    150169: {"Unified_Ideograph", "Ideographic"},
    150170: {"Unified_Ideograph", "Ideographic"},
    150171: {"Unified_Ideograph", "Ideographic"},
    150172: {"Unified_Ideograph", "Ideographic"},
    150173: {"Unified_Ideograph", "Ideographic"},
    150174: {"Unified_Ideograph", "Ideographic"},
    150175: {"Unified_Ideograph", "Ideographic"},
    150176: {"Unified_Ideograph", "Ideographic"},
    150177: {"Unified_Ideograph", "Ideographic"},
    150178: {"Unified_Ideograph", "Ideographic"},
    150179: {"Unified_Ideograph", "Ideographic"},
    150180: {"Unified_Ideograph", "Ideographic"},
    150181: {"Unified_Ideograph", "Ideographic"},
    150182: {"Unified_Ideograph", "Ideographic"},
    150183: {"Unified_Ideograph", "Ideographic"},
    150184: {"Unified_Ideograph", "Ideographic"},
    150185: {"Unified_Ideograph", "Ideographic"},
    150186: {"Unified_Ideograph", "Ideographic"},
    150187: {"Unified_Ideograph", "Ideographic"},
    150188: {"Unified_Ideograph", "Ideographic"},
    150189: {"Unified_Ideograph", "Ideographic"},
    150190: {"Unified_Ideograph", "Ideographic"},
    150191: {"Unified_Ideograph", "Ideographic"},
    150192: {"Unified_Ideograph", "Ideographic"},
    150193: {"Unified_Ideograph", "Ideographic"},
    150194: {"Unified_Ideograph", "Ideographic"},
    150195: {"Unified_Ideograph", "Ideographic"},
    150196: {"Unified_Ideograph", "Ideographic"},
    150197: {"Unified_Ideograph", "Ideographic"},
    150198: {"Unified_Ideograph", "Ideographic"},
    150199: {"Unified_Ideograph", "Ideographic"},
    150200: {"Unified_Ideograph", "Ideographic"},
    150201: {"Unified_Ideograph", "Ideographic"},
    150202: {"Unified_Ideograph", "Ideographic"},
    150203: {"Unified_Ideograph", "Ideographic"},
    150204: {"Unified_Ideograph", "Ideographic"},
    150205: {"Unified_Ideograph", "Ideographic"},
    150206: {"Unified_Ideograph", "Ideographic"},
    150207: {"Unified_Ideograph", "Ideographic"},
    150208: {"Unified_Ideograph", "Ideographic"},
    150209: {"Unified_Ideograph", "Ideographic"},
    150210: {"Unified_Ideograph", "Ideographic"},
    150211: {"Unified_Ideograph", "Ideographic"},
    150212: {"Unified_Ideograph", "Ideographic"},
    150213: {"Unified_Ideograph", "Ideographic"},
    150214: {"Unified_Ideograph", "Ideographic"},
    150215: {"Unified_Ideograph", "Ideographic"},
    150216: {"Unified_Ideograph", "Ideographic"},
    150217: {"Unified_Ideograph", "Ideographic"},
    150218: {"Unified_Ideograph", "Ideographic"},
    150219: {"Unified_Ideograph", "Ideographic"},
    150220: {"Unified_Ideograph", "Ideographic"},
    150221: {"Unified_Ideograph", "Ideographic"},
    150222: {"Unified_Ideograph", "Ideographic"},
    150223: {"Unified_Ideograph", "Ideographic"},
    150224: {"Unified_Ideograph", "Ideographic"},
    150225: {"Unified_Ideograph", "Ideographic"},
    150226: {"Unified_Ideograph", "Ideographic"},
    150227: {"Unified_Ideograph", "Ideographic"},
    150228: {"Unified_Ideograph", "Ideographic"},
    150229: {"Unified_Ideograph", "Ideographic"},
    150230: {"Unified_Ideograph", "Ideographic"},
    150231: {"Unified_Ideograph", "Ideographic"},
    150232: {"Unified_Ideograph", "Ideographic"},
    150233: {"Unified_Ideograph", "Ideographic"},
    150234: {"Unified_Ideograph", "Ideographic"},
    150235: {"Unified_Ideograph", "Ideographic"},
    150236: {"Unified_Ideograph", "Ideographic"},
    150237: {"Unified_Ideograph", "Ideographic"},
    150238: {"Unified_Ideograph", "Ideographic"},
    150239: {"Unified_Ideograph", "Ideographic"},
    150240: {"Unified_Ideograph", "Ideographic"},
    150241: {"Unified_Ideograph", "Ideographic"},
    150242: {"Unified_Ideograph", "Ideographic"},
    150243: {"Unified_Ideograph", "Ideographic"},
    150244: {"Unified_Ideograph", "Ideographic"},
    150245: {"Unified_Ideograph", "Ideographic"},
    150246: {"Unified_Ideograph", "Ideographic"},
    150247: {"Unified_Ideograph", "Ideographic"},
    150248: {"Unified_Ideograph", "Ideographic"},
    150249: {"Unified_Ideograph", "Ideographic"},
    150250: {"Unified_Ideograph", "Ideographic"},
    150251: {"Unified_Ideograph", "Ideographic"},
    150252: {"Unified_Ideograph", "Ideographic"},
    150253: {"Unified_Ideograph", "Ideographic"},
    150254: {"Unified_Ideograph", "Ideographic"},
    150255: {"Unified_Ideograph", "Ideographic"},
    150256: {"Unified_Ideograph", "Ideographic"},
    150257: {"Unified_Ideograph", "Ideographic"},
    150258: {"Unified_Ideograph", "Ideographic"},
    150259: {"Unified_Ideograph", "Ideographic"},
    150260: {"Unified_Ideograph", "Ideographic"},
    150261: {"Unified_Ideograph", "Ideographic"},
    150262: {"Unified_Ideograph", "Ideographic"},
    150263: {"Unified_Ideograph", "Ideographic"},
    150264: {"Unified_Ideograph", "Ideographic"},
    150265: {"Unified_Ideograph", "Ideographic"},
    150266: {"Unified_Ideograph", "Ideographic"},
    150267: {"Unified_Ideograph", "Ideographic"},
    150268: {"Unified_Ideograph", "Ideographic"},
    150269: {"Unified_Ideograph", "Ideographic"},
    150270: {"Unified_Ideograph", "Ideographic"},
    150271: {"Unified_Ideograph", "Ideographic"},
    150272: {"Unified_Ideograph", "Ideographic"},
    150273: {"Unified_Ideograph", "Ideographic"},
    150274: {"Unified_Ideograph", "Ideographic"},
    150275: {"Unified_Ideograph", "Ideographic"},
    150276: {"Unified_Ideograph", "Ideographic"},
    150277: {"Unified_Ideograph", "Ideographic"},
    150278: {"Unified_Ideograph", "Ideographic"},
    150279: {"Unified_Ideograph", "Ideographic"},
    150280: {"Unified_Ideograph", "Ideographic"},
    150281: {"Unified_Ideograph", "Ideographic"},
    150282: {"Unified_Ideograph", "Ideographic"},
    150283: {"Unified_Ideograph", "Ideographic"},
    150284: {"Unified_Ideograph", "Ideographic"},
    150285: {"Unified_Ideograph", "Ideographic"},
    150286: {"Unified_Ideograph", "Ideographic"},
    150287: {"Unified_Ideograph", "Ideographic"},
    150288: {"Unified_Ideograph", "Ideographic"},
    150289: {"Unified_Ideograph", "Ideographic"},
    150290: {"Unified_Ideograph", "Ideographic"},
    150291: {"Unified_Ideograph", "Ideographic"},
    150292: {"Unified_Ideograph", "Ideographic"},
    150293: {"Unified_Ideograph", "Ideographic"},
    150294: {"Unified_Ideograph", "Ideographic"},
    150295: {"Unified_Ideograph", "Ideographic"},
    150296: {"Unified_Ideograph", "Ideographic"},
    150297: {"Unified_Ideograph", "Ideographic"},
    150298: {"Unified_Ideograph", "Ideographic"},
    150299: {"Unified_Ideograph", "Ideographic"},
    150300: {"Unified_Ideograph", "Ideographic"},
    150301: {"Unified_Ideograph", "Ideographic"},
    150302: {"Unified_Ideograph", "Ideographic"},
    150303: {"Unified_Ideograph", "Ideographic"},
    150304: {"Unified_Ideograph", "Ideographic"},
    150305: {"Unified_Ideograph", "Ideographic"},
    150306: {"Unified_Ideograph", "Ideographic"},
    150307: {"Unified_Ideograph", "Ideographic"},
    150308: {"Unified_Ideograph", "Ideographic"},
    150309: {"Unified_Ideograph", "Ideographic"},
    150310: {"Unified_Ideograph", "Ideographic"},
    150311: {"Unified_Ideograph", "Ideographic"},
    150312: {"Unified_Ideograph", "Ideographic"},
    150313: {"Unified_Ideograph", "Ideographic"},
    150314: {"Unified_Ideograph", "Ideographic"},
    150315: {"Unified_Ideograph", "Ideographic"},
    150316: {"Unified_Ideograph", "Ideographic"},
    150317: {"Unified_Ideograph", "Ideographic"},
    150318: {"Unified_Ideograph", "Ideographic"},
    150319: {"Unified_Ideograph", "Ideographic"},
    150320: {"Unified_Ideograph", "Ideographic"},
    150321: {"Unified_Ideograph", "Ideographic"},
    150322: {"Unified_Ideograph", "Ideographic"},
    150323: {"Unified_Ideograph", "Ideographic"},
    150324: {"Unified_Ideograph", "Ideographic"},
    150325: {"Unified_Ideograph", "Ideographic"},
    150326: {"Unified_Ideograph", "Ideographic"},
    150327: {"Unified_Ideograph", "Ideographic"},
    150328: {"Unified_Ideograph", "Ideographic"},
    150329: {"Unified_Ideograph", "Ideographic"},
    150330: {"Unified_Ideograph", "Ideographic"},
    150331: {"Unified_Ideograph", "Ideographic"},
    150332: {"Unified_Ideograph", "Ideographic"},
    150333: {"Unified_Ideograph", "Ideographic"},
    150334: {"Unified_Ideograph", "Ideographic"},
    150335: {"Unified_Ideograph", "Ideographic"},
    150336: {"Unified_Ideograph", "Ideographic"},
    150337: {"Unified_Ideograph", "Ideographic"},
    150338: {"Unified_Ideograph", "Ideographic"},
    150339: {"Unified_Ideograph", "Ideographic"},
    150340: {"Unified_Ideograph", "Ideographic"},
    150341: {"Unified_Ideograph", "Ideographic"},
    150342: {"Unified_Ideograph", "Ideographic"},
    150343: {"Unified_Ideograph", "Ideographic"},
    150344: {"Unified_Ideograph", "Ideographic"},
    150345: {"Unified_Ideograph", "Ideographic"},
    150346: {"Unified_Ideograph", "Ideographic"},
    150347: {"Unified_Ideograph", "Ideographic"},
    150348: {"Unified_Ideograph", "Ideographic"},
    150349: {"Unified_Ideograph", "Ideographic"},
    150350: {"Unified_Ideograph", "Ideographic"},
    150351: {"Unified_Ideograph", "Ideographic"},
    150352: {"Unified_Ideograph", "Ideographic"},
    150353: {"Unified_Ideograph", "Ideographic"},
    150354: {"Unified_Ideograph", "Ideographic"},
    150355: {"Unified_Ideograph", "Ideographic"},
    150356: {"Unified_Ideograph", "Ideographic"},
    150357: {"Unified_Ideograph", "Ideographic"},
    150358: {"Unified_Ideograph", "Ideographic"},
    150359: {"Unified_Ideograph", "Ideographic"},
    150360: {"Unified_Ideograph", "Ideographic"},
    150361: {"Unified_Ideograph", "Ideographic"},
    150362: {"Unified_Ideograph", "Ideographic"},
    150363: {"Unified_Ideograph", "Ideographic"},
    150364: {"Unified_Ideograph", "Ideographic"},
    150365: {"Unified_Ideograph", "Ideographic"},
    150366: {"Unified_Ideograph", "Ideographic"},
    150367: {"Unified_Ideograph", "Ideographic"},
    150368: {"Unified_Ideograph", "Ideographic"},
    150369: {"Unified_Ideograph", "Ideographic"},
    150370: {"Unified_Ideograph", "Ideographic"},
    150371: {"Unified_Ideograph", "Ideographic"},
    150372: {"Unified_Ideograph", "Ideographic"},
    150373: {"Unified_Ideograph", "Ideographic"},
    150374: {"Unified_Ideograph", "Ideographic"},
    150375: {"Unified_Ideograph", "Ideographic"},
    150376: {"Unified_Ideograph", "Ideographic"},
    150377: {"Unified_Ideograph", "Ideographic"},
    150378: {"Unified_Ideograph", "Ideographic"},
    150379: {"Unified_Ideograph", "Ideographic"},
    150380: {"Unified_Ideograph", "Ideographic"},
    150381: {"Unified_Ideograph", "Ideographic"},
    150382: {"Unified_Ideograph", "Ideographic"},
    150383: {"Unified_Ideograph", "Ideographic"},
    150384: {"Unified_Ideograph", "Ideographic"},
    150385: {"Unified_Ideograph", "Ideographic"},
    150386: {"Unified_Ideograph", "Ideographic"},
    150387: {"Unified_Ideograph", "Ideographic"},
    150388: {"Unified_Ideograph", "Ideographic"},
    150389: {"Unified_Ideograph", "Ideographic"},
    150390: {"Unified_Ideograph", "Ideographic"},
    150391: {"Unified_Ideograph", "Ideographic"},
    150392: {"Unified_Ideograph", "Ideographic"},
    150393: {"Unified_Ideograph", "Ideographic"},
    150394: {"Unified_Ideograph", "Ideographic"},
    150395: {"Unified_Ideograph", "Ideographic"},
    150396: {"Unified_Ideograph", "Ideographic"},
    150397: {"Unified_Ideograph", "Ideographic"},
    150398: {"Unified_Ideograph", "Ideographic"},
    150399: {"Unified_Ideograph", "Ideographic"},
    150400: {"Unified_Ideograph", "Ideographic"},
    150401: {"Unified_Ideograph", "Ideographic"},
    150402: {"Unified_Ideograph", "Ideographic"},
    150403: {"Unified_Ideograph", "Ideographic"},
    150404: {"Unified_Ideograph", "Ideographic"},
    150405: {"Unified_Ideograph", "Ideographic"},
    150406: {"Unified_Ideograph", "Ideographic"},
    150407: {"Unified_Ideograph", "Ideographic"},
    150408: {"Unified_Ideograph", "Ideographic"},
    150409: {"Unified_Ideograph", "Ideographic"},
    150410: {"Unified_Ideograph", "Ideographic"},
    150411: {"Unified_Ideograph", "Ideographic"},
    150412: {"Unified_Ideograph", "Ideographic"},
    150413: {"Unified_Ideograph", "Ideographic"},
    150414: {"Unified_Ideograph", "Ideographic"},
    150415: {"Unified_Ideograph", "Ideographic"},
    150416: {"Unified_Ideograph", "Ideographic"},
    150417: {"Unified_Ideograph", "Ideographic"},
    150418: {"Unified_Ideograph", "Ideographic"},
    150419: {"Unified_Ideograph", "Ideographic"},
    150420: {"Unified_Ideograph", "Ideographic"},
    150421: {"Unified_Ideograph", "Ideographic"},
    150422: {"Unified_Ideograph", "Ideographic"},
    150423: {"Unified_Ideograph", "Ideographic"},
    150424: {"Unified_Ideograph", "Ideographic"},
    150425: {"Unified_Ideograph", "Ideographic"},
    150426: {"Unified_Ideograph", "Ideographic"},
    150427: {"Unified_Ideograph", "Ideographic"},
    150428: {"Unified_Ideograph", "Ideographic"},
    150429: {"Unified_Ideograph", "Ideographic"},
    150430: {"Unified_Ideograph", "Ideographic"},
    150431: {"Unified_Ideograph", "Ideographic"},
    150432: {"Unified_Ideograph", "Ideographic"},
    150433: {"Unified_Ideograph", "Ideographic"},
    150434: {"Unified_Ideograph", "Ideographic"},
    150435: {"Unified_Ideograph", "Ideographic"},
    150436: {"Unified_Ideograph", "Ideographic"},
    150437: {"Unified_Ideograph", "Ideographic"},
    150438: {"Unified_Ideograph", "Ideographic"},
    150439: {"Unified_Ideograph", "Ideographic"},
    150440: {"Unified_Ideograph", "Ideographic"},
    150441: {"Unified_Ideograph", "Ideographic"},
    150442: {"Unified_Ideograph", "Ideographic"},
    150443: {"Unified_Ideograph", "Ideographic"},
    150444: {"Unified_Ideograph", "Ideographic"},
    150445: {"Unified_Ideograph", "Ideographic"},
    150446: {"Unified_Ideograph", "Ideographic"},
    150447: {"Unified_Ideograph", "Ideographic"},
    150448: {"Unified_Ideograph", "Ideographic"},
    150449: {"Unified_Ideograph", "Ideographic"},
    150450: {"Unified_Ideograph", "Ideographic"},
    150451: {"Unified_Ideograph", "Ideographic"},
    150452: {"Unified_Ideograph", "Ideographic"},
    150453: {"Unified_Ideograph", "Ideographic"},
    150454: {"Unified_Ideograph", "Ideographic"},
    150455: {"Unified_Ideograph", "Ideographic"},
    150456: {"Unified_Ideograph", "Ideographic"},
    150457: {"Unified_Ideograph", "Ideographic"},
    150458: {"Unified_Ideograph", "Ideographic"},
    150459: {"Unified_Ideograph", "Ideographic"},
    150460: {"Unified_Ideograph", "Ideographic"},
    150461: {"Unified_Ideograph", "Ideographic"},
    150462: {"Unified_Ideograph", "Ideographic"},
    150463: {"Unified_Ideograph", "Ideographic"},
    150464: {"Unified_Ideograph", "Ideographic"},
    150465: {"Unified_Ideograph", "Ideographic"},
    150466: {"Unified_Ideograph", "Ideographic"},
    150467: {"Unified_Ideograph", "Ideographic"},
    150468: {"Unified_Ideograph", "Ideographic"},
    150469: {"Unified_Ideograph", "Ideographic"},
    150470: {"Unified_Ideograph", "Ideographic"},
    150471: {"Unified_Ideograph", "Ideographic"},
    150472: {"Unified_Ideograph", "Ideographic"},
    150473: {"Unified_Ideograph", "Ideographic"},
    150474: {"Unified_Ideograph", "Ideographic"},
    150475: {"Unified_Ideograph", "Ideographic"},
    150476: {"Unified_Ideograph", "Ideographic"},
    150477: {"Unified_Ideograph", "Ideographic"},
    150478: {"Unified_Ideograph", "Ideographic"},
    150479: {"Unified_Ideograph", "Ideographic"},
    150480: {"Unified_Ideograph", "Ideographic"},
    150481: {"Unified_Ideograph", "Ideographic"},
    150482: {"Unified_Ideograph", "Ideographic"},
    150483: {"Unified_Ideograph", "Ideographic"},
    150484: {"Unified_Ideograph", "Ideographic"},
    150485: {"Unified_Ideograph", "Ideographic"},
    150486: {"Unified_Ideograph", "Ideographic"},
    150487: {"Unified_Ideograph", "Ideographic"},
    150488: {"Unified_Ideograph", "Ideographic"},
    150489: {"Unified_Ideograph", "Ideographic"},
    150490: {"Unified_Ideograph", "Ideographic"},
    150491: {"Unified_Ideograph", "Ideographic"},
    150492: {"Unified_Ideograph", "Ideographic"},
    150493: {"Unified_Ideograph", "Ideographic"},
    150494: {"Unified_Ideograph", "Ideographic"},
    150495: {"Unified_Ideograph", "Ideographic"},
    150496: {"Unified_Ideograph", "Ideographic"},
    150497: {"Unified_Ideograph", "Ideographic"},
    150498: {"Unified_Ideograph", "Ideographic"},
    150499: {"Unified_Ideograph", "Ideographic"},
    150500: {"Unified_Ideograph", "Ideographic"},
    150501: {"Unified_Ideograph", "Ideographic"},
    150502: {"Unified_Ideograph", "Ideographic"},
    150503: {"Unified_Ideograph", "Ideographic"},
    150504: {"Unified_Ideograph", "Ideographic"},
    150505: {"Unified_Ideograph", "Ideographic"},
    150506: {"Unified_Ideograph", "Ideographic"},
    150507: {"Unified_Ideograph", "Ideographic"},
    150508: {"Unified_Ideograph", "Ideographic"},
    150509: {"Unified_Ideograph", "Ideographic"},
    150510: {"Unified_Ideograph", "Ideographic"},
    150511: {"Unified_Ideograph", "Ideographic"},
    150512: {"Unified_Ideograph", "Ideographic"},
    150513: {"Unified_Ideograph", "Ideographic"},
    150514: {"Unified_Ideograph", "Ideographic"},
    150515: {"Unified_Ideograph", "Ideographic"},
    150516: {"Unified_Ideograph", "Ideographic"},
    150517: {"Unified_Ideograph", "Ideographic"},
    150518: {"Unified_Ideograph", "Ideographic"},
    150519: {"Unified_Ideograph", "Ideographic"},
    150520: {"Unified_Ideograph", "Ideographic"},
    150521: {"Unified_Ideograph", "Ideographic"},
    150522: {"Unified_Ideograph", "Ideographic"},
    150523: {"Unified_Ideograph", "Ideographic"},
    150524: {"Unified_Ideograph", "Ideographic"},
    150525: {"Unified_Ideograph", "Ideographic"},
    150526: {"Unified_Ideograph", "Ideographic"},
    150527: {"Unified_Ideograph", "Ideographic"},
    150528: {"Unified_Ideograph", "Ideographic"},
    150529: {"Unified_Ideograph", "Ideographic"},
    150530: {"Unified_Ideograph", "Ideographic"},
    150531: {"Unified_Ideograph", "Ideographic"},
    150532: {"Unified_Ideograph", "Ideographic"},
    150533: {"Unified_Ideograph", "Ideographic"},
    150534: {"Unified_Ideograph", "Ideographic"},
    150535: {"Unified_Ideograph", "Ideographic"},
    150536: {"Unified_Ideograph", "Ideographic"},
    150537: {"Unified_Ideograph", "Ideographic"},
    150538: {"Unified_Ideograph", "Ideographic"},
    150539: {"Unified_Ideograph", "Ideographic"},
    150540: {"Unified_Ideograph", "Ideographic"},
    150541: {"Unified_Ideograph", "Ideographic"},
    150542: {"Unified_Ideograph", "Ideographic"},
    150543: {"Unified_Ideograph", "Ideographic"},
    150544: {"Unified_Ideograph", "Ideographic"},
    150545: {"Unified_Ideograph", "Ideographic"},
    150546: {"Unified_Ideograph", "Ideographic"},
    150547: {"Unified_Ideograph", "Ideographic"},
    150548: {"Unified_Ideograph", "Ideographic"},
    150549: {"Unified_Ideograph", "Ideographic"},
    150550: {"Unified_Ideograph", "Ideographic"},
    150551: {"Unified_Ideograph", "Ideographic"},
    150552: {"Unified_Ideograph", "Ideographic"},
    150553: {"Unified_Ideograph", "Ideographic"},
    150554: {"Unified_Ideograph", "Ideographic"},
    150555: {"Unified_Ideograph", "Ideographic"},
    150556: {"Unified_Ideograph", "Ideographic"},
    150557: {"Unified_Ideograph", "Ideographic"},
    150558: {"Unified_Ideograph", "Ideographic"},
    150559: {"Unified_Ideograph", "Ideographic"},
    150560: {"Unified_Ideograph", "Ideographic"},
    150561: {"Unified_Ideograph", "Ideographic"},
    150562: {"Unified_Ideograph", "Ideographic"},
    150563: {"Unified_Ideograph", "Ideographic"},
    150564: {"Unified_Ideograph", "Ideographic"},
    150565: {"Unified_Ideograph", "Ideographic"},
    150566: {"Unified_Ideograph", "Ideographic"},
    150567: {"Unified_Ideograph", "Ideographic"},
    150568: {"Unified_Ideograph", "Ideographic"},
    150569: {"Unified_Ideograph", "Ideographic"},
    150570: {"Unified_Ideograph", "Ideographic"},
    150571: {"Unified_Ideograph", "Ideographic"},
    150572: {"Unified_Ideograph", "Ideographic"},
    150573: {"Unified_Ideograph", "Ideographic"},
    150574: {"Unified_Ideograph", "Ideographic"},
    150575: {"Unified_Ideograph", "Ideographic"},
    150576: {"Unified_Ideograph", "Ideographic"},
    150577: {"Unified_Ideograph", "Ideographic"},
    150578: {"Unified_Ideograph", "Ideographic"},
    150579: {"Unified_Ideograph", "Ideographic"},
    150580: {"Unified_Ideograph", "Ideographic"},
    150581: {"Unified_Ideograph", "Ideographic"},
    150582: {"Unified_Ideograph", "Ideographic"},
    150583: {"Unified_Ideograph", "Ideographic"},
    150584: {"Unified_Ideograph", "Ideographic"},
    150585: {"Unified_Ideograph", "Ideographic"},
    150586: {"Unified_Ideograph", "Ideographic"},
    150587: {"Unified_Ideograph", "Ideographic"},
    150588: {"Unified_Ideograph", "Ideographic"},
    150589: {"Unified_Ideograph", "Ideographic"},
    150590: {"Unified_Ideograph", "Ideographic"},
    150591: {"Unified_Ideograph", "Ideographic"},
    150592: {"Unified_Ideograph", "Ideographic"},
    150593: {"Unified_Ideograph", "Ideographic"},
    150594: {"Unified_Ideograph", "Ideographic"},
    150595: {"Unified_Ideograph", "Ideographic"},
    150596: {"Unified_Ideograph", "Ideographic"},
    150597: {"Unified_Ideograph", "Ideographic"},
    150598: {"Unified_Ideograph", "Ideographic"},
    150599: {"Unified_Ideograph", "Ideographic"},
    150600: {"Unified_Ideograph", "Ideographic"},
    150601: {"Unified_Ideograph", "Ideographic"},
    150602: {"Unified_Ideograph", "Ideographic"},
    150603: {"Unified_Ideograph", "Ideographic"},
    150604: {"Unified_Ideograph", "Ideographic"},
    150605: {"Unified_Ideograph", "Ideographic"},
    150606: {"Unified_Ideograph", "Ideographic"},
    150607: {"Unified_Ideograph", "Ideographic"},
    150608: {"Unified_Ideograph", "Ideographic"},
    150609: {"Unified_Ideograph", "Ideographic"},
    150610: {"Unified_Ideograph", "Ideographic"},
    150611: {"Unified_Ideograph", "Ideographic"},
    150612: {"Unified_Ideograph", "Ideographic"},
    150613: {"Unified_Ideograph", "Ideographic"},
    150614: {"Unified_Ideograph", "Ideographic"},
    150615: {"Unified_Ideograph", "Ideographic"},
    150616: {"Unified_Ideograph", "Ideographic"},
    150617: {"Unified_Ideograph", "Ideographic"},
    150618: {"Unified_Ideograph", "Ideographic"},
    150619: {"Unified_Ideograph", "Ideographic"},
    150620: {"Unified_Ideograph", "Ideographic"},
    150621: {"Unified_Ideograph", "Ideographic"},
    150622: {"Unified_Ideograph", "Ideographic"},
    150623: {"Unified_Ideograph", "Ideographic"},
    150624: {"Unified_Ideograph", "Ideographic"},
    150625: {"Unified_Ideograph", "Ideographic"},
    150626: {"Unified_Ideograph", "Ideographic"},
    150627: {"Unified_Ideograph", "Ideographic"},
    150628: {"Unified_Ideograph", "Ideographic"},
    150629: {"Unified_Ideograph", "Ideographic"},
    150630: {"Unified_Ideograph", "Ideographic"},
    150631: {"Unified_Ideograph", "Ideographic"},
    150632: {"Unified_Ideograph", "Ideographic"},
    150633: {"Unified_Ideograph", "Ideographic"},
    150634: {"Unified_Ideograph", "Ideographic"},
    150635: {"Unified_Ideograph", "Ideographic"},
    150636: {"Unified_Ideograph", "Ideographic"},
    150637: {"Unified_Ideograph", "Ideographic"},
    150638: {"Unified_Ideograph", "Ideographic"},
    150639: {"Unified_Ideograph", "Ideographic"},
    150640: {"Unified_Ideograph", "Ideographic"},
    150641: {"Unified_Ideograph", "Ideographic"},
    150642: {"Unified_Ideograph", "Ideographic"},
    150643: {"Unified_Ideograph", "Ideographic"},
    150644: {"Unified_Ideograph", "Ideographic"},
    150645: {"Unified_Ideograph", "Ideographic"},
    150646: {"Unified_Ideograph", "Ideographic"},
    150647: {"Unified_Ideograph", "Ideographic"},
    150648: {"Unified_Ideograph", "Ideographic"},
    150649: {"Unified_Ideograph", "Ideographic"},
    150650: {"Unified_Ideograph", "Ideographic"},
    150651: {"Unified_Ideograph", "Ideographic"},
    150652: {"Unified_Ideograph", "Ideographic"},
    150653: {"Unified_Ideograph", "Ideographic"},
    150654: {"Unified_Ideograph", "Ideographic"},
    150655: {"Unified_Ideograph", "Ideographic"},
    150656: {"Unified_Ideograph", "Ideographic"},
    150657: {"Unified_Ideograph", "Ideographic"},
    150658: {"Unified_Ideograph", "Ideographic"},
    150659: {"Unified_Ideograph", "Ideographic"},
    150660: {"Unified_Ideograph", "Ideographic"},
    150661: {"Unified_Ideograph", "Ideographic"},
    150662: {"Unified_Ideograph", "Ideographic"},
    150663: {"Unified_Ideograph", "Ideographic"},
    150664: {"Unified_Ideograph", "Ideographic"},
    150665: {"Unified_Ideograph", "Ideographic"},
    150666: {"Unified_Ideograph", "Ideographic"},
    150667: {"Unified_Ideograph", "Ideographic"},
    150668: {"Unified_Ideograph", "Ideographic"},
    150669: {"Unified_Ideograph", "Ideographic"},
    150670: {"Unified_Ideograph", "Ideographic"},
    150671: {"Unified_Ideograph", "Ideographic"},
    150672: {"Unified_Ideograph", "Ideographic"},
    150673: {"Unified_Ideograph", "Ideographic"},
    150674: {"Unified_Ideograph", "Ideographic"},
    150675: {"Unified_Ideograph", "Ideographic"},
    150676: {"Unified_Ideograph", "Ideographic"},
    150677: {"Unified_Ideograph", "Ideographic"},
    150678: {"Unified_Ideograph", "Ideographic"},
    150679: {"Unified_Ideograph", "Ideographic"},
    150680: {"Unified_Ideograph", "Ideographic"},
    150681: {"Unified_Ideograph", "Ideographic"},
    150682: {"Unified_Ideograph", "Ideographic"},
    150683: {"Unified_Ideograph", "Ideographic"},
    150684: {"Unified_Ideograph", "Ideographic"},
    150685: {"Unified_Ideograph", "Ideographic"},
    150686: {"Unified_Ideograph", "Ideographic"},
    150687: {"Unified_Ideograph", "Ideographic"},
    150688: {"Unified_Ideograph", "Ideographic"},
    150689: {"Unified_Ideograph", "Ideographic"},
    150690: {"Unified_Ideograph", "Ideographic"},
    150691: {"Unified_Ideograph", "Ideographic"},
    150692: {"Unified_Ideograph", "Ideographic"},
    150693: {"Unified_Ideograph", "Ideographic"},
    150694: {"Unified_Ideograph", "Ideographic"},
    150695: {"Unified_Ideograph", "Ideographic"},
    150696: {"Unified_Ideograph", "Ideographic"},
    150697: {"Unified_Ideograph", "Ideographic"},
    150698: {"Unified_Ideograph", "Ideographic"},
    150699: {"Unified_Ideograph", "Ideographic"},
    150700: {"Unified_Ideograph", "Ideographic"},
    150701: {"Unified_Ideograph", "Ideographic"},
    150702: {"Unified_Ideograph", "Ideographic"},
    150703: {"Unified_Ideograph", "Ideographic"},
    150704: {"Unified_Ideograph", "Ideographic"},
    150705: {"Unified_Ideograph", "Ideographic"},
    150706: {"Unified_Ideograph", "Ideographic"},
    150707: {"Unified_Ideograph", "Ideographic"},
    150708: {"Unified_Ideograph", "Ideographic"},
    150709: {"Unified_Ideograph", "Ideographic"},
    150710: {"Unified_Ideograph", "Ideographic"},
    150711: {"Unified_Ideograph", "Ideographic"},
    150712: {"Unified_Ideograph", "Ideographic"},
    150713: {"Unified_Ideograph", "Ideographic"},
    150714: {"Unified_Ideograph", "Ideographic"},
    150715: {"Unified_Ideograph", "Ideographic"},
    150716: {"Unified_Ideograph", "Ideographic"},
    150717: {"Unified_Ideograph", "Ideographic"},
    150718: {"Unified_Ideograph", "Ideographic"},
    150719: {"Unified_Ideograph", "Ideographic"},
    150720: {"Unified_Ideograph", "Ideographic"},
    150721: {"Unified_Ideograph", "Ideographic"},
    150722: {"Unified_Ideograph", "Ideographic"},
    150723: {"Unified_Ideograph", "Ideographic"},
    150724: {"Unified_Ideograph", "Ideographic"},
    150725: {"Unified_Ideograph", "Ideographic"},
    150726: {"Unified_Ideograph", "Ideographic"},
    150727: {"Unified_Ideograph", "Ideographic"},
    150728: {"Unified_Ideograph", "Ideographic"},
    150729: {"Unified_Ideograph", "Ideographic"},
    150730: {"Unified_Ideograph", "Ideographic"},
    150731: {"Unified_Ideograph", "Ideographic"},
    150732: {"Unified_Ideograph", "Ideographic"},
    150733: {"Unified_Ideograph", "Ideographic"},
    150734: {"Unified_Ideograph", "Ideographic"},
    150735: {"Unified_Ideograph", "Ideographic"},
    150736: {"Unified_Ideograph", "Ideographic"},
    150737: {"Unified_Ideograph", "Ideographic"},
    150738: {"Unified_Ideograph", "Ideographic"},
    150739: {"Unified_Ideograph", "Ideographic"},
    150740: {"Unified_Ideograph", "Ideographic"},
    150741: {"Unified_Ideograph", "Ideographic"},
    150742: {"Unified_Ideograph", "Ideographic"},
    150743: {"Unified_Ideograph", "Ideographic"},
    150744: {"Unified_Ideograph", "Ideographic"},
    150745: {"Unified_Ideograph", "Ideographic"},
    150746: {"Unified_Ideograph", "Ideographic"},
    150747: {"Unified_Ideograph", "Ideographic"},
    150748: {"Unified_Ideograph", "Ideographic"},
    150749: {"Unified_Ideograph", "Ideographic"},
    150750: {"Unified_Ideograph", "Ideographic"},
    150751: {"Unified_Ideograph", "Ideographic"},
    150752: {"Unified_Ideograph", "Ideographic"},
    150753: {"Unified_Ideograph", "Ideographic"},
    150754: {"Unified_Ideograph", "Ideographic"},
    150755: {"Unified_Ideograph", "Ideographic"},
    150756: {"Unified_Ideograph", "Ideographic"},
    150757: {"Unified_Ideograph", "Ideographic"},
    150758: {"Unified_Ideograph", "Ideographic"},
    150759: {"Unified_Ideograph", "Ideographic"},
    150760: {"Unified_Ideograph", "Ideographic"},
    150761: {"Unified_Ideograph", "Ideographic"},
    150762: {"Unified_Ideograph", "Ideographic"},
    150763: {"Unified_Ideograph", "Ideographic"},
    150764: {"Unified_Ideograph", "Ideographic"},
    150765: {"Unified_Ideograph", "Ideographic"},
    150766: {"Unified_Ideograph", "Ideographic"},
    150767: {"Unified_Ideograph", "Ideographic"},
    150768: {"Unified_Ideograph", "Ideographic"},
    150769: {"Unified_Ideograph", "Ideographic"},
    150770: {"Unified_Ideograph", "Ideographic"},
    150771: {"Unified_Ideograph", "Ideographic"},
    150772: {"Unified_Ideograph", "Ideographic"},
    150773: {"Unified_Ideograph", "Ideographic"},
    150774: {"Unified_Ideograph", "Ideographic"},
    150775: {"Unified_Ideograph", "Ideographic"},
    150776: {"Unified_Ideograph", "Ideographic"},
    150777: {"Unified_Ideograph", "Ideographic"},
    150778: {"Unified_Ideograph", "Ideographic"},
    150779: {"Unified_Ideograph", "Ideographic"},
    150780: {"Unified_Ideograph", "Ideographic"},
    150781: {"Unified_Ideograph", "Ideographic"},
    150782: {"Unified_Ideograph", "Ideographic"},
    150783: {"Unified_Ideograph", "Ideographic"},
    150784: {"Unified_Ideograph", "Ideographic"},
    150785: {"Unified_Ideograph", "Ideographic"},
    150786: {"Unified_Ideograph", "Ideographic"},
    150787: {"Unified_Ideograph", "Ideographic"},
    150788: {"Unified_Ideograph", "Ideographic"},
    150789: {"Unified_Ideograph", "Ideographic"},
    150790: {"Unified_Ideograph", "Ideographic"},
    150791: {"Unified_Ideograph", "Ideographic"},
    150792: {"Unified_Ideograph", "Ideographic"},
    150793: {"Unified_Ideograph", "Ideographic"},
    150794: {"Unified_Ideograph", "Ideographic"},
    150795: {"Unified_Ideograph", "Ideographic"},
    150796: {"Unified_Ideograph", "Ideographic"},
    150797: {"Unified_Ideograph", "Ideographic"},
    150798: {"Unified_Ideograph", "Ideographic"},
    150799: {"Unified_Ideograph", "Ideographic"},
    150800: {"Unified_Ideograph", "Ideographic"},
    150801: {"Unified_Ideograph", "Ideographic"},
    150802: {"Unified_Ideograph", "Ideographic"},
    150803: {"Unified_Ideograph", "Ideographic"},
    150804: {"Unified_Ideograph", "Ideographic"},
    150805: {"Unified_Ideograph", "Ideographic"},
    150806: {"Unified_Ideograph", "Ideographic"},
    150807: {"Unified_Ideograph", "Ideographic"},
    150808: {"Unified_Ideograph", "Ideographic"},
    150809: {"Unified_Ideograph", "Ideographic"},
    150810: {"Unified_Ideograph", "Ideographic"},
    150811: {"Unified_Ideograph", "Ideographic"},
    150812: {"Unified_Ideograph", "Ideographic"},
    150813: {"Unified_Ideograph", "Ideographic"},
    150814: {"Unified_Ideograph", "Ideographic"},
    150815: {"Unified_Ideograph", "Ideographic"},
    150816: {"Unified_Ideograph", "Ideographic"},
    150817: {"Unified_Ideograph", "Ideographic"},
    150818: {"Unified_Ideograph", "Ideographic"},
    150819: {"Unified_Ideograph", "Ideographic"},
    150820: {"Unified_Ideograph", "Ideographic"},
    150821: {"Unified_Ideograph", "Ideographic"},
    150822: {"Unified_Ideograph", "Ideographic"},
    150823: {"Unified_Ideograph", "Ideographic"},
    150824: {"Unified_Ideograph", "Ideographic"},
    150825: {"Unified_Ideograph", "Ideographic"},
    150826: {"Unified_Ideograph", "Ideographic"},
    150827: {"Unified_Ideograph", "Ideographic"},
    150828: {"Unified_Ideograph", "Ideographic"},
    150829: {"Unified_Ideograph", "Ideographic"},
    150830: {"Unified_Ideograph", "Ideographic"},
    150831: {"Unified_Ideograph", "Ideographic"},
    150832: {"Unified_Ideograph", "Ideographic"},
    150833: {"Unified_Ideograph", "Ideographic"},
    150834: {"Unified_Ideograph", "Ideographic"},
    150835: {"Unified_Ideograph", "Ideographic"},
    150836: {"Unified_Ideograph", "Ideographic"},
    150837: {"Unified_Ideograph", "Ideographic"},
    150838: {"Unified_Ideograph", "Ideographic"},
    150839: {"Unified_Ideograph", "Ideographic"},
    150840: {"Unified_Ideograph", "Ideographic"},
    150841: {"Unified_Ideograph", "Ideographic"},
    150842: {"Unified_Ideograph", "Ideographic"},
    150843: {"Unified_Ideograph", "Ideographic"},
    150844: {"Unified_Ideograph", "Ideographic"},
    150845: {"Unified_Ideograph", "Ideographic"},
    150846: {"Unified_Ideograph", "Ideographic"},
    150847: {"Unified_Ideograph", "Ideographic"},
    150848: {"Unified_Ideograph", "Ideographic"},
    150849: {"Unified_Ideograph", "Ideographic"},
    150850: {"Unified_Ideograph", "Ideographic"},
    150851: {"Unified_Ideograph", "Ideographic"},
    150852: {"Unified_Ideograph", "Ideographic"},
    150853: {"Unified_Ideograph", "Ideographic"},
    150854: {"Unified_Ideograph", "Ideographic"},
    150855: {"Unified_Ideograph", "Ideographic"},
    150856: {"Unified_Ideograph", "Ideographic"},
    150857: {"Unified_Ideograph", "Ideographic"},
    150858: {"Unified_Ideograph", "Ideographic"},
    150859: {"Unified_Ideograph", "Ideographic"},
    150860: {"Unified_Ideograph", "Ideographic"},
    150861: {"Unified_Ideograph", "Ideographic"},
    150862: {"Unified_Ideograph", "Ideographic"},
    150863: {"Unified_Ideograph", "Ideographic"},
    150864: {"Unified_Ideograph", "Ideographic"},
    150865: {"Unified_Ideograph", "Ideographic"},
    150866: {"Unified_Ideograph", "Ideographic"},
    150867: {"Unified_Ideograph", "Ideographic"},
    150868: {"Unified_Ideograph", "Ideographic"},
    150869: {"Unified_Ideograph", "Ideographic"},
    150870: {"Unified_Ideograph", "Ideographic"},
    150871: {"Unified_Ideograph", "Ideographic"},
    150872: {"Unified_Ideograph", "Ideographic"},
    150873: {"Unified_Ideograph", "Ideographic"},
    150874: {"Unified_Ideograph", "Ideographic"},
    150875: {"Unified_Ideograph", "Ideographic"},
    150876: {"Unified_Ideograph", "Ideographic"},
    150877: {"Unified_Ideograph", "Ideographic"},
    150878: {"Unified_Ideograph", "Ideographic"},
    150879: {"Unified_Ideograph", "Ideographic"},
    150880: {"Unified_Ideograph", "Ideographic"},
    150881: {"Unified_Ideograph", "Ideographic"},
    150882: {"Unified_Ideograph", "Ideographic"},
    150883: {"Unified_Ideograph", "Ideographic"},
    150884: {"Unified_Ideograph", "Ideographic"},
    150885: {"Unified_Ideograph", "Ideographic"},
    150886: {"Unified_Ideograph", "Ideographic"},
    150887: {"Unified_Ideograph", "Ideographic"},
    150888: {"Unified_Ideograph", "Ideographic"},
    150889: {"Unified_Ideograph", "Ideographic"},
    150890: {"Unified_Ideograph", "Ideographic"},
    150891: {"Unified_Ideograph", "Ideographic"},
    150892: {"Unified_Ideograph", "Ideographic"},
    150893: {"Unified_Ideograph", "Ideographic"},
    150894: {"Unified_Ideograph", "Ideographic"},
    150895: {"Unified_Ideograph", "Ideographic"},
    150896: {"Unified_Ideograph", "Ideographic"},
    150897: {"Unified_Ideograph", "Ideographic"},
    150898: {"Unified_Ideograph", "Ideographic"},
    150899: {"Unified_Ideograph", "Ideographic"},
    150900: {"Unified_Ideograph", "Ideographic"},
    150901: {"Unified_Ideograph", "Ideographic"},
    150902: {"Unified_Ideograph", "Ideographic"},
    150903: {"Unified_Ideograph", "Ideographic"},
    150904: {"Unified_Ideograph", "Ideographic"},
    150905: {"Unified_Ideograph", "Ideographic"},
    150906: {"Unified_Ideograph", "Ideographic"},
    150907: {"Unified_Ideograph", "Ideographic"},
    150908: {"Unified_Ideograph", "Ideographic"},
    150909: {"Unified_Ideograph", "Ideographic"},
    150910: {"Unified_Ideograph", "Ideographic"},
    150911: {"Unified_Ideograph", "Ideographic"},
    150912: {"Unified_Ideograph", "Ideographic"},
    150913: {"Unified_Ideograph", "Ideographic"},
    150914: {"Unified_Ideograph", "Ideographic"},
    150915: {"Unified_Ideograph", "Ideographic"},
    150916: {"Unified_Ideograph", "Ideographic"},
    150917: {"Unified_Ideograph", "Ideographic"},
    150918: {"Unified_Ideograph", "Ideographic"},
    150919: {"Unified_Ideograph", "Ideographic"},
    150920: {"Unified_Ideograph", "Ideographic"},
    150921: {"Unified_Ideograph", "Ideographic"},
    150922: {"Unified_Ideograph", "Ideographic"},
    150923: {"Unified_Ideograph", "Ideographic"},
    150924: {"Unified_Ideograph", "Ideographic"},
    150925: {"Unified_Ideograph", "Ideographic"},
    150926: {"Unified_Ideograph", "Ideographic"},
    150927: {"Unified_Ideograph", "Ideographic"},
    150928: {"Unified_Ideograph", "Ideographic"},
    150929: {"Unified_Ideograph", "Ideographic"},
    150930: {"Unified_Ideograph", "Ideographic"},
    150931: {"Unified_Ideograph", "Ideographic"},
    150932: {"Unified_Ideograph", "Ideographic"},
    150933: {"Unified_Ideograph", "Ideographic"},
    150934: {"Unified_Ideograph", "Ideographic"},
    150935: {"Unified_Ideograph", "Ideographic"},
    150936: {"Unified_Ideograph", "Ideographic"},
    150937: {"Unified_Ideograph", "Ideographic"},
    150938: {"Unified_Ideograph", "Ideographic"},
    150939: {"Unified_Ideograph", "Ideographic"},
    150940: {"Unified_Ideograph", "Ideographic"},
    150941: {"Unified_Ideograph", "Ideographic"},
    150942: {"Unified_Ideograph", "Ideographic"},
    150943: {"Unified_Ideograph", "Ideographic"},
    150944: {"Unified_Ideograph", "Ideographic"},
    150945: {"Unified_Ideograph", "Ideographic"},
    150946: {"Unified_Ideograph", "Ideographic"},
    150947: {"Unified_Ideograph", "Ideographic"},
    150948: {"Unified_Ideograph", "Ideographic"},
    150949: {"Unified_Ideograph", "Ideographic"},
    150950: {"Unified_Ideograph", "Ideographic"},
    150951: {"Unified_Ideograph", "Ideographic"},
    150952: {"Unified_Ideograph", "Ideographic"},
    150953: {"Unified_Ideograph", "Ideographic"},
    150954: {"Unified_Ideograph", "Ideographic"},
    150955: {"Unified_Ideograph", "Ideographic"},
    150956: {"Unified_Ideograph", "Ideographic"},
    150957: {"Unified_Ideograph", "Ideographic"},
    150958: {"Unified_Ideograph", "Ideographic"},
    150959: {"Unified_Ideograph", "Ideographic"},
    150960: {"Unified_Ideograph", "Ideographic"},
    150961: {"Unified_Ideograph", "Ideographic"},
    150962: {"Unified_Ideograph", "Ideographic"},
    150963: {"Unified_Ideograph", "Ideographic"},
    150964: {"Unified_Ideograph", "Ideographic"},
    150965: {"Unified_Ideograph", "Ideographic"},
    150966: {"Unified_Ideograph", "Ideographic"},
    150967: {"Unified_Ideograph", "Ideographic"},
    150968: {"Unified_Ideograph", "Ideographic"},
    150969: {"Unified_Ideograph", "Ideographic"},
    150970: {"Unified_Ideograph", "Ideographic"},
    150971: {"Unified_Ideograph", "Ideographic"},
    150972: {"Unified_Ideograph", "Ideographic"},
    150973: {"Unified_Ideograph", "Ideographic"},
    150974: {"Unified_Ideograph", "Ideographic"},
    150975: {"Unified_Ideograph", "Ideographic"},
    150976: {"Unified_Ideograph", "Ideographic"},
    150977: {"Unified_Ideograph", "Ideographic"},
    150978: {"Unified_Ideograph", "Ideographic"},
    150979: {"Unified_Ideograph", "Ideographic"},
    150980: {"Unified_Ideograph", "Ideographic"},
    150981: {"Unified_Ideograph", "Ideographic"},
    150982: {"Unified_Ideograph", "Ideographic"},
    150983: {"Unified_Ideograph", "Ideographic"},
    150984: {"Unified_Ideograph", "Ideographic"},
    150985: {"Unified_Ideograph", "Ideographic"},
    150986: {"Unified_Ideograph", "Ideographic"},
    150987: {"Unified_Ideograph", "Ideographic"},
    150988: {"Unified_Ideograph", "Ideographic"},
    150989: {"Unified_Ideograph", "Ideographic"},
    150990: {"Unified_Ideograph", "Ideographic"},
    150991: {"Unified_Ideograph", "Ideographic"},
    150992: {"Unified_Ideograph", "Ideographic"},
    150993: {"Unified_Ideograph", "Ideographic"},
    150994: {"Unified_Ideograph", "Ideographic"},
    150995: {"Unified_Ideograph", "Ideographic"},
    150996: {"Unified_Ideograph", "Ideographic"},
    150997: {"Unified_Ideograph", "Ideographic"},
    150998: {"Unified_Ideograph", "Ideographic"},
    150999: {"Unified_Ideograph", "Ideographic"},
    151000: {"Unified_Ideograph", "Ideographic"},
    151001: {"Unified_Ideograph", "Ideographic"},
    151002: {"Unified_Ideograph", "Ideographic"},
    151003: {"Unified_Ideograph", "Ideographic"},
    151004: {"Unified_Ideograph", "Ideographic"},
    151005: {"Unified_Ideograph", "Ideographic"},
    151006: {"Unified_Ideograph", "Ideographic"},
    151007: {"Unified_Ideograph", "Ideographic"},
    151008: {"Unified_Ideograph", "Ideographic"},
    151009: {"Unified_Ideograph", "Ideographic"},
    151010: {"Unified_Ideograph", "Ideographic"},
    151011: {"Unified_Ideograph", "Ideographic"},
    151012: {"Unified_Ideograph", "Ideographic"},
    151013: {"Unified_Ideograph", "Ideographic"},
    151014: {"Unified_Ideograph", "Ideographic"},
    151015: {"Unified_Ideograph", "Ideographic"},
    151016: {"Unified_Ideograph", "Ideographic"},
    151017: {"Unified_Ideograph", "Ideographic"},
    151018: {"Unified_Ideograph", "Ideographic"},
    151019: {"Unified_Ideograph", "Ideographic"},
    151020: {"Unified_Ideograph", "Ideographic"},
    151021: {"Unified_Ideograph", "Ideographic"},
    151022: {"Unified_Ideograph", "Ideographic"},
    151023: {"Unified_Ideograph", "Ideographic"},
    151024: {"Unified_Ideograph", "Ideographic"},
    151025: {"Unified_Ideograph", "Ideographic"},
    151026: {"Unified_Ideograph", "Ideographic"},
    151027: {"Unified_Ideograph", "Ideographic"},
    151028: {"Unified_Ideograph", "Ideographic"},
    151029: {"Unified_Ideograph", "Ideographic"},
    151030: {"Unified_Ideograph", "Ideographic"},
    151031: {"Unified_Ideograph", "Ideographic"},
    151032: {"Unified_Ideograph", "Ideographic"},
    151033: {"Unified_Ideograph", "Ideographic"},
    151034: {"Unified_Ideograph", "Ideographic"},
    151035: {"Unified_Ideograph", "Ideographic"},
    151036: {"Unified_Ideograph", "Ideographic"},
    151037: {"Unified_Ideograph", "Ideographic"},
    151038: {"Unified_Ideograph", "Ideographic"},
    151039: {"Unified_Ideograph", "Ideographic"},
    151040: {"Unified_Ideograph", "Ideographic"},
    151041: {"Unified_Ideograph", "Ideographic"},
    151042: {"Unified_Ideograph", "Ideographic"},
    151043: {"Unified_Ideograph", "Ideographic"},
    151044: {"Unified_Ideograph", "Ideographic"},
    151045: {"Unified_Ideograph", "Ideographic"},
    151046: {"Unified_Ideograph", "Ideographic"},
    151047: {"Unified_Ideograph", "Ideographic"},
    151048: {"Unified_Ideograph", "Ideographic"},
    151049: {"Unified_Ideograph", "Ideographic"},
    151050: {"Unified_Ideograph", "Ideographic"},
    151051: {"Unified_Ideograph", "Ideographic"},
    151052: {"Unified_Ideograph", "Ideographic"},
    151053: {"Unified_Ideograph", "Ideographic"},
    151054: {"Unified_Ideograph", "Ideographic"},
    151055: {"Unified_Ideograph", "Ideographic"},
    151056: {"Unified_Ideograph", "Ideographic"},
    151057: {"Unified_Ideograph", "Ideographic"},
    151058: {"Unified_Ideograph", "Ideographic"},
    151059: {"Unified_Ideograph", "Ideographic"},
    151060: {"Unified_Ideograph", "Ideographic"},
    151061: {"Unified_Ideograph", "Ideographic"},
    151062: {"Unified_Ideograph", "Ideographic"},
    151063: {"Unified_Ideograph", "Ideographic"},
    151064: {"Unified_Ideograph", "Ideographic"},
    151065: {"Unified_Ideograph", "Ideographic"},
    151066: {"Unified_Ideograph", "Ideographic"},
    151067: {"Unified_Ideograph", "Ideographic"},
    151068: {"Unified_Ideograph", "Ideographic"},
    151069: {"Unified_Ideograph", "Ideographic"},
    151070: {"Unified_Ideograph", "Ideographic"},
    151071: {"Unified_Ideograph", "Ideographic"},
    151072: {"Unified_Ideograph", "Ideographic"},
    151073: {"Unified_Ideograph", "Ideographic"},
    151074: {"Unified_Ideograph", "Ideographic"},
    151075: {"Unified_Ideograph", "Ideographic"},
    151076: {"Unified_Ideograph", "Ideographic"},
    151077: {"Unified_Ideograph", "Ideographic"},
    151078: {"Unified_Ideograph", "Ideographic"},
    151079: {"Unified_Ideograph", "Ideographic"},
    151080: {"Unified_Ideograph", "Ideographic"},
    151081: {"Unified_Ideograph", "Ideographic"},
    151082: {"Unified_Ideograph", "Ideographic"},
    151083: {"Unified_Ideograph", "Ideographic"},
    151084: {"Unified_Ideograph", "Ideographic"},
    151085: {"Unified_Ideograph", "Ideographic"},
    151086: {"Unified_Ideograph", "Ideographic"},
    151087: {"Unified_Ideograph", "Ideographic"},
    151088: {"Unified_Ideograph", "Ideographic"},
    151089: {"Unified_Ideograph", "Ideographic"},
    151090: {"Unified_Ideograph", "Ideographic"},
    151091: {"Unified_Ideograph", "Ideographic"},
    151092: {"Unified_Ideograph", "Ideographic"},
    151093: {"Unified_Ideograph", "Ideographic"},
    151094: {"Unified_Ideograph", "Ideographic"},
    151095: {"Unified_Ideograph", "Ideographic"},
    151096: {"Unified_Ideograph", "Ideographic"},
    151097: {"Unified_Ideograph", "Ideographic"},
    151098: {"Unified_Ideograph", "Ideographic"},
    151099: {"Unified_Ideograph", "Ideographic"},
    151100: {"Unified_Ideograph", "Ideographic"},
    151101: {"Unified_Ideograph", "Ideographic"},
    151102: {"Unified_Ideograph", "Ideographic"},
    151103: {"Unified_Ideograph", "Ideographic"},
    151104: {"Unified_Ideograph", "Ideographic"},
    151105: {"Unified_Ideograph", "Ideographic"},
    151106: {"Unified_Ideograph", "Ideographic"},
    151107: {"Unified_Ideograph", "Ideographic"},
    151108: {"Unified_Ideograph", "Ideographic"},
    151109: {"Unified_Ideograph", "Ideographic"},
    151110: {"Unified_Ideograph", "Ideographic"},
    151111: {"Unified_Ideograph", "Ideographic"},
    151112: {"Unified_Ideograph", "Ideographic"},
    151113: {"Unified_Ideograph", "Ideographic"},
    151114: {"Unified_Ideograph", "Ideographic"},
    151115: {"Unified_Ideograph", "Ideographic"},
    151116: {"Unified_Ideograph", "Ideographic"},
    151117: {"Unified_Ideograph", "Ideographic"},
    151118: {"Unified_Ideograph", "Ideographic"},
    151119: {"Unified_Ideograph", "Ideographic"},
    151120: {"Unified_Ideograph", "Ideographic"},
    151121: {"Unified_Ideograph", "Ideographic"},
    151122: {"Unified_Ideograph", "Ideographic"},
    151123: {"Unified_Ideograph", "Ideographic"},
    151124: {"Unified_Ideograph", "Ideographic"},
    151125: {"Unified_Ideograph", "Ideographic"},
    151126: {"Unified_Ideograph", "Ideographic"},
    151127: {"Unified_Ideograph", "Ideographic"},
    151128: {"Unified_Ideograph", "Ideographic"},
    151129: {"Unified_Ideograph", "Ideographic"},
    151130: {"Unified_Ideograph", "Ideographic"},
    151131: {"Unified_Ideograph", "Ideographic"},
    151132: {"Unified_Ideograph", "Ideographic"},
    151133: {"Unified_Ideograph", "Ideographic"},
    151134: {"Unified_Ideograph", "Ideographic"},
    151135: {"Unified_Ideograph", "Ideographic"},
    151136: {"Unified_Ideograph", "Ideographic"},
    151137: {"Unified_Ideograph", "Ideographic"},
    151138: {"Unified_Ideograph", "Ideographic"},
    151139: {"Unified_Ideograph", "Ideographic"},
    151140: {"Unified_Ideograph", "Ideographic"},
    151141: {"Unified_Ideograph", "Ideographic"},
    151142: {"Unified_Ideograph", "Ideographic"},
    151143: {"Unified_Ideograph", "Ideographic"},
    151144: {"Unified_Ideograph", "Ideographic"},
    151145: {"Unified_Ideograph", "Ideographic"},
    151146: {"Unified_Ideograph", "Ideographic"},
    151147: {"Unified_Ideograph", "Ideographic"},
    151148: {"Unified_Ideograph", "Ideographic"},
    151149: {"Unified_Ideograph", "Ideographic"},
    151150: {"Unified_Ideograph", "Ideographic"},
    151151: {"Unified_Ideograph", "Ideographic"},
    151152: {"Unified_Ideograph", "Ideographic"},
    151153: {"Unified_Ideograph", "Ideographic"},
    151154: {"Unified_Ideograph", "Ideographic"},
    151155: {"Unified_Ideograph", "Ideographic"},
    151156: {"Unified_Ideograph", "Ideographic"},
    151157: {"Unified_Ideograph", "Ideographic"},
    151158: {"Unified_Ideograph", "Ideographic"},
    151159: {"Unified_Ideograph", "Ideographic"},
    151160: {"Unified_Ideograph", "Ideographic"},
    151161: {"Unified_Ideograph", "Ideographic"},
    151162: {"Unified_Ideograph", "Ideographic"},
    151163: {"Unified_Ideograph", "Ideographic"},
    151164: {"Unified_Ideograph", "Ideographic"},
    151165: {"Unified_Ideograph", "Ideographic"},
    151166: {"Unified_Ideograph", "Ideographic"},
    151167: {"Unified_Ideograph", "Ideographic"},
    151168: {"Unified_Ideograph", "Ideographic"},
    151169: {"Unified_Ideograph", "Ideographic"},
    151170: {"Unified_Ideograph", "Ideographic"},
    151171: {"Unified_Ideograph", "Ideographic"},
    151172: {"Unified_Ideograph", "Ideographic"},
    151173: {"Unified_Ideograph", "Ideographic"},
    151174: {"Unified_Ideograph", "Ideographic"},
    151175: {"Unified_Ideograph", "Ideographic"},
    151176: {"Unified_Ideograph", "Ideographic"},
    151177: {"Unified_Ideograph", "Ideographic"},
    151178: {"Unified_Ideograph", "Ideographic"},
    151179: {"Unified_Ideograph", "Ideographic"},
    151180: {"Unified_Ideograph", "Ideographic"},
    151181: {"Unified_Ideograph", "Ideographic"},
    151182: {"Unified_Ideograph", "Ideographic"},
    151183: {"Unified_Ideograph", "Ideographic"},
    151184: {"Unified_Ideograph", "Ideographic"},
    151185: {"Unified_Ideograph", "Ideographic"},
    151186: {"Unified_Ideograph", "Ideographic"},
    151187: {"Unified_Ideograph", "Ideographic"},
    151188: {"Unified_Ideograph", "Ideographic"},
    151189: {"Unified_Ideograph", "Ideographic"},
    151190: {"Unified_Ideograph", "Ideographic"},
    151191: {"Unified_Ideograph", "Ideographic"},
    151192: {"Unified_Ideograph", "Ideographic"},
    151193: {"Unified_Ideograph", "Ideographic"},
    151194: {"Unified_Ideograph", "Ideographic"},
    151195: {"Unified_Ideograph", "Ideographic"},
    151196: {"Unified_Ideograph", "Ideographic"},
    151197: {"Unified_Ideograph", "Ideographic"},
    151198: {"Unified_Ideograph", "Ideographic"},
    151199: {"Unified_Ideograph", "Ideographic"},
    151200: {"Unified_Ideograph", "Ideographic"},
    151201: {"Unified_Ideograph", "Ideographic"},
    151202: {"Unified_Ideograph", "Ideographic"},
    151203: {"Unified_Ideograph", "Ideographic"},
    151204: {"Unified_Ideograph", "Ideographic"},
    151205: {"Unified_Ideograph", "Ideographic"},
    151206: {"Unified_Ideograph", "Ideographic"},
    151207: {"Unified_Ideograph", "Ideographic"},
    151208: {"Unified_Ideograph", "Ideographic"},
    151209: {"Unified_Ideograph", "Ideographic"},
    151210: {"Unified_Ideograph", "Ideographic"},
    151211: {"Unified_Ideograph", "Ideographic"},
    151212: {"Unified_Ideograph", "Ideographic"},
    151213: {"Unified_Ideograph", "Ideographic"},
    151214: {"Unified_Ideograph", "Ideographic"},
    151215: {"Unified_Ideograph", "Ideographic"},
    151216: {"Unified_Ideograph", "Ideographic"},
    151217: {"Unified_Ideograph", "Ideographic"},
    151218: {"Unified_Ideograph", "Ideographic"},
    151219: {"Unified_Ideograph", "Ideographic"},
    151220: {"Unified_Ideograph", "Ideographic"},
    151221: {"Unified_Ideograph", "Ideographic"},
    151222: {"Unified_Ideograph", "Ideographic"},
    151223: {"Unified_Ideograph", "Ideographic"},
    151224: {"Unified_Ideograph", "Ideographic"},
    151225: {"Unified_Ideograph", "Ideographic"},
    151226: {"Unified_Ideograph", "Ideographic"},
    151227: {"Unified_Ideograph", "Ideographic"},
    151228: {"Unified_Ideograph", "Ideographic"},
    151229: {"Unified_Ideograph", "Ideographic"},
    151230: {"Unified_Ideograph", "Ideographic"},
    151231: {"Unified_Ideograph", "Ideographic"},
    151232: {"Unified_Ideograph", "Ideographic"},
    151233: {"Unified_Ideograph", "Ideographic"},
    151234: {"Unified_Ideograph", "Ideographic"},
    151235: {"Unified_Ideograph", "Ideographic"},
    151236: {"Unified_Ideograph", "Ideographic"},
    151237: {"Unified_Ideograph", "Ideographic"},
    151238: {"Unified_Ideograph", "Ideographic"},
    151239: {"Unified_Ideograph", "Ideographic"},
    151240: {"Unified_Ideograph", "Ideographic"},
    151241: {"Unified_Ideograph", "Ideographic"},
    151242: {"Unified_Ideograph", "Ideographic"},
    151243: {"Unified_Ideograph", "Ideographic"},
    151244: {"Unified_Ideograph", "Ideographic"},
    151245: {"Unified_Ideograph", "Ideographic"},
    151246: {"Unified_Ideograph", "Ideographic"},
    151247: {"Unified_Ideograph", "Ideographic"},
    151248: {"Unified_Ideograph", "Ideographic"},
    151249: {"Unified_Ideograph", "Ideographic"},
    151250: {"Unified_Ideograph", "Ideographic"},
    151251: {"Unified_Ideograph", "Ideographic"},
    151252: {"Unified_Ideograph", "Ideographic"},
    151253: {"Unified_Ideograph", "Ideographic"},
    151254: {"Unified_Ideograph", "Ideographic"},
    151255: {"Unified_Ideograph", "Ideographic"},
    151256: {"Unified_Ideograph", "Ideographic"},
    151257: {"Unified_Ideograph", "Ideographic"},
    151258: {"Unified_Ideograph", "Ideographic"},
    151259: {"Unified_Ideograph", "Ideographic"},
    151260: {"Unified_Ideograph", "Ideographic"},
    151261: {"Unified_Ideograph", "Ideographic"},
    151262: {"Unified_Ideograph", "Ideographic"},
    151263: {"Unified_Ideograph", "Ideographic"},
    151264: {"Unified_Ideograph", "Ideographic"},
    151265: {"Unified_Ideograph", "Ideographic"},
    151266: {"Unified_Ideograph", "Ideographic"},
    151267: {"Unified_Ideograph", "Ideographic"},
    151268: {"Unified_Ideograph", "Ideographic"},
    151269: {"Unified_Ideograph", "Ideographic"},
    151270: {"Unified_Ideograph", "Ideographic"},
    151271: {"Unified_Ideograph", "Ideographic"},
    151272: {"Unified_Ideograph", "Ideographic"},
    151273: {"Unified_Ideograph", "Ideographic"},
    151274: {"Unified_Ideograph", "Ideographic"},
    151275: {"Unified_Ideograph", "Ideographic"},
    151276: {"Unified_Ideograph", "Ideographic"},
    151277: {"Unified_Ideograph", "Ideographic"},
    151278: {"Unified_Ideograph", "Ideographic"},
    151279: {"Unified_Ideograph", "Ideographic"},
    151280: {"Unified_Ideograph", "Ideographic"},
    151281: {"Unified_Ideograph", "Ideographic"},
    151282: {"Unified_Ideograph", "Ideographic"},
    151283: {"Unified_Ideograph", "Ideographic"},
    151284: {"Unified_Ideograph", "Ideographic"},
    151285: {"Unified_Ideograph", "Ideographic"},
    151286: {"Unified_Ideograph", "Ideographic"},
    151287: {"Unified_Ideograph", "Ideographic"},
    151288: {"Unified_Ideograph", "Ideographic"},
    151289: {"Unified_Ideograph", "Ideographic"},
    151290: {"Unified_Ideograph", "Ideographic"},
    151291: {"Unified_Ideograph", "Ideographic"},
    151292: {"Unified_Ideograph", "Ideographic"},
    151293: {"Unified_Ideograph", "Ideographic"},
    151294: {"Unified_Ideograph", "Ideographic"},
    151295: {"Unified_Ideograph", "Ideographic"},
    151296: {"Unified_Ideograph", "Ideographic"},
    151297: {"Unified_Ideograph", "Ideographic"},
    151298: {"Unified_Ideograph", "Ideographic"},
    151299: {"Unified_Ideograph", "Ideographic"},
    151300: {"Unified_Ideograph", "Ideographic"},
    151301: {"Unified_Ideograph", "Ideographic"},
    151302: {"Unified_Ideograph", "Ideographic"},
    151303: {"Unified_Ideograph", "Ideographic"},
    151304: {"Unified_Ideograph", "Ideographic"},
    151305: {"Unified_Ideograph", "Ideographic"},
    151306: {"Unified_Ideograph", "Ideographic"},
    151307: {"Unified_Ideograph", "Ideographic"},
    151308: {"Unified_Ideograph", "Ideographic"},
    151309: {"Unified_Ideograph", "Ideographic"},
    151310: {"Unified_Ideograph", "Ideographic"},
    151311: {"Unified_Ideograph", "Ideographic"},
    151312: {"Unified_Ideograph", "Ideographic"},
    151313: {"Unified_Ideograph", "Ideographic"},
    151314: {"Unified_Ideograph", "Ideographic"},
    151315: {"Unified_Ideograph", "Ideographic"},
    151316: {"Unified_Ideograph", "Ideographic"},
    151317: {"Unified_Ideograph", "Ideographic"},
    151318: {"Unified_Ideograph", "Ideographic"},
    151319: {"Unified_Ideograph", "Ideographic"},
    151320: {"Unified_Ideograph", "Ideographic"},
    151321: {"Unified_Ideograph", "Ideographic"},
    151322: {"Unified_Ideograph", "Ideographic"},
    151323: {"Unified_Ideograph", "Ideographic"},
    151324: {"Unified_Ideograph", "Ideographic"},
    151325: {"Unified_Ideograph", "Ideographic"},
    151326: {"Unified_Ideograph", "Ideographic"},
    151327: {"Unified_Ideograph", "Ideographic"},
    151328: {"Unified_Ideograph", "Ideographic"},
    151329: {"Unified_Ideograph", "Ideographic"},
    151330: {"Unified_Ideograph", "Ideographic"},
    151331: {"Unified_Ideograph", "Ideographic"},
    151332: {"Unified_Ideograph", "Ideographic"},
    151333: {"Unified_Ideograph", "Ideographic"},
    151334: {"Unified_Ideograph", "Ideographic"},
    151335: {"Unified_Ideograph", "Ideographic"},
    151336: {"Unified_Ideograph", "Ideographic"},
    151337: {"Unified_Ideograph", "Ideographic"},
    151338: {"Unified_Ideograph", "Ideographic"},
    151339: {"Unified_Ideograph", "Ideographic"},
    151340: {"Unified_Ideograph", "Ideographic"},
    151341: {"Unified_Ideograph", "Ideographic"},
    151342: {"Unified_Ideograph", "Ideographic"},
    151343: {"Unified_Ideograph", "Ideographic"},
    151344: {"Unified_Ideograph", "Ideographic"},
    151345: {"Unified_Ideograph", "Ideographic"},
    151346: {"Unified_Ideograph", "Ideographic"},
    151347: {"Unified_Ideograph", "Ideographic"},
    151348: {"Unified_Ideograph", "Ideographic"},
    151349: {"Unified_Ideograph", "Ideographic"},
    151350: {"Unified_Ideograph", "Ideographic"},
    151351: {"Unified_Ideograph", "Ideographic"},
    151352: {"Unified_Ideograph", "Ideographic"},
    151353: {"Unified_Ideograph", "Ideographic"},
    151354: {"Unified_Ideograph", "Ideographic"},
    151355: {"Unified_Ideograph", "Ideographic"},
    151356: {"Unified_Ideograph", "Ideographic"},
    151357: {"Unified_Ideograph", "Ideographic"},
    151358: {"Unified_Ideograph", "Ideographic"},
    151359: {"Unified_Ideograph", "Ideographic"},
    151360: {"Unified_Ideograph", "Ideographic"},
    151361: {"Unified_Ideograph", "Ideographic"},
    151362: {"Unified_Ideograph", "Ideographic"},
    151363: {"Unified_Ideograph", "Ideographic"},
    151364: {"Unified_Ideograph", "Ideographic"},
    151365: {"Unified_Ideograph", "Ideographic"},
    151366: {"Unified_Ideograph", "Ideographic"},
    151367: {"Unified_Ideograph", "Ideographic"},
    151368: {"Unified_Ideograph", "Ideographic"},
    151369: {"Unified_Ideograph", "Ideographic"},
    151370: {"Unified_Ideograph", "Ideographic"},
    151371: {"Unified_Ideograph", "Ideographic"},
    151372: {"Unified_Ideograph", "Ideographic"},
    151373: {"Unified_Ideograph", "Ideographic"},
    151374: {"Unified_Ideograph", "Ideographic"},
    151375: {"Unified_Ideograph", "Ideographic"},
    151376: {"Unified_Ideograph", "Ideographic"},
    151377: {"Unified_Ideograph", "Ideographic"},
    151378: {"Unified_Ideograph", "Ideographic"},
    151379: {"Unified_Ideograph", "Ideographic"},
    151380: {"Unified_Ideograph", "Ideographic"},
    151381: {"Unified_Ideograph", "Ideographic"},
    151382: {"Unified_Ideograph", "Ideographic"},
    151383: {"Unified_Ideograph", "Ideographic"},
    151384: {"Unified_Ideograph", "Ideographic"},
    151385: {"Unified_Ideograph", "Ideographic"},
    151386: {"Unified_Ideograph", "Ideographic"},
    151387: {"Unified_Ideograph", "Ideographic"},
    151388: {"Unified_Ideograph", "Ideographic"},
    151389: {"Unified_Ideograph", "Ideographic"},
    151390: {"Unified_Ideograph", "Ideographic"},
    151391: {"Unified_Ideograph", "Ideographic"},
    151392: {"Unified_Ideograph", "Ideographic"},
    151393: {"Unified_Ideograph", "Ideographic"},
    151394: {"Unified_Ideograph", "Ideographic"},
    151395: {"Unified_Ideograph", "Ideographic"},
    151396: {"Unified_Ideograph", "Ideographic"},
    151397: {"Unified_Ideograph", "Ideographic"},
    151398: {"Unified_Ideograph", "Ideographic"},
    151399: {"Unified_Ideograph", "Ideographic"},
    151400: {"Unified_Ideograph", "Ideographic"},
    151401: {"Unified_Ideograph", "Ideographic"},
    151402: {"Unified_Ideograph", "Ideographic"},
    151403: {"Unified_Ideograph", "Ideographic"},
    151404: {"Unified_Ideograph", "Ideographic"},
    151405: {"Unified_Ideograph", "Ideographic"},
    151406: {"Unified_Ideograph", "Ideographic"},
    151407: {"Unified_Ideograph", "Ideographic"},
    151408: {"Unified_Ideograph", "Ideographic"},
    151409: {"Unified_Ideograph", "Ideographic"},
    151410: {"Unified_Ideograph", "Ideographic"},
    151411: {"Unified_Ideograph", "Ideographic"},
    151412: {"Unified_Ideograph", "Ideographic"},
    151413: {"Unified_Ideograph", "Ideographic"},
    151414: {"Unified_Ideograph", "Ideographic"},
    151415: {"Unified_Ideograph", "Ideographic"},
    151416: {"Unified_Ideograph", "Ideographic"},
    151417: {"Unified_Ideograph", "Ideographic"},
    151418: {"Unified_Ideograph", "Ideographic"},
    151419: {"Unified_Ideograph", "Ideographic"},
    151420: {"Unified_Ideograph", "Ideographic"},
    151421: {"Unified_Ideograph", "Ideographic"},
    151422: {"Unified_Ideograph", "Ideographic"},
    151423: {"Unified_Ideograph", "Ideographic"},
    151424: {"Unified_Ideograph", "Ideographic"},
    151425: {"Unified_Ideograph", "Ideographic"},
    151426: {"Unified_Ideograph", "Ideographic"},
    151427: {"Unified_Ideograph", "Ideographic"},
    151428: {"Unified_Ideograph", "Ideographic"},
    151429: {"Unified_Ideograph", "Ideographic"},
    151430: {"Unified_Ideograph", "Ideographic"},
    151431: {"Unified_Ideograph", "Ideographic"},
    151432: {"Unified_Ideograph", "Ideographic"},
    151433: {"Unified_Ideograph", "Ideographic"},
    151434: {"Unified_Ideograph", "Ideographic"},
    151435: {"Unified_Ideograph", "Ideographic"},
    151436: {"Unified_Ideograph", "Ideographic"},
    151437: {"Unified_Ideograph", "Ideographic"},
    151438: {"Unified_Ideograph", "Ideographic"},
    151439: {"Unified_Ideograph", "Ideographic"},
    151440: {"Unified_Ideograph", "Ideographic"},
    151441: {"Unified_Ideograph", "Ideographic"},
    151442: {"Unified_Ideograph", "Ideographic"},
    151443: {"Unified_Ideograph", "Ideographic"},
    151444: {"Unified_Ideograph", "Ideographic"},
    151445: {"Unified_Ideograph", "Ideographic"},
    151446: {"Unified_Ideograph", "Ideographic"},
    151447: {"Unified_Ideograph", "Ideographic"},
    151448: {"Unified_Ideograph", "Ideographic"},
    151449: {"Unified_Ideograph", "Ideographic"},
    151450: {"Unified_Ideograph", "Ideographic"},
    151451: {"Unified_Ideograph", "Ideographic"},
    151452: {"Unified_Ideograph", "Ideographic"},
    151453: {"Unified_Ideograph", "Ideographic"},
    151454: {"Unified_Ideograph", "Ideographic"},
    151455: {"Unified_Ideograph", "Ideographic"},
    151456: {"Unified_Ideograph", "Ideographic"},
    151457: {"Unified_Ideograph", "Ideographic"},
    151458: {"Unified_Ideograph", "Ideographic"},
    151459: {"Unified_Ideograph", "Ideographic"},
    151460: {"Unified_Ideograph", "Ideographic"},
    151461: {"Unified_Ideograph", "Ideographic"},
    151462: {"Unified_Ideograph", "Ideographic"},
    151463: {"Unified_Ideograph", "Ideographic"},
    151464: {"Unified_Ideograph", "Ideographic"},
    151465: {"Unified_Ideograph", "Ideographic"},
    151466: {"Unified_Ideograph", "Ideographic"},
    151467: {"Unified_Ideograph", "Ideographic"},
    151468: {"Unified_Ideograph", "Ideographic"},
    151469: {"Unified_Ideograph", "Ideographic"},
    151470: {"Unified_Ideograph", "Ideographic"},
    151471: {"Unified_Ideograph", "Ideographic"},
    151472: {"Unified_Ideograph", "Ideographic"},
    151473: {"Unified_Ideograph", "Ideographic"},
    151474: {"Unified_Ideograph", "Ideographic"},
    151475: {"Unified_Ideograph", "Ideographic"},
    151476: {"Unified_Ideograph", "Ideographic"},
    151477: {"Unified_Ideograph", "Ideographic"},
    151478: {"Unified_Ideograph", "Ideographic"},
    151479: {"Unified_Ideograph", "Ideographic"},
    151480: {"Unified_Ideograph", "Ideographic"},
    151481: {"Unified_Ideograph", "Ideographic"},
    151482: {"Unified_Ideograph", "Ideographic"},
    151483: {"Unified_Ideograph", "Ideographic"},
    151484: {"Unified_Ideograph", "Ideographic"},
    151485: {"Unified_Ideograph", "Ideographic"},
    151486: {"Unified_Ideograph", "Ideographic"},
    151487: {"Unified_Ideograph", "Ideographic"},
    151488: {"Unified_Ideograph", "Ideographic"},
    151489: {"Unified_Ideograph", "Ideographic"},
    151490: {"Unified_Ideograph", "Ideographic"},
    151491: {"Unified_Ideograph", "Ideographic"},
    151492: {"Unified_Ideograph", "Ideographic"},
    151493: {"Unified_Ideograph", "Ideographic"},
    151494: {"Unified_Ideograph", "Ideographic"},
    151495: {"Unified_Ideograph", "Ideographic"},
    151496: {"Unified_Ideograph", "Ideographic"},
    151497: {"Unified_Ideograph", "Ideographic"},
    151498: {"Unified_Ideograph", "Ideographic"},
    151499: {"Unified_Ideograph", "Ideographic"},
    151500: {"Unified_Ideograph", "Ideographic"},
    151501: {"Unified_Ideograph", "Ideographic"},
    151502: {"Unified_Ideograph", "Ideographic"},
    151503: {"Unified_Ideograph", "Ideographic"},
    151504: {"Unified_Ideograph", "Ideographic"},
    151505: {"Unified_Ideograph", "Ideographic"},
    151506: {"Unified_Ideograph", "Ideographic"},
    151507: {"Unified_Ideograph", "Ideographic"},
    151508: {"Unified_Ideograph", "Ideographic"},
    151509: {"Unified_Ideograph", "Ideographic"},
    151510: {"Unified_Ideograph", "Ideographic"},
    151511: {"Unified_Ideograph", "Ideographic"},
    151512: {"Unified_Ideograph", "Ideographic"},
    151513: {"Unified_Ideograph", "Ideographic"},
    151514: {"Unified_Ideograph", "Ideographic"},
    151515: {"Unified_Ideograph", "Ideographic"},
    151516: {"Unified_Ideograph", "Ideographic"},
    151517: {"Unified_Ideograph", "Ideographic"},
    151518: {"Unified_Ideograph", "Ideographic"},
    151519: {"Unified_Ideograph", "Ideographic"},
    151520: {"Unified_Ideograph", "Ideographic"},
    151521: {"Unified_Ideograph", "Ideographic"},
    151522: {"Unified_Ideograph", "Ideographic"},
    151523: {"Unified_Ideograph", "Ideographic"},
    151524: {"Unified_Ideograph", "Ideographic"},
    151525: {"Unified_Ideograph", "Ideographic"},
    151526: {"Unified_Ideograph", "Ideographic"},
    151527: {"Unified_Ideograph", "Ideographic"},
    151528: {"Unified_Ideograph", "Ideographic"},
    151529: {"Unified_Ideograph", "Ideographic"},
    151530: {"Unified_Ideograph", "Ideographic"},
    151531: {"Unified_Ideograph", "Ideographic"},
    151532: {"Unified_Ideograph", "Ideographic"},
    151533: {"Unified_Ideograph", "Ideographic"},
    151534: {"Unified_Ideograph", "Ideographic"},
    151535: {"Unified_Ideograph", "Ideographic"},
    151536: {"Unified_Ideograph", "Ideographic"},
    151537: {"Unified_Ideograph", "Ideographic"},
    151538: {"Unified_Ideograph", "Ideographic"},
    151539: {"Unified_Ideograph", "Ideographic"},
    151540: {"Unified_Ideograph", "Ideographic"},
    151541: {"Unified_Ideograph", "Ideographic"},
    151542: {"Unified_Ideograph", "Ideographic"},
    151543: {"Unified_Ideograph", "Ideographic"},
    151544: {"Unified_Ideograph", "Ideographic"},
    151545: {"Unified_Ideograph", "Ideographic"},
    151546: {"Unified_Ideograph", "Ideographic"},
    151547: {"Unified_Ideograph", "Ideographic"},
    151548: {"Unified_Ideograph", "Ideographic"},
    151549: {"Unified_Ideograph", "Ideographic"},
    151550: {"Unified_Ideograph", "Ideographic"},
    151551: {"Unified_Ideograph", "Ideographic"},
    151552: {"Unified_Ideograph", "Ideographic"},
    151553: {"Unified_Ideograph", "Ideographic"},
    151554: {"Unified_Ideograph", "Ideographic"},
    151555: {"Unified_Ideograph", "Ideographic"},
    151556: {"Unified_Ideograph", "Ideographic"},
    151557: {"Unified_Ideograph", "Ideographic"},
    151558: {"Unified_Ideograph", "Ideographic"},
    151559: {"Unified_Ideograph", "Ideographic"},
    151560: {"Unified_Ideograph", "Ideographic"},
    151561: {"Unified_Ideograph", "Ideographic"},
    151562: {"Unified_Ideograph", "Ideographic"},
    151563: {"Unified_Ideograph", "Ideographic"},
    151564: {"Unified_Ideograph", "Ideographic"},
    151565: {"Unified_Ideograph", "Ideographic"},
    151566: {"Unified_Ideograph", "Ideographic"},
    151567: {"Unified_Ideograph", "Ideographic"},
    151568: {"Unified_Ideograph", "Ideographic"},
    151569: {"Unified_Ideograph", "Ideographic"},
    151570: {"Unified_Ideograph", "Ideographic"},
    151571: {"Unified_Ideograph", "Ideographic"},
    151572: {"Unified_Ideograph", "Ideographic"},
    151573: {"Unified_Ideograph", "Ideographic"},
    151574: {"Unified_Ideograph", "Ideographic"},
    151575: {"Unified_Ideograph", "Ideographic"},
    151576: {"Unified_Ideograph", "Ideographic"},
    151577: {"Unified_Ideograph", "Ideographic"},
    151578: {"Unified_Ideograph", "Ideographic"},
    151579: {"Unified_Ideograph", "Ideographic"},
    151580: {"Unified_Ideograph", "Ideographic"},
    151581: {"Unified_Ideograph", "Ideographic"},
    151582: {"Unified_Ideograph", "Ideographic"},
    151583: {"Unified_Ideograph", "Ideographic"},
    151584: {"Unified_Ideograph", "Ideographic"},
    151585: {"Unified_Ideograph", "Ideographic"},
    151586: {"Unified_Ideograph", "Ideographic"},
    151587: {"Unified_Ideograph", "Ideographic"},
    151588: {"Unified_Ideograph", "Ideographic"},
    151589: {"Unified_Ideograph", "Ideographic"},
    151590: {"Unified_Ideograph", "Ideographic"},
    151591: {"Unified_Ideograph", "Ideographic"},
    151592: {"Unified_Ideograph", "Ideographic"},
    151593: {"Unified_Ideograph", "Ideographic"},
    151594: {"Unified_Ideograph", "Ideographic"},
    151595: {"Unified_Ideograph", "Ideographic"},
    151596: {"Unified_Ideograph", "Ideographic"},
    151597: {"Unified_Ideograph", "Ideographic"},
    151598: {"Unified_Ideograph", "Ideographic"},
    151599: {"Unified_Ideograph", "Ideographic"},
    151600: {"Unified_Ideograph", "Ideographic"},
    151601: {"Unified_Ideograph", "Ideographic"},
    151602: {"Unified_Ideograph", "Ideographic"},
    151603: {"Unified_Ideograph", "Ideographic"},
    151604: {"Unified_Ideograph", "Ideographic"},
    151605: {"Unified_Ideograph", "Ideographic"},
    151606: {"Unified_Ideograph", "Ideographic"},
    151607: {"Unified_Ideograph", "Ideographic"},
    151608: {"Unified_Ideograph", "Ideographic"},
    151609: {"Unified_Ideograph", "Ideographic"},
    151610: {"Unified_Ideograph", "Ideographic"},
    151611: {"Unified_Ideograph", "Ideographic"},
    151612: {"Unified_Ideograph", "Ideographic"},
    151613: {"Unified_Ideograph", "Ideographic"},
    151614: {"Unified_Ideograph", "Ideographic"},
    151615: {"Unified_Ideograph", "Ideographic"},
    151616: {"Unified_Ideograph", "Ideographic"},
    151617: {"Unified_Ideograph", "Ideographic"},
    151618: {"Unified_Ideograph", "Ideographic"},
    151619: {"Unified_Ideograph", "Ideographic"},
    151620: {"Unified_Ideograph", "Ideographic"},
    151621: {"Unified_Ideograph", "Ideographic"},
    151622: {"Unified_Ideograph", "Ideographic"},
    151623: {"Unified_Ideograph", "Ideographic"},
    151624: {"Unified_Ideograph", "Ideographic"},
    151625: {"Unified_Ideograph", "Ideographic"},
    151626: {"Unified_Ideograph", "Ideographic"},
    151627: {"Unified_Ideograph", "Ideographic"},
    151628: {"Unified_Ideograph", "Ideographic"},
    151629: {"Unified_Ideograph", "Ideographic"},
    151630: {"Unified_Ideograph", "Ideographic"},
    151631: {"Unified_Ideograph", "Ideographic"},
    151632: {"Unified_Ideograph", "Ideographic"},
    151633: {"Unified_Ideograph", "Ideographic"},
    151634: {"Unified_Ideograph", "Ideographic"},
    151635: {"Unified_Ideograph", "Ideographic"},
    151636: {"Unified_Ideograph", "Ideographic"},
    151637: {"Unified_Ideograph", "Ideographic"},
    151638: {"Unified_Ideograph", "Ideographic"},
    151639: {"Unified_Ideograph", "Ideographic"},
    151640: {"Unified_Ideograph", "Ideographic"},
    151641: {"Unified_Ideograph", "Ideographic"},
    151642: {"Unified_Ideograph", "Ideographic"},
    151643: {"Unified_Ideograph", "Ideographic"},
    151644: {"Unified_Ideograph", "Ideographic"},
    151645: {"Unified_Ideograph", "Ideographic"},
    151646: {"Unified_Ideograph", "Ideographic"},
    151647: {"Unified_Ideograph", "Ideographic"},
    151648: {"Unified_Ideograph", "Ideographic"},
    151649: {"Unified_Ideograph", "Ideographic"},
    151650: {"Unified_Ideograph", "Ideographic"},
    151651: {"Unified_Ideograph", "Ideographic"},
    151652: {"Unified_Ideograph", "Ideographic"},
    151653: {"Unified_Ideograph", "Ideographic"},
    151654: {"Unified_Ideograph", "Ideographic"},
    151655: {"Unified_Ideograph", "Ideographic"},
    151656: {"Unified_Ideograph", "Ideographic"},
    151657: {"Unified_Ideograph", "Ideographic"},
    151658: {"Unified_Ideograph", "Ideographic"},
    151659: {"Unified_Ideograph", "Ideographic"},
    151660: {"Unified_Ideograph", "Ideographic"},
    151661: {"Unified_Ideograph", "Ideographic"},
    151662: {"Unified_Ideograph", "Ideographic"},
    151663: {"Unified_Ideograph", "Ideographic"},
    151664: {"Unified_Ideograph", "Ideographic"},
    151665: {"Unified_Ideograph", "Ideographic"},
    151666: {"Unified_Ideograph", "Ideographic"},
    151667: {"Unified_Ideograph", "Ideographic"},
    151668: {"Unified_Ideograph", "Ideographic"},
    151669: {"Unified_Ideograph", "Ideographic"},
    151670: {"Unified_Ideograph", "Ideographic"},
    151671: {"Unified_Ideograph", "Ideographic"},
    151672: {"Unified_Ideograph", "Ideographic"},
    151673: {"Unified_Ideograph", "Ideographic"},
    151674: {"Unified_Ideograph", "Ideographic"},
    151675: {"Unified_Ideograph", "Ideographic"},
    151676: {"Unified_Ideograph", "Ideographic"},
    151677: {"Unified_Ideograph", "Ideographic"},
    151678: {"Unified_Ideograph", "Ideographic"},
    151679: {"Unified_Ideograph", "Ideographic"},
    151680: {"Unified_Ideograph", "Ideographic"},
    151681: {"Unified_Ideograph", "Ideographic"},
    151682: {"Unified_Ideograph", "Ideographic"},
    151683: {"Unified_Ideograph", "Ideographic"},
    151684: {"Unified_Ideograph", "Ideographic"},
    151685: {"Unified_Ideograph", "Ideographic"},
    151686: {"Unified_Ideograph", "Ideographic"},
    151687: {"Unified_Ideograph", "Ideographic"},
    151688: {"Unified_Ideograph", "Ideographic"},
    151689: {"Unified_Ideograph", "Ideographic"},
    151690: {"Unified_Ideograph", "Ideographic"},
    151691: {"Unified_Ideograph", "Ideographic"},
    151692: {"Unified_Ideograph", "Ideographic"},
    151693: {"Unified_Ideograph", "Ideographic"},
    151694: {"Unified_Ideograph", "Ideographic"},
    151695: {"Unified_Ideograph", "Ideographic"},
    151696: {"Unified_Ideograph", "Ideographic"},
    151697: {"Unified_Ideograph", "Ideographic"},
    151698: {"Unified_Ideograph", "Ideographic"},
    151699: {"Unified_Ideograph", "Ideographic"},
    151700: {"Unified_Ideograph", "Ideographic"},
    151701: {"Unified_Ideograph", "Ideographic"},
    151702: {"Unified_Ideograph", "Ideographic"},
    151703: {"Unified_Ideograph", "Ideographic"},
    151704: {"Unified_Ideograph", "Ideographic"},
    151705: {"Unified_Ideograph", "Ideographic"},
    151706: {"Unified_Ideograph", "Ideographic"},
    151707: {"Unified_Ideograph", "Ideographic"},
    151708: {"Unified_Ideograph", "Ideographic"},
    151709: {"Unified_Ideograph", "Ideographic"},
    151710: {"Unified_Ideograph", "Ideographic"},
    151711: {"Unified_Ideograph", "Ideographic"},
    151712: {"Unified_Ideograph", "Ideographic"},
    151713: {"Unified_Ideograph", "Ideographic"},
    151714: {"Unified_Ideograph", "Ideographic"},
    151715: {"Unified_Ideograph", "Ideographic"},
    151716: {"Unified_Ideograph", "Ideographic"},
    151717: {"Unified_Ideograph", "Ideographic"},
    151718: {"Unified_Ideograph", "Ideographic"},
    151719: {"Unified_Ideograph", "Ideographic"},
    151720: {"Unified_Ideograph", "Ideographic"},
    151721: {"Unified_Ideograph", "Ideographic"},
    151722: {"Unified_Ideograph", "Ideographic"},
    151723: {"Unified_Ideograph", "Ideographic"},
    151724: {"Unified_Ideograph", "Ideographic"},
    151725: {"Unified_Ideograph", "Ideographic"},
    151726: {"Unified_Ideograph", "Ideographic"},
    151727: {"Unified_Ideograph", "Ideographic"},
    151728: {"Unified_Ideograph", "Ideographic"},
    151729: {"Unified_Ideograph", "Ideographic"},
    151730: {"Unified_Ideograph", "Ideographic"},
    151731: {"Unified_Ideograph", "Ideographic"},
    151732: {"Unified_Ideograph", "Ideographic"},
    151733: {"Unified_Ideograph", "Ideographic"},
    151734: {"Unified_Ideograph", "Ideographic"},
    151735: {"Unified_Ideograph", "Ideographic"},
    151736: {"Unified_Ideograph", "Ideographic"},
    151737: {"Unified_Ideograph", "Ideographic"},
    151738: {"Unified_Ideograph", "Ideographic"},
    151739: {"Unified_Ideograph", "Ideographic"},
    151740: {"Unified_Ideograph", "Ideographic"},
    151741: {"Unified_Ideograph", "Ideographic"},
    151742: {"Unified_Ideograph", "Ideographic"},
    151743: {"Unified_Ideograph", "Ideographic"},
    151744: {"Unified_Ideograph", "Ideographic"},
    151745: {"Unified_Ideograph", "Ideographic"},
    151746: {"Unified_Ideograph", "Ideographic"},
    151747: {"Unified_Ideograph", "Ideographic"},
    151748: {"Unified_Ideograph", "Ideographic"},
    151749: {"Unified_Ideograph", "Ideographic"},
    151750: {"Unified_Ideograph", "Ideographic"},
    151751: {"Unified_Ideograph", "Ideographic"},
    151752: {"Unified_Ideograph", "Ideographic"},
    151753: {"Unified_Ideograph", "Ideographic"},
    151754: {"Unified_Ideograph", "Ideographic"},
    151755: {"Unified_Ideograph", "Ideographic"},
    151756: {"Unified_Ideograph", "Ideographic"},
    151757: {"Unified_Ideograph", "Ideographic"},
    151758: {"Unified_Ideograph", "Ideographic"},
    151759: {"Unified_Ideograph", "Ideographic"},
    151760: {"Unified_Ideograph", "Ideographic"},
    151761: {"Unified_Ideograph", "Ideographic"},
    151762: {"Unified_Ideograph", "Ideographic"},
    151763: {"Unified_Ideograph", "Ideographic"},
    151764: {"Unified_Ideograph", "Ideographic"},
    151765: {"Unified_Ideograph", "Ideographic"},
    151766: {"Unified_Ideograph", "Ideographic"},
    151767: {"Unified_Ideograph", "Ideographic"},
    151768: {"Unified_Ideograph", "Ideographic"},
    151769: {"Unified_Ideograph", "Ideographic"},
    151770: {"Unified_Ideograph", "Ideographic"},
    151771: {"Unified_Ideograph", "Ideographic"},
    151772: {"Unified_Ideograph", "Ideographic"},
    151773: {"Unified_Ideograph", "Ideographic"},
    151774: {"Unified_Ideograph", "Ideographic"},
    151775: {"Unified_Ideograph", "Ideographic"},
    151776: {"Unified_Ideograph", "Ideographic"},
    151777: {"Unified_Ideograph", "Ideographic"},
    151778: {"Unified_Ideograph", "Ideographic"},
    151779: {"Unified_Ideograph", "Ideographic"},
    151780: {"Unified_Ideograph", "Ideographic"},
    151781: {"Unified_Ideograph", "Ideographic"},
    151782: {"Unified_Ideograph", "Ideographic"},
    151783: {"Unified_Ideograph", "Ideographic"},
    151784: {"Unified_Ideograph", "Ideographic"},
    151785: {"Unified_Ideograph", "Ideographic"},
    151786: {"Unified_Ideograph", "Ideographic"},
    151787: {"Unified_Ideograph", "Ideographic"},
    151788: {"Unified_Ideograph", "Ideographic"},
    151789: {"Unified_Ideograph", "Ideographic"},
    151790: {"Unified_Ideograph", "Ideographic"},
    151791: {"Unified_Ideograph", "Ideographic"},
    151792: {"Unified_Ideograph", "Ideographic"},
    151793: {"Unified_Ideograph", "Ideographic"},
    151794: {"Unified_Ideograph", "Ideographic"},
    151795: {"Unified_Ideograph", "Ideographic"},
    151796: {"Unified_Ideograph", "Ideographic"},
    151797: {"Unified_Ideograph", "Ideographic"},
    151798: {"Unified_Ideograph", "Ideographic"},
    151799: {"Unified_Ideograph", "Ideographic"},
    151800: {"Unified_Ideograph", "Ideographic"},
    151801: {"Unified_Ideograph", "Ideographic"},
    151802: {"Unified_Ideograph", "Ideographic"},
    151803: {"Unified_Ideograph", "Ideographic"},
    151804: {"Unified_Ideograph", "Ideographic"},
    151805: {"Unified_Ideograph", "Ideographic"},
    151806: {"Unified_Ideograph", "Ideographic"},
    151807: {"Unified_Ideograph", "Ideographic"},
    151808: {"Unified_Ideograph", "Ideographic"},
    151809: {"Unified_Ideograph", "Ideographic"},
    151810: {"Unified_Ideograph", "Ideographic"},
    151811: {"Unified_Ideograph", "Ideographic"},
    151812: {"Unified_Ideograph", "Ideographic"},
    151813: {"Unified_Ideograph", "Ideographic"},
    151814: {"Unified_Ideograph", "Ideographic"},
    151815: {"Unified_Ideograph", "Ideographic"},
    151816: {"Unified_Ideograph", "Ideographic"},
    151817: {"Unified_Ideograph", "Ideographic"},
    151818: {"Unified_Ideograph", "Ideographic"},
    151819: {"Unified_Ideograph", "Ideographic"},
    151820: {"Unified_Ideograph", "Ideographic"},
    151821: {"Unified_Ideograph", "Ideographic"},
    151822: {"Unified_Ideograph", "Ideographic"},
    151823: {"Unified_Ideograph", "Ideographic"},
    151824: {"Unified_Ideograph", "Ideographic"},
    151825: {"Unified_Ideograph", "Ideographic"},
    151826: {"Unified_Ideograph", "Ideographic"},
    151827: {"Unified_Ideograph", "Ideographic"},
    151828: {"Unified_Ideograph", "Ideographic"},
    151829: {"Unified_Ideograph", "Ideographic"},
    151830: {"Unified_Ideograph", "Ideographic"},
    151831: {"Unified_Ideograph", "Ideographic"},
    151832: {"Unified_Ideograph", "Ideographic"},
    151833: {"Unified_Ideograph", "Ideographic"},
    151834: {"Unified_Ideograph", "Ideographic"},
    151835: {"Unified_Ideograph", "Ideographic"},
    151836: {"Unified_Ideograph", "Ideographic"},
    151837: {"Unified_Ideograph", "Ideographic"},
    151838: {"Unified_Ideograph", "Ideographic"},
    151839: {"Unified_Ideograph", "Ideographic"},
    151840: {"Unified_Ideograph", "Ideographic"},
    151841: {"Unified_Ideograph", "Ideographic"},
    151842: {"Unified_Ideograph", "Ideographic"},
    151843: {"Unified_Ideograph", "Ideographic"},
    151844: {"Unified_Ideograph", "Ideographic"},
    151845: {"Unified_Ideograph", "Ideographic"},
    151846: {"Unified_Ideograph", "Ideographic"},
    151847: {"Unified_Ideograph", "Ideographic"},
    151848: {"Unified_Ideograph", "Ideographic"},
    151849: {"Unified_Ideograph", "Ideographic"},
    151850: {"Unified_Ideograph", "Ideographic"},
    151851: {"Unified_Ideograph", "Ideographic"},
    151852: {"Unified_Ideograph", "Ideographic"},
    151853: {"Unified_Ideograph", "Ideographic"},
    151854: {"Unified_Ideograph", "Ideographic"},
    151855: {"Unified_Ideograph", "Ideographic"},
    151856: {"Unified_Ideograph", "Ideographic"},
    151857: {"Unified_Ideograph", "Ideographic"},
    151858: {"Unified_Ideograph", "Ideographic"},
    151859: {"Unified_Ideograph", "Ideographic"},
    151860: {"Unified_Ideograph", "Ideographic"},
    151861: {"Unified_Ideograph", "Ideographic"},
    151862: {"Unified_Ideograph", "Ideographic"},
    151863: {"Unified_Ideograph", "Ideographic"},
    151864: {"Unified_Ideograph", "Ideographic"},
    151865: {"Unified_Ideograph", "Ideographic"},
    151866: {"Unified_Ideograph", "Ideographic"},
    151867: {"Unified_Ideograph", "Ideographic"},
    151868: {"Unified_Ideograph", "Ideographic"},
    151869: {"Unified_Ideograph", "Ideographic"},
    151870: {"Unified_Ideograph", "Ideographic"},
    151871: {"Unified_Ideograph", "Ideographic"},
    151872: {"Unified_Ideograph", "Ideographic"},
    151873: {"Unified_Ideograph", "Ideographic"},
    151874: {"Unified_Ideograph", "Ideographic"},
    151875: {"Unified_Ideograph", "Ideographic"},
    151876: {"Unified_Ideograph", "Ideographic"},
    151877: {"Unified_Ideograph", "Ideographic"},
    151878: {"Unified_Ideograph", "Ideographic"},
    151879: {"Unified_Ideograph", "Ideographic"},
    151880: {"Unified_Ideograph", "Ideographic"},
    151881: {"Unified_Ideograph", "Ideographic"},
    151882: {"Unified_Ideograph", "Ideographic"},
    151883: {"Unified_Ideograph", "Ideographic"},
    151884: {"Unified_Ideograph", "Ideographic"},
    151885: {"Unified_Ideograph", "Ideographic"},
    151886: {"Unified_Ideograph", "Ideographic"},
    151887: {"Unified_Ideograph", "Ideographic"},
    151888: {"Unified_Ideograph", "Ideographic"},
    151889: {"Unified_Ideograph", "Ideographic"},
    151890: {"Unified_Ideograph", "Ideographic"},
    151891: {"Unified_Ideograph", "Ideographic"},
    151892: {"Unified_Ideograph", "Ideographic"},
    151893: {"Unified_Ideograph", "Ideographic"},
    151894: {"Unified_Ideograph", "Ideographic"},
    151895: {"Unified_Ideograph", "Ideographic"},
    151896: {"Unified_Ideograph", "Ideographic"},
    151897: {"Unified_Ideograph", "Ideographic"},
    151898: {"Unified_Ideograph", "Ideographic"},
    151899: {"Unified_Ideograph", "Ideographic"},
    151900: {"Unified_Ideograph", "Ideographic"},
    151901: {"Unified_Ideograph", "Ideographic"},
    151902: {"Unified_Ideograph", "Ideographic"},
    151903: {"Unified_Ideograph", "Ideographic"},
    151904: {"Unified_Ideograph", "Ideographic"},
    151905: {"Unified_Ideograph", "Ideographic"},
    151906: {"Unified_Ideograph", "Ideographic"},
    151907: {"Unified_Ideograph", "Ideographic"},
    151908: {"Unified_Ideograph", "Ideographic"},
    151909: {"Unified_Ideograph", "Ideographic"},
    151910: {"Unified_Ideograph", "Ideographic"},
    151911: {"Unified_Ideograph", "Ideographic"},
    151912: {"Unified_Ideograph", "Ideographic"},
    151913: {"Unified_Ideograph", "Ideographic"},
    151914: {"Unified_Ideograph", "Ideographic"},
    151915: {"Unified_Ideograph", "Ideographic"},
    151916: {"Unified_Ideograph", "Ideographic"},
    151917: {"Unified_Ideograph", "Ideographic"},
    151918: {"Unified_Ideograph", "Ideographic"},
    151919: {"Unified_Ideograph", "Ideographic"},
    151920: {"Unified_Ideograph", "Ideographic"},
    151921: {"Unified_Ideograph", "Ideographic"},
    151922: {"Unified_Ideograph", "Ideographic"},
    151923: {"Unified_Ideograph", "Ideographic"},
    151924: {"Unified_Ideograph", "Ideographic"},
    151925: {"Unified_Ideograph", "Ideographic"},
    151926: {"Unified_Ideograph", "Ideographic"},
    151927: {"Unified_Ideograph", "Ideographic"},
    151928: {"Unified_Ideograph", "Ideographic"},
    151929: {"Unified_Ideograph", "Ideographic"},
    151930: {"Unified_Ideograph", "Ideographic"},
    151931: {"Unified_Ideograph", "Ideographic"},
    151932: {"Unified_Ideograph", "Ideographic"},
    151933: {"Unified_Ideograph", "Ideographic"},
    151934: {"Unified_Ideograph", "Ideographic"},
    151935: {"Unified_Ideograph", "Ideographic"},
    151936: {"Unified_Ideograph", "Ideographic"},
    151937: {"Unified_Ideograph", "Ideographic"},
    151938: {"Unified_Ideograph", "Ideographic"},
    151939: {"Unified_Ideograph", "Ideographic"},
    151940: {"Unified_Ideograph", "Ideographic"},
    151941: {"Unified_Ideograph", "Ideographic"},
    151942: {"Unified_Ideograph", "Ideographic"},
    151943: {"Unified_Ideograph", "Ideographic"},
    151944: {"Unified_Ideograph", "Ideographic"},
    151945: {"Unified_Ideograph", "Ideographic"},
    151946: {"Unified_Ideograph", "Ideographic"},
    151947: {"Unified_Ideograph", "Ideographic"},
    151948: {"Unified_Ideograph", "Ideographic"},
    151949: {"Unified_Ideograph", "Ideographic"},
    151950: {"Unified_Ideograph", "Ideographic"},
    151951: {"Unified_Ideograph", "Ideographic"},
    151952: {"Unified_Ideograph", "Ideographic"},
    151953: {"Unified_Ideograph", "Ideographic"},
    151954: {"Unified_Ideograph", "Ideographic"},
    151955: {"Unified_Ideograph", "Ideographic"},
    151956: {"Unified_Ideograph", "Ideographic"},
    151957: {"Unified_Ideograph", "Ideographic"},
    151958: {"Unified_Ideograph", "Ideographic"},
    151959: {"Unified_Ideograph", "Ideographic"},
    151960: {"Unified_Ideograph", "Ideographic"},
    151961: {"Unified_Ideograph", "Ideographic"},
    151962: {"Unified_Ideograph", "Ideographic"},
    151963: {"Unified_Ideograph", "Ideographic"},
    151964: {"Unified_Ideograph", "Ideographic"},
    151965: {"Unified_Ideograph", "Ideographic"},
    151966: {"Unified_Ideograph", "Ideographic"},
    151967: {"Unified_Ideograph", "Ideographic"},
    151968: {"Unified_Ideograph", "Ideographic"},
    151969: {"Unified_Ideograph", "Ideographic"},
    151970: {"Unified_Ideograph", "Ideographic"},
    151971: {"Unified_Ideograph", "Ideographic"},
    151972: {"Unified_Ideograph", "Ideographic"},
    151973: {"Unified_Ideograph", "Ideographic"},
    151974: {"Unified_Ideograph", "Ideographic"},
    151975: {"Unified_Ideograph", "Ideographic"},
    151976: {"Unified_Ideograph", "Ideographic"},
    151977: {"Unified_Ideograph", "Ideographic"},
    151978: {"Unified_Ideograph", "Ideographic"},
    151979: {"Unified_Ideograph", "Ideographic"},
    151980: {"Unified_Ideograph", "Ideographic"},
    151981: {"Unified_Ideograph", "Ideographic"},
    151982: {"Unified_Ideograph", "Ideographic"},
    151983: {"Unified_Ideograph", "Ideographic"},
    151984: {"Unified_Ideograph", "Ideographic"},
    151985: {"Unified_Ideograph", "Ideographic"},
    151986: {"Unified_Ideograph", "Ideographic"},
    151987: {"Unified_Ideograph", "Ideographic"},
    151988: {"Unified_Ideograph", "Ideographic"},
    151989: {"Unified_Ideograph", "Ideographic"},
    151990: {"Unified_Ideograph", "Ideographic"},
    151991: {"Unified_Ideograph", "Ideographic"},
    151992: {"Unified_Ideograph", "Ideographic"},
    151993: {"Unified_Ideograph", "Ideographic"},
    151994: {"Unified_Ideograph", "Ideographic"},
    151995: {"Unified_Ideograph", "Ideographic"},
    151996: {"Unified_Ideograph", "Ideographic"},
    151997: {"Unified_Ideograph", "Ideographic"},
    151998: {"Unified_Ideograph", "Ideographic"},
    151999: {"Unified_Ideograph", "Ideographic"},
    152000: {"Unified_Ideograph", "Ideographic"},
    152001: {"Unified_Ideograph", "Ideographic"},
    152002: {"Unified_Ideograph", "Ideographic"},
    152003: {"Unified_Ideograph", "Ideographic"},
    152004: {"Unified_Ideograph", "Ideographic"},
    152005: {"Unified_Ideograph", "Ideographic"},
    152006: {"Unified_Ideograph", "Ideographic"},
    152007: {"Unified_Ideograph", "Ideographic"},
    152008: {"Unified_Ideograph", "Ideographic"},
    152009: {"Unified_Ideograph", "Ideographic"},
    152010: {"Unified_Ideograph", "Ideographic"},
    152011: {"Unified_Ideograph", "Ideographic"},
    152012: {"Unified_Ideograph", "Ideographic"},
    152013: {"Unified_Ideograph", "Ideographic"},
    152014: {"Unified_Ideograph", "Ideographic"},
    152015: {"Unified_Ideograph", "Ideographic"},
    152016: {"Unified_Ideograph", "Ideographic"},
    152017: {"Unified_Ideograph", "Ideographic"},
    152018: {"Unified_Ideograph", "Ideographic"},
    152019: {"Unified_Ideograph", "Ideographic"},
    152020: {"Unified_Ideograph", "Ideographic"},
    152021: {"Unified_Ideograph", "Ideographic"},
    152022: {"Unified_Ideograph", "Ideographic"},
    152023: {"Unified_Ideograph", "Ideographic"},
    152024: {"Unified_Ideograph", "Ideographic"},
    152025: {"Unified_Ideograph", "Ideographic"},
    152026: {"Unified_Ideograph", "Ideographic"},
    152027: {"Unified_Ideograph", "Ideographic"},
    152028: {"Unified_Ideograph", "Ideographic"},
    152029: {"Unified_Ideograph", "Ideographic"},
    152030: {"Unified_Ideograph", "Ideographic"},
    152031: {"Unified_Ideograph", "Ideographic"},
    152032: {"Unified_Ideograph", "Ideographic"},
    152033: {"Unified_Ideograph", "Ideographic"},
    152034: {"Unified_Ideograph", "Ideographic"},
    152035: {"Unified_Ideograph", "Ideographic"},
    152036: {"Unified_Ideograph", "Ideographic"},
    152037: {"Unified_Ideograph", "Ideographic"},
    152038: {"Unified_Ideograph", "Ideographic"},
    152039: {"Unified_Ideograph", "Ideographic"},
    152040: {"Unified_Ideograph", "Ideographic"},
    152041: {"Unified_Ideograph", "Ideographic"},
    152042: {"Unified_Ideograph", "Ideographic"},
    152043: {"Unified_Ideograph", "Ideographic"},
    152044: {"Unified_Ideograph", "Ideographic"},
    152045: {"Unified_Ideograph", "Ideographic"},
    152046: {"Unified_Ideograph", "Ideographic"},
    152047: {"Unified_Ideograph", "Ideographic"},
    152048: {"Unified_Ideograph", "Ideographic"},
    152049: {"Unified_Ideograph", "Ideographic"},
    152050: {"Unified_Ideograph", "Ideographic"},
    152051: {"Unified_Ideograph", "Ideographic"},
    152052: {"Unified_Ideograph", "Ideographic"},
    152053: {"Unified_Ideograph", "Ideographic"},
    152054: {"Unified_Ideograph", "Ideographic"},
    152055: {"Unified_Ideograph", "Ideographic"},
    152056: {"Unified_Ideograph", "Ideographic"},
    152057: {"Unified_Ideograph", "Ideographic"},
    152058: {"Unified_Ideograph", "Ideographic"},
    152059: {"Unified_Ideograph", "Ideographic"},
    152060: {"Unified_Ideograph", "Ideographic"},
    152061: {"Unified_Ideograph", "Ideographic"},
    152062: {"Unified_Ideograph", "Ideographic"},
    152063: {"Unified_Ideograph", "Ideographic"},
    152064: {"Unified_Ideograph", "Ideographic"},
    152065: {"Unified_Ideograph", "Ideographic"},
    152066: {"Unified_Ideograph", "Ideographic"},
    152067: {"Unified_Ideograph", "Ideographic"},
    152068: {"Unified_Ideograph", "Ideographic"},
    152069: {"Unified_Ideograph", "Ideographic"},
    152070: {"Unified_Ideograph", "Ideographic"},
    152071: {"Unified_Ideograph", "Ideographic"},
    152072: {"Unified_Ideograph", "Ideographic"},
    152073: {"Unified_Ideograph", "Ideographic"},
    152074: {"Unified_Ideograph", "Ideographic"},
    152075: {"Unified_Ideograph", "Ideographic"},
    152076: {"Unified_Ideograph", "Ideographic"},
    152077: {"Unified_Ideograph", "Ideographic"},
    152078: {"Unified_Ideograph", "Ideographic"},
    152079: {"Unified_Ideograph", "Ideographic"},
    152080: {"Unified_Ideograph", "Ideographic"},
    152081: {"Unified_Ideograph", "Ideographic"},
    152082: {"Unified_Ideograph", "Ideographic"},
    152083: {"Unified_Ideograph", "Ideographic"},
    152084: {"Unified_Ideograph", "Ideographic"},
    152085: {"Unified_Ideograph", "Ideographic"},
    152086: {"Unified_Ideograph", "Ideographic"},
    152087: {"Unified_Ideograph", "Ideographic"},
    152088: {"Unified_Ideograph", "Ideographic"},
    152089: {"Unified_Ideograph", "Ideographic"},
    152090: {"Unified_Ideograph", "Ideographic"},
    152091: {"Unified_Ideograph", "Ideographic"},
    152092: {"Unified_Ideograph", "Ideographic"},
    152093: {"Unified_Ideograph", "Ideographic"},
    152094: {"Unified_Ideograph", "Ideographic"},
    152095: {"Unified_Ideograph", "Ideographic"},
    152096: {"Unified_Ideograph", "Ideographic"},
    152097: {"Unified_Ideograph", "Ideographic"},
    152098: {"Unified_Ideograph", "Ideographic"},
    152099: {"Unified_Ideograph", "Ideographic"},
    152100: {"Unified_Ideograph", "Ideographic"},
    152101: {"Unified_Ideograph", "Ideographic"},
    152102: {"Unified_Ideograph", "Ideographic"},
    152103: {"Unified_Ideograph", "Ideographic"},
    152104: {"Unified_Ideograph", "Ideographic"},
    152105: {"Unified_Ideograph", "Ideographic"},
    152106: {"Unified_Ideograph", "Ideographic"},
    152107: {"Unified_Ideograph", "Ideographic"},
    152108: {"Unified_Ideograph", "Ideographic"},
    152109: {"Unified_Ideograph", "Ideographic"},
    152110: {"Unified_Ideograph", "Ideographic"},
    152111: {"Unified_Ideograph", "Ideographic"},
    152112: {"Unified_Ideograph", "Ideographic"},
    152113: {"Unified_Ideograph", "Ideographic"},
    152114: {"Unified_Ideograph", "Ideographic"},
    152115: {"Unified_Ideograph", "Ideographic"},
    152116: {"Unified_Ideograph", "Ideographic"},
    152117: {"Unified_Ideograph", "Ideographic"},
    152118: {"Unified_Ideograph", "Ideographic"},
    152119: {"Unified_Ideograph", "Ideographic"},
    152120: {"Unified_Ideograph", "Ideographic"},
    152121: {"Unified_Ideograph", "Ideographic"},
    152122: {"Unified_Ideograph", "Ideographic"},
    152123: {"Unified_Ideograph", "Ideographic"},
    152124: {"Unified_Ideograph", "Ideographic"},
    152125: {"Unified_Ideograph", "Ideographic"},
    152126: {"Unified_Ideograph", "Ideographic"},
    152127: {"Unified_Ideograph", "Ideographic"},
    152128: {"Unified_Ideograph", "Ideographic"},
    152129: {"Unified_Ideograph", "Ideographic"},
    152130: {"Unified_Ideograph", "Ideographic"},
    152131: {"Unified_Ideograph", "Ideographic"},
    152132: {"Unified_Ideograph", "Ideographic"},
    152133: {"Unified_Ideograph", "Ideographic"},
    152134: {"Unified_Ideograph", "Ideographic"},
    152135: {"Unified_Ideograph", "Ideographic"},
    152136: {"Unified_Ideograph", "Ideographic"},
    152137: {"Unified_Ideograph", "Ideographic"},
    152138: {"Unified_Ideograph", "Ideographic"},
    152139: {"Unified_Ideograph", "Ideographic"},
    152140: {"Unified_Ideograph", "Ideographic"},
    152141: {"Unified_Ideograph", "Ideographic"},
    152142: {"Unified_Ideograph", "Ideographic"},
    152143: {"Unified_Ideograph", "Ideographic"},
    152144: {"Unified_Ideograph", "Ideographic"},
    152145: {"Unified_Ideograph", "Ideographic"},
    152146: {"Unified_Ideograph", "Ideographic"},
    152147: {"Unified_Ideograph", "Ideographic"},
    152148: {"Unified_Ideograph", "Ideographic"},
    152149: {"Unified_Ideograph", "Ideographic"},
    152150: {"Unified_Ideograph", "Ideographic"},
    152151: {"Unified_Ideograph", "Ideographic"},
    152152: {"Unified_Ideograph", "Ideographic"},
    152153: {"Unified_Ideograph", "Ideographic"},
    152154: {"Unified_Ideograph", "Ideographic"},
    152155: {"Unified_Ideograph", "Ideographic"},
    152156: {"Unified_Ideograph", "Ideographic"},
    152157: {"Unified_Ideograph", "Ideographic"},
    152158: {"Unified_Ideograph", "Ideographic"},
    152159: {"Unified_Ideograph", "Ideographic"},
    152160: {"Unified_Ideograph", "Ideographic"},
    152161: {"Unified_Ideograph", "Ideographic"},
    152162: {"Unified_Ideograph", "Ideographic"},
    152163: {"Unified_Ideograph", "Ideographic"},
    152164: {"Unified_Ideograph", "Ideographic"},
    152165: {"Unified_Ideograph", "Ideographic"},
    152166: {"Unified_Ideograph", "Ideographic"},
    152167: {"Unified_Ideograph", "Ideographic"},
    152168: {"Unified_Ideograph", "Ideographic"},
    152169: {"Unified_Ideograph", "Ideographic"},
    152170: {"Unified_Ideograph", "Ideographic"},
    152171: {"Unified_Ideograph", "Ideographic"},
    152172: {"Unified_Ideograph", "Ideographic"},
    152173: {"Unified_Ideograph", "Ideographic"},
    152174: {"Unified_Ideograph", "Ideographic"},
    152175: {"Unified_Ideograph", "Ideographic"},
    152176: {"Unified_Ideograph", "Ideographic"},
    152177: {"Unified_Ideograph", "Ideographic"},
    152178: {"Unified_Ideograph", "Ideographic"},
    152179: {"Unified_Ideograph", "Ideographic"},
    152180: {"Unified_Ideograph", "Ideographic"},
    152181: {"Unified_Ideograph", "Ideographic"},
    152182: {"Unified_Ideograph", "Ideographic"},
    152183: {"Unified_Ideograph", "Ideographic"},
    152184: {"Unified_Ideograph", "Ideographic"},
    152185: {"Unified_Ideograph", "Ideographic"},
    152186: {"Unified_Ideograph", "Ideographic"},
    152187: {"Unified_Ideograph", "Ideographic"},
    152188: {"Unified_Ideograph", "Ideographic"},
    152189: {"Unified_Ideograph", "Ideographic"},
    152190: {"Unified_Ideograph", "Ideographic"},
    152191: {"Unified_Ideograph", "Ideographic"},
    152192: {"Unified_Ideograph", "Ideographic"},
    152193: {"Unified_Ideograph", "Ideographic"},
    152194: {"Unified_Ideograph", "Ideographic"},
    152195: {"Unified_Ideograph", "Ideographic"},
    152196: {"Unified_Ideograph", "Ideographic"},
    152197: {"Unified_Ideograph", "Ideographic"},
    152198: {"Unified_Ideograph", "Ideographic"},
    152199: {"Unified_Ideograph", "Ideographic"},
    152200: {"Unified_Ideograph", "Ideographic"},
    152201: {"Unified_Ideograph", "Ideographic"},
    152202: {"Unified_Ideograph", "Ideographic"},
    152203: {"Unified_Ideograph", "Ideographic"},
    152204: {"Unified_Ideograph", "Ideographic"},
    152205: {"Unified_Ideograph", "Ideographic"},
    152206: {"Unified_Ideograph", "Ideographic"},
    152207: {"Unified_Ideograph", "Ideographic"},
    152208: {"Unified_Ideograph", "Ideographic"},
    152209: {"Unified_Ideograph", "Ideographic"},
    152210: {"Unified_Ideograph", "Ideographic"},
    152211: {"Unified_Ideograph", "Ideographic"},
    152212: {"Unified_Ideograph", "Ideographic"},
    152213: {"Unified_Ideograph", "Ideographic"},
    152214: {"Unified_Ideograph", "Ideographic"},
    152215: {"Unified_Ideograph", "Ideographic"},
    152216: {"Unified_Ideograph", "Ideographic"},
    152217: {"Unified_Ideograph", "Ideographic"},
    152218: {"Unified_Ideograph", "Ideographic"},
    152219: {"Unified_Ideograph", "Ideographic"},
    152220: {"Unified_Ideograph", "Ideographic"},
    152221: {"Unified_Ideograph", "Ideographic"},
    152222: {"Unified_Ideograph", "Ideographic"},
    152223: {"Unified_Ideograph", "Ideographic"},
    152224: {"Unified_Ideograph", "Ideographic"},
    152225: {"Unified_Ideograph", "Ideographic"},
    152226: {"Unified_Ideograph", "Ideographic"},
    152227: {"Unified_Ideograph", "Ideographic"},
    152228: {"Unified_Ideograph", "Ideographic"},
    152229: {"Unified_Ideograph", "Ideographic"},
    152230: {"Unified_Ideograph", "Ideographic"},
    152231: {"Unified_Ideograph", "Ideographic"},
    152232: {"Unified_Ideograph", "Ideographic"},
    152233: {"Unified_Ideograph", "Ideographic"},
    152234: {"Unified_Ideograph", "Ideographic"},
    152235: {"Unified_Ideograph", "Ideographic"},
    152236: {"Unified_Ideograph", "Ideographic"},
    152237: {"Unified_Ideograph", "Ideographic"},
    152238: {"Unified_Ideograph", "Ideographic"},
    152239: {"Unified_Ideograph", "Ideographic"},
    152240: {"Unified_Ideograph", "Ideographic"},
    152241: {"Unified_Ideograph", "Ideographic"},
    152242: {"Unified_Ideograph", "Ideographic"},
    152243: {"Unified_Ideograph", "Ideographic"},
    152244: {"Unified_Ideograph", "Ideographic"},
    152245: {"Unified_Ideograph", "Ideographic"},
    152246: {"Unified_Ideograph", "Ideographic"},
    152247: {"Unified_Ideograph", "Ideographic"},
    152248: {"Unified_Ideograph", "Ideographic"},
    152249: {"Unified_Ideograph", "Ideographic"},
    152250: {"Unified_Ideograph", "Ideographic"},
    152251: {"Unified_Ideograph", "Ideographic"},
    152252: {"Unified_Ideograph", "Ideographic"},
    152253: {"Unified_Ideograph", "Ideographic"},
    152254: {"Unified_Ideograph", "Ideographic"},
    152255: {"Unified_Ideograph", "Ideographic"},
    152256: {"Unified_Ideograph", "Ideographic"},
    152257: {"Unified_Ideograph", "Ideographic"},
    152258: {"Unified_Ideograph", "Ideographic"},
    152259: {"Unified_Ideograph", "Ideographic"},
    152260: {"Unified_Ideograph", "Ideographic"},
    152261: {"Unified_Ideograph", "Ideographic"},
    152262: {"Unified_Ideograph", "Ideographic"},
    152263: {"Unified_Ideograph", "Ideographic"},
    152264: {"Unified_Ideograph", "Ideographic"},
    152265: {"Unified_Ideograph", "Ideographic"},
    152266: {"Unified_Ideograph", "Ideographic"},
    152267: {"Unified_Ideograph", "Ideographic"},
    152268: {"Unified_Ideograph", "Ideographic"},
    152269: {"Unified_Ideograph", "Ideographic"},
    152270: {"Unified_Ideograph", "Ideographic"},
    152271: {"Unified_Ideograph", "Ideographic"},
    152272: {"Unified_Ideograph", "Ideographic"},
    152273: {"Unified_Ideograph", "Ideographic"},
    152274: {"Unified_Ideograph", "Ideographic"},
    152275: {"Unified_Ideograph", "Ideographic"},
    152276: {"Unified_Ideograph", "Ideographic"},
    152277: {"Unified_Ideograph", "Ideographic"},
    152278: {"Unified_Ideograph", "Ideographic"},
    152279: {"Unified_Ideograph", "Ideographic"},
    152280: {"Unified_Ideograph", "Ideographic"},
    152281: {"Unified_Ideograph", "Ideographic"},
    152282: {"Unified_Ideograph", "Ideographic"},
    152283: {"Unified_Ideograph", "Ideographic"},
    152284: {"Unified_Ideograph", "Ideographic"},
    152285: {"Unified_Ideograph", "Ideographic"},
    152286: {"Unified_Ideograph", "Ideographic"},
    152287: {"Unified_Ideograph", "Ideographic"},
    152288: {"Unified_Ideograph", "Ideographic"},
    152289: {"Unified_Ideograph", "Ideographic"},
    152290: {"Unified_Ideograph", "Ideographic"},
    152291: {"Unified_Ideograph", "Ideographic"},
    152292: {"Unified_Ideograph", "Ideographic"},
    152293: {"Unified_Ideograph", "Ideographic"},
    152294: {"Unified_Ideograph", "Ideographic"},
    152295: {"Unified_Ideograph", "Ideographic"},
    152296: {"Unified_Ideograph", "Ideographic"},
    152297: {"Unified_Ideograph", "Ideographic"},
    152298: {"Unified_Ideograph", "Ideographic"},
    152299: {"Unified_Ideograph", "Ideographic"},
    152300: {"Unified_Ideograph", "Ideographic"},
    152301: {"Unified_Ideograph", "Ideographic"},
    152302: {"Unified_Ideograph", "Ideographic"},
    152303: {"Unified_Ideograph", "Ideographic"},
    152304: {"Unified_Ideograph", "Ideographic"},
    152305: {"Unified_Ideograph", "Ideographic"},
    152306: {"Unified_Ideograph", "Ideographic"},
    152307: {"Unified_Ideograph", "Ideographic"},
    152308: {"Unified_Ideograph", "Ideographic"},
    152309: {"Unified_Ideograph", "Ideographic"},
    152310: {"Unified_Ideograph", "Ideographic"},
    152311: {"Unified_Ideograph", "Ideographic"},
    152312: {"Unified_Ideograph", "Ideographic"},
    152313: {"Unified_Ideograph", "Ideographic"},
    152314: {"Unified_Ideograph", "Ideographic"},
    152315: {"Unified_Ideograph", "Ideographic"},
    152316: {"Unified_Ideograph", "Ideographic"},
    152317: {"Unified_Ideograph", "Ideographic"},
    152318: {"Unified_Ideograph", "Ideographic"},
    152319: {"Unified_Ideograph", "Ideographic"},
    152320: {"Unified_Ideograph", "Ideographic"},
    152321: {"Unified_Ideograph", "Ideographic"},
    152322: {"Unified_Ideograph", "Ideographic"},
    152323: {"Unified_Ideograph", "Ideographic"},
    152324: {"Unified_Ideograph", "Ideographic"},
    152325: {"Unified_Ideograph", "Ideographic"},
    152326: {"Unified_Ideograph", "Ideographic"},
    152327: {"Unified_Ideograph", "Ideographic"},
    152328: {"Unified_Ideograph", "Ideographic"},
    152329: {"Unified_Ideograph", "Ideographic"},
    152330: {"Unified_Ideograph", "Ideographic"},
    152331: {"Unified_Ideograph", "Ideographic"},
    152332: {"Unified_Ideograph", "Ideographic"},
    152333: {"Unified_Ideograph", "Ideographic"},
    152334: {"Unified_Ideograph", "Ideographic"},
    152335: {"Unified_Ideograph", "Ideographic"},
    152336: {"Unified_Ideograph", "Ideographic"},
    152337: {"Unified_Ideograph", "Ideographic"},
    152338: {"Unified_Ideograph", "Ideographic"},
    152339: {"Unified_Ideograph", "Ideographic"},
    152340: {"Unified_Ideograph", "Ideographic"},
    152341: {"Unified_Ideograph", "Ideographic"},
    152342: {"Unified_Ideograph", "Ideographic"},
    152343: {"Unified_Ideograph", "Ideographic"},
    152344: {"Unified_Ideograph", "Ideographic"},
    152345: {"Unified_Ideograph", "Ideographic"},
    152346: {"Unified_Ideograph", "Ideographic"},
    152347: {"Unified_Ideograph", "Ideographic"},
    152348: {"Unified_Ideograph", "Ideographic"},
    152349: {"Unified_Ideograph", "Ideographic"},
    152350: {"Unified_Ideograph", "Ideographic"},
    152351: {"Unified_Ideograph", "Ideographic"},
    152352: {"Unified_Ideograph", "Ideographic"},
    152353: {"Unified_Ideograph", "Ideographic"},
    152354: {"Unified_Ideograph", "Ideographic"},
    152355: {"Unified_Ideograph", "Ideographic"},
    152356: {"Unified_Ideograph", "Ideographic"},
    152357: {"Unified_Ideograph", "Ideographic"},
    152358: {"Unified_Ideograph", "Ideographic"},
    152359: {"Unified_Ideograph", "Ideographic"},
    152360: {"Unified_Ideograph", "Ideographic"},
    152361: {"Unified_Ideograph", "Ideographic"},
    152362: {"Unified_Ideograph", "Ideographic"},
    152363: {"Unified_Ideograph", "Ideographic"},
    152364: {"Unified_Ideograph", "Ideographic"},
    152365: {"Unified_Ideograph", "Ideographic"},
    152366: {"Unified_Ideograph", "Ideographic"},
    152367: {"Unified_Ideograph", "Ideographic"},
    152368: {"Unified_Ideograph", "Ideographic"},
    152369: {"Unified_Ideograph", "Ideographic"},
    152370: {"Unified_Ideograph", "Ideographic"},
    152371: {"Unified_Ideograph", "Ideographic"},
    152372: {"Unified_Ideograph", "Ideographic"},
    152373: {"Unified_Ideograph", "Ideographic"},
    152374: {"Unified_Ideograph", "Ideographic"},
    152375: {"Unified_Ideograph", "Ideographic"},
    152376: {"Unified_Ideograph", "Ideographic"},
    152377: {"Unified_Ideograph", "Ideographic"},
    152378: {"Unified_Ideograph", "Ideographic"},
    152379: {"Unified_Ideograph", "Ideographic"},
    152380: {"Unified_Ideograph", "Ideographic"},
    152381: {"Unified_Ideograph", "Ideographic"},
    152382: {"Unified_Ideograph", "Ideographic"},
    152383: {"Unified_Ideograph", "Ideographic"},
    152384: {"Unified_Ideograph", "Ideographic"},
    152385: {"Unified_Ideograph", "Ideographic"},
    152386: {"Unified_Ideograph", "Ideographic"},
    152387: {"Unified_Ideograph", "Ideographic"},
    152388: {"Unified_Ideograph", "Ideographic"},
    152389: {"Unified_Ideograph", "Ideographic"},
    152390: {"Unified_Ideograph", "Ideographic"},
    152391: {"Unified_Ideograph", "Ideographic"},
    152392: {"Unified_Ideograph", "Ideographic"},
    152393: {"Unified_Ideograph", "Ideographic"},
    152394: {"Unified_Ideograph", "Ideographic"},
    152395: {"Unified_Ideograph", "Ideographic"},
    152396: {"Unified_Ideograph", "Ideographic"},
    152397: {"Unified_Ideograph", "Ideographic"},
    152398: {"Unified_Ideograph", "Ideographic"},
    152399: {"Unified_Ideograph", "Ideographic"},
    152400: {"Unified_Ideograph", "Ideographic"},
    152401: {"Unified_Ideograph", "Ideographic"},
    152402: {"Unified_Ideograph", "Ideographic"},
    152403: {"Unified_Ideograph", "Ideographic"},
    152404: {"Unified_Ideograph", "Ideographic"},
    152405: {"Unified_Ideograph", "Ideographic"},
    152406: {"Unified_Ideograph", "Ideographic"},
    152407: {"Unified_Ideograph", "Ideographic"},
    152408: {"Unified_Ideograph", "Ideographic"},
    152409: {"Unified_Ideograph", "Ideographic"},
    152410: {"Unified_Ideograph", "Ideographic"},
    152411: {"Unified_Ideograph", "Ideographic"},
    152412: {"Unified_Ideograph", "Ideographic"},
    152413: {"Unified_Ideograph", "Ideographic"},
    152414: {"Unified_Ideograph", "Ideographic"},
    152415: {"Unified_Ideograph", "Ideographic"},
    152416: {"Unified_Ideograph", "Ideographic"},
    152417: {"Unified_Ideograph", "Ideographic"},
    152418: {"Unified_Ideograph", "Ideographic"},
    152419: {"Unified_Ideograph", "Ideographic"},
    152420: {"Unified_Ideograph", "Ideographic"},
    152421: {"Unified_Ideograph", "Ideographic"},
    152422: {"Unified_Ideograph", "Ideographic"},
    152423: {"Unified_Ideograph", "Ideographic"},
    152424: {"Unified_Ideograph", "Ideographic"},
    152425: {"Unified_Ideograph", "Ideographic"},
    152426: {"Unified_Ideograph", "Ideographic"},
    152427: {"Unified_Ideograph", "Ideographic"},
    152428: {"Unified_Ideograph", "Ideographic"},
    152429: {"Unified_Ideograph", "Ideographic"},
    152430: {"Unified_Ideograph", "Ideographic"},
    152431: {"Unified_Ideograph", "Ideographic"},
    152432: {"Unified_Ideograph", "Ideographic"},
    152433: {"Unified_Ideograph", "Ideographic"},
    152434: {"Unified_Ideograph", "Ideographic"},
    152435: {"Unified_Ideograph", "Ideographic"},
    152436: {"Unified_Ideograph", "Ideographic"},
    152437: {"Unified_Ideograph", "Ideographic"},
    152438: {"Unified_Ideograph", "Ideographic"},
    152439: {"Unified_Ideograph", "Ideographic"},
    152440: {"Unified_Ideograph", "Ideographic"},
    152441: {"Unified_Ideograph", "Ideographic"},
    152442: {"Unified_Ideograph", "Ideographic"},
    152443: {"Unified_Ideograph", "Ideographic"},
    152444: {"Unified_Ideograph", "Ideographic"},
    152445: {"Unified_Ideograph", "Ideographic"},
    152446: {"Unified_Ideograph", "Ideographic"},
    152447: {"Unified_Ideograph", "Ideographic"},
    152448: {"Unified_Ideograph", "Ideographic"},
    152449: {"Unified_Ideograph", "Ideographic"},
    152450: {"Unified_Ideograph", "Ideographic"},
    152451: {"Unified_Ideograph", "Ideographic"},
    152452: {"Unified_Ideograph", "Ideographic"},
    152453: {"Unified_Ideograph", "Ideographic"},
    152454: {"Unified_Ideograph", "Ideographic"},
    152455: {"Unified_Ideograph", "Ideographic"},
    152456: {"Unified_Ideograph", "Ideographic"},
    152457: {"Unified_Ideograph", "Ideographic"},
    152458: {"Unified_Ideograph", "Ideographic"},
    152459: {"Unified_Ideograph", "Ideographic"},
    152460: {"Unified_Ideograph", "Ideographic"},
    152461: {"Unified_Ideograph", "Ideographic"},
    152462: {"Unified_Ideograph", "Ideographic"},
    152463: {"Unified_Ideograph", "Ideographic"},
    152464: {"Unified_Ideograph", "Ideographic"},
    152465: {"Unified_Ideograph", "Ideographic"},
    152466: {"Unified_Ideograph", "Ideographic"},
    152467: {"Unified_Ideograph", "Ideographic"},
    152468: {"Unified_Ideograph", "Ideographic"},
    152469: {"Unified_Ideograph", "Ideographic"},
    152470: {"Unified_Ideograph", "Ideographic"},
    152471: {"Unified_Ideograph", "Ideographic"},
    152472: {"Unified_Ideograph", "Ideographic"},
    152473: {"Unified_Ideograph", "Ideographic"},
    152474: {"Unified_Ideograph", "Ideographic"},
    152475: {"Unified_Ideograph", "Ideographic"},
    152476: {"Unified_Ideograph", "Ideographic"},
    152477: {"Unified_Ideograph", "Ideographic"},
    152478: {"Unified_Ideograph", "Ideographic"},
    152479: {"Unified_Ideograph", "Ideographic"},
    152480: {"Unified_Ideograph", "Ideographic"},
    152481: {"Unified_Ideograph", "Ideographic"},
    152482: {"Unified_Ideograph", "Ideographic"},
    152483: {"Unified_Ideograph", "Ideographic"},
    152484: {"Unified_Ideograph", "Ideographic"},
    152485: {"Unified_Ideograph", "Ideographic"},
    152486: {"Unified_Ideograph", "Ideographic"},
    152487: {"Unified_Ideograph", "Ideographic"},
    152488: {"Unified_Ideograph", "Ideographic"},
    152489: {"Unified_Ideograph", "Ideographic"},
    152490: {"Unified_Ideograph", "Ideographic"},
    152491: {"Unified_Ideograph", "Ideographic"},
    152492: {"Unified_Ideograph", "Ideographic"},
    152493: {"Unified_Ideograph", "Ideographic"},
    152494: {"Unified_Ideograph", "Ideographic"},
    152495: {"Unified_Ideograph", "Ideographic"},
    152496: {"Unified_Ideograph", "Ideographic"},
    152497: {"Unified_Ideograph", "Ideographic"},
    152498: {"Unified_Ideograph", "Ideographic"},
    152499: {"Unified_Ideograph", "Ideographic"},
    152500: {"Unified_Ideograph", "Ideographic"},
    152501: {"Unified_Ideograph", "Ideographic"},
    152502: {"Unified_Ideograph", "Ideographic"},
    152503: {"Unified_Ideograph", "Ideographic"},
    152504: {"Unified_Ideograph", "Ideographic"},
    152505: {"Unified_Ideograph", "Ideographic"},
    152506: {"Unified_Ideograph", "Ideographic"},
    152507: {"Unified_Ideograph", "Ideographic"},
    152508: {"Unified_Ideograph", "Ideographic"},
    152509: {"Unified_Ideograph", "Ideographic"},
    152510: {"Unified_Ideograph", "Ideographic"},
    152511: {"Unified_Ideograph", "Ideographic"},
    152512: {"Unified_Ideograph", "Ideographic"},
    152513: {"Unified_Ideograph", "Ideographic"},
    152514: {"Unified_Ideograph", "Ideographic"},
    152515: {"Unified_Ideograph", "Ideographic"},
    152516: {"Unified_Ideograph", "Ideographic"},
    152517: {"Unified_Ideograph", "Ideographic"},
    152518: {"Unified_Ideograph", "Ideographic"},
    152519: {"Unified_Ideograph", "Ideographic"},
    152520: {"Unified_Ideograph", "Ideographic"},
    152521: {"Unified_Ideograph", "Ideographic"},
    152522: {"Unified_Ideograph", "Ideographic"},
    152523: {"Unified_Ideograph", "Ideographic"},
    152524: {"Unified_Ideograph", "Ideographic"},
    152525: {"Unified_Ideograph", "Ideographic"},
    152526: {"Unified_Ideograph", "Ideographic"},
    152527: {"Unified_Ideograph", "Ideographic"},
    152528: {"Unified_Ideograph", "Ideographic"},
    152529: {"Unified_Ideograph", "Ideographic"},
    152530: {"Unified_Ideograph", "Ideographic"},
    152531: {"Unified_Ideograph", "Ideographic"},
    152532: {"Unified_Ideograph", "Ideographic"},
    152533: {"Unified_Ideograph", "Ideographic"},
    152534: {"Unified_Ideograph", "Ideographic"},
    152535: {"Unified_Ideograph", "Ideographic"},
    152536: {"Unified_Ideograph", "Ideographic"},
    152537: {"Unified_Ideograph", "Ideographic"},
    152538: {"Unified_Ideograph", "Ideographic"},
    152539: {"Unified_Ideograph", "Ideographic"},
    152540: {"Unified_Ideograph", "Ideographic"},
    152541: {"Unified_Ideograph", "Ideographic"},
    152542: {"Unified_Ideograph", "Ideographic"},
    152543: {"Unified_Ideograph", "Ideographic"},
    152544: {"Unified_Ideograph", "Ideographic"},
    152545: {"Unified_Ideograph", "Ideographic"},
    152546: {"Unified_Ideograph", "Ideographic"},
    152547: {"Unified_Ideograph", "Ideographic"},
    152548: {"Unified_Ideograph", "Ideographic"},
    152549: {"Unified_Ideograph", "Ideographic"},
    152550: {"Unified_Ideograph", "Ideographic"},
    152551: {"Unified_Ideograph", "Ideographic"},
    152552: {"Unified_Ideograph", "Ideographic"},
    152553: {"Unified_Ideograph", "Ideographic"},
    152554: {"Unified_Ideograph", "Ideographic"},
    152555: {"Unified_Ideograph", "Ideographic"},
    152556: {"Unified_Ideograph", "Ideographic"},
    152557: {"Unified_Ideograph", "Ideographic"},
    152558: {"Unified_Ideograph", "Ideographic"},
    152559: {"Unified_Ideograph", "Ideographic"},
    152560: {"Unified_Ideograph", "Ideographic"},
    152561: {"Unified_Ideograph", "Ideographic"},
    152562: {"Unified_Ideograph", "Ideographic"},
    152563: {"Unified_Ideograph", "Ideographic"},
    152564: {"Unified_Ideograph", "Ideographic"},
    152565: {"Unified_Ideograph", "Ideographic"},
    152566: {"Unified_Ideograph", "Ideographic"},
    152567: {"Unified_Ideograph", "Ideographic"},
    152568: {"Unified_Ideograph", "Ideographic"},
    152569: {"Unified_Ideograph", "Ideographic"},
    152570: {"Unified_Ideograph", "Ideographic"},
    152571: {"Unified_Ideograph", "Ideographic"},
    152572: {"Unified_Ideograph", "Ideographic"},
    152573: {"Unified_Ideograph", "Ideographic"},
    152574: {"Unified_Ideograph", "Ideographic"},
    152575: {"Unified_Ideograph", "Ideographic"},
    152576: {"Unified_Ideograph", "Ideographic"},
    152577: {"Unified_Ideograph", "Ideographic"},
    152578: {"Unified_Ideograph", "Ideographic"},
    152579: {"Unified_Ideograph", "Ideographic"},
    152580: {"Unified_Ideograph", "Ideographic"},
    152581: {"Unified_Ideograph", "Ideographic"},
    152582: {"Unified_Ideograph", "Ideographic"},
    152583: {"Unified_Ideograph", "Ideographic"},
    152584: {"Unified_Ideograph", "Ideographic"},
    152585: {"Unified_Ideograph", "Ideographic"},
    152586: {"Unified_Ideograph", "Ideographic"},
    152587: {"Unified_Ideograph", "Ideographic"},
    152588: {"Unified_Ideograph", "Ideographic"},
    152589: {"Unified_Ideograph", "Ideographic"},
    152590: {"Unified_Ideograph", "Ideographic"},
    152591: {"Unified_Ideograph", "Ideographic"},
    152592: {"Unified_Ideograph", "Ideographic"},
    152593: {"Unified_Ideograph", "Ideographic"},
    152594: {"Unified_Ideograph", "Ideographic"},
    152595: {"Unified_Ideograph", "Ideographic"},
    152596: {"Unified_Ideograph", "Ideographic"},
    152597: {"Unified_Ideograph", "Ideographic"},
    152598: {"Unified_Ideograph", "Ideographic"},
    152599: {"Unified_Ideograph", "Ideographic"},
    152600: {"Unified_Ideograph", "Ideographic"},
    152601: {"Unified_Ideograph", "Ideographic"},
    152602: {"Unified_Ideograph", "Ideographic"},
    152603: {"Unified_Ideograph", "Ideographic"},
    152604: {"Unified_Ideograph", "Ideographic"},
    152605: {"Unified_Ideograph", "Ideographic"},
    152606: {"Unified_Ideograph", "Ideographic"},
    152607: {"Unified_Ideograph", "Ideographic"},
    152608: {"Unified_Ideograph", "Ideographic"},
    152609: {"Unified_Ideograph", "Ideographic"},
    152610: {"Unified_Ideograph", "Ideographic"},
    152611: {"Unified_Ideograph", "Ideographic"},
    152612: {"Unified_Ideograph", "Ideographic"},
    152613: {"Unified_Ideograph", "Ideographic"},
    152614: {"Unified_Ideograph", "Ideographic"},
    152615: {"Unified_Ideograph", "Ideographic"},
    152616: {"Unified_Ideograph", "Ideographic"},
    152617: {"Unified_Ideograph", "Ideographic"},
    152618: {"Unified_Ideograph", "Ideographic"},
    152619: {"Unified_Ideograph", "Ideographic"},
    152620: {"Unified_Ideograph", "Ideographic"},
    152621: {"Unified_Ideograph", "Ideographic"},
    152622: {"Unified_Ideograph", "Ideographic"},
    152623: {"Unified_Ideograph", "Ideographic"},
    152624: {"Unified_Ideograph", "Ideographic"},
    152625: {"Unified_Ideograph", "Ideographic"},
    152626: {"Unified_Ideograph", "Ideographic"},
    152627: {"Unified_Ideograph", "Ideographic"},
    152628: {"Unified_Ideograph", "Ideographic"},
    152629: {"Unified_Ideograph", "Ideographic"},
    152630: {"Unified_Ideograph", "Ideographic"},
    152631: {"Unified_Ideograph", "Ideographic"},
    152632: {"Unified_Ideograph", "Ideographic"},
    152633: {"Unified_Ideograph", "Ideographic"},
    152634: {"Unified_Ideograph", "Ideographic"},
    152635: {"Unified_Ideograph", "Ideographic"},
    152636: {"Unified_Ideograph", "Ideographic"},
    152637: {"Unified_Ideograph", "Ideographic"},
    152638: {"Unified_Ideograph", "Ideographic"},
    152639: {"Unified_Ideograph", "Ideographic"},
    152640: {"Unified_Ideograph", "Ideographic"},
    152641: {"Unified_Ideograph", "Ideographic"},
    152642: {"Unified_Ideograph", "Ideographic"},
    152643: {"Unified_Ideograph", "Ideographic"},
    152644: {"Unified_Ideograph", "Ideographic"},
    152645: {"Unified_Ideograph", "Ideographic"},
    152646: {"Unified_Ideograph", "Ideographic"},
    152647: {"Unified_Ideograph", "Ideographic"},
    152648: {"Unified_Ideograph", "Ideographic"},
    152649: {"Unified_Ideograph", "Ideographic"},
    152650: {"Unified_Ideograph", "Ideographic"},
    152651: {"Unified_Ideograph", "Ideographic"},
    152652: {"Unified_Ideograph", "Ideographic"},
    152653: {"Unified_Ideograph", "Ideographic"},
    152654: {"Unified_Ideograph", "Ideographic"},
    152655: {"Unified_Ideograph", "Ideographic"},
    152656: {"Unified_Ideograph", "Ideographic"},
    152657: {"Unified_Ideograph", "Ideographic"},
    152658: {"Unified_Ideograph", "Ideographic"},
    152659: {"Unified_Ideograph", "Ideographic"},
    152660: {"Unified_Ideograph", "Ideographic"},
    152661: {"Unified_Ideograph", "Ideographic"},
    152662: {"Unified_Ideograph", "Ideographic"},
    152663: {"Unified_Ideograph", "Ideographic"},
    152664: {"Unified_Ideograph", "Ideographic"},
    152665: {"Unified_Ideograph", "Ideographic"},
    152666: {"Unified_Ideograph", "Ideographic"},
    152667: {"Unified_Ideograph", "Ideographic"},
    152668: {"Unified_Ideograph", "Ideographic"},
    152669: {"Unified_Ideograph", "Ideographic"},
    152670: {"Unified_Ideograph", "Ideographic"},
    152671: {"Unified_Ideograph", "Ideographic"},
    152672: {"Unified_Ideograph", "Ideographic"},
    152673: {"Unified_Ideograph", "Ideographic"},
    152674: {"Unified_Ideograph", "Ideographic"},
    152675: {"Unified_Ideograph", "Ideographic"},
    152676: {"Unified_Ideograph", "Ideographic"},
    152677: {"Unified_Ideograph", "Ideographic"},
    152678: {"Unified_Ideograph", "Ideographic"},
    152679: {"Unified_Ideograph", "Ideographic"},
    152680: {"Unified_Ideograph", "Ideographic"},
    152681: {"Unified_Ideograph", "Ideographic"},
    152682: {"Unified_Ideograph", "Ideographic"},
    152683: {"Unified_Ideograph", "Ideographic"},
    152684: {"Unified_Ideograph", "Ideographic"},
    152685: {"Unified_Ideograph", "Ideographic"},
    152686: {"Unified_Ideograph", "Ideographic"},
    152687: {"Unified_Ideograph", "Ideographic"},
    152688: {"Unified_Ideograph", "Ideographic"},
    152689: {"Unified_Ideograph", "Ideographic"},
    152690: {"Unified_Ideograph", "Ideographic"},
    152691: {"Unified_Ideograph", "Ideographic"},
    152692: {"Unified_Ideograph", "Ideographic"},
    152693: {"Unified_Ideograph", "Ideographic"},
    152694: {"Unified_Ideograph", "Ideographic"},
    152695: {"Unified_Ideograph", "Ideographic"},
    152696: {"Unified_Ideograph", "Ideographic"},
    152697: {"Unified_Ideograph", "Ideographic"},
    152698: {"Unified_Ideograph", "Ideographic"},
    152699: {"Unified_Ideograph", "Ideographic"},
    152700: {"Unified_Ideograph", "Ideographic"},
    152701: {"Unified_Ideograph", "Ideographic"},
    152702: {"Unified_Ideograph", "Ideographic"},
    152703: {"Unified_Ideograph", "Ideographic"},
    152704: {"Unified_Ideograph", "Ideographic"},
    152705: {"Unified_Ideograph", "Ideographic"},
    152706: {"Unified_Ideograph", "Ideographic"},
    152707: {"Unified_Ideograph", "Ideographic"},
    152708: {"Unified_Ideograph", "Ideographic"},
    152709: {"Unified_Ideograph", "Ideographic"},
    152710: {"Unified_Ideograph", "Ideographic"},
    152711: {"Unified_Ideograph", "Ideographic"},
    152712: {"Unified_Ideograph", "Ideographic"},
    152713: {"Unified_Ideograph", "Ideographic"},
    152714: {"Unified_Ideograph", "Ideographic"},
    152715: {"Unified_Ideograph", "Ideographic"},
    152716: {"Unified_Ideograph", "Ideographic"},
    152717: {"Unified_Ideograph", "Ideographic"},
    152718: {"Unified_Ideograph", "Ideographic"},
    152719: {"Unified_Ideograph", "Ideographic"},
    152720: {"Unified_Ideograph", "Ideographic"},
    152721: {"Unified_Ideograph", "Ideographic"},
    152722: {"Unified_Ideograph", "Ideographic"},
    152723: {"Unified_Ideograph", "Ideographic"},
    152724: {"Unified_Ideograph", "Ideographic"},
    152725: {"Unified_Ideograph", "Ideographic"},
    152726: {"Unified_Ideograph", "Ideographic"},
    152727: {"Unified_Ideograph", "Ideographic"},
    152728: {"Unified_Ideograph", "Ideographic"},
    152729: {"Unified_Ideograph", "Ideographic"},
    152730: {"Unified_Ideograph", "Ideographic"},
    152731: {"Unified_Ideograph", "Ideographic"},
    152732: {"Unified_Ideograph", "Ideographic"},
    152733: {"Unified_Ideograph", "Ideographic"},
    152734: {"Unified_Ideograph", "Ideographic"},
    152735: {"Unified_Ideograph", "Ideographic"},
    152736: {"Unified_Ideograph", "Ideographic"},
    152737: {"Unified_Ideograph", "Ideographic"},
    152738: {"Unified_Ideograph", "Ideographic"},
    152739: {"Unified_Ideograph", "Ideographic"},
    152740: {"Unified_Ideograph", "Ideographic"},
    152741: {"Unified_Ideograph", "Ideographic"},
    152742: {"Unified_Ideograph", "Ideographic"},
    152743: {"Unified_Ideograph", "Ideographic"},
    152744: {"Unified_Ideograph", "Ideographic"},
    152745: {"Unified_Ideograph", "Ideographic"},
    152746: {"Unified_Ideograph", "Ideographic"},
    152747: {"Unified_Ideograph", "Ideographic"},
    152748: {"Unified_Ideograph", "Ideographic"},
    152749: {"Unified_Ideograph", "Ideographic"},
    152750: {"Unified_Ideograph", "Ideographic"},
    152751: {"Unified_Ideograph", "Ideographic"},
    152752: {"Unified_Ideograph", "Ideographic"},
    152753: {"Unified_Ideograph", "Ideographic"},
    152754: {"Unified_Ideograph", "Ideographic"},
    152755: {"Unified_Ideograph", "Ideographic"},
    152756: {"Unified_Ideograph", "Ideographic"},
    152757: {"Unified_Ideograph", "Ideographic"},
    152758: {"Unified_Ideograph", "Ideographic"},
    152759: {"Unified_Ideograph", "Ideographic"},
    152760: {"Unified_Ideograph", "Ideographic"},
    152761: {"Unified_Ideograph", "Ideographic"},
    152762: {"Unified_Ideograph", "Ideographic"},
    152763: {"Unified_Ideograph", "Ideographic"},
    152764: {"Unified_Ideograph", "Ideographic"},
    152765: {"Unified_Ideograph", "Ideographic"},
    152766: {"Unified_Ideograph", "Ideographic"},
    152767: {"Unified_Ideograph", "Ideographic"},
    152768: {"Unified_Ideograph", "Ideographic"},
    152769: {"Unified_Ideograph", "Ideographic"},
    152770: {"Unified_Ideograph", "Ideographic"},
    152771: {"Unified_Ideograph", "Ideographic"},
    152772: {"Unified_Ideograph", "Ideographic"},
    152773: {"Unified_Ideograph", "Ideographic"},
    152774: {"Unified_Ideograph", "Ideographic"},
    152775: {"Unified_Ideograph", "Ideographic"},
    152776: {"Unified_Ideograph", "Ideographic"},
    152777: {"Unified_Ideograph", "Ideographic"},
    152778: {"Unified_Ideograph", "Ideographic"},
    152779: {"Unified_Ideograph", "Ideographic"},
    152780: {"Unified_Ideograph", "Ideographic"},
    152781: {"Unified_Ideograph", "Ideographic"},
    152782: {"Unified_Ideograph", "Ideographic"},
    152783: {"Unified_Ideograph", "Ideographic"},
    152784: {"Unified_Ideograph", "Ideographic"},
    152785: {"Unified_Ideograph", "Ideographic"},
    152786: {"Unified_Ideograph", "Ideographic"},
    152787: {"Unified_Ideograph", "Ideographic"},
    152788: {"Unified_Ideograph", "Ideographic"},
    152789: {"Unified_Ideograph", "Ideographic"},
    152790: {"Unified_Ideograph", "Ideographic"},
    152791: {"Unified_Ideograph", "Ideographic"},
    152792: {"Unified_Ideograph", "Ideographic"},
    152793: {"Unified_Ideograph", "Ideographic"},
    152794: {"Unified_Ideograph", "Ideographic"},
    152795: {"Unified_Ideograph", "Ideographic"},
    152796: {"Unified_Ideograph", "Ideographic"},
    152797: {"Unified_Ideograph", "Ideographic"},
    152798: {"Unified_Ideograph", "Ideographic"},
    152799: {"Unified_Ideograph", "Ideographic"},
    152800: {"Unified_Ideograph", "Ideographic"},
    152801: {"Unified_Ideograph", "Ideographic"},
    152802: {"Unified_Ideograph", "Ideographic"},
    152803: {"Unified_Ideograph", "Ideographic"},
    152804: {"Unified_Ideograph", "Ideographic"},
    152805: {"Unified_Ideograph", "Ideographic"},
    152806: {"Unified_Ideograph", "Ideographic"},
    152807: {"Unified_Ideograph", "Ideographic"},
    152808: {"Unified_Ideograph", "Ideographic"},
    152809: {"Unified_Ideograph", "Ideographic"},
    152810: {"Unified_Ideograph", "Ideographic"},
    152811: {"Unified_Ideograph", "Ideographic"},
    152812: {"Unified_Ideograph", "Ideographic"},
    152813: {"Unified_Ideograph", "Ideographic"},
    152814: {"Unified_Ideograph", "Ideographic"},
    152815: {"Unified_Ideograph", "Ideographic"},
    152816: {"Unified_Ideograph", "Ideographic"},
    152817: {"Unified_Ideograph", "Ideographic"},
    152818: {"Unified_Ideograph", "Ideographic"},
    152819: {"Unified_Ideograph", "Ideographic"},
    152820: {"Unified_Ideograph", "Ideographic"},
    152821: {"Unified_Ideograph", "Ideographic"},
    152822: {"Unified_Ideograph", "Ideographic"},
    152823: {"Unified_Ideograph", "Ideographic"},
    152824: {"Unified_Ideograph", "Ideographic"},
    152825: {"Unified_Ideograph", "Ideographic"},
    152826: {"Unified_Ideograph", "Ideographic"},
    152827: {"Unified_Ideograph", "Ideographic"},
    152828: {"Unified_Ideograph", "Ideographic"},
    152829: {"Unified_Ideograph", "Ideographic"},
    152830: {"Unified_Ideograph", "Ideographic"},
    152831: {"Unified_Ideograph", "Ideographic"},
    152832: {"Unified_Ideograph", "Ideographic"},
    152833: {"Unified_Ideograph", "Ideographic"},
    152834: {"Unified_Ideograph", "Ideographic"},
    152835: {"Unified_Ideograph", "Ideographic"},
    152836: {"Unified_Ideograph", "Ideographic"},
    152837: {"Unified_Ideograph", "Ideographic"},
    152838: {"Unified_Ideograph", "Ideographic"},
    152839: {"Unified_Ideograph", "Ideographic"},
    152840: {"Unified_Ideograph", "Ideographic"},
    152841: {"Unified_Ideograph", "Ideographic"},
    152842: {"Unified_Ideograph", "Ideographic"},
    152843: {"Unified_Ideograph", "Ideographic"},
    152844: {"Unified_Ideograph", "Ideographic"},
    152845: {"Unified_Ideograph", "Ideographic"},
    152846: {"Unified_Ideograph", "Ideographic"},
    152847: {"Unified_Ideograph", "Ideographic"},
    152848: {"Unified_Ideograph", "Ideographic"},
    152849: {"Unified_Ideograph", "Ideographic"},
    152850: {"Unified_Ideograph", "Ideographic"},
    152851: {"Unified_Ideograph", "Ideographic"},
    152852: {"Unified_Ideograph", "Ideographic"},
    152853: {"Unified_Ideograph", "Ideographic"},
    152854: {"Unified_Ideograph", "Ideographic"},
    152855: {"Unified_Ideograph", "Ideographic"},
    152856: {"Unified_Ideograph", "Ideographic"},
    152857: {"Unified_Ideograph", "Ideographic"},
    152858: {"Unified_Ideograph", "Ideographic"},
    152859: {"Unified_Ideograph", "Ideographic"},
    152860: {"Unified_Ideograph", "Ideographic"},
    152861: {"Unified_Ideograph", "Ideographic"},
    152862: {"Unified_Ideograph", "Ideographic"},
    152863: {"Unified_Ideograph", "Ideographic"},
    152864: {"Unified_Ideograph", "Ideographic"},
    152865: {"Unified_Ideograph", "Ideographic"},
    152866: {"Unified_Ideograph", "Ideographic"},
    152867: {"Unified_Ideograph", "Ideographic"},
    152868: {"Unified_Ideograph", "Ideographic"},
    152869: {"Unified_Ideograph", "Ideographic"},
    152870: {"Unified_Ideograph", "Ideographic"},
    152871: {"Unified_Ideograph", "Ideographic"},
    152872: {"Unified_Ideograph", "Ideographic"},
    152873: {"Unified_Ideograph", "Ideographic"},
    152874: {"Unified_Ideograph", "Ideographic"},
    152875: {"Unified_Ideograph", "Ideographic"},
    152876: {"Unified_Ideograph", "Ideographic"},
    152877: {"Unified_Ideograph", "Ideographic"},
    152878: {"Unified_Ideograph", "Ideographic"},
    152879: {"Unified_Ideograph", "Ideographic"},
    152880: {"Unified_Ideograph", "Ideographic"},
    152881: {"Unified_Ideograph", "Ideographic"},
    152882: {"Unified_Ideograph", "Ideographic"},
    152883: {"Unified_Ideograph", "Ideographic"},
    152884: {"Unified_Ideograph", "Ideographic"},
    152885: {"Unified_Ideograph", "Ideographic"},
    152886: {"Unified_Ideograph", "Ideographic"},
    152887: {"Unified_Ideograph", "Ideographic"},
    152888: {"Unified_Ideograph", "Ideographic"},
    152889: {"Unified_Ideograph", "Ideographic"},
    152890: {"Unified_Ideograph", "Ideographic"},
    152891: {"Unified_Ideograph", "Ideographic"},
    152892: {"Unified_Ideograph", "Ideographic"},
    152893: {"Unified_Ideograph", "Ideographic"},
    152894: {"Unified_Ideograph", "Ideographic"},
    152895: {"Unified_Ideograph", "Ideographic"},
    152896: {"Unified_Ideograph", "Ideographic"},
    152897: {"Unified_Ideograph", "Ideographic"},
    152898: {"Unified_Ideograph", "Ideographic"},
    152899: {"Unified_Ideograph", "Ideographic"},
    152900: {"Unified_Ideograph", "Ideographic"},
    152901: {"Unified_Ideograph", "Ideographic"},
    152902: {"Unified_Ideograph", "Ideographic"},
    152903: {"Unified_Ideograph", "Ideographic"},
    152904: {"Unified_Ideograph", "Ideographic"},
    152905: {"Unified_Ideograph", "Ideographic"},
    152906: {"Unified_Ideograph", "Ideographic"},
    152907: {"Unified_Ideograph", "Ideographic"},
    152908: {"Unified_Ideograph", "Ideographic"},
    152909: {"Unified_Ideograph", "Ideographic"},
    152910: {"Unified_Ideograph", "Ideographic"},
    152911: {"Unified_Ideograph", "Ideographic"},
    152912: {"Unified_Ideograph", "Ideographic"},
    152913: {"Unified_Ideograph", "Ideographic"},
    152914: {"Unified_Ideograph", "Ideographic"},
    152915: {"Unified_Ideograph", "Ideographic"},
    152916: {"Unified_Ideograph", "Ideographic"},
    152917: {"Unified_Ideograph", "Ideographic"},
    152918: {"Unified_Ideograph", "Ideographic"},
    152919: {"Unified_Ideograph", "Ideographic"},
    152920: {"Unified_Ideograph", "Ideographic"},
    152921: {"Unified_Ideograph", "Ideographic"},
    152922: {"Unified_Ideograph", "Ideographic"},
    152923: {"Unified_Ideograph", "Ideographic"},
    152924: {"Unified_Ideograph", "Ideographic"},
    152925: {"Unified_Ideograph", "Ideographic"},
    152926: {"Unified_Ideograph", "Ideographic"},
    152927: {"Unified_Ideograph", "Ideographic"},
    152928: {"Unified_Ideograph", "Ideographic"},
    152929: {"Unified_Ideograph", "Ideographic"},
    152930: {"Unified_Ideograph", "Ideographic"},
    152931: {"Unified_Ideograph", "Ideographic"},
    152932: {"Unified_Ideograph", "Ideographic"},
    152933: {"Unified_Ideograph", "Ideographic"},
    152934: {"Unified_Ideograph", "Ideographic"},
    152935: {"Unified_Ideograph", "Ideographic"},
    152936: {"Unified_Ideograph", "Ideographic"},
    152937: {"Unified_Ideograph", "Ideographic"},
    152938: {"Unified_Ideograph", "Ideographic"},
    152939: {"Unified_Ideograph", "Ideographic"},
    152940: {"Unified_Ideograph", "Ideographic"},
    152941: {"Unified_Ideograph", "Ideographic"},
    152942: {"Unified_Ideograph", "Ideographic"},
    152943: {"Unified_Ideograph", "Ideographic"},
    152944: {"Unified_Ideograph", "Ideographic"},
    152945: {"Unified_Ideograph", "Ideographic"},
    152946: {"Unified_Ideograph", "Ideographic"},
    152947: {"Unified_Ideograph", "Ideographic"},
    152948: {"Unified_Ideograph", "Ideographic"},
    152949: {"Unified_Ideograph", "Ideographic"},
    152950: {"Unified_Ideograph", "Ideographic"},
    152951: {"Unified_Ideograph", "Ideographic"},
    152952: {"Unified_Ideograph", "Ideographic"},
    152953: {"Unified_Ideograph", "Ideographic"},
    152954: {"Unified_Ideograph", "Ideographic"},
    152955: {"Unified_Ideograph", "Ideographic"},
    152956: {"Unified_Ideograph", "Ideographic"},
    152957: {"Unified_Ideograph", "Ideographic"},
    152958: {"Unified_Ideograph", "Ideographic"},
    152959: {"Unified_Ideograph", "Ideographic"},
    152960: {"Unified_Ideograph", "Ideographic"},
    152961: {"Unified_Ideograph", "Ideographic"},
    152962: {"Unified_Ideograph", "Ideographic"},
    152963: {"Unified_Ideograph", "Ideographic"},
    152964: {"Unified_Ideograph", "Ideographic"},
    152965: {"Unified_Ideograph", "Ideographic"},
    152966: {"Unified_Ideograph", "Ideographic"},
    152967: {"Unified_Ideograph", "Ideographic"},
    152968: {"Unified_Ideograph", "Ideographic"},
    152969: {"Unified_Ideograph", "Ideographic"},
    152970: {"Unified_Ideograph", "Ideographic"},
    152971: {"Unified_Ideograph", "Ideographic"},
    152972: {"Unified_Ideograph", "Ideographic"},
    152973: {"Unified_Ideograph", "Ideographic"},
    152974: {"Unified_Ideograph", "Ideographic"},
    152975: {"Unified_Ideograph", "Ideographic"},
    152976: {"Unified_Ideograph", "Ideographic"},
    152977: {"Unified_Ideograph", "Ideographic"},
    152978: {"Unified_Ideograph", "Ideographic"},
    152979: {"Unified_Ideograph", "Ideographic"},
    152980: {"Unified_Ideograph", "Ideographic"},
    152981: {"Unified_Ideograph", "Ideographic"},
    152982: {"Unified_Ideograph", "Ideographic"},
    152983: {"Unified_Ideograph", "Ideographic"},
    152984: {"Unified_Ideograph", "Ideographic"},
    152985: {"Unified_Ideograph", "Ideographic"},
    152986: {"Unified_Ideograph", "Ideographic"},
    152987: {"Unified_Ideograph", "Ideographic"},
    152988: {"Unified_Ideograph", "Ideographic"},
    152989: {"Unified_Ideograph", "Ideographic"},
    152990: {"Unified_Ideograph", "Ideographic"},
    152991: {"Unified_Ideograph", "Ideographic"},
    152992: {"Unified_Ideograph", "Ideographic"},
    152993: {"Unified_Ideograph", "Ideographic"},
    152994: {"Unified_Ideograph", "Ideographic"},
    152995: {"Unified_Ideograph", "Ideographic"},
    152996: {"Unified_Ideograph", "Ideographic"},
    152997: {"Unified_Ideograph", "Ideographic"},
    152998: {"Unified_Ideograph", "Ideographic"},
    152999: {"Unified_Ideograph", "Ideographic"},
    153000: {"Unified_Ideograph", "Ideographic"},
    153001: {"Unified_Ideograph", "Ideographic"},
    153002: {"Unified_Ideograph", "Ideographic"},
    153003: {"Unified_Ideograph", "Ideographic"},
    153004: {"Unified_Ideograph", "Ideographic"},
    153005: {"Unified_Ideograph", "Ideographic"},
    153006: {"Unified_Ideograph", "Ideographic"},
    153007: {"Unified_Ideograph", "Ideographic"},
    153008: {"Unified_Ideograph", "Ideographic"},
    153009: {"Unified_Ideograph", "Ideographic"},
    153010: {"Unified_Ideograph", "Ideographic"},
    153011: {"Unified_Ideograph", "Ideographic"},
    153012: {"Unified_Ideograph", "Ideographic"},
    153013: {"Unified_Ideograph", "Ideographic"},
    153014: {"Unified_Ideograph", "Ideographic"},
    153015: {"Unified_Ideograph", "Ideographic"},
    153016: {"Unified_Ideograph", "Ideographic"},
    153017: {"Unified_Ideograph", "Ideographic"},
    153018: {"Unified_Ideograph", "Ideographic"},
    153019: {"Unified_Ideograph", "Ideographic"},
    153020: {"Unified_Ideograph", "Ideographic"},
    153021: {"Unified_Ideograph", "Ideographic"},
    153022: {"Unified_Ideograph", "Ideographic"},
    153023: {"Unified_Ideograph", "Ideographic"},
    153024: {"Unified_Ideograph", "Ideographic"},
    153025: {"Unified_Ideograph", "Ideographic"},
    153026: {"Unified_Ideograph", "Ideographic"},
    153027: {"Unified_Ideograph", "Ideographic"},
    153028: {"Unified_Ideograph", "Ideographic"},
    153029: {"Unified_Ideograph", "Ideographic"},
    153030: {"Unified_Ideograph", "Ideographic"},
    153031: {"Unified_Ideograph", "Ideographic"},
    153032: {"Unified_Ideograph", "Ideographic"},
    153033: {"Unified_Ideograph", "Ideographic"},
    153034: {"Unified_Ideograph", "Ideographic"},
    153035: {"Unified_Ideograph", "Ideographic"},
    153036: {"Unified_Ideograph", "Ideographic"},
    153037: {"Unified_Ideograph", "Ideographic"},
    153038: {"Unified_Ideograph", "Ideographic"},
    153039: {"Unified_Ideograph", "Ideographic"},
    153040: {"Unified_Ideograph", "Ideographic"},
    153041: {"Unified_Ideograph", "Ideographic"},
    153042: {"Unified_Ideograph", "Ideographic"},
    153043: {"Unified_Ideograph", "Ideographic"},
    153044: {"Unified_Ideograph", "Ideographic"},
    153045: {"Unified_Ideograph", "Ideographic"},
    153046: {"Unified_Ideograph", "Ideographic"},
    153047: {"Unified_Ideograph", "Ideographic"},
    153048: {"Unified_Ideograph", "Ideographic"},
    153049: {"Unified_Ideograph", "Ideographic"},
    153050: {"Unified_Ideograph", "Ideographic"},
    153051: {"Unified_Ideograph", "Ideographic"},
    153052: {"Unified_Ideograph", "Ideographic"},
    153053: {"Unified_Ideograph", "Ideographic"},
    153054: {"Unified_Ideograph", "Ideographic"},
    153055: {"Unified_Ideograph", "Ideographic"},
    153056: {"Unified_Ideograph", "Ideographic"},
    153057: {"Unified_Ideograph", "Ideographic"},
    153058: {"Unified_Ideograph", "Ideographic"},
    153059: {"Unified_Ideograph", "Ideographic"},
    153060: {"Unified_Ideograph", "Ideographic"},
    153061: {"Unified_Ideograph", "Ideographic"},
    153062: {"Unified_Ideograph", "Ideographic"},
    153063: {"Unified_Ideograph", "Ideographic"},
    153064: {"Unified_Ideograph", "Ideographic"},
    153065: {"Unified_Ideograph", "Ideographic"},
    153066: {"Unified_Ideograph", "Ideographic"},
    153067: {"Unified_Ideograph", "Ideographic"},
    153068: {"Unified_Ideograph", "Ideographic"},
    153069: {"Unified_Ideograph", "Ideographic"},
    153070: {"Unified_Ideograph", "Ideographic"},
    153071: {"Unified_Ideograph", "Ideographic"},
    153072: {"Unified_Ideograph", "Ideographic"},
    153073: {"Unified_Ideograph", "Ideographic"},
    153074: {"Unified_Ideograph", "Ideographic"},
    153075: {"Unified_Ideograph", "Ideographic"},
    153076: {"Unified_Ideograph", "Ideographic"},
    153077: {"Unified_Ideograph", "Ideographic"},
    153078: {"Unified_Ideograph", "Ideographic"},
    153079: {"Unified_Ideograph", "Ideographic"},
    153080: {"Unified_Ideograph", "Ideographic"},
    153081: {"Unified_Ideograph", "Ideographic"},
    153082: {"Unified_Ideograph", "Ideographic"},
    153083: {"Unified_Ideograph", "Ideographic"},
    153084: {"Unified_Ideograph", "Ideographic"},
    153085: {"Unified_Ideograph", "Ideographic"},
    153086: {"Unified_Ideograph", "Ideographic"},
    153087: {"Unified_Ideograph", "Ideographic"},
    153088: {"Unified_Ideograph", "Ideographic"},
    153089: {"Unified_Ideograph", "Ideographic"},
    153090: {"Unified_Ideograph", "Ideographic"},
    153091: {"Unified_Ideograph", "Ideographic"},
    153092: {"Unified_Ideograph", "Ideographic"},
    153093: {"Unified_Ideograph", "Ideographic"},
    153094: {"Unified_Ideograph", "Ideographic"},
    153095: {"Unified_Ideograph", "Ideographic"},
    153096: {"Unified_Ideograph", "Ideographic"},
    153097: {"Unified_Ideograph", "Ideographic"},
    153098: {"Unified_Ideograph", "Ideographic"},
    153099: {"Unified_Ideograph", "Ideographic"},
    153100: {"Unified_Ideograph", "Ideographic"},
    153101: {"Unified_Ideograph", "Ideographic"},
    153102: {"Unified_Ideograph", "Ideographic"},
    153103: {"Unified_Ideograph", "Ideographic"},
    153104: {"Unified_Ideograph", "Ideographic"},
    153105: {"Unified_Ideograph", "Ideographic"},
    153106: {"Unified_Ideograph", "Ideographic"},
    153107: {"Unified_Ideograph", "Ideographic"},
    153108: {"Unified_Ideograph", "Ideographic"},
    153109: {"Unified_Ideograph", "Ideographic"},
    153110: {"Unified_Ideograph", "Ideographic"},
    153111: {"Unified_Ideograph", "Ideographic"},
    153112: {"Unified_Ideograph", "Ideographic"},
    153113: {"Unified_Ideograph", "Ideographic"},
    153114: {"Unified_Ideograph", "Ideographic"},
    153115: {"Unified_Ideograph", "Ideographic"},
    153116: {"Unified_Ideograph", "Ideographic"},
    153117: {"Unified_Ideograph", "Ideographic"},
    153118: {"Unified_Ideograph", "Ideographic"},
    153119: {"Unified_Ideograph", "Ideographic"},
    153120: {"Unified_Ideograph", "Ideographic"},
    153121: {"Unified_Ideograph", "Ideographic"},
    153122: {"Unified_Ideograph", "Ideographic"},
    153123: {"Unified_Ideograph", "Ideographic"},
    153124: {"Unified_Ideograph", "Ideographic"},
    153125: {"Unified_Ideograph", "Ideographic"},
    153126: {"Unified_Ideograph", "Ideographic"},
    153127: {"Unified_Ideograph", "Ideographic"},
    153128: {"Unified_Ideograph", "Ideographic"},
    153129: {"Unified_Ideograph", "Ideographic"},
    153130: {"Unified_Ideograph", "Ideographic"},
    153131: {"Unified_Ideograph", "Ideographic"},
    153132: {"Unified_Ideograph", "Ideographic"},
    153133: {"Unified_Ideograph", "Ideographic"},
    153134: {"Unified_Ideograph", "Ideographic"},
    153135: {"Unified_Ideograph", "Ideographic"},
    153136: {"Unified_Ideograph", "Ideographic"},
    153137: {"Unified_Ideograph", "Ideographic"},
    153138: {"Unified_Ideograph", "Ideographic"},
    153139: {"Unified_Ideograph", "Ideographic"},
    153140: {"Unified_Ideograph", "Ideographic"},
    153141: {"Unified_Ideograph", "Ideographic"},
    153142: {"Unified_Ideograph", "Ideographic"},
    153143: {"Unified_Ideograph", "Ideographic"},
    153144: {"Unified_Ideograph", "Ideographic"},
    153145: {"Unified_Ideograph", "Ideographic"},
    153146: {"Unified_Ideograph", "Ideographic"},
    153147: {"Unified_Ideograph", "Ideographic"},
    153148: {"Unified_Ideograph", "Ideographic"},
    153149: {"Unified_Ideograph", "Ideographic"},
    153150: {"Unified_Ideograph", "Ideographic"},
    153151: {"Unified_Ideograph", "Ideographic"},
    153152: {"Unified_Ideograph", "Ideographic"},
    153153: {"Unified_Ideograph", "Ideographic"},
    153154: {"Unified_Ideograph", "Ideographic"},
    153155: {"Unified_Ideograph", "Ideographic"},
    153156: {"Unified_Ideograph", "Ideographic"},
    153157: {"Unified_Ideograph", "Ideographic"},
    153158: {"Unified_Ideograph", "Ideographic"},
    153159: {"Unified_Ideograph", "Ideographic"},
    153160: {"Unified_Ideograph", "Ideographic"},
    153161: {"Unified_Ideograph", "Ideographic"},
    153162: {"Unified_Ideograph", "Ideographic"},
    153163: {"Unified_Ideograph", "Ideographic"},
    153164: {"Unified_Ideograph", "Ideographic"},
    153165: {"Unified_Ideograph", "Ideographic"},
    153166: {"Unified_Ideograph", "Ideographic"},
    153167: {"Unified_Ideograph", "Ideographic"},
    153168: {"Unified_Ideograph", "Ideographic"},
    153169: {"Unified_Ideograph", "Ideographic"},
    153170: {"Unified_Ideograph", "Ideographic"},
    153171: {"Unified_Ideograph", "Ideographic"},
    153172: {"Unified_Ideograph", "Ideographic"},
    153173: {"Unified_Ideograph", "Ideographic"},
    153174: {"Unified_Ideograph", "Ideographic"},
    153175: {"Unified_Ideograph", "Ideographic"},
    153176: {"Unified_Ideograph", "Ideographic"},
    153177: {"Unified_Ideograph", "Ideographic"},
    153178: {"Unified_Ideograph", "Ideographic"},
    153179: {"Unified_Ideograph", "Ideographic"},
    153180: {"Unified_Ideograph", "Ideographic"},
    153181: {"Unified_Ideograph", "Ideographic"},
    153182: {"Unified_Ideograph", "Ideographic"},
    153183: {"Unified_Ideograph", "Ideographic"},
    153184: {"Unified_Ideograph", "Ideographic"},
    153185: {"Unified_Ideograph", "Ideographic"},
    153186: {"Unified_Ideograph", "Ideographic"},
    153187: {"Unified_Ideograph", "Ideographic"},
    153188: {"Unified_Ideograph", "Ideographic"},
    153189: {"Unified_Ideograph", "Ideographic"},
    153190: {"Unified_Ideograph", "Ideographic"},
    153191: {"Unified_Ideograph", "Ideographic"},
    153192: {"Unified_Ideograph", "Ideographic"},
    153193: {"Unified_Ideograph", "Ideographic"},
    153194: {"Unified_Ideograph", "Ideographic"},
    153195: {"Unified_Ideograph", "Ideographic"},
    153196: {"Unified_Ideograph", "Ideographic"},
    153197: {"Unified_Ideograph", "Ideographic"},
    153198: {"Unified_Ideograph", "Ideographic"},
    153199: {"Unified_Ideograph", "Ideographic"},
    153200: {"Unified_Ideograph", "Ideographic"},
    153201: {"Unified_Ideograph", "Ideographic"},
    153202: {"Unified_Ideograph", "Ideographic"},
    153203: {"Unified_Ideograph", "Ideographic"},
    153204: {"Unified_Ideograph", "Ideographic"},
    153205: {"Unified_Ideograph", "Ideographic"},
    153206: {"Unified_Ideograph", "Ideographic"},
    153207: {"Unified_Ideograph", "Ideographic"},
    153208: {"Unified_Ideograph", "Ideographic"},
    153209: {"Unified_Ideograph", "Ideographic"},
    153210: {"Unified_Ideograph", "Ideographic"},
    153211: {"Unified_Ideograph", "Ideographic"},
    153212: {"Unified_Ideograph", "Ideographic"},
    153213: {"Unified_Ideograph", "Ideographic"},
    153214: {"Unified_Ideograph", "Ideographic"},
    153215: {"Unified_Ideograph", "Ideographic"},
    153216: {"Unified_Ideograph", "Ideographic"},
    153217: {"Unified_Ideograph", "Ideographic"},
    153218: {"Unified_Ideograph", "Ideographic"},
    153219: {"Unified_Ideograph", "Ideographic"},
    153220: {"Unified_Ideograph", "Ideographic"},
    153221: {"Unified_Ideograph", "Ideographic"},
    153222: {"Unified_Ideograph", "Ideographic"},
    153223: {"Unified_Ideograph", "Ideographic"},
    153224: {"Unified_Ideograph", "Ideographic"},
    153225: {"Unified_Ideograph", "Ideographic"},
    153226: {"Unified_Ideograph", "Ideographic"},
    153227: {"Unified_Ideograph", "Ideographic"},
    153228: {"Unified_Ideograph", "Ideographic"},
    153229: {"Unified_Ideograph", "Ideographic"},
    153230: {"Unified_Ideograph", "Ideographic"},
    153231: {"Unified_Ideograph", "Ideographic"},
    153232: {"Unified_Ideograph", "Ideographic"},
    153233: {"Unified_Ideograph", "Ideographic"},
    153234: {"Unified_Ideograph", "Ideographic"},
    153235: {"Unified_Ideograph", "Ideographic"},
    153236: {"Unified_Ideograph", "Ideographic"},
    153237: {"Unified_Ideograph", "Ideographic"},
    153238: {"Unified_Ideograph", "Ideographic"},
    153239: {"Unified_Ideograph", "Ideographic"},
    153240: {"Unified_Ideograph", "Ideographic"},
    153241: {"Unified_Ideograph", "Ideographic"},
    153242: {"Unified_Ideograph", "Ideographic"},
    153243: {"Unified_Ideograph", "Ideographic"},
    153244: {"Unified_Ideograph", "Ideographic"},
    153245: {"Unified_Ideograph", "Ideographic"},
    153246: {"Unified_Ideograph", "Ideographic"},
    153247: {"Unified_Ideograph", "Ideographic"},
    153248: {"Unified_Ideograph", "Ideographic"},
    153249: {"Unified_Ideograph", "Ideographic"},
    153250: {"Unified_Ideograph", "Ideographic"},
    153251: {"Unified_Ideograph", "Ideographic"},
    153252: {"Unified_Ideograph", "Ideographic"},
    153253: {"Unified_Ideograph", "Ideographic"},
    153254: {"Unified_Ideograph", "Ideographic"},
    153255: {"Unified_Ideograph", "Ideographic"},
    153256: {"Unified_Ideograph", "Ideographic"},
    153257: {"Unified_Ideograph", "Ideographic"},
    153258: {"Unified_Ideograph", "Ideographic"},
    153259: {"Unified_Ideograph", "Ideographic"},
    153260: {"Unified_Ideograph", "Ideographic"},
    153261: {"Unified_Ideograph", "Ideographic"},
    153262: {"Unified_Ideograph", "Ideographic"},
    153263: {"Unified_Ideograph", "Ideographic"},
    153264: {"Unified_Ideograph", "Ideographic"},
    153265: {"Unified_Ideograph", "Ideographic"},
    153266: {"Unified_Ideograph", "Ideographic"},
    153267: {"Unified_Ideograph", "Ideographic"},
    153268: {"Unified_Ideograph", "Ideographic"},
    153269: {"Unified_Ideograph", "Ideographic"},
    153270: {"Unified_Ideograph", "Ideographic"},
    153271: {"Unified_Ideograph", "Ideographic"},
    153272: {"Unified_Ideograph", "Ideographic"},
    153273: {"Unified_Ideograph", "Ideographic"},
    153274: {"Unified_Ideograph", "Ideographic"},
    153275: {"Unified_Ideograph", "Ideographic"},
    153276: {"Unified_Ideograph", "Ideographic"},
    153277: {"Unified_Ideograph", "Ideographic"},
    153278: {"Unified_Ideograph", "Ideographic"},
    153279: {"Unified_Ideograph", "Ideographic"},
    153280: {"Unified_Ideograph", "Ideographic"},
    153281: {"Unified_Ideograph", "Ideographic"},
    153282: {"Unified_Ideograph", "Ideographic"},
    153283: {"Unified_Ideograph", "Ideographic"},
    153284: {"Unified_Ideograph", "Ideographic"},
    153285: {"Unified_Ideograph", "Ideographic"},
    153286: {"Unified_Ideograph", "Ideographic"},
    153287: {"Unified_Ideograph", "Ideographic"},
    153288: {"Unified_Ideograph", "Ideographic"},
    153289: {"Unified_Ideograph", "Ideographic"},
    153290: {"Unified_Ideograph", "Ideographic"},
    153291: {"Unified_Ideograph", "Ideographic"},
    153292: {"Unified_Ideograph", "Ideographic"},
    153293: {"Unified_Ideograph", "Ideographic"},
    153294: {"Unified_Ideograph", "Ideographic"},
    153295: {"Unified_Ideograph", "Ideographic"},
    153296: {"Unified_Ideograph", "Ideographic"},
    153297: {"Unified_Ideograph", "Ideographic"},
    153298: {"Unified_Ideograph", "Ideographic"},
    153299: {"Unified_Ideograph", "Ideographic"},
    153300: {"Unified_Ideograph", "Ideographic"},
    153301: {"Unified_Ideograph", "Ideographic"},
    153302: {"Unified_Ideograph", "Ideographic"},
    153303: {"Unified_Ideograph", "Ideographic"},
    153304: {"Unified_Ideograph", "Ideographic"},
    153305: {"Unified_Ideograph", "Ideographic"},
    153306: {"Unified_Ideograph", "Ideographic"},
    153307: {"Unified_Ideograph", "Ideographic"},
    153308: {"Unified_Ideograph", "Ideographic"},
    153309: {"Unified_Ideograph", "Ideographic"},
    153310: {"Unified_Ideograph", "Ideographic"},
    153311: {"Unified_Ideograph", "Ideographic"},
    153312: {"Unified_Ideograph", "Ideographic"},
    153313: {"Unified_Ideograph", "Ideographic"},
    153314: {"Unified_Ideograph", "Ideographic"},
    153315: {"Unified_Ideograph", "Ideographic"},
    153316: {"Unified_Ideograph", "Ideographic"},
    153317: {"Unified_Ideograph", "Ideographic"},
    153318: {"Unified_Ideograph", "Ideographic"},
    153319: {"Unified_Ideograph", "Ideographic"},
    153320: {"Unified_Ideograph", "Ideographic"},
    153321: {"Unified_Ideograph", "Ideographic"},
    153322: {"Unified_Ideograph", "Ideographic"},
    153323: {"Unified_Ideograph", "Ideographic"},
    153324: {"Unified_Ideograph", "Ideographic"},
    153325: {"Unified_Ideograph", "Ideographic"},
    153326: {"Unified_Ideograph", "Ideographic"},
    153327: {"Unified_Ideograph", "Ideographic"},
    153328: {"Unified_Ideograph", "Ideographic"},
    153329: {"Unified_Ideograph", "Ideographic"},
    153330: {"Unified_Ideograph", "Ideographic"},
    153331: {"Unified_Ideograph", "Ideographic"},
    153332: {"Unified_Ideograph", "Ideographic"},
    153333: {"Unified_Ideograph", "Ideographic"},
    153334: {"Unified_Ideograph", "Ideographic"},
    153335: {"Unified_Ideograph", "Ideographic"},
    153336: {"Unified_Ideograph", "Ideographic"},
    153337: {"Unified_Ideograph", "Ideographic"},
    153338: {"Unified_Ideograph", "Ideographic"},
    153339: {"Unified_Ideograph", "Ideographic"},
    153340: {"Unified_Ideograph", "Ideographic"},
    153341: {"Unified_Ideograph", "Ideographic"},
    153342: {"Unified_Ideograph", "Ideographic"},
    153343: {"Unified_Ideograph", "Ideographic"},
    153344: {"Unified_Ideograph", "Ideographic"},
    153345: {"Unified_Ideograph", "Ideographic"},
    153346: {"Unified_Ideograph", "Ideographic"},
    153347: {"Unified_Ideograph", "Ideographic"},
    153348: {"Unified_Ideograph", "Ideographic"},
    153349: {"Unified_Ideograph", "Ideographic"},
    153350: {"Unified_Ideograph", "Ideographic"},
    153351: {"Unified_Ideograph", "Ideographic"},
    153352: {"Unified_Ideograph", "Ideographic"},
    153353: {"Unified_Ideograph", "Ideographic"},
    153354: {"Unified_Ideograph", "Ideographic"},
    153355: {"Unified_Ideograph", "Ideographic"},
    153356: {"Unified_Ideograph", "Ideographic"},
    153357: {"Unified_Ideograph", "Ideographic"},
    153358: {"Unified_Ideograph", "Ideographic"},
    153359: {"Unified_Ideograph", "Ideographic"},
    153360: {"Unified_Ideograph", "Ideographic"},
    153361: {"Unified_Ideograph", "Ideographic"},
    153362: {"Unified_Ideograph", "Ideographic"},
    153363: {"Unified_Ideograph", "Ideographic"},
    153364: {"Unified_Ideograph", "Ideographic"},
    153365: {"Unified_Ideograph", "Ideographic"},
    153366: {"Unified_Ideograph", "Ideographic"},
    153367: {"Unified_Ideograph", "Ideographic"},
    153368: {"Unified_Ideograph", "Ideographic"},
    153369: {"Unified_Ideograph", "Ideographic"},
    153370: {"Unified_Ideograph", "Ideographic"},
    153371: {"Unified_Ideograph", "Ideographic"},
    153372: {"Unified_Ideograph", "Ideographic"},
    153373: {"Unified_Ideograph", "Ideographic"},
    153374: {"Unified_Ideograph", "Ideographic"},
    153375: {"Unified_Ideograph", "Ideographic"},
    153376: {"Unified_Ideograph", "Ideographic"},
    153377: {"Unified_Ideograph", "Ideographic"},
    153378: {"Unified_Ideograph", "Ideographic"},
    153379: {"Unified_Ideograph", "Ideographic"},
    153380: {"Unified_Ideograph", "Ideographic"},
    153381: {"Unified_Ideograph", "Ideographic"},
    153382: {"Unified_Ideograph", "Ideographic"},
    153383: {"Unified_Ideograph", "Ideographic"},
    153384: {"Unified_Ideograph", "Ideographic"},
    153385: {"Unified_Ideograph", "Ideographic"},
    153386: {"Unified_Ideograph", "Ideographic"},
    153387: {"Unified_Ideograph", "Ideographic"},
    153388: {"Unified_Ideograph", "Ideographic"},
    153389: {"Unified_Ideograph", "Ideographic"},
    153390: {"Unified_Ideograph", "Ideographic"},
    153391: {"Unified_Ideograph", "Ideographic"},
    153392: {"Unified_Ideograph", "Ideographic"},
    153393: {"Unified_Ideograph", "Ideographic"},
    153394: {"Unified_Ideograph", "Ideographic"},
    153395: {"Unified_Ideograph", "Ideographic"},
    153396: {"Unified_Ideograph", "Ideographic"},
    153397: {"Unified_Ideograph", "Ideographic"},
    153398: {"Unified_Ideograph", "Ideographic"},
    153399: {"Unified_Ideograph", "Ideographic"},
    153400: {"Unified_Ideograph", "Ideographic"},
    153401: {"Unified_Ideograph", "Ideographic"},
    153402: {"Unified_Ideograph", "Ideographic"},
    153403: {"Unified_Ideograph", "Ideographic"},
    153404: {"Unified_Ideograph", "Ideographic"},
    153405: {"Unified_Ideograph", "Ideographic"},
    153406: {"Unified_Ideograph", "Ideographic"},
    153407: {"Unified_Ideograph", "Ideographic"},
    153408: {"Unified_Ideograph", "Ideographic"},
    153409: {"Unified_Ideograph", "Ideographic"},
    153410: {"Unified_Ideograph", "Ideographic"},
    153411: {"Unified_Ideograph", "Ideographic"},
    153412: {"Unified_Ideograph", "Ideographic"},
    153413: {"Unified_Ideograph", "Ideographic"},
    153414: {"Unified_Ideograph", "Ideographic"},
    153415: {"Unified_Ideograph", "Ideographic"},
    153416: {"Unified_Ideograph", "Ideographic"},
    153417: {"Unified_Ideograph", "Ideographic"},
    153418: {"Unified_Ideograph", "Ideographic"},
    153419: {"Unified_Ideograph", "Ideographic"},
    153420: {"Unified_Ideograph", "Ideographic"},
    153421: {"Unified_Ideograph", "Ideographic"},
    153422: {"Unified_Ideograph", "Ideographic"},
    153423: {"Unified_Ideograph", "Ideographic"},
    153424: {"Unified_Ideograph", "Ideographic"},
    153425: {"Unified_Ideograph", "Ideographic"},
    153426: {"Unified_Ideograph", "Ideographic"},
    153427: {"Unified_Ideograph", "Ideographic"},
    153428: {"Unified_Ideograph", "Ideographic"},
    153429: {"Unified_Ideograph", "Ideographic"},
    153430: {"Unified_Ideograph", "Ideographic"},
    153431: {"Unified_Ideograph", "Ideographic"},
    153432: {"Unified_Ideograph", "Ideographic"},
    153433: {"Unified_Ideograph", "Ideographic"},
    153434: {"Unified_Ideograph", "Ideographic"},
    153435: {"Unified_Ideograph", "Ideographic"},
    153436: {"Unified_Ideograph", "Ideographic"},
    153437: {"Unified_Ideograph", "Ideographic"},
    153438: {"Unified_Ideograph", "Ideographic"},
    153439: {"Unified_Ideograph", "Ideographic"},
    153440: {"Unified_Ideograph", "Ideographic"},
    153441: {"Unified_Ideograph", "Ideographic"},
    153442: {"Unified_Ideograph", "Ideographic"},
    153443: {"Unified_Ideograph", "Ideographic"},
    153444: {"Unified_Ideograph", "Ideographic"},
    153445: {"Unified_Ideograph", "Ideographic"},
    153446: {"Unified_Ideograph", "Ideographic"},
    153447: {"Unified_Ideograph", "Ideographic"},
    153448: {"Unified_Ideograph", "Ideographic"},
    153449: {"Unified_Ideograph", "Ideographic"},
    153450: {"Unified_Ideograph", "Ideographic"},
    153451: {"Unified_Ideograph", "Ideographic"},
    153452: {"Unified_Ideograph", "Ideographic"},
    153453: {"Unified_Ideograph", "Ideographic"},
    153454: {"Unified_Ideograph", "Ideographic"},
    153455: {"Unified_Ideograph", "Ideographic"},
    153456: {"Unified_Ideograph", "Ideographic"},
    153457: {"Unified_Ideograph", "Ideographic"},
    153458: {"Unified_Ideograph", "Ideographic"},
    153459: {"Unified_Ideograph", "Ideographic"},
    153460: {"Unified_Ideograph", "Ideographic"},
    153461: {"Unified_Ideograph", "Ideographic"},
    153462: {"Unified_Ideograph", "Ideographic"},
    153463: {"Unified_Ideograph", "Ideographic"},
    153464: {"Unified_Ideograph", "Ideographic"},
    153465: {"Unified_Ideograph", "Ideographic"},
    153466: {"Unified_Ideograph", "Ideographic"},
    153467: {"Unified_Ideograph", "Ideographic"},
    153468: {"Unified_Ideograph", "Ideographic"},
    153469: {"Unified_Ideograph", "Ideographic"},
    153470: {"Unified_Ideograph", "Ideographic"},
    153471: {"Unified_Ideograph", "Ideographic"},
    153472: {"Unified_Ideograph", "Ideographic"},
    153473: {"Unified_Ideograph", "Ideographic"},
    153474: {"Unified_Ideograph", "Ideographic"},
    153475: {"Unified_Ideograph", "Ideographic"},
    153476: {"Unified_Ideograph", "Ideographic"},
    153477: {"Unified_Ideograph", "Ideographic"},
    153478: {"Unified_Ideograph", "Ideographic"},
    153479: {"Unified_Ideograph", "Ideographic"},
    153480: {"Unified_Ideograph", "Ideographic"},
    153481: {"Unified_Ideograph", "Ideographic"},
    153482: {"Unified_Ideograph", "Ideographic"},
    153483: {"Unified_Ideograph", "Ideographic"},
    153484: {"Unified_Ideograph", "Ideographic"},
    153485: {"Unified_Ideograph", "Ideographic"},
    153486: {"Unified_Ideograph", "Ideographic"},
    153487: {"Unified_Ideograph", "Ideographic"},
    153488: {"Unified_Ideograph", "Ideographic"},
    153489: {"Unified_Ideograph", "Ideographic"},
    153490: {"Unified_Ideograph", "Ideographic"},
    153491: {"Unified_Ideograph", "Ideographic"},
    153492: {"Unified_Ideograph", "Ideographic"},
    153493: {"Unified_Ideograph", "Ideographic"},
    153494: {"Unified_Ideograph", "Ideographic"},
    153495: {"Unified_Ideograph", "Ideographic"},
    153496: {"Unified_Ideograph", "Ideographic"},
    153497: {"Unified_Ideograph", "Ideographic"},
    153498: {"Unified_Ideograph", "Ideographic"},
    153499: {"Unified_Ideograph", "Ideographic"},
    153500: {"Unified_Ideograph", "Ideographic"},
    153501: {"Unified_Ideograph", "Ideographic"},
    153502: {"Unified_Ideograph", "Ideographic"},
    153503: {"Unified_Ideograph", "Ideographic"},
    153504: {"Unified_Ideograph", "Ideographic"},
    153505: {"Unified_Ideograph", "Ideographic"},
    153506: {"Unified_Ideograph", "Ideographic"},
    153507: {"Unified_Ideograph", "Ideographic"},
    153508: {"Unified_Ideograph", "Ideographic"},
    153509: {"Unified_Ideograph", "Ideographic"},
    153510: {"Unified_Ideograph", "Ideographic"},
    153511: {"Unified_Ideograph", "Ideographic"},
    153512: {"Unified_Ideograph", "Ideographic"},
    153513: {"Unified_Ideograph", "Ideographic"},
    153514: {"Unified_Ideograph", "Ideographic"},
    153515: {"Unified_Ideograph", "Ideographic"},
    153516: {"Unified_Ideograph", "Ideographic"},
    153517: {"Unified_Ideograph", "Ideographic"},
    153518: {"Unified_Ideograph", "Ideographic"},
    153519: {"Unified_Ideograph", "Ideographic"},
    153520: {"Unified_Ideograph", "Ideographic"},
    153521: {"Unified_Ideograph", "Ideographic"},
    153522: {"Unified_Ideograph", "Ideographic"},
    153523: {"Unified_Ideograph", "Ideographic"},
    153524: {"Unified_Ideograph", "Ideographic"},
    153525: {"Unified_Ideograph", "Ideographic"},
    153526: {"Unified_Ideograph", "Ideographic"},
    153527: {"Unified_Ideograph", "Ideographic"},
    153528: {"Unified_Ideograph", "Ideographic"},
    153529: {"Unified_Ideograph", "Ideographic"},
    153530: {"Unified_Ideograph", "Ideographic"},
    153531: {"Unified_Ideograph", "Ideographic"},
    153532: {"Unified_Ideograph", "Ideographic"},
    153533: {"Unified_Ideograph", "Ideographic"},
    153534: {"Unified_Ideograph", "Ideographic"},
    153535: {"Unified_Ideograph", "Ideographic"},
    153536: {"Unified_Ideograph", "Ideographic"},
    153537: {"Unified_Ideograph", "Ideographic"},
    153538: {"Unified_Ideograph", "Ideographic"},
    153539: {"Unified_Ideograph", "Ideographic"},
    153540: {"Unified_Ideograph", "Ideographic"},
    153541: {"Unified_Ideograph", "Ideographic"},
    153542: {"Unified_Ideograph", "Ideographic"},
    153543: {"Unified_Ideograph", "Ideographic"},
    153544: {"Unified_Ideograph", "Ideographic"},
    153545: {"Unified_Ideograph", "Ideographic"},
    153546: {"Unified_Ideograph", "Ideographic"},
    153547: {"Unified_Ideograph", "Ideographic"},
    153548: {"Unified_Ideograph", "Ideographic"},
    153549: {"Unified_Ideograph", "Ideographic"},
    153550: {"Unified_Ideograph", "Ideographic"},
    153551: {"Unified_Ideograph", "Ideographic"},
    153552: {"Unified_Ideograph", "Ideographic"},
    153553: {"Unified_Ideograph", "Ideographic"},
    153554: {"Unified_Ideograph", "Ideographic"},
    153555: {"Unified_Ideograph", "Ideographic"},
    153556: {"Unified_Ideograph", "Ideographic"},
    153557: {"Unified_Ideograph", "Ideographic"},
    153558: {"Unified_Ideograph", "Ideographic"},
    153559: {"Unified_Ideograph", "Ideographic"},
    153560: {"Unified_Ideograph", "Ideographic"},
    153561: {"Unified_Ideograph", "Ideographic"},
    153562: {"Unified_Ideograph", "Ideographic"},
    153563: {"Unified_Ideograph", "Ideographic"},
    153564: {"Unified_Ideograph", "Ideographic"},
    153565: {"Unified_Ideograph", "Ideographic"},
    153566: {"Unified_Ideograph", "Ideographic"},
    153567: {"Unified_Ideograph", "Ideographic"},
    153568: {"Unified_Ideograph", "Ideographic"},
    153569: {"Unified_Ideograph", "Ideographic"},
    153570: {"Unified_Ideograph", "Ideographic"},
    153571: {"Unified_Ideograph", "Ideographic"},
    153572: {"Unified_Ideograph", "Ideographic"},
    153573: {"Unified_Ideograph", "Ideographic"},
    153574: {"Unified_Ideograph", "Ideographic"},
    153575: {"Unified_Ideograph", "Ideographic"},
    153576: {"Unified_Ideograph", "Ideographic"},
    153577: {"Unified_Ideograph", "Ideographic"},
    153578: {"Unified_Ideograph", "Ideographic"},
    153579: {"Unified_Ideograph", "Ideographic"},
    153580: {"Unified_Ideograph", "Ideographic"},
    153581: {"Unified_Ideograph", "Ideographic"},
    153582: {"Unified_Ideograph", "Ideographic"},
    153583: {"Unified_Ideograph", "Ideographic"},
    153584: {"Unified_Ideograph", "Ideographic"},
    153585: {"Unified_Ideograph", "Ideographic"},
    153586: {"Unified_Ideograph", "Ideographic"},
    153587: {"Unified_Ideograph", "Ideographic"},
    153588: {"Unified_Ideograph", "Ideographic"},
    153589: {"Unified_Ideograph", "Ideographic"},
    153590: {"Unified_Ideograph", "Ideographic"},
    153591: {"Unified_Ideograph", "Ideographic"},
    153592: {"Unified_Ideograph", "Ideographic"},
    153593: {"Unified_Ideograph", "Ideographic"},
    153594: {"Unified_Ideograph", "Ideographic"},
    153595: {"Unified_Ideograph", "Ideographic"},
    153596: {"Unified_Ideograph", "Ideographic"},
    153597: {"Unified_Ideograph", "Ideographic"},
    153598: {"Unified_Ideograph", "Ideographic"},
    153599: {"Unified_Ideograph", "Ideographic"},
    153600: {"Unified_Ideograph", "Ideographic"},
    153601: {"Unified_Ideograph", "Ideographic"},
    153602: {"Unified_Ideograph", "Ideographic"},
    153603: {"Unified_Ideograph", "Ideographic"},
    153604: {"Unified_Ideograph", "Ideographic"},
    153605: {"Unified_Ideograph", "Ideographic"},
    153606: {"Unified_Ideograph", "Ideographic"},
    153607: {"Unified_Ideograph", "Ideographic"},
    153608: {"Unified_Ideograph", "Ideographic"},
    153609: {"Unified_Ideograph", "Ideographic"},
    153610: {"Unified_Ideograph", "Ideographic"},
    153611: {"Unified_Ideograph", "Ideographic"},
    153612: {"Unified_Ideograph", "Ideographic"},
    153613: {"Unified_Ideograph", "Ideographic"},
    153614: {"Unified_Ideograph", "Ideographic"},
    153615: {"Unified_Ideograph", "Ideographic"},
    153616: {"Unified_Ideograph", "Ideographic"},
    153617: {"Unified_Ideograph", "Ideographic"},
    153618: {"Unified_Ideograph", "Ideographic"},
    153619: {"Unified_Ideograph", "Ideographic"},
    153620: {"Unified_Ideograph", "Ideographic"},
    153621: {"Unified_Ideograph", "Ideographic"},
    153622: {"Unified_Ideograph", "Ideographic"},
    153623: {"Unified_Ideograph", "Ideographic"},
    153624: {"Unified_Ideograph", "Ideographic"},
    153625: {"Unified_Ideograph", "Ideographic"},
    153626: {"Unified_Ideograph", "Ideographic"},
    153627: {"Unified_Ideograph", "Ideographic"},
    153628: {"Unified_Ideograph", "Ideographic"},
    153629: {"Unified_Ideograph", "Ideographic"},
    153630: {"Unified_Ideograph", "Ideographic"},
    153631: {"Unified_Ideograph", "Ideographic"},
    153632: {"Unified_Ideograph", "Ideographic"},
    153633: {"Unified_Ideograph", "Ideographic"},
    153634: {"Unified_Ideograph", "Ideographic"},
    153635: {"Unified_Ideograph", "Ideographic"},
    153636: {"Unified_Ideograph", "Ideographic"},
    153637: {"Unified_Ideograph", "Ideographic"},
    153638: {"Unified_Ideograph", "Ideographic"},
    153639: {"Unified_Ideograph", "Ideographic"},
    153640: {"Unified_Ideograph", "Ideographic"},
    153641: {"Unified_Ideograph", "Ideographic"},
    153642: {"Unified_Ideograph", "Ideographic"},
    153643: {"Unified_Ideograph", "Ideographic"},
    153644: {"Unified_Ideograph", "Ideographic"},
    153645: {"Unified_Ideograph", "Ideographic"},
    153646: {"Unified_Ideograph", "Ideographic"},
    153647: {"Unified_Ideograph", "Ideographic"},
    153648: {"Unified_Ideograph", "Ideographic"},
    153649: {"Unified_Ideograph", "Ideographic"},
    153650: {"Unified_Ideograph", "Ideographic"},
    153651: {"Unified_Ideograph", "Ideographic"},
    153652: {"Unified_Ideograph", "Ideographic"},
    153653: {"Unified_Ideograph", "Ideographic"},
    153654: {"Unified_Ideograph", "Ideographic"},
    153655: {"Unified_Ideograph", "Ideographic"},
    153656: {"Unified_Ideograph", "Ideographic"},
    153657: {"Unified_Ideograph", "Ideographic"},
    153658: {"Unified_Ideograph", "Ideographic"},
    153659: {"Unified_Ideograph", "Ideographic"},
    153660: {"Unified_Ideograph", "Ideographic"},
    153661: {"Unified_Ideograph", "Ideographic"},
    153662: {"Unified_Ideograph", "Ideographic"},
    153663: {"Unified_Ideograph", "Ideographic"},
    153664: {"Unified_Ideograph", "Ideographic"},
    153665: {"Unified_Ideograph", "Ideographic"},
    153666: {"Unified_Ideograph", "Ideographic"},
    153667: {"Unified_Ideograph", "Ideographic"},
    153668: {"Unified_Ideograph", "Ideographic"},
    153669: {"Unified_Ideograph", "Ideographic"},
    153670: {"Unified_Ideograph", "Ideographic"},
    153671: {"Unified_Ideograph", "Ideographic"},
    153672: {"Unified_Ideograph", "Ideographic"},
    153673: {"Unified_Ideograph", "Ideographic"},
    153674: {"Unified_Ideograph", "Ideographic"},
    153675: {"Unified_Ideograph", "Ideographic"},
    153676: {"Unified_Ideograph", "Ideographic"},
    153677: {"Unified_Ideograph", "Ideographic"},
    153678: {"Unified_Ideograph", "Ideographic"},
    153679: {"Unified_Ideograph", "Ideographic"},
    153680: {"Unified_Ideograph", "Ideographic"},
    153681: {"Unified_Ideograph", "Ideographic"},
    153682: {"Unified_Ideograph", "Ideographic"},
    153683: {"Unified_Ideograph", "Ideographic"},
    153684: {"Unified_Ideograph", "Ideographic"},
    153685: {"Unified_Ideograph", "Ideographic"},
    153686: {"Unified_Ideograph", "Ideographic"},
    153687: {"Unified_Ideograph", "Ideographic"},
    153688: {"Unified_Ideograph", "Ideographic"},
    153689: {"Unified_Ideograph", "Ideographic"},
    153690: {"Unified_Ideograph", "Ideographic"},
    153691: {"Unified_Ideograph", "Ideographic"},
    153692: {"Unified_Ideograph", "Ideographic"},
    153693: {"Unified_Ideograph", "Ideographic"},
    153694: {"Unified_Ideograph", "Ideographic"},
    153695: {"Unified_Ideograph", "Ideographic"},
    153696: {"Unified_Ideograph", "Ideographic"},
    153697: {"Unified_Ideograph", "Ideographic"},
    153698: {"Unified_Ideograph", "Ideographic"},
    153699: {"Unified_Ideograph", "Ideographic"},
    153700: {"Unified_Ideograph", "Ideographic"},
    153701: {"Unified_Ideograph", "Ideographic"},
    153702: {"Unified_Ideograph", "Ideographic"},
    153703: {"Unified_Ideograph", "Ideographic"},
    153704: {"Unified_Ideograph", "Ideographic"},
    153705: {"Unified_Ideograph", "Ideographic"},
    153706: {"Unified_Ideograph", "Ideographic"},
    153707: {"Unified_Ideograph", "Ideographic"},
    153708: {"Unified_Ideograph", "Ideographic"},
    153709: {"Unified_Ideograph", "Ideographic"},
    153710: {"Unified_Ideograph", "Ideographic"},
    153711: {"Unified_Ideograph", "Ideographic"},
    153712: {"Unified_Ideograph", "Ideographic"},
    153713: {"Unified_Ideograph", "Ideographic"},
    153714: {"Unified_Ideograph", "Ideographic"},
    153715: {"Unified_Ideograph", "Ideographic"},
    153716: {"Unified_Ideograph", "Ideographic"},
    153717: {"Unified_Ideograph", "Ideographic"},
    153718: {"Unified_Ideograph", "Ideographic"},
    153719: {"Unified_Ideograph", "Ideographic"},
    153720: {"Unified_Ideograph", "Ideographic"},
    153721: {"Unified_Ideograph", "Ideographic"},
    153722: {"Unified_Ideograph", "Ideographic"},
    153723: {"Unified_Ideograph", "Ideographic"},
    153724: {"Unified_Ideograph", "Ideographic"},
    153725: {"Unified_Ideograph", "Ideographic"},
    153726: {"Unified_Ideograph", "Ideographic"},
    153727: {"Unified_Ideograph", "Ideographic"},
    153728: {"Unified_Ideograph", "Ideographic"},
    153729: {"Unified_Ideograph", "Ideographic"},
    153730: {"Unified_Ideograph", "Ideographic"},
    153731: {"Unified_Ideograph", "Ideographic"},
    153732: {"Unified_Ideograph", "Ideographic"},
    153733: {"Unified_Ideograph", "Ideographic"},
    153734: {"Unified_Ideograph", "Ideographic"},
    153735: {"Unified_Ideograph", "Ideographic"},
    153736: {"Unified_Ideograph", "Ideographic"},
    153737: {"Unified_Ideograph", "Ideographic"},
    153738: {"Unified_Ideograph", "Ideographic"},
    153739: {"Unified_Ideograph", "Ideographic"},
    153740: {"Unified_Ideograph", "Ideographic"},
    153741: {"Unified_Ideograph", "Ideographic"},
    153742: {"Unified_Ideograph", "Ideographic"},
    153743: {"Unified_Ideograph", "Ideographic"},
    153744: {"Unified_Ideograph", "Ideographic"},
    153745: {"Unified_Ideograph", "Ideographic"},
    153746: {"Unified_Ideograph", "Ideographic"},
    153747: {"Unified_Ideograph", "Ideographic"},
    153748: {"Unified_Ideograph", "Ideographic"},
    153749: {"Unified_Ideograph", "Ideographic"},
    153750: {"Unified_Ideograph", "Ideographic"},
    153751: {"Unified_Ideograph", "Ideographic"},
    153752: {"Unified_Ideograph", "Ideographic"},
    153753: {"Unified_Ideograph", "Ideographic"},
    153754: {"Unified_Ideograph", "Ideographic"},
    153755: {"Unified_Ideograph", "Ideographic"},
    153756: {"Unified_Ideograph", "Ideographic"},
    153757: {"Unified_Ideograph", "Ideographic"},
    153758: {"Unified_Ideograph", "Ideographic"},
    153759: {"Unified_Ideograph", "Ideographic"},
    153760: {"Unified_Ideograph", "Ideographic"},
    153761: {"Unified_Ideograph", "Ideographic"},
    153762: {"Unified_Ideograph", "Ideographic"},
    153763: {"Unified_Ideograph", "Ideographic"},
    153764: {"Unified_Ideograph", "Ideographic"},
    153765: {"Unified_Ideograph", "Ideographic"},
    153766: {"Unified_Ideograph", "Ideographic"},
    153767: {"Unified_Ideograph", "Ideographic"},
    153768: {"Unified_Ideograph", "Ideographic"},
    153769: {"Unified_Ideograph", "Ideographic"},
    153770: {"Unified_Ideograph", "Ideographic"},
    153771: {"Unified_Ideograph", "Ideographic"},
    153772: {"Unified_Ideograph", "Ideographic"},
    153773: {"Unified_Ideograph", "Ideographic"},
    153774: {"Unified_Ideograph", "Ideographic"},
    153775: {"Unified_Ideograph", "Ideographic"},
    153776: {"Unified_Ideograph", "Ideographic"},
    153777: {"Unified_Ideograph", "Ideographic"},
    153778: {"Unified_Ideograph", "Ideographic"},
    153779: {"Unified_Ideograph", "Ideographic"},
    153780: {"Unified_Ideograph", "Ideographic"},
    153781: {"Unified_Ideograph", "Ideographic"},
    153782: {"Unified_Ideograph", "Ideographic"},
    153783: {"Unified_Ideograph", "Ideographic"},
    153784: {"Unified_Ideograph", "Ideographic"},
    153785: {"Unified_Ideograph", "Ideographic"},
    153786: {"Unified_Ideograph", "Ideographic"},
    153787: {"Unified_Ideograph", "Ideographic"},
    153788: {"Unified_Ideograph", "Ideographic"},
    153789: {"Unified_Ideograph", "Ideographic"},
    153790: {"Unified_Ideograph", "Ideographic"},
    153791: {"Unified_Ideograph", "Ideographic"},
    153792: {"Unified_Ideograph", "Ideographic"},
    153793: {"Unified_Ideograph", "Ideographic"},
    153794: {"Unified_Ideograph", "Ideographic"},
    153795: {"Unified_Ideograph", "Ideographic"},
    153796: {"Unified_Ideograph", "Ideographic"},
    153797: {"Unified_Ideograph", "Ideographic"},
    153798: {"Unified_Ideograph", "Ideographic"},
    153799: {"Unified_Ideograph", "Ideographic"},
    153800: {"Unified_Ideograph", "Ideographic"},
    153801: {"Unified_Ideograph", "Ideographic"},
    153802: {"Unified_Ideograph", "Ideographic"},
    153803: {"Unified_Ideograph", "Ideographic"},
    153804: {"Unified_Ideograph", "Ideographic"},
    153805: {"Unified_Ideograph", "Ideographic"},
    153806: {"Unified_Ideograph", "Ideographic"},
    153807: {"Unified_Ideograph", "Ideographic"},
    153808: {"Unified_Ideograph", "Ideographic"},
    153809: {"Unified_Ideograph", "Ideographic"},
    153810: {"Unified_Ideograph", "Ideographic"},
    153811: {"Unified_Ideograph", "Ideographic"},
    153812: {"Unified_Ideograph", "Ideographic"},
    153813: {"Unified_Ideograph", "Ideographic"},
    153814: {"Unified_Ideograph", "Ideographic"},
    153815: {"Unified_Ideograph", "Ideographic"},
    153816: {"Unified_Ideograph", "Ideographic"},
    153817: {"Unified_Ideograph", "Ideographic"},
    153818: {"Unified_Ideograph", "Ideographic"},
    153819: {"Unified_Ideograph", "Ideographic"},
    153820: {"Unified_Ideograph", "Ideographic"},
    153821: {"Unified_Ideograph", "Ideographic"},
    153822: {"Unified_Ideograph", "Ideographic"},
    153823: {"Unified_Ideograph", "Ideographic"},
    153824: {"Unified_Ideograph", "Ideographic"},
    153825: {"Unified_Ideograph", "Ideographic"},
    153826: {"Unified_Ideograph", "Ideographic"},
    153827: {"Unified_Ideograph", "Ideographic"},
    153828: {"Unified_Ideograph", "Ideographic"},
    153829: {"Unified_Ideograph", "Ideographic"},
    153830: {"Unified_Ideograph", "Ideographic"},
    153831: {"Unified_Ideograph", "Ideographic"},
    153832: {"Unified_Ideograph", "Ideographic"},
    153833: {"Unified_Ideograph", "Ideographic"},
    153834: {"Unified_Ideograph", "Ideographic"},
    153835: {"Unified_Ideograph", "Ideographic"},
    153836: {"Unified_Ideograph", "Ideographic"},
    153837: {"Unified_Ideograph", "Ideographic"},
    153838: {"Unified_Ideograph", "Ideographic"},
    153839: {"Unified_Ideograph", "Ideographic"},
    153840: {"Unified_Ideograph", "Ideographic"},
    153841: {"Unified_Ideograph", "Ideographic"},
    153842: {"Unified_Ideograph", "Ideographic"},
    153843: {"Unified_Ideograph", "Ideographic"},
    153844: {"Unified_Ideograph", "Ideographic"},
    153845: {"Unified_Ideograph", "Ideographic"},
    153846: {"Unified_Ideograph", "Ideographic"},
    153847: {"Unified_Ideograph", "Ideographic"},
    153848: {"Unified_Ideograph", "Ideographic"},
    153849: {"Unified_Ideograph", "Ideographic"},
    153850: {"Unified_Ideograph", "Ideographic"},
    153851: {"Unified_Ideograph", "Ideographic"},
    153852: {"Unified_Ideograph", "Ideographic"},
    153853: {"Unified_Ideograph", "Ideographic"},
    153854: {"Unified_Ideograph", "Ideographic"},
    153855: {"Unified_Ideograph", "Ideographic"},
    153856: {"Unified_Ideograph", "Ideographic"},
    153857: {"Unified_Ideograph", "Ideographic"},
    153858: {"Unified_Ideograph", "Ideographic"},
    153859: {"Unified_Ideograph", "Ideographic"},
    153860: {"Unified_Ideograph", "Ideographic"},
    153861: {"Unified_Ideograph", "Ideographic"},
    153862: {"Unified_Ideograph", "Ideographic"},
    153863: {"Unified_Ideograph", "Ideographic"},
    153864: {"Unified_Ideograph", "Ideographic"},
    153865: {"Unified_Ideograph", "Ideographic"},
    153866: {"Unified_Ideograph", "Ideographic"},
    153867: {"Unified_Ideograph", "Ideographic"},
    153868: {"Unified_Ideograph", "Ideographic"},
    153869: {"Unified_Ideograph", "Ideographic"},
    153870: {"Unified_Ideograph", "Ideographic"},
    153871: {"Unified_Ideograph", "Ideographic"},
    153872: {"Unified_Ideograph", "Ideographic"},
    153873: {"Unified_Ideograph", "Ideographic"},
    153874: {"Unified_Ideograph", "Ideographic"},
    153875: {"Unified_Ideograph", "Ideographic"},
    153876: {"Unified_Ideograph", "Ideographic"},
    153877: {"Unified_Ideograph", "Ideographic"},
    153878: {"Unified_Ideograph", "Ideographic"},
    153879: {"Unified_Ideograph", "Ideographic"},
    153880: {"Unified_Ideograph", "Ideographic"},
    153881: {"Unified_Ideograph", "Ideographic"},
    153882: {"Unified_Ideograph", "Ideographic"},
    153883: {"Unified_Ideograph", "Ideographic"},
    153884: {"Unified_Ideograph", "Ideographic"},
    153885: {"Unified_Ideograph", "Ideographic"},
    153886: {"Unified_Ideograph", "Ideographic"},
    153887: {"Unified_Ideograph", "Ideographic"},
    153888: {"Unified_Ideograph", "Ideographic"},
    153889: {"Unified_Ideograph", "Ideographic"},
    153890: {"Unified_Ideograph", "Ideographic"},
    153891: {"Unified_Ideograph", "Ideographic"},
    153892: {"Unified_Ideograph", "Ideographic"},
    153893: {"Unified_Ideograph", "Ideographic"},
    153894: {"Unified_Ideograph", "Ideographic"},
    153895: {"Unified_Ideograph", "Ideographic"},
    153896: {"Unified_Ideograph", "Ideographic"},
    153897: {"Unified_Ideograph", "Ideographic"},
    153898: {"Unified_Ideograph", "Ideographic"},
    153899: {"Unified_Ideograph", "Ideographic"},
    153900: {"Unified_Ideograph", "Ideographic"},
    153901: {"Unified_Ideograph", "Ideographic"},
    153902: {"Unified_Ideograph", "Ideographic"},
    153903: {"Unified_Ideograph", "Ideographic"},
    153904: {"Unified_Ideograph", "Ideographic"},
    153905: {"Unified_Ideograph", "Ideographic"},
    153906: {"Unified_Ideograph", "Ideographic"},
    153907: {"Unified_Ideograph", "Ideographic"},
    153908: {"Unified_Ideograph", "Ideographic"},
    153909: {"Unified_Ideograph", "Ideographic"},
    153910: {"Unified_Ideograph", "Ideographic"},
    153911: {"Unified_Ideograph", "Ideographic"},
    153912: {"Unified_Ideograph", "Ideographic"},
    153913: {"Unified_Ideograph", "Ideographic"},
    153914: {"Unified_Ideograph", "Ideographic"},
    153915: {"Unified_Ideograph", "Ideographic"},
    153916: {"Unified_Ideograph", "Ideographic"},
    153917: {"Unified_Ideograph", "Ideographic"},
    153918: {"Unified_Ideograph", "Ideographic"},
    153919: {"Unified_Ideograph", "Ideographic"},
    153920: {"Unified_Ideograph", "Ideographic"},
    153921: {"Unified_Ideograph", "Ideographic"},
    153922: {"Unified_Ideograph", "Ideographic"},
    153923: {"Unified_Ideograph", "Ideographic"},
    153924: {"Unified_Ideograph", "Ideographic"},
    153925: {"Unified_Ideograph", "Ideographic"},
    153926: {"Unified_Ideograph", "Ideographic"},
    153927: {"Unified_Ideograph", "Ideographic"},
    153928: {"Unified_Ideograph", "Ideographic"},
    153929: {"Unified_Ideograph", "Ideographic"},
    153930: {"Unified_Ideograph", "Ideographic"},
    153931: {"Unified_Ideograph", "Ideographic"},
    153932: {"Unified_Ideograph", "Ideographic"},
    153933: {"Unified_Ideograph", "Ideographic"},
    153934: {"Unified_Ideograph", "Ideographic"},
    153935: {"Unified_Ideograph", "Ideographic"},
    153936: {"Unified_Ideograph", "Ideographic"},
    153937: {"Unified_Ideograph", "Ideographic"},
    153938: {"Unified_Ideograph", "Ideographic"},
    153939: {"Unified_Ideograph", "Ideographic"},
    153940: {"Unified_Ideograph", "Ideographic"},
    153941: {"Unified_Ideograph", "Ideographic"},
    153942: {"Unified_Ideograph", "Ideographic"},
    153943: {"Unified_Ideograph", "Ideographic"},
    153944: {"Unified_Ideograph", "Ideographic"},
    153945: {"Unified_Ideograph", "Ideographic"},
    153946: {"Unified_Ideograph", "Ideographic"},
    153947: {"Unified_Ideograph", "Ideographic"},
    153948: {"Unified_Ideograph", "Ideographic"},
    153949: {"Unified_Ideograph", "Ideographic"},
    153950: {"Unified_Ideograph", "Ideographic"},
    153951: {"Unified_Ideograph", "Ideographic"},
    153952: {"Unified_Ideograph", "Ideographic"},
    153953: {"Unified_Ideograph", "Ideographic"},
    153954: {"Unified_Ideograph", "Ideographic"},
    153955: {"Unified_Ideograph", "Ideographic"},
    153956: {"Unified_Ideograph", "Ideographic"},
    153957: {"Unified_Ideograph", "Ideographic"},
    153958: {"Unified_Ideograph", "Ideographic"},
    153959: {"Unified_Ideograph", "Ideographic"},
    153960: {"Unified_Ideograph", "Ideographic"},
    153961: {"Unified_Ideograph", "Ideographic"},
    153962: {"Unified_Ideograph", "Ideographic"},
    153963: {"Unified_Ideograph", "Ideographic"},
    153964: {"Unified_Ideograph", "Ideographic"},
    153965: {"Unified_Ideograph", "Ideographic"},
    153966: {"Unified_Ideograph", "Ideographic"},
    153967: {"Unified_Ideograph", "Ideographic"},
    153968: {"Unified_Ideograph", "Ideographic"},
    153969: {"Unified_Ideograph", "Ideographic"},
    153970: {"Unified_Ideograph", "Ideographic"},
    153971: {"Unified_Ideograph", "Ideographic"},
    153972: {"Unified_Ideograph", "Ideographic"},
    153973: {"Unified_Ideograph", "Ideographic"},
    153974: {"Unified_Ideograph", "Ideographic"},
    153975: {"Unified_Ideograph", "Ideographic"},
    153976: {"Unified_Ideograph", "Ideographic"},
    153977: {"Unified_Ideograph", "Ideographic"},
    153978: {"Unified_Ideograph", "Ideographic"},
    153979: {"Unified_Ideograph", "Ideographic"},
    153980: {"Unified_Ideograph", "Ideographic"},
    153981: {"Unified_Ideograph", "Ideographic"},
    153982: {"Unified_Ideograph", "Ideographic"},
    153983: {"Unified_Ideograph", "Ideographic"},
    153984: {"Unified_Ideograph", "Ideographic"},
    153985: {"Unified_Ideograph", "Ideographic"},
    153986: {"Unified_Ideograph", "Ideographic"},
    153987: {"Unified_Ideograph", "Ideographic"},
    153988: {"Unified_Ideograph", "Ideographic"},
    153989: {"Unified_Ideograph", "Ideographic"},
    153990: {"Unified_Ideograph", "Ideographic"},
    153991: {"Unified_Ideograph", "Ideographic"},
    153992: {"Unified_Ideograph", "Ideographic"},
    153993: {"Unified_Ideograph", "Ideographic"},
    153994: {"Unified_Ideograph", "Ideographic"},
    153995: {"Unified_Ideograph", "Ideographic"},
    153996: {"Unified_Ideograph", "Ideographic"},
    153997: {"Unified_Ideograph", "Ideographic"},
    153998: {"Unified_Ideograph", "Ideographic"},
    153999: {"Unified_Ideograph", "Ideographic"},
    154000: {"Unified_Ideograph", "Ideographic"},
    154001: {"Unified_Ideograph", "Ideographic"},
    154002: {"Unified_Ideograph", "Ideographic"},
    154003: {"Unified_Ideograph", "Ideographic"},
    154004: {"Unified_Ideograph", "Ideographic"},
    154005: {"Unified_Ideograph", "Ideographic"},
    154006: {"Unified_Ideograph", "Ideographic"},
    154007: {"Unified_Ideograph", "Ideographic"},
    154008: {"Unified_Ideograph", "Ideographic"},
    154009: {"Unified_Ideograph", "Ideographic"},
    154010: {"Unified_Ideograph", "Ideographic"},
    154011: {"Unified_Ideograph", "Ideographic"},
    154012: {"Unified_Ideograph", "Ideographic"},
    154013: {"Unified_Ideograph", "Ideographic"},
    154014: {"Unified_Ideograph", "Ideographic"},
    154015: {"Unified_Ideograph", "Ideographic"},
    154016: {"Unified_Ideograph", "Ideographic"},
    154017: {"Unified_Ideograph", "Ideographic"},
    154018: {"Unified_Ideograph", "Ideographic"},
    154019: {"Unified_Ideograph", "Ideographic"},
    154020: {"Unified_Ideograph", "Ideographic"},
    154021: {"Unified_Ideograph", "Ideographic"},
    154022: {"Unified_Ideograph", "Ideographic"},
    154023: {"Unified_Ideograph", "Ideographic"},
    154024: {"Unified_Ideograph", "Ideographic"},
    154025: {"Unified_Ideograph", "Ideographic"},
    154026: {"Unified_Ideograph", "Ideographic"},
    154027: {"Unified_Ideograph", "Ideographic"},
    154028: {"Unified_Ideograph", "Ideographic"},
    154029: {"Unified_Ideograph", "Ideographic"},
    154030: {"Unified_Ideograph", "Ideographic"},
    154031: {"Unified_Ideograph", "Ideographic"},
    154032: {"Unified_Ideograph", "Ideographic"},
    154033: {"Unified_Ideograph", "Ideographic"},
    154034: {"Unified_Ideograph", "Ideographic"},
    154035: {"Unified_Ideograph", "Ideographic"},
    154036: {"Unified_Ideograph", "Ideographic"},
    154037: {"Unified_Ideograph", "Ideographic"},
    154038: {"Unified_Ideograph", "Ideographic"},
    154039: {"Unified_Ideograph", "Ideographic"},
    154040: {"Unified_Ideograph", "Ideographic"},
    154041: {"Unified_Ideograph", "Ideographic"},
    154042: {"Unified_Ideograph", "Ideographic"},
    154043: {"Unified_Ideograph", "Ideographic"},
    154044: {"Unified_Ideograph", "Ideographic"},
    154045: {"Unified_Ideograph", "Ideographic"},
    154046: {"Unified_Ideograph", "Ideographic"},
    154047: {"Unified_Ideograph", "Ideographic"},
    154048: {"Unified_Ideograph", "Ideographic"},
    154049: {"Unified_Ideograph", "Ideographic"},
    154050: {"Unified_Ideograph", "Ideographic"},
    154051: {"Unified_Ideograph", "Ideographic"},
    154052: {"Unified_Ideograph", "Ideographic"},
    154053: {"Unified_Ideograph", "Ideographic"},
    154054: {"Unified_Ideograph", "Ideographic"},
    154055: {"Unified_Ideograph", "Ideographic"},
    154056: {"Unified_Ideograph", "Ideographic"},
    154057: {"Unified_Ideograph", "Ideographic"},
    154058: {"Unified_Ideograph", "Ideographic"},
    154059: {"Unified_Ideograph", "Ideographic"},
    154060: {"Unified_Ideograph", "Ideographic"},
    154061: {"Unified_Ideograph", "Ideographic"},
    154062: {"Unified_Ideograph", "Ideographic"},
    154063: {"Unified_Ideograph", "Ideographic"},
    154064: {"Unified_Ideograph", "Ideographic"},
    154065: {"Unified_Ideograph", "Ideographic"},
    154066: {"Unified_Ideograph", "Ideographic"},
    154067: {"Unified_Ideograph", "Ideographic"},
    154068: {"Unified_Ideograph", "Ideographic"},
    154069: {"Unified_Ideograph", "Ideographic"},
    154070: {"Unified_Ideograph", "Ideographic"},
    154071: {"Unified_Ideograph", "Ideographic"},
    154072: {"Unified_Ideograph", "Ideographic"},
    154073: {"Unified_Ideograph", "Ideographic"},
    154074: {"Unified_Ideograph", "Ideographic"},
    154075: {"Unified_Ideograph", "Ideographic"},
    154076: {"Unified_Ideograph", "Ideographic"},
    154077: {"Unified_Ideograph", "Ideographic"},
    154078: {"Unified_Ideograph", "Ideographic"},
    154079: {"Unified_Ideograph", "Ideographic"},
    154080: {"Unified_Ideograph", "Ideographic"},
    154081: {"Unified_Ideograph", "Ideographic"},
    154082: {"Unified_Ideograph", "Ideographic"},
    154083: {"Unified_Ideograph", "Ideographic"},
    154084: {"Unified_Ideograph", "Ideographic"},
    154085: {"Unified_Ideograph", "Ideographic"},
    154086: {"Unified_Ideograph", "Ideographic"},
    154087: {"Unified_Ideograph", "Ideographic"},
    154088: {"Unified_Ideograph", "Ideographic"},
    154089: {"Unified_Ideograph", "Ideographic"},
    154090: {"Unified_Ideograph", "Ideographic"},
    154091: {"Unified_Ideograph", "Ideographic"},
    154092: {"Unified_Ideograph", "Ideographic"},
    154093: {"Unified_Ideograph", "Ideographic"},
    154094: {"Unified_Ideograph", "Ideographic"},
    154095: {"Unified_Ideograph", "Ideographic"},
    154096: {"Unified_Ideograph", "Ideographic"},
    154097: {"Unified_Ideograph", "Ideographic"},
    154098: {"Unified_Ideograph", "Ideographic"},
    154099: {"Unified_Ideograph", "Ideographic"},
    154100: {"Unified_Ideograph", "Ideographic"},
    154101: {"Unified_Ideograph", "Ideographic"},
    154102: {"Unified_Ideograph", "Ideographic"},
    154103: {"Unified_Ideograph", "Ideographic"},
    154104: {"Unified_Ideograph", "Ideographic"},
    154105: {"Unified_Ideograph", "Ideographic"},
    154106: {"Unified_Ideograph", "Ideographic"},
    154107: {"Unified_Ideograph", "Ideographic"},
    154108: {"Unified_Ideograph", "Ideographic"},
    154109: {"Unified_Ideograph", "Ideographic"},
    154110: {"Unified_Ideograph", "Ideographic"},
    154111: {"Unified_Ideograph", "Ideographic"},
    154112: {"Unified_Ideograph", "Ideographic"},
    154113: {"Unified_Ideograph", "Ideographic"},
    154114: {"Unified_Ideograph", "Ideographic"},
    154115: {"Unified_Ideograph", "Ideographic"},
    154116: {"Unified_Ideograph", "Ideographic"},
    154117: {"Unified_Ideograph", "Ideographic"},
    154118: {"Unified_Ideograph", "Ideographic"},
    154119: {"Unified_Ideograph", "Ideographic"},
    154120: {"Unified_Ideograph", "Ideographic"},
    154121: {"Unified_Ideograph", "Ideographic"},
    154122: {"Unified_Ideograph", "Ideographic"},
    154123: {"Unified_Ideograph", "Ideographic"},
    154124: {"Unified_Ideograph", "Ideographic"},
    154125: {"Unified_Ideograph", "Ideographic"},
    154126: {"Unified_Ideograph", "Ideographic"},
    154127: {"Unified_Ideograph", "Ideographic"},
    154128: {"Unified_Ideograph", "Ideographic"},
    154129: {"Unified_Ideograph", "Ideographic"},
    154130: {"Unified_Ideograph", "Ideographic"},
    154131: {"Unified_Ideograph", "Ideographic"},
    154132: {"Unified_Ideograph", "Ideographic"},
    154133: {"Unified_Ideograph", "Ideographic"},
    154134: {"Unified_Ideograph", "Ideographic"},
    154135: {"Unified_Ideograph", "Ideographic"},
    154136: {"Unified_Ideograph", "Ideographic"},
    154137: {"Unified_Ideograph", "Ideographic"},
    154138: {"Unified_Ideograph", "Ideographic"},
    154139: {"Unified_Ideograph", "Ideographic"},
    154140: {"Unified_Ideograph", "Ideographic"},
    154141: {"Unified_Ideograph", "Ideographic"},
    154142: {"Unified_Ideograph", "Ideographic"},
    154143: {"Unified_Ideograph", "Ideographic"},
    154144: {"Unified_Ideograph", "Ideographic"},
    154145: {"Unified_Ideograph", "Ideographic"},
    154146: {"Unified_Ideograph", "Ideographic"},
    154147: {"Unified_Ideograph", "Ideographic"},
    154148: {"Unified_Ideograph", "Ideographic"},
    154149: {"Unified_Ideograph", "Ideographic"},
    154150: {"Unified_Ideograph", "Ideographic"},
    154151: {"Unified_Ideograph", "Ideographic"},
    154152: {"Unified_Ideograph", "Ideographic"},
    154153: {"Unified_Ideograph", "Ideographic"},
    154154: {"Unified_Ideograph", "Ideographic"},
    154155: {"Unified_Ideograph", "Ideographic"},
    154156: {"Unified_Ideograph", "Ideographic"},
    154157: {"Unified_Ideograph", "Ideographic"},
    154158: {"Unified_Ideograph", "Ideographic"},
    154159: {"Unified_Ideograph", "Ideographic"},
    154160: {"Unified_Ideograph", "Ideographic"},
    154161: {"Unified_Ideograph", "Ideographic"},
    154162: {"Unified_Ideograph", "Ideographic"},
    154163: {"Unified_Ideograph", "Ideographic"},
    154164: {"Unified_Ideograph", "Ideographic"},
    154165: {"Unified_Ideograph", "Ideographic"},
    154166: {"Unified_Ideograph", "Ideographic"},
    154167: {"Unified_Ideograph", "Ideographic"},
    154168: {"Unified_Ideograph", "Ideographic"},
    154169: {"Unified_Ideograph", "Ideographic"},
    154170: {"Unified_Ideograph", "Ideographic"},
    154171: {"Unified_Ideograph", "Ideographic"},
    154172: {"Unified_Ideograph", "Ideographic"},
    154173: {"Unified_Ideograph", "Ideographic"},
    154174: {"Unified_Ideograph", "Ideographic"},
    154175: {"Unified_Ideograph", "Ideographic"},
    154176: {"Unified_Ideograph", "Ideographic"},
    154177: {"Unified_Ideograph", "Ideographic"},
    154178: {"Unified_Ideograph", "Ideographic"},
    154179: {"Unified_Ideograph", "Ideographic"},
    154180: {"Unified_Ideograph", "Ideographic"},
    154181: {"Unified_Ideograph", "Ideographic"},
    154182: {"Unified_Ideograph", "Ideographic"},
    154183: {"Unified_Ideograph", "Ideographic"},
    154184: {"Unified_Ideograph", "Ideographic"},
    154185: {"Unified_Ideograph", "Ideographic"},
    154186: {"Unified_Ideograph", "Ideographic"},
    154187: {"Unified_Ideograph", "Ideographic"},
    154188: {"Unified_Ideograph", "Ideographic"},
    154189: {"Unified_Ideograph", "Ideographic"},
    154190: {"Unified_Ideograph", "Ideographic"},
    154191: {"Unified_Ideograph", "Ideographic"},
    154192: {"Unified_Ideograph", "Ideographic"},
    154193: {"Unified_Ideograph", "Ideographic"},
    154194: {"Unified_Ideograph", "Ideographic"},
    154195: {"Unified_Ideograph", "Ideographic"},
    154196: {"Unified_Ideograph", "Ideographic"},
    154197: {"Unified_Ideograph", "Ideographic"},
    154198: {"Unified_Ideograph", "Ideographic"},
    154199: {"Unified_Ideograph", "Ideographic"},
    154200: {"Unified_Ideograph", "Ideographic"},
    154201: {"Unified_Ideograph", "Ideographic"},
    154202: {"Unified_Ideograph", "Ideographic"},
    154203: {"Unified_Ideograph", "Ideographic"},
    154204: {"Unified_Ideograph", "Ideographic"},
    154205: {"Unified_Ideograph", "Ideographic"},
    154206: {"Unified_Ideograph", "Ideographic"},
    154207: {"Unified_Ideograph", "Ideographic"},
    154208: {"Unified_Ideograph", "Ideographic"},
    154209: {"Unified_Ideograph", "Ideographic"},
    154210: {"Unified_Ideograph", "Ideographic"},
    154211: {"Unified_Ideograph", "Ideographic"},
    154212: {"Unified_Ideograph", "Ideographic"},
    154213: {"Unified_Ideograph", "Ideographic"},
    154214: {"Unified_Ideograph", "Ideographic"},
    154215: {"Unified_Ideograph", "Ideographic"},
    154216: {"Unified_Ideograph", "Ideographic"},
    154217: {"Unified_Ideograph", "Ideographic"},
    154218: {"Unified_Ideograph", "Ideographic"},
    154219: {"Unified_Ideograph", "Ideographic"},
    154220: {"Unified_Ideograph", "Ideographic"},
    154221: {"Unified_Ideograph", "Ideographic"},
    154222: {"Unified_Ideograph", "Ideographic"},
    154223: {"Unified_Ideograph", "Ideographic"},
    154224: {"Unified_Ideograph", "Ideographic"},
    154225: {"Unified_Ideograph", "Ideographic"},
    154226: {"Unified_Ideograph", "Ideographic"},
    154227: {"Unified_Ideograph", "Ideographic"},
    154228: {"Unified_Ideograph", "Ideographic"},
    154229: {"Unified_Ideograph", "Ideographic"},
    154230: {"Unified_Ideograph", "Ideographic"},
    154231: {"Unified_Ideograph", "Ideographic"},
    154232: {"Unified_Ideograph", "Ideographic"},
    154233: {"Unified_Ideograph", "Ideographic"},
    154234: {"Unified_Ideograph", "Ideographic"},
    154235: {"Unified_Ideograph", "Ideographic"},
    154236: {"Unified_Ideograph", "Ideographic"},
    154237: {"Unified_Ideograph", "Ideographic"},
    154238: {"Unified_Ideograph", "Ideographic"},
    154239: {"Unified_Ideograph", "Ideographic"},
    154240: {"Unified_Ideograph", "Ideographic"},
    154241: {"Unified_Ideograph", "Ideographic"},
    154242: {"Unified_Ideograph", "Ideographic"},
    154243: {"Unified_Ideograph", "Ideographic"},
    154244: {"Unified_Ideograph", "Ideographic"},
    154245: {"Unified_Ideograph", "Ideographic"},
    154246: {"Unified_Ideograph", "Ideographic"},
    154247: {"Unified_Ideograph", "Ideographic"},
    154248: {"Unified_Ideograph", "Ideographic"},
    154249: {"Unified_Ideograph", "Ideographic"},
    154250: {"Unified_Ideograph", "Ideographic"},
    154251: {"Unified_Ideograph", "Ideographic"},
    154252: {"Unified_Ideograph", "Ideographic"},
    154253: {"Unified_Ideograph", "Ideographic"},
    154254: {"Unified_Ideograph", "Ideographic"},
    154255: {"Unified_Ideograph", "Ideographic"},
    154256: {"Unified_Ideograph", "Ideographic"},
    154257: {"Unified_Ideograph", "Ideographic"},
    154258: {"Unified_Ideograph", "Ideographic"},
    154259: {"Unified_Ideograph", "Ideographic"},
    154260: {"Unified_Ideograph", "Ideographic"},
    154261: {"Unified_Ideograph", "Ideographic"},
    154262: {"Unified_Ideograph", "Ideographic"},
    154263: {"Unified_Ideograph", "Ideographic"},
    154264: {"Unified_Ideograph", "Ideographic"},
    154265: {"Unified_Ideograph", "Ideographic"},
    154266: {"Unified_Ideograph", "Ideographic"},
    154267: {"Unified_Ideograph", "Ideographic"},
    154268: {"Unified_Ideograph", "Ideographic"},
    154269: {"Unified_Ideograph", "Ideographic"},
    154270: {"Unified_Ideograph", "Ideographic"},
    154271: {"Unified_Ideograph", "Ideographic"},
    154272: {"Unified_Ideograph", "Ideographic"},
    154273: {"Unified_Ideograph", "Ideographic"},
    154274: {"Unified_Ideograph", "Ideographic"},
    154275: {"Unified_Ideograph", "Ideographic"},
    154276: {"Unified_Ideograph", "Ideographic"},
    154277: {"Unified_Ideograph", "Ideographic"},
    154278: {"Unified_Ideograph", "Ideographic"},
    154279: {"Unified_Ideograph", "Ideographic"},
    154280: {"Unified_Ideograph", "Ideographic"},
    154281: {"Unified_Ideograph", "Ideographic"},
    154282: {"Unified_Ideograph", "Ideographic"},
    154283: {"Unified_Ideograph", "Ideographic"},
    154284: {"Unified_Ideograph", "Ideographic"},
    154285: {"Unified_Ideograph", "Ideographic"},
    154286: {"Unified_Ideograph", "Ideographic"},
    154287: {"Unified_Ideograph", "Ideographic"},
    154288: {"Unified_Ideograph", "Ideographic"},
    154289: {"Unified_Ideograph", "Ideographic"},
    154290: {"Unified_Ideograph", "Ideographic"},
    154291: {"Unified_Ideograph", "Ideographic"},
    154292: {"Unified_Ideograph", "Ideographic"},
    154293: {"Unified_Ideograph", "Ideographic"},
    154294: {"Unified_Ideograph", "Ideographic"},
    154295: {"Unified_Ideograph", "Ideographic"},
    154296: {"Unified_Ideograph", "Ideographic"},
    154297: {"Unified_Ideograph", "Ideographic"},
    154298: {"Unified_Ideograph", "Ideographic"},
    154299: {"Unified_Ideograph", "Ideographic"},
    154300: {"Unified_Ideograph", "Ideographic"},
    154301: {"Unified_Ideograph", "Ideographic"},
    154302: {"Unified_Ideograph", "Ideographic"},
    154303: {"Unified_Ideograph", "Ideographic"},
    154304: {"Unified_Ideograph", "Ideographic"},
    154305: {"Unified_Ideograph", "Ideographic"},
    154306: {"Unified_Ideograph", "Ideographic"},
    154307: {"Unified_Ideograph", "Ideographic"},
    154308: {"Unified_Ideograph", "Ideographic"},
    154309: {"Unified_Ideograph", "Ideographic"},
    154310: {"Unified_Ideograph", "Ideographic"},
    154311: {"Unified_Ideograph", "Ideographic"},
    154312: {"Unified_Ideograph", "Ideographic"},
    154313: {"Unified_Ideograph", "Ideographic"},
    154314: {"Unified_Ideograph", "Ideographic"},
    154315: {"Unified_Ideograph", "Ideographic"},
    154316: {"Unified_Ideograph", "Ideographic"},
    154317: {"Unified_Ideograph", "Ideographic"},
    154318: {"Unified_Ideograph", "Ideographic"},
    154319: {"Unified_Ideograph", "Ideographic"},
    154320: {"Unified_Ideograph", "Ideographic"},
    154321: {"Unified_Ideograph", "Ideographic"},
    154322: {"Unified_Ideograph", "Ideographic"},
    154323: {"Unified_Ideograph", "Ideographic"},
    154324: {"Unified_Ideograph", "Ideographic"},
    154325: {"Unified_Ideograph", "Ideographic"},
    154326: {"Unified_Ideograph", "Ideographic"},
    154327: {"Unified_Ideograph", "Ideographic"},
    154328: {"Unified_Ideograph", "Ideographic"},
    154329: {"Unified_Ideograph", "Ideographic"},
    154330: {"Unified_Ideograph", "Ideographic"},
    154331: {"Unified_Ideograph", "Ideographic"},
    154332: {"Unified_Ideograph", "Ideographic"},
    154333: {"Unified_Ideograph", "Ideographic"},
    154334: {"Unified_Ideograph", "Ideographic"},
    154335: {"Unified_Ideograph", "Ideographic"},
    154336: {"Unified_Ideograph", "Ideographic"},
    154337: {"Unified_Ideograph", "Ideographic"},
    154338: {"Unified_Ideograph", "Ideographic"},
    154339: {"Unified_Ideograph", "Ideographic"},
    154340: {"Unified_Ideograph", "Ideographic"},
    154341: {"Unified_Ideograph", "Ideographic"},
    154342: {"Unified_Ideograph", "Ideographic"},
    154343: {"Unified_Ideograph", "Ideographic"},
    154344: {"Unified_Ideograph", "Ideographic"},
    154345: {"Unified_Ideograph", "Ideographic"},
    154346: {"Unified_Ideograph", "Ideographic"},
    154347: {"Unified_Ideograph", "Ideographic"},
    154348: {"Unified_Ideograph", "Ideographic"},
    154349: {"Unified_Ideograph", "Ideographic"},
    154350: {"Unified_Ideograph", "Ideographic"},
    154351: {"Unified_Ideograph", "Ideographic"},
    154352: {"Unified_Ideograph", "Ideographic"},
    154353: {"Unified_Ideograph", "Ideographic"},
    154354: {"Unified_Ideograph", "Ideographic"},
    154355: {"Unified_Ideograph", "Ideographic"},
    154356: {"Unified_Ideograph", "Ideographic"},
    154357: {"Unified_Ideograph", "Ideographic"},
    154358: {"Unified_Ideograph", "Ideographic"},
    154359: {"Unified_Ideograph", "Ideographic"},
    154360: {"Unified_Ideograph", "Ideographic"},
    154361: {"Unified_Ideograph", "Ideographic"},
    154362: {"Unified_Ideograph", "Ideographic"},
    154363: {"Unified_Ideograph", "Ideographic"},
    154364: {"Unified_Ideograph", "Ideographic"},
    154365: {"Unified_Ideograph", "Ideographic"},
    154366: {"Unified_Ideograph", "Ideographic"},
    154367: {"Unified_Ideograph", "Ideographic"},
    154368: {"Unified_Ideograph", "Ideographic"},
    154369: {"Unified_Ideograph", "Ideographic"},
    154370: {"Unified_Ideograph", "Ideographic"},
    154371: {"Unified_Ideograph", "Ideographic"},
    154372: {"Unified_Ideograph", "Ideographic"},
    154373: {"Unified_Ideograph", "Ideographic"},
    154374: {"Unified_Ideograph", "Ideographic"},
    154375: {"Unified_Ideograph", "Ideographic"},
    154376: {"Unified_Ideograph", "Ideographic"},
    154377: {"Unified_Ideograph", "Ideographic"},
    154378: {"Unified_Ideograph", "Ideographic"},
    154379: {"Unified_Ideograph", "Ideographic"},
    154380: {"Unified_Ideograph", "Ideographic"},
    154381: {"Unified_Ideograph", "Ideographic"},
    154382: {"Unified_Ideograph", "Ideographic"},
    154383: {"Unified_Ideograph", "Ideographic"},
    154384: {"Unified_Ideograph", "Ideographic"},
    154385: {"Unified_Ideograph", "Ideographic"},
    154386: {"Unified_Ideograph", "Ideographic"},
    154387: {"Unified_Ideograph", "Ideographic"},
    154388: {"Unified_Ideograph", "Ideographic"},
    154389: {"Unified_Ideograph", "Ideographic"},
    154390: {"Unified_Ideograph", "Ideographic"},
    154391: {"Unified_Ideograph", "Ideographic"},
    154392: {"Unified_Ideograph", "Ideographic"},
    154393: {"Unified_Ideograph", "Ideographic"},
    154394: {"Unified_Ideograph", "Ideographic"},
    154395: {"Unified_Ideograph", "Ideographic"},
    154396: {"Unified_Ideograph", "Ideographic"},
    154397: {"Unified_Ideograph", "Ideographic"},
    154398: {"Unified_Ideograph", "Ideographic"},
    154399: {"Unified_Ideograph", "Ideographic"},
    154400: {"Unified_Ideograph", "Ideographic"},
    154401: {"Unified_Ideograph", "Ideographic"},
    154402: {"Unified_Ideograph", "Ideographic"},
    154403: {"Unified_Ideograph", "Ideographic"},
    154404: {"Unified_Ideograph", "Ideographic"},
    154405: {"Unified_Ideograph", "Ideographic"},
    154406: {"Unified_Ideograph", "Ideographic"},
    154407: {"Unified_Ideograph", "Ideographic"},
    154408: {"Unified_Ideograph", "Ideographic"},
    154409: {"Unified_Ideograph", "Ideographic"},
    154410: {"Unified_Ideograph", "Ideographic"},
    154411: {"Unified_Ideograph", "Ideographic"},
    154412: {"Unified_Ideograph", "Ideographic"},
    154413: {"Unified_Ideograph", "Ideographic"},
    154414: {"Unified_Ideograph", "Ideographic"},
    154415: {"Unified_Ideograph", "Ideographic"},
    154416: {"Unified_Ideograph", "Ideographic"},
    154417: {"Unified_Ideograph", "Ideographic"},
    154418: {"Unified_Ideograph", "Ideographic"},
    154419: {"Unified_Ideograph", "Ideographic"},
    154420: {"Unified_Ideograph", "Ideographic"},
    154421: {"Unified_Ideograph", "Ideographic"},
    154422: {"Unified_Ideograph", "Ideographic"},
    154423: {"Unified_Ideograph", "Ideographic"},
    154424: {"Unified_Ideograph", "Ideographic"},
    154425: {"Unified_Ideograph", "Ideographic"},
    154426: {"Unified_Ideograph", "Ideographic"},
    154427: {"Unified_Ideograph", "Ideographic"},
    154428: {"Unified_Ideograph", "Ideographic"},
    154429: {"Unified_Ideograph", "Ideographic"},
    154430: {"Unified_Ideograph", "Ideographic"},
    154431: {"Unified_Ideograph", "Ideographic"},
    154432: {"Unified_Ideograph", "Ideographic"},
    154433: {"Unified_Ideograph", "Ideographic"},
    154434: {"Unified_Ideograph", "Ideographic"},
    154435: {"Unified_Ideograph", "Ideographic"},
    154436: {"Unified_Ideograph", "Ideographic"},
    154437: {"Unified_Ideograph", "Ideographic"},
    154438: {"Unified_Ideograph", "Ideographic"},
    154439: {"Unified_Ideograph", "Ideographic"},
    154440: {"Unified_Ideograph", "Ideographic"},
    154441: {"Unified_Ideograph", "Ideographic"},
    154442: {"Unified_Ideograph", "Ideographic"},
    154443: {"Unified_Ideograph", "Ideographic"},
    154444: {"Unified_Ideograph", "Ideographic"},
    154445: {"Unified_Ideograph", "Ideographic"},
    154446: {"Unified_Ideograph", "Ideographic"},
    154447: {"Unified_Ideograph", "Ideographic"},
    154448: {"Unified_Ideograph", "Ideographic"},
    154449: {"Unified_Ideograph", "Ideographic"},
    154450: {"Unified_Ideograph", "Ideographic"},
    154451: {"Unified_Ideograph", "Ideographic"},
    154452: {"Unified_Ideograph", "Ideographic"},
    154453: {"Unified_Ideograph", "Ideographic"},
    154454: {"Unified_Ideograph", "Ideographic"},
    154455: {"Unified_Ideograph", "Ideographic"},
    154456: {"Unified_Ideograph", "Ideographic"},
    154457: {"Unified_Ideograph", "Ideographic"},
    154458: {"Unified_Ideograph", "Ideographic"},
    154459: {"Unified_Ideograph", "Ideographic"},
    154460: {"Unified_Ideograph", "Ideographic"},
    154461: {"Unified_Ideograph", "Ideographic"},
    154462: {"Unified_Ideograph", "Ideographic"},
    154463: {"Unified_Ideograph", "Ideographic"},
    154464: {"Unified_Ideograph", "Ideographic"},
    154465: {"Unified_Ideograph", "Ideographic"},
    154466: {"Unified_Ideograph", "Ideographic"},
    154467: {"Unified_Ideograph", "Ideographic"},
    154468: {"Unified_Ideograph", "Ideographic"},
    154469: {"Unified_Ideograph", "Ideographic"},
    154470: {"Unified_Ideograph", "Ideographic"},
    154471: {"Unified_Ideograph", "Ideographic"},
    154472: {"Unified_Ideograph", "Ideographic"},
    154473: {"Unified_Ideograph", "Ideographic"},
    154474: {"Unified_Ideograph", "Ideographic"},
    154475: {"Unified_Ideograph", "Ideographic"},
    154476: {"Unified_Ideograph", "Ideographic"},
    154477: {"Unified_Ideograph", "Ideographic"},
    154478: {"Unified_Ideograph", "Ideographic"},
    154479: {"Unified_Ideograph", "Ideographic"},
    154480: {"Unified_Ideograph", "Ideographic"},
    154481: {"Unified_Ideograph", "Ideographic"},
    154482: {"Unified_Ideograph", "Ideographic"},
    154483: {"Unified_Ideograph", "Ideographic"},
    154484: {"Unified_Ideograph", "Ideographic"},
    154485: {"Unified_Ideograph", "Ideographic"},
    154486: {"Unified_Ideograph", "Ideographic"},
    154487: {"Unified_Ideograph", "Ideographic"},
    154488: {"Unified_Ideograph", "Ideographic"},
    154489: {"Unified_Ideograph", "Ideographic"},
    154490: {"Unified_Ideograph", "Ideographic"},
    154491: {"Unified_Ideograph", "Ideographic"},
    154492: {"Unified_Ideograph", "Ideographic"},
    154493: {"Unified_Ideograph", "Ideographic"},
    154494: {"Unified_Ideograph", "Ideographic"},
    154495: {"Unified_Ideograph", "Ideographic"},
    154496: {"Unified_Ideograph", "Ideographic"},
    154497: {"Unified_Ideograph", "Ideographic"},
    154498: {"Unified_Ideograph", "Ideographic"},
    154499: {"Unified_Ideograph", "Ideographic"},
    154500: {"Unified_Ideograph", "Ideographic"},
    154501: {"Unified_Ideograph", "Ideographic"},
    154502: {"Unified_Ideograph", "Ideographic"},
    154503: {"Unified_Ideograph", "Ideographic"},
    154504: {"Unified_Ideograph", "Ideographic"},
    154505: {"Unified_Ideograph", "Ideographic"},
    154506: {"Unified_Ideograph", "Ideographic"},
    154507: {"Unified_Ideograph", "Ideographic"},
    154508: {"Unified_Ideograph", "Ideographic"},
    154509: {"Unified_Ideograph", "Ideographic"},
    154510: {"Unified_Ideograph", "Ideographic"},
    154511: {"Unified_Ideograph", "Ideographic"},
    154512: {"Unified_Ideograph", "Ideographic"},
    154513: {"Unified_Ideograph", "Ideographic"},
    154514: {"Unified_Ideograph", "Ideographic"},
    154515: {"Unified_Ideograph", "Ideographic"},
    154516: {"Unified_Ideograph", "Ideographic"},
    154517: {"Unified_Ideograph", "Ideographic"},
    154518: {"Unified_Ideograph", "Ideographic"},
    154519: {"Unified_Ideograph", "Ideographic"},
    154520: {"Unified_Ideograph", "Ideographic"},
    154521: {"Unified_Ideograph", "Ideographic"},
    154522: {"Unified_Ideograph", "Ideographic"},
    154523: {"Unified_Ideograph", "Ideographic"},
    154524: {"Unified_Ideograph", "Ideographic"},
    154525: {"Unified_Ideograph", "Ideographic"},
    154526: {"Unified_Ideograph", "Ideographic"},
    154527: {"Unified_Ideograph", "Ideographic"},
    154528: {"Unified_Ideograph", "Ideographic"},
    154529: {"Unified_Ideograph", "Ideographic"},
    154530: {"Unified_Ideograph", "Ideographic"},
    154531: {"Unified_Ideograph", "Ideographic"},
    154532: {"Unified_Ideograph", "Ideographic"},
    154533: {"Unified_Ideograph", "Ideographic"},
    154534: {"Unified_Ideograph", "Ideographic"},
    154535: {"Unified_Ideograph", "Ideographic"},
    154536: {"Unified_Ideograph", "Ideographic"},
    154537: {"Unified_Ideograph", "Ideographic"},
    154538: {"Unified_Ideograph", "Ideographic"},
    154539: {"Unified_Ideograph", "Ideographic"},
    154540: {"Unified_Ideograph", "Ideographic"},
    154541: {"Unified_Ideograph", "Ideographic"},
    154542: {"Unified_Ideograph", "Ideographic"},
    154543: {"Unified_Ideograph", "Ideographic"},
    154544: {"Unified_Ideograph", "Ideographic"},
    154545: {"Unified_Ideograph", "Ideographic"},
    154546: {"Unified_Ideograph", "Ideographic"},
    154547: {"Unified_Ideograph", "Ideographic"},
    154548: {"Unified_Ideograph", "Ideographic"},
    154549: {"Unified_Ideograph", "Ideographic"},
    154550: {"Unified_Ideograph", "Ideographic"},
    154551: {"Unified_Ideograph", "Ideographic"},
    154552: {"Unified_Ideograph", "Ideographic"},
    154553: {"Unified_Ideograph", "Ideographic"},
    154554: {"Unified_Ideograph", "Ideographic"},
    154555: {"Unified_Ideograph", "Ideographic"},
    154556: {"Unified_Ideograph", "Ideographic"},
    154557: {"Unified_Ideograph", "Ideographic"},
    154558: {"Unified_Ideograph", "Ideographic"},
    154559: {"Unified_Ideograph", "Ideographic"},
    154560: {"Unified_Ideograph", "Ideographic"},
    154561: {"Unified_Ideograph", "Ideographic"},
    154562: {"Unified_Ideograph", "Ideographic"},
    154563: {"Unified_Ideograph", "Ideographic"},
    154564: {"Unified_Ideograph", "Ideographic"},
    154565: {"Unified_Ideograph", "Ideographic"},
    154566: {"Unified_Ideograph", "Ideographic"},
    154567: {"Unified_Ideograph", "Ideographic"},
    154568: {"Unified_Ideograph", "Ideographic"},
    154569: {"Unified_Ideograph", "Ideographic"},
    154570: {"Unified_Ideograph", "Ideographic"},
    154571: {"Unified_Ideograph", "Ideographic"},
    154572: {"Unified_Ideograph", "Ideographic"},
    154573: {"Unified_Ideograph", "Ideographic"},
    154574: {"Unified_Ideograph", "Ideographic"},
    154575: {"Unified_Ideograph", "Ideographic"},
    154576: {"Unified_Ideograph", "Ideographic"},
    154577: {"Unified_Ideograph", "Ideographic"},
    154578: {"Unified_Ideograph", "Ideographic"},
    154579: {"Unified_Ideograph", "Ideographic"},
    154580: {"Unified_Ideograph", "Ideographic"},
    154581: {"Unified_Ideograph", "Ideographic"},
    154582: {"Unified_Ideograph", "Ideographic"},
    154583: {"Unified_Ideograph", "Ideographic"},
    154584: {"Unified_Ideograph", "Ideographic"},
    154585: {"Unified_Ideograph", "Ideographic"},
    154586: {"Unified_Ideograph", "Ideographic"},
    154587: {"Unified_Ideograph", "Ideographic"},
    154588: {"Unified_Ideograph", "Ideographic"},
    154589: {"Unified_Ideograph", "Ideographic"},
    154590: {"Unified_Ideograph", "Ideographic"},
    154591: {"Unified_Ideograph", "Ideographic"},
    154592: {"Unified_Ideograph", "Ideographic"},
    154593: {"Unified_Ideograph", "Ideographic"},
    154594: {"Unified_Ideograph", "Ideographic"},
    154595: {"Unified_Ideograph", "Ideographic"},
    154596: {"Unified_Ideograph", "Ideographic"},
    154597: {"Unified_Ideograph", "Ideographic"},
    154598: {"Unified_Ideograph", "Ideographic"},
    154599: {"Unified_Ideograph", "Ideographic"},
    154600: {"Unified_Ideograph", "Ideographic"},
    154601: {"Unified_Ideograph", "Ideographic"},
    154602: {"Unified_Ideograph", "Ideographic"},
    154603: {"Unified_Ideograph", "Ideographic"},
    154604: {"Unified_Ideograph", "Ideographic"},
    154605: {"Unified_Ideograph", "Ideographic"},
    154606: {"Unified_Ideograph", "Ideographic"},
    154607: {"Unified_Ideograph", "Ideographic"},
    154608: {"Unified_Ideograph", "Ideographic"},
    154609: {"Unified_Ideograph", "Ideographic"},
    154610: {"Unified_Ideograph", "Ideographic"},
    154611: {"Unified_Ideograph", "Ideographic"},
    154612: {"Unified_Ideograph", "Ideographic"},
    154613: {"Unified_Ideograph", "Ideographic"},
    154614: {"Unified_Ideograph", "Ideographic"},
    154615: {"Unified_Ideograph", "Ideographic"},
    154616: {"Unified_Ideograph", "Ideographic"},
    154617: {"Unified_Ideograph", "Ideographic"},
    154618: {"Unified_Ideograph", "Ideographic"},
    154619: {"Unified_Ideograph", "Ideographic"},
    154620: {"Unified_Ideograph", "Ideographic"},
    154621: {"Unified_Ideograph", "Ideographic"},
    154622: {"Unified_Ideograph", "Ideographic"},
    154623: {"Unified_Ideograph", "Ideographic"},
    154624: {"Unified_Ideograph", "Ideographic"},
    154625: {"Unified_Ideograph", "Ideographic"},
    154626: {"Unified_Ideograph", "Ideographic"},
    154627: {"Unified_Ideograph", "Ideographic"},
    154628: {"Unified_Ideograph", "Ideographic"},
    154629: {"Unified_Ideograph", "Ideographic"},
    154630: {"Unified_Ideograph", "Ideographic"},
    154631: {"Unified_Ideograph", "Ideographic"},
    154632: {"Unified_Ideograph", "Ideographic"},
    154633: {"Unified_Ideograph", "Ideographic"},
    154634: {"Unified_Ideograph", "Ideographic"},
    154635: {"Unified_Ideograph", "Ideographic"},
    154636: {"Unified_Ideograph", "Ideographic"},
    154637: {"Unified_Ideograph", "Ideographic"},
    154638: {"Unified_Ideograph", "Ideographic"},
    154639: {"Unified_Ideograph", "Ideographic"},
    154640: {"Unified_Ideograph", "Ideographic"},
    154641: {"Unified_Ideograph", "Ideographic"},
    154642: {"Unified_Ideograph", "Ideographic"},
    154643: {"Unified_Ideograph", "Ideographic"},
    154644: {"Unified_Ideograph", "Ideographic"},
    154645: {"Unified_Ideograph", "Ideographic"},
    154646: {"Unified_Ideograph", "Ideographic"},
    154647: {"Unified_Ideograph", "Ideographic"},
    154648: {"Unified_Ideograph", "Ideographic"},
    154649: {"Unified_Ideograph", "Ideographic"},
    154650: {"Unified_Ideograph", "Ideographic"},
    154651: {"Unified_Ideograph", "Ideographic"},
    154652: {"Unified_Ideograph", "Ideographic"},
    154653: {"Unified_Ideograph", "Ideographic"},
    154654: {"Unified_Ideograph", "Ideographic"},
    154655: {"Unified_Ideograph", "Ideographic"},
    154656: {"Unified_Ideograph", "Ideographic"},
    154657: {"Unified_Ideograph", "Ideographic"},
    154658: {"Unified_Ideograph", "Ideographic"},
    154659: {"Unified_Ideograph", "Ideographic"},
    154660: {"Unified_Ideograph", "Ideographic"},
    154661: {"Unified_Ideograph", "Ideographic"},
    154662: {"Unified_Ideograph", "Ideographic"},
    154663: {"Unified_Ideograph", "Ideographic"},
    154664: {"Unified_Ideograph", "Ideographic"},
    154665: {"Unified_Ideograph", "Ideographic"},
    154666: {"Unified_Ideograph", "Ideographic"},
    154667: {"Unified_Ideograph", "Ideographic"},
    154668: {"Unified_Ideograph", "Ideographic"},
    154669: {"Unified_Ideograph", "Ideographic"},
    154670: {"Unified_Ideograph", "Ideographic"},
    154671: {"Unified_Ideograph", "Ideographic"},
    154672: {"Unified_Ideograph", "Ideographic"},
    154673: {"Unified_Ideograph", "Ideographic"},
    154674: {"Unified_Ideograph", "Ideographic"},
    154675: {"Unified_Ideograph", "Ideographic"},
    154676: {"Unified_Ideograph", "Ideographic"},
    154677: {"Unified_Ideograph", "Ideographic"},
    154678: {"Unified_Ideograph", "Ideographic"},
    154679: {"Unified_Ideograph", "Ideographic"},
    154680: {"Unified_Ideograph", "Ideographic"},
    154681: {"Unified_Ideograph", "Ideographic"},
    154682: {"Unified_Ideograph", "Ideographic"},
    154683: {"Unified_Ideograph", "Ideographic"},
    154684: {"Unified_Ideograph", "Ideographic"},
    154685: {"Unified_Ideograph", "Ideographic"},
    154686: {"Unified_Ideograph", "Ideographic"},
    154687: {"Unified_Ideograph", "Ideographic"},
    154688: {"Unified_Ideograph", "Ideographic"},
    154689: {"Unified_Ideograph", "Ideographic"},
    154690: {"Unified_Ideograph", "Ideographic"},
    154691: {"Unified_Ideograph", "Ideographic"},
    154692: {"Unified_Ideograph", "Ideographic"},
    154693: {"Unified_Ideograph", "Ideographic"},
    154694: {"Unified_Ideograph", "Ideographic"},
    154695: {"Unified_Ideograph", "Ideographic"},
    154696: {"Unified_Ideograph", "Ideographic"},
    154697: {"Unified_Ideograph", "Ideographic"},
    154698: {"Unified_Ideograph", "Ideographic"},
    154699: {"Unified_Ideograph", "Ideographic"},
    154700: {"Unified_Ideograph", "Ideographic"},
    154701: {"Unified_Ideograph", "Ideographic"},
    154702: {"Unified_Ideograph", "Ideographic"},
    154703: {"Unified_Ideograph", "Ideographic"},
    154704: {"Unified_Ideograph", "Ideographic"},
    154705: {"Unified_Ideograph", "Ideographic"},
    154706: {"Unified_Ideograph", "Ideographic"},
    154707: {"Unified_Ideograph", "Ideographic"},
    154708: {"Unified_Ideograph", "Ideographic"},
    154709: {"Unified_Ideograph", "Ideographic"},
    154710: {"Unified_Ideograph", "Ideographic"},
    154711: {"Unified_Ideograph", "Ideographic"},
    154712: {"Unified_Ideograph", "Ideographic"},
    154713: {"Unified_Ideograph", "Ideographic"},
    154714: {"Unified_Ideograph", "Ideographic"},
    154715: {"Unified_Ideograph", "Ideographic"},
    154716: {"Unified_Ideograph", "Ideographic"},
    154717: {"Unified_Ideograph", "Ideographic"},
    154718: {"Unified_Ideograph", "Ideographic"},
    154719: {"Unified_Ideograph", "Ideographic"},
    154720: {"Unified_Ideograph", "Ideographic"},
    154721: {"Unified_Ideograph", "Ideographic"},
    154722: {"Unified_Ideograph", "Ideographic"},
    154723: {"Unified_Ideograph", "Ideographic"},
    154724: {"Unified_Ideograph", "Ideographic"},
    154725: {"Unified_Ideograph", "Ideographic"},
    154726: {"Unified_Ideograph", "Ideographic"},
    154727: {"Unified_Ideograph", "Ideographic"},
    154728: {"Unified_Ideograph", "Ideographic"},
    154729: {"Unified_Ideograph", "Ideographic"},
    154730: {"Unified_Ideograph", "Ideographic"},
    154731: {"Unified_Ideograph", "Ideographic"},
    154732: {"Unified_Ideograph", "Ideographic"},
    154733: {"Unified_Ideograph", "Ideographic"},
    154734: {"Unified_Ideograph", "Ideographic"},
    154735: {"Unified_Ideograph", "Ideographic"},
    154736: {"Unified_Ideograph", "Ideographic"},
    154737: {"Unified_Ideograph", "Ideographic"},
    154738: {"Unified_Ideograph", "Ideographic"},
    154739: {"Unified_Ideograph", "Ideographic"},
    154740: {"Unified_Ideograph", "Ideographic"},
    154741: {"Unified_Ideograph", "Ideographic"},
    154742: {"Unified_Ideograph", "Ideographic"},
    154743: {"Unified_Ideograph", "Ideographic"},
    154744: {"Unified_Ideograph", "Ideographic"},
    154745: {"Unified_Ideograph", "Ideographic"},
    154746: {"Unified_Ideograph", "Ideographic"},
    154747: {"Unified_Ideograph", "Ideographic"},
    154748: {"Unified_Ideograph", "Ideographic"},
    154749: {"Unified_Ideograph", "Ideographic"},
    154750: {"Unified_Ideograph", "Ideographic"},
    154751: {"Unified_Ideograph", "Ideographic"},
    154752: {"Unified_Ideograph", "Ideographic"},
    154753: {"Unified_Ideograph", "Ideographic"},
    154754: {"Unified_Ideograph", "Ideographic"},
    154755: {"Unified_Ideograph", "Ideographic"},
    154756: {"Unified_Ideograph", "Ideographic"},
    154757: {"Unified_Ideograph", "Ideographic"},
    154758: {"Unified_Ideograph", "Ideographic"},
    154759: {"Unified_Ideograph", "Ideographic"},
    154760: {"Unified_Ideograph", "Ideographic"},
    154761: {"Unified_Ideograph", "Ideographic"},
    154762: {"Unified_Ideograph", "Ideographic"},
    154763: {"Unified_Ideograph", "Ideographic"},
    154764: {"Unified_Ideograph", "Ideographic"},
    154765: {"Unified_Ideograph", "Ideographic"},
    154766: {"Unified_Ideograph", "Ideographic"},
    154767: {"Unified_Ideograph", "Ideographic"},
    154768: {"Unified_Ideograph", "Ideographic"},
    154769: {"Unified_Ideograph", "Ideographic"},
    154770: {"Unified_Ideograph", "Ideographic"},
    154771: {"Unified_Ideograph", "Ideographic"},
    154772: {"Unified_Ideograph", "Ideographic"},
    154773: {"Unified_Ideograph", "Ideographic"},
    154774: {"Unified_Ideograph", "Ideographic"},
    154775: {"Unified_Ideograph", "Ideographic"},
    154776: {"Unified_Ideograph", "Ideographic"},
    154777: {"Unified_Ideograph", "Ideographic"},
    154778: {"Unified_Ideograph", "Ideographic"},
    154779: {"Unified_Ideograph", "Ideographic"},
    154780: {"Unified_Ideograph", "Ideographic"},
    154781: {"Unified_Ideograph", "Ideographic"},
    154782: {"Unified_Ideograph", "Ideographic"},
    154783: {"Unified_Ideograph", "Ideographic"},
    154784: {"Unified_Ideograph", "Ideographic"},
    154785: {"Unified_Ideograph", "Ideographic"},
    154786: {"Unified_Ideograph", "Ideographic"},
    154787: {"Unified_Ideograph", "Ideographic"},
    154788: {"Unified_Ideograph", "Ideographic"},
    154789: {"Unified_Ideograph", "Ideographic"},
    154790: {"Unified_Ideograph", "Ideographic"},
    154791: {"Unified_Ideograph", "Ideographic"},
    154792: {"Unified_Ideograph", "Ideographic"},
    154793: {"Unified_Ideograph", "Ideographic"},
    154794: {"Unified_Ideograph", "Ideographic"},
    154795: {"Unified_Ideograph", "Ideographic"},
    154796: {"Unified_Ideograph", "Ideographic"},
    154797: {"Unified_Ideograph", "Ideographic"},
    154798: {"Unified_Ideograph", "Ideographic"},
    154799: {"Unified_Ideograph", "Ideographic"},
    154800: {"Unified_Ideograph", "Ideographic"},
    154801: {"Unified_Ideograph", "Ideographic"},
    154802: {"Unified_Ideograph", "Ideographic"},
    154803: {"Unified_Ideograph", "Ideographic"},
    154804: {"Unified_Ideograph", "Ideographic"},
    154805: {"Unified_Ideograph", "Ideographic"},
    154806: {"Unified_Ideograph", "Ideographic"},
    154807: {"Unified_Ideograph", "Ideographic"},
    154808: {"Unified_Ideograph", "Ideographic"},
    154809: {"Unified_Ideograph", "Ideographic"},
    154810: {"Unified_Ideograph", "Ideographic"},
    154811: {"Unified_Ideograph", "Ideographic"},
    154812: {"Unified_Ideograph", "Ideographic"},
    154813: {"Unified_Ideograph", "Ideographic"},
    154814: {"Unified_Ideograph", "Ideographic"},
    154815: {"Unified_Ideograph", "Ideographic"},
    154816: {"Unified_Ideograph", "Ideographic"},
    154817: {"Unified_Ideograph", "Ideographic"},
    154818: {"Unified_Ideograph", "Ideographic"},
    154819: {"Unified_Ideograph", "Ideographic"},
    154820: {"Unified_Ideograph", "Ideographic"},
    154821: {"Unified_Ideograph", "Ideographic"},
    154822: {"Unified_Ideograph", "Ideographic"},
    154823: {"Unified_Ideograph", "Ideographic"},
    154824: {"Unified_Ideograph", "Ideographic"},
    154825: {"Unified_Ideograph", "Ideographic"},
    154826: {"Unified_Ideograph", "Ideographic"},
    154827: {"Unified_Ideograph", "Ideographic"},
    154828: {"Unified_Ideograph", "Ideographic"},
    154829: {"Unified_Ideograph", "Ideographic"},
    154830: {"Unified_Ideograph", "Ideographic"},
    154831: {"Unified_Ideograph", "Ideographic"},
    154832: {"Unified_Ideograph", "Ideographic"},
    154833: {"Unified_Ideograph", "Ideographic"},
    154834: {"Unified_Ideograph", "Ideographic"},
    154835: {"Unified_Ideograph", "Ideographic"},
    154836: {"Unified_Ideograph", "Ideographic"},
    154837: {"Unified_Ideograph", "Ideographic"},
    154838: {"Unified_Ideograph", "Ideographic"},
    154839: {"Unified_Ideograph", "Ideographic"},
    154840: {"Unified_Ideograph", "Ideographic"},
    154841: {"Unified_Ideograph", "Ideographic"},
    154842: {"Unified_Ideograph", "Ideographic"},
    154843: {"Unified_Ideograph", "Ideographic"},
    154844: {"Unified_Ideograph", "Ideographic"},
    154845: {"Unified_Ideograph", "Ideographic"},
    154846: {"Unified_Ideograph", "Ideographic"},
    154847: {"Unified_Ideograph", "Ideographic"},
    154848: {"Unified_Ideograph", "Ideographic"},
    154849: {"Unified_Ideograph", "Ideographic"},
    154850: {"Unified_Ideograph", "Ideographic"},
    154851: {"Unified_Ideograph", "Ideographic"},
    154852: {"Unified_Ideograph", "Ideographic"},
    154853: {"Unified_Ideograph", "Ideographic"},
    154854: {"Unified_Ideograph", "Ideographic"},
    154855: {"Unified_Ideograph", "Ideographic"},
    154856: {"Unified_Ideograph", "Ideographic"},
    154857: {"Unified_Ideograph", "Ideographic"},
    154858: {"Unified_Ideograph", "Ideographic"},
    154859: {"Unified_Ideograph", "Ideographic"},
    154860: {"Unified_Ideograph", "Ideographic"},
    154861: {"Unified_Ideograph", "Ideographic"},
    154862: {"Unified_Ideograph", "Ideographic"},
    154863: {"Unified_Ideograph", "Ideographic"},
    154864: {"Unified_Ideograph", "Ideographic"},
    154865: {"Unified_Ideograph", "Ideographic"},
    154866: {"Unified_Ideograph", "Ideographic"},
    154867: {"Unified_Ideograph", "Ideographic"},
    154868: {"Unified_Ideograph", "Ideographic"},
    154869: {"Unified_Ideograph", "Ideographic"},
    154870: {"Unified_Ideograph", "Ideographic"},
    154871: {"Unified_Ideograph", "Ideographic"},
    154872: {"Unified_Ideograph", "Ideographic"},
    154873: {"Unified_Ideograph", "Ideographic"},
    154874: {"Unified_Ideograph", "Ideographic"},
    154875: {"Unified_Ideograph", "Ideographic"},
    154876: {"Unified_Ideograph", "Ideographic"},
    154877: {"Unified_Ideograph", "Ideographic"},
    154878: {"Unified_Ideograph", "Ideographic"},
    154879: {"Unified_Ideograph", "Ideographic"},
    154880: {"Unified_Ideograph", "Ideographic"},
    154881: {"Unified_Ideograph", "Ideographic"},
    154882: {"Unified_Ideograph", "Ideographic"},
    154883: {"Unified_Ideograph", "Ideographic"},
    154884: {"Unified_Ideograph", "Ideographic"},
    154885: {"Unified_Ideograph", "Ideographic"},
    154886: {"Unified_Ideograph", "Ideographic"},
    154887: {"Unified_Ideograph", "Ideographic"},
    154888: {"Unified_Ideograph", "Ideographic"},
    154889: {"Unified_Ideograph", "Ideographic"},
    154890: {"Unified_Ideograph", "Ideographic"},
    154891: {"Unified_Ideograph", "Ideographic"},
    154892: {"Unified_Ideograph", "Ideographic"},
    154893: {"Unified_Ideograph", "Ideographic"},
    154894: {"Unified_Ideograph", "Ideographic"},
    154895: {"Unified_Ideograph", "Ideographic"},
    154896: {"Unified_Ideograph", "Ideographic"},
    154897: {"Unified_Ideograph", "Ideographic"},
    154898: {"Unified_Ideograph", "Ideographic"},
    154899: {"Unified_Ideograph", "Ideographic"},
    154900: {"Unified_Ideograph", "Ideographic"},
    154901: {"Unified_Ideograph", "Ideographic"},
    154902: {"Unified_Ideograph", "Ideographic"},
    154903: {"Unified_Ideograph", "Ideographic"},
    154904: {"Unified_Ideograph", "Ideographic"},
    154905: {"Unified_Ideograph", "Ideographic"},
    154906: {"Unified_Ideograph", "Ideographic"},
    154907: {"Unified_Ideograph", "Ideographic"},
    154908: {"Unified_Ideograph", "Ideographic"},
    154909: {"Unified_Ideograph", "Ideographic"},
    154910: {"Unified_Ideograph", "Ideographic"},
    154911: {"Unified_Ideograph", "Ideographic"},
    154912: {"Unified_Ideograph", "Ideographic"},
    154913: {"Unified_Ideograph", "Ideographic"},
    154914: {"Unified_Ideograph", "Ideographic"},
    154915: {"Unified_Ideograph", "Ideographic"},
    154916: {"Unified_Ideograph", "Ideographic"},
    154917: {"Unified_Ideograph", "Ideographic"},
    154918: {"Unified_Ideograph", "Ideographic"},
    154919: {"Unified_Ideograph", "Ideographic"},
    154920: {"Unified_Ideograph", "Ideographic"},
    154921: {"Unified_Ideograph", "Ideographic"},
    154922: {"Unified_Ideograph", "Ideographic"},
    154923: {"Unified_Ideograph", "Ideographic"},
    154924: {"Unified_Ideograph", "Ideographic"},
    154925: {"Unified_Ideograph", "Ideographic"},
    154926: {"Unified_Ideograph", "Ideographic"},
    154927: {"Unified_Ideograph", "Ideographic"},
    154928: {"Unified_Ideograph", "Ideographic"},
    154929: {"Unified_Ideograph", "Ideographic"},
    154930: {"Unified_Ideograph", "Ideographic"},
    154931: {"Unified_Ideograph", "Ideographic"},
    154932: {"Unified_Ideograph", "Ideographic"},
    154933: {"Unified_Ideograph", "Ideographic"},
    154934: {"Unified_Ideograph", "Ideographic"},
    154935: {"Unified_Ideograph", "Ideographic"},
    154936: {"Unified_Ideograph", "Ideographic"},
    154937: {"Unified_Ideograph", "Ideographic"},
    154938: {"Unified_Ideograph", "Ideographic"},
    154939: {"Unified_Ideograph", "Ideographic"},
    154940: {"Unified_Ideograph", "Ideographic"},
    154941: {"Unified_Ideograph", "Ideographic"},
    154942: {"Unified_Ideograph", "Ideographic"},
    154943: {"Unified_Ideograph", "Ideographic"},
    154944: {"Unified_Ideograph", "Ideographic"},
    154945: {"Unified_Ideograph", "Ideographic"},
    154946: {"Unified_Ideograph", "Ideographic"},
    154947: {"Unified_Ideograph", "Ideographic"},
    154948: {"Unified_Ideograph", "Ideographic"},
    154949: {"Unified_Ideograph", "Ideographic"},
    154950: {"Unified_Ideograph", "Ideographic"},
    154951: {"Unified_Ideograph", "Ideographic"},
    154952: {"Unified_Ideograph", "Ideographic"},
    154953: {"Unified_Ideograph", "Ideographic"},
    154954: {"Unified_Ideograph", "Ideographic"},
    154955: {"Unified_Ideograph", "Ideographic"},
    154956: {"Unified_Ideograph", "Ideographic"},
    154957: {"Unified_Ideograph", "Ideographic"},
    154958: {"Unified_Ideograph", "Ideographic"},
    154959: {"Unified_Ideograph", "Ideographic"},
    154960: {"Unified_Ideograph", "Ideographic"},
    154961: {"Unified_Ideograph", "Ideographic"},
    154962: {"Unified_Ideograph", "Ideographic"},
    154963: {"Unified_Ideograph", "Ideographic"},
    154964: {"Unified_Ideograph", "Ideographic"},
    154965: {"Unified_Ideograph", "Ideographic"},
    154966: {"Unified_Ideograph", "Ideographic"},
    154967: {"Unified_Ideograph", "Ideographic"},
    154968: {"Unified_Ideograph", "Ideographic"},
    154969: {"Unified_Ideograph", "Ideographic"},
    154970: {"Unified_Ideograph", "Ideographic"},
    154971: {"Unified_Ideograph", "Ideographic"},
    154972: {"Unified_Ideograph", "Ideographic"},
    154973: {"Unified_Ideograph", "Ideographic"},
    154974: {"Unified_Ideograph", "Ideographic"},
    154975: {"Unified_Ideograph", "Ideographic"},
    154976: {"Unified_Ideograph", "Ideographic"},
    154977: {"Unified_Ideograph", "Ideographic"},
    154978: {"Unified_Ideograph", "Ideographic"},
    154979: {"Unified_Ideograph", "Ideographic"},
    154980: {"Unified_Ideograph", "Ideographic"},
    154981: {"Unified_Ideograph", "Ideographic"},
    154982: {"Unified_Ideograph", "Ideographic"},
    154983: {"Unified_Ideograph", "Ideographic"},
    154984: {"Unified_Ideograph", "Ideographic"},
    154985: {"Unified_Ideograph", "Ideographic"},
    154986: {"Unified_Ideograph", "Ideographic"},
    154987: {"Unified_Ideograph", "Ideographic"},
    154988: {"Unified_Ideograph", "Ideographic"},
    154989: {"Unified_Ideograph", "Ideographic"},
    154990: {"Unified_Ideograph", "Ideographic"},
    154991: {"Unified_Ideograph", "Ideographic"},
    154992: {"Unified_Ideograph", "Ideographic"},
    154993: {"Unified_Ideograph", "Ideographic"},
    154994: {"Unified_Ideograph", "Ideographic"},
    154995: {"Unified_Ideograph", "Ideographic"},
    154996: {"Unified_Ideograph", "Ideographic"},
    154997: {"Unified_Ideograph", "Ideographic"},
    154998: {"Unified_Ideograph", "Ideographic"},
    154999: {"Unified_Ideograph", "Ideographic"},
    155000: {"Unified_Ideograph", "Ideographic"},
    155001: {"Unified_Ideograph", "Ideographic"},
    155002: {"Unified_Ideograph", "Ideographic"},
    155003: {"Unified_Ideograph", "Ideographic"},
    155004: {"Unified_Ideograph", "Ideographic"},
    155005: {"Unified_Ideograph", "Ideographic"},
    155006: {"Unified_Ideograph", "Ideographic"},
    155007: {"Unified_Ideograph", "Ideographic"},
    155008: {"Unified_Ideograph", "Ideographic"},
    155009: {"Unified_Ideograph", "Ideographic"},
    155010: {"Unified_Ideograph", "Ideographic"},
    155011: {"Unified_Ideograph", "Ideographic"},
    155012: {"Unified_Ideograph", "Ideographic"},
    155013: {"Unified_Ideograph", "Ideographic"},
    155014: {"Unified_Ideograph", "Ideographic"},
    155015: {"Unified_Ideograph", "Ideographic"},
    155016: {"Unified_Ideograph", "Ideographic"},
    155017: {"Unified_Ideograph", "Ideographic"},
    155018: {"Unified_Ideograph", "Ideographic"},
    155019: {"Unified_Ideograph", "Ideographic"},
    155020: {"Unified_Ideograph", "Ideographic"},
    155021: {"Unified_Ideograph", "Ideographic"},
    155022: {"Unified_Ideograph", "Ideographic"},
    155023: {"Unified_Ideograph", "Ideographic"},
    155024: {"Unified_Ideograph", "Ideographic"},
    155025: {"Unified_Ideograph", "Ideographic"},
    155026: {"Unified_Ideograph", "Ideographic"},
    155027: {"Unified_Ideograph", "Ideographic"},
    155028: {"Unified_Ideograph", "Ideographic"},
    155029: {"Unified_Ideograph", "Ideographic"},
    155030: {"Unified_Ideograph", "Ideographic"},
    155031: {"Unified_Ideograph", "Ideographic"},
    155032: {"Unified_Ideograph", "Ideographic"},
    155033: {"Unified_Ideograph", "Ideographic"},
    155034: {"Unified_Ideograph", "Ideographic"},
    155035: {"Unified_Ideograph", "Ideographic"},
    155036: {"Unified_Ideograph", "Ideographic"},
    155037: {"Unified_Ideograph", "Ideographic"},
    155038: {"Unified_Ideograph", "Ideographic"},
    155039: {"Unified_Ideograph", "Ideographic"},
    155040: {"Unified_Ideograph", "Ideographic"},
    155041: {"Unified_Ideograph", "Ideographic"},
    155042: {"Unified_Ideograph", "Ideographic"},
    155043: {"Unified_Ideograph", "Ideographic"},
    155044: {"Unified_Ideograph", "Ideographic"},
    155045: {"Unified_Ideograph", "Ideographic"},
    155046: {"Unified_Ideograph", "Ideographic"},
    155047: {"Unified_Ideograph", "Ideographic"},
    155048: {"Unified_Ideograph", "Ideographic"},
    155049: {"Unified_Ideograph", "Ideographic"},
    155050: {"Unified_Ideograph", "Ideographic"},
    155051: {"Unified_Ideograph", "Ideographic"},
    155052: {"Unified_Ideograph", "Ideographic"},
    155053: {"Unified_Ideograph", "Ideographic"},
    155054: {"Unified_Ideograph", "Ideographic"},
    155055: {"Unified_Ideograph", "Ideographic"},
    155056: {"Unified_Ideograph", "Ideographic"},
    155057: {"Unified_Ideograph", "Ideographic"},
    155058: {"Unified_Ideograph", "Ideographic"},
    155059: {"Unified_Ideograph", "Ideographic"},
    155060: {"Unified_Ideograph", "Ideographic"},
    155061: {"Unified_Ideograph", "Ideographic"},
    155062: {"Unified_Ideograph", "Ideographic"},
    155063: {"Unified_Ideograph", "Ideographic"},
    155064: {"Unified_Ideograph", "Ideographic"},
    155065: {"Unified_Ideograph", "Ideographic"},
    155066: {"Unified_Ideograph", "Ideographic"},
    155067: {"Unified_Ideograph", "Ideographic"},
    155068: {"Unified_Ideograph", "Ideographic"},
    155069: {"Unified_Ideograph", "Ideographic"},
    155070: {"Unified_Ideograph", "Ideographic"},
    155071: {"Unified_Ideograph", "Ideographic"},
    155072: {"Unified_Ideograph", "Ideographic"},
    155073: {"Unified_Ideograph", "Ideographic"},
    155074: {"Unified_Ideograph", "Ideographic"},
    155075: {"Unified_Ideograph", "Ideographic"},
    155076: {"Unified_Ideograph", "Ideographic"},
    155077: {"Unified_Ideograph", "Ideographic"},
    155078: {"Unified_Ideograph", "Ideographic"},
    155079: {"Unified_Ideograph", "Ideographic"},
    155080: {"Unified_Ideograph", "Ideographic"},
    155081: {"Unified_Ideograph", "Ideographic"},
    155082: {"Unified_Ideograph", "Ideographic"},
    155083: {"Unified_Ideograph", "Ideographic"},
    155084: {"Unified_Ideograph", "Ideographic"},
    155085: {"Unified_Ideograph", "Ideographic"},
    155086: {"Unified_Ideograph", "Ideographic"},
    155087: {"Unified_Ideograph", "Ideographic"},
    155088: {"Unified_Ideograph", "Ideographic"},
    155089: {"Unified_Ideograph", "Ideographic"},
    155090: {"Unified_Ideograph", "Ideographic"},
    155091: {"Unified_Ideograph", "Ideographic"},
    155092: {"Unified_Ideograph", "Ideographic"},
    155093: {"Unified_Ideograph", "Ideographic"},
    155094: {"Unified_Ideograph", "Ideographic"},
    155095: {"Unified_Ideograph", "Ideographic"},
    155096: {"Unified_Ideograph", "Ideographic"},
    155097: {"Unified_Ideograph", "Ideographic"},
    155098: {"Unified_Ideograph", "Ideographic"},
    155099: {"Unified_Ideograph", "Ideographic"},
    155100: {"Unified_Ideograph", "Ideographic"},
    155101: {"Unified_Ideograph", "Ideographic"},
    155102: {"Unified_Ideograph", "Ideographic"},
    155103: {"Unified_Ideograph", "Ideographic"},
    155104: {"Unified_Ideograph", "Ideographic"},
    155105: {"Unified_Ideograph", "Ideographic"},
    155106: {"Unified_Ideograph", "Ideographic"},
    155107: {"Unified_Ideograph", "Ideographic"},
    155108: {"Unified_Ideograph", "Ideographic"},
    155109: {"Unified_Ideograph", "Ideographic"},
    155110: {"Unified_Ideograph", "Ideographic"},
    155111: {"Unified_Ideograph", "Ideographic"},
    155112: {"Unified_Ideograph", "Ideographic"},
    155113: {"Unified_Ideograph", "Ideographic"},
    155114: {"Unified_Ideograph", "Ideographic"},
    155115: {"Unified_Ideograph", "Ideographic"},
    155116: {"Unified_Ideograph", "Ideographic"},
    155117: {"Unified_Ideograph", "Ideographic"},
    155118: {"Unified_Ideograph", "Ideographic"},
    155119: {"Unified_Ideograph", "Ideographic"},
    155120: {"Unified_Ideograph", "Ideographic"},
    155121: {"Unified_Ideograph", "Ideographic"},
    155122: {"Unified_Ideograph", "Ideographic"},
    155123: {"Unified_Ideograph", "Ideographic"},
    155124: {"Unified_Ideograph", "Ideographic"},
    155125: {"Unified_Ideograph", "Ideographic"},
    155126: {"Unified_Ideograph", "Ideographic"},
    155127: {"Unified_Ideograph", "Ideographic"},
    155128: {"Unified_Ideograph", "Ideographic"},
    155129: {"Unified_Ideograph", "Ideographic"},
    155130: {"Unified_Ideograph", "Ideographic"},
    155131: {"Unified_Ideograph", "Ideographic"},
    155132: {"Unified_Ideograph", "Ideographic"},
    155133: {"Unified_Ideograph", "Ideographic"},
    155134: {"Unified_Ideograph", "Ideographic"},
    155135: {"Unified_Ideograph", "Ideographic"},
    155136: {"Unified_Ideograph", "Ideographic"},
    155137: {"Unified_Ideograph", "Ideographic"},
    155138: {"Unified_Ideograph", "Ideographic"},
    155139: {"Unified_Ideograph", "Ideographic"},
    155140: {"Unified_Ideograph", "Ideographic"},
    155141: {"Unified_Ideograph", "Ideographic"},
    155142: {"Unified_Ideograph", "Ideographic"},
    155143: {"Unified_Ideograph", "Ideographic"},
    155144: {"Unified_Ideograph", "Ideographic"},
    155145: {"Unified_Ideograph", "Ideographic"},
    155146: {"Unified_Ideograph", "Ideographic"},
    155147: {"Unified_Ideograph", "Ideographic"},
    155148: {"Unified_Ideograph", "Ideographic"},
    155149: {"Unified_Ideograph", "Ideographic"},
    155150: {"Unified_Ideograph", "Ideographic"},
    155151: {"Unified_Ideograph", "Ideographic"},
    155152: {"Unified_Ideograph", "Ideographic"},
    155153: {"Unified_Ideograph", "Ideographic"},
    155154: {"Unified_Ideograph", "Ideographic"},
    155155: {"Unified_Ideograph", "Ideographic"},
    155156: {"Unified_Ideograph", "Ideographic"},
    155157: {"Unified_Ideograph", "Ideographic"},
    155158: {"Unified_Ideograph", "Ideographic"},
    155159: {"Unified_Ideograph", "Ideographic"},
    155160: {"Unified_Ideograph", "Ideographic"},
    155161: {"Unified_Ideograph", "Ideographic"},
    155162: {"Unified_Ideograph", "Ideographic"},
    155163: {"Unified_Ideograph", "Ideographic"},
    155164: {"Unified_Ideograph", "Ideographic"},
    155165: {"Unified_Ideograph", "Ideographic"},
    155166: {"Unified_Ideograph", "Ideographic"},
    155167: {"Unified_Ideograph", "Ideographic"},
    155168: {"Unified_Ideograph", "Ideographic"},
    155169: {"Unified_Ideograph", "Ideographic"},
    155170: {"Unified_Ideograph", "Ideographic"},
    155171: {"Unified_Ideograph", "Ideographic"},
    155172: {"Unified_Ideograph", "Ideographic"},
    155173: {"Unified_Ideograph", "Ideographic"},
    155174: {"Unified_Ideograph", "Ideographic"},
    155175: {"Unified_Ideograph", "Ideographic"},
    155176: {"Unified_Ideograph", "Ideographic"},
    155177: {"Unified_Ideograph", "Ideographic"},
    155178: {"Unified_Ideograph", "Ideographic"},
    155179: {"Unified_Ideograph", "Ideographic"},
    155180: {"Unified_Ideograph", "Ideographic"},
    155181: {"Unified_Ideograph", "Ideographic"},
    155182: {"Unified_Ideograph", "Ideographic"},
    155183: {"Unified_Ideograph", "Ideographic"},
    155184: {"Unified_Ideograph", "Ideographic"},
    155185: {"Unified_Ideograph", "Ideographic"},
    155186: {"Unified_Ideograph", "Ideographic"},
    155187: {"Unified_Ideograph", "Ideographic"},
    155188: {"Unified_Ideograph", "Ideographic"},
    155189: {"Unified_Ideograph", "Ideographic"},
    155190: {"Unified_Ideograph", "Ideographic"},
    155191: {"Unified_Ideograph", "Ideographic"},
    155192: {"Unified_Ideograph", "Ideographic"},
    155193: {"Unified_Ideograph", "Ideographic"},
    155194: {"Unified_Ideograph", "Ideographic"},
    155195: {"Unified_Ideograph", "Ideographic"},
    155196: {"Unified_Ideograph", "Ideographic"},
    155197: {"Unified_Ideograph", "Ideographic"},
    155198: {"Unified_Ideograph", "Ideographic"},
    155199: {"Unified_Ideograph", "Ideographic"},
    155200: {"Unified_Ideograph", "Ideographic"},
    155201: {"Unified_Ideograph", "Ideographic"},
    155202: {"Unified_Ideograph", "Ideographic"},
    155203: {"Unified_Ideograph", "Ideographic"},
    155204: {"Unified_Ideograph", "Ideographic"},
    155205: {"Unified_Ideograph", "Ideographic"},
    155206: {"Unified_Ideograph", "Ideographic"},
    155207: {"Unified_Ideograph", "Ideographic"},
    155208: {"Unified_Ideograph", "Ideographic"},
    155209: {"Unified_Ideograph", "Ideographic"},
    155210: {"Unified_Ideograph", "Ideographic"},
    155211: {"Unified_Ideograph", "Ideographic"},
    155212: {"Unified_Ideograph", "Ideographic"},
    155213: {"Unified_Ideograph", "Ideographic"},
    155214: {"Unified_Ideograph", "Ideographic"},
    155215: {"Unified_Ideograph", "Ideographic"},
    155216: {"Unified_Ideograph", "Ideographic"},
    155217: {"Unified_Ideograph", "Ideographic"},
    155218: {"Unified_Ideograph", "Ideographic"},
    155219: {"Unified_Ideograph", "Ideographic"},
    155220: {"Unified_Ideograph", "Ideographic"},
    155221: {"Unified_Ideograph", "Ideographic"},
    155222: {"Unified_Ideograph", "Ideographic"},
    155223: {"Unified_Ideograph", "Ideographic"},
    155224: {"Unified_Ideograph", "Ideographic"},
    155225: {"Unified_Ideograph", "Ideographic"},
    155226: {"Unified_Ideograph", "Ideographic"},
    155227: {"Unified_Ideograph", "Ideographic"},
    155228: {"Unified_Ideograph", "Ideographic"},
    155229: {"Unified_Ideograph", "Ideographic"},
    155230: {"Unified_Ideograph", "Ideographic"},
    155231: {"Unified_Ideograph", "Ideographic"},
    155232: {"Unified_Ideograph", "Ideographic"},
    155233: {"Unified_Ideograph", "Ideographic"},
    155234: {"Unified_Ideograph", "Ideographic"},
    155235: {"Unified_Ideograph", "Ideographic"},
    155236: {"Unified_Ideograph", "Ideographic"},
    155237: {"Unified_Ideograph", "Ideographic"},
    155238: {"Unified_Ideograph", "Ideographic"},
    155239: {"Unified_Ideograph", "Ideographic"},
    155240: {"Unified_Ideograph", "Ideographic"},
    155241: {"Unified_Ideograph", "Ideographic"},
    155242: {"Unified_Ideograph", "Ideographic"},
    155243: {"Unified_Ideograph", "Ideographic"},
    155244: {"Unified_Ideograph", "Ideographic"},
    155245: {"Unified_Ideograph", "Ideographic"},
    155246: {"Unified_Ideograph", "Ideographic"},
    155247: {"Unified_Ideograph", "Ideographic"},
    155248: {"Unified_Ideograph", "Ideographic"},
    155249: {"Unified_Ideograph", "Ideographic"},
    155250: {"Unified_Ideograph", "Ideographic"},
    155251: {"Unified_Ideograph", "Ideographic"},
    155252: {"Unified_Ideograph", "Ideographic"},
    155253: {"Unified_Ideograph", "Ideographic"},
    155254: {"Unified_Ideograph", "Ideographic"},
    155255: {"Unified_Ideograph", "Ideographic"},
    155256: {"Unified_Ideograph", "Ideographic"},
    155257: {"Unified_Ideograph", "Ideographic"},
    155258: {"Unified_Ideograph", "Ideographic"},
    155259: {"Unified_Ideograph", "Ideographic"},
    155260: {"Unified_Ideograph", "Ideographic"},
    155261: {"Unified_Ideograph", "Ideographic"},
    155262: {"Unified_Ideograph", "Ideographic"},
    155263: {"Unified_Ideograph", "Ideographic"},
    155264: {"Unified_Ideograph", "Ideographic"},
    155265: {"Unified_Ideograph", "Ideographic"},
    155266: {"Unified_Ideograph", "Ideographic"},
    155267: {"Unified_Ideograph", "Ideographic"},
    155268: {"Unified_Ideograph", "Ideographic"},
    155269: {"Unified_Ideograph", "Ideographic"},
    155270: {"Unified_Ideograph", "Ideographic"},
    155271: {"Unified_Ideograph", "Ideographic"},
    155272: {"Unified_Ideograph", "Ideographic"},
    155273: {"Unified_Ideograph", "Ideographic"},
    155274: {"Unified_Ideograph", "Ideographic"},
    155275: {"Unified_Ideograph", "Ideographic"},
    155276: {"Unified_Ideograph", "Ideographic"},
    155277: {"Unified_Ideograph", "Ideographic"},
    155278: {"Unified_Ideograph", "Ideographic"},
    155279: {"Unified_Ideograph", "Ideographic"},
    155280: {"Unified_Ideograph", "Ideographic"},
    155281: {"Unified_Ideograph", "Ideographic"},
    155282: {"Unified_Ideograph", "Ideographic"},
    155283: {"Unified_Ideograph", "Ideographic"},
    155284: {"Unified_Ideograph", "Ideographic"},
    155285: {"Unified_Ideograph", "Ideographic"},
    155286: {"Unified_Ideograph", "Ideographic"},
    155287: {"Unified_Ideograph", "Ideographic"},
    155288: {"Unified_Ideograph", "Ideographic"},
    155289: {"Unified_Ideograph", "Ideographic"},
    155290: {"Unified_Ideograph", "Ideographic"},
    155291: {"Unified_Ideograph", "Ideographic"},
    155292: {"Unified_Ideograph", "Ideographic"},
    155293: {"Unified_Ideograph", "Ideographic"},
    155294: {"Unified_Ideograph", "Ideographic"},
    155295: {"Unified_Ideograph", "Ideographic"},
    155296: {"Unified_Ideograph", "Ideographic"},
    155297: {"Unified_Ideograph", "Ideographic"},
    155298: {"Unified_Ideograph", "Ideographic"},
    155299: {"Unified_Ideograph", "Ideographic"},
    155300: {"Unified_Ideograph", "Ideographic"},
    155301: {"Unified_Ideograph", "Ideographic"},
    155302: {"Unified_Ideograph", "Ideographic"},
    155303: {"Unified_Ideograph", "Ideographic"},
    155304: {"Unified_Ideograph", "Ideographic"},
    155305: {"Unified_Ideograph", "Ideographic"},
    155306: {"Unified_Ideograph", "Ideographic"},
    155307: {"Unified_Ideograph", "Ideographic"},
    155308: {"Unified_Ideograph", "Ideographic"},
    155309: {"Unified_Ideograph", "Ideographic"},
    155310: {"Unified_Ideograph", "Ideographic"},
    155311: {"Unified_Ideograph", "Ideographic"},
    155312: {"Unified_Ideograph", "Ideographic"},
    155313: {"Unified_Ideograph", "Ideographic"},
    155314: {"Unified_Ideograph", "Ideographic"},
    155315: {"Unified_Ideograph", "Ideographic"},
    155316: {"Unified_Ideograph", "Ideographic"},
    155317: {"Unified_Ideograph", "Ideographic"},
    155318: {"Unified_Ideograph", "Ideographic"},
    155319: {"Unified_Ideograph", "Ideographic"},
    155320: {"Unified_Ideograph", "Ideographic"},
    155321: {"Unified_Ideograph", "Ideographic"},
    155322: {"Unified_Ideograph", "Ideographic"},
    155323: {"Unified_Ideograph", "Ideographic"},
    155324: {"Unified_Ideograph", "Ideographic"},
    155325: {"Unified_Ideograph", "Ideographic"},
    155326: {"Unified_Ideograph", "Ideographic"},
    155327: {"Unified_Ideograph", "Ideographic"},
    155328: {"Unified_Ideograph", "Ideographic"},
    155329: {"Unified_Ideograph", "Ideographic"},
    155330: {"Unified_Ideograph", "Ideographic"},
    155331: {"Unified_Ideograph", "Ideographic"},
    155332: {"Unified_Ideograph", "Ideographic"},
    155333: {"Unified_Ideograph", "Ideographic"},
    155334: {"Unified_Ideograph", "Ideographic"},
    155335: {"Unified_Ideograph", "Ideographic"},
    155336: {"Unified_Ideograph", "Ideographic"},
    155337: {"Unified_Ideograph", "Ideographic"},
    155338: {"Unified_Ideograph", "Ideographic"},
    155339: {"Unified_Ideograph", "Ideographic"},
    155340: {"Unified_Ideograph", "Ideographic"},
    155341: {"Unified_Ideograph", "Ideographic"},
    155342: {"Unified_Ideograph", "Ideographic"},
    155343: {"Unified_Ideograph", "Ideographic"},
    155344: {"Unified_Ideograph", "Ideographic"},
    155345: {"Unified_Ideograph", "Ideographic"},
    155346: {"Unified_Ideograph", "Ideographic"},
    155347: {"Unified_Ideograph", "Ideographic"},
    155348: {"Unified_Ideograph", "Ideographic"},
    155349: {"Unified_Ideograph", "Ideographic"},
    155350: {"Unified_Ideograph", "Ideographic"},
    155351: {"Unified_Ideograph", "Ideographic"},
    155352: {"Unified_Ideograph", "Ideographic"},
    155353: {"Unified_Ideograph", "Ideographic"},
    155354: {"Unified_Ideograph", "Ideographic"},
    155355: {"Unified_Ideograph", "Ideographic"},
    155356: {"Unified_Ideograph", "Ideographic"},
    155357: {"Unified_Ideograph", "Ideographic"},
    155358: {"Unified_Ideograph", "Ideographic"},
    155359: {"Unified_Ideograph", "Ideographic"},
    155360: {"Unified_Ideograph", "Ideographic"},
    155361: {"Unified_Ideograph", "Ideographic"},
    155362: {"Unified_Ideograph", "Ideographic"},
    155363: {"Unified_Ideograph", "Ideographic"},
    155364: {"Unified_Ideograph", "Ideographic"},
    155365: {"Unified_Ideograph", "Ideographic"},
    155366: {"Unified_Ideograph", "Ideographic"},
    155367: {"Unified_Ideograph", "Ideographic"},
    155368: {"Unified_Ideograph", "Ideographic"},
    155369: {"Unified_Ideograph", "Ideographic"},
    155370: {"Unified_Ideograph", "Ideographic"},
    155371: {"Unified_Ideograph", "Ideographic"},
    155372: {"Unified_Ideograph", "Ideographic"},
    155373: {"Unified_Ideograph", "Ideographic"},
    155374: {"Unified_Ideograph", "Ideographic"},
    155375: {"Unified_Ideograph", "Ideographic"},
    155376: {"Unified_Ideograph", "Ideographic"},
    155377: {"Unified_Ideograph", "Ideographic"},
    155378: {"Unified_Ideograph", "Ideographic"},
    155379: {"Unified_Ideograph", "Ideographic"},
    155380: {"Unified_Ideograph", "Ideographic"},
    155381: {"Unified_Ideograph", "Ideographic"},
    155382: {"Unified_Ideograph", "Ideographic"},
    155383: {"Unified_Ideograph", "Ideographic"},
    155384: {"Unified_Ideograph", "Ideographic"},
    155385: {"Unified_Ideograph", "Ideographic"},
    155386: {"Unified_Ideograph", "Ideographic"},
    155387: {"Unified_Ideograph", "Ideographic"},
    155388: {"Unified_Ideograph", "Ideographic"},
    155389: {"Unified_Ideograph", "Ideographic"},
    155390: {"Unified_Ideograph", "Ideographic"},
    155391: {"Unified_Ideograph", "Ideographic"},
    155392: {"Unified_Ideograph", "Ideographic"},
    155393: {"Unified_Ideograph", "Ideographic"},
    155394: {"Unified_Ideograph", "Ideographic"},
    155395: {"Unified_Ideograph", "Ideographic"},
    155396: {"Unified_Ideograph", "Ideographic"},
    155397: {"Unified_Ideograph", "Ideographic"},
    155398: {"Unified_Ideograph", "Ideographic"},
    155399: {"Unified_Ideograph", "Ideographic"},
    155400: {"Unified_Ideograph", "Ideographic"},
    155401: {"Unified_Ideograph", "Ideographic"},
    155402: {"Unified_Ideograph", "Ideographic"},
    155403: {"Unified_Ideograph", "Ideographic"},
    155404: {"Unified_Ideograph", "Ideographic"},
    155405: {"Unified_Ideograph", "Ideographic"},
    155406: {"Unified_Ideograph", "Ideographic"},
    155407: {"Unified_Ideograph", "Ideographic"},
    155408: {"Unified_Ideograph", "Ideographic"},
    155409: {"Unified_Ideograph", "Ideographic"},
    155410: {"Unified_Ideograph", "Ideographic"},
    155411: {"Unified_Ideograph", "Ideographic"},
    155412: {"Unified_Ideograph", "Ideographic"},
    155413: {"Unified_Ideograph", "Ideographic"},
    155414: {"Unified_Ideograph", "Ideographic"},
    155415: {"Unified_Ideograph", "Ideographic"},
    155416: {"Unified_Ideograph", "Ideographic"},
    155417: {"Unified_Ideograph", "Ideographic"},
    155418: {"Unified_Ideograph", "Ideographic"},
    155419: {"Unified_Ideograph", "Ideographic"},
    155420: {"Unified_Ideograph", "Ideographic"},
    155421: {"Unified_Ideograph", "Ideographic"},
    155422: {"Unified_Ideograph", "Ideographic"},
    155423: {"Unified_Ideograph", "Ideographic"},
    155424: {"Unified_Ideograph", "Ideographic"},
    155425: {"Unified_Ideograph", "Ideographic"},
    155426: {"Unified_Ideograph", "Ideographic"},
    155427: {"Unified_Ideograph", "Ideographic"},
    155428: {"Unified_Ideograph", "Ideographic"},
    155429: {"Unified_Ideograph", "Ideographic"},
    155430: {"Unified_Ideograph", "Ideographic"},
    155431: {"Unified_Ideograph", "Ideographic"},
    155432: {"Unified_Ideograph", "Ideographic"},
    155433: {"Unified_Ideograph", "Ideographic"},
    155434: {"Unified_Ideograph", "Ideographic"},
    155435: {"Unified_Ideograph", "Ideographic"},
    155436: {"Unified_Ideograph", "Ideographic"},
    155437: {"Unified_Ideograph", "Ideographic"},
    155438: {"Unified_Ideograph", "Ideographic"},
    155439: {"Unified_Ideograph", "Ideographic"},
    155440: {"Unified_Ideograph", "Ideographic"},
    155441: {"Unified_Ideograph", "Ideographic"},
    155442: {"Unified_Ideograph", "Ideographic"},
    155443: {"Unified_Ideograph", "Ideographic"},
    155444: {"Unified_Ideograph", "Ideographic"},
    155445: {"Unified_Ideograph", "Ideographic"},
    155446: {"Unified_Ideograph", "Ideographic"},
    155447: {"Unified_Ideograph", "Ideographic"},
    155448: {"Unified_Ideograph", "Ideographic"},
    155449: {"Unified_Ideograph", "Ideographic"},
    155450: {"Unified_Ideograph", "Ideographic"},
    155451: {"Unified_Ideograph", "Ideographic"},
    155452: {"Unified_Ideograph", "Ideographic"},
    155453: {"Unified_Ideograph", "Ideographic"},
    155454: {"Unified_Ideograph", "Ideographic"},
    155455: {"Unified_Ideograph", "Ideographic"},
    155456: {"Unified_Ideograph", "Ideographic"},
    155457: {"Unified_Ideograph", "Ideographic"},
    155458: {"Unified_Ideograph", "Ideographic"},
    155459: {"Unified_Ideograph", "Ideographic"},
    155460: {"Unified_Ideograph", "Ideographic"},
    155461: {"Unified_Ideograph", "Ideographic"},
    155462: {"Unified_Ideograph", "Ideographic"},
    155463: {"Unified_Ideograph", "Ideographic"},
    155464: {"Unified_Ideograph", "Ideographic"},
    155465: {"Unified_Ideograph", "Ideographic"},
    155466: {"Unified_Ideograph", "Ideographic"},
    155467: {"Unified_Ideograph", "Ideographic"},
    155468: {"Unified_Ideograph", "Ideographic"},
    155469: {"Unified_Ideograph", "Ideographic"},
    155470: {"Unified_Ideograph", "Ideographic"},
    155471: {"Unified_Ideograph", "Ideographic"},
    155472: {"Unified_Ideograph", "Ideographic"},
    155473: {"Unified_Ideograph", "Ideographic"},
    155474: {"Unified_Ideograph", "Ideographic"},
    155475: {"Unified_Ideograph", "Ideographic"},
    155476: {"Unified_Ideograph", "Ideographic"},
    155477: {"Unified_Ideograph", "Ideographic"},
    155478: {"Unified_Ideograph", "Ideographic"},
    155479: {"Unified_Ideograph", "Ideographic"},
    155480: {"Unified_Ideograph", "Ideographic"},
    155481: {"Unified_Ideograph", "Ideographic"},
    155482: {"Unified_Ideograph", "Ideographic"},
    155483: {"Unified_Ideograph", "Ideographic"},
    155484: {"Unified_Ideograph", "Ideographic"},
    155485: {"Unified_Ideograph", "Ideographic"},
    155486: {"Unified_Ideograph", "Ideographic"},
    155487: {"Unified_Ideograph", "Ideographic"},
    155488: {"Unified_Ideograph", "Ideographic"},
    155489: {"Unified_Ideograph", "Ideographic"},
    155490: {"Unified_Ideograph", "Ideographic"},
    155491: {"Unified_Ideograph", "Ideographic"},
    155492: {"Unified_Ideograph", "Ideographic"},
    155493: {"Unified_Ideograph", "Ideographic"},
    155494: {"Unified_Ideograph", "Ideographic"},
    155495: {"Unified_Ideograph", "Ideographic"},
    155496: {"Unified_Ideograph", "Ideographic"},
    155497: {"Unified_Ideograph", "Ideographic"},
    155498: {"Unified_Ideograph", "Ideographic"},
    155499: {"Unified_Ideograph", "Ideographic"},
    155500: {"Unified_Ideograph", "Ideographic"},
    155501: {"Unified_Ideograph", "Ideographic"},
    155502: {"Unified_Ideograph", "Ideographic"},
    155503: {"Unified_Ideograph", "Ideographic"},
    155504: {"Unified_Ideograph", "Ideographic"},
    155505: {"Unified_Ideograph", "Ideographic"},
    155506: {"Unified_Ideograph", "Ideographic"},
    155507: {"Unified_Ideograph", "Ideographic"},
    155508: {"Unified_Ideograph", "Ideographic"},
    155509: {"Unified_Ideograph", "Ideographic"},
    155510: {"Unified_Ideograph", "Ideographic"},
    155511: {"Unified_Ideograph", "Ideographic"},
    155512: {"Unified_Ideograph", "Ideographic"},
    155513: {"Unified_Ideograph", "Ideographic"},
    155514: {"Unified_Ideograph", "Ideographic"},
    155515: {"Unified_Ideograph", "Ideographic"},
    155516: {"Unified_Ideograph", "Ideographic"},
    155517: {"Unified_Ideograph", "Ideographic"},
    155518: {"Unified_Ideograph", "Ideographic"},
    155519: {"Unified_Ideograph", "Ideographic"},
    155520: {"Unified_Ideograph", "Ideographic"},
    155521: {"Unified_Ideograph", "Ideographic"},
    155522: {"Unified_Ideograph", "Ideographic"},
    155523: {"Unified_Ideograph", "Ideographic"},
    155524: {"Unified_Ideograph", "Ideographic"},
    155525: {"Unified_Ideograph", "Ideographic"},
    155526: {"Unified_Ideograph", "Ideographic"},
    155527: {"Unified_Ideograph", "Ideographic"},
    155528: {"Unified_Ideograph", "Ideographic"},
    155529: {"Unified_Ideograph", "Ideographic"},
    155530: {"Unified_Ideograph", "Ideographic"},
    155531: {"Unified_Ideograph", "Ideographic"},
    155532: {"Unified_Ideograph", "Ideographic"},
    155533: {"Unified_Ideograph", "Ideographic"},
    155534: {"Unified_Ideograph", "Ideographic"},
    155535: {"Unified_Ideograph", "Ideographic"},
    155536: {"Unified_Ideograph", "Ideographic"},
    155537: {"Unified_Ideograph", "Ideographic"},
    155538: {"Unified_Ideograph", "Ideographic"},
    155539: {"Unified_Ideograph", "Ideographic"},
    155540: {"Unified_Ideograph", "Ideographic"},
    155541: {"Unified_Ideograph", "Ideographic"},
    155542: {"Unified_Ideograph", "Ideographic"},
    155543: {"Unified_Ideograph", "Ideographic"},
    155544: {"Unified_Ideograph", "Ideographic"},
    155545: {"Unified_Ideograph", "Ideographic"},
    155546: {"Unified_Ideograph", "Ideographic"},
    155547: {"Unified_Ideograph", "Ideographic"},
    155548: {"Unified_Ideograph", "Ideographic"},
    155549: {"Unified_Ideograph", "Ideographic"},
    155550: {"Unified_Ideograph", "Ideographic"},
    155551: {"Unified_Ideograph", "Ideographic"},
    155552: {"Unified_Ideograph", "Ideographic"},
    155553: {"Unified_Ideograph", "Ideographic"},
    155554: {"Unified_Ideograph", "Ideographic"},
    155555: {"Unified_Ideograph", "Ideographic"},
    155556: {"Unified_Ideograph", "Ideographic"},
    155557: {"Unified_Ideograph", "Ideographic"},
    155558: {"Unified_Ideograph", "Ideographic"},
    155559: {"Unified_Ideograph", "Ideographic"},
    155560: {"Unified_Ideograph", "Ideographic"},
    155561: {"Unified_Ideograph", "Ideographic"},
    155562: {"Unified_Ideograph", "Ideographic"},
    155563: {"Unified_Ideograph", "Ideographic"},
    155564: {"Unified_Ideograph", "Ideographic"},
    155565: {"Unified_Ideograph", "Ideographic"},
    155566: {"Unified_Ideograph", "Ideographic"},
    155567: {"Unified_Ideograph", "Ideographic"},
    155568: {"Unified_Ideograph", "Ideographic"},
    155569: {"Unified_Ideograph", "Ideographic"},
    155570: {"Unified_Ideograph", "Ideographic"},
    155571: {"Unified_Ideograph", "Ideographic"},
    155572: {"Unified_Ideograph", "Ideographic"},
    155573: {"Unified_Ideograph", "Ideographic"},
    155574: {"Unified_Ideograph", "Ideographic"},
    155575: {"Unified_Ideograph", "Ideographic"},
    155576: {"Unified_Ideograph", "Ideographic"},
    155577: {"Unified_Ideograph", "Ideographic"},
    155578: {"Unified_Ideograph", "Ideographic"},
    155579: {"Unified_Ideograph", "Ideographic"},
    155580: {"Unified_Ideograph", "Ideographic"},
    155581: {"Unified_Ideograph", "Ideographic"},
    155582: {"Unified_Ideograph", "Ideographic"},
    155583: {"Unified_Ideograph", "Ideographic"},
    155584: {"Unified_Ideograph", "Ideographic"},
    155585: {"Unified_Ideograph", "Ideographic"},
    155586: {"Unified_Ideograph", "Ideographic"},
    155587: {"Unified_Ideograph", "Ideographic"},
    155588: {"Unified_Ideograph", "Ideographic"},
    155589: {"Unified_Ideograph", "Ideographic"},
    155590: {"Unified_Ideograph", "Ideographic"},
    155591: {"Unified_Ideograph", "Ideographic"},
    155592: {"Unified_Ideograph", "Ideographic"},
    155593: {"Unified_Ideograph", "Ideographic"},
    155594: {"Unified_Ideograph", "Ideographic"},
    155595: {"Unified_Ideograph", "Ideographic"},
    155596: {"Unified_Ideograph", "Ideographic"},
    155597: {"Unified_Ideograph", "Ideographic"},
    155598: {"Unified_Ideograph", "Ideographic"},
    155599: {"Unified_Ideograph", "Ideographic"},
    155600: {"Unified_Ideograph", "Ideographic"},
    155601: {"Unified_Ideograph", "Ideographic"},
    155602: {"Unified_Ideograph", "Ideographic"},
    155603: {"Unified_Ideograph", "Ideographic"},
    155604: {"Unified_Ideograph", "Ideographic"},
    155605: {"Unified_Ideograph", "Ideographic"},
    155606: {"Unified_Ideograph", "Ideographic"},
    155607: {"Unified_Ideograph", "Ideographic"},
    155608: {"Unified_Ideograph", "Ideographic"},
    155609: {"Unified_Ideograph", "Ideographic"},
    155610: {"Unified_Ideograph", "Ideographic"},
    155611: {"Unified_Ideograph", "Ideographic"},
    155612: {"Unified_Ideograph", "Ideographic"},
    155613: {"Unified_Ideograph", "Ideographic"},
    155614: {"Unified_Ideograph", "Ideographic"},
    155615: {"Unified_Ideograph", "Ideographic"},
    155616: {"Unified_Ideograph", "Ideographic"},
    155617: {"Unified_Ideograph", "Ideographic"},
    155618: {"Unified_Ideograph", "Ideographic"},
    155619: {"Unified_Ideograph", "Ideographic"},
    155620: {"Unified_Ideograph", "Ideographic"},
    155621: {"Unified_Ideograph", "Ideographic"},
    155622: {"Unified_Ideograph", "Ideographic"},
    155623: {"Unified_Ideograph", "Ideographic"},
    155624: {"Unified_Ideograph", "Ideographic"},
    155625: {"Unified_Ideograph", "Ideographic"},
    155626: {"Unified_Ideograph", "Ideographic"},
    155627: {"Unified_Ideograph", "Ideographic"},
    155628: {"Unified_Ideograph", "Ideographic"},
    155629: {"Unified_Ideograph", "Ideographic"},
    155630: {"Unified_Ideograph", "Ideographic"},
    155631: {"Unified_Ideograph", "Ideographic"},
    155632: {"Unified_Ideograph", "Ideographic"},
    155633: {"Unified_Ideograph", "Ideographic"},
    155634: {"Unified_Ideograph", "Ideographic"},
    155635: {"Unified_Ideograph", "Ideographic"},
    155636: {"Unified_Ideograph", "Ideographic"},
    155637: {"Unified_Ideograph", "Ideographic"},
    155638: {"Unified_Ideograph", "Ideographic"},
    155639: {"Unified_Ideograph", "Ideographic"},
    155640: {"Unified_Ideograph", "Ideographic"},
    155641: {"Unified_Ideograph", "Ideographic"},
    155642: {"Unified_Ideograph", "Ideographic"},
    155643: {"Unified_Ideograph", "Ideographic"},
    155644: {"Unified_Ideograph", "Ideographic"},
    155645: {"Unified_Ideograph", "Ideographic"},
    155646: {"Unified_Ideograph", "Ideographic"},
    155647: {"Unified_Ideograph", "Ideographic"},
    155648: {"Unified_Ideograph", "Ideographic"},
    155649: {"Unified_Ideograph", "Ideographic"},
    155650: {"Unified_Ideograph", "Ideographic"},
    155651: {"Unified_Ideograph", "Ideographic"},
    155652: {"Unified_Ideograph", "Ideographic"},
    155653: {"Unified_Ideograph", "Ideographic"},
    155654: {"Unified_Ideograph", "Ideographic"},
    155655: {"Unified_Ideograph", "Ideographic"},
    155656: {"Unified_Ideograph", "Ideographic"},
    155657: {"Unified_Ideograph", "Ideographic"},
    155658: {"Unified_Ideograph", "Ideographic"},
    155659: {"Unified_Ideograph", "Ideographic"},
    155660: {"Unified_Ideograph", "Ideographic"},
    155661: {"Unified_Ideograph", "Ideographic"},
    155662: {"Unified_Ideograph", "Ideographic"},
    155663: {"Unified_Ideograph", "Ideographic"},
    155664: {"Unified_Ideograph", "Ideographic"},
    155665: {"Unified_Ideograph", "Ideographic"},
    155666: {"Unified_Ideograph", "Ideographic"},
    155667: {"Unified_Ideograph", "Ideographic"},
    155668: {"Unified_Ideograph", "Ideographic"},
    155669: {"Unified_Ideograph", "Ideographic"},
    155670: {"Unified_Ideograph", "Ideographic"},
    155671: {"Unified_Ideograph", "Ideographic"},
    155672: {"Unified_Ideograph", "Ideographic"},
    155673: {"Unified_Ideograph", "Ideographic"},
    155674: {"Unified_Ideograph", "Ideographic"},
    155675: {"Unified_Ideograph", "Ideographic"},
    155676: {"Unified_Ideograph", "Ideographic"},
    155677: {"Unified_Ideograph", "Ideographic"},
    155678: {"Unified_Ideograph", "Ideographic"},
    155679: {"Unified_Ideograph", "Ideographic"},
    155680: {"Unified_Ideograph", "Ideographic"},
    155681: {"Unified_Ideograph", "Ideographic"},
    155682: {"Unified_Ideograph", "Ideographic"},
    155683: {"Unified_Ideograph", "Ideographic"},
    155684: {"Unified_Ideograph", "Ideographic"},
    155685: {"Unified_Ideograph", "Ideographic"},
    155686: {"Unified_Ideograph", "Ideographic"},
    155687: {"Unified_Ideograph", "Ideographic"},
    155688: {"Unified_Ideograph", "Ideographic"},
    155689: {"Unified_Ideograph", "Ideographic"},
    155690: {"Unified_Ideograph", "Ideographic"},
    155691: {"Unified_Ideograph", "Ideographic"},
    155692: {"Unified_Ideograph", "Ideographic"},
    155693: {"Unified_Ideograph", "Ideographic"},
    155694: {"Unified_Ideograph", "Ideographic"},
    155695: {"Unified_Ideograph", "Ideographic"},
    155696: {"Unified_Ideograph", "Ideographic"},
    155697: {"Unified_Ideograph", "Ideographic"},
    155698: {"Unified_Ideograph", "Ideographic"},
    155699: {"Unified_Ideograph", "Ideographic"},
    155700: {"Unified_Ideograph", "Ideographic"},
    155701: {"Unified_Ideograph", "Ideographic"},
    155702: {"Unified_Ideograph", "Ideographic"},
    155703: {"Unified_Ideograph", "Ideographic"},
    155704: {"Unified_Ideograph", "Ideographic"},
    155705: {"Unified_Ideograph", "Ideographic"},
    155706: {"Unified_Ideograph", "Ideographic"},
    155707: {"Unified_Ideograph", "Ideographic"},
    155708: {"Unified_Ideograph", "Ideographic"},
    155709: {"Unified_Ideograph", "Ideographic"},
    155710: {"Unified_Ideograph", "Ideographic"},
    155711: {"Unified_Ideograph", "Ideographic"},
    155712: {"Unified_Ideograph", "Ideographic"},
    155713: {"Unified_Ideograph", "Ideographic"},
    155714: {"Unified_Ideograph", "Ideographic"},
    155715: {"Unified_Ideograph", "Ideographic"},
    155716: {"Unified_Ideograph", "Ideographic"},
    155717: {"Unified_Ideograph", "Ideographic"},
    155718: {"Unified_Ideograph", "Ideographic"},
    155719: {"Unified_Ideograph", "Ideographic"},
    155720: {"Unified_Ideograph", "Ideographic"},
    155721: {"Unified_Ideograph", "Ideographic"},
    155722: {"Unified_Ideograph", "Ideographic"},
    155723: {"Unified_Ideograph", "Ideographic"},
    155724: {"Unified_Ideograph", "Ideographic"},
    155725: {"Unified_Ideograph", "Ideographic"},
    155726: {"Unified_Ideograph", "Ideographic"},
    155727: {"Unified_Ideograph", "Ideographic"},
    155728: {"Unified_Ideograph", "Ideographic"},
    155729: {"Unified_Ideograph", "Ideographic"},
    155730: {"Unified_Ideograph", "Ideographic"},
    155731: {"Unified_Ideograph", "Ideographic"},
    155732: {"Unified_Ideograph", "Ideographic"},
    155733: {"Unified_Ideograph", "Ideographic"},
    155734: {"Unified_Ideograph", "Ideographic"},
    155735: {"Unified_Ideograph", "Ideographic"},
    155736: {"Unified_Ideograph", "Ideographic"},
    155737: {"Unified_Ideograph", "Ideographic"},
    155738: {"Unified_Ideograph", "Ideographic"},
    155739: {"Unified_Ideograph", "Ideographic"},
    155740: {"Unified_Ideograph", "Ideographic"},
    155741: {"Unified_Ideograph", "Ideographic"},
    155742: {"Unified_Ideograph", "Ideographic"},
    155743: {"Unified_Ideograph", "Ideographic"},
    155744: {"Unified_Ideograph", "Ideographic"},
    155745: {"Unified_Ideograph", "Ideographic"},
    155746: {"Unified_Ideograph", "Ideographic"},
    155747: {"Unified_Ideograph", "Ideographic"},
    155748: {"Unified_Ideograph", "Ideographic"},
    155749: {"Unified_Ideograph", "Ideographic"},
    155750: {"Unified_Ideograph", "Ideographic"},
    155751: {"Unified_Ideograph", "Ideographic"},
    155752: {"Unified_Ideograph", "Ideographic"},
    155753: {"Unified_Ideograph", "Ideographic"},
    155754: {"Unified_Ideograph", "Ideographic"},
    155755: {"Unified_Ideograph", "Ideographic"},
    155756: {"Unified_Ideograph", "Ideographic"},
    155757: {"Unified_Ideograph", "Ideographic"},
    155758: {"Unified_Ideograph", "Ideographic"},
    155759: {"Unified_Ideograph", "Ideographic"},
    155760: {"Unified_Ideograph", "Ideographic"},
    155761: {"Unified_Ideograph", "Ideographic"},
    155762: {"Unified_Ideograph", "Ideographic"},
    155763: {"Unified_Ideograph", "Ideographic"},
    155764: {"Unified_Ideograph", "Ideographic"},
    155765: {"Unified_Ideograph", "Ideographic"},
    155766: {"Unified_Ideograph", "Ideographic"},
    155767: {"Unified_Ideograph", "Ideographic"},
    155768: {"Unified_Ideograph", "Ideographic"},
    155769: {"Unified_Ideograph", "Ideographic"},
    155770: {"Unified_Ideograph", "Ideographic"},
    155771: {"Unified_Ideograph", "Ideographic"},
    155772: {"Unified_Ideograph", "Ideographic"},
    155773: {"Unified_Ideograph", "Ideographic"},
    155774: {"Unified_Ideograph", "Ideographic"},
    155775: {"Unified_Ideograph", "Ideographic"},
    155776: {"Unified_Ideograph", "Ideographic"},
    155777: {"Unified_Ideograph", "Ideographic"},
    155778: {"Unified_Ideograph", "Ideographic"},
    155779: {"Unified_Ideograph", "Ideographic"},
    155780: {"Unified_Ideograph", "Ideographic"},
    155781: {"Unified_Ideograph", "Ideographic"},
    155782: {"Unified_Ideograph", "Ideographic"},
    155783: {"Unified_Ideograph", "Ideographic"},
    155784: {"Unified_Ideograph", "Ideographic"},
    155785: {"Unified_Ideograph", "Ideographic"},
    155786: {"Unified_Ideograph", "Ideographic"},
    155787: {"Unified_Ideograph", "Ideographic"},
    155788: {"Unified_Ideograph", "Ideographic"},
    155789: {"Unified_Ideograph", "Ideographic"},
    155790: {"Unified_Ideograph", "Ideographic"},
    155791: {"Unified_Ideograph", "Ideographic"},
    155792: {"Unified_Ideograph", "Ideographic"},
    155793: {"Unified_Ideograph", "Ideographic"},
    155794: {"Unified_Ideograph", "Ideographic"},
    155795: {"Unified_Ideograph", "Ideographic"},
    155796: {"Unified_Ideograph", "Ideographic"},
    155797: {"Unified_Ideograph", "Ideographic"},
    155798: {"Unified_Ideograph", "Ideographic"},
    155799: {"Unified_Ideograph", "Ideographic"},
    155800: {"Unified_Ideograph", "Ideographic"},
    155801: {"Unified_Ideograph", "Ideographic"},
    155802: {"Unified_Ideograph", "Ideographic"},
    155803: {"Unified_Ideograph", "Ideographic"},
    155804: {"Unified_Ideograph", "Ideographic"},
    155805: {"Unified_Ideograph", "Ideographic"},
    155806: {"Unified_Ideograph", "Ideographic"},
    155807: {"Unified_Ideograph", "Ideographic"},
    155808: {"Unified_Ideograph", "Ideographic"},
    155809: {"Unified_Ideograph", "Ideographic"},
    155810: {"Unified_Ideograph", "Ideographic"},
    155811: {"Unified_Ideograph", "Ideographic"},
    155812: {"Unified_Ideograph", "Ideographic"},
    155813: {"Unified_Ideograph", "Ideographic"},
    155814: {"Unified_Ideograph", "Ideographic"},
    155815: {"Unified_Ideograph", "Ideographic"},
    155816: {"Unified_Ideograph", "Ideographic"},
    155817: {"Unified_Ideograph", "Ideographic"},
    155818: {"Unified_Ideograph", "Ideographic"},
    155819: {"Unified_Ideograph", "Ideographic"},
    155820: {"Unified_Ideograph", "Ideographic"},
    155821: {"Unified_Ideograph", "Ideographic"},
    155822: {"Unified_Ideograph", "Ideographic"},
    155823: {"Unified_Ideograph", "Ideographic"},
    155824: {"Unified_Ideograph", "Ideographic"},
    155825: {"Unified_Ideograph", "Ideographic"},
    155826: {"Unified_Ideograph", "Ideographic"},
    155827: {"Unified_Ideograph", "Ideographic"},
    155828: {"Unified_Ideograph", "Ideographic"},
    155829: {"Unified_Ideograph", "Ideographic"},
    155830: {"Unified_Ideograph", "Ideographic"},
    155831: {"Unified_Ideograph", "Ideographic"},
    155832: {"Unified_Ideograph", "Ideographic"},
    155833: {"Unified_Ideograph", "Ideographic"},
    155834: {"Unified_Ideograph", "Ideographic"},
    155835: {"Unified_Ideograph", "Ideographic"},
    155836: {"Unified_Ideograph", "Ideographic"},
    155837: {"Unified_Ideograph", "Ideographic"},
    155838: {"Unified_Ideograph", "Ideographic"},
    155839: {"Unified_Ideograph", "Ideographic"},
    155840: {"Unified_Ideograph", "Ideographic"},
    155841: {"Unified_Ideograph", "Ideographic"},
    155842: {"Unified_Ideograph", "Ideographic"},
    155843: {"Unified_Ideograph", "Ideographic"},
    155844: {"Unified_Ideograph", "Ideographic"},
    155845: {"Unified_Ideograph", "Ideographic"},
    155846: {"Unified_Ideograph", "Ideographic"},
    155847: {"Unified_Ideograph", "Ideographic"},
    155848: {"Unified_Ideograph", "Ideographic"},
    155849: {"Unified_Ideograph", "Ideographic"},
    155850: {"Unified_Ideograph", "Ideographic"},
    155851: {"Unified_Ideograph", "Ideographic"},
    155852: {"Unified_Ideograph", "Ideographic"},
    155853: {"Unified_Ideograph", "Ideographic"},
    155854: {"Unified_Ideograph", "Ideographic"},
    155855: {"Unified_Ideograph", "Ideographic"},
    155856: {"Unified_Ideograph", "Ideographic"},
    155857: {"Unified_Ideograph", "Ideographic"},
    155858: {"Unified_Ideograph", "Ideographic"},
    155859: {"Unified_Ideograph", "Ideographic"},
    155860: {"Unified_Ideograph", "Ideographic"},
    155861: {"Unified_Ideograph", "Ideographic"},
    155862: {"Unified_Ideograph", "Ideographic"},
    155863: {"Unified_Ideograph", "Ideographic"},
    155864: {"Unified_Ideograph", "Ideographic"},
    155865: {"Unified_Ideograph", "Ideographic"},
    155866: {"Unified_Ideograph", "Ideographic"},
    155867: {"Unified_Ideograph", "Ideographic"},
    155868: {"Unified_Ideograph", "Ideographic"},
    155869: {"Unified_Ideograph", "Ideographic"},
    155870: {"Unified_Ideograph", "Ideographic"},
    155871: {"Unified_Ideograph", "Ideographic"},
    155872: {"Unified_Ideograph", "Ideographic"},
    155873: {"Unified_Ideograph", "Ideographic"},
    155874: {"Unified_Ideograph", "Ideographic"},
    155875: {"Unified_Ideograph", "Ideographic"},
    155876: {"Unified_Ideograph", "Ideographic"},
    155877: {"Unified_Ideograph", "Ideographic"},
    155878: {"Unified_Ideograph", "Ideographic"},
    155879: {"Unified_Ideograph", "Ideographic"},
    155880: {"Unified_Ideograph", "Ideographic"},
    155881: {"Unified_Ideograph", "Ideographic"},
    155882: {"Unified_Ideograph", "Ideographic"},
    155883: {"Unified_Ideograph", "Ideographic"},
    155884: {"Unified_Ideograph", "Ideographic"},
    155885: {"Unified_Ideograph", "Ideographic"},
    155886: {"Unified_Ideograph", "Ideographic"},
    155887: {"Unified_Ideograph", "Ideographic"},
    155888: {"Unified_Ideograph", "Ideographic"},
    155889: {"Unified_Ideograph", "Ideographic"},
    155890: {"Unified_Ideograph", "Ideographic"},
    155891: {"Unified_Ideograph", "Ideographic"},
    155892: {"Unified_Ideograph", "Ideographic"},
    155893: {"Unified_Ideograph", "Ideographic"},
    155894: {"Unified_Ideograph", "Ideographic"},
    155895: {"Unified_Ideograph", "Ideographic"},
    155896: {"Unified_Ideograph", "Ideographic"},
    155897: {"Unified_Ideograph", "Ideographic"},
    155898: {"Unified_Ideograph", "Ideographic"},
    155899: {"Unified_Ideograph", "Ideographic"},
    155900: {"Unified_Ideograph", "Ideographic"},
    155901: {"Unified_Ideograph", "Ideographic"},
    155902: {"Unified_Ideograph", "Ideographic"},
    155903: {"Unified_Ideograph", "Ideographic"},
    155904: {"Unified_Ideograph", "Ideographic"},
    155905: {"Unified_Ideograph", "Ideographic"},
    155906: {"Unified_Ideograph", "Ideographic"},
    155907: {"Unified_Ideograph", "Ideographic"},
    155908: {"Unified_Ideograph", "Ideographic"},
    155909: {"Unified_Ideograph", "Ideographic"},
    155910: {"Unified_Ideograph", "Ideographic"},
    155911: {"Unified_Ideograph", "Ideographic"},
    155912: {"Unified_Ideograph", "Ideographic"},
    155913: {"Unified_Ideograph", "Ideographic"},
    155914: {"Unified_Ideograph", "Ideographic"},
    155915: {"Unified_Ideograph", "Ideographic"},
    155916: {"Unified_Ideograph", "Ideographic"},
    155917: {"Unified_Ideograph", "Ideographic"},
    155918: {"Unified_Ideograph", "Ideographic"},
    155919: {"Unified_Ideograph", "Ideographic"},
    155920: {"Unified_Ideograph", "Ideographic"},
    155921: {"Unified_Ideograph", "Ideographic"},
    155922: {"Unified_Ideograph", "Ideographic"},
    155923: {"Unified_Ideograph", "Ideographic"},
    155924: {"Unified_Ideograph", "Ideographic"},
    155925: {"Unified_Ideograph", "Ideographic"},
    155926: {"Unified_Ideograph", "Ideographic"},
    155927: {"Unified_Ideograph", "Ideographic"},
    155928: {"Unified_Ideograph", "Ideographic"},
    155929: {"Unified_Ideograph", "Ideographic"},
    155930: {"Unified_Ideograph", "Ideographic"},
    155931: {"Unified_Ideograph", "Ideographic"},
    155932: {"Unified_Ideograph", "Ideographic"},
    155933: {"Unified_Ideograph", "Ideographic"},
    155934: {"Unified_Ideograph", "Ideographic"},
    155935: {"Unified_Ideograph", "Ideographic"},
    155936: {"Unified_Ideograph", "Ideographic"},
    155937: {"Unified_Ideograph", "Ideographic"},
    155938: {"Unified_Ideograph", "Ideographic"},
    155939: {"Unified_Ideograph", "Ideographic"},
    155940: {"Unified_Ideograph", "Ideographic"},
    155941: {"Unified_Ideograph", "Ideographic"},
    155942: {"Unified_Ideograph", "Ideographic"},
    155943: {"Unified_Ideograph", "Ideographic"},
    155944: {"Unified_Ideograph", "Ideographic"},
    155945: {"Unified_Ideograph", "Ideographic"},
    155946: {"Unified_Ideograph", "Ideographic"},
    155947: {"Unified_Ideograph", "Ideographic"},
    155948: {"Unified_Ideograph", "Ideographic"},
    155949: {"Unified_Ideograph", "Ideographic"},
    155950: {"Unified_Ideograph", "Ideographic"},
    155951: {"Unified_Ideograph", "Ideographic"},
    155952: {"Unified_Ideograph", "Ideographic"},
    155953: {"Unified_Ideograph", "Ideographic"},
    155954: {"Unified_Ideograph", "Ideographic"},
    155955: {"Unified_Ideograph", "Ideographic"},
    155956: {"Unified_Ideograph", "Ideographic"},
    155957: {"Unified_Ideograph", "Ideographic"},
    155958: {"Unified_Ideograph", "Ideographic"},
    155959: {"Unified_Ideograph", "Ideographic"},
    155960: {"Unified_Ideograph", "Ideographic"},
    155961: {"Unified_Ideograph", "Ideographic"},
    155962: {"Unified_Ideograph", "Ideographic"},
    155963: {"Unified_Ideograph", "Ideographic"},
    155964: {"Unified_Ideograph", "Ideographic"},
    155965: {"Unified_Ideograph", "Ideographic"},
    155966: {"Unified_Ideograph", "Ideographic"},
    155967: {"Unified_Ideograph", "Ideographic"},
    155968: {"Unified_Ideograph", "Ideographic"},
    155969: {"Unified_Ideograph", "Ideographic"},
    155970: {"Unified_Ideograph", "Ideographic"},
    155971: {"Unified_Ideograph", "Ideographic"},
    155972: {"Unified_Ideograph", "Ideographic"},
    155973: {"Unified_Ideograph", "Ideographic"},
    155974: {"Unified_Ideograph", "Ideographic"},
    155975: {"Unified_Ideograph", "Ideographic"},
    155976: {"Unified_Ideograph", "Ideographic"},
    155977: {"Unified_Ideograph", "Ideographic"},
    155978: {"Unified_Ideograph", "Ideographic"},
    155979: {"Unified_Ideograph", "Ideographic"},
    155980: {"Unified_Ideograph", "Ideographic"},
    155981: {"Unified_Ideograph", "Ideographic"},
    155982: {"Unified_Ideograph", "Ideographic"},
    155983: {"Unified_Ideograph", "Ideographic"},
    155984: {"Unified_Ideograph", "Ideographic"},
    155985: {"Unified_Ideograph", "Ideographic"},
    155986: {"Unified_Ideograph", "Ideographic"},
    155987: {"Unified_Ideograph", "Ideographic"},
    155988: {"Unified_Ideograph", "Ideographic"},
    155989: {"Unified_Ideograph", "Ideographic"},
    155990: {"Unified_Ideograph", "Ideographic"},
    155991: {"Unified_Ideograph", "Ideographic"},
    155992: {"Unified_Ideograph", "Ideographic"},
    155993: {"Unified_Ideograph", "Ideographic"},
    155994: {"Unified_Ideograph", "Ideographic"},
    155995: {"Unified_Ideograph", "Ideographic"},
    155996: {"Unified_Ideograph", "Ideographic"},
    155997: {"Unified_Ideograph", "Ideographic"},
    155998: {"Unified_Ideograph", "Ideographic"},
    155999: {"Unified_Ideograph", "Ideographic"},
    156000: {"Unified_Ideograph", "Ideographic"},
    156001: {"Unified_Ideograph", "Ideographic"},
    156002: {"Unified_Ideograph", "Ideographic"},
    156003: {"Unified_Ideograph", "Ideographic"},
    156004: {"Unified_Ideograph", "Ideographic"},
    156005: {"Unified_Ideograph", "Ideographic"},
    156006: {"Unified_Ideograph", "Ideographic"},
    156007: {"Unified_Ideograph", "Ideographic"},
    156008: {"Unified_Ideograph", "Ideographic"},
    156009: {"Unified_Ideograph", "Ideographic"},
    156010: {"Unified_Ideograph", "Ideographic"},
    156011: {"Unified_Ideograph", "Ideographic"},
    156012: {"Unified_Ideograph", "Ideographic"},
    156013: {"Unified_Ideograph", "Ideographic"},
    156014: {"Unified_Ideograph", "Ideographic"},
    156015: {"Unified_Ideograph", "Ideographic"},
    156016: {"Unified_Ideograph", "Ideographic"},
    156017: {"Unified_Ideograph", "Ideographic"},
    156018: {"Unified_Ideograph", "Ideographic"},
    156019: {"Unified_Ideograph", "Ideographic"},
    156020: {"Unified_Ideograph", "Ideographic"},
    156021: {"Unified_Ideograph", "Ideographic"},
    156022: {"Unified_Ideograph", "Ideographic"},
    156023: {"Unified_Ideograph", "Ideographic"},
    156024: {"Unified_Ideograph", "Ideographic"},
    156025: {"Unified_Ideograph", "Ideographic"},
    156026: {"Unified_Ideograph", "Ideographic"},
    156027: {"Unified_Ideograph", "Ideographic"},
    156028: {"Unified_Ideograph", "Ideographic"},
    156029: {"Unified_Ideograph", "Ideographic"},
    156030: {"Unified_Ideograph", "Ideographic"},
    156031: {"Unified_Ideograph", "Ideographic"},
    156032: {"Unified_Ideograph", "Ideographic"},
    156033: {"Unified_Ideograph", "Ideographic"},
    156034: {"Unified_Ideograph", "Ideographic"},
    156035: {"Unified_Ideograph", "Ideographic"},
    156036: {"Unified_Ideograph", "Ideographic"},
    156037: {"Unified_Ideograph", "Ideographic"},
    156038: {"Unified_Ideograph", "Ideographic"},
    156039: {"Unified_Ideograph", "Ideographic"},
    156040: {"Unified_Ideograph", "Ideographic"},
    156041: {"Unified_Ideograph", "Ideographic"},
    156042: {"Unified_Ideograph", "Ideographic"},
    156043: {"Unified_Ideograph", "Ideographic"},
    156044: {"Unified_Ideograph", "Ideographic"},
    156045: {"Unified_Ideograph", "Ideographic"},
    156046: {"Unified_Ideograph", "Ideographic"},
    156047: {"Unified_Ideograph", "Ideographic"},
    156048: {"Unified_Ideograph", "Ideographic"},
    156049: {"Unified_Ideograph", "Ideographic"},
    156050: {"Unified_Ideograph", "Ideographic"},
    156051: {"Unified_Ideograph", "Ideographic"},
    156052: {"Unified_Ideograph", "Ideographic"},
    156053: {"Unified_Ideograph", "Ideographic"},
    156054: {"Unified_Ideograph", "Ideographic"},
    156055: {"Unified_Ideograph", "Ideographic"},
    156056: {"Unified_Ideograph", "Ideographic"},
    156057: {"Unified_Ideograph", "Ideographic"},
    156058: {"Unified_Ideograph", "Ideographic"},
    156059: {"Unified_Ideograph", "Ideographic"},
    156060: {"Unified_Ideograph", "Ideographic"},
    156061: {"Unified_Ideograph", "Ideographic"},
    156062: {"Unified_Ideograph", "Ideographic"},
    156063: {"Unified_Ideograph", "Ideographic"},
    156064: {"Unified_Ideograph", "Ideographic"},
    156065: {"Unified_Ideograph", "Ideographic"},
    156066: {"Unified_Ideograph", "Ideographic"},
    156067: {"Unified_Ideograph", "Ideographic"},
    156068: {"Unified_Ideograph", "Ideographic"},
    156069: {"Unified_Ideograph", "Ideographic"},
    156070: {"Unified_Ideograph", "Ideographic"},
    156071: {"Unified_Ideograph", "Ideographic"},
    156072: {"Unified_Ideograph", "Ideographic"},
    156073: {"Unified_Ideograph", "Ideographic"},
    156074: {"Unified_Ideograph", "Ideographic"},
    156075: {"Unified_Ideograph", "Ideographic"},
    156076: {"Unified_Ideograph", "Ideographic"},
    156077: {"Unified_Ideograph", "Ideographic"},
    156078: {"Unified_Ideograph", "Ideographic"},
    156079: {"Unified_Ideograph", "Ideographic"},
    156080: {"Unified_Ideograph", "Ideographic"},
    156081: {"Unified_Ideograph", "Ideographic"},
    156082: {"Unified_Ideograph", "Ideographic"},
    156083: {"Unified_Ideograph", "Ideographic"},
    156084: {"Unified_Ideograph", "Ideographic"},
    156085: {"Unified_Ideograph", "Ideographic"},
    156086: {"Unified_Ideograph", "Ideographic"},
    156087: {"Unified_Ideograph", "Ideographic"},
    156088: {"Unified_Ideograph", "Ideographic"},
    156089: {"Unified_Ideograph", "Ideographic"},
    156090: {"Unified_Ideograph", "Ideographic"},
    156091: {"Unified_Ideograph", "Ideographic"},
    156092: {"Unified_Ideograph", "Ideographic"},
    156093: {"Unified_Ideograph", "Ideographic"},
    156094: {"Unified_Ideograph", "Ideographic"},
    156095: {"Unified_Ideograph", "Ideographic"},
    156096: {"Unified_Ideograph", "Ideographic"},
    156097: {"Unified_Ideograph", "Ideographic"},
    156098: {"Unified_Ideograph", "Ideographic"},
    156099: {"Unified_Ideograph", "Ideographic"},
    156100: {"Unified_Ideograph", "Ideographic"},
    156101: {"Unified_Ideograph", "Ideographic"},
    156102: {"Unified_Ideograph", "Ideographic"},
    156103: {"Unified_Ideograph", "Ideographic"},
    156104: {"Unified_Ideograph", "Ideographic"},
    156105: {"Unified_Ideograph", "Ideographic"},
    156106: {"Unified_Ideograph", "Ideographic"},
    156107: {"Unified_Ideograph", "Ideographic"},
    156108: {"Unified_Ideograph", "Ideographic"},
    156109: {"Unified_Ideograph", "Ideographic"},
    156110: {"Unified_Ideograph", "Ideographic"},
    156111: {"Unified_Ideograph", "Ideographic"},
    156112: {"Unified_Ideograph", "Ideographic"},
    156113: {"Unified_Ideograph", "Ideographic"},
    156114: {"Unified_Ideograph", "Ideographic"},
    156115: {"Unified_Ideograph", "Ideographic"},
    156116: {"Unified_Ideograph", "Ideographic"},
    156117: {"Unified_Ideograph", "Ideographic"},
    156118: {"Unified_Ideograph", "Ideographic"},
    156119: {"Unified_Ideograph", "Ideographic"},
    156120: {"Unified_Ideograph", "Ideographic"},
    156121: {"Unified_Ideograph", "Ideographic"},
    156122: {"Unified_Ideograph", "Ideographic"},
    156123: {"Unified_Ideograph", "Ideographic"},
    156124: {"Unified_Ideograph", "Ideographic"},
    156125: {"Unified_Ideograph", "Ideographic"},
    156126: {"Unified_Ideograph", "Ideographic"},
    156127: {"Unified_Ideograph", "Ideographic"},
    156128: {"Unified_Ideograph", "Ideographic"},
    156129: {"Unified_Ideograph", "Ideographic"},
    156130: {"Unified_Ideograph", "Ideographic"},
    156131: {"Unified_Ideograph", "Ideographic"},
    156132: {"Unified_Ideograph", "Ideographic"},
    156133: {"Unified_Ideograph", "Ideographic"},
    156134: {"Unified_Ideograph", "Ideographic"},
    156135: {"Unified_Ideograph", "Ideographic"},
    156136: {"Unified_Ideograph", "Ideographic"},
    156137: {"Unified_Ideograph", "Ideographic"},
    156138: {"Unified_Ideograph", "Ideographic"},
    156139: {"Unified_Ideograph", "Ideographic"},
    156140: {"Unified_Ideograph", "Ideographic"},
    156141: {"Unified_Ideograph", "Ideographic"},
    156142: {"Unified_Ideograph", "Ideographic"},
    156143: {"Unified_Ideograph", "Ideographic"},
    156144: {"Unified_Ideograph", "Ideographic"},
    156145: {"Unified_Ideograph", "Ideographic"},
    156146: {"Unified_Ideograph", "Ideographic"},
    156147: {"Unified_Ideograph", "Ideographic"},
    156148: {"Unified_Ideograph", "Ideographic"},
    156149: {"Unified_Ideograph", "Ideographic"},
    156150: {"Unified_Ideograph", "Ideographic"},
    156151: {"Unified_Ideograph", "Ideographic"},
    156152: {"Unified_Ideograph", "Ideographic"},
    156153: {"Unified_Ideograph", "Ideographic"},
    156154: {"Unified_Ideograph", "Ideographic"},
    156155: {"Unified_Ideograph", "Ideographic"},
    156156: {"Unified_Ideograph", "Ideographic"},
    156157: {"Unified_Ideograph", "Ideographic"},
    156158: {"Unified_Ideograph", "Ideographic"},
    156159: {"Unified_Ideograph", "Ideographic"},
    156160: {"Unified_Ideograph", "Ideographic"},
    156161: {"Unified_Ideograph", "Ideographic"},
    156162: {"Unified_Ideograph", "Ideographic"},
    156163: {"Unified_Ideograph", "Ideographic"},
    156164: {"Unified_Ideograph", "Ideographic"},
    156165: {"Unified_Ideograph", "Ideographic"},
    156166: {"Unified_Ideograph", "Ideographic"},
    156167: {"Unified_Ideograph", "Ideographic"},
    156168: {"Unified_Ideograph", "Ideographic"},
    156169: {"Unified_Ideograph", "Ideographic"},
    156170: {"Unified_Ideograph", "Ideographic"},
    156171: {"Unified_Ideograph", "Ideographic"},
    156172: {"Unified_Ideograph", "Ideographic"},
    156173: {"Unified_Ideograph", "Ideographic"},
    156174: {"Unified_Ideograph", "Ideographic"},
    156175: {"Unified_Ideograph", "Ideographic"},
    156176: {"Unified_Ideograph", "Ideographic"},
    156177: {"Unified_Ideograph", "Ideographic"},
    156178: {"Unified_Ideograph", "Ideographic"},
    156179: {"Unified_Ideograph", "Ideographic"},
    156180: {"Unified_Ideograph", "Ideographic"},
    156181: {"Unified_Ideograph", "Ideographic"},
    156182: {"Unified_Ideograph", "Ideographic"},
    156183: {"Unified_Ideograph", "Ideographic"},
    156184: {"Unified_Ideograph", "Ideographic"},
    156185: {"Unified_Ideograph", "Ideographic"},
    156186: {"Unified_Ideograph", "Ideographic"},
    156187: {"Unified_Ideograph", "Ideographic"},
    156188: {"Unified_Ideograph", "Ideographic"},
    156189: {"Unified_Ideograph", "Ideographic"},
    156190: {"Unified_Ideograph", "Ideographic"},
    156191: {"Unified_Ideograph", "Ideographic"},
    156192: {"Unified_Ideograph", "Ideographic"},
    156193: {"Unified_Ideograph", "Ideographic"},
    156194: {"Unified_Ideograph", "Ideographic"},
    156195: {"Unified_Ideograph", "Ideographic"},
    156196: {"Unified_Ideograph", "Ideographic"},
    156197: {"Unified_Ideograph", "Ideographic"},
    156198: {"Unified_Ideograph", "Ideographic"},
    156199: {"Unified_Ideograph", "Ideographic"},
    156200: {"Unified_Ideograph", "Ideographic"},
    156201: {"Unified_Ideograph", "Ideographic"},
    156202: {"Unified_Ideograph", "Ideographic"},
    156203: {"Unified_Ideograph", "Ideographic"},
    156204: {"Unified_Ideograph", "Ideographic"},
    156205: {"Unified_Ideograph", "Ideographic"},
    156206: {"Unified_Ideograph", "Ideographic"},
    156207: {"Unified_Ideograph", "Ideographic"},
    156208: {"Unified_Ideograph", "Ideographic"},
    156209: {"Unified_Ideograph", "Ideographic"},
    156210: {"Unified_Ideograph", "Ideographic"},
    156211: {"Unified_Ideograph", "Ideographic"},
    156212: {"Unified_Ideograph", "Ideographic"},
    156213: {"Unified_Ideograph", "Ideographic"},
    156214: {"Unified_Ideograph", "Ideographic"},
    156215: {"Unified_Ideograph", "Ideographic"},
    156216: {"Unified_Ideograph", "Ideographic"},
    156217: {"Unified_Ideograph", "Ideographic"},
    156218: {"Unified_Ideograph", "Ideographic"},
    156219: {"Unified_Ideograph", "Ideographic"},
    156220: {"Unified_Ideograph", "Ideographic"},
    156221: {"Unified_Ideograph", "Ideographic"},
    156222: {"Unified_Ideograph", "Ideographic"},
    156223: {"Unified_Ideograph", "Ideographic"},
    156224: {"Unified_Ideograph", "Ideographic"},
    156225: {"Unified_Ideograph", "Ideographic"},
    156226: {"Unified_Ideograph", "Ideographic"},
    156227: {"Unified_Ideograph", "Ideographic"},
    156228: {"Unified_Ideograph", "Ideographic"},
    156229: {"Unified_Ideograph", "Ideographic"},
    156230: {"Unified_Ideograph", "Ideographic"},
    156231: {"Unified_Ideograph", "Ideographic"},
    156232: {"Unified_Ideograph", "Ideographic"},
    156233: {"Unified_Ideograph", "Ideographic"},
    156234: {"Unified_Ideograph", "Ideographic"},
    156235: {"Unified_Ideograph", "Ideographic"},
    156236: {"Unified_Ideograph", "Ideographic"},
    156237: {"Unified_Ideograph", "Ideographic"},
    156238: {"Unified_Ideograph", "Ideographic"},
    156239: {"Unified_Ideograph", "Ideographic"},
    156240: {"Unified_Ideograph", "Ideographic"},
    156241: {"Unified_Ideograph", "Ideographic"},
    156242: {"Unified_Ideograph", "Ideographic"},
    156243: {"Unified_Ideograph", "Ideographic"},
    156244: {"Unified_Ideograph", "Ideographic"},
    156245: {"Unified_Ideograph", "Ideographic"},
    156246: {"Unified_Ideograph", "Ideographic"},
    156247: {"Unified_Ideograph", "Ideographic"},
    156248: {"Unified_Ideograph", "Ideographic"},
    156249: {"Unified_Ideograph", "Ideographic"},
    156250: {"Unified_Ideograph", "Ideographic"},
    156251: {"Unified_Ideograph", "Ideographic"},
    156252: {"Unified_Ideograph", "Ideographic"},
    156253: {"Unified_Ideograph", "Ideographic"},
    156254: {"Unified_Ideograph", "Ideographic"},
    156255: {"Unified_Ideograph", "Ideographic"},
    156256: {"Unified_Ideograph", "Ideographic"},
    156257: {"Unified_Ideograph", "Ideographic"},
    156258: {"Unified_Ideograph", "Ideographic"},
    156259: {"Unified_Ideograph", "Ideographic"},
    156260: {"Unified_Ideograph", "Ideographic"},
    156261: {"Unified_Ideograph", "Ideographic"},
    156262: {"Unified_Ideograph", "Ideographic"},
    156263: {"Unified_Ideograph", "Ideographic"},
    156264: {"Unified_Ideograph", "Ideographic"},
    156265: {"Unified_Ideograph", "Ideographic"},
    156266: {"Unified_Ideograph", "Ideographic"},
    156267: {"Unified_Ideograph", "Ideographic"},
    156268: {"Unified_Ideograph", "Ideographic"},
    156269: {"Unified_Ideograph", "Ideographic"},
    156270: {"Unified_Ideograph", "Ideographic"},
    156271: {"Unified_Ideograph", "Ideographic"},
    156272: {"Unified_Ideograph", "Ideographic"},
    156273: {"Unified_Ideograph", "Ideographic"},
    156274: {"Unified_Ideograph", "Ideographic"},
    156275: {"Unified_Ideograph", "Ideographic"},
    156276: {"Unified_Ideograph", "Ideographic"},
    156277: {"Unified_Ideograph", "Ideographic"},
    156278: {"Unified_Ideograph", "Ideographic"},
    156279: {"Unified_Ideograph", "Ideographic"},
    156280: {"Unified_Ideograph", "Ideographic"},
    156281: {"Unified_Ideograph", "Ideographic"},
    156282: {"Unified_Ideograph", "Ideographic"},
    156283: {"Unified_Ideograph", "Ideographic"},
    156284: {"Unified_Ideograph", "Ideographic"},
    156285: {"Unified_Ideograph", "Ideographic"},
    156286: {"Unified_Ideograph", "Ideographic"},
    156287: {"Unified_Ideograph", "Ideographic"},
    156288: {"Unified_Ideograph", "Ideographic"},
    156289: {"Unified_Ideograph", "Ideographic"},
    156290: {"Unified_Ideograph", "Ideographic"},
    156291: {"Unified_Ideograph", "Ideographic"},
    156292: {"Unified_Ideograph", "Ideographic"},
    156293: {"Unified_Ideograph", "Ideographic"},
    156294: {"Unified_Ideograph", "Ideographic"},
    156295: {"Unified_Ideograph", "Ideographic"},
    156296: {"Unified_Ideograph", "Ideographic"},
    156297: {"Unified_Ideograph", "Ideographic"},
    156298: {"Unified_Ideograph", "Ideographic"},
    156299: {"Unified_Ideograph", "Ideographic"},
    156300: {"Unified_Ideograph", "Ideographic"},
    156301: {"Unified_Ideograph", "Ideographic"},
    156302: {"Unified_Ideograph", "Ideographic"},
    156303: {"Unified_Ideograph", "Ideographic"},
    156304: {"Unified_Ideograph", "Ideographic"},
    156305: {"Unified_Ideograph", "Ideographic"},
    156306: {"Unified_Ideograph", "Ideographic"},
    156307: {"Unified_Ideograph", "Ideographic"},
    156308: {"Unified_Ideograph", "Ideographic"},
    156309: {"Unified_Ideograph", "Ideographic"},
    156310: {"Unified_Ideograph", "Ideographic"},
    156311: {"Unified_Ideograph", "Ideographic"},
    156312: {"Unified_Ideograph", "Ideographic"},
    156313: {"Unified_Ideograph", "Ideographic"},
    156314: {"Unified_Ideograph", "Ideographic"},
    156315: {"Unified_Ideograph", "Ideographic"},
    156316: {"Unified_Ideograph", "Ideographic"},
    156317: {"Unified_Ideograph", "Ideographic"},
    156318: {"Unified_Ideograph", "Ideographic"},
    156319: {"Unified_Ideograph", "Ideographic"},
    156320: {"Unified_Ideograph", "Ideographic"},
    156321: {"Unified_Ideograph", "Ideographic"},
    156322: {"Unified_Ideograph", "Ideographic"},
    156323: {"Unified_Ideograph", "Ideographic"},
    156324: {"Unified_Ideograph", "Ideographic"},
    156325: {"Unified_Ideograph", "Ideographic"},
    156326: {"Unified_Ideograph", "Ideographic"},
    156327: {"Unified_Ideograph", "Ideographic"},
    156328: {"Unified_Ideograph", "Ideographic"},
    156329: {"Unified_Ideograph", "Ideographic"},
    156330: {"Unified_Ideograph", "Ideographic"},
    156331: {"Unified_Ideograph", "Ideographic"},
    156332: {"Unified_Ideograph", "Ideographic"},
    156333: {"Unified_Ideograph", "Ideographic"},
    156334: {"Unified_Ideograph", "Ideographic"},
    156335: {"Unified_Ideograph", "Ideographic"},
    156336: {"Unified_Ideograph", "Ideographic"},
    156337: {"Unified_Ideograph", "Ideographic"},
    156338: {"Unified_Ideograph", "Ideographic"},
    156339: {"Unified_Ideograph", "Ideographic"},
    156340: {"Unified_Ideograph", "Ideographic"},
    156341: {"Unified_Ideograph", "Ideographic"},
    156342: {"Unified_Ideograph", "Ideographic"},
    156343: {"Unified_Ideograph", "Ideographic"},
    156344: {"Unified_Ideograph", "Ideographic"},
    156345: {"Unified_Ideograph", "Ideographic"},
    156346: {"Unified_Ideograph", "Ideographic"},
    156347: {"Unified_Ideograph", "Ideographic"},
    156348: {"Unified_Ideograph", "Ideographic"},
    156349: {"Unified_Ideograph", "Ideographic"},
    156350: {"Unified_Ideograph", "Ideographic"},
    156351: {"Unified_Ideograph", "Ideographic"},
    156352: {"Unified_Ideograph", "Ideographic"},
    156353: {"Unified_Ideograph", "Ideographic"},
    156354: {"Unified_Ideograph", "Ideographic"},
    156355: {"Unified_Ideograph", "Ideographic"},
    156356: {"Unified_Ideograph", "Ideographic"},
    156357: {"Unified_Ideograph", "Ideographic"},
    156358: {"Unified_Ideograph", "Ideographic"},
    156359: {"Unified_Ideograph", "Ideographic"},
    156360: {"Unified_Ideograph", "Ideographic"},
    156361: {"Unified_Ideograph", "Ideographic"},
    156362: {"Unified_Ideograph", "Ideographic"},
    156363: {"Unified_Ideograph", "Ideographic"},
    156364: {"Unified_Ideograph", "Ideographic"},
    156365: {"Unified_Ideograph", "Ideographic"},
    156366: {"Unified_Ideograph", "Ideographic"},
    156367: {"Unified_Ideograph", "Ideographic"},
    156368: {"Unified_Ideograph", "Ideographic"},
    156369: {"Unified_Ideograph", "Ideographic"},
    156370: {"Unified_Ideograph", "Ideographic"},
    156371: {"Unified_Ideograph", "Ideographic"},
    156372: {"Unified_Ideograph", "Ideographic"},
    156373: {"Unified_Ideograph", "Ideographic"},
    156374: {"Unified_Ideograph", "Ideographic"},
    156375: {"Unified_Ideograph", "Ideographic"},
    156376: {"Unified_Ideograph", "Ideographic"},
    156377: {"Unified_Ideograph", "Ideographic"},
    156378: {"Unified_Ideograph", "Ideographic"},
    156379: {"Unified_Ideograph", "Ideographic"},
    156380: {"Unified_Ideograph", "Ideographic"},
    156381: {"Unified_Ideograph", "Ideographic"},
    156382: {"Unified_Ideograph", "Ideographic"},
    156383: {"Unified_Ideograph", "Ideographic"},
    156384: {"Unified_Ideograph", "Ideographic"},
    156385: {"Unified_Ideograph", "Ideographic"},
    156386: {"Unified_Ideograph", "Ideographic"},
    156387: {"Unified_Ideograph", "Ideographic"},
    156388: {"Unified_Ideograph", "Ideographic"},
    156389: {"Unified_Ideograph", "Ideographic"},
    156390: {"Unified_Ideograph", "Ideographic"},
    156391: {"Unified_Ideograph", "Ideographic"},
    156392: {"Unified_Ideograph", "Ideographic"},
    156393: {"Unified_Ideograph", "Ideographic"},
    156394: {"Unified_Ideograph", "Ideographic"},
    156395: {"Unified_Ideograph", "Ideographic"},
    156396: {"Unified_Ideograph", "Ideographic"},
    156397: {"Unified_Ideograph", "Ideographic"},
    156398: {"Unified_Ideograph", "Ideographic"},
    156399: {"Unified_Ideograph", "Ideographic"},
    156400: {"Unified_Ideograph", "Ideographic"},
    156401: {"Unified_Ideograph", "Ideographic"},
    156402: {"Unified_Ideograph", "Ideographic"},
    156403: {"Unified_Ideograph", "Ideographic"},
    156404: {"Unified_Ideograph", "Ideographic"},
    156405: {"Unified_Ideograph", "Ideographic"},
    156406: {"Unified_Ideograph", "Ideographic"},
    156407: {"Unified_Ideograph", "Ideographic"},
    156408: {"Unified_Ideograph", "Ideographic"},
    156409: {"Unified_Ideograph", "Ideographic"},
    156410: {"Unified_Ideograph", "Ideographic"},
    156411: {"Unified_Ideograph", "Ideographic"},
    156412: {"Unified_Ideograph", "Ideographic"},
    156413: {"Unified_Ideograph", "Ideographic"},
    156414: {"Unified_Ideograph", "Ideographic"},
    156415: {"Unified_Ideograph", "Ideographic"},
    156416: {"Unified_Ideograph", "Ideographic"},
    156417: {"Unified_Ideograph", "Ideographic"},
    156418: {"Unified_Ideograph", "Ideographic"},
    156419: {"Unified_Ideograph", "Ideographic"},
    156420: {"Unified_Ideograph", "Ideographic"},
    156421: {"Unified_Ideograph", "Ideographic"},
    156422: {"Unified_Ideograph", "Ideographic"},
    156423: {"Unified_Ideograph", "Ideographic"},
    156424: {"Unified_Ideograph", "Ideographic"},
    156425: {"Unified_Ideograph", "Ideographic"},
    156426: {"Unified_Ideograph", "Ideographic"},
    156427: {"Unified_Ideograph", "Ideographic"},
    156428: {"Unified_Ideograph", "Ideographic"},
    156429: {"Unified_Ideograph", "Ideographic"},
    156430: {"Unified_Ideograph", "Ideographic"},
    156431: {"Unified_Ideograph", "Ideographic"},
    156432: {"Unified_Ideograph", "Ideographic"},
    156433: {"Unified_Ideograph", "Ideographic"},
    156434: {"Unified_Ideograph", "Ideographic"},
    156435: {"Unified_Ideograph", "Ideographic"},
    156436: {"Unified_Ideograph", "Ideographic"},
    156437: {"Unified_Ideograph", "Ideographic"},
    156438: {"Unified_Ideograph", "Ideographic"},
    156439: {"Unified_Ideograph", "Ideographic"},
    156440: {"Unified_Ideograph", "Ideographic"},
    156441: {"Unified_Ideograph", "Ideographic"},
    156442: {"Unified_Ideograph", "Ideographic"},
    156443: {"Unified_Ideograph", "Ideographic"},
    156444: {"Unified_Ideograph", "Ideographic"},
    156445: {"Unified_Ideograph", "Ideographic"},
    156446: {"Unified_Ideograph", "Ideographic"},
    156447: {"Unified_Ideograph", "Ideographic"},
    156448: {"Unified_Ideograph", "Ideographic"},
    156449: {"Unified_Ideograph", "Ideographic"},
    156450: {"Unified_Ideograph", "Ideographic"},
    156451: {"Unified_Ideograph", "Ideographic"},
    156452: {"Unified_Ideograph", "Ideographic"},
    156453: {"Unified_Ideograph", "Ideographic"},
    156454: {"Unified_Ideograph", "Ideographic"},
    156455: {"Unified_Ideograph", "Ideographic"},
    156456: {"Unified_Ideograph", "Ideographic"},
    156457: {"Unified_Ideograph", "Ideographic"},
    156458: {"Unified_Ideograph", "Ideographic"},
    156459: {"Unified_Ideograph", "Ideographic"},
    156460: {"Unified_Ideograph", "Ideographic"},
    156461: {"Unified_Ideograph", "Ideographic"},
    156462: {"Unified_Ideograph", "Ideographic"},
    156463: {"Unified_Ideograph", "Ideographic"},
    156464: {"Unified_Ideograph", "Ideographic"},
    156465: {"Unified_Ideograph", "Ideographic"},
    156466: {"Unified_Ideograph", "Ideographic"},
    156467: {"Unified_Ideograph", "Ideographic"},
    156468: {"Unified_Ideograph", "Ideographic"},
    156469: {"Unified_Ideograph", "Ideographic"},
    156470: {"Unified_Ideograph", "Ideographic"},
    156471: {"Unified_Ideograph", "Ideographic"},
    156472: {"Unified_Ideograph", "Ideographic"},
    156473: {"Unified_Ideograph", "Ideographic"},
    156474: {"Unified_Ideograph", "Ideographic"},
    156475: {"Unified_Ideograph", "Ideographic"},
    156476: {"Unified_Ideograph", "Ideographic"},
    156477: {"Unified_Ideograph", "Ideographic"},
    156478: {"Unified_Ideograph", "Ideographic"},
    156479: {"Unified_Ideograph", "Ideographic"},
    156480: {"Unified_Ideograph", "Ideographic"},
    156481: {"Unified_Ideograph", "Ideographic"},
    156482: {"Unified_Ideograph", "Ideographic"},
    156483: {"Unified_Ideograph", "Ideographic"},
    156484: {"Unified_Ideograph", "Ideographic"},
    156485: {"Unified_Ideograph", "Ideographic"},
    156486: {"Unified_Ideograph", "Ideographic"},
    156487: {"Unified_Ideograph", "Ideographic"},
    156488: {"Unified_Ideograph", "Ideographic"},
    156489: {"Unified_Ideograph", "Ideographic"},
    156490: {"Unified_Ideograph", "Ideographic"},
    156491: {"Unified_Ideograph", "Ideographic"},
    156492: {"Unified_Ideograph", "Ideographic"},
    156493: {"Unified_Ideograph", "Ideographic"},
    156494: {"Unified_Ideograph", "Ideographic"},
    156495: {"Unified_Ideograph", "Ideographic"},
    156496: {"Unified_Ideograph", "Ideographic"},
    156497: {"Unified_Ideograph", "Ideographic"},
    156498: {"Unified_Ideograph", "Ideographic"},
    156499: {"Unified_Ideograph", "Ideographic"},
    156500: {"Unified_Ideograph", "Ideographic"},
    156501: {"Unified_Ideograph", "Ideographic"},
    156502: {"Unified_Ideograph", "Ideographic"},
    156503: {"Unified_Ideograph", "Ideographic"},
    156504: {"Unified_Ideograph", "Ideographic"},
    156505: {"Unified_Ideograph", "Ideographic"},
    156506: {"Unified_Ideograph", "Ideographic"},
    156507: {"Unified_Ideograph", "Ideographic"},
    156508: {"Unified_Ideograph", "Ideographic"},
    156509: {"Unified_Ideograph", "Ideographic"},
    156510: {"Unified_Ideograph", "Ideographic"},
    156511: {"Unified_Ideograph", "Ideographic"},
    156512: {"Unified_Ideograph", "Ideographic"},
    156513: {"Unified_Ideograph", "Ideographic"},
    156514: {"Unified_Ideograph", "Ideographic"},
    156515: {"Unified_Ideograph", "Ideographic"},
    156516: {"Unified_Ideograph", "Ideographic"},
    156517: {"Unified_Ideograph", "Ideographic"},
    156518: {"Unified_Ideograph", "Ideographic"},
    156519: {"Unified_Ideograph", "Ideographic"},
    156520: {"Unified_Ideograph", "Ideographic"},
    156521: {"Unified_Ideograph", "Ideographic"},
    156522: {"Unified_Ideograph", "Ideographic"},
    156523: {"Unified_Ideograph", "Ideographic"},
    156524: {"Unified_Ideograph", "Ideographic"},
    156525: {"Unified_Ideograph", "Ideographic"},
    156526: {"Unified_Ideograph", "Ideographic"},
    156527: {"Unified_Ideograph", "Ideographic"},
    156528: {"Unified_Ideograph", "Ideographic"},
    156529: {"Unified_Ideograph", "Ideographic"},
    156530: {"Unified_Ideograph", "Ideographic"},
    156531: {"Unified_Ideograph", "Ideographic"},
    156532: {"Unified_Ideograph", "Ideographic"},
    156533: {"Unified_Ideograph", "Ideographic"},
    156534: {"Unified_Ideograph", "Ideographic"},
    156535: {"Unified_Ideograph", "Ideographic"},
    156536: {"Unified_Ideograph", "Ideographic"},
    156537: {"Unified_Ideograph", "Ideographic"},
    156538: {"Unified_Ideograph", "Ideographic"},
    156539: {"Unified_Ideograph", "Ideographic"},
    156540: {"Unified_Ideograph", "Ideographic"},
    156541: {"Unified_Ideograph", "Ideographic"},
    156542: {"Unified_Ideograph", "Ideographic"},
    156543: {"Unified_Ideograph", "Ideographic"},
    156544: {"Unified_Ideograph", "Ideographic"},
    156545: {"Unified_Ideograph", "Ideographic"},
    156546: {"Unified_Ideograph", "Ideographic"},
    156547: {"Unified_Ideograph", "Ideographic"},
    156548: {"Unified_Ideograph", "Ideographic"},
    156549: {"Unified_Ideograph", "Ideographic"},
    156550: {"Unified_Ideograph", "Ideographic"},
    156551: {"Unified_Ideograph", "Ideographic"},
    156552: {"Unified_Ideograph", "Ideographic"},
    156553: {"Unified_Ideograph", "Ideographic"},
    156554: {"Unified_Ideograph", "Ideographic"},
    156555: {"Unified_Ideograph", "Ideographic"},
    156556: {"Unified_Ideograph", "Ideographic"},
    156557: {"Unified_Ideograph", "Ideographic"},
    156558: {"Unified_Ideograph", "Ideographic"},
    156559: {"Unified_Ideograph", "Ideographic"},
    156560: {"Unified_Ideograph", "Ideographic"},
    156561: {"Unified_Ideograph", "Ideographic"},
    156562: {"Unified_Ideograph", "Ideographic"},
    156563: {"Unified_Ideograph", "Ideographic"},
    156564: {"Unified_Ideograph", "Ideographic"},
    156565: {"Unified_Ideograph", "Ideographic"},
    156566: {"Unified_Ideograph", "Ideographic"},
    156567: {"Unified_Ideograph", "Ideographic"},
    156568: {"Unified_Ideograph", "Ideographic"},
    156569: {"Unified_Ideograph", "Ideographic"},
    156570: {"Unified_Ideograph", "Ideographic"},
    156571: {"Unified_Ideograph", "Ideographic"},
    156572: {"Unified_Ideograph", "Ideographic"},
    156573: {"Unified_Ideograph", "Ideographic"},
    156574: {"Unified_Ideograph", "Ideographic"},
    156575: {"Unified_Ideograph", "Ideographic"},
    156576: {"Unified_Ideograph", "Ideographic"},
    156577: {"Unified_Ideograph", "Ideographic"},
    156578: {"Unified_Ideograph", "Ideographic"},
    156579: {"Unified_Ideograph", "Ideographic"},
    156580: {"Unified_Ideograph", "Ideographic"},
    156581: {"Unified_Ideograph", "Ideographic"},
    156582: {"Unified_Ideograph", "Ideographic"},
    156583: {"Unified_Ideograph", "Ideographic"},
    156584: {"Unified_Ideograph", "Ideographic"},
    156585: {"Unified_Ideograph", "Ideographic"},
    156586: {"Unified_Ideograph", "Ideographic"},
    156587: {"Unified_Ideograph", "Ideographic"},
    156588: {"Unified_Ideograph", "Ideographic"},
    156589: {"Unified_Ideograph", "Ideographic"},
    156590: {"Unified_Ideograph", "Ideographic"},
    156591: {"Unified_Ideograph", "Ideographic"},
    156592: {"Unified_Ideograph", "Ideographic"},
    156593: {"Unified_Ideograph", "Ideographic"},
    156594: {"Unified_Ideograph", "Ideographic"},
    156595: {"Unified_Ideograph", "Ideographic"},
    156596: {"Unified_Ideograph", "Ideographic"},
    156597: {"Unified_Ideograph", "Ideographic"},
    156598: {"Unified_Ideograph", "Ideographic"},
    156599: {"Unified_Ideograph", "Ideographic"},
    156600: {"Unified_Ideograph", "Ideographic"},
    156601: {"Unified_Ideograph", "Ideographic"},
    156602: {"Unified_Ideograph", "Ideographic"},
    156603: {"Unified_Ideograph", "Ideographic"},
    156604: {"Unified_Ideograph", "Ideographic"},
    156605: {"Unified_Ideograph", "Ideographic"},
    156606: {"Unified_Ideograph", "Ideographic"},
    156607: {"Unified_Ideograph", "Ideographic"},
    156608: {"Unified_Ideograph", "Ideographic"},
    156609: {"Unified_Ideograph", "Ideographic"},
    156610: {"Unified_Ideograph", "Ideographic"},
    156611: {"Unified_Ideograph", "Ideographic"},
    156612: {"Unified_Ideograph", "Ideographic"},
    156613: {"Unified_Ideograph", "Ideographic"},
    156614: {"Unified_Ideograph", "Ideographic"},
    156615: {"Unified_Ideograph", "Ideographic"},
    156616: {"Unified_Ideograph", "Ideographic"},
    156617: {"Unified_Ideograph", "Ideographic"},
    156618: {"Unified_Ideograph", "Ideographic"},
    156619: {"Unified_Ideograph", "Ideographic"},
    156620: {"Unified_Ideograph", "Ideographic"},
    156621: {"Unified_Ideograph", "Ideographic"},
    156622: {"Unified_Ideograph", "Ideographic"},
    156623: {"Unified_Ideograph", "Ideographic"},
    156624: {"Unified_Ideograph", "Ideographic"},
    156625: {"Unified_Ideograph", "Ideographic"},
    156626: {"Unified_Ideograph", "Ideographic"},
    156627: {"Unified_Ideograph", "Ideographic"},
    156628: {"Unified_Ideograph", "Ideographic"},
    156629: {"Unified_Ideograph", "Ideographic"},
    156630: {"Unified_Ideograph", "Ideographic"},
    156631: {"Unified_Ideograph", "Ideographic"},
    156632: {"Unified_Ideograph", "Ideographic"},
    156633: {"Unified_Ideograph", "Ideographic"},
    156634: {"Unified_Ideograph", "Ideographic"},
    156635: {"Unified_Ideograph", "Ideographic"},
    156636: {"Unified_Ideograph", "Ideographic"},
    156637: {"Unified_Ideograph", "Ideographic"},
    156638: {"Unified_Ideograph", "Ideographic"},
    156639: {"Unified_Ideograph", "Ideographic"},
    156640: {"Unified_Ideograph", "Ideographic"},
    156641: {"Unified_Ideograph", "Ideographic"},
    156642: {"Unified_Ideograph", "Ideographic"},
    156643: {"Unified_Ideograph", "Ideographic"},
    156644: {"Unified_Ideograph", "Ideographic"},
    156645: {"Unified_Ideograph", "Ideographic"},
    156646: {"Unified_Ideograph", "Ideographic"},
    156647: {"Unified_Ideograph", "Ideographic"},
    156648: {"Unified_Ideograph", "Ideographic"},
    156649: {"Unified_Ideograph", "Ideographic"},
    156650: {"Unified_Ideograph", "Ideographic"},
    156651: {"Unified_Ideograph", "Ideographic"},
    156652: {"Unified_Ideograph", "Ideographic"},
    156653: {"Unified_Ideograph", "Ideographic"},
    156654: {"Unified_Ideograph", "Ideographic"},
    156655: {"Unified_Ideograph", "Ideographic"},
    156656: {"Unified_Ideograph", "Ideographic"},
    156657: {"Unified_Ideograph", "Ideographic"},
    156658: {"Unified_Ideograph", "Ideographic"},
    156659: {"Unified_Ideograph", "Ideographic"},
    156660: {"Unified_Ideograph", "Ideographic"},
    156661: {"Unified_Ideograph", "Ideographic"},
    156662: {"Unified_Ideograph", "Ideographic"},
    156663: {"Unified_Ideograph", "Ideographic"},
    156664: {"Unified_Ideograph", "Ideographic"},
    156665: {"Unified_Ideograph", "Ideographic"},
    156666: {"Unified_Ideograph", "Ideographic"},
    156667: {"Unified_Ideograph", "Ideographic"},
    156668: {"Unified_Ideograph", "Ideographic"},
    156669: {"Unified_Ideograph", "Ideographic"},
    156670: {"Unified_Ideograph", "Ideographic"},
    156671: {"Unified_Ideograph", "Ideographic"},
    156672: {"Unified_Ideograph", "Ideographic"},
    156673: {"Unified_Ideograph", "Ideographic"},
    156674: {"Unified_Ideograph", "Ideographic"},
    156675: {"Unified_Ideograph", "Ideographic"},
    156676: {"Unified_Ideograph", "Ideographic"},
    156677: {"Unified_Ideograph", "Ideographic"},
    156678: {"Unified_Ideograph", "Ideographic"},
    156679: {"Unified_Ideograph", "Ideographic"},
    156680: {"Unified_Ideograph", "Ideographic"},
    156681: {"Unified_Ideograph", "Ideographic"},
    156682: {"Unified_Ideograph", "Ideographic"},
    156683: {"Unified_Ideograph", "Ideographic"},
    156684: {"Unified_Ideograph", "Ideographic"},
    156685: {"Unified_Ideograph", "Ideographic"},
    156686: {"Unified_Ideograph", "Ideographic"},
    156687: {"Unified_Ideograph", "Ideographic"},
    156688: {"Unified_Ideograph", "Ideographic"},
    156689: {"Unified_Ideograph", "Ideographic"},
    156690: {"Unified_Ideograph", "Ideographic"},
    156691: {"Unified_Ideograph", "Ideographic"},
    156692: {"Unified_Ideograph", "Ideographic"},
    156693: {"Unified_Ideograph", "Ideographic"},
    156694: {"Unified_Ideograph", "Ideographic"},
    156695: {"Unified_Ideograph", "Ideographic"},
    156696: {"Unified_Ideograph", "Ideographic"},
    156697: {"Unified_Ideograph", "Ideographic"},
    156698: {"Unified_Ideograph", "Ideographic"},
    156699: {"Unified_Ideograph", "Ideographic"},
    156700: {"Unified_Ideograph", "Ideographic"},
    156701: {"Unified_Ideograph", "Ideographic"},
    156702: {"Unified_Ideograph", "Ideographic"},
    156703: {"Unified_Ideograph", "Ideographic"},
    156704: {"Unified_Ideograph", "Ideographic"},
    156705: {"Unified_Ideograph", "Ideographic"},
    156706: {"Unified_Ideograph", "Ideographic"},
    156707: {"Unified_Ideograph", "Ideographic"},
    156708: {"Unified_Ideograph", "Ideographic"},
    156709: {"Unified_Ideograph", "Ideographic"},
    156710: {"Unified_Ideograph", "Ideographic"},
    156711: {"Unified_Ideograph", "Ideographic"},
    156712: {"Unified_Ideograph", "Ideographic"},
    156713: {"Unified_Ideograph", "Ideographic"},
    156714: {"Unified_Ideograph", "Ideographic"},
    156715: {"Unified_Ideograph", "Ideographic"},
    156716: {"Unified_Ideograph", "Ideographic"},
    156717: {"Unified_Ideograph", "Ideographic"},
    156718: {"Unified_Ideograph", "Ideographic"},
    156719: {"Unified_Ideograph", "Ideographic"},
    156720: {"Unified_Ideograph", "Ideographic"},
    156721: {"Unified_Ideograph", "Ideographic"},
    156722: {"Unified_Ideograph", "Ideographic"},
    156723: {"Unified_Ideograph", "Ideographic"},
    156724: {"Unified_Ideograph", "Ideographic"},
    156725: {"Unified_Ideograph", "Ideographic"},
    156726: {"Unified_Ideograph", "Ideographic"},
    156727: {"Unified_Ideograph", "Ideographic"},
    156728: {"Unified_Ideograph", "Ideographic"},
    156729: {"Unified_Ideograph", "Ideographic"},
    156730: {"Unified_Ideograph", "Ideographic"},
    156731: {"Unified_Ideograph", "Ideographic"},
    156732: {"Unified_Ideograph", "Ideographic"},
    156733: {"Unified_Ideograph", "Ideographic"},
    156734: {"Unified_Ideograph", "Ideographic"},
    156735: {"Unified_Ideograph", "Ideographic"},
    156736: {"Unified_Ideograph", "Ideographic"},
    156737: {"Unified_Ideograph", "Ideographic"},
    156738: {"Unified_Ideograph", "Ideographic"},
    156739: {"Unified_Ideograph", "Ideographic"},
    156740: {"Unified_Ideograph", "Ideographic"},
    156741: {"Unified_Ideograph", "Ideographic"},
    156742: {"Unified_Ideograph", "Ideographic"},
    156743: {"Unified_Ideograph", "Ideographic"},
    156744: {"Unified_Ideograph", "Ideographic"},
    156745: {"Unified_Ideograph", "Ideographic"},
    156746: {"Unified_Ideograph", "Ideographic"},
    156747: {"Unified_Ideograph", "Ideographic"},
    156748: {"Unified_Ideograph", "Ideographic"},
    156749: {"Unified_Ideograph", "Ideographic"},
    156750: {"Unified_Ideograph", "Ideographic"},
    156751: {"Unified_Ideograph", "Ideographic"},
    156752: {"Unified_Ideograph", "Ideographic"},
    156753: {"Unified_Ideograph", "Ideographic"},
    156754: {"Unified_Ideograph", "Ideographic"},
    156755: {"Unified_Ideograph", "Ideographic"},
    156756: {"Unified_Ideograph", "Ideographic"},
    156757: {"Unified_Ideograph", "Ideographic"},
    156758: {"Unified_Ideograph", "Ideographic"},
    156759: {"Unified_Ideograph", "Ideographic"},
    156760: {"Unified_Ideograph", "Ideographic"},
    156761: {"Unified_Ideograph", "Ideographic"},
    156762: {"Unified_Ideograph", "Ideographic"},
    156763: {"Unified_Ideograph", "Ideographic"},
    156764: {"Unified_Ideograph", "Ideographic"},
    156765: {"Unified_Ideograph", "Ideographic"},
    156766: {"Unified_Ideograph", "Ideographic"},
    156767: {"Unified_Ideograph", "Ideographic"},
    156768: {"Unified_Ideograph", "Ideographic"},
    156769: {"Unified_Ideograph", "Ideographic"},
    156770: {"Unified_Ideograph", "Ideographic"},
    156771: {"Unified_Ideograph", "Ideographic"},
    156772: {"Unified_Ideograph", "Ideographic"},
    156773: {"Unified_Ideograph", "Ideographic"},
    156774: {"Unified_Ideograph", "Ideographic"},
    156775: {"Unified_Ideograph", "Ideographic"},
    156776: {"Unified_Ideograph", "Ideographic"},
    156777: {"Unified_Ideograph", "Ideographic"},
    156778: {"Unified_Ideograph", "Ideographic"},
    156779: {"Unified_Ideograph", "Ideographic"},
    156780: {"Unified_Ideograph", "Ideographic"},
    156781: {"Unified_Ideograph", "Ideographic"},
    156782: {"Unified_Ideograph", "Ideographic"},
    156783: {"Unified_Ideograph", "Ideographic"},
    156784: {"Unified_Ideograph", "Ideographic"},
    156785: {"Unified_Ideograph", "Ideographic"},
    156786: {"Unified_Ideograph", "Ideographic"},
    156787: {"Unified_Ideograph", "Ideographic"},
    156788: {"Unified_Ideograph", "Ideographic"},
    156789: {"Unified_Ideograph", "Ideographic"},
    156790: {"Unified_Ideograph", "Ideographic"},
    156791: {"Unified_Ideograph", "Ideographic"},
    156792: {"Unified_Ideograph", "Ideographic"},
    156793: {"Unified_Ideograph", "Ideographic"},
    156794: {"Unified_Ideograph", "Ideographic"},
    156795: {"Unified_Ideograph", "Ideographic"},
    156796: {"Unified_Ideograph", "Ideographic"},
    156797: {"Unified_Ideograph", "Ideographic"},
    156798: {"Unified_Ideograph", "Ideographic"},
    156799: {"Unified_Ideograph", "Ideographic"},
    156800: {"Unified_Ideograph", "Ideographic"},
    156801: {"Unified_Ideograph", "Ideographic"},
    156802: {"Unified_Ideograph", "Ideographic"},
    156803: {"Unified_Ideograph", "Ideographic"},
    156804: {"Unified_Ideograph", "Ideographic"},
    156805: {"Unified_Ideograph", "Ideographic"},
    156806: {"Unified_Ideograph", "Ideographic"},
    156807: {"Unified_Ideograph", "Ideographic"},
    156808: {"Unified_Ideograph", "Ideographic"},
    156809: {"Unified_Ideograph", "Ideographic"},
    156810: {"Unified_Ideograph", "Ideographic"},
    156811: {"Unified_Ideograph", "Ideographic"},
    156812: {"Unified_Ideograph", "Ideographic"},
    156813: {"Unified_Ideograph", "Ideographic"},
    156814: {"Unified_Ideograph", "Ideographic"},
    156815: {"Unified_Ideograph", "Ideographic"},
    156816: {"Unified_Ideograph", "Ideographic"},
    156817: {"Unified_Ideograph", "Ideographic"},
    156818: {"Unified_Ideograph", "Ideographic"},
    156819: {"Unified_Ideograph", "Ideographic"},
    156820: {"Unified_Ideograph", "Ideographic"},
    156821: {"Unified_Ideograph", "Ideographic"},
    156822: {"Unified_Ideograph", "Ideographic"},
    156823: {"Unified_Ideograph", "Ideographic"},
    156824: {"Unified_Ideograph", "Ideographic"},
    156825: {"Unified_Ideograph", "Ideographic"},
    156826: {"Unified_Ideograph", "Ideographic"},
    156827: {"Unified_Ideograph", "Ideographic"},
    156828: {"Unified_Ideograph", "Ideographic"},
    156829: {"Unified_Ideograph", "Ideographic"},
    156830: {"Unified_Ideograph", "Ideographic"},
    156831: {"Unified_Ideograph", "Ideographic"},
    156832: {"Unified_Ideograph", "Ideographic"},
    156833: {"Unified_Ideograph", "Ideographic"},
    156834: {"Unified_Ideograph", "Ideographic"},
    156835: {"Unified_Ideograph", "Ideographic"},
    156836: {"Unified_Ideograph", "Ideographic"},
    156837: {"Unified_Ideograph", "Ideographic"},
    156838: {"Unified_Ideograph", "Ideographic"},
    156839: {"Unified_Ideograph", "Ideographic"},
    156840: {"Unified_Ideograph", "Ideographic"},
    156841: {"Unified_Ideograph", "Ideographic"},
    156842: {"Unified_Ideograph", "Ideographic"},
    156843: {"Unified_Ideograph", "Ideographic"},
    156844: {"Unified_Ideograph", "Ideographic"},
    156845: {"Unified_Ideograph", "Ideographic"},
    156846: {"Unified_Ideograph", "Ideographic"},
    156847: {"Unified_Ideograph", "Ideographic"},
    156848: {"Unified_Ideograph", "Ideographic"},
    156849: {"Unified_Ideograph", "Ideographic"},
    156850: {"Unified_Ideograph", "Ideographic"},
    156851: {"Unified_Ideograph", "Ideographic"},
    156852: {"Unified_Ideograph", "Ideographic"},
    156853: {"Unified_Ideograph", "Ideographic"},
    156854: {"Unified_Ideograph", "Ideographic"},
    156855: {"Unified_Ideograph", "Ideographic"},
    156856: {"Unified_Ideograph", "Ideographic"},
    156857: {"Unified_Ideograph", "Ideographic"},
    156858: {"Unified_Ideograph", "Ideographic"},
    156859: {"Unified_Ideograph", "Ideographic"},
    156860: {"Unified_Ideograph", "Ideographic"},
    156861: {"Unified_Ideograph", "Ideographic"},
    156862: {"Unified_Ideograph", "Ideographic"},
    156863: {"Unified_Ideograph", "Ideographic"},
    156864: {"Unified_Ideograph", "Ideographic"},
    156865: {"Unified_Ideograph", "Ideographic"},
    156866: {"Unified_Ideograph", "Ideographic"},
    156867: {"Unified_Ideograph", "Ideographic"},
    156868: {"Unified_Ideograph", "Ideographic"},
    156869: {"Unified_Ideograph", "Ideographic"},
    156870: {"Unified_Ideograph", "Ideographic"},
    156871: {"Unified_Ideograph", "Ideographic"},
    156872: {"Unified_Ideograph", "Ideographic"},
    156873: {"Unified_Ideograph", "Ideographic"},
    156874: {"Unified_Ideograph", "Ideographic"},
    156875: {"Unified_Ideograph", "Ideographic"},
    156876: {"Unified_Ideograph", "Ideographic"},
    156877: {"Unified_Ideograph", "Ideographic"},
    156878: {"Unified_Ideograph", "Ideographic"},
    156879: {"Unified_Ideograph", "Ideographic"},
    156880: {"Unified_Ideograph", "Ideographic"},
    156881: {"Unified_Ideograph", "Ideographic"},
    156882: {"Unified_Ideograph", "Ideographic"},
    156883: {"Unified_Ideograph", "Ideographic"},
    156884: {"Unified_Ideograph", "Ideographic"},
    156885: {"Unified_Ideograph", "Ideographic"},
    156886: {"Unified_Ideograph", "Ideographic"},
    156887: {"Unified_Ideograph", "Ideographic"},
    156888: {"Unified_Ideograph", "Ideographic"},
    156889: {"Unified_Ideograph", "Ideographic"},
    156890: {"Unified_Ideograph", "Ideographic"},
    156891: {"Unified_Ideograph", "Ideographic"},
    156892: {"Unified_Ideograph", "Ideographic"},
    156893: {"Unified_Ideograph", "Ideographic"},
    156894: {"Unified_Ideograph", "Ideographic"},
    156895: {"Unified_Ideograph", "Ideographic"},
    156896: {"Unified_Ideograph", "Ideographic"},
    156897: {"Unified_Ideograph", "Ideographic"},
    156898: {"Unified_Ideograph", "Ideographic"},
    156899: {"Unified_Ideograph", "Ideographic"},
    156900: {"Unified_Ideograph", "Ideographic"},
    156901: {"Unified_Ideograph", "Ideographic"},
    156902: {"Unified_Ideograph", "Ideographic"},
    156903: {"Unified_Ideograph", "Ideographic"},
    156904: {"Unified_Ideograph", "Ideographic"},
    156905: {"Unified_Ideograph", "Ideographic"},
    156906: {"Unified_Ideograph", "Ideographic"},
    156907: {"Unified_Ideograph", "Ideographic"},
    156908: {"Unified_Ideograph", "Ideographic"},
    156909: {"Unified_Ideograph", "Ideographic"},
    156910: {"Unified_Ideograph", "Ideographic"},
    156911: {"Unified_Ideograph", "Ideographic"},
    156912: {"Unified_Ideograph", "Ideographic"},
    156913: {"Unified_Ideograph", "Ideographic"},
    156914: {"Unified_Ideograph", "Ideographic"},
    156915: {"Unified_Ideograph", "Ideographic"},
    156916: {"Unified_Ideograph", "Ideographic"},
    156917: {"Unified_Ideograph", "Ideographic"},
    156918: {"Unified_Ideograph", "Ideographic"},
    156919: {"Unified_Ideograph", "Ideographic"},
    156920: {"Unified_Ideograph", "Ideographic"},
    156921: {"Unified_Ideograph", "Ideographic"},
    156922: {"Unified_Ideograph", "Ideographic"},
    156923: {"Unified_Ideograph", "Ideographic"},
    156924: {"Unified_Ideograph", "Ideographic"},
    156925: {"Unified_Ideograph", "Ideographic"},
    156926: {"Unified_Ideograph", "Ideographic"},
    156927: {"Unified_Ideograph", "Ideographic"},
    156928: {"Unified_Ideograph", "Ideographic"},
    156929: {"Unified_Ideograph", "Ideographic"},
    156930: {"Unified_Ideograph", "Ideographic"},
    156931: {"Unified_Ideograph", "Ideographic"},
    156932: {"Unified_Ideograph", "Ideographic"},
    156933: {"Unified_Ideograph", "Ideographic"},
    156934: {"Unified_Ideograph", "Ideographic"},
    156935: {"Unified_Ideograph", "Ideographic"},
    156936: {"Unified_Ideograph", "Ideographic"},
    156937: {"Unified_Ideograph", "Ideographic"},
    156938: {"Unified_Ideograph", "Ideographic"},
    156939: {"Unified_Ideograph", "Ideographic"},
    156940: {"Unified_Ideograph", "Ideographic"},
    156941: {"Unified_Ideograph", "Ideographic"},
    156942: {"Unified_Ideograph", "Ideographic"},
    156943: {"Unified_Ideograph", "Ideographic"},
    156944: {"Unified_Ideograph", "Ideographic"},
    156945: {"Unified_Ideograph", "Ideographic"},
    156946: {"Unified_Ideograph", "Ideographic"},
    156947: {"Unified_Ideograph", "Ideographic"},
    156948: {"Unified_Ideograph", "Ideographic"},
    156949: {"Unified_Ideograph", "Ideographic"},
    156950: {"Unified_Ideograph", "Ideographic"},
    156951: {"Unified_Ideograph", "Ideographic"},
    156952: {"Unified_Ideograph", "Ideographic"},
    156953: {"Unified_Ideograph", "Ideographic"},
    156954: {"Unified_Ideograph", "Ideographic"},
    156955: {"Unified_Ideograph", "Ideographic"},
    156956: {"Unified_Ideograph", "Ideographic"},
    156957: {"Unified_Ideograph", "Ideographic"},
    156958: {"Unified_Ideograph", "Ideographic"},
    156959: {"Unified_Ideograph", "Ideographic"},
    156960: {"Unified_Ideograph", "Ideographic"},
    156961: {"Unified_Ideograph", "Ideographic"},
    156962: {"Unified_Ideograph", "Ideographic"},
    156963: {"Unified_Ideograph", "Ideographic"},
    156964: {"Unified_Ideograph", "Ideographic"},
    156965: {"Unified_Ideograph", "Ideographic"},
    156966: {"Unified_Ideograph", "Ideographic"},
    156967: {"Unified_Ideograph", "Ideographic"},
    156968: {"Unified_Ideograph", "Ideographic"},
    156969: {"Unified_Ideograph", "Ideographic"},
    156970: {"Unified_Ideograph", "Ideographic"},
    156971: {"Unified_Ideograph", "Ideographic"},
    156972: {"Unified_Ideograph", "Ideographic"},
    156973: {"Unified_Ideograph", "Ideographic"},
    156974: {"Unified_Ideograph", "Ideographic"},
    156975: {"Unified_Ideograph", "Ideographic"},
    156976: {"Unified_Ideograph", "Ideographic"},
    156977: {"Unified_Ideograph", "Ideographic"},
    156978: {"Unified_Ideograph", "Ideographic"},
    156979: {"Unified_Ideograph", "Ideographic"},
    156980: {"Unified_Ideograph", "Ideographic"},
    156981: {"Unified_Ideograph", "Ideographic"},
    156982: {"Unified_Ideograph", "Ideographic"},
    156983: {"Unified_Ideograph", "Ideographic"},
    156984: {"Unified_Ideograph", "Ideographic"},
    156985: {"Unified_Ideograph", "Ideographic"},
    156986: {"Unified_Ideograph", "Ideographic"},
    156987: {"Unified_Ideograph", "Ideographic"},
    156988: {"Unified_Ideograph", "Ideographic"},
    156989: {"Unified_Ideograph", "Ideographic"},
    156990: {"Unified_Ideograph", "Ideographic"},
    156991: {"Unified_Ideograph", "Ideographic"},
    156992: {"Unified_Ideograph", "Ideographic"},
    156993: {"Unified_Ideograph", "Ideographic"},
    156994: {"Unified_Ideograph", "Ideographic"},
    156995: {"Unified_Ideograph", "Ideographic"},
    156996: {"Unified_Ideograph", "Ideographic"},
    156997: {"Unified_Ideograph", "Ideographic"},
    156998: {"Unified_Ideograph", "Ideographic"},
    156999: {"Unified_Ideograph", "Ideographic"},
    157000: {"Unified_Ideograph", "Ideographic"},
    157001: {"Unified_Ideograph", "Ideographic"},
    157002: {"Unified_Ideograph", "Ideographic"},
    157003: {"Unified_Ideograph", "Ideographic"},
    157004: {"Unified_Ideograph", "Ideographic"},
    157005: {"Unified_Ideograph", "Ideographic"},
    157006: {"Unified_Ideograph", "Ideographic"},
    157007: {"Unified_Ideograph", "Ideographic"},
    157008: {"Unified_Ideograph", "Ideographic"},
    157009: {"Unified_Ideograph", "Ideographic"},
    157010: {"Unified_Ideograph", "Ideographic"},
    157011: {"Unified_Ideograph", "Ideographic"},
    157012: {"Unified_Ideograph", "Ideographic"},
    157013: {"Unified_Ideograph", "Ideographic"},
    157014: {"Unified_Ideograph", "Ideographic"},
    157015: {"Unified_Ideograph", "Ideographic"},
    157016: {"Unified_Ideograph", "Ideographic"},
    157017: {"Unified_Ideograph", "Ideographic"},
    157018: {"Unified_Ideograph", "Ideographic"},
    157019: {"Unified_Ideograph", "Ideographic"},
    157020: {"Unified_Ideograph", "Ideographic"},
    157021: {"Unified_Ideograph", "Ideographic"},
    157022: {"Unified_Ideograph", "Ideographic"},
    157023: {"Unified_Ideograph", "Ideographic"},
    157024: {"Unified_Ideograph", "Ideographic"},
    157025: {"Unified_Ideograph", "Ideographic"},
    157026: {"Unified_Ideograph", "Ideographic"},
    157027: {"Unified_Ideograph", "Ideographic"},
    157028: {"Unified_Ideograph", "Ideographic"},
    157029: {"Unified_Ideograph", "Ideographic"},
    157030: {"Unified_Ideograph", "Ideographic"},
    157031: {"Unified_Ideograph", "Ideographic"},
    157032: {"Unified_Ideograph", "Ideographic"},
    157033: {"Unified_Ideograph", "Ideographic"},
    157034: {"Unified_Ideograph", "Ideographic"},
    157035: {"Unified_Ideograph", "Ideographic"},
    157036: {"Unified_Ideograph", "Ideographic"},
    157037: {"Unified_Ideograph", "Ideographic"},
    157038: {"Unified_Ideograph", "Ideographic"},
    157039: {"Unified_Ideograph", "Ideographic"},
    157040: {"Unified_Ideograph", "Ideographic"},
    157041: {"Unified_Ideograph", "Ideographic"},
    157042: {"Unified_Ideograph", "Ideographic"},
    157043: {"Unified_Ideograph", "Ideographic"},
    157044: {"Unified_Ideograph", "Ideographic"},
    157045: {"Unified_Ideograph", "Ideographic"},
    157046: {"Unified_Ideograph", "Ideographic"},
    157047: {"Unified_Ideograph", "Ideographic"},
    157048: {"Unified_Ideograph", "Ideographic"},
    157049: {"Unified_Ideograph", "Ideographic"},
    157050: {"Unified_Ideograph", "Ideographic"},
    157051: {"Unified_Ideograph", "Ideographic"},
    157052: {"Unified_Ideograph", "Ideographic"},
    157053: {"Unified_Ideograph", "Ideographic"},
    157054: {"Unified_Ideograph", "Ideographic"},
    157055: {"Unified_Ideograph", "Ideographic"},
    157056: {"Unified_Ideograph", "Ideographic"},
    157057: {"Unified_Ideograph", "Ideographic"},
    157058: {"Unified_Ideograph", "Ideographic"},
    157059: {"Unified_Ideograph", "Ideographic"},
    157060: {"Unified_Ideograph", "Ideographic"},
    157061: {"Unified_Ideograph", "Ideographic"},
    157062: {"Unified_Ideograph", "Ideographic"},
    157063: {"Unified_Ideograph", "Ideographic"},
    157064: {"Unified_Ideograph", "Ideographic"},
    157065: {"Unified_Ideograph", "Ideographic"},
    157066: {"Unified_Ideograph", "Ideographic"},
    157067: {"Unified_Ideograph", "Ideographic"},
    157068: {"Unified_Ideograph", "Ideographic"},
    157069: {"Unified_Ideograph", "Ideographic"},
    157070: {"Unified_Ideograph", "Ideographic"},
    157071: {"Unified_Ideograph", "Ideographic"},
    157072: {"Unified_Ideograph", "Ideographic"},
    157073: {"Unified_Ideograph", "Ideographic"},
    157074: {"Unified_Ideograph", "Ideographic"},
    157075: {"Unified_Ideograph", "Ideographic"},
    157076: {"Unified_Ideograph", "Ideographic"},
    157077: {"Unified_Ideograph", "Ideographic"},
    157078: {"Unified_Ideograph", "Ideographic"},
    157079: {"Unified_Ideograph", "Ideographic"},
    157080: {"Unified_Ideograph", "Ideographic"},
    157081: {"Unified_Ideograph", "Ideographic"},
    157082: {"Unified_Ideograph", "Ideographic"},
    157083: {"Unified_Ideograph", "Ideographic"},
    157084: {"Unified_Ideograph", "Ideographic"},
    157085: {"Unified_Ideograph", "Ideographic"},
    157086: {"Unified_Ideograph", "Ideographic"},
    157087: {"Unified_Ideograph", "Ideographic"},
    157088: {"Unified_Ideograph", "Ideographic"},
    157089: {"Unified_Ideograph", "Ideographic"},
    157090: {"Unified_Ideograph", "Ideographic"},
    157091: {"Unified_Ideograph", "Ideographic"},
    157092: {"Unified_Ideograph", "Ideographic"},
    157093: {"Unified_Ideograph", "Ideographic"},
    157094: {"Unified_Ideograph", "Ideographic"},
    157095: {"Unified_Ideograph", "Ideographic"},
    157096: {"Unified_Ideograph", "Ideographic"},
    157097: {"Unified_Ideograph", "Ideographic"},
    157098: {"Unified_Ideograph", "Ideographic"},
    157099: {"Unified_Ideograph", "Ideographic"},
    157100: {"Unified_Ideograph", "Ideographic"},
    157101: {"Unified_Ideograph", "Ideographic"},
    157102: {"Unified_Ideograph", "Ideographic"},
    157103: {"Unified_Ideograph", "Ideographic"},
    157104: {"Unified_Ideograph", "Ideographic"},
    157105: {"Unified_Ideograph", "Ideographic"},
    157106: {"Unified_Ideograph", "Ideographic"},
    157107: {"Unified_Ideograph", "Ideographic"},
    157108: {"Unified_Ideograph", "Ideographic"},
    157109: {"Unified_Ideograph", "Ideographic"},
    157110: {"Unified_Ideograph", "Ideographic"},
    157111: {"Unified_Ideograph", "Ideographic"},
    157112: {"Unified_Ideograph", "Ideographic"},
    157113: {"Unified_Ideograph", "Ideographic"},
    157114: {"Unified_Ideograph", "Ideographic"},
    157115: {"Unified_Ideograph", "Ideographic"},
    157116: {"Unified_Ideograph", "Ideographic"},
    157117: {"Unified_Ideograph", "Ideographic"},
    157118: {"Unified_Ideograph", "Ideographic"},
    157119: {"Unified_Ideograph", "Ideographic"},
    157120: {"Unified_Ideograph", "Ideographic"},
    157121: {"Unified_Ideograph", "Ideographic"},
    157122: {"Unified_Ideograph", "Ideographic"},
    157123: {"Unified_Ideograph", "Ideographic"},
    157124: {"Unified_Ideograph", "Ideographic"},
    157125: {"Unified_Ideograph", "Ideographic"},
    157126: {"Unified_Ideograph", "Ideographic"},
    157127: {"Unified_Ideograph", "Ideographic"},
    157128: {"Unified_Ideograph", "Ideographic"},
    157129: {"Unified_Ideograph", "Ideographic"},
    157130: {"Unified_Ideograph", "Ideographic"},
    157131: {"Unified_Ideograph", "Ideographic"},
    157132: {"Unified_Ideograph", "Ideographic"},
    157133: {"Unified_Ideograph", "Ideographic"},
    157134: {"Unified_Ideograph", "Ideographic"},
    157135: {"Unified_Ideograph", "Ideographic"},
    157136: {"Unified_Ideograph", "Ideographic"},
    157137: {"Unified_Ideograph", "Ideographic"},
    157138: {"Unified_Ideograph", "Ideographic"},
    157139: {"Unified_Ideograph", "Ideographic"},
    157140: {"Unified_Ideograph", "Ideographic"},
    157141: {"Unified_Ideograph", "Ideographic"},
    157142: {"Unified_Ideograph", "Ideographic"},
    157143: {"Unified_Ideograph", "Ideographic"},
    157144: {"Unified_Ideograph", "Ideographic"},
    157145: {"Unified_Ideograph", "Ideographic"},
    157146: {"Unified_Ideograph", "Ideographic"},
    157147: {"Unified_Ideograph", "Ideographic"},
    157148: {"Unified_Ideograph", "Ideographic"},
    157149: {"Unified_Ideograph", "Ideographic"},
    157150: {"Unified_Ideograph", "Ideographic"},
    157151: {"Unified_Ideograph", "Ideographic"},
    157152: {"Unified_Ideograph", "Ideographic"},
    157153: {"Unified_Ideograph", "Ideographic"},
    157154: {"Unified_Ideograph", "Ideographic"},
    157155: {"Unified_Ideograph", "Ideographic"},
    157156: {"Unified_Ideograph", "Ideographic"},
    157157: {"Unified_Ideograph", "Ideographic"},
    157158: {"Unified_Ideograph", "Ideographic"},
    157159: {"Unified_Ideograph", "Ideographic"},
    157160: {"Unified_Ideograph", "Ideographic"},
    157161: {"Unified_Ideograph", "Ideographic"},
    157162: {"Unified_Ideograph", "Ideographic"},
    157163: {"Unified_Ideograph", "Ideographic"},
    157164: {"Unified_Ideograph", "Ideographic"},
    157165: {"Unified_Ideograph", "Ideographic"},
    157166: {"Unified_Ideograph", "Ideographic"},
    157167: {"Unified_Ideograph", "Ideographic"},
    157168: {"Unified_Ideograph", "Ideographic"},
    157169: {"Unified_Ideograph", "Ideographic"},
    157170: {"Unified_Ideograph", "Ideographic"},
    157171: {"Unified_Ideograph", "Ideographic"},
    157172: {"Unified_Ideograph", "Ideographic"},
    157173: {"Unified_Ideograph", "Ideographic"},
    157174: {"Unified_Ideograph", "Ideographic"},
    157175: {"Unified_Ideograph", "Ideographic"},
    157176: {"Unified_Ideograph", "Ideographic"},
    157177: {"Unified_Ideograph", "Ideographic"},
    157178: {"Unified_Ideograph", "Ideographic"},
    157179: {"Unified_Ideograph", "Ideographic"},
    157180: {"Unified_Ideograph", "Ideographic"},
    157181: {"Unified_Ideograph", "Ideographic"},
    157182: {"Unified_Ideograph", "Ideographic"},
    157183: {"Unified_Ideograph", "Ideographic"},
    157184: {"Unified_Ideograph", "Ideographic"},
    157185: {"Unified_Ideograph", "Ideographic"},
    157186: {"Unified_Ideograph", "Ideographic"},
    157187: {"Unified_Ideograph", "Ideographic"},
    157188: {"Unified_Ideograph", "Ideographic"},
    157189: {"Unified_Ideograph", "Ideographic"},
    157190: {"Unified_Ideograph", "Ideographic"},
    157191: {"Unified_Ideograph", "Ideographic"},
    157192: {"Unified_Ideograph", "Ideographic"},
    157193: {"Unified_Ideograph", "Ideographic"},
    157194: {"Unified_Ideograph", "Ideographic"},
    157195: {"Unified_Ideograph", "Ideographic"},
    157196: {"Unified_Ideograph", "Ideographic"},
    157197: {"Unified_Ideograph", "Ideographic"},
    157198: {"Unified_Ideograph", "Ideographic"},
    157199: {"Unified_Ideograph", "Ideographic"},
    157200: {"Unified_Ideograph", "Ideographic"},
    157201: {"Unified_Ideograph", "Ideographic"},
    157202: {"Unified_Ideograph", "Ideographic"},
    157203: {"Unified_Ideograph", "Ideographic"},
    157204: {"Unified_Ideograph", "Ideographic"},
    157205: {"Unified_Ideograph", "Ideographic"},
    157206: {"Unified_Ideograph", "Ideographic"},
    157207: {"Unified_Ideograph", "Ideographic"},
    157208: {"Unified_Ideograph", "Ideographic"},
    157209: {"Unified_Ideograph", "Ideographic"},
    157210: {"Unified_Ideograph", "Ideographic"},
    157211: {"Unified_Ideograph", "Ideographic"},
    157212: {"Unified_Ideograph", "Ideographic"},
    157213: {"Unified_Ideograph", "Ideographic"},
    157214: {"Unified_Ideograph", "Ideographic"},
    157215: {"Unified_Ideograph", "Ideographic"},
    157216: {"Unified_Ideograph", "Ideographic"},
    157217: {"Unified_Ideograph", "Ideographic"},
    157218: {"Unified_Ideograph", "Ideographic"},
    157219: {"Unified_Ideograph", "Ideographic"},
    157220: {"Unified_Ideograph", "Ideographic"},
    157221: {"Unified_Ideograph", "Ideographic"},
    157222: {"Unified_Ideograph", "Ideographic"},
    157223: {"Unified_Ideograph", "Ideographic"},
    157224: {"Unified_Ideograph", "Ideographic"},
    157225: {"Unified_Ideograph", "Ideographic"},
    157226: {"Unified_Ideograph", "Ideographic"},
    157227: {"Unified_Ideograph", "Ideographic"},
    157228: {"Unified_Ideograph", "Ideographic"},
    157229: {"Unified_Ideograph", "Ideographic"},
    157230: {"Unified_Ideograph", "Ideographic"},
    157231: {"Unified_Ideograph", "Ideographic"},
    157232: {"Unified_Ideograph", "Ideographic"},
    157233: {"Unified_Ideograph", "Ideographic"},
    157234: {"Unified_Ideograph", "Ideographic"},
    157235: {"Unified_Ideograph", "Ideographic"},
    157236: {"Unified_Ideograph", "Ideographic"},
    157237: {"Unified_Ideograph", "Ideographic"},
    157238: {"Unified_Ideograph", "Ideographic"},
    157239: {"Unified_Ideograph", "Ideographic"},
    157240: {"Unified_Ideograph", "Ideographic"},
    157241: {"Unified_Ideograph", "Ideographic"},
    157242: {"Unified_Ideograph", "Ideographic"},
    157243: {"Unified_Ideograph", "Ideographic"},
    157244: {"Unified_Ideograph", "Ideographic"},
    157245: {"Unified_Ideograph", "Ideographic"},
    157246: {"Unified_Ideograph", "Ideographic"},
    157247: {"Unified_Ideograph", "Ideographic"},
    157248: {"Unified_Ideograph", "Ideographic"},
    157249: {"Unified_Ideograph", "Ideographic"},
    157250: {"Unified_Ideograph", "Ideographic"},
    157251: {"Unified_Ideograph", "Ideographic"},
    157252: {"Unified_Ideograph", "Ideographic"},
    157253: {"Unified_Ideograph", "Ideographic"},
    157254: {"Unified_Ideograph", "Ideographic"},
    157255: {"Unified_Ideograph", "Ideographic"},
    157256: {"Unified_Ideograph", "Ideographic"},
    157257: {"Unified_Ideograph", "Ideographic"},
    157258: {"Unified_Ideograph", "Ideographic"},
    157259: {"Unified_Ideograph", "Ideographic"},
    157260: {"Unified_Ideograph", "Ideographic"},
    157261: {"Unified_Ideograph", "Ideographic"},
    157262: {"Unified_Ideograph", "Ideographic"},
    157263: {"Unified_Ideograph", "Ideographic"},
    157264: {"Unified_Ideograph", "Ideographic"},
    157265: {"Unified_Ideograph", "Ideographic"},
    157266: {"Unified_Ideograph", "Ideographic"},
    157267: {"Unified_Ideograph", "Ideographic"},
    157268: {"Unified_Ideograph", "Ideographic"},
    157269: {"Unified_Ideograph", "Ideographic"},
    157270: {"Unified_Ideograph", "Ideographic"},
    157271: {"Unified_Ideograph", "Ideographic"},
    157272: {"Unified_Ideograph", "Ideographic"},
    157273: {"Unified_Ideograph", "Ideographic"},
    157274: {"Unified_Ideograph", "Ideographic"},
    157275: {"Unified_Ideograph", "Ideographic"},
    157276: {"Unified_Ideograph", "Ideographic"},
    157277: {"Unified_Ideograph", "Ideographic"},
    157278: {"Unified_Ideograph", "Ideographic"},
    157279: {"Unified_Ideograph", "Ideographic"},
    157280: {"Unified_Ideograph", "Ideographic"},
    157281: {"Unified_Ideograph", "Ideographic"},
    157282: {"Unified_Ideograph", "Ideographic"},
    157283: {"Unified_Ideograph", "Ideographic"},
    157284: {"Unified_Ideograph", "Ideographic"},
    157285: {"Unified_Ideograph", "Ideographic"},
    157286: {"Unified_Ideograph", "Ideographic"},
    157287: {"Unified_Ideograph", "Ideographic"},
    157288: {"Unified_Ideograph", "Ideographic"},
    157289: {"Unified_Ideograph", "Ideographic"},
    157290: {"Unified_Ideograph", "Ideographic"},
    157291: {"Unified_Ideograph", "Ideographic"},
    157292: {"Unified_Ideograph", "Ideographic"},
    157293: {"Unified_Ideograph", "Ideographic"},
    157294: {"Unified_Ideograph", "Ideographic"},
    157295: {"Unified_Ideograph", "Ideographic"},
    157296: {"Unified_Ideograph", "Ideographic"},
    157297: {"Unified_Ideograph", "Ideographic"},
    157298: {"Unified_Ideograph", "Ideographic"},
    157299: {"Unified_Ideograph", "Ideographic"},
    157300: {"Unified_Ideograph", "Ideographic"},
    157301: {"Unified_Ideograph", "Ideographic"},
    157302: {"Unified_Ideograph", "Ideographic"},
    157303: {"Unified_Ideograph", "Ideographic"},
    157304: {"Unified_Ideograph", "Ideographic"},
    157305: {"Unified_Ideograph", "Ideographic"},
    157306: {"Unified_Ideograph", "Ideographic"},
    157307: {"Unified_Ideograph", "Ideographic"},
    157308: {"Unified_Ideograph", "Ideographic"},
    157309: {"Unified_Ideograph", "Ideographic"},
    157310: {"Unified_Ideograph", "Ideographic"},
    157311: {"Unified_Ideograph", "Ideographic"},
    157312: {"Unified_Ideograph", "Ideographic"},
    157313: {"Unified_Ideograph", "Ideographic"},
    157314: {"Unified_Ideograph", "Ideographic"},
    157315: {"Unified_Ideograph", "Ideographic"},
    157316: {"Unified_Ideograph", "Ideographic"},
    157317: {"Unified_Ideograph", "Ideographic"},
    157318: {"Unified_Ideograph", "Ideographic"},
    157319: {"Unified_Ideograph", "Ideographic"},
    157320: {"Unified_Ideograph", "Ideographic"},
    157321: {"Unified_Ideograph", "Ideographic"},
    157322: {"Unified_Ideograph", "Ideographic"},
    157323: {"Unified_Ideograph", "Ideographic"},
    157324: {"Unified_Ideograph", "Ideographic"},
    157325: {"Unified_Ideograph", "Ideographic"},
    157326: {"Unified_Ideograph", "Ideographic"},
    157327: {"Unified_Ideograph", "Ideographic"},
    157328: {"Unified_Ideograph", "Ideographic"},
    157329: {"Unified_Ideograph", "Ideographic"},
    157330: {"Unified_Ideograph", "Ideographic"},
    157331: {"Unified_Ideograph", "Ideographic"},
    157332: {"Unified_Ideograph", "Ideographic"},
    157333: {"Unified_Ideograph", "Ideographic"},
    157334: {"Unified_Ideograph", "Ideographic"},
    157335: {"Unified_Ideograph", "Ideographic"},
    157336: {"Unified_Ideograph", "Ideographic"},
    157337: {"Unified_Ideograph", "Ideographic"},
    157338: {"Unified_Ideograph", "Ideographic"},
    157339: {"Unified_Ideograph", "Ideographic"},
    157340: {"Unified_Ideograph", "Ideographic"},
    157341: {"Unified_Ideograph", "Ideographic"},
    157342: {"Unified_Ideograph", "Ideographic"},
    157343: {"Unified_Ideograph", "Ideographic"},
    157344: {"Unified_Ideograph", "Ideographic"},
    157345: {"Unified_Ideograph", "Ideographic"},
    157346: {"Unified_Ideograph", "Ideographic"},
    157347: {"Unified_Ideograph", "Ideographic"},
    157348: {"Unified_Ideograph", "Ideographic"},
    157349: {"Unified_Ideograph", "Ideographic"},
    157350: {"Unified_Ideograph", "Ideographic"},
    157351: {"Unified_Ideograph", "Ideographic"},
    157352: {"Unified_Ideograph", "Ideographic"},
    157353: {"Unified_Ideograph", "Ideographic"},
    157354: {"Unified_Ideograph", "Ideographic"},
    157355: {"Unified_Ideograph", "Ideographic"},
    157356: {"Unified_Ideograph", "Ideographic"},
    157357: {"Unified_Ideograph", "Ideographic"},
    157358: {"Unified_Ideograph", "Ideographic"},
    157359: {"Unified_Ideograph", "Ideographic"},
    157360: {"Unified_Ideograph", "Ideographic"},
    157361: {"Unified_Ideograph", "Ideographic"},
    157362: {"Unified_Ideograph", "Ideographic"},
    157363: {"Unified_Ideograph", "Ideographic"},
    157364: {"Unified_Ideograph", "Ideographic"},
    157365: {"Unified_Ideograph", "Ideographic"},
    157366: {"Unified_Ideograph", "Ideographic"},
    157367: {"Unified_Ideograph", "Ideographic"},
    157368: {"Unified_Ideograph", "Ideographic"},
    157369: {"Unified_Ideograph", "Ideographic"},
    157370: {"Unified_Ideograph", "Ideographic"},
    157371: {"Unified_Ideograph", "Ideographic"},
    157372: {"Unified_Ideograph", "Ideographic"},
    157373: {"Unified_Ideograph", "Ideographic"},
    157374: {"Unified_Ideograph", "Ideographic"},
    157375: {"Unified_Ideograph", "Ideographic"},
    157376: {"Unified_Ideograph", "Ideographic"},
    157377: {"Unified_Ideograph", "Ideographic"},
    157378: {"Unified_Ideograph", "Ideographic"},
    157379: {"Unified_Ideograph", "Ideographic"},
    157380: {"Unified_Ideograph", "Ideographic"},
    157381: {"Unified_Ideograph", "Ideographic"},
    157382: {"Unified_Ideograph", "Ideographic"},
    157383: {"Unified_Ideograph", "Ideographic"},
    157384: {"Unified_Ideograph", "Ideographic"},
    157385: {"Unified_Ideograph", "Ideographic"},
    157386: {"Unified_Ideograph", "Ideographic"},
    157387: {"Unified_Ideograph", "Ideographic"},
    157388: {"Unified_Ideograph", "Ideographic"},
    157389: {"Unified_Ideograph", "Ideographic"},
    157390: {"Unified_Ideograph", "Ideographic"},
    157391: {"Unified_Ideograph", "Ideographic"},
    157392: {"Unified_Ideograph", "Ideographic"},
    157393: {"Unified_Ideograph", "Ideographic"},
    157394: {"Unified_Ideograph", "Ideographic"},
    157395: {"Unified_Ideograph", "Ideographic"},
    157396: {"Unified_Ideograph", "Ideographic"},
    157397: {"Unified_Ideograph", "Ideographic"},
    157398: {"Unified_Ideograph", "Ideographic"},
    157399: {"Unified_Ideograph", "Ideographic"},
    157400: {"Unified_Ideograph", "Ideographic"},
    157401: {"Unified_Ideograph", "Ideographic"},
    157402: {"Unified_Ideograph", "Ideographic"},
    157403: {"Unified_Ideograph", "Ideographic"},
    157404: {"Unified_Ideograph", "Ideographic"},
    157405: {"Unified_Ideograph", "Ideographic"},
    157406: {"Unified_Ideograph", "Ideographic"},
    157407: {"Unified_Ideograph", "Ideographic"},
    157408: {"Unified_Ideograph", "Ideographic"},
    157409: {"Unified_Ideograph", "Ideographic"},
    157410: {"Unified_Ideograph", "Ideographic"},
    157411: {"Unified_Ideograph", "Ideographic"},
    157412: {"Unified_Ideograph", "Ideographic"},
    157413: {"Unified_Ideograph", "Ideographic"},
    157414: {"Unified_Ideograph", "Ideographic"},
    157415: {"Unified_Ideograph", "Ideographic"},
    157416: {"Unified_Ideograph", "Ideographic"},
    157417: {"Unified_Ideograph", "Ideographic"},
    157418: {"Unified_Ideograph", "Ideographic"},
    157419: {"Unified_Ideograph", "Ideographic"},
    157420: {"Unified_Ideograph", "Ideographic"},
    157421: {"Unified_Ideograph", "Ideographic"},
    157422: {"Unified_Ideograph", "Ideographic"},
    157423: {"Unified_Ideograph", "Ideographic"},
    157424: {"Unified_Ideograph", "Ideographic"},
    157425: {"Unified_Ideograph", "Ideographic"},
    157426: {"Unified_Ideograph", "Ideographic"},
    157427: {"Unified_Ideograph", "Ideographic"},
    157428: {"Unified_Ideograph", "Ideographic"},
    157429: {"Unified_Ideograph", "Ideographic"},
    157430: {"Unified_Ideograph", "Ideographic"},
    157431: {"Unified_Ideograph", "Ideographic"},
    157432: {"Unified_Ideograph", "Ideographic"},
    157433: {"Unified_Ideograph", "Ideographic"},
    157434: {"Unified_Ideograph", "Ideographic"},
    157435: {"Unified_Ideograph", "Ideographic"},
    157436: {"Unified_Ideograph", "Ideographic"},
    157437: {"Unified_Ideograph", "Ideographic"},
    157438: {"Unified_Ideograph", "Ideographic"},
    157439: {"Unified_Ideograph", "Ideographic"},
    157440: {"Unified_Ideograph", "Ideographic"},
    157441: {"Unified_Ideograph", "Ideographic"},
    157442: {"Unified_Ideograph", "Ideographic"},
    157443: {"Unified_Ideograph", "Ideographic"},
    157444: {"Unified_Ideograph", "Ideographic"},
    157445: {"Unified_Ideograph", "Ideographic"},
    157446: {"Unified_Ideograph", "Ideographic"},
    157447: {"Unified_Ideograph", "Ideographic"},
    157448: {"Unified_Ideograph", "Ideographic"},
    157449: {"Unified_Ideograph", "Ideographic"},
    157450: {"Unified_Ideograph", "Ideographic"},
    157451: {"Unified_Ideograph", "Ideographic"},
    157452: {"Unified_Ideograph", "Ideographic"},
    157453: {"Unified_Ideograph", "Ideographic"},
    157454: {"Unified_Ideograph", "Ideographic"},
    157455: {"Unified_Ideograph", "Ideographic"},
    157456: {"Unified_Ideograph", "Ideographic"},
    157457: {"Unified_Ideograph", "Ideographic"},
    157458: {"Unified_Ideograph", "Ideographic"},
    157459: {"Unified_Ideograph", "Ideographic"},
    157460: {"Unified_Ideograph", "Ideographic"},
    157461: {"Unified_Ideograph", "Ideographic"},
    157462: {"Unified_Ideograph", "Ideographic"},
    157463: {"Unified_Ideograph", "Ideographic"},
    157464: {"Unified_Ideograph", "Ideographic"},
    157465: {"Unified_Ideograph", "Ideographic"},
    157466: {"Unified_Ideograph", "Ideographic"},
    157467: {"Unified_Ideograph", "Ideographic"},
    157468: {"Unified_Ideograph", "Ideographic"},
    157469: {"Unified_Ideograph", "Ideographic"},
    157470: {"Unified_Ideograph", "Ideographic"},
    157471: {"Unified_Ideograph", "Ideographic"},
    157472: {"Unified_Ideograph", "Ideographic"},
    157473: {"Unified_Ideograph", "Ideographic"},
    157474: {"Unified_Ideograph", "Ideographic"},
    157475: {"Unified_Ideograph", "Ideographic"},
    157476: {"Unified_Ideograph", "Ideographic"},
    157477: {"Unified_Ideograph", "Ideographic"},
    157478: {"Unified_Ideograph", "Ideographic"},
    157479: {"Unified_Ideograph", "Ideographic"},
    157480: {"Unified_Ideograph", "Ideographic"},
    157481: {"Unified_Ideograph", "Ideographic"},
    157482: {"Unified_Ideograph", "Ideographic"},
    157483: {"Unified_Ideograph", "Ideographic"},
    157484: {"Unified_Ideograph", "Ideographic"},
    157485: {"Unified_Ideograph", "Ideographic"},
    157486: {"Unified_Ideograph", "Ideographic"},
    157487: {"Unified_Ideograph", "Ideographic"},
    157488: {"Unified_Ideograph", "Ideographic"},
    157489: {"Unified_Ideograph", "Ideographic"},
    157490: {"Unified_Ideograph", "Ideographic"},
    157491: {"Unified_Ideograph", "Ideographic"},
    157492: {"Unified_Ideograph", "Ideographic"},
    157493: {"Unified_Ideograph", "Ideographic"},
    157494: {"Unified_Ideograph", "Ideographic"},
    157495: {"Unified_Ideograph", "Ideographic"},
    157496: {"Unified_Ideograph", "Ideographic"},
    157497: {"Unified_Ideograph", "Ideographic"},
    157498: {"Unified_Ideograph", "Ideographic"},
    157499: {"Unified_Ideograph", "Ideographic"},
    157500: {"Unified_Ideograph", "Ideographic"},
    157501: {"Unified_Ideograph", "Ideographic"},
    157502: {"Unified_Ideograph", "Ideographic"},
    157503: {"Unified_Ideograph", "Ideographic"},
    157504: {"Unified_Ideograph", "Ideographic"},
    157505: {"Unified_Ideograph", "Ideographic"},
    157506: {"Unified_Ideograph", "Ideographic"},
    157507: {"Unified_Ideograph", "Ideographic"},
    157508: {"Unified_Ideograph", "Ideographic"},
    157509: {"Unified_Ideograph", "Ideographic"},
    157510: {"Unified_Ideograph", "Ideographic"},
    157511: {"Unified_Ideograph", "Ideographic"},
    157512: {"Unified_Ideograph", "Ideographic"},
    157513: {"Unified_Ideograph", "Ideographic"},
    157514: {"Unified_Ideograph", "Ideographic"},
    157515: {"Unified_Ideograph", "Ideographic"},
    157516: {"Unified_Ideograph", "Ideographic"},
    157517: {"Unified_Ideograph", "Ideographic"},
    157518: {"Unified_Ideograph", "Ideographic"},
    157519: {"Unified_Ideograph", "Ideographic"},
    157520: {"Unified_Ideograph", "Ideographic"},
    157521: {"Unified_Ideograph", "Ideographic"},
    157522: {"Unified_Ideograph", "Ideographic"},
    157523: {"Unified_Ideograph", "Ideographic"},
    157524: {"Unified_Ideograph", "Ideographic"},
    157525: {"Unified_Ideograph", "Ideographic"},
    157526: {"Unified_Ideograph", "Ideographic"},
    157527: {"Unified_Ideograph", "Ideographic"},
    157528: {"Unified_Ideograph", "Ideographic"},
    157529: {"Unified_Ideograph", "Ideographic"},
    157530: {"Unified_Ideograph", "Ideographic"},
    157531: {"Unified_Ideograph", "Ideographic"},
    157532: {"Unified_Ideograph", "Ideographic"},
    157533: {"Unified_Ideograph", "Ideographic"},
    157534: {"Unified_Ideograph", "Ideographic"},
    157535: {"Unified_Ideograph", "Ideographic"},
    157536: {"Unified_Ideograph", "Ideographic"},
    157537: {"Unified_Ideograph", "Ideographic"},
    157538: {"Unified_Ideograph", "Ideographic"},
    157539: {"Unified_Ideograph", "Ideographic"},
    157540: {"Unified_Ideograph", "Ideographic"},
    157541: {"Unified_Ideograph", "Ideographic"},
    157542: {"Unified_Ideograph", "Ideographic"},
    157543: {"Unified_Ideograph", "Ideographic"},
    157544: {"Unified_Ideograph", "Ideographic"},
    157545: {"Unified_Ideograph", "Ideographic"},
    157546: {"Unified_Ideograph", "Ideographic"},
    157547: {"Unified_Ideograph", "Ideographic"},
    157548: {"Unified_Ideograph", "Ideographic"},
    157549: {"Unified_Ideograph", "Ideographic"},
    157550: {"Unified_Ideograph", "Ideographic"},
    157551: {"Unified_Ideograph", "Ideographic"},
    157552: {"Unified_Ideograph", "Ideographic"},
    157553: {"Unified_Ideograph", "Ideographic"},
    157554: {"Unified_Ideograph", "Ideographic"},
    157555: {"Unified_Ideograph", "Ideographic"},
    157556: {"Unified_Ideograph", "Ideographic"},
    157557: {"Unified_Ideograph", "Ideographic"},
    157558: {"Unified_Ideograph", "Ideographic"},
    157559: {"Unified_Ideograph", "Ideographic"},
    157560: {"Unified_Ideograph", "Ideographic"},
    157561: {"Unified_Ideograph", "Ideographic"},
    157562: {"Unified_Ideograph", "Ideographic"},
    157563: {"Unified_Ideograph", "Ideographic"},
    157564: {"Unified_Ideograph", "Ideographic"},
    157565: {"Unified_Ideograph", "Ideographic"},
    157566: {"Unified_Ideograph", "Ideographic"},
    157567: {"Unified_Ideograph", "Ideographic"},
    157568: {"Unified_Ideograph", "Ideographic"},
    157569: {"Unified_Ideograph", "Ideographic"},
    157570: {"Unified_Ideograph", "Ideographic"},
    157571: {"Unified_Ideograph", "Ideographic"},
    157572: {"Unified_Ideograph", "Ideographic"},
    157573: {"Unified_Ideograph", "Ideographic"},
    157574: {"Unified_Ideograph", "Ideographic"},
    157575: {"Unified_Ideograph", "Ideographic"},
    157576: {"Unified_Ideograph", "Ideographic"},
    157577: {"Unified_Ideograph", "Ideographic"},
    157578: {"Unified_Ideograph", "Ideographic"},
    157579: {"Unified_Ideograph", "Ideographic"},
    157580: {"Unified_Ideograph", "Ideographic"},
    157581: {"Unified_Ideograph", "Ideographic"},
    157582: {"Unified_Ideograph", "Ideographic"},
    157583: {"Unified_Ideograph", "Ideographic"},
    157584: {"Unified_Ideograph", "Ideographic"},
    157585: {"Unified_Ideograph", "Ideographic"},
    157586: {"Unified_Ideograph", "Ideographic"},
    157587: {"Unified_Ideograph", "Ideographic"},
    157588: {"Unified_Ideograph", "Ideographic"},
    157589: {"Unified_Ideograph", "Ideographic"},
    157590: {"Unified_Ideograph", "Ideographic"},
    157591: {"Unified_Ideograph", "Ideographic"},
    157592: {"Unified_Ideograph", "Ideographic"},
    157593: {"Unified_Ideograph", "Ideographic"},
    157594: {"Unified_Ideograph", "Ideographic"},
    157595: {"Unified_Ideograph", "Ideographic"},
    157596: {"Unified_Ideograph", "Ideographic"},
    157597: {"Unified_Ideograph", "Ideographic"},
    157598: {"Unified_Ideograph", "Ideographic"},
    157599: {"Unified_Ideograph", "Ideographic"},
    157600: {"Unified_Ideograph", "Ideographic"},
    157601: {"Unified_Ideograph", "Ideographic"},
    157602: {"Unified_Ideograph", "Ideographic"},
    157603: {"Unified_Ideograph", "Ideographic"},
    157604: {"Unified_Ideograph", "Ideographic"},
    157605: {"Unified_Ideograph", "Ideographic"},
    157606: {"Unified_Ideograph", "Ideographic"},
    157607: {"Unified_Ideograph", "Ideographic"},
    157608: {"Unified_Ideograph", "Ideographic"},
    157609: {"Unified_Ideograph", "Ideographic"},
    157610: {"Unified_Ideograph", "Ideographic"},
    157611: {"Unified_Ideograph", "Ideographic"},
    157612: {"Unified_Ideograph", "Ideographic"},
    157613: {"Unified_Ideograph", "Ideographic"},
    157614: {"Unified_Ideograph", "Ideographic"},
    157615: {"Unified_Ideograph", "Ideographic"},
    157616: {"Unified_Ideograph", "Ideographic"},
    157617: {"Unified_Ideograph", "Ideographic"},
    157618: {"Unified_Ideograph", "Ideographic"},
    157619: {"Unified_Ideograph", "Ideographic"},
    157620: {"Unified_Ideograph", "Ideographic"},
    157621: {"Unified_Ideograph", "Ideographic"},
    157622: {"Unified_Ideograph", "Ideographic"},
    157623: {"Unified_Ideograph", "Ideographic"},
    157624: {"Unified_Ideograph", "Ideographic"},
    157625: {"Unified_Ideograph", "Ideographic"},
    157626: {"Unified_Ideograph", "Ideographic"},
    157627: {"Unified_Ideograph", "Ideographic"},
    157628: {"Unified_Ideograph", "Ideographic"},
    157629: {"Unified_Ideograph", "Ideographic"},
    157630: {"Unified_Ideograph", "Ideographic"},
    157631: {"Unified_Ideograph", "Ideographic"},
    157632: {"Unified_Ideograph", "Ideographic"},
    157633: {"Unified_Ideograph", "Ideographic"},
    157634: {"Unified_Ideograph", "Ideographic"},
    157635: {"Unified_Ideograph", "Ideographic"},
    157636: {"Unified_Ideograph", "Ideographic"},
    157637: {"Unified_Ideograph", "Ideographic"},
    157638: {"Unified_Ideograph", "Ideographic"},
    157639: {"Unified_Ideograph", "Ideographic"},
    157640: {"Unified_Ideograph", "Ideographic"},
    157641: {"Unified_Ideograph", "Ideographic"},
    157642: {"Unified_Ideograph", "Ideographic"},
    157643: {"Unified_Ideograph", "Ideographic"},
    157644: {"Unified_Ideograph", "Ideographic"},
    157645: {"Unified_Ideograph", "Ideographic"},
    157646: {"Unified_Ideograph", "Ideographic"},
    157647: {"Unified_Ideograph", "Ideographic"},
    157648: {"Unified_Ideograph", "Ideographic"},
    157649: {"Unified_Ideograph", "Ideographic"},
    157650: {"Unified_Ideograph", "Ideographic"},
    157651: {"Unified_Ideograph", "Ideographic"},
    157652: {"Unified_Ideograph", "Ideographic"},
    157653: {"Unified_Ideograph", "Ideographic"},
    157654: {"Unified_Ideograph", "Ideographic"},
    157655: {"Unified_Ideograph", "Ideographic"},
    157656: {"Unified_Ideograph", "Ideographic"},
    157657: {"Unified_Ideograph", "Ideographic"},
    157658: {"Unified_Ideograph", "Ideographic"},
    157659: {"Unified_Ideograph", "Ideographic"},
    157660: {"Unified_Ideograph", "Ideographic"},
    157661: {"Unified_Ideograph", "Ideographic"},
    157662: {"Unified_Ideograph", "Ideographic"},
    157663: {"Unified_Ideograph", "Ideographic"},
    157664: {"Unified_Ideograph", "Ideographic"},
    157665: {"Unified_Ideograph", "Ideographic"},
    157666: {"Unified_Ideograph", "Ideographic"},
    157667: {"Unified_Ideograph", "Ideographic"},
    157668: {"Unified_Ideograph", "Ideographic"},
    157669: {"Unified_Ideograph", "Ideographic"},
    157670: {"Unified_Ideograph", "Ideographic"},
    157671: {"Unified_Ideograph", "Ideographic"},
    157672: {"Unified_Ideograph", "Ideographic"},
    157673: {"Unified_Ideograph", "Ideographic"},
    157674: {"Unified_Ideograph", "Ideographic"},
    157675: {"Unified_Ideograph", "Ideographic"},
    157676: {"Unified_Ideograph", "Ideographic"},
    157677: {"Unified_Ideograph", "Ideographic"},
    157678: {"Unified_Ideograph", "Ideographic"},
    157679: {"Unified_Ideograph", "Ideographic"},
    157680: {"Unified_Ideograph", "Ideographic"},
    157681: {"Unified_Ideograph", "Ideographic"},
    157682: {"Unified_Ideograph", "Ideographic"},
    157683: {"Unified_Ideograph", "Ideographic"},
    157684: {"Unified_Ideograph", "Ideographic"},
    157685: {"Unified_Ideograph", "Ideographic"},
    157686: {"Unified_Ideograph", "Ideographic"},
    157687: {"Unified_Ideograph", "Ideographic"},
    157688: {"Unified_Ideograph", "Ideographic"},
    157689: {"Unified_Ideograph", "Ideographic"},
    157690: {"Unified_Ideograph", "Ideographic"},
    157691: {"Unified_Ideograph", "Ideographic"},
    157692: {"Unified_Ideograph", "Ideographic"},
    157693: {"Unified_Ideograph", "Ideographic"},
    157694: {"Unified_Ideograph", "Ideographic"},
    157695: {"Unified_Ideograph", "Ideographic"},
    157696: {"Unified_Ideograph", "Ideographic"},
    157697: {"Unified_Ideograph", "Ideographic"},
    157698: {"Unified_Ideograph", "Ideographic"},
    157699: {"Unified_Ideograph", "Ideographic"},
    157700: {"Unified_Ideograph", "Ideographic"},
    157701: {"Unified_Ideograph", "Ideographic"},
    157702: {"Unified_Ideograph", "Ideographic"},
    157703: {"Unified_Ideograph", "Ideographic"},
    157704: {"Unified_Ideograph", "Ideographic"},
    157705: {"Unified_Ideograph", "Ideographic"},
    157706: {"Unified_Ideograph", "Ideographic"},
    157707: {"Unified_Ideograph", "Ideographic"},
    157708: {"Unified_Ideograph", "Ideographic"},
    157709: {"Unified_Ideograph", "Ideographic"},
    157710: {"Unified_Ideograph", "Ideographic"},
    157711: {"Unified_Ideograph", "Ideographic"},
    157712: {"Unified_Ideograph", "Ideographic"},
    157713: {"Unified_Ideograph", "Ideographic"},
    157714: {"Unified_Ideograph", "Ideographic"},
    157715: {"Unified_Ideograph", "Ideographic"},
    157716: {"Unified_Ideograph", "Ideographic"},
    157717: {"Unified_Ideograph", "Ideographic"},
    157718: {"Unified_Ideograph", "Ideographic"},
    157719: {"Unified_Ideograph", "Ideographic"},
    157720: {"Unified_Ideograph", "Ideographic"},
    157721: {"Unified_Ideograph", "Ideographic"},
    157722: {"Unified_Ideograph", "Ideographic"},
    157723: {"Unified_Ideograph", "Ideographic"},
    157724: {"Unified_Ideograph", "Ideographic"},
    157725: {"Unified_Ideograph", "Ideographic"},
    157726: {"Unified_Ideograph", "Ideographic"},
    157727: {"Unified_Ideograph", "Ideographic"},
    157728: {"Unified_Ideograph", "Ideographic"},
    157729: {"Unified_Ideograph", "Ideographic"},
    157730: {"Unified_Ideograph", "Ideographic"},
    157731: {"Unified_Ideograph", "Ideographic"},
    157732: {"Unified_Ideograph", "Ideographic"},
    157733: {"Unified_Ideograph", "Ideographic"},
    157734: {"Unified_Ideograph", "Ideographic"},
    157735: {"Unified_Ideograph", "Ideographic"},
    157736: {"Unified_Ideograph", "Ideographic"},
    157737: {"Unified_Ideograph", "Ideographic"},
    157738: {"Unified_Ideograph", "Ideographic"},
    157739: {"Unified_Ideograph", "Ideographic"},
    157740: {"Unified_Ideograph", "Ideographic"},
    157741: {"Unified_Ideograph", "Ideographic"},
    157742: {"Unified_Ideograph", "Ideographic"},
    157743: {"Unified_Ideograph", "Ideographic"},
    157744: {"Unified_Ideograph", "Ideographic"},
    157745: {"Unified_Ideograph", "Ideographic"},
    157746: {"Unified_Ideograph", "Ideographic"},
    157747: {"Unified_Ideograph", "Ideographic"},
    157748: {"Unified_Ideograph", "Ideographic"},
    157749: {"Unified_Ideograph", "Ideographic"},
    157750: {"Unified_Ideograph", "Ideographic"},
    157751: {"Unified_Ideograph", "Ideographic"},
    157752: {"Unified_Ideograph", "Ideographic"},
    157753: {"Unified_Ideograph", "Ideographic"},
    157754: {"Unified_Ideograph", "Ideographic"},
    157755: {"Unified_Ideograph", "Ideographic"},
    157756: {"Unified_Ideograph", "Ideographic"},
    157757: {"Unified_Ideograph", "Ideographic"},
    157758: {"Unified_Ideograph", "Ideographic"},
    157759: {"Unified_Ideograph", "Ideographic"},
    157760: {"Unified_Ideograph", "Ideographic"},
    157761: {"Unified_Ideograph", "Ideographic"},
    157762: {"Unified_Ideograph", "Ideographic"},
    157763: {"Unified_Ideograph", "Ideographic"},
    157764: {"Unified_Ideograph", "Ideographic"},
    157765: {"Unified_Ideograph", "Ideographic"},
    157766: {"Unified_Ideograph", "Ideographic"},
    157767: {"Unified_Ideograph", "Ideographic"},
    157768: {"Unified_Ideograph", "Ideographic"},
    157769: {"Unified_Ideograph", "Ideographic"},
    157770: {"Unified_Ideograph", "Ideographic"},
    157771: {"Unified_Ideograph", "Ideographic"},
    157772: {"Unified_Ideograph", "Ideographic"},
    157773: {"Unified_Ideograph", "Ideographic"},
    157774: {"Unified_Ideograph", "Ideographic"},
    157775: {"Unified_Ideograph", "Ideographic"},
    157776: {"Unified_Ideograph", "Ideographic"},
    157777: {"Unified_Ideograph", "Ideographic"},
    157778: {"Unified_Ideograph", "Ideographic"},
    157779: {"Unified_Ideograph", "Ideographic"},
    157780: {"Unified_Ideograph", "Ideographic"},
    157781: {"Unified_Ideograph", "Ideographic"},
    157782: {"Unified_Ideograph", "Ideographic"},
    157783: {"Unified_Ideograph", "Ideographic"},
    157784: {"Unified_Ideograph", "Ideographic"},
    157785: {"Unified_Ideograph", "Ideographic"},
    157786: {"Unified_Ideograph", "Ideographic"},
    157787: {"Unified_Ideograph", "Ideographic"},
    157788: {"Unified_Ideograph", "Ideographic"},
    157789: {"Unified_Ideograph", "Ideographic"},
    157790: {"Unified_Ideograph", "Ideographic"},
    157791: {"Unified_Ideograph", "Ideographic"},
    157792: {"Unified_Ideograph", "Ideographic"},
    157793: {"Unified_Ideograph", "Ideographic"},
    157794: {"Unified_Ideograph", "Ideographic"},
    157795: {"Unified_Ideograph", "Ideographic"},
    157796: {"Unified_Ideograph", "Ideographic"},
    157797: {"Unified_Ideograph", "Ideographic"},
    157798: {"Unified_Ideograph", "Ideographic"},
    157799: {"Unified_Ideograph", "Ideographic"},
    157800: {"Unified_Ideograph", "Ideographic"},
    157801: {"Unified_Ideograph", "Ideographic"},
    157802: {"Unified_Ideograph", "Ideographic"},
    157803: {"Unified_Ideograph", "Ideographic"},
    157804: {"Unified_Ideograph", "Ideographic"},
    157805: {"Unified_Ideograph", "Ideographic"},
    157806: {"Unified_Ideograph", "Ideographic"},
    157807: {"Unified_Ideograph", "Ideographic"},
    157808: {"Unified_Ideograph", "Ideographic"},
    157809: {"Unified_Ideograph", "Ideographic"},
    157810: {"Unified_Ideograph", "Ideographic"},
    157811: {"Unified_Ideograph", "Ideographic"},
    157812: {"Unified_Ideograph", "Ideographic"},
    157813: {"Unified_Ideograph", "Ideographic"},
    157814: {"Unified_Ideograph", "Ideographic"},
    157815: {"Unified_Ideograph", "Ideographic"},
    157816: {"Unified_Ideograph", "Ideographic"},
    157817: {"Unified_Ideograph", "Ideographic"},
    157818: {"Unified_Ideograph", "Ideographic"},
    157819: {"Unified_Ideograph", "Ideographic"},
    157820: {"Unified_Ideograph", "Ideographic"},
    157821: {"Unified_Ideograph", "Ideographic"},
    157822: {"Unified_Ideograph", "Ideographic"},
    157823: {"Unified_Ideograph", "Ideographic"},
    157824: {"Unified_Ideograph", "Ideographic"},
    157825: {"Unified_Ideograph", "Ideographic"},
    157826: {"Unified_Ideograph", "Ideographic"},
    157827: {"Unified_Ideograph", "Ideographic"},
    157828: {"Unified_Ideograph", "Ideographic"},
    157829: {"Unified_Ideograph", "Ideographic"},
    157830: {"Unified_Ideograph", "Ideographic"},
    157831: {"Unified_Ideograph", "Ideographic"},
    157832: {"Unified_Ideograph", "Ideographic"},
    157833: {"Unified_Ideograph", "Ideographic"},
    157834: {"Unified_Ideograph", "Ideographic"},
    157835: {"Unified_Ideograph", "Ideographic"},
    157836: {"Unified_Ideograph", "Ideographic"},
    157837: {"Unified_Ideograph", "Ideographic"},
    157838: {"Unified_Ideograph", "Ideographic"},
    157839: {"Unified_Ideograph", "Ideographic"},
    157840: {"Unified_Ideograph", "Ideographic"},
    157841: {"Unified_Ideograph", "Ideographic"},
    157842: {"Unified_Ideograph", "Ideographic"},
    157843: {"Unified_Ideograph", "Ideographic"},
    157844: {"Unified_Ideograph", "Ideographic"},
    157845: {"Unified_Ideograph", "Ideographic"},
    157846: {"Unified_Ideograph", "Ideographic"},
    157847: {"Unified_Ideograph", "Ideographic"},
    157848: {"Unified_Ideograph", "Ideographic"},
    157849: {"Unified_Ideograph", "Ideographic"},
    157850: {"Unified_Ideograph", "Ideographic"},
    157851: {"Unified_Ideograph", "Ideographic"},
    157852: {"Unified_Ideograph", "Ideographic"},
    157853: {"Unified_Ideograph", "Ideographic"},
    157854: {"Unified_Ideograph", "Ideographic"},
    157855: {"Unified_Ideograph", "Ideographic"},
    157856: {"Unified_Ideograph", "Ideographic"},
    157857: {"Unified_Ideograph", "Ideographic"},
    157858: {"Unified_Ideograph", "Ideographic"},
    157859: {"Unified_Ideograph", "Ideographic"},
    157860: {"Unified_Ideograph", "Ideographic"},
    157861: {"Unified_Ideograph", "Ideographic"},
    157862: {"Unified_Ideograph", "Ideographic"},
    157863: {"Unified_Ideograph", "Ideographic"},
    157864: {"Unified_Ideograph", "Ideographic"},
    157865: {"Unified_Ideograph", "Ideographic"},
    157866: {"Unified_Ideograph", "Ideographic"},
    157867: {"Unified_Ideograph", "Ideographic"},
    157868: {"Unified_Ideograph", "Ideographic"},
    157869: {"Unified_Ideograph", "Ideographic"},
    157870: {"Unified_Ideograph", "Ideographic"},
    157871: {"Unified_Ideograph", "Ideographic"},
    157872: {"Unified_Ideograph", "Ideographic"},
    157873: {"Unified_Ideograph", "Ideographic"},
    157874: {"Unified_Ideograph", "Ideographic"},
    157875: {"Unified_Ideograph", "Ideographic"},
    157876: {"Unified_Ideograph", "Ideographic"},
    157877: {"Unified_Ideograph", "Ideographic"},
    157878: {"Unified_Ideograph", "Ideographic"},
    157879: {"Unified_Ideograph", "Ideographic"},
    157880: {"Unified_Ideograph", "Ideographic"},
    157881: {"Unified_Ideograph", "Ideographic"},
    157882: {"Unified_Ideograph", "Ideographic"},
    157883: {"Unified_Ideograph", "Ideographic"},
    157884: {"Unified_Ideograph", "Ideographic"},
    157885: {"Unified_Ideograph", "Ideographic"},
    157886: {"Unified_Ideograph", "Ideographic"},
    157887: {"Unified_Ideograph", "Ideographic"},
    157888: {"Unified_Ideograph", "Ideographic"},
    157889: {"Unified_Ideograph", "Ideographic"},
    157890: {"Unified_Ideograph", "Ideographic"},
    157891: {"Unified_Ideograph", "Ideographic"},
    157892: {"Unified_Ideograph", "Ideographic"},
    157893: {"Unified_Ideograph", "Ideographic"},
    157894: {"Unified_Ideograph", "Ideographic"},
    157895: {"Unified_Ideograph", "Ideographic"},
    157896: {"Unified_Ideograph", "Ideographic"},
    157897: {"Unified_Ideograph", "Ideographic"},
    157898: {"Unified_Ideograph", "Ideographic"},
    157899: {"Unified_Ideograph", "Ideographic"},
    157900: {"Unified_Ideograph", "Ideographic"},
    157901: {"Unified_Ideograph", "Ideographic"},
    157902: {"Unified_Ideograph", "Ideographic"},
    157903: {"Unified_Ideograph", "Ideographic"},
    157904: {"Unified_Ideograph", "Ideographic"},
    157905: {"Unified_Ideograph", "Ideographic"},
    157906: {"Unified_Ideograph", "Ideographic"},
    157907: {"Unified_Ideograph", "Ideographic"},
    157908: {"Unified_Ideograph", "Ideographic"},
    157909: {"Unified_Ideograph", "Ideographic"},
    157910: {"Unified_Ideograph", "Ideographic"},
    157911: {"Unified_Ideograph", "Ideographic"},
    157912: {"Unified_Ideograph", "Ideographic"},
    157913: {"Unified_Ideograph", "Ideographic"},
    157914: {"Unified_Ideograph", "Ideographic"},
    157915: {"Unified_Ideograph", "Ideographic"},
    157916: {"Unified_Ideograph", "Ideographic"},
    157917: {"Unified_Ideograph", "Ideographic"},
    157918: {"Unified_Ideograph", "Ideographic"},
    157919: {"Unified_Ideograph", "Ideographic"},
    157920: {"Unified_Ideograph", "Ideographic"},
    157921: {"Unified_Ideograph", "Ideographic"},
    157922: {"Unified_Ideograph", "Ideographic"},
    157923: {"Unified_Ideograph", "Ideographic"},
    157924: {"Unified_Ideograph", "Ideographic"},
    157925: {"Unified_Ideograph", "Ideographic"},
    157926: {"Unified_Ideograph", "Ideographic"},
    157927: {"Unified_Ideograph", "Ideographic"},
    157928: {"Unified_Ideograph", "Ideographic"},
    157929: {"Unified_Ideograph", "Ideographic"},
    157930: {"Unified_Ideograph", "Ideographic"},
    157931: {"Unified_Ideograph", "Ideographic"},
    157932: {"Unified_Ideograph", "Ideographic"},
    157933: {"Unified_Ideograph", "Ideographic"},
    157934: {"Unified_Ideograph", "Ideographic"},
    157935: {"Unified_Ideograph", "Ideographic"},
    157936: {"Unified_Ideograph", "Ideographic"},
    157937: {"Unified_Ideograph", "Ideographic"},
    157938: {"Unified_Ideograph", "Ideographic"},
    157939: {"Unified_Ideograph", "Ideographic"},
    157940: {"Unified_Ideograph", "Ideographic"},
    157941: {"Unified_Ideograph", "Ideographic"},
    157942: {"Unified_Ideograph", "Ideographic"},
    157943: {"Unified_Ideograph", "Ideographic"},
    157944: {"Unified_Ideograph", "Ideographic"},
    157945: {"Unified_Ideograph", "Ideographic"},
    157946: {"Unified_Ideograph", "Ideographic"},
    157947: {"Unified_Ideograph", "Ideographic"},
    157948: {"Unified_Ideograph", "Ideographic"},
    157949: {"Unified_Ideograph", "Ideographic"},
    157950: {"Unified_Ideograph", "Ideographic"},
    157951: {"Unified_Ideograph", "Ideographic"},
    157952: {"Unified_Ideograph", "Ideographic"},
    157953: {"Unified_Ideograph", "Ideographic"},
    157954: {"Unified_Ideograph", "Ideographic"},
    157955: {"Unified_Ideograph", "Ideographic"},
    157956: {"Unified_Ideograph", "Ideographic"},
    157957: {"Unified_Ideograph", "Ideographic"},
    157958: {"Unified_Ideograph", "Ideographic"},
    157959: {"Unified_Ideograph", "Ideographic"},
    157960: {"Unified_Ideograph", "Ideographic"},
    157961: {"Unified_Ideograph", "Ideographic"},
    157962: {"Unified_Ideograph", "Ideographic"},
    157963: {"Unified_Ideograph", "Ideographic"},
    157964: {"Unified_Ideograph", "Ideographic"},
    157965: {"Unified_Ideograph", "Ideographic"},
    157966: {"Unified_Ideograph", "Ideographic"},
    157967: {"Unified_Ideograph", "Ideographic"},
    157968: {"Unified_Ideograph", "Ideographic"},
    157969: {"Unified_Ideograph", "Ideographic"},
    157970: {"Unified_Ideograph", "Ideographic"},
    157971: {"Unified_Ideograph", "Ideographic"},
    157972: {"Unified_Ideograph", "Ideographic"},
    157973: {"Unified_Ideograph", "Ideographic"},
    157974: {"Unified_Ideograph", "Ideographic"},
    157975: {"Unified_Ideograph", "Ideographic"},
    157976: {"Unified_Ideograph", "Ideographic"},
    157977: {"Unified_Ideograph", "Ideographic"},
    157978: {"Unified_Ideograph", "Ideographic"},
    157979: {"Unified_Ideograph", "Ideographic"},
    157980: {"Unified_Ideograph", "Ideographic"},
    157981: {"Unified_Ideograph", "Ideographic"},
    157982: {"Unified_Ideograph", "Ideographic"},
    157983: {"Unified_Ideograph", "Ideographic"},
    157984: {"Unified_Ideograph", "Ideographic"},
    157985: {"Unified_Ideograph", "Ideographic"},
    157986: {"Unified_Ideograph", "Ideographic"},
    157987: {"Unified_Ideograph", "Ideographic"},
    157988: {"Unified_Ideograph", "Ideographic"},
    157989: {"Unified_Ideograph", "Ideographic"},
    157990: {"Unified_Ideograph", "Ideographic"},
    157991: {"Unified_Ideograph", "Ideographic"},
    157992: {"Unified_Ideograph", "Ideographic"},
    157993: {"Unified_Ideograph", "Ideographic"},
    157994: {"Unified_Ideograph", "Ideographic"},
    157995: {"Unified_Ideograph", "Ideographic"},
    157996: {"Unified_Ideograph", "Ideographic"},
    157997: {"Unified_Ideograph", "Ideographic"},
    157998: {"Unified_Ideograph", "Ideographic"},
    157999: {"Unified_Ideograph", "Ideographic"},
    158000: {"Unified_Ideograph", "Ideographic"},
    158001: {"Unified_Ideograph", "Ideographic"},
    158002: {"Unified_Ideograph", "Ideographic"},
    158003: {"Unified_Ideograph", "Ideographic"},
    158004: {"Unified_Ideograph", "Ideographic"},
    158005: {"Unified_Ideograph", "Ideographic"},
    158006: {"Unified_Ideograph", "Ideographic"},
    158007: {"Unified_Ideograph", "Ideographic"},
    158008: {"Unified_Ideograph", "Ideographic"},
    158009: {"Unified_Ideograph", "Ideographic"},
    158010: {"Unified_Ideograph", "Ideographic"},
    158011: {"Unified_Ideograph", "Ideographic"},
    158012: {"Unified_Ideograph", "Ideographic"},
    158013: {"Unified_Ideograph", "Ideographic"},
    158014: {"Unified_Ideograph", "Ideographic"},
    158015: {"Unified_Ideograph", "Ideographic"},
    158016: {"Unified_Ideograph", "Ideographic"},
    158017: {"Unified_Ideograph", "Ideographic"},
    158018: {"Unified_Ideograph", "Ideographic"},
    158019: {"Unified_Ideograph", "Ideographic"},
    158020: {"Unified_Ideograph", "Ideographic"},
    158021: {"Unified_Ideograph", "Ideographic"},
    158022: {"Unified_Ideograph", "Ideographic"},
    158023: {"Unified_Ideograph", "Ideographic"},
    158024: {"Unified_Ideograph", "Ideographic"},
    158025: {"Unified_Ideograph", "Ideographic"},
    158026: {"Unified_Ideograph", "Ideographic"},
    158027: {"Unified_Ideograph", "Ideographic"},
    158028: {"Unified_Ideograph", "Ideographic"},
    158029: {"Unified_Ideograph", "Ideographic"},
    158030: {"Unified_Ideograph", "Ideographic"},
    158031: {"Unified_Ideograph", "Ideographic"},
    158032: {"Unified_Ideograph", "Ideographic"},
    158033: {"Unified_Ideograph", "Ideographic"},
    158034: {"Unified_Ideograph", "Ideographic"},
    158035: {"Unified_Ideograph", "Ideographic"},
    158036: {"Unified_Ideograph", "Ideographic"},
    158037: {"Unified_Ideograph", "Ideographic"},
    158038: {"Unified_Ideograph", "Ideographic"},
    158039: {"Unified_Ideograph", "Ideographic"},
    158040: {"Unified_Ideograph", "Ideographic"},
    158041: {"Unified_Ideograph", "Ideographic"},
    158042: {"Unified_Ideograph", "Ideographic"},
    158043: {"Unified_Ideograph", "Ideographic"},
    158044: {"Unified_Ideograph", "Ideographic"},
    158045: {"Unified_Ideograph", "Ideographic"},
    158046: {"Unified_Ideograph", "Ideographic"},
    158047: {"Unified_Ideograph", "Ideographic"},
    158048: {"Unified_Ideograph", "Ideographic"},
    158049: {"Unified_Ideograph", "Ideographic"},
    158050: {"Unified_Ideograph", "Ideographic"},
    158051: {"Unified_Ideograph", "Ideographic"},
    158052: {"Unified_Ideograph", "Ideographic"},
    158053: {"Unified_Ideograph", "Ideographic"},
    158054: {"Unified_Ideograph", "Ideographic"},
    158055: {"Unified_Ideograph", "Ideographic"},
    158056: {"Unified_Ideograph", "Ideographic"},
    158057: {"Unified_Ideograph", "Ideographic"},
    158058: {"Unified_Ideograph", "Ideographic"},
    158059: {"Unified_Ideograph", "Ideographic"},
    158060: {"Unified_Ideograph", "Ideographic"},
    158061: {"Unified_Ideograph", "Ideographic"},
    158062: {"Unified_Ideograph", "Ideographic"},
    158063: {"Unified_Ideograph", "Ideographic"},
    158064: {"Unified_Ideograph", "Ideographic"},
    158065: {"Unified_Ideograph", "Ideographic"},
    158066: {"Unified_Ideograph", "Ideographic"},
    158067: {"Unified_Ideograph", "Ideographic"},
    158068: {"Unified_Ideograph", "Ideographic"},
    158069: {"Unified_Ideograph", "Ideographic"},
    158070: {"Unified_Ideograph", "Ideographic"},
    158071: {"Unified_Ideograph", "Ideographic"},
    158072: {"Unified_Ideograph", "Ideographic"},
    158073: {"Unified_Ideograph", "Ideographic"},
    158074: {"Unified_Ideograph", "Ideographic"},
    158075: {"Unified_Ideograph", "Ideographic"},
    158076: {"Unified_Ideograph", "Ideographic"},
    158077: {"Unified_Ideograph", "Ideographic"},
    158078: {"Unified_Ideograph", "Ideographic"},
    158079: {"Unified_Ideograph", "Ideographic"},
    158080: {"Unified_Ideograph", "Ideographic"},
    158081: {"Unified_Ideograph", "Ideographic"},
    158082: {"Unified_Ideograph", "Ideographic"},
    158083: {"Unified_Ideograph", "Ideographic"},
    158084: {"Unified_Ideograph", "Ideographic"},
    158085: {"Unified_Ideograph", "Ideographic"},
    158086: {"Unified_Ideograph", "Ideographic"},
    158087: {"Unified_Ideograph", "Ideographic"},
    158088: {"Unified_Ideograph", "Ideographic"},
    158089: {"Unified_Ideograph", "Ideographic"},
    158090: {"Unified_Ideograph", "Ideographic"},
    158091: {"Unified_Ideograph", "Ideographic"},
    158092: {"Unified_Ideograph", "Ideographic"},
    158093: {"Unified_Ideograph", "Ideographic"},
    158094: {"Unified_Ideograph", "Ideographic"},
    158095: {"Unified_Ideograph", "Ideographic"},
    158096: {"Unified_Ideograph", "Ideographic"},
    158097: {"Unified_Ideograph", "Ideographic"},
    158098: {"Unified_Ideograph", "Ideographic"},
    158099: {"Unified_Ideograph", "Ideographic"},
    158100: {"Unified_Ideograph", "Ideographic"},
    158101: {"Unified_Ideograph", "Ideographic"},
    158102: {"Unified_Ideograph", "Ideographic"},
    158103: {"Unified_Ideograph", "Ideographic"},
    158104: {"Unified_Ideograph", "Ideographic"},
    158105: {"Unified_Ideograph", "Ideographic"},
    158106: {"Unified_Ideograph", "Ideographic"},
    158107: {"Unified_Ideograph", "Ideographic"},
    158108: {"Unified_Ideograph", "Ideographic"},
    158109: {"Unified_Ideograph", "Ideographic"},
    158110: {"Unified_Ideograph", "Ideographic"},
    158111: {"Unified_Ideograph", "Ideographic"},
    158112: {"Unified_Ideograph", "Ideographic"},
    158113: {"Unified_Ideograph", "Ideographic"},
    158114: {"Unified_Ideograph", "Ideographic"},
    158115: {"Unified_Ideograph", "Ideographic"},
    158116: {"Unified_Ideograph", "Ideographic"},
    158117: {"Unified_Ideograph", "Ideographic"},
    158118: {"Unified_Ideograph", "Ideographic"},
    158119: {"Unified_Ideograph", "Ideographic"},
    158120: {"Unified_Ideograph", "Ideographic"},
    158121: {"Unified_Ideograph", "Ideographic"},
    158122: {"Unified_Ideograph", "Ideographic"},
    158123: {"Unified_Ideograph", "Ideographic"},
    158124: {"Unified_Ideograph", "Ideographic"},
    158125: {"Unified_Ideograph", "Ideographic"},
    158126: {"Unified_Ideograph", "Ideographic"},
    158127: {"Unified_Ideograph", "Ideographic"},
    158128: {"Unified_Ideograph", "Ideographic"},
    158129: {"Unified_Ideograph", "Ideographic"},
    158130: {"Unified_Ideograph", "Ideographic"},
    158131: {"Unified_Ideograph", "Ideographic"},
    158132: {"Unified_Ideograph", "Ideographic"},
    158133: {"Unified_Ideograph", "Ideographic"},
    158134: {"Unified_Ideograph", "Ideographic"},
    158135: {"Unified_Ideograph", "Ideographic"},
    158136: {"Unified_Ideograph", "Ideographic"},
    158137: {"Unified_Ideograph", "Ideographic"},
    158138: {"Unified_Ideograph", "Ideographic"},
    158139: {"Unified_Ideograph", "Ideographic"},
    158140: {"Unified_Ideograph", "Ideographic"},
    158141: {"Unified_Ideograph", "Ideographic"},
    158142: {"Unified_Ideograph", "Ideographic"},
    158143: {"Unified_Ideograph", "Ideographic"},
    158144: {"Unified_Ideograph", "Ideographic"},
    158145: {"Unified_Ideograph", "Ideographic"},
    158146: {"Unified_Ideograph", "Ideographic"},
    158147: {"Unified_Ideograph", "Ideographic"},
    158148: {"Unified_Ideograph", "Ideographic"},
    158149: {"Unified_Ideograph", "Ideographic"},
    158150: {"Unified_Ideograph", "Ideographic"},
    158151: {"Unified_Ideograph", "Ideographic"},
    158152: {"Unified_Ideograph", "Ideographic"},
    158153: {"Unified_Ideograph", "Ideographic"},
    158154: {"Unified_Ideograph", "Ideographic"},
    158155: {"Unified_Ideograph", "Ideographic"},
    158156: {"Unified_Ideograph", "Ideographic"},
    158157: {"Unified_Ideograph", "Ideographic"},
    158158: {"Unified_Ideograph", "Ideographic"},
    158159: {"Unified_Ideograph", "Ideographic"},
    158160: {"Unified_Ideograph", "Ideographic"},
    158161: {"Unified_Ideograph", "Ideographic"},
    158162: {"Unified_Ideograph", "Ideographic"},
    158163: {"Unified_Ideograph", "Ideographic"},
    158164: {"Unified_Ideograph", "Ideographic"},
    158165: {"Unified_Ideograph", "Ideographic"},
    158166: {"Unified_Ideograph", "Ideographic"},
    158167: {"Unified_Ideograph", "Ideographic"},
    158168: {"Unified_Ideograph", "Ideographic"},
    158169: {"Unified_Ideograph", "Ideographic"},
    158170: {"Unified_Ideograph", "Ideographic"},
    158171: {"Unified_Ideograph", "Ideographic"},
    158172: {"Unified_Ideograph", "Ideographic"},
    158173: {"Unified_Ideograph", "Ideographic"},
    158174: {"Unified_Ideograph", "Ideographic"},
    158175: {"Unified_Ideograph", "Ideographic"},
    158176: {"Unified_Ideograph", "Ideographic"},
    158177: {"Unified_Ideograph", "Ideographic"},
    158178: {"Unified_Ideograph", "Ideographic"},
    158179: {"Unified_Ideograph", "Ideographic"},
    158180: {"Unified_Ideograph", "Ideographic"},
    158181: {"Unified_Ideograph", "Ideographic"},
    158182: {"Unified_Ideograph", "Ideographic"},
    158183: {"Unified_Ideograph", "Ideographic"},
    158184: {"Unified_Ideograph", "Ideographic"},
    158185: {"Unified_Ideograph", "Ideographic"},
    158186: {"Unified_Ideograph", "Ideographic"},
    158187: {"Unified_Ideograph", "Ideographic"},
    158188: {"Unified_Ideograph", "Ideographic"},
    158189: {"Unified_Ideograph", "Ideographic"},
    158190: {"Unified_Ideograph", "Ideographic"},
    158191: {"Unified_Ideograph", "Ideographic"},
    158192: {"Unified_Ideograph", "Ideographic"},
    158193: {"Unified_Ideograph", "Ideographic"},
    158194: {"Unified_Ideograph", "Ideographic"},
    158195: {"Unified_Ideograph", "Ideographic"},
    158196: {"Unified_Ideograph", "Ideographic"},
    158197: {"Unified_Ideograph", "Ideographic"},
    158198: {"Unified_Ideograph", "Ideographic"},
    158199: {"Unified_Ideograph", "Ideographic"},
    158200: {"Unified_Ideograph", "Ideographic"},
    158201: {"Unified_Ideograph", "Ideographic"},
    158202: {"Unified_Ideograph", "Ideographic"},
    158203: {"Unified_Ideograph", "Ideographic"},
    158204: {"Unified_Ideograph", "Ideographic"},
    158205: {"Unified_Ideograph", "Ideographic"},
    158206: {"Unified_Ideograph", "Ideographic"},
    158207: {"Unified_Ideograph", "Ideographic"},
    158208: {"Unified_Ideograph", "Ideographic"},
    158209: {"Unified_Ideograph", "Ideographic"},
    158210: {"Unified_Ideograph", "Ideographic"},
    158211: {"Unified_Ideograph", "Ideographic"},
    158212: {"Unified_Ideograph", "Ideographic"},
    158213: {"Unified_Ideograph", "Ideographic"},
    158214: {"Unified_Ideograph", "Ideographic"},
    158215: {"Unified_Ideograph", "Ideographic"},
    158216: {"Unified_Ideograph", "Ideographic"},
    158217: {"Unified_Ideograph", "Ideographic"},
    158218: {"Unified_Ideograph", "Ideographic"},
    158219: {"Unified_Ideograph", "Ideographic"},
    158220: {"Unified_Ideograph", "Ideographic"},
    158221: {"Unified_Ideograph", "Ideographic"},
    158222: {"Unified_Ideograph", "Ideographic"},
    158223: {"Unified_Ideograph", "Ideographic"},
    158224: {"Unified_Ideograph", "Ideographic"},
    158225: {"Unified_Ideograph", "Ideographic"},
    158226: {"Unified_Ideograph", "Ideographic"},
    158227: {"Unified_Ideograph", "Ideographic"},
    158228: {"Unified_Ideograph", "Ideographic"},
    158229: {"Unified_Ideograph", "Ideographic"},
    158230: {"Unified_Ideograph", "Ideographic"},
    158231: {"Unified_Ideograph", "Ideographic"},
    158232: {"Unified_Ideograph", "Ideographic"},
    158233: {"Unified_Ideograph", "Ideographic"},
    158234: {"Unified_Ideograph", "Ideographic"},
    158235: {"Unified_Ideograph", "Ideographic"},
    158236: {"Unified_Ideograph", "Ideographic"},
    158237: {"Unified_Ideograph", "Ideographic"},
    158238: {"Unified_Ideograph", "Ideographic"},
    158239: {"Unified_Ideograph", "Ideographic"},
    158240: {"Unified_Ideograph", "Ideographic"},
    158241: {"Unified_Ideograph", "Ideographic"},
    158242: {"Unified_Ideograph", "Ideographic"},
    158243: {"Unified_Ideograph", "Ideographic"},
    158244: {"Unified_Ideograph", "Ideographic"},
    158245: {"Unified_Ideograph", "Ideographic"},
    158246: {"Unified_Ideograph", "Ideographic"},
    158247: {"Unified_Ideograph", "Ideographic"},
    158248: {"Unified_Ideograph", "Ideographic"},
    158249: {"Unified_Ideograph", "Ideographic"},
    158250: {"Unified_Ideograph", "Ideographic"},
    158251: {"Unified_Ideograph", "Ideographic"},
    158252: {"Unified_Ideograph", "Ideographic"},
    158253: {"Unified_Ideograph", "Ideographic"},
    158254: {"Unified_Ideograph", "Ideographic"},
    158255: {"Unified_Ideograph", "Ideographic"},
    158256: {"Unified_Ideograph", "Ideographic"},
    158257: {"Unified_Ideograph", "Ideographic"},
    158258: {"Unified_Ideograph", "Ideographic"},
    158259: {"Unified_Ideograph", "Ideographic"},
    158260: {"Unified_Ideograph", "Ideographic"},
    158261: {"Unified_Ideograph", "Ideographic"},
    158262: {"Unified_Ideograph", "Ideographic"},
    158263: {"Unified_Ideograph", "Ideographic"},
    158264: {"Unified_Ideograph", "Ideographic"},
    158265: {"Unified_Ideograph", "Ideographic"},
    158266: {"Unified_Ideograph", "Ideographic"},
    158267: {"Unified_Ideograph", "Ideographic"},
    158268: {"Unified_Ideograph", "Ideographic"},
    158269: {"Unified_Ideograph", "Ideographic"},
    158270: {"Unified_Ideograph", "Ideographic"},
    158271: {"Unified_Ideograph", "Ideographic"},
    158272: {"Unified_Ideograph", "Ideographic"},
    158273: {"Unified_Ideograph", "Ideographic"},
    158274: {"Unified_Ideograph", "Ideographic"},
    158275: {"Unified_Ideograph", "Ideographic"},
    158276: {"Unified_Ideograph", "Ideographic"},
    158277: {"Unified_Ideograph", "Ideographic"},
    158278: {"Unified_Ideograph", "Ideographic"},
    158279: {"Unified_Ideograph", "Ideographic"},
    158280: {"Unified_Ideograph", "Ideographic"},
    158281: {"Unified_Ideograph", "Ideographic"},
    158282: {"Unified_Ideograph", "Ideographic"},
    158283: {"Unified_Ideograph", "Ideographic"},
    158284: {"Unified_Ideograph", "Ideographic"},
    158285: {"Unified_Ideograph", "Ideographic"},
    158286: {"Unified_Ideograph", "Ideographic"},
    158287: {"Unified_Ideograph", "Ideographic"},
    158288: {"Unified_Ideograph", "Ideographic"},
    158289: {"Unified_Ideograph", "Ideographic"},
    158290: {"Unified_Ideograph", "Ideographic"},
    158291: {"Unified_Ideograph", "Ideographic"},
    158292: {"Unified_Ideograph", "Ideographic"},
    158293: {"Unified_Ideograph", "Ideographic"},
    158294: {"Unified_Ideograph", "Ideographic"},
    158295: {"Unified_Ideograph", "Ideographic"},
    158296: {"Unified_Ideograph", "Ideographic"},
    158297: {"Unified_Ideograph", "Ideographic"},
    158298: {"Unified_Ideograph", "Ideographic"},
    158299: {"Unified_Ideograph", "Ideographic"},
    158300: {"Unified_Ideograph", "Ideographic"},
    158301: {"Unified_Ideograph", "Ideographic"},
    158302: {"Unified_Ideograph", "Ideographic"},
    158303: {"Unified_Ideograph", "Ideographic"},
    158304: {"Unified_Ideograph", "Ideographic"},
    158305: {"Unified_Ideograph", "Ideographic"},
    158306: {"Unified_Ideograph", "Ideographic"},
    158307: {"Unified_Ideograph", "Ideographic"},
    158308: {"Unified_Ideograph", "Ideographic"},
    158309: {"Unified_Ideograph", "Ideographic"},
    158310: {"Unified_Ideograph", "Ideographic"},
    158311: {"Unified_Ideograph", "Ideographic"},
    158312: {"Unified_Ideograph", "Ideographic"},
    158313: {"Unified_Ideograph", "Ideographic"},
    158314: {"Unified_Ideograph", "Ideographic"},
    158315: {"Unified_Ideograph", "Ideographic"},
    158316: {"Unified_Ideograph", "Ideographic"},
    158317: {"Unified_Ideograph", "Ideographic"},
    158318: {"Unified_Ideograph", "Ideographic"},
    158319: {"Unified_Ideograph", "Ideographic"},
    158320: {"Unified_Ideograph", "Ideographic"},
    158321: {"Unified_Ideograph", "Ideographic"},
    158322: {"Unified_Ideograph", "Ideographic"},
    158323: {"Unified_Ideograph", "Ideographic"},
    158324: {"Unified_Ideograph", "Ideographic"},
    158325: {"Unified_Ideograph", "Ideographic"},
    158326: {"Unified_Ideograph", "Ideographic"},
    158327: {"Unified_Ideograph", "Ideographic"},
    158328: {"Unified_Ideograph", "Ideographic"},
    158329: {"Unified_Ideograph", "Ideographic"},
    158330: {"Unified_Ideograph", "Ideographic"},
    158331: {"Unified_Ideograph", "Ideographic"},
    158332: {"Unified_Ideograph", "Ideographic"},
    158333: {"Unified_Ideograph", "Ideographic"},
    158334: {"Unified_Ideograph", "Ideographic"},
    158335: {"Unified_Ideograph", "Ideographic"},
    158336: {"Unified_Ideograph", "Ideographic"},
    158337: {"Unified_Ideograph", "Ideographic"},
    158338: {"Unified_Ideograph", "Ideographic"},
    158339: {"Unified_Ideograph", "Ideographic"},
    158340: {"Unified_Ideograph", "Ideographic"},
    158341: {"Unified_Ideograph", "Ideographic"},
    158342: {"Unified_Ideograph", "Ideographic"},
    158343: {"Unified_Ideograph", "Ideographic"},
    158344: {"Unified_Ideograph", "Ideographic"},
    158345: {"Unified_Ideograph", "Ideographic"},
    158346: {"Unified_Ideograph", "Ideographic"},
    158347: {"Unified_Ideograph", "Ideographic"},
    158348: {"Unified_Ideograph", "Ideographic"},
    158349: {"Unified_Ideograph", "Ideographic"},
    158350: {"Unified_Ideograph", "Ideographic"},
    158351: {"Unified_Ideograph", "Ideographic"},
    158352: {"Unified_Ideograph", "Ideographic"},
    158353: {"Unified_Ideograph", "Ideographic"},
    158354: {"Unified_Ideograph", "Ideographic"},
    158355: {"Unified_Ideograph", "Ideographic"},
    158356: {"Unified_Ideograph", "Ideographic"},
    158357: {"Unified_Ideograph", "Ideographic"},
    158358: {"Unified_Ideograph", "Ideographic"},
    158359: {"Unified_Ideograph", "Ideographic"},
    158360: {"Unified_Ideograph", "Ideographic"},
    158361: {"Unified_Ideograph", "Ideographic"},
    158362: {"Unified_Ideograph", "Ideographic"},
    158363: {"Unified_Ideograph", "Ideographic"},
    158364: {"Unified_Ideograph", "Ideographic"},
    158365: {"Unified_Ideograph", "Ideographic"},
    158366: {"Unified_Ideograph", "Ideographic"},
    158367: {"Unified_Ideograph", "Ideographic"},
    158368: {"Unified_Ideograph", "Ideographic"},
    158369: {"Unified_Ideograph", "Ideographic"},
    158370: {"Unified_Ideograph", "Ideographic"},
    158371: {"Unified_Ideograph", "Ideographic"},
    158372: {"Unified_Ideograph", "Ideographic"},
    158373: {"Unified_Ideograph", "Ideographic"},
    158374: {"Unified_Ideograph", "Ideographic"},
    158375: {"Unified_Ideograph", "Ideographic"},
    158376: {"Unified_Ideograph", "Ideographic"},
    158377: {"Unified_Ideograph", "Ideographic"},
    158378: {"Unified_Ideograph", "Ideographic"},
    158379: {"Unified_Ideograph", "Ideographic"},
    158380: {"Unified_Ideograph", "Ideographic"},
    158381: {"Unified_Ideograph", "Ideographic"},
    158382: {"Unified_Ideograph", "Ideographic"},
    158383: {"Unified_Ideograph", "Ideographic"},
    158384: {"Unified_Ideograph", "Ideographic"},
    158385: {"Unified_Ideograph", "Ideographic"},
    158386: {"Unified_Ideograph", "Ideographic"},
    158387: {"Unified_Ideograph", "Ideographic"},
    158388: {"Unified_Ideograph", "Ideographic"},
    158389: {"Unified_Ideograph", "Ideographic"},
    158390: {"Unified_Ideograph", "Ideographic"},
    158391: {"Unified_Ideograph", "Ideographic"},
    158392: {"Unified_Ideograph", "Ideographic"},
    158393: {"Unified_Ideograph", "Ideographic"},
    158394: {"Unified_Ideograph", "Ideographic"},
    158395: {"Unified_Ideograph", "Ideographic"},
    158396: {"Unified_Ideograph", "Ideographic"},
    158397: {"Unified_Ideograph", "Ideographic"},
    158398: {"Unified_Ideograph", "Ideographic"},
    158399: {"Unified_Ideograph", "Ideographic"},
    158400: {"Unified_Ideograph", "Ideographic"},
    158401: {"Unified_Ideograph", "Ideographic"},
    158402: {"Unified_Ideograph", "Ideographic"},
    158403: {"Unified_Ideograph", "Ideographic"},
    158404: {"Unified_Ideograph", "Ideographic"},
    158405: {"Unified_Ideograph", "Ideographic"},
    158406: {"Unified_Ideograph", "Ideographic"},
    158407: {"Unified_Ideograph", "Ideographic"},
    158408: {"Unified_Ideograph", "Ideographic"},
    158409: {"Unified_Ideograph", "Ideographic"},
    158410: {"Unified_Ideograph", "Ideographic"},
    158411: {"Unified_Ideograph", "Ideographic"},
    158412: {"Unified_Ideograph", "Ideographic"},
    158413: {"Unified_Ideograph", "Ideographic"},
    158414: {"Unified_Ideograph", "Ideographic"},
    158415: {"Unified_Ideograph", "Ideographic"},
    158416: {"Unified_Ideograph", "Ideographic"},
    158417: {"Unified_Ideograph", "Ideographic"},
    158418: {"Unified_Ideograph", "Ideographic"},
    158419: {"Unified_Ideograph", "Ideographic"},
    158420: {"Unified_Ideograph", "Ideographic"},
    158421: {"Unified_Ideograph", "Ideographic"},
    158422: {"Unified_Ideograph", "Ideographic"},
    158423: {"Unified_Ideograph", "Ideographic"},
    158424: {"Unified_Ideograph", "Ideographic"},
    158425: {"Unified_Ideograph", "Ideographic"},
    158426: {"Unified_Ideograph", "Ideographic"},
    158427: {"Unified_Ideograph", "Ideographic"},
    158428: {"Unified_Ideograph", "Ideographic"},
    158429: {"Unified_Ideograph", "Ideographic"},
    158430: {"Unified_Ideograph", "Ideographic"},
    158431: {"Unified_Ideograph", "Ideographic"},
    158432: {"Unified_Ideograph", "Ideographic"},
    158433: {"Unified_Ideograph", "Ideographic"},
    158434: {"Unified_Ideograph", "Ideographic"},
    158435: {"Unified_Ideograph", "Ideographic"},
    158436: {"Unified_Ideograph", "Ideographic"},
    158437: {"Unified_Ideograph", "Ideographic"},
    158438: {"Unified_Ideograph", "Ideographic"},
    158439: {"Unified_Ideograph", "Ideographic"},
    158440: {"Unified_Ideograph", "Ideographic"},
    158441: {"Unified_Ideograph", "Ideographic"},
    158442: {"Unified_Ideograph", "Ideographic"},
    158443: {"Unified_Ideograph", "Ideographic"},
    158444: {"Unified_Ideograph", "Ideographic"},
    158445: {"Unified_Ideograph", "Ideographic"},
    158446: {"Unified_Ideograph", "Ideographic"},
    158447: {"Unified_Ideograph", "Ideographic"},
    158448: {"Unified_Ideograph", "Ideographic"},
    158449: {"Unified_Ideograph", "Ideographic"},
    158450: {"Unified_Ideograph", "Ideographic"},
    158451: {"Unified_Ideograph", "Ideographic"},
    158452: {"Unified_Ideograph", "Ideographic"},
    158453: {"Unified_Ideograph", "Ideographic"},
    158454: {"Unified_Ideograph", "Ideographic"},
    158455: {"Unified_Ideograph", "Ideographic"},
    158456: {"Unified_Ideograph", "Ideographic"},
    158457: {"Unified_Ideograph", "Ideographic"},
    158458: {"Unified_Ideograph", "Ideographic"},
    158459: {"Unified_Ideograph", "Ideographic"},
    158460: {"Unified_Ideograph", "Ideographic"},
    158461: {"Unified_Ideograph", "Ideographic"},
    158462: {"Unified_Ideograph", "Ideographic"},
    158463: {"Unified_Ideograph", "Ideographic"},
    158464: {"Unified_Ideograph", "Ideographic"},
    158465: {"Unified_Ideograph", "Ideographic"},
    158466: {"Unified_Ideograph", "Ideographic"},
    158467: {"Unified_Ideograph", "Ideographic"},
    158468: {"Unified_Ideograph", "Ideographic"},
    158469: {"Unified_Ideograph", "Ideographic"},
    158470: {"Unified_Ideograph", "Ideographic"},
    158471: {"Unified_Ideograph", "Ideographic"},
    158472: {"Unified_Ideograph", "Ideographic"},
    158473: {"Unified_Ideograph", "Ideographic"},
    158474: {"Unified_Ideograph", "Ideographic"},
    158475: {"Unified_Ideograph", "Ideographic"},
    158476: {"Unified_Ideograph", "Ideographic"},
    158477: {"Unified_Ideograph", "Ideographic"},
    158478: {"Unified_Ideograph", "Ideographic"},
    158479: {"Unified_Ideograph", "Ideographic"},
    158480: {"Unified_Ideograph", "Ideographic"},
    158481: {"Unified_Ideograph", "Ideographic"},
    158482: {"Unified_Ideograph", "Ideographic"},
    158483: {"Unified_Ideograph", "Ideographic"},
    158484: {"Unified_Ideograph", "Ideographic"},
    158485: {"Unified_Ideograph", "Ideographic"},
    158486: {"Unified_Ideograph", "Ideographic"},
    158487: {"Unified_Ideograph", "Ideographic"},
    158488: {"Unified_Ideograph", "Ideographic"},
    158489: {"Unified_Ideograph", "Ideographic"},
    158490: {"Unified_Ideograph", "Ideographic"},
    158491: {"Unified_Ideograph", "Ideographic"},
    158492: {"Unified_Ideograph", "Ideographic"},
    158493: {"Unified_Ideograph", "Ideographic"},
    158494: {"Unified_Ideograph", "Ideographic"},
    158495: {"Unified_Ideograph", "Ideographic"},
    158496: {"Unified_Ideograph", "Ideographic"},
    158497: {"Unified_Ideograph", "Ideographic"},
    158498: {"Unified_Ideograph", "Ideographic"},
    158499: {"Unified_Ideograph", "Ideographic"},
    158500: {"Unified_Ideograph", "Ideographic"},
    158501: {"Unified_Ideograph", "Ideographic"},
    158502: {"Unified_Ideograph", "Ideographic"},
    158503: {"Unified_Ideograph", "Ideographic"},
    158504: {"Unified_Ideograph", "Ideographic"},
    158505: {"Unified_Ideograph", "Ideographic"},
    158506: {"Unified_Ideograph", "Ideographic"},
    158507: {"Unified_Ideograph", "Ideographic"},
    158508: {"Unified_Ideograph", "Ideographic"},
    158509: {"Unified_Ideograph", "Ideographic"},
    158510: {"Unified_Ideograph", "Ideographic"},
    158511: {"Unified_Ideograph", "Ideographic"},
    158512: {"Unified_Ideograph", "Ideographic"},
    158513: {"Unified_Ideograph", "Ideographic"},
    158514: {"Unified_Ideograph", "Ideographic"},
    158515: {"Unified_Ideograph", "Ideographic"},
    158516: {"Unified_Ideograph", "Ideographic"},
    158517: {"Unified_Ideograph", "Ideographic"},
    158518: {"Unified_Ideograph", "Ideographic"},
    158519: {"Unified_Ideograph", "Ideographic"},
    158520: {"Unified_Ideograph", "Ideographic"},
    158521: {"Unified_Ideograph", "Ideographic"},
    158522: {"Unified_Ideograph", "Ideographic"},
    158523: {"Unified_Ideograph", "Ideographic"},
    158524: {"Unified_Ideograph", "Ideographic"},
    158525: {"Unified_Ideograph", "Ideographic"},
    158526: {"Unified_Ideograph", "Ideographic"},
    158527: {"Unified_Ideograph", "Ideographic"},
    158528: {"Unified_Ideograph", "Ideographic"},
    158529: {"Unified_Ideograph", "Ideographic"},
    158530: {"Unified_Ideograph", "Ideographic"},
    158531: {"Unified_Ideograph", "Ideographic"},
    158532: {"Unified_Ideograph", "Ideographic"},
    158533: {"Unified_Ideograph", "Ideographic"},
    158534: {"Unified_Ideograph", "Ideographic"},
    158535: {"Unified_Ideograph", "Ideographic"},
    158536: {"Unified_Ideograph", "Ideographic"},
    158537: {"Unified_Ideograph", "Ideographic"},
    158538: {"Unified_Ideograph", "Ideographic"},
    158539: {"Unified_Ideograph", "Ideographic"},
    158540: {"Unified_Ideograph", "Ideographic"},
    158541: {"Unified_Ideograph", "Ideographic"},
    158542: {"Unified_Ideograph", "Ideographic"},
    158543: {"Unified_Ideograph", "Ideographic"},
    158544: {"Unified_Ideograph", "Ideographic"},
    158545: {"Unified_Ideograph", "Ideographic"},
    158546: {"Unified_Ideograph", "Ideographic"},
    158547: {"Unified_Ideograph", "Ideographic"},
    158548: {"Unified_Ideograph", "Ideographic"},
    158549: {"Unified_Ideograph", "Ideographic"},
    158550: {"Unified_Ideograph", "Ideographic"},
    158551: {"Unified_Ideograph", "Ideographic"},
    158552: {"Unified_Ideograph", "Ideographic"},
    158553: {"Unified_Ideograph", "Ideographic"},
    158554: {"Unified_Ideograph", "Ideographic"},
    158555: {"Unified_Ideograph", "Ideographic"},
    158556: {"Unified_Ideograph", "Ideographic"},
    158557: {"Unified_Ideograph", "Ideographic"},
    158558: {"Unified_Ideograph", "Ideographic"},
    158559: {"Unified_Ideograph", "Ideographic"},
    158560: {"Unified_Ideograph", "Ideographic"},
    158561: {"Unified_Ideograph", "Ideographic"},
    158562: {"Unified_Ideograph", "Ideographic"},
    158563: {"Unified_Ideograph", "Ideographic"},
    158564: {"Unified_Ideograph", "Ideographic"},
    158565: {"Unified_Ideograph", "Ideographic"},
    158566: {"Unified_Ideograph", "Ideographic"},
    158567: {"Unified_Ideograph", "Ideographic"},
    158568: {"Unified_Ideograph", "Ideographic"},
    158569: {"Unified_Ideograph", "Ideographic"},
    158570: {"Unified_Ideograph", "Ideographic"},
    158571: {"Unified_Ideograph", "Ideographic"},
    158572: {"Unified_Ideograph", "Ideographic"},
    158573: {"Unified_Ideograph", "Ideographic"},
    158574: {"Unified_Ideograph", "Ideographic"},
    158575: {"Unified_Ideograph", "Ideographic"},
    158576: {"Unified_Ideograph", "Ideographic"},
    158577: {"Unified_Ideograph", "Ideographic"},
    158578: {"Unified_Ideograph", "Ideographic"},
    158579: {"Unified_Ideograph", "Ideographic"},
    158580: {"Unified_Ideograph", "Ideographic"},
    158581: {"Unified_Ideograph", "Ideographic"},
    158582: {"Unified_Ideograph", "Ideographic"},
    158583: {"Unified_Ideograph", "Ideographic"},
    158584: {"Unified_Ideograph", "Ideographic"},
    158585: {"Unified_Ideograph", "Ideographic"},
    158586: {"Unified_Ideograph", "Ideographic"},
    158587: {"Unified_Ideograph", "Ideographic"},
    158588: {"Unified_Ideograph", "Ideographic"},
    158589: {"Unified_Ideograph", "Ideographic"},
    158590: {"Unified_Ideograph", "Ideographic"},
    158591: {"Unified_Ideograph", "Ideographic"},
    158592: {"Unified_Ideograph", "Ideographic"},
    158593: {"Unified_Ideograph", "Ideographic"},
    158594: {"Unified_Ideograph", "Ideographic"},
    158595: {"Unified_Ideograph", "Ideographic"},
    158596: {"Unified_Ideograph", "Ideographic"},
    158597: {"Unified_Ideograph", "Ideographic"},
    158598: {"Unified_Ideograph", "Ideographic"},
    158599: {"Unified_Ideograph", "Ideographic"},
    158600: {"Unified_Ideograph", "Ideographic"},
    158601: {"Unified_Ideograph", "Ideographic"},
    158602: {"Unified_Ideograph", "Ideographic"},
    158603: {"Unified_Ideograph", "Ideographic"},
    158604: {"Unified_Ideograph", "Ideographic"},
    158605: {"Unified_Ideograph", "Ideographic"},
    158606: {"Unified_Ideograph", "Ideographic"},
    158607: {"Unified_Ideograph", "Ideographic"},
    158608: {"Unified_Ideograph", "Ideographic"},
    158609: {"Unified_Ideograph", "Ideographic"},
    158610: {"Unified_Ideograph", "Ideographic"},
    158611: {"Unified_Ideograph", "Ideographic"},
    158612: {"Unified_Ideograph", "Ideographic"},
    158613: {"Unified_Ideograph", "Ideographic"},
    158614: {"Unified_Ideograph", "Ideographic"},
    158615: {"Unified_Ideograph", "Ideographic"},
    158616: {"Unified_Ideograph", "Ideographic"},
    158617: {"Unified_Ideograph", "Ideographic"},
    158618: {"Unified_Ideograph", "Ideographic"},
    158619: {"Unified_Ideograph", "Ideographic"},
    158620: {"Unified_Ideograph", "Ideographic"},
    158621: {"Unified_Ideograph", "Ideographic"},
    158622: {"Unified_Ideograph", "Ideographic"},
    158623: {"Unified_Ideograph", "Ideographic"},
    158624: {"Unified_Ideograph", "Ideographic"},
    158625: {"Unified_Ideograph", "Ideographic"},
    158626: {"Unified_Ideograph", "Ideographic"},
    158627: {"Unified_Ideograph", "Ideographic"},
    158628: {"Unified_Ideograph", "Ideographic"},
    158629: {"Unified_Ideograph", "Ideographic"},
    158630: {"Unified_Ideograph", "Ideographic"},
    158631: {"Unified_Ideograph", "Ideographic"},
    158632: {"Unified_Ideograph", "Ideographic"},
    158633: {"Unified_Ideograph", "Ideographic"},
    158634: {"Unified_Ideograph", "Ideographic"},
    158635: {"Unified_Ideograph", "Ideographic"},
    158636: {"Unified_Ideograph", "Ideographic"},
    158637: {"Unified_Ideograph", "Ideographic"},
    158638: {"Unified_Ideograph", "Ideographic"},
    158639: {"Unified_Ideograph", "Ideographic"},
    158640: {"Unified_Ideograph", "Ideographic"},
    158641: {"Unified_Ideograph", "Ideographic"},
    158642: {"Unified_Ideograph", "Ideographic"},
    158643: {"Unified_Ideograph", "Ideographic"},
    158644: {"Unified_Ideograph", "Ideographic"},
    158645: {"Unified_Ideograph", "Ideographic"},
    158646: {"Unified_Ideograph", "Ideographic"},
    158647: {"Unified_Ideograph", "Ideographic"},
    158648: {"Unified_Ideograph", "Ideographic"},
    158649: {"Unified_Ideograph", "Ideographic"},
    158650: {"Unified_Ideograph", "Ideographic"},
    158651: {"Unified_Ideograph", "Ideographic"},
    158652: {"Unified_Ideograph", "Ideographic"},
    158653: {"Unified_Ideograph", "Ideographic"},
    158654: {"Unified_Ideograph", "Ideographic"},
    158655: {"Unified_Ideograph", "Ideographic"},
    158656: {"Unified_Ideograph", "Ideographic"},
    158657: {"Unified_Ideograph", "Ideographic"},
    158658: {"Unified_Ideograph", "Ideographic"},
    158659: {"Unified_Ideograph", "Ideographic"},
    158660: {"Unified_Ideograph", "Ideographic"},
    158661: {"Unified_Ideograph", "Ideographic"},
    158662: {"Unified_Ideograph", "Ideographic"},
    158663: {"Unified_Ideograph", "Ideographic"},
    158664: {"Unified_Ideograph", "Ideographic"},
    158665: {"Unified_Ideograph", "Ideographic"},
    158666: {"Unified_Ideograph", "Ideographic"},
    158667: {"Unified_Ideograph", "Ideographic"},
    158668: {"Unified_Ideograph", "Ideographic"},
    158669: {"Unified_Ideograph", "Ideographic"},
    158670: {"Unified_Ideograph", "Ideographic"},
    158671: {"Unified_Ideograph", "Ideographic"},
    158672: {"Unified_Ideograph", "Ideographic"},
    158673: {"Unified_Ideograph", "Ideographic"},
    158674: {"Unified_Ideograph", "Ideographic"},
    158675: {"Unified_Ideograph", "Ideographic"},
    158676: {"Unified_Ideograph", "Ideographic"},
    158677: {"Unified_Ideograph", "Ideographic"},
    158678: {"Unified_Ideograph", "Ideographic"},
    158679: {"Unified_Ideograph", "Ideographic"},
    158680: {"Unified_Ideograph", "Ideographic"},
    158681: {"Unified_Ideograph", "Ideographic"},
    158682: {"Unified_Ideograph", "Ideographic"},
    158683: {"Unified_Ideograph", "Ideographic"},
    158684: {"Unified_Ideograph", "Ideographic"},
    158685: {"Unified_Ideograph", "Ideographic"},
    158686: {"Unified_Ideograph", "Ideographic"},
    158687: {"Unified_Ideograph", "Ideographic"},
    158688: {"Unified_Ideograph", "Ideographic"},
    158689: {"Unified_Ideograph", "Ideographic"},
    158690: {"Unified_Ideograph", "Ideographic"},
    158691: {"Unified_Ideograph", "Ideographic"},
    158692: {"Unified_Ideograph", "Ideographic"},
    158693: {"Unified_Ideograph", "Ideographic"},
    158694: {"Unified_Ideograph", "Ideographic"},
    158695: {"Unified_Ideograph", "Ideographic"},
    158696: {"Unified_Ideograph", "Ideographic"},
    158697: {"Unified_Ideograph", "Ideographic"},
    158698: {"Unified_Ideograph", "Ideographic"},
    158699: {"Unified_Ideograph", "Ideographic"},
    158700: {"Unified_Ideograph", "Ideographic"},
    158701: {"Unified_Ideograph", "Ideographic"},
    158702: {"Unified_Ideograph", "Ideographic"},
    158703: {"Unified_Ideograph", "Ideographic"},
    158704: {"Unified_Ideograph", "Ideographic"},
    158705: {"Unified_Ideograph", "Ideographic"},
    158706: {"Unified_Ideograph", "Ideographic"},
    158707: {"Unified_Ideograph", "Ideographic"},
    158708: {"Unified_Ideograph", "Ideographic"},
    158709: {"Unified_Ideograph", "Ideographic"},
    158710: {"Unified_Ideograph", "Ideographic"},
    158711: {"Unified_Ideograph", "Ideographic"},
    158712: {"Unified_Ideograph", "Ideographic"},
    158713: {"Unified_Ideograph", "Ideographic"},
    158714: {"Unified_Ideograph", "Ideographic"},
    158715: {"Unified_Ideograph", "Ideographic"},
    158716: {"Unified_Ideograph", "Ideographic"},
    158717: {"Unified_Ideograph", "Ideographic"},
    158718: {"Unified_Ideograph", "Ideographic"},
    158719: {"Unified_Ideograph", "Ideographic"},
    158720: {"Unified_Ideograph", "Ideographic"},
    158721: {"Unified_Ideograph", "Ideographic"},
    158722: {"Unified_Ideograph", "Ideographic"},
    158723: {"Unified_Ideograph", "Ideographic"},
    158724: {"Unified_Ideograph", "Ideographic"},
    158725: {"Unified_Ideograph", "Ideographic"},
    158726: {"Unified_Ideograph", "Ideographic"},
    158727: {"Unified_Ideograph", "Ideographic"},
    158728: {"Unified_Ideograph", "Ideographic"},
    158729: {"Unified_Ideograph", "Ideographic"},
    158730: {"Unified_Ideograph", "Ideographic"},
    158731: {"Unified_Ideograph", "Ideographic"},
    158732: {"Unified_Ideograph", "Ideographic"},
    158733: {"Unified_Ideograph", "Ideographic"},
    158734: {"Unified_Ideograph", "Ideographic"},
    158735: {"Unified_Ideograph", "Ideographic"},
    158736: {"Unified_Ideograph", "Ideographic"},
    158737: {"Unified_Ideograph", "Ideographic"},
    158738: {"Unified_Ideograph", "Ideographic"},
    158739: {"Unified_Ideograph", "Ideographic"},
    158740: {"Unified_Ideograph", "Ideographic"},
    158741: {"Unified_Ideograph", "Ideographic"},
    158742: {"Unified_Ideograph", "Ideographic"},
    158743: {"Unified_Ideograph", "Ideographic"},
    158744: {"Unified_Ideograph", "Ideographic"},
    158745: {"Unified_Ideograph", "Ideographic"},
    158746: {"Unified_Ideograph", "Ideographic"},
    158747: {"Unified_Ideograph", "Ideographic"},
    158748: {"Unified_Ideograph", "Ideographic"},
    158749: {"Unified_Ideograph", "Ideographic"},
    158750: {"Unified_Ideograph", "Ideographic"},
    158751: {"Unified_Ideograph", "Ideographic"},
    158752: {"Unified_Ideograph", "Ideographic"},
    158753: {"Unified_Ideograph", "Ideographic"},
    158754: {"Unified_Ideograph", "Ideographic"},
    158755: {"Unified_Ideograph", "Ideographic"},
    158756: {"Unified_Ideograph", "Ideographic"},
    158757: {"Unified_Ideograph", "Ideographic"},
    158758: {"Unified_Ideograph", "Ideographic"},
    158759: {"Unified_Ideograph", "Ideographic"},
    158760: {"Unified_Ideograph", "Ideographic"},
    158761: {"Unified_Ideograph", "Ideographic"},
    158762: {"Unified_Ideograph", "Ideographic"},
    158763: {"Unified_Ideograph", "Ideographic"},
    158764: {"Unified_Ideograph", "Ideographic"},
    158765: {"Unified_Ideograph", "Ideographic"},
    158766: {"Unified_Ideograph", "Ideographic"},
    158767: {"Unified_Ideograph", "Ideographic"},
    158768: {"Unified_Ideograph", "Ideographic"},
    158769: {"Unified_Ideograph", "Ideographic"},
    158770: {"Unified_Ideograph", "Ideographic"},
    158771: {"Unified_Ideograph", "Ideographic"},
    158772: {"Unified_Ideograph", "Ideographic"},
    158773: {"Unified_Ideograph", "Ideographic"},
    158774: {"Unified_Ideograph", "Ideographic"},
    158775: {"Unified_Ideograph", "Ideographic"},
    158776: {"Unified_Ideograph", "Ideographic"},
    158777: {"Unified_Ideograph", "Ideographic"},
    158778: {"Unified_Ideograph", "Ideographic"},
    158779: {"Unified_Ideograph", "Ideographic"},
    158780: {"Unified_Ideograph", "Ideographic"},
    158781: {"Unified_Ideograph", "Ideographic"},
    158782: {"Unified_Ideograph", "Ideographic"},
    158783: {"Unified_Ideograph", "Ideographic"},
    158784: {"Unified_Ideograph", "Ideographic"},
    158785: {"Unified_Ideograph", "Ideographic"},
    158786: {"Unified_Ideograph", "Ideographic"},
    158787: {"Unified_Ideograph", "Ideographic"},
    158788: {"Unified_Ideograph", "Ideographic"},
    158789: {"Unified_Ideograph", "Ideographic"},
    158790: {"Unified_Ideograph", "Ideographic"},
    158791: {"Unified_Ideograph", "Ideographic"},
    158792: {"Unified_Ideograph", "Ideographic"},
    158793: {"Unified_Ideograph", "Ideographic"},
    158794: {"Unified_Ideograph", "Ideographic"},
    158795: {"Unified_Ideograph", "Ideographic"},
    158796: {"Unified_Ideograph", "Ideographic"},
    158797: {"Unified_Ideograph", "Ideographic"},
    158798: {"Unified_Ideograph", "Ideographic"},
    158799: {"Unified_Ideograph", "Ideographic"},
    158800: {"Unified_Ideograph", "Ideographic"},
    158801: {"Unified_Ideograph", "Ideographic"},
    158802: {"Unified_Ideograph", "Ideographic"},
    158803: {"Unified_Ideograph", "Ideographic"},
    158804: {"Unified_Ideograph", "Ideographic"},
    158805: {"Unified_Ideograph", "Ideographic"},
    158806: {"Unified_Ideograph", "Ideographic"},
    158807: {"Unified_Ideograph", "Ideographic"},
    158808: {"Unified_Ideograph", "Ideographic"},
    158809: {"Unified_Ideograph", "Ideographic"},
    158810: {"Unified_Ideograph", "Ideographic"},
    158811: {"Unified_Ideograph", "Ideographic"},
    158812: {"Unified_Ideograph", "Ideographic"},
    158813: {"Unified_Ideograph", "Ideographic"},
    158814: {"Unified_Ideograph", "Ideographic"},
    158815: {"Unified_Ideograph", "Ideographic"},
    158816: {"Unified_Ideograph", "Ideographic"},
    158817: {"Unified_Ideograph", "Ideographic"},
    158818: {"Unified_Ideograph", "Ideographic"},
    158819: {"Unified_Ideograph", "Ideographic"},
    158820: {"Unified_Ideograph", "Ideographic"},
    158821: {"Unified_Ideograph", "Ideographic"},
    158822: {"Unified_Ideograph", "Ideographic"},
    158823: {"Unified_Ideograph", "Ideographic"},
    158824: {"Unified_Ideograph", "Ideographic"},
    158825: {"Unified_Ideograph", "Ideographic"},
    158826: {"Unified_Ideograph", "Ideographic"},
    158827: {"Unified_Ideograph", "Ideographic"},
    158828: {"Unified_Ideograph", "Ideographic"},
    158829: {"Unified_Ideograph", "Ideographic"},
    158830: {"Unified_Ideograph", "Ideographic"},
    158831: {"Unified_Ideograph", "Ideographic"},
    158832: {"Unified_Ideograph", "Ideographic"},
    158833: {"Unified_Ideograph", "Ideographic"},
    158834: {"Unified_Ideograph", "Ideographic"},
    158835: {"Unified_Ideograph", "Ideographic"},
    158836: {"Unified_Ideograph", "Ideographic"},
    158837: {"Unified_Ideograph", "Ideographic"},
    158838: {"Unified_Ideograph", "Ideographic"},
    158839: {"Unified_Ideograph", "Ideographic"},
    158840: {"Unified_Ideograph", "Ideographic"},
    158841: {"Unified_Ideograph", "Ideographic"},
    158842: {"Unified_Ideograph", "Ideographic"},
    158843: {"Unified_Ideograph", "Ideographic"},
    158844: {"Unified_Ideograph", "Ideographic"},
    158845: {"Unified_Ideograph", "Ideographic"},
    158846: {"Unified_Ideograph", "Ideographic"},
    158847: {"Unified_Ideograph", "Ideographic"},
    158848: {"Unified_Ideograph", "Ideographic"},
    158849: {"Unified_Ideograph", "Ideographic"},
    158850: {"Unified_Ideograph", "Ideographic"},
    158851: {"Unified_Ideograph", "Ideographic"},
    158852: {"Unified_Ideograph", "Ideographic"},
    158853: {"Unified_Ideograph", "Ideographic"},
    158854: {"Unified_Ideograph", "Ideographic"},
    158855: {"Unified_Ideograph", "Ideographic"},
    158856: {"Unified_Ideograph", "Ideographic"},
    158857: {"Unified_Ideograph", "Ideographic"},
    158858: {"Unified_Ideograph", "Ideographic"},
    158859: {"Unified_Ideograph", "Ideographic"},
    158860: {"Unified_Ideograph", "Ideographic"},
    158861: {"Unified_Ideograph", "Ideographic"},
    158862: {"Unified_Ideograph", "Ideographic"},
    158863: {"Unified_Ideograph", "Ideographic"},
    158864: {"Unified_Ideograph", "Ideographic"},
    158865: {"Unified_Ideograph", "Ideographic"},
    158866: {"Unified_Ideograph", "Ideographic"},
    158867: {"Unified_Ideograph", "Ideographic"},
    158868: {"Unified_Ideograph", "Ideographic"},
    158869: {"Unified_Ideograph", "Ideographic"},
    158870: {"Unified_Ideograph", "Ideographic"},
    158871: {"Unified_Ideograph", "Ideographic"},
    158872: {"Unified_Ideograph", "Ideographic"},
    158873: {"Unified_Ideograph", "Ideographic"},
    158874: {"Unified_Ideograph", "Ideographic"},
    158875: {"Unified_Ideograph", "Ideographic"},
    158876: {"Unified_Ideograph", "Ideographic"},
    158877: {"Unified_Ideograph", "Ideographic"},
    158878: {"Unified_Ideograph", "Ideographic"},
    158879: {"Unified_Ideograph", "Ideographic"},
    158880: {"Unified_Ideograph", "Ideographic"},
    158881: {"Unified_Ideograph", "Ideographic"},
    158882: {"Unified_Ideograph", "Ideographic"},
    158883: {"Unified_Ideograph", "Ideographic"},
    158884: {"Unified_Ideograph", "Ideographic"},
    158885: {"Unified_Ideograph", "Ideographic"},
    158886: {"Unified_Ideograph", "Ideographic"},
    158887: {"Unified_Ideograph", "Ideographic"},
    158888: {"Unified_Ideograph", "Ideographic"},
    158889: {"Unified_Ideograph", "Ideographic"},
    158890: {"Unified_Ideograph", "Ideographic"},
    158891: {"Unified_Ideograph", "Ideographic"},
    158892: {"Unified_Ideograph", "Ideographic"},
    158893: {"Unified_Ideograph", "Ideographic"},
    158894: {"Unified_Ideograph", "Ideographic"},
    158895: {"Unified_Ideograph", "Ideographic"},
    158896: {"Unified_Ideograph", "Ideographic"},
    158897: {"Unified_Ideograph", "Ideographic"},
    158898: {"Unified_Ideograph", "Ideographic"},
    158899: {"Unified_Ideograph", "Ideographic"},
    158900: {"Unified_Ideograph", "Ideographic"},
    158901: {"Unified_Ideograph", "Ideographic"},
    158902: {"Unified_Ideograph", "Ideographic"},
    158903: {"Unified_Ideograph", "Ideographic"},
    158904: {"Unified_Ideograph", "Ideographic"},
    158905: {"Unified_Ideograph", "Ideographic"},
    158906: {"Unified_Ideograph", "Ideographic"},
    158907: {"Unified_Ideograph", "Ideographic"},
    158908: {"Unified_Ideograph", "Ideographic"},
    158909: {"Unified_Ideograph", "Ideographic"},
    158910: {"Unified_Ideograph", "Ideographic"},
    158911: {"Unified_Ideograph", "Ideographic"},
    158912: {"Unified_Ideograph", "Ideographic"},
    158913: {"Unified_Ideograph", "Ideographic"},
    158914: {"Unified_Ideograph", "Ideographic"},
    158915: {"Unified_Ideograph", "Ideographic"},
    158916: {"Unified_Ideograph", "Ideographic"},
    158917: {"Unified_Ideograph", "Ideographic"},
    158918: {"Unified_Ideograph", "Ideographic"},
    158919: {"Unified_Ideograph", "Ideographic"},
    158920: {"Unified_Ideograph", "Ideographic"},
    158921: {"Unified_Ideograph", "Ideographic"},
    158922: {"Unified_Ideograph", "Ideographic"},
    158923: {"Unified_Ideograph", "Ideographic"},
    158924: {"Unified_Ideograph", "Ideographic"},
    158925: {"Unified_Ideograph", "Ideographic"},
    158926: {"Unified_Ideograph", "Ideographic"},
    158927: {"Unified_Ideograph", "Ideographic"},
    158928: {"Unified_Ideograph", "Ideographic"},
    158929: {"Unified_Ideograph", "Ideographic"},
    158930: {"Unified_Ideograph", "Ideographic"},
    158931: {"Unified_Ideograph", "Ideographic"},
    158932: {"Unified_Ideograph", "Ideographic"},
    158933: {"Unified_Ideograph", "Ideographic"},
    158934: {"Unified_Ideograph", "Ideographic"},
    158935: {"Unified_Ideograph", "Ideographic"},
    158936: {"Unified_Ideograph", "Ideographic"},
    158937: {"Unified_Ideograph", "Ideographic"},
    158938: {"Unified_Ideograph", "Ideographic"},
    158939: {"Unified_Ideograph", "Ideographic"},
    158940: {"Unified_Ideograph", "Ideographic"},
    158941: {"Unified_Ideograph", "Ideographic"},
    158942: {"Unified_Ideograph", "Ideographic"},
    158943: {"Unified_Ideograph", "Ideographic"},
    158944: {"Unified_Ideograph", "Ideographic"},
    158945: {"Unified_Ideograph", "Ideographic"},
    158946: {"Unified_Ideograph", "Ideographic"},
    158947: {"Unified_Ideograph", "Ideographic"},
    158948: {"Unified_Ideograph", "Ideographic"},
    158949: {"Unified_Ideograph", "Ideographic"},
    158950: {"Unified_Ideograph", "Ideographic"},
    158951: {"Unified_Ideograph", "Ideographic"},
    158952: {"Unified_Ideograph", "Ideographic"},
    158953: {"Unified_Ideograph", "Ideographic"},
    158954: {"Unified_Ideograph", "Ideographic"},
    158955: {"Unified_Ideograph", "Ideographic"},
    158956: {"Unified_Ideograph", "Ideographic"},
    158957: {"Unified_Ideograph", "Ideographic"},
    158958: {"Unified_Ideograph", "Ideographic"},
    158959: {"Unified_Ideograph", "Ideographic"},
    158960: {"Unified_Ideograph", "Ideographic"},
    158961: {"Unified_Ideograph", "Ideographic"},
    158962: {"Unified_Ideograph", "Ideographic"},
    158963: {"Unified_Ideograph", "Ideographic"},
    158964: {"Unified_Ideograph", "Ideographic"},
    158965: {"Unified_Ideograph", "Ideographic"},
    158966: {"Unified_Ideograph", "Ideographic"},
    158967: {"Unified_Ideograph", "Ideographic"},
    158968: {"Unified_Ideograph", "Ideographic"},
    158969: {"Unified_Ideograph", "Ideographic"},
    158970: {"Unified_Ideograph", "Ideographic"},
    158971: {"Unified_Ideograph", "Ideographic"},
    158972: {"Unified_Ideograph", "Ideographic"},
    158973: {"Unified_Ideograph", "Ideographic"},
    158974: {"Unified_Ideograph", "Ideographic"},
    158975: {"Unified_Ideograph", "Ideographic"},
    158976: {"Unified_Ideograph", "Ideographic"},
    158977: {"Unified_Ideograph", "Ideographic"},
    158978: {"Unified_Ideograph", "Ideographic"},
    158979: {"Unified_Ideograph", "Ideographic"},
    158980: {"Unified_Ideograph", "Ideographic"},
    158981: {"Unified_Ideograph", "Ideographic"},
    158982: {"Unified_Ideograph", "Ideographic"},
    158983: {"Unified_Ideograph", "Ideographic"},
    158984: {"Unified_Ideograph", "Ideographic"},
    158985: {"Unified_Ideograph", "Ideographic"},
    158986: {"Unified_Ideograph", "Ideographic"},
    158987: {"Unified_Ideograph", "Ideographic"},
    158988: {"Unified_Ideograph", "Ideographic"},
    158989: {"Unified_Ideograph", "Ideographic"},
    158990: {"Unified_Ideograph", "Ideographic"},
    158991: {"Unified_Ideograph", "Ideographic"},
    158992: {"Unified_Ideograph", "Ideographic"},
    158993: {"Unified_Ideograph", "Ideographic"},
    158994: {"Unified_Ideograph", "Ideographic"},
    158995: {"Unified_Ideograph", "Ideographic"},
    158996: {"Unified_Ideograph", "Ideographic"},
    158997: {"Unified_Ideograph", "Ideographic"},
    158998: {"Unified_Ideograph", "Ideographic"},
    158999: {"Unified_Ideograph", "Ideographic"},
    159000: {"Unified_Ideograph", "Ideographic"},
    159001: {"Unified_Ideograph", "Ideographic"},
    159002: {"Unified_Ideograph", "Ideographic"},
    159003: {"Unified_Ideograph", "Ideographic"},
    159004: {"Unified_Ideograph", "Ideographic"},
    159005: {"Unified_Ideograph", "Ideographic"},
    159006: {"Unified_Ideograph", "Ideographic"},
    159007: {"Unified_Ideograph", "Ideographic"},
    159008: {"Unified_Ideograph", "Ideographic"},
    159009: {"Unified_Ideograph", "Ideographic"},
    159010: {"Unified_Ideograph", "Ideographic"},
    159011: {"Unified_Ideograph", "Ideographic"},
    159012: {"Unified_Ideograph", "Ideographic"},
    159013: {"Unified_Ideograph", "Ideographic"},
    159014: {"Unified_Ideograph", "Ideographic"},
    159015: {"Unified_Ideograph", "Ideographic"},
    159016: {"Unified_Ideograph", "Ideographic"},
    159017: {"Unified_Ideograph", "Ideographic"},
    159018: {"Unified_Ideograph", "Ideographic"},
    159019: {"Unified_Ideograph", "Ideographic"},
    159020: {"Unified_Ideograph", "Ideographic"},
    159021: {"Unified_Ideograph", "Ideographic"},
    159022: {"Unified_Ideograph", "Ideographic"},
    159023: {"Unified_Ideograph", "Ideographic"},
    159024: {"Unified_Ideograph", "Ideographic"},
    159025: {"Unified_Ideograph", "Ideographic"},
    159026: {"Unified_Ideograph", "Ideographic"},
    159027: {"Unified_Ideograph", "Ideographic"},
    159028: {"Unified_Ideograph", "Ideographic"},
    159029: {"Unified_Ideograph", "Ideographic"},
    159030: {"Unified_Ideograph", "Ideographic"},
    159031: {"Unified_Ideograph", "Ideographic"},
    159032: {"Unified_Ideograph", "Ideographic"},
    159033: {"Unified_Ideograph", "Ideographic"},
    159034: {"Unified_Ideograph", "Ideographic"},
    159035: {"Unified_Ideograph", "Ideographic"},
    159036: {"Unified_Ideograph", "Ideographic"},
    159037: {"Unified_Ideograph", "Ideographic"},
    159038: {"Unified_Ideograph", "Ideographic"},
    159039: {"Unified_Ideograph", "Ideographic"},
    159040: {"Unified_Ideograph", "Ideographic"},
    159041: {"Unified_Ideograph", "Ideographic"},
    159042: {"Unified_Ideograph", "Ideographic"},
    159043: {"Unified_Ideograph", "Ideographic"},
    159044: {"Unified_Ideograph", "Ideographic"},
    159045: {"Unified_Ideograph", "Ideographic"},
    159046: {"Unified_Ideograph", "Ideographic"},
    159047: {"Unified_Ideograph", "Ideographic"},
    159048: {"Unified_Ideograph", "Ideographic"},
    159049: {"Unified_Ideograph", "Ideographic"},
    159050: {"Unified_Ideograph", "Ideographic"},
    159051: {"Unified_Ideograph", "Ideographic"},
    159052: {"Unified_Ideograph", "Ideographic"},
    159053: {"Unified_Ideograph", "Ideographic"},
    159054: {"Unified_Ideograph", "Ideographic"},
    159055: {"Unified_Ideograph", "Ideographic"},
    159056: {"Unified_Ideograph", "Ideographic"},
    159057: {"Unified_Ideograph", "Ideographic"},
    159058: {"Unified_Ideograph", "Ideographic"},
    159059: {"Unified_Ideograph", "Ideographic"},
    159060: {"Unified_Ideograph", "Ideographic"},
    159061: {"Unified_Ideograph", "Ideographic"},
    159062: {"Unified_Ideograph", "Ideographic"},
    159063: {"Unified_Ideograph", "Ideographic"},
    159064: {"Unified_Ideograph", "Ideographic"},
    159065: {"Unified_Ideograph", "Ideographic"},
    159066: {"Unified_Ideograph", "Ideographic"},
    159067: {"Unified_Ideograph", "Ideographic"},
    159068: {"Unified_Ideograph", "Ideographic"},
    159069: {"Unified_Ideograph", "Ideographic"},
    159070: {"Unified_Ideograph", "Ideographic"},
    159071: {"Unified_Ideograph", "Ideographic"},
    159072: {"Unified_Ideograph", "Ideographic"},
    159073: {"Unified_Ideograph", "Ideographic"},
    159074: {"Unified_Ideograph", "Ideographic"},
    159075: {"Unified_Ideograph", "Ideographic"},
    159076: {"Unified_Ideograph", "Ideographic"},
    159077: {"Unified_Ideograph", "Ideographic"},
    159078: {"Unified_Ideograph", "Ideographic"},
    159079: {"Unified_Ideograph", "Ideographic"},
    159080: {"Unified_Ideograph", "Ideographic"},
    159081: {"Unified_Ideograph", "Ideographic"},
    159082: {"Unified_Ideograph", "Ideographic"},
    159083: {"Unified_Ideograph", "Ideographic"},
    159084: {"Unified_Ideograph", "Ideographic"},
    159085: {"Unified_Ideograph", "Ideographic"},
    159086: {"Unified_Ideograph", "Ideographic"},
    159087: {"Unified_Ideograph", "Ideographic"},
    159088: {"Unified_Ideograph", "Ideographic"},
    159089: {"Unified_Ideograph", "Ideographic"},
    159090: {"Unified_Ideograph", "Ideographic"},
    159091: {"Unified_Ideograph", "Ideographic"},
    159092: {"Unified_Ideograph", "Ideographic"},
    159093: {"Unified_Ideograph", "Ideographic"},
    159094: {"Unified_Ideograph", "Ideographic"},
    159095: {"Unified_Ideograph", "Ideographic"},
    159096: {"Unified_Ideograph", "Ideographic"},
    159097: {"Unified_Ideograph", "Ideographic"},
    159098: {"Unified_Ideograph", "Ideographic"},
    159099: {"Unified_Ideograph", "Ideographic"},
    159100: {"Unified_Ideograph", "Ideographic"},
    159101: {"Unified_Ideograph", "Ideographic"},
    159102: {"Unified_Ideograph", "Ideographic"},
    159103: {"Unified_Ideograph", "Ideographic"},
    159104: {"Unified_Ideograph", "Ideographic"},
    159105: {"Unified_Ideograph", "Ideographic"},
    159106: {"Unified_Ideograph", "Ideographic"},
    159107: {"Unified_Ideograph", "Ideographic"},
    159108: {"Unified_Ideograph", "Ideographic"},
    159109: {"Unified_Ideograph", "Ideographic"},
    159110: {"Unified_Ideograph", "Ideographic"},
    159111: {"Unified_Ideograph", "Ideographic"},
    159112: {"Unified_Ideograph", "Ideographic"},
    159113: {"Unified_Ideograph", "Ideographic"},
    159114: {"Unified_Ideograph", "Ideographic"},
    159115: {"Unified_Ideograph", "Ideographic"},
    159116: {"Unified_Ideograph", "Ideographic"},
    159117: {"Unified_Ideograph", "Ideographic"},
    159118: {"Unified_Ideograph", "Ideographic"},
    159119: {"Unified_Ideograph", "Ideographic"},
    159120: {"Unified_Ideograph", "Ideographic"},
    159121: {"Unified_Ideograph", "Ideographic"},
    159122: {"Unified_Ideograph", "Ideographic"},
    159123: {"Unified_Ideograph", "Ideographic"},
    159124: {"Unified_Ideograph", "Ideographic"},
    159125: {"Unified_Ideograph", "Ideographic"},
    159126: {"Unified_Ideograph", "Ideographic"},
    159127: {"Unified_Ideograph", "Ideographic"},
    159128: {"Unified_Ideograph", "Ideographic"},
    159129: {"Unified_Ideograph", "Ideographic"},
    159130: {"Unified_Ideograph", "Ideographic"},
    159131: {"Unified_Ideograph", "Ideographic"},
    159132: {"Unified_Ideograph", "Ideographic"},
    159133: {"Unified_Ideograph", "Ideographic"},
    159134: {"Unified_Ideograph", "Ideographic"},
    159135: {"Unified_Ideograph", "Ideographic"},
    159136: {"Unified_Ideograph", "Ideographic"},
    159137: {"Unified_Ideograph", "Ideographic"},
    159138: {"Unified_Ideograph", "Ideographic"},
    159139: {"Unified_Ideograph", "Ideographic"},
    159140: {"Unified_Ideograph", "Ideographic"},
    159141: {"Unified_Ideograph", "Ideographic"},
    159142: {"Unified_Ideograph", "Ideographic"},
    159143: {"Unified_Ideograph", "Ideographic"},
    159144: {"Unified_Ideograph", "Ideographic"},
    159145: {"Unified_Ideograph", "Ideographic"},
    159146: {"Unified_Ideograph", "Ideographic"},
    159147: {"Unified_Ideograph", "Ideographic"},
    159148: {"Unified_Ideograph", "Ideographic"},
    159149: {"Unified_Ideograph", "Ideographic"},
    159150: {"Unified_Ideograph", "Ideographic"},
    159151: {"Unified_Ideograph", "Ideographic"},
    159152: {"Unified_Ideograph", "Ideographic"},
    159153: {"Unified_Ideograph", "Ideographic"},
    159154: {"Unified_Ideograph", "Ideographic"},
    159155: {"Unified_Ideograph", "Ideographic"},
    159156: {"Unified_Ideograph", "Ideographic"},
    159157: {"Unified_Ideograph", "Ideographic"},
    159158: {"Unified_Ideograph", "Ideographic"},
    159159: {"Unified_Ideograph", "Ideographic"},
    159160: {"Unified_Ideograph", "Ideographic"},
    159161: {"Unified_Ideograph", "Ideographic"},
    159162: {"Unified_Ideograph", "Ideographic"},
    159163: {"Unified_Ideograph", "Ideographic"},
    159164: {"Unified_Ideograph", "Ideographic"},
    159165: {"Unified_Ideograph", "Ideographic"},
    159166: {"Unified_Ideograph", "Ideographic"},
    159167: {"Unified_Ideograph", "Ideographic"},
    159168: {"Unified_Ideograph", "Ideographic"},
    159169: {"Unified_Ideograph", "Ideographic"},
    159170: {"Unified_Ideograph", "Ideographic"},
    159171: {"Unified_Ideograph", "Ideographic"},
    159172: {"Unified_Ideograph", "Ideographic"},
    159173: {"Unified_Ideograph", "Ideographic"},
    159174: {"Unified_Ideograph", "Ideographic"},
    159175: {"Unified_Ideograph", "Ideographic"},
    159176: {"Unified_Ideograph", "Ideographic"},
    159177: {"Unified_Ideograph", "Ideographic"},
    159178: {"Unified_Ideograph", "Ideographic"},
    159179: {"Unified_Ideograph", "Ideographic"},
    159180: {"Unified_Ideograph", "Ideographic"},
    159181: {"Unified_Ideograph", "Ideographic"},
    159182: {"Unified_Ideograph", "Ideographic"},
    159183: {"Unified_Ideograph", "Ideographic"},
    159184: {"Unified_Ideograph", "Ideographic"},
    159185: {"Unified_Ideograph", "Ideographic"},
    159186: {"Unified_Ideograph", "Ideographic"},
    159187: {"Unified_Ideograph", "Ideographic"},
    159188: {"Unified_Ideograph", "Ideographic"},
    159189: {"Unified_Ideograph", "Ideographic"},
    159190: {"Unified_Ideograph", "Ideographic"},
    159191: {"Unified_Ideograph", "Ideographic"},
    159192: {"Unified_Ideograph", "Ideographic"},
    159193: {"Unified_Ideograph", "Ideographic"},
    159194: {"Unified_Ideograph", "Ideographic"},
    159195: {"Unified_Ideograph", "Ideographic"},
    159196: {"Unified_Ideograph", "Ideographic"},
    159197: {"Unified_Ideograph", "Ideographic"},
    159198: {"Unified_Ideograph", "Ideographic"},
    159199: {"Unified_Ideograph", "Ideographic"},
    159200: {"Unified_Ideograph", "Ideographic"},
    159201: {"Unified_Ideograph", "Ideographic"},
    159202: {"Unified_Ideograph", "Ideographic"},
    159203: {"Unified_Ideograph", "Ideographic"},
    159204: {"Unified_Ideograph", "Ideographic"},
    159205: {"Unified_Ideograph", "Ideographic"},
    159206: {"Unified_Ideograph", "Ideographic"},
    159207: {"Unified_Ideograph", "Ideographic"},
    159208: {"Unified_Ideograph", "Ideographic"},
    159209: {"Unified_Ideograph", "Ideographic"},
    159210: {"Unified_Ideograph", "Ideographic"},
    159211: {"Unified_Ideograph", "Ideographic"},
    159212: {"Unified_Ideograph", "Ideographic"},
    159213: {"Unified_Ideograph", "Ideographic"},
    159214: {"Unified_Ideograph", "Ideographic"},
    159215: {"Unified_Ideograph", "Ideographic"},
    159216: {"Unified_Ideograph", "Ideographic"},
    159217: {"Unified_Ideograph", "Ideographic"},
    159218: {"Unified_Ideograph", "Ideographic"},
    159219: {"Unified_Ideograph", "Ideographic"},
    159220: {"Unified_Ideograph", "Ideographic"},
    159221: {"Unified_Ideograph", "Ideographic"},
    159222: {"Unified_Ideograph", "Ideographic"},
    159223: {"Unified_Ideograph", "Ideographic"},
    159224: {"Unified_Ideograph", "Ideographic"},
    159225: {"Unified_Ideograph", "Ideographic"},
    159226: {"Unified_Ideograph", "Ideographic"},
    159227: {"Unified_Ideograph", "Ideographic"},
    159228: {"Unified_Ideograph", "Ideographic"},
    159229: {"Unified_Ideograph", "Ideographic"},
    159230: {"Unified_Ideograph", "Ideographic"},
    159231: {"Unified_Ideograph", "Ideographic"},
    159232: {"Unified_Ideograph", "Ideographic"},
    159233: {"Unified_Ideograph", "Ideographic"},
    159234: {"Unified_Ideograph", "Ideographic"},
    159235: {"Unified_Ideograph", "Ideographic"},
    159236: {"Unified_Ideograph", "Ideographic"},
    159237: {"Unified_Ideograph", "Ideographic"},
    159238: {"Unified_Ideograph", "Ideographic"},
    159239: {"Unified_Ideograph", "Ideographic"},
    159240: {"Unified_Ideograph", "Ideographic"},
    159241: {"Unified_Ideograph", "Ideographic"},
    159242: {"Unified_Ideograph", "Ideographic"},
    159243: {"Unified_Ideograph", "Ideographic"},
    159244: {"Unified_Ideograph", "Ideographic"},
    159245: {"Unified_Ideograph", "Ideographic"},
    159246: {"Unified_Ideograph", "Ideographic"},
    159247: {"Unified_Ideograph", "Ideographic"},
    159248: {"Unified_Ideograph", "Ideographic"},
    159249: {"Unified_Ideograph", "Ideographic"},
    159250: {"Unified_Ideograph", "Ideographic"},
    159251: {"Unified_Ideograph", "Ideographic"},
    159252: {"Unified_Ideograph", "Ideographic"},
    159253: {"Unified_Ideograph", "Ideographic"},
    159254: {"Unified_Ideograph", "Ideographic"},
    159255: {"Unified_Ideograph", "Ideographic"},
    159256: {"Unified_Ideograph", "Ideographic"},
    159257: {"Unified_Ideograph", "Ideographic"},
    159258: {"Unified_Ideograph", "Ideographic"},
    159259: {"Unified_Ideograph", "Ideographic"},
    159260: {"Unified_Ideograph", "Ideographic"},
    159261: {"Unified_Ideograph", "Ideographic"},
    159262: {"Unified_Ideograph", "Ideographic"},
    159263: {"Unified_Ideograph", "Ideographic"},
    159264: {"Unified_Ideograph", "Ideographic"},
    159265: {"Unified_Ideograph", "Ideographic"},
    159266: {"Unified_Ideograph", "Ideographic"},
    159267: {"Unified_Ideograph", "Ideographic"},
    159268: {"Unified_Ideograph", "Ideographic"},
    159269: {"Unified_Ideograph", "Ideographic"},
    159270: {"Unified_Ideograph", "Ideographic"},
    159271: {"Unified_Ideograph", "Ideographic"},
    159272: {"Unified_Ideograph", "Ideographic"},
    159273: {"Unified_Ideograph", "Ideographic"},
    159274: {"Unified_Ideograph", "Ideographic"},
    159275: {"Unified_Ideograph", "Ideographic"},
    159276: {"Unified_Ideograph", "Ideographic"},
    159277: {"Unified_Ideograph", "Ideographic"},
    159278: {"Unified_Ideograph", "Ideographic"},
    159279: {"Unified_Ideograph", "Ideographic"},
    159280: {"Unified_Ideograph", "Ideographic"},
    159281: {"Unified_Ideograph", "Ideographic"},
    159282: {"Unified_Ideograph", "Ideographic"},
    159283: {"Unified_Ideograph", "Ideographic"},
    159284: {"Unified_Ideograph", "Ideographic"},
    159285: {"Unified_Ideograph", "Ideographic"},
    159286: {"Unified_Ideograph", "Ideographic"},
    159287: {"Unified_Ideograph", "Ideographic"},
    159288: {"Unified_Ideograph", "Ideographic"},
    159289: {"Unified_Ideograph", "Ideographic"},
    159290: {"Unified_Ideograph", "Ideographic"},
    159291: {"Unified_Ideograph", "Ideographic"},
    159292: {"Unified_Ideograph", "Ideographic"},
    159293: {"Unified_Ideograph", "Ideographic"},
    159294: {"Unified_Ideograph", "Ideographic"},
    159295: {"Unified_Ideograph", "Ideographic"},
    159296: {"Unified_Ideograph", "Ideographic"},
    159297: {"Unified_Ideograph", "Ideographic"},
    159298: {"Unified_Ideograph", "Ideographic"},
    159299: {"Unified_Ideograph", "Ideographic"},
    159300: {"Unified_Ideograph", "Ideographic"},
    159301: {"Unified_Ideograph", "Ideographic"},
    159302: {"Unified_Ideograph", "Ideographic"},
    159303: {"Unified_Ideograph", "Ideographic"},
    159304: {"Unified_Ideograph", "Ideographic"},
    159305: {"Unified_Ideograph", "Ideographic"},
    159306: {"Unified_Ideograph", "Ideographic"},
    159307: {"Unified_Ideograph", "Ideographic"},
    159308: {"Unified_Ideograph", "Ideographic"},
    159309: {"Unified_Ideograph", "Ideographic"},
    159310: {"Unified_Ideograph", "Ideographic"},
    159311: {"Unified_Ideograph", "Ideographic"},
    159312: {"Unified_Ideograph", "Ideographic"},
    159313: {"Unified_Ideograph", "Ideographic"},
    159314: {"Unified_Ideograph", "Ideographic"},
    159315: {"Unified_Ideograph", "Ideographic"},
    159316: {"Unified_Ideograph", "Ideographic"},
    159317: {"Unified_Ideograph", "Ideographic"},
    159318: {"Unified_Ideograph", "Ideographic"},
    159319: {"Unified_Ideograph", "Ideographic"},
    159320: {"Unified_Ideograph", "Ideographic"},
    159321: {"Unified_Ideograph", "Ideographic"},
    159322: {"Unified_Ideograph", "Ideographic"},
    159323: {"Unified_Ideograph", "Ideographic"},
    159324: {"Unified_Ideograph", "Ideographic"},
    159325: {"Unified_Ideograph", "Ideographic"},
    159326: {"Unified_Ideograph", "Ideographic"},
    159327: {"Unified_Ideograph", "Ideographic"},
    159328: {"Unified_Ideograph", "Ideographic"},
    159329: {"Unified_Ideograph", "Ideographic"},
    159330: {"Unified_Ideograph", "Ideographic"},
    159331: {"Unified_Ideograph", "Ideographic"},
    159332: {"Unified_Ideograph", "Ideographic"},
    159333: {"Unified_Ideograph", "Ideographic"},
    159334: {"Unified_Ideograph", "Ideographic"},
    159335: {"Unified_Ideograph", "Ideographic"},
    159336: {"Unified_Ideograph", "Ideographic"},
    159337: {"Unified_Ideograph", "Ideographic"},
    159338: {"Unified_Ideograph", "Ideographic"},
    159339: {"Unified_Ideograph", "Ideographic"},
    159340: {"Unified_Ideograph", "Ideographic"},
    159341: {"Unified_Ideograph", "Ideographic"},
    159342: {"Unified_Ideograph", "Ideographic"},
    159343: {"Unified_Ideograph", "Ideographic"},
    159344: {"Unified_Ideograph", "Ideographic"},
    159345: {"Unified_Ideograph", "Ideographic"},
    159346: {"Unified_Ideograph", "Ideographic"},
    159347: {"Unified_Ideograph", "Ideographic"},
    159348: {"Unified_Ideograph", "Ideographic"},
    159349: {"Unified_Ideograph", "Ideographic"},
    159350: {"Unified_Ideograph", "Ideographic"},
    159351: {"Unified_Ideograph", "Ideographic"},
    159352: {"Unified_Ideograph", "Ideographic"},
    159353: {"Unified_Ideograph", "Ideographic"},
    159354: {"Unified_Ideograph", "Ideographic"},
    159355: {"Unified_Ideograph", "Ideographic"},
    159356: {"Unified_Ideograph", "Ideographic"},
    159357: {"Unified_Ideograph", "Ideographic"},
    159358: {"Unified_Ideograph", "Ideographic"},
    159359: {"Unified_Ideograph", "Ideographic"},
    159360: {"Unified_Ideograph", "Ideographic"},
    159361: {"Unified_Ideograph", "Ideographic"},
    159362: {"Unified_Ideograph", "Ideographic"},
    159363: {"Unified_Ideograph", "Ideographic"},
    159364: {"Unified_Ideograph", "Ideographic"},
    159365: {"Unified_Ideograph", "Ideographic"},
    159366: {"Unified_Ideograph", "Ideographic"},
    159367: {"Unified_Ideograph", "Ideographic"},
    159368: {"Unified_Ideograph", "Ideographic"},
    159369: {"Unified_Ideograph", "Ideographic"},
    159370: {"Unified_Ideograph", "Ideographic"},
    159371: {"Unified_Ideograph", "Ideographic"},
    159372: {"Unified_Ideograph", "Ideographic"},
    159373: {"Unified_Ideograph", "Ideographic"},
    159374: {"Unified_Ideograph", "Ideographic"},
    159375: {"Unified_Ideograph", "Ideographic"},
    159376: {"Unified_Ideograph", "Ideographic"},
    159377: {"Unified_Ideograph", "Ideographic"},
    159378: {"Unified_Ideograph", "Ideographic"},
    159379: {"Unified_Ideograph", "Ideographic"},
    159380: {"Unified_Ideograph", "Ideographic"},
    159381: {"Unified_Ideograph", "Ideographic"},
    159382: {"Unified_Ideograph", "Ideographic"},
    159383: {"Unified_Ideograph", "Ideographic"},
    159384: {"Unified_Ideograph", "Ideographic"},
    159385: {"Unified_Ideograph", "Ideographic"},
    159386: {"Unified_Ideograph", "Ideographic"},
    159387: {"Unified_Ideograph", "Ideographic"},
    159388: {"Unified_Ideograph", "Ideographic"},
    159389: {"Unified_Ideograph", "Ideographic"},
    159390: {"Unified_Ideograph", "Ideographic"},
    159391: {"Unified_Ideograph", "Ideographic"},
    159392: {"Unified_Ideograph", "Ideographic"},
    159393: {"Unified_Ideograph", "Ideographic"},
    159394: {"Unified_Ideograph", "Ideographic"},
    159395: {"Unified_Ideograph", "Ideographic"},
    159396: {"Unified_Ideograph", "Ideographic"},
    159397: {"Unified_Ideograph", "Ideographic"},
    159398: {"Unified_Ideograph", "Ideographic"},
    159399: {"Unified_Ideograph", "Ideographic"},
    159400: {"Unified_Ideograph", "Ideographic"},
    159401: {"Unified_Ideograph", "Ideographic"},
    159402: {"Unified_Ideograph", "Ideographic"},
    159403: {"Unified_Ideograph", "Ideographic"},
    159404: {"Unified_Ideograph", "Ideographic"},
    159405: {"Unified_Ideograph", "Ideographic"},
    159406: {"Unified_Ideograph", "Ideographic"},
    159407: {"Unified_Ideograph", "Ideographic"},
    159408: {"Unified_Ideograph", "Ideographic"},
    159409: {"Unified_Ideograph", "Ideographic"},
    159410: {"Unified_Ideograph", "Ideographic"},
    159411: {"Unified_Ideograph", "Ideographic"},
    159412: {"Unified_Ideograph", "Ideographic"},
    159413: {"Unified_Ideograph", "Ideographic"},
    159414: {"Unified_Ideograph", "Ideographic"},
    159415: {"Unified_Ideograph", "Ideographic"},
    159416: {"Unified_Ideograph", "Ideographic"},
    159417: {"Unified_Ideograph", "Ideographic"},
    159418: {"Unified_Ideograph", "Ideographic"},
    159419: {"Unified_Ideograph", "Ideographic"},
    159420: {"Unified_Ideograph", "Ideographic"},
    159421: {"Unified_Ideograph", "Ideographic"},
    159422: {"Unified_Ideograph", "Ideographic"},
    159423: {"Unified_Ideograph", "Ideographic"},
    159424: {"Unified_Ideograph", "Ideographic"},
    159425: {"Unified_Ideograph", "Ideographic"},
    159426: {"Unified_Ideograph", "Ideographic"},
    159427: {"Unified_Ideograph", "Ideographic"},
    159428: {"Unified_Ideograph", "Ideographic"},
    159429: {"Unified_Ideograph", "Ideographic"},
    159430: {"Unified_Ideograph", "Ideographic"},
    159431: {"Unified_Ideograph", "Ideographic"},
    159432: {"Unified_Ideograph", "Ideographic"},
    159433: {"Unified_Ideograph", "Ideographic"},
    159434: {"Unified_Ideograph", "Ideographic"},
    159435: {"Unified_Ideograph", "Ideographic"},
    159436: {"Unified_Ideograph", "Ideographic"},
    159437: {"Unified_Ideograph", "Ideographic"},
    159438: {"Unified_Ideograph", "Ideographic"},
    159439: {"Unified_Ideograph", "Ideographic"},
    159440: {"Unified_Ideograph", "Ideographic"},
    159441: {"Unified_Ideograph", "Ideographic"},
    159442: {"Unified_Ideograph", "Ideographic"},
    159443: {"Unified_Ideograph", "Ideographic"},
    159444: {"Unified_Ideograph", "Ideographic"},
    159445: {"Unified_Ideograph", "Ideographic"},
    159446: {"Unified_Ideograph", "Ideographic"},
    159447: {"Unified_Ideograph", "Ideographic"},
    159448: {"Unified_Ideograph", "Ideographic"},
    159449: {"Unified_Ideograph", "Ideographic"},
    159450: {"Unified_Ideograph", "Ideographic"},
    159451: {"Unified_Ideograph", "Ideographic"},
    159452: {"Unified_Ideograph", "Ideographic"},
    159453: {"Unified_Ideograph", "Ideographic"},
    159454: {"Unified_Ideograph", "Ideographic"},
    159455: {"Unified_Ideograph", "Ideographic"},
    159456: {"Unified_Ideograph", "Ideographic"},
    159457: {"Unified_Ideograph", "Ideographic"},
    159458: {"Unified_Ideograph", "Ideographic"},
    159459: {"Unified_Ideograph", "Ideographic"},
    159460: {"Unified_Ideograph", "Ideographic"},
    159461: {"Unified_Ideograph", "Ideographic"},
    159462: {"Unified_Ideograph", "Ideographic"},
    159463: {"Unified_Ideograph", "Ideographic"},
    159464: {"Unified_Ideograph", "Ideographic"},
    159465: {"Unified_Ideograph", "Ideographic"},
    159466: {"Unified_Ideograph", "Ideographic"},
    159467: {"Unified_Ideograph", "Ideographic"},
    159468: {"Unified_Ideograph", "Ideographic"},
    159469: {"Unified_Ideograph", "Ideographic"},
    159470: {"Unified_Ideograph", "Ideographic"},
    159471: {"Unified_Ideograph", "Ideographic"},
    159472: {"Unified_Ideograph", "Ideographic"},
    159473: {"Unified_Ideograph", "Ideographic"},
    159474: {"Unified_Ideograph", "Ideographic"},
    159475: {"Unified_Ideograph", "Ideographic"},
    159476: {"Unified_Ideograph", "Ideographic"},
    159477: {"Unified_Ideograph", "Ideographic"},
    159478: {"Unified_Ideograph", "Ideographic"},
    159479: {"Unified_Ideograph", "Ideographic"},
    159480: {"Unified_Ideograph", "Ideographic"},
    159481: {"Unified_Ideograph", "Ideographic"},
    159482: {"Unified_Ideograph", "Ideographic"},
    159483: {"Unified_Ideograph", "Ideographic"},
    159484: {"Unified_Ideograph", "Ideographic"},
    159485: {"Unified_Ideograph", "Ideographic"},
    159486: {"Unified_Ideograph", "Ideographic"},
    159487: {"Unified_Ideograph", "Ideographic"},
    159488: {"Unified_Ideograph", "Ideographic"},
    159489: {"Unified_Ideograph", "Ideographic"},
    159490: {"Unified_Ideograph", "Ideographic"},
    159491: {"Unified_Ideograph", "Ideographic"},
    159492: {"Unified_Ideograph", "Ideographic"},
    159493: {"Unified_Ideograph", "Ideographic"},
    159494: {"Unified_Ideograph", "Ideographic"},
    159495: {"Unified_Ideograph", "Ideographic"},
    159496: {"Unified_Ideograph", "Ideographic"},
    159497: {"Unified_Ideograph", "Ideographic"},
    159498: {"Unified_Ideograph", "Ideographic"},
    159499: {"Unified_Ideograph", "Ideographic"},
    159500: {"Unified_Ideograph", "Ideographic"},
    159501: {"Unified_Ideograph", "Ideographic"},
    159502: {"Unified_Ideograph", "Ideographic"},
    159503: {"Unified_Ideograph", "Ideographic"},
    159504: {"Unified_Ideograph", "Ideographic"},
    159505: {"Unified_Ideograph", "Ideographic"},
    159506: {"Unified_Ideograph", "Ideographic"},
    159507: {"Unified_Ideograph", "Ideographic"},
    159508: {"Unified_Ideograph", "Ideographic"},
    159509: {"Unified_Ideograph", "Ideographic"},
    159510: {"Unified_Ideograph", "Ideographic"},
    159511: {"Unified_Ideograph", "Ideographic"},
    159512: {"Unified_Ideograph", "Ideographic"},
    159513: {"Unified_Ideograph", "Ideographic"},
    159514: {"Unified_Ideograph", "Ideographic"},
    159515: {"Unified_Ideograph", "Ideographic"},
    159516: {"Unified_Ideograph", "Ideographic"},
    159517: {"Unified_Ideograph", "Ideographic"},
    159518: {"Unified_Ideograph", "Ideographic"},
    159519: {"Unified_Ideograph", "Ideographic"},
    159520: {"Unified_Ideograph", "Ideographic"},
    159521: {"Unified_Ideograph", "Ideographic"},
    159522: {"Unified_Ideograph", "Ideographic"},
    159523: {"Unified_Ideograph", "Ideographic"},
    159524: {"Unified_Ideograph", "Ideographic"},
    159525: {"Unified_Ideograph", "Ideographic"},
    159526: {"Unified_Ideograph", "Ideographic"},
    159527: {"Unified_Ideograph", "Ideographic"},
    159528: {"Unified_Ideograph", "Ideographic"},
    159529: {"Unified_Ideograph", "Ideographic"},
    159530: {"Unified_Ideograph", "Ideographic"},
    159531: {"Unified_Ideograph", "Ideographic"},
    159532: {"Unified_Ideograph", "Ideographic"},
    159533: {"Unified_Ideograph", "Ideographic"},
    159534: {"Unified_Ideograph", "Ideographic"},
    159535: {"Unified_Ideograph", "Ideographic"},
    159536: {"Unified_Ideograph", "Ideographic"},
    159537: {"Unified_Ideograph", "Ideographic"},
    159538: {"Unified_Ideograph", "Ideographic"},
    159539: {"Unified_Ideograph", "Ideographic"},
    159540: {"Unified_Ideograph", "Ideographic"},
    159541: {"Unified_Ideograph", "Ideographic"},
    159542: {"Unified_Ideograph", "Ideographic"},
    159543: {"Unified_Ideograph", "Ideographic"},
    159544: {"Unified_Ideograph", "Ideographic"},
    159545: {"Unified_Ideograph", "Ideographic"},
    159546: {"Unified_Ideograph", "Ideographic"},
    159547: {"Unified_Ideograph", "Ideographic"},
    159548: {"Unified_Ideograph", "Ideographic"},
    159549: {"Unified_Ideograph", "Ideographic"},
    159550: {"Unified_Ideograph", "Ideographic"},
    159551: {"Unified_Ideograph", "Ideographic"},
    159552: {"Unified_Ideograph", "Ideographic"},
    159553: {"Unified_Ideograph", "Ideographic"},
    159554: {"Unified_Ideograph", "Ideographic"},
    159555: {"Unified_Ideograph", "Ideographic"},
    159556: {"Unified_Ideograph", "Ideographic"},
    159557: {"Unified_Ideograph", "Ideographic"},
    159558: {"Unified_Ideograph", "Ideographic"},
    159559: {"Unified_Ideograph", "Ideographic"},
    159560: {"Unified_Ideograph", "Ideographic"},
    159561: {"Unified_Ideograph", "Ideographic"},
    159562: {"Unified_Ideograph", "Ideographic"},
    159563: {"Unified_Ideograph", "Ideographic"},
    159564: {"Unified_Ideograph", "Ideographic"},
    159565: {"Unified_Ideograph", "Ideographic"},
    159566: {"Unified_Ideograph", "Ideographic"},
    159567: {"Unified_Ideograph", "Ideographic"},
    159568: {"Unified_Ideograph", "Ideographic"},
    159569: {"Unified_Ideograph", "Ideographic"},
    159570: {"Unified_Ideograph", "Ideographic"},
    159571: {"Unified_Ideograph", "Ideographic"},
    159572: {"Unified_Ideograph", "Ideographic"},
    159573: {"Unified_Ideograph", "Ideographic"},
    159574: {"Unified_Ideograph", "Ideographic"},
    159575: {"Unified_Ideograph", "Ideographic"},
    159576: {"Unified_Ideograph", "Ideographic"},
    159577: {"Unified_Ideograph", "Ideographic"},
    159578: {"Unified_Ideograph", "Ideographic"},
    159579: {"Unified_Ideograph", "Ideographic"},
    159580: {"Unified_Ideograph", "Ideographic"},
    159581: {"Unified_Ideograph", "Ideographic"},
    159582: {"Unified_Ideograph", "Ideographic"},
    159583: {"Unified_Ideograph", "Ideographic"},
    159584: {"Unified_Ideograph", "Ideographic"},
    159585: {"Unified_Ideograph", "Ideographic"},
    159586: {"Unified_Ideograph", "Ideographic"},
    159587: {"Unified_Ideograph", "Ideographic"},
    159588: {"Unified_Ideograph", "Ideographic"},
    159589: {"Unified_Ideograph", "Ideographic"},
    159590: {"Unified_Ideograph", "Ideographic"},
    159591: {"Unified_Ideograph", "Ideographic"},
    159592: {"Unified_Ideograph", "Ideographic"},
    159593: {"Unified_Ideograph", "Ideographic"},
    159594: {"Unified_Ideograph", "Ideographic"},
    159595: {"Unified_Ideograph", "Ideographic"},
    159596: {"Unified_Ideograph", "Ideographic"},
    159597: {"Unified_Ideograph", "Ideographic"},
    159598: {"Unified_Ideograph", "Ideographic"},
    159599: {"Unified_Ideograph", "Ideographic"},
    159600: {"Unified_Ideograph", "Ideographic"},
    159601: {"Unified_Ideograph", "Ideographic"},
    159602: {"Unified_Ideograph", "Ideographic"},
    159603: {"Unified_Ideograph", "Ideographic"},
    159604: {"Unified_Ideograph", "Ideographic"},
    159605: {"Unified_Ideograph", "Ideographic"},
    159606: {"Unified_Ideograph", "Ideographic"},
    159607: {"Unified_Ideograph", "Ideographic"},
    159608: {"Unified_Ideograph", "Ideographic"},
    159609: {"Unified_Ideograph", "Ideographic"},
    159610: {"Unified_Ideograph", "Ideographic"},
    159611: {"Unified_Ideograph", "Ideographic"},
    159612: {"Unified_Ideograph", "Ideographic"},
    159613: {"Unified_Ideograph", "Ideographic"},
    159614: {"Unified_Ideograph", "Ideographic"},
    159615: {"Unified_Ideograph", "Ideographic"},
    159616: {"Unified_Ideograph", "Ideographic"},
    159617: {"Unified_Ideograph", "Ideographic"},
    159618: {"Unified_Ideograph", "Ideographic"},
    159619: {"Unified_Ideograph", "Ideographic"},
    159620: {"Unified_Ideograph", "Ideographic"},
    159621: {"Unified_Ideograph", "Ideographic"},
    159622: {"Unified_Ideograph", "Ideographic"},
    159623: {"Unified_Ideograph", "Ideographic"},
    159624: {"Unified_Ideograph", "Ideographic"},
    159625: {"Unified_Ideograph", "Ideographic"},
    159626: {"Unified_Ideograph", "Ideographic"},
    159627: {"Unified_Ideograph", "Ideographic"},
    159628: {"Unified_Ideograph", "Ideographic"},
    159629: {"Unified_Ideograph", "Ideographic"},
    159630: {"Unified_Ideograph", "Ideographic"},
    159631: {"Unified_Ideograph", "Ideographic"},
    159632: {"Unified_Ideograph", "Ideographic"},
    159633: {"Unified_Ideograph", "Ideographic"},
    159634: {"Unified_Ideograph", "Ideographic"},
    159635: {"Unified_Ideograph", "Ideographic"},
    159636: {"Unified_Ideograph", "Ideographic"},
    159637: {"Unified_Ideograph", "Ideographic"},
    159638: {"Unified_Ideograph", "Ideographic"},
    159639: {"Unified_Ideograph", "Ideographic"},
    159640: {"Unified_Ideograph", "Ideographic"},
    159641: {"Unified_Ideograph", "Ideographic"},
    159642: {"Unified_Ideograph", "Ideographic"},
    159643: {"Unified_Ideograph", "Ideographic"},
    159644: {"Unified_Ideograph", "Ideographic"},
    159645: {"Unified_Ideograph", "Ideographic"},
    159646: {"Unified_Ideograph", "Ideographic"},
    159647: {"Unified_Ideograph", "Ideographic"},
    159648: {"Unified_Ideograph", "Ideographic"},
    159649: {"Unified_Ideograph", "Ideographic"},
    159650: {"Unified_Ideograph", "Ideographic"},
    159651: {"Unified_Ideograph", "Ideographic"},
    159652: {"Unified_Ideograph", "Ideographic"},
    159653: {"Unified_Ideograph", "Ideographic"},
    159654: {"Unified_Ideograph", "Ideographic"},
    159655: {"Unified_Ideograph", "Ideographic"},
    159656: {"Unified_Ideograph", "Ideographic"},
    159657: {"Unified_Ideograph", "Ideographic"},
    159658: {"Unified_Ideograph", "Ideographic"},
    159659: {"Unified_Ideograph", "Ideographic"},
    159660: {"Unified_Ideograph", "Ideographic"},
    159661: {"Unified_Ideograph", "Ideographic"},
    159662: {"Unified_Ideograph", "Ideographic"},
    159663: {"Unified_Ideograph", "Ideographic"},
    159664: {"Unified_Ideograph", "Ideographic"},
    159665: {"Unified_Ideograph", "Ideographic"},
    159666: {"Unified_Ideograph", "Ideographic"},
    159667: {"Unified_Ideograph", "Ideographic"},
    159668: {"Unified_Ideograph", "Ideographic"},
    159669: {"Unified_Ideograph", "Ideographic"},
    159670: {"Unified_Ideograph", "Ideographic"},
    159671: {"Unified_Ideograph", "Ideographic"},
    159672: {"Unified_Ideograph", "Ideographic"},
    159673: {"Unified_Ideograph", "Ideographic"},
    159674: {"Unified_Ideograph", "Ideographic"},
    159675: {"Unified_Ideograph", "Ideographic"},
    159676: {"Unified_Ideograph", "Ideographic"},
    159677: {"Unified_Ideograph", "Ideographic"},
    159678: {"Unified_Ideograph", "Ideographic"},
    159679: {"Unified_Ideograph", "Ideographic"},
    159680: {"Unified_Ideograph", "Ideographic"},
    159681: {"Unified_Ideograph", "Ideographic"},
    159682: {"Unified_Ideograph", "Ideographic"},
    159683: {"Unified_Ideograph", "Ideographic"},
    159684: {"Unified_Ideograph", "Ideographic"},
    159685: {"Unified_Ideograph", "Ideographic"},
    159686: {"Unified_Ideograph", "Ideographic"},
    159687: {"Unified_Ideograph", "Ideographic"},
    159688: {"Unified_Ideograph", "Ideographic"},
    159689: {"Unified_Ideograph", "Ideographic"},
    159690: {"Unified_Ideograph", "Ideographic"},
    159691: {"Unified_Ideograph", "Ideographic"},
    159692: {"Unified_Ideograph", "Ideographic"},
    159693: {"Unified_Ideograph", "Ideographic"},
    159694: {"Unified_Ideograph", "Ideographic"},
    159695: {"Unified_Ideograph", "Ideographic"},
    159696: {"Unified_Ideograph", "Ideographic"},
    159697: {"Unified_Ideograph", "Ideographic"},
    159698: {"Unified_Ideograph", "Ideographic"},
    159699: {"Unified_Ideograph", "Ideographic"},
    159700: {"Unified_Ideograph", "Ideographic"},
    159701: {"Unified_Ideograph", "Ideographic"},
    159702: {"Unified_Ideograph", "Ideographic"},
    159703: {"Unified_Ideograph", "Ideographic"},
    159704: {"Unified_Ideograph", "Ideographic"},
    159705: {"Unified_Ideograph", "Ideographic"},
    159706: {"Unified_Ideograph", "Ideographic"},
    159707: {"Unified_Ideograph", "Ideographic"},
    159708: {"Unified_Ideograph", "Ideographic"},
    159709: {"Unified_Ideograph", "Ideographic"},
    159710: {"Unified_Ideograph", "Ideographic"},
    159711: {"Unified_Ideograph", "Ideographic"},
    159712: {"Unified_Ideograph", "Ideographic"},
    159713: {"Unified_Ideograph", "Ideographic"},
    159714: {"Unified_Ideograph", "Ideographic"},
    159715: {"Unified_Ideograph", "Ideographic"},
    159716: {"Unified_Ideograph", "Ideographic"},
    159717: {"Unified_Ideograph", "Ideographic"},
    159718: {"Unified_Ideograph", "Ideographic"},
    159719: {"Unified_Ideograph", "Ideographic"},
    159720: {"Unified_Ideograph", "Ideographic"},
    159721: {"Unified_Ideograph", "Ideographic"},
    159722: {"Unified_Ideograph", "Ideographic"},
    159723: {"Unified_Ideograph", "Ideographic"},
    159724: {"Unified_Ideograph", "Ideographic"},
    159725: {"Unified_Ideograph", "Ideographic"},
    159726: {"Unified_Ideograph", "Ideographic"},
    159727: {"Unified_Ideograph", "Ideographic"},
    159728: {"Unified_Ideograph", "Ideographic"},
    159729: {"Unified_Ideograph", "Ideographic"},
    159730: {"Unified_Ideograph", "Ideographic"},
    159731: {"Unified_Ideograph", "Ideographic"},
    159732: {"Unified_Ideograph", "Ideographic"},
    159733: {"Unified_Ideograph", "Ideographic"},
    159734: {"Unified_Ideograph", "Ideographic"},
    159735: {"Unified_Ideograph", "Ideographic"},
    159736: {"Unified_Ideograph", "Ideographic"},
    159737: {"Unified_Ideograph", "Ideographic"},
    159738: {"Unified_Ideograph", "Ideographic"},
    159739: {"Unified_Ideograph", "Ideographic"},
    159740: {"Unified_Ideograph", "Ideographic"},
    159741: {"Unified_Ideograph", "Ideographic"},
    159742: {"Unified_Ideograph", "Ideographic"},
    159743: {"Unified_Ideograph", "Ideographic"},
    159744: {"Unified_Ideograph", "Ideographic"},
    159745: {"Unified_Ideograph", "Ideographic"},
    159746: {"Unified_Ideograph", "Ideographic"},
    159747: {"Unified_Ideograph", "Ideographic"},
    159748: {"Unified_Ideograph", "Ideographic"},
    159749: {"Unified_Ideograph", "Ideographic"},
    159750: {"Unified_Ideograph", "Ideographic"},
    159751: {"Unified_Ideograph", "Ideographic"},
    159752: {"Unified_Ideograph", "Ideographic"},
    159753: {"Unified_Ideograph", "Ideographic"},
    159754: {"Unified_Ideograph", "Ideographic"},
    159755: {"Unified_Ideograph", "Ideographic"},
    159756: {"Unified_Ideograph", "Ideographic"},
    159757: {"Unified_Ideograph", "Ideographic"},
    159758: {"Unified_Ideograph", "Ideographic"},
    159759: {"Unified_Ideograph", "Ideographic"},
    159760: {"Unified_Ideograph", "Ideographic"},
    159761: {"Unified_Ideograph", "Ideographic"},
    159762: {"Unified_Ideograph", "Ideographic"},
    159763: {"Unified_Ideograph", "Ideographic"},
    159764: {"Unified_Ideograph", "Ideographic"},
    159765: {"Unified_Ideograph", "Ideographic"},
    159766: {"Unified_Ideograph", "Ideographic"},
    159767: {"Unified_Ideograph", "Ideographic"},
    159768: {"Unified_Ideograph", "Ideographic"},
    159769: {"Unified_Ideograph", "Ideographic"},
    159770: {"Unified_Ideograph", "Ideographic"},
    159771: {"Unified_Ideograph", "Ideographic"},
    159772: {"Unified_Ideograph", "Ideographic"},
    159773: {"Unified_Ideograph", "Ideographic"},
    159774: {"Unified_Ideograph", "Ideographic"},
    159775: {"Unified_Ideograph", "Ideographic"},
    159776: {"Unified_Ideograph", "Ideographic"},
    159777: {"Unified_Ideograph", "Ideographic"},
    159778: {"Unified_Ideograph", "Ideographic"},
    159779: {"Unified_Ideograph", "Ideographic"},
    159780: {"Unified_Ideograph", "Ideographic"},
    159781: {"Unified_Ideograph", "Ideographic"},
    159782: {"Unified_Ideograph", "Ideographic"},
    159783: {"Unified_Ideograph", "Ideographic"},
    159784: {"Unified_Ideograph", "Ideographic"},
    159785: {"Unified_Ideograph", "Ideographic"},
    159786: {"Unified_Ideograph", "Ideographic"},
    159787: {"Unified_Ideograph", "Ideographic"},
    159788: {"Unified_Ideograph", "Ideographic"},
    159789: {"Unified_Ideograph", "Ideographic"},
    159790: {"Unified_Ideograph", "Ideographic"},
    159791: {"Unified_Ideograph", "Ideographic"},
    159792: {"Unified_Ideograph", "Ideographic"},
    159793: {"Unified_Ideograph", "Ideographic"},
    159794: {"Unified_Ideograph", "Ideographic"},
    159795: {"Unified_Ideograph", "Ideographic"},
    159796: {"Unified_Ideograph", "Ideographic"},
    159797: {"Unified_Ideograph", "Ideographic"},
    159798: {"Unified_Ideograph", "Ideographic"},
    159799: {"Unified_Ideograph", "Ideographic"},
    159800: {"Unified_Ideograph", "Ideographic"},
    159801: {"Unified_Ideograph", "Ideographic"},
    159802: {"Unified_Ideograph", "Ideographic"},
    159803: {"Unified_Ideograph", "Ideographic"},
    159804: {"Unified_Ideograph", "Ideographic"},
    159805: {"Unified_Ideograph", "Ideographic"},
    159806: {"Unified_Ideograph", "Ideographic"},
    159807: {"Unified_Ideograph", "Ideographic"},
    159808: {"Unified_Ideograph", "Ideographic"},
    159809: {"Unified_Ideograph", "Ideographic"},
    159810: {"Unified_Ideograph", "Ideographic"},
    159811: {"Unified_Ideograph", "Ideographic"},
    159812: {"Unified_Ideograph", "Ideographic"},
    159813: {"Unified_Ideograph", "Ideographic"},
    159814: {"Unified_Ideograph", "Ideographic"},
    159815: {"Unified_Ideograph", "Ideographic"},
    159816: {"Unified_Ideograph", "Ideographic"},
    159817: {"Unified_Ideograph", "Ideographic"},
    159818: {"Unified_Ideograph", "Ideographic"},
    159819: {"Unified_Ideograph", "Ideographic"},
    159820: {"Unified_Ideograph", "Ideographic"},
    159821: {"Unified_Ideograph", "Ideographic"},
    159822: {"Unified_Ideograph", "Ideographic"},
    159823: {"Unified_Ideograph", "Ideographic"},
    159824: {"Unified_Ideograph", "Ideographic"},
    159825: {"Unified_Ideograph", "Ideographic"},
    159826: {"Unified_Ideograph", "Ideographic"},
    159827: {"Unified_Ideograph", "Ideographic"},
    159828: {"Unified_Ideograph", "Ideographic"},
    159829: {"Unified_Ideograph", "Ideographic"},
    159830: {"Unified_Ideograph", "Ideographic"},
    159831: {"Unified_Ideograph", "Ideographic"},
    159832: {"Unified_Ideograph", "Ideographic"},
    159833: {"Unified_Ideograph", "Ideographic"},
    159834: {"Unified_Ideograph", "Ideographic"},
    159835: {"Unified_Ideograph", "Ideographic"},
    159836: {"Unified_Ideograph", "Ideographic"},
    159837: {"Unified_Ideograph", "Ideographic"},
    159838: {"Unified_Ideograph", "Ideographic"},
    159839: {"Unified_Ideograph", "Ideographic"},
    159840: {"Unified_Ideograph", "Ideographic"},
    159841: {"Unified_Ideograph", "Ideographic"},
    159842: {"Unified_Ideograph", "Ideographic"},
    159843: {"Unified_Ideograph", "Ideographic"},
    159844: {"Unified_Ideograph", "Ideographic"},
    159845: {"Unified_Ideograph", "Ideographic"},
    159846: {"Unified_Ideograph", "Ideographic"},
    159847: {"Unified_Ideograph", "Ideographic"},
    159848: {"Unified_Ideograph", "Ideographic"},
    159849: {"Unified_Ideograph", "Ideographic"},
    159850: {"Unified_Ideograph", "Ideographic"},
    159851: {"Unified_Ideograph", "Ideographic"},
    159852: {"Unified_Ideograph", "Ideographic"},
    159853: {"Unified_Ideograph", "Ideographic"},
    159854: {"Unified_Ideograph", "Ideographic"},
    159855: {"Unified_Ideograph", "Ideographic"},
    159856: {"Unified_Ideograph", "Ideographic"},
    159857: {"Unified_Ideograph", "Ideographic"},
    159858: {"Unified_Ideograph", "Ideographic"},
    159859: {"Unified_Ideograph", "Ideographic"},
    159860: {"Unified_Ideograph", "Ideographic"},
    159861: {"Unified_Ideograph", "Ideographic"},
    159862: {"Unified_Ideograph", "Ideographic"},
    159863: {"Unified_Ideograph", "Ideographic"},
    159864: {"Unified_Ideograph", "Ideographic"},
    159865: {"Unified_Ideograph", "Ideographic"},
    159866: {"Unified_Ideograph", "Ideographic"},
    159867: {"Unified_Ideograph", "Ideographic"},
    159868: {"Unified_Ideograph", "Ideographic"},
    159869: {"Unified_Ideograph", "Ideographic"},
    159870: {"Unified_Ideograph", "Ideographic"},
    159871: {"Unified_Ideograph", "Ideographic"},
    159872: {"Unified_Ideograph", "Ideographic"},
    159873: {"Unified_Ideograph", "Ideographic"},
    159874: {"Unified_Ideograph", "Ideographic"},
    159875: {"Unified_Ideograph", "Ideographic"},
    159876: {"Unified_Ideograph", "Ideographic"},
    159877: {"Unified_Ideograph", "Ideographic"},
    159878: {"Unified_Ideograph", "Ideographic"},
    159879: {"Unified_Ideograph", "Ideographic"},
    159880: {"Unified_Ideograph", "Ideographic"},
    159881: {"Unified_Ideograph", "Ideographic"},
    159882: {"Unified_Ideograph", "Ideographic"},
    159883: {"Unified_Ideograph", "Ideographic"},
    159884: {"Unified_Ideograph", "Ideographic"},
    159885: {"Unified_Ideograph", "Ideographic"},
    159886: {"Unified_Ideograph", "Ideographic"},
    159887: {"Unified_Ideograph", "Ideographic"},
    159888: {"Unified_Ideograph", "Ideographic"},
    159889: {"Unified_Ideograph", "Ideographic"},
    159890: {"Unified_Ideograph", "Ideographic"},
    159891: {"Unified_Ideograph", "Ideographic"},
    159892: {"Unified_Ideograph", "Ideographic"},
    159893: {"Unified_Ideograph", "Ideographic"},
    159894: {"Unified_Ideograph", "Ideographic"},
    159895: {"Unified_Ideograph", "Ideographic"},
    159896: {"Unified_Ideograph", "Ideographic"},
    159897: {"Unified_Ideograph", "Ideographic"},
    159898: {"Unified_Ideograph", "Ideographic"},
    159899: {"Unified_Ideograph", "Ideographic"},
    159900: {"Unified_Ideograph", "Ideographic"},
    159901: {"Unified_Ideograph", "Ideographic"},
    159902: {"Unified_Ideograph", "Ideographic"},
    159903: {"Unified_Ideograph", "Ideographic"},
    159904: {"Unified_Ideograph", "Ideographic"},
    159905: {"Unified_Ideograph", "Ideographic"},
    159906: {"Unified_Ideograph", "Ideographic"},
    159907: {"Unified_Ideograph", "Ideographic"},
    159908: {"Unified_Ideograph", "Ideographic"},
    159909: {"Unified_Ideograph", "Ideographic"},
    159910: {"Unified_Ideograph", "Ideographic"},
    159911: {"Unified_Ideograph", "Ideographic"},
    159912: {"Unified_Ideograph", "Ideographic"},
    159913: {"Unified_Ideograph", "Ideographic"},
    159914: {"Unified_Ideograph", "Ideographic"},
    159915: {"Unified_Ideograph", "Ideographic"},
    159916: {"Unified_Ideograph", "Ideographic"},
    159917: {"Unified_Ideograph", "Ideographic"},
    159918: {"Unified_Ideograph", "Ideographic"},
    159919: {"Unified_Ideograph", "Ideographic"},
    159920: {"Unified_Ideograph", "Ideographic"},
    159921: {"Unified_Ideograph", "Ideographic"},
    159922: {"Unified_Ideograph", "Ideographic"},
    159923: {"Unified_Ideograph", "Ideographic"},
    159924: {"Unified_Ideograph", "Ideographic"},
    159925: {"Unified_Ideograph", "Ideographic"},
    159926: {"Unified_Ideograph", "Ideographic"},
    159927: {"Unified_Ideograph", "Ideographic"},
    159928: {"Unified_Ideograph", "Ideographic"},
    159929: {"Unified_Ideograph", "Ideographic"},
    159930: {"Unified_Ideograph", "Ideographic"},
    159931: {"Unified_Ideograph", "Ideographic"},
    159932: {"Unified_Ideograph", "Ideographic"},
    159933: {"Unified_Ideograph", "Ideographic"},
    159934: {"Unified_Ideograph", "Ideographic"},
    159935: {"Unified_Ideograph", "Ideographic"},
    159936: {"Unified_Ideograph", "Ideographic"},
    159937: {"Unified_Ideograph", "Ideographic"},
    159938: {"Unified_Ideograph", "Ideographic"},
    159939: {"Unified_Ideograph", "Ideographic"},
    159940: {"Unified_Ideograph", "Ideographic"},
    159941: {"Unified_Ideograph", "Ideographic"},
    159942: {"Unified_Ideograph", "Ideographic"},
    159943: {"Unified_Ideograph", "Ideographic"},
    159944: {"Unified_Ideograph", "Ideographic"},
    159945: {"Unified_Ideograph", "Ideographic"},
    159946: {"Unified_Ideograph", "Ideographic"},
    159947: {"Unified_Ideograph", "Ideographic"},
    159948: {"Unified_Ideograph", "Ideographic"},
    159949: {"Unified_Ideograph", "Ideographic"},
    159950: {"Unified_Ideograph", "Ideographic"},
    159951: {"Unified_Ideograph", "Ideographic"},
    159952: {"Unified_Ideograph", "Ideographic"},
    159953: {"Unified_Ideograph", "Ideographic"},
    159954: {"Unified_Ideograph", "Ideographic"},
    159955: {"Unified_Ideograph", "Ideographic"},
    159956: {"Unified_Ideograph", "Ideographic"},
    159957: {"Unified_Ideograph", "Ideographic"},
    159958: {"Unified_Ideograph", "Ideographic"},
    159959: {"Unified_Ideograph", "Ideographic"},
    159960: {"Unified_Ideograph", "Ideographic"},
    159961: {"Unified_Ideograph", "Ideographic"},
    159962: {"Unified_Ideograph", "Ideographic"},
    159963: {"Unified_Ideograph", "Ideographic"},
    159964: {"Unified_Ideograph", "Ideographic"},
    159965: {"Unified_Ideograph", "Ideographic"},
    159966: {"Unified_Ideograph", "Ideographic"},
    159967: {"Unified_Ideograph", "Ideographic"},
    159968: {"Unified_Ideograph", "Ideographic"},
    159969: {"Unified_Ideograph", "Ideographic"},
    159970: {"Unified_Ideograph", "Ideographic"},
    159971: {"Unified_Ideograph", "Ideographic"},
    159972: {"Unified_Ideograph", "Ideographic"},
    159973: {"Unified_Ideograph", "Ideographic"},
    159974: {"Unified_Ideograph", "Ideographic"},
    159975: {"Unified_Ideograph", "Ideographic"},
    159976: {"Unified_Ideograph", "Ideographic"},
    159977: {"Unified_Ideograph", "Ideographic"},
    159978: {"Unified_Ideograph", "Ideographic"},
    159979: {"Unified_Ideograph", "Ideographic"},
    159980: {"Unified_Ideograph", "Ideographic"},
    159981: {"Unified_Ideograph", "Ideographic"},
    159982: {"Unified_Ideograph", "Ideographic"},
    159983: {"Unified_Ideograph", "Ideographic"},
    159984: {"Unified_Ideograph", "Ideographic"},
    159985: {"Unified_Ideograph", "Ideographic"},
    159986: {"Unified_Ideograph", "Ideographic"},
    159987: {"Unified_Ideograph", "Ideographic"},
    159988: {"Unified_Ideograph", "Ideographic"},
    159989: {"Unified_Ideograph", "Ideographic"},
    159990: {"Unified_Ideograph", "Ideographic"},
    159991: {"Unified_Ideograph", "Ideographic"},
    159992: {"Unified_Ideograph", "Ideographic"},
    159993: {"Unified_Ideograph", "Ideographic"},
    159994: {"Unified_Ideograph", "Ideographic"},
    159995: {"Unified_Ideograph", "Ideographic"},
    159996: {"Unified_Ideograph", "Ideographic"},
    159997: {"Unified_Ideograph", "Ideographic"},
    159998: {"Unified_Ideograph", "Ideographic"},
    159999: {"Unified_Ideograph", "Ideographic"},
    160000: {"Unified_Ideograph", "Ideographic"},
    160001: {"Unified_Ideograph", "Ideographic"},
    160002: {"Unified_Ideograph", "Ideographic"},
    160003: {"Unified_Ideograph", "Ideographic"},
    160004: {"Unified_Ideograph", "Ideographic"},
    160005: {"Unified_Ideograph", "Ideographic"},
    160006: {"Unified_Ideograph", "Ideographic"},
    160007: {"Unified_Ideograph", "Ideographic"},
    160008: {"Unified_Ideograph", "Ideographic"},
    160009: {"Unified_Ideograph", "Ideographic"},
    160010: {"Unified_Ideograph", "Ideographic"},
    160011: {"Unified_Ideograph", "Ideographic"},
    160012: {"Unified_Ideograph", "Ideographic"},
    160013: {"Unified_Ideograph", "Ideographic"},
    160014: {"Unified_Ideograph", "Ideographic"},
    160015: {"Unified_Ideograph", "Ideographic"},
    160016: {"Unified_Ideograph", "Ideographic"},
    160017: {"Unified_Ideograph", "Ideographic"},
    160018: {"Unified_Ideograph", "Ideographic"},
    160019: {"Unified_Ideograph", "Ideographic"},
    160020: {"Unified_Ideograph", "Ideographic"},
    160021: {"Unified_Ideograph", "Ideographic"},
    160022: {"Unified_Ideograph", "Ideographic"},
    160023: {"Unified_Ideograph", "Ideographic"},
    160024: {"Unified_Ideograph", "Ideographic"},
    160025: {"Unified_Ideograph", "Ideographic"},
    160026: {"Unified_Ideograph", "Ideographic"},
    160027: {"Unified_Ideograph", "Ideographic"},
    160028: {"Unified_Ideograph", "Ideographic"},
    160029: {"Unified_Ideograph", "Ideographic"},
    160030: {"Unified_Ideograph", "Ideographic"},
    160031: {"Unified_Ideograph", "Ideographic"},
    160032: {"Unified_Ideograph", "Ideographic"},
    160033: {"Unified_Ideograph", "Ideographic"},
    160034: {"Unified_Ideograph", "Ideographic"},
    160035: {"Unified_Ideograph", "Ideographic"},
    160036: {"Unified_Ideograph", "Ideographic"},
    160037: {"Unified_Ideograph", "Ideographic"},
    160038: {"Unified_Ideograph", "Ideographic"},
    160039: {"Unified_Ideograph", "Ideographic"},
    160040: {"Unified_Ideograph", "Ideographic"},
    160041: {"Unified_Ideograph", "Ideographic"},
    160042: {"Unified_Ideograph", "Ideographic"},
    160043: {"Unified_Ideograph", "Ideographic"},
    160044: {"Unified_Ideograph", "Ideographic"},
    160045: {"Unified_Ideograph", "Ideographic"},
    160046: {"Unified_Ideograph", "Ideographic"},
    160047: {"Unified_Ideograph", "Ideographic"},
    160048: {"Unified_Ideograph", "Ideographic"},
    160049: {"Unified_Ideograph", "Ideographic"},
    160050: {"Unified_Ideograph", "Ideographic"},
    160051: {"Unified_Ideograph", "Ideographic"},
    160052: {"Unified_Ideograph", "Ideographic"},
    160053: {"Unified_Ideograph", "Ideographic"},
    160054: {"Unified_Ideograph", "Ideographic"},
    160055: {"Unified_Ideograph", "Ideographic"},
    160056: {"Unified_Ideograph", "Ideographic"},
    160057: {"Unified_Ideograph", "Ideographic"},
    160058: {"Unified_Ideograph", "Ideographic"},
    160059: {"Unified_Ideograph", "Ideographic"},
    160060: {"Unified_Ideograph", "Ideographic"},
    160061: {"Unified_Ideograph", "Ideographic"},
    160062: {"Unified_Ideograph", "Ideographic"},
    160063: {"Unified_Ideograph", "Ideographic"},
    160064: {"Unified_Ideograph", "Ideographic"},
    160065: {"Unified_Ideograph", "Ideographic"},
    160066: {"Unified_Ideograph", "Ideographic"},
    160067: {"Unified_Ideograph", "Ideographic"},
    160068: {"Unified_Ideograph", "Ideographic"},
    160069: {"Unified_Ideograph", "Ideographic"},
    160070: {"Unified_Ideograph", "Ideographic"},
    160071: {"Unified_Ideograph", "Ideographic"},
    160072: {"Unified_Ideograph", "Ideographic"},
    160073: {"Unified_Ideograph", "Ideographic"},
    160074: {"Unified_Ideograph", "Ideographic"},
    160075: {"Unified_Ideograph", "Ideographic"},
    160076: {"Unified_Ideograph", "Ideographic"},
    160077: {"Unified_Ideograph", "Ideographic"},
    160078: {"Unified_Ideograph", "Ideographic"},
    160079: {"Unified_Ideograph", "Ideographic"},
    160080: {"Unified_Ideograph", "Ideographic"},
    160081: {"Unified_Ideograph", "Ideographic"},
    160082: {"Unified_Ideograph", "Ideographic"},
    160083: {"Unified_Ideograph", "Ideographic"},
    160084: {"Unified_Ideograph", "Ideographic"},
    160085: {"Unified_Ideograph", "Ideographic"},
    160086: {"Unified_Ideograph", "Ideographic"},
    160087: {"Unified_Ideograph", "Ideographic"},
    160088: {"Unified_Ideograph", "Ideographic"},
    160089: {"Unified_Ideograph", "Ideographic"},
    160090: {"Unified_Ideograph", "Ideographic"},
    160091: {"Unified_Ideograph", "Ideographic"},
    160092: {"Unified_Ideograph", "Ideographic"},
    160093: {"Unified_Ideograph", "Ideographic"},
    160094: {"Unified_Ideograph", "Ideographic"},
    160095: {"Unified_Ideograph", "Ideographic"},
    160096: {"Unified_Ideograph", "Ideographic"},
    160097: {"Unified_Ideograph", "Ideographic"},
    160098: {"Unified_Ideograph", "Ideographic"},
    160099: {"Unified_Ideograph", "Ideographic"},
    160100: {"Unified_Ideograph", "Ideographic"},
    160101: {"Unified_Ideograph", "Ideographic"},
    160102: {"Unified_Ideograph", "Ideographic"},
    160103: {"Unified_Ideograph", "Ideographic"},
    160104: {"Unified_Ideograph", "Ideographic"},
    160105: {"Unified_Ideograph", "Ideographic"},
    160106: {"Unified_Ideograph", "Ideographic"},
    160107: {"Unified_Ideograph", "Ideographic"},
    160108: {"Unified_Ideograph", "Ideographic"},
    160109: {"Unified_Ideograph", "Ideographic"},
    160110: {"Unified_Ideograph", "Ideographic"},
    160111: {"Unified_Ideograph", "Ideographic"},
    160112: {"Unified_Ideograph", "Ideographic"},
    160113: {"Unified_Ideograph", "Ideographic"},
    160114: {"Unified_Ideograph", "Ideographic"},
    160115: {"Unified_Ideograph", "Ideographic"},
    160116: {"Unified_Ideograph", "Ideographic"},
    160117: {"Unified_Ideograph", "Ideographic"},
    160118: {"Unified_Ideograph", "Ideographic"},
    160119: {"Unified_Ideograph", "Ideographic"},
    160120: {"Unified_Ideograph", "Ideographic"},
    160121: {"Unified_Ideograph", "Ideographic"},
    160122: {"Unified_Ideograph", "Ideographic"},
    160123: {"Unified_Ideograph", "Ideographic"},
    160124: {"Unified_Ideograph", "Ideographic"},
    160125: {"Unified_Ideograph", "Ideographic"},
    160126: {"Unified_Ideograph", "Ideographic"},
    160127: {"Unified_Ideograph", "Ideographic"},
    160128: {"Unified_Ideograph", "Ideographic"},
    160129: {"Unified_Ideograph", "Ideographic"},
    160130: {"Unified_Ideograph", "Ideographic"},
    160131: {"Unified_Ideograph", "Ideographic"},
    160132: {"Unified_Ideograph", "Ideographic"},
    160133: {"Unified_Ideograph", "Ideographic"},
    160134: {"Unified_Ideograph", "Ideographic"},
    160135: {"Unified_Ideograph", "Ideographic"},
    160136: {"Unified_Ideograph", "Ideographic"},
    160137: {"Unified_Ideograph", "Ideographic"},
    160138: {"Unified_Ideograph", "Ideographic"},
    160139: {"Unified_Ideograph", "Ideographic"},
    160140: {"Unified_Ideograph", "Ideographic"},
    160141: {"Unified_Ideograph", "Ideographic"},
    160142: {"Unified_Ideograph", "Ideographic"},
    160143: {"Unified_Ideograph", "Ideographic"},
    160144: {"Unified_Ideograph", "Ideographic"},
    160145: {"Unified_Ideograph", "Ideographic"},
    160146: {"Unified_Ideograph", "Ideographic"},
    160147: {"Unified_Ideograph", "Ideographic"},
    160148: {"Unified_Ideograph", "Ideographic"},
    160149: {"Unified_Ideograph", "Ideographic"},
    160150: {"Unified_Ideograph", "Ideographic"},
    160151: {"Unified_Ideograph", "Ideographic"},
    160152: {"Unified_Ideograph", "Ideographic"},
    160153: {"Unified_Ideograph", "Ideographic"},
    160154: {"Unified_Ideograph", "Ideographic"},
    160155: {"Unified_Ideograph", "Ideographic"},
    160156: {"Unified_Ideograph", "Ideographic"},
    160157: {"Unified_Ideograph", "Ideographic"},
    160158: {"Unified_Ideograph", "Ideographic"},
    160159: {"Unified_Ideograph", "Ideographic"},
    160160: {"Unified_Ideograph", "Ideographic"},
    160161: {"Unified_Ideograph", "Ideographic"},
    160162: {"Unified_Ideograph", "Ideographic"},
    160163: {"Unified_Ideograph", "Ideographic"},
    160164: {"Unified_Ideograph", "Ideographic"},
    160165: {"Unified_Ideograph", "Ideographic"},
    160166: {"Unified_Ideograph", "Ideographic"},
    160167: {"Unified_Ideograph", "Ideographic"},
    160168: {"Unified_Ideograph", "Ideographic"},
    160169: {"Unified_Ideograph", "Ideographic"},
    160170: {"Unified_Ideograph", "Ideographic"},
    160171: {"Unified_Ideograph", "Ideographic"},
    160172: {"Unified_Ideograph", "Ideographic"},
    160173: {"Unified_Ideograph", "Ideographic"},
    160174: {"Unified_Ideograph", "Ideographic"},
    160175: {"Unified_Ideograph", "Ideographic"},
    160176: {"Unified_Ideograph", "Ideographic"},
    160177: {"Unified_Ideograph", "Ideographic"},
    160178: {"Unified_Ideograph", "Ideographic"},
    160179: {"Unified_Ideograph", "Ideographic"},
    160180: {"Unified_Ideograph", "Ideographic"},
    160181: {"Unified_Ideograph", "Ideographic"},
    160182: {"Unified_Ideograph", "Ideographic"},
    160183: {"Unified_Ideograph", "Ideographic"},
    160184: {"Unified_Ideograph", "Ideographic"},
    160185: {"Unified_Ideograph", "Ideographic"},
    160186: {"Unified_Ideograph", "Ideographic"},
    160187: {"Unified_Ideograph", "Ideographic"},
    160188: {"Unified_Ideograph", "Ideographic"},
    160189: {"Unified_Ideograph", "Ideographic"},
    160190: {"Unified_Ideograph", "Ideographic"},
    160191: {"Unified_Ideograph", "Ideographic"},
    160192: {"Unified_Ideograph", "Ideographic"},
    160193: {"Unified_Ideograph", "Ideographic"},
    160194: {"Unified_Ideograph", "Ideographic"},
    160195: {"Unified_Ideograph", "Ideographic"},
    160196: {"Unified_Ideograph", "Ideographic"},
    160197: {"Unified_Ideograph", "Ideographic"},
    160198: {"Unified_Ideograph", "Ideographic"},
    160199: {"Unified_Ideograph", "Ideographic"},
    160200: {"Unified_Ideograph", "Ideographic"},
    160201: {"Unified_Ideograph", "Ideographic"},
    160202: {"Unified_Ideograph", "Ideographic"},
    160203: {"Unified_Ideograph", "Ideographic"},
    160204: {"Unified_Ideograph", "Ideographic"},
    160205: {"Unified_Ideograph", "Ideographic"},
    160206: {"Unified_Ideograph", "Ideographic"},
    160207: {"Unified_Ideograph", "Ideographic"},
    160208: {"Unified_Ideograph", "Ideographic"},
    160209: {"Unified_Ideograph", "Ideographic"},
    160210: {"Unified_Ideograph", "Ideographic"},
    160211: {"Unified_Ideograph", "Ideographic"},
    160212: {"Unified_Ideograph", "Ideographic"},
    160213: {"Unified_Ideograph", "Ideographic"},
    160214: {"Unified_Ideograph", "Ideographic"},
    160215: {"Unified_Ideograph", "Ideographic"},
    160216: {"Unified_Ideograph", "Ideographic"},
    160217: {"Unified_Ideograph", "Ideographic"},
    160218: {"Unified_Ideograph", "Ideographic"},
    160219: {"Unified_Ideograph", "Ideographic"},
    160220: {"Unified_Ideograph", "Ideographic"},
    160221: {"Unified_Ideograph", "Ideographic"},
    160222: {"Unified_Ideograph", "Ideographic"},
    160223: {"Unified_Ideograph", "Ideographic"},
    160224: {"Unified_Ideograph", "Ideographic"},
    160225: {"Unified_Ideograph", "Ideographic"},
    160226: {"Unified_Ideograph", "Ideographic"},
    160227: {"Unified_Ideograph", "Ideographic"},
    160228: {"Unified_Ideograph", "Ideographic"},
    160229: {"Unified_Ideograph", "Ideographic"},
    160230: {"Unified_Ideograph", "Ideographic"},
    160231: {"Unified_Ideograph", "Ideographic"},
    160232: {"Unified_Ideograph", "Ideographic"},
    160233: {"Unified_Ideograph", "Ideographic"},
    160234: {"Unified_Ideograph", "Ideographic"},
    160235: {"Unified_Ideograph", "Ideographic"},
    160236: {"Unified_Ideograph", "Ideographic"},
    160237: {"Unified_Ideograph", "Ideographic"},
    160238: {"Unified_Ideograph", "Ideographic"},
    160239: {"Unified_Ideograph", "Ideographic"},
    160240: {"Unified_Ideograph", "Ideographic"},
    160241: {"Unified_Ideograph", "Ideographic"},
    160242: {"Unified_Ideograph", "Ideographic"},
    160243: {"Unified_Ideograph", "Ideographic"},
    160244: {"Unified_Ideograph", "Ideographic"},
    160245: {"Unified_Ideograph", "Ideographic"},
    160246: {"Unified_Ideograph", "Ideographic"},
    160247: {"Unified_Ideograph", "Ideographic"},
    160248: {"Unified_Ideograph", "Ideographic"},
    160249: {"Unified_Ideograph", "Ideographic"},
    160250: {"Unified_Ideograph", "Ideographic"},
    160251: {"Unified_Ideograph", "Ideographic"},
    160252: {"Unified_Ideograph", "Ideographic"},
    160253: {"Unified_Ideograph", "Ideographic"},
    160254: {"Unified_Ideograph", "Ideographic"},
    160255: {"Unified_Ideograph", "Ideographic"},
    160256: {"Unified_Ideograph", "Ideographic"},
    160257: {"Unified_Ideograph", "Ideographic"},
    160258: {"Unified_Ideograph", "Ideographic"},
    160259: {"Unified_Ideograph", "Ideographic"},
    160260: {"Unified_Ideograph", "Ideographic"},
    160261: {"Unified_Ideograph", "Ideographic"},
    160262: {"Unified_Ideograph", "Ideographic"},
    160263: {"Unified_Ideograph", "Ideographic"},
    160264: {"Unified_Ideograph", "Ideographic"},
    160265: {"Unified_Ideograph", "Ideographic"},
    160266: {"Unified_Ideograph", "Ideographic"},
    160267: {"Unified_Ideograph", "Ideographic"},
    160268: {"Unified_Ideograph", "Ideographic"},
    160269: {"Unified_Ideograph", "Ideographic"},
    160270: {"Unified_Ideograph", "Ideographic"},
    160271: {"Unified_Ideograph", "Ideographic"},
    160272: {"Unified_Ideograph", "Ideographic"},
    160273: {"Unified_Ideograph", "Ideographic"},
    160274: {"Unified_Ideograph", "Ideographic"},
    160275: {"Unified_Ideograph", "Ideographic"},
    160276: {"Unified_Ideograph", "Ideographic"},
    160277: {"Unified_Ideograph", "Ideographic"},
    160278: {"Unified_Ideograph", "Ideographic"},
    160279: {"Unified_Ideograph", "Ideographic"},
    160280: {"Unified_Ideograph", "Ideographic"},
    160281: {"Unified_Ideograph", "Ideographic"},
    160282: {"Unified_Ideograph", "Ideographic"},
    160283: {"Unified_Ideograph", "Ideographic"},
    160284: {"Unified_Ideograph", "Ideographic"},
    160285: {"Unified_Ideograph", "Ideographic"},
    160286: {"Unified_Ideograph", "Ideographic"},
    160287: {"Unified_Ideograph", "Ideographic"},
    160288: {"Unified_Ideograph", "Ideographic"},
    160289: {"Unified_Ideograph", "Ideographic"},
    160290: {"Unified_Ideograph", "Ideographic"},
    160291: {"Unified_Ideograph", "Ideographic"},
    160292: {"Unified_Ideograph", "Ideographic"},
    160293: {"Unified_Ideograph", "Ideographic"},
    160294: {"Unified_Ideograph", "Ideographic"},
    160295: {"Unified_Ideograph", "Ideographic"},
    160296: {"Unified_Ideograph", "Ideographic"},
    160297: {"Unified_Ideograph", "Ideographic"},
    160298: {"Unified_Ideograph", "Ideographic"},
    160299: {"Unified_Ideograph", "Ideographic"},
    160300: {"Unified_Ideograph", "Ideographic"},
    160301: {"Unified_Ideograph", "Ideographic"},
    160302: {"Unified_Ideograph", "Ideographic"},
    160303: {"Unified_Ideograph", "Ideographic"},
    160304: {"Unified_Ideograph", "Ideographic"},
    160305: {"Unified_Ideograph", "Ideographic"},
    160306: {"Unified_Ideograph", "Ideographic"},
    160307: {"Unified_Ideograph", "Ideographic"},
    160308: {"Unified_Ideograph", "Ideographic"},
    160309: {"Unified_Ideograph", "Ideographic"},
    160310: {"Unified_Ideograph", "Ideographic"},
    160311: {"Unified_Ideograph", "Ideographic"},
    160312: {"Unified_Ideograph", "Ideographic"},
    160313: {"Unified_Ideograph", "Ideographic"},
    160314: {"Unified_Ideograph", "Ideographic"},
    160315: {"Unified_Ideograph", "Ideographic"},
    160316: {"Unified_Ideograph", "Ideographic"},
    160317: {"Unified_Ideograph", "Ideographic"},
    160318: {"Unified_Ideograph", "Ideographic"},
    160319: {"Unified_Ideograph", "Ideographic"},
    160320: {"Unified_Ideograph", "Ideographic"},
    160321: {"Unified_Ideograph", "Ideographic"},
    160322: {"Unified_Ideograph", "Ideographic"},
    160323: {"Unified_Ideograph", "Ideographic"},
    160324: {"Unified_Ideograph", "Ideographic"},
    160325: {"Unified_Ideograph", "Ideographic"},
    160326: {"Unified_Ideograph", "Ideographic"},
    160327: {"Unified_Ideograph", "Ideographic"},
    160328: {"Unified_Ideograph", "Ideographic"},
    160329: {"Unified_Ideograph", "Ideographic"},
    160330: {"Unified_Ideograph", "Ideographic"},
    160331: {"Unified_Ideograph", "Ideographic"},
    160332: {"Unified_Ideograph", "Ideographic"},
    160333: {"Unified_Ideograph", "Ideographic"},
    160334: {"Unified_Ideograph", "Ideographic"},
    160335: {"Unified_Ideograph", "Ideographic"},
    160336: {"Unified_Ideograph", "Ideographic"},
    160337: {"Unified_Ideograph", "Ideographic"},
    160338: {"Unified_Ideograph", "Ideographic"},
    160339: {"Unified_Ideograph", "Ideographic"},
    160340: {"Unified_Ideograph", "Ideographic"},
    160341: {"Unified_Ideograph", "Ideographic"},
    160342: {"Unified_Ideograph", "Ideographic"},
    160343: {"Unified_Ideograph", "Ideographic"},
    160344: {"Unified_Ideograph", "Ideographic"},
    160345: {"Unified_Ideograph", "Ideographic"},
    160346: {"Unified_Ideograph", "Ideographic"},
    160347: {"Unified_Ideograph", "Ideographic"},
    160348: {"Unified_Ideograph", "Ideographic"},
    160349: {"Unified_Ideograph", "Ideographic"},
    160350: {"Unified_Ideograph", "Ideographic"},
    160351: {"Unified_Ideograph", "Ideographic"},
    160352: {"Unified_Ideograph", "Ideographic"},
    160353: {"Unified_Ideograph", "Ideographic"},
    160354: {"Unified_Ideograph", "Ideographic"},
    160355: {"Unified_Ideograph", "Ideographic"},
    160356: {"Unified_Ideograph", "Ideographic"},
    160357: {"Unified_Ideograph", "Ideographic"},
    160358: {"Unified_Ideograph", "Ideographic"},
    160359: {"Unified_Ideograph", "Ideographic"},
    160360: {"Unified_Ideograph", "Ideographic"},
    160361: {"Unified_Ideograph", "Ideographic"},
    160362: {"Unified_Ideograph", "Ideographic"},
    160363: {"Unified_Ideograph", "Ideographic"},
    160364: {"Unified_Ideograph", "Ideographic"},
    160365: {"Unified_Ideograph", "Ideographic"},
    160366: {"Unified_Ideograph", "Ideographic"},
    160367: {"Unified_Ideograph", "Ideographic"},
    160368: {"Unified_Ideograph", "Ideographic"},
    160369: {"Unified_Ideograph", "Ideographic"},
    160370: {"Unified_Ideograph", "Ideographic"},
    160371: {"Unified_Ideograph", "Ideographic"},
    160372: {"Unified_Ideograph", "Ideographic"},
    160373: {"Unified_Ideograph", "Ideographic"},
    160374: {"Unified_Ideograph", "Ideographic"},
    160375: {"Unified_Ideograph", "Ideographic"},
    160376: {"Unified_Ideograph", "Ideographic"},
    160377: {"Unified_Ideograph", "Ideographic"},
    160378: {"Unified_Ideograph", "Ideographic"},
    160379: {"Unified_Ideograph", "Ideographic"},
    160380: {"Unified_Ideograph", "Ideographic"},
    160381: {"Unified_Ideograph", "Ideographic"},
    160382: {"Unified_Ideograph", "Ideographic"},
    160383: {"Unified_Ideograph", "Ideographic"},
    160384: {"Unified_Ideograph", "Ideographic"},
    160385: {"Unified_Ideograph", "Ideographic"},
    160386: {"Unified_Ideograph", "Ideographic"},
    160387: {"Unified_Ideograph", "Ideographic"},
    160388: {"Unified_Ideograph", "Ideographic"},
    160389: {"Unified_Ideograph", "Ideographic"},
    160390: {"Unified_Ideograph", "Ideographic"},
    160391: {"Unified_Ideograph", "Ideographic"},
    160392: {"Unified_Ideograph", "Ideographic"},
    160393: {"Unified_Ideograph", "Ideographic"},
    160394: {"Unified_Ideograph", "Ideographic"},
    160395: {"Unified_Ideograph", "Ideographic"},
    160396: {"Unified_Ideograph", "Ideographic"},
    160397: {"Unified_Ideograph", "Ideographic"},
    160398: {"Unified_Ideograph", "Ideographic"},
    160399: {"Unified_Ideograph", "Ideographic"},
    160400: {"Unified_Ideograph", "Ideographic"},
    160401: {"Unified_Ideograph", "Ideographic"},
    160402: {"Unified_Ideograph", "Ideographic"},
    160403: {"Unified_Ideograph", "Ideographic"},
    160404: {"Unified_Ideograph", "Ideographic"},
    160405: {"Unified_Ideograph", "Ideographic"},
    160406: {"Unified_Ideograph", "Ideographic"},
    160407: {"Unified_Ideograph", "Ideographic"},
    160408: {"Unified_Ideograph", "Ideographic"},
    160409: {"Unified_Ideograph", "Ideographic"},
    160410: {"Unified_Ideograph", "Ideographic"},
    160411: {"Unified_Ideograph", "Ideographic"},
    160412: {"Unified_Ideograph", "Ideographic"},
    160413: {"Unified_Ideograph", "Ideographic"},
    160414: {"Unified_Ideograph", "Ideographic"},
    160415: {"Unified_Ideograph", "Ideographic"},
    160416: {"Unified_Ideograph", "Ideographic"},
    160417: {"Unified_Ideograph", "Ideographic"},
    160418: {"Unified_Ideograph", "Ideographic"},
    160419: {"Unified_Ideograph", "Ideographic"},
    160420: {"Unified_Ideograph", "Ideographic"},
    160421: {"Unified_Ideograph", "Ideographic"},
    160422: {"Unified_Ideograph", "Ideographic"},
    160423: {"Unified_Ideograph", "Ideographic"},
    160424: {"Unified_Ideograph", "Ideographic"},
    160425: {"Unified_Ideograph", "Ideographic"},
    160426: {"Unified_Ideograph", "Ideographic"},
    160427: {"Unified_Ideograph", "Ideographic"},
    160428: {"Unified_Ideograph", "Ideographic"},
    160429: {"Unified_Ideograph", "Ideographic"},
    160430: {"Unified_Ideograph", "Ideographic"},
    160431: {"Unified_Ideograph", "Ideographic"},
    160432: {"Unified_Ideograph", "Ideographic"},
    160433: {"Unified_Ideograph", "Ideographic"},
    160434: {"Unified_Ideograph", "Ideographic"},
    160435: {"Unified_Ideograph", "Ideographic"},
    160436: {"Unified_Ideograph", "Ideographic"},
    160437: {"Unified_Ideograph", "Ideographic"},
    160438: {"Unified_Ideograph", "Ideographic"},
    160439: {"Unified_Ideograph", "Ideographic"},
    160440: {"Unified_Ideograph", "Ideographic"},
    160441: {"Unified_Ideograph", "Ideographic"},
    160442: {"Unified_Ideograph", "Ideographic"},
    160443: {"Unified_Ideograph", "Ideographic"},
    160444: {"Unified_Ideograph", "Ideographic"},
    160445: {"Unified_Ideograph", "Ideographic"},
    160446: {"Unified_Ideograph", "Ideographic"},
    160447: {"Unified_Ideograph", "Ideographic"},
    160448: {"Unified_Ideograph", "Ideographic"},
    160449: {"Unified_Ideograph", "Ideographic"},
    160450: {"Unified_Ideograph", "Ideographic"},
    160451: {"Unified_Ideograph", "Ideographic"},
    160452: {"Unified_Ideograph", "Ideographic"},
    160453: {"Unified_Ideograph", "Ideographic"},
    160454: {"Unified_Ideograph", "Ideographic"},
    160455: {"Unified_Ideograph", "Ideographic"},
    160456: {"Unified_Ideograph", "Ideographic"},
    160457: {"Unified_Ideograph", "Ideographic"},
    160458: {"Unified_Ideograph", "Ideographic"},
    160459: {"Unified_Ideograph", "Ideographic"},
    160460: {"Unified_Ideograph", "Ideographic"},
    160461: {"Unified_Ideograph", "Ideographic"},
    160462: {"Unified_Ideograph", "Ideographic"},
    160463: {"Unified_Ideograph", "Ideographic"},
    160464: {"Unified_Ideograph", "Ideographic"},
    160465: {"Unified_Ideograph", "Ideographic"},
    160466: {"Unified_Ideograph", "Ideographic"},
    160467: {"Unified_Ideograph", "Ideographic"},
    160468: {"Unified_Ideograph", "Ideographic"},
    160469: {"Unified_Ideograph", "Ideographic"},
    160470: {"Unified_Ideograph", "Ideographic"},
    160471: {"Unified_Ideograph", "Ideographic"},
    160472: {"Unified_Ideograph", "Ideographic"},
    160473: {"Unified_Ideograph", "Ideographic"},
    160474: {"Unified_Ideograph", "Ideographic"},
    160475: {"Unified_Ideograph", "Ideographic"},
    160476: {"Unified_Ideograph", "Ideographic"},
    160477: {"Unified_Ideograph", "Ideographic"},
    160478: {"Unified_Ideograph", "Ideographic"},
    160479: {"Unified_Ideograph", "Ideographic"},
    160480: {"Unified_Ideograph", "Ideographic"},
    160481: {"Unified_Ideograph", "Ideographic"},
    160482: {"Unified_Ideograph", "Ideographic"},
    160483: {"Unified_Ideograph", "Ideographic"},
    160484: {"Unified_Ideograph", "Ideographic"},
    160485: {"Unified_Ideograph", "Ideographic"},
    160486: {"Unified_Ideograph", "Ideographic"},
    160487: {"Unified_Ideograph", "Ideographic"},
    160488: {"Unified_Ideograph", "Ideographic"},
    160489: {"Unified_Ideograph", "Ideographic"},
    160490: {"Unified_Ideograph", "Ideographic"},
    160491: {"Unified_Ideograph", "Ideographic"},
    160492: {"Unified_Ideograph", "Ideographic"},
    160493: {"Unified_Ideograph", "Ideographic"},
    160494: {"Unified_Ideograph", "Ideographic"},
    160495: {"Unified_Ideograph", "Ideographic"},
    160496: {"Unified_Ideograph", "Ideographic"},
    160497: {"Unified_Ideograph", "Ideographic"},
    160498: {"Unified_Ideograph", "Ideographic"},
    160499: {"Unified_Ideograph", "Ideographic"},
    160500: {"Unified_Ideograph", "Ideographic"},
    160501: {"Unified_Ideograph", "Ideographic"},
    160502: {"Unified_Ideograph", "Ideographic"},
    160503: {"Unified_Ideograph", "Ideographic"},
    160504: {"Unified_Ideograph", "Ideographic"},
    160505: {"Unified_Ideograph", "Ideographic"},
    160506: {"Unified_Ideograph", "Ideographic"},
    160507: {"Unified_Ideograph", "Ideographic"},
    160508: {"Unified_Ideograph", "Ideographic"},
    160509: {"Unified_Ideograph", "Ideographic"},
    160510: {"Unified_Ideograph", "Ideographic"},
    160511: {"Unified_Ideograph", "Ideographic"},
    160512: {"Unified_Ideograph", "Ideographic"},
    160513: {"Unified_Ideograph", "Ideographic"},
    160514: {"Unified_Ideograph", "Ideographic"},
    160515: {"Unified_Ideograph", "Ideographic"},
    160516: {"Unified_Ideograph", "Ideographic"},
    160517: {"Unified_Ideograph", "Ideographic"},
    160518: {"Unified_Ideograph", "Ideographic"},
    160519: {"Unified_Ideograph", "Ideographic"},
    160520: {"Unified_Ideograph", "Ideographic"},
    160521: {"Unified_Ideograph", "Ideographic"},
    160522: {"Unified_Ideograph", "Ideographic"},
    160523: {"Unified_Ideograph", "Ideographic"},
    160524: {"Unified_Ideograph", "Ideographic"},
    160525: {"Unified_Ideograph", "Ideographic"},
    160526: {"Unified_Ideograph", "Ideographic"},
    160527: {"Unified_Ideograph", "Ideographic"},
    160528: {"Unified_Ideograph", "Ideographic"},
    160529: {"Unified_Ideograph", "Ideographic"},
    160530: {"Unified_Ideograph", "Ideographic"},
    160531: {"Unified_Ideograph", "Ideographic"},
    160532: {"Unified_Ideograph", "Ideographic"},
    160533: {"Unified_Ideograph", "Ideographic"},
    160534: {"Unified_Ideograph", "Ideographic"},
    160535: {"Unified_Ideograph", "Ideographic"},
    160536: {"Unified_Ideograph", "Ideographic"},
    160537: {"Unified_Ideograph", "Ideographic"},
    160538: {"Unified_Ideograph", "Ideographic"},
    160539: {"Unified_Ideograph", "Ideographic"},
    160540: {"Unified_Ideograph", "Ideographic"},
    160541: {"Unified_Ideograph", "Ideographic"},
    160542: {"Unified_Ideograph", "Ideographic"},
    160543: {"Unified_Ideograph", "Ideographic"},
    160544: {"Unified_Ideograph", "Ideographic"},
    160545: {"Unified_Ideograph", "Ideographic"},
    160546: {"Unified_Ideograph", "Ideographic"},
    160547: {"Unified_Ideograph", "Ideographic"},
    160548: {"Unified_Ideograph", "Ideographic"},
    160549: {"Unified_Ideograph", "Ideographic"},
    160550: {"Unified_Ideograph", "Ideographic"},
    160551: {"Unified_Ideograph", "Ideographic"},
    160552: {"Unified_Ideograph", "Ideographic"},
    160553: {"Unified_Ideograph", "Ideographic"},
    160554: {"Unified_Ideograph", "Ideographic"},
    160555: {"Unified_Ideograph", "Ideographic"},
    160556: {"Unified_Ideograph", "Ideographic"},
    160557: {"Unified_Ideograph", "Ideographic"},
    160558: {"Unified_Ideograph", "Ideographic"},
    160559: {"Unified_Ideograph", "Ideographic"},
    160560: {"Unified_Ideograph", "Ideographic"},
    160561: {"Unified_Ideograph", "Ideographic"},
    160562: {"Unified_Ideograph", "Ideographic"},
    160563: {"Unified_Ideograph", "Ideographic"},
    160564: {"Unified_Ideograph", "Ideographic"},
    160565: {"Unified_Ideograph", "Ideographic"},
    160566: {"Unified_Ideograph", "Ideographic"},
    160567: {"Unified_Ideograph", "Ideographic"},
    160568: {"Unified_Ideograph", "Ideographic"},
    160569: {"Unified_Ideograph", "Ideographic"},
    160570: {"Unified_Ideograph", "Ideographic"},
    160571: {"Unified_Ideograph", "Ideographic"},
    160572: {"Unified_Ideograph", "Ideographic"},
    160573: {"Unified_Ideograph", "Ideographic"},
    160574: {"Unified_Ideograph", "Ideographic"},
    160575: {"Unified_Ideograph", "Ideographic"},
    160576: {"Unified_Ideograph", "Ideographic"},
    160577: {"Unified_Ideograph", "Ideographic"},
    160578: {"Unified_Ideograph", "Ideographic"},
    160579: {"Unified_Ideograph", "Ideographic"},
    160580: {"Unified_Ideograph", "Ideographic"},
    160581: {"Unified_Ideograph", "Ideographic"},
    160582: {"Unified_Ideograph", "Ideographic"},
    160583: {"Unified_Ideograph", "Ideographic"},
    160584: {"Unified_Ideograph", "Ideographic"},
    160585: {"Unified_Ideograph", "Ideographic"},
    160586: {"Unified_Ideograph", "Ideographic"},
    160587: {"Unified_Ideograph", "Ideographic"},
    160588: {"Unified_Ideograph", "Ideographic"},
    160589: {"Unified_Ideograph", "Ideographic"},
    160590: {"Unified_Ideograph", "Ideographic"},
    160591: {"Unified_Ideograph", "Ideographic"},
    160592: {"Unified_Ideograph", "Ideographic"},
    160593: {"Unified_Ideograph", "Ideographic"},
    160594: {"Unified_Ideograph", "Ideographic"},
    160595: {"Unified_Ideograph", "Ideographic"},
    160596: {"Unified_Ideograph", "Ideographic"},
    160597: {"Unified_Ideograph", "Ideographic"},
    160598: {"Unified_Ideograph", "Ideographic"},
    160599: {"Unified_Ideograph", "Ideographic"},
    160600: {"Unified_Ideograph", "Ideographic"},
    160601: {"Unified_Ideograph", "Ideographic"},
    160602: {"Unified_Ideograph", "Ideographic"},
    160603: {"Unified_Ideograph", "Ideographic"},
    160604: {"Unified_Ideograph", "Ideographic"},
    160605: {"Unified_Ideograph", "Ideographic"},
    160606: {"Unified_Ideograph", "Ideographic"},
    160607: {"Unified_Ideograph", "Ideographic"},
    160608: {"Unified_Ideograph", "Ideographic"},
    160609: {"Unified_Ideograph", "Ideographic"},
    160610: {"Unified_Ideograph", "Ideographic"},
    160611: {"Unified_Ideograph", "Ideographic"},
    160612: {"Unified_Ideograph", "Ideographic"},
    160613: {"Unified_Ideograph", "Ideographic"},
    160614: {"Unified_Ideograph", "Ideographic"},
    160615: {"Unified_Ideograph", "Ideographic"},
    160616: {"Unified_Ideograph", "Ideographic"},
    160617: {"Unified_Ideograph", "Ideographic"},
    160618: {"Unified_Ideograph", "Ideographic"},
    160619: {"Unified_Ideograph", "Ideographic"},
    160620: {"Unified_Ideograph", "Ideographic"},
    160621: {"Unified_Ideograph", "Ideographic"},
    160622: {"Unified_Ideograph", "Ideographic"},
    160623: {"Unified_Ideograph", "Ideographic"},
    160624: {"Unified_Ideograph", "Ideographic"},
    160625: {"Unified_Ideograph", "Ideographic"},
    160626: {"Unified_Ideograph", "Ideographic"},
    160627: {"Unified_Ideograph", "Ideographic"},
    160628: {"Unified_Ideograph", "Ideographic"},
    160629: {"Unified_Ideograph", "Ideographic"},
    160630: {"Unified_Ideograph", "Ideographic"},
    160631: {"Unified_Ideograph", "Ideographic"},
    160632: {"Unified_Ideograph", "Ideographic"},
    160633: {"Unified_Ideograph", "Ideographic"},
    160634: {"Unified_Ideograph", "Ideographic"},
    160635: {"Unified_Ideograph", "Ideographic"},
    160636: {"Unified_Ideograph", "Ideographic"},
    160637: {"Unified_Ideograph", "Ideographic"},
    160638: {"Unified_Ideograph", "Ideographic"},
    160639: {"Unified_Ideograph", "Ideographic"},
    160640: {"Unified_Ideograph", "Ideographic"},
    160641: {"Unified_Ideograph", "Ideographic"},
    160642: {"Unified_Ideograph", "Ideographic"},
    160643: {"Unified_Ideograph", "Ideographic"},
    160644: {"Unified_Ideograph", "Ideographic"},
    160645: {"Unified_Ideograph", "Ideographic"},
    160646: {"Unified_Ideograph", "Ideographic"},
    160647: {"Unified_Ideograph", "Ideographic"},
    160648: {"Unified_Ideograph", "Ideographic"},
    160649: {"Unified_Ideograph", "Ideographic"},
    160650: {"Unified_Ideograph", "Ideographic"},
    160651: {"Unified_Ideograph", "Ideographic"},
    160652: {"Unified_Ideograph", "Ideographic"},
    160653: {"Unified_Ideograph", "Ideographic"},
    160654: {"Unified_Ideograph", "Ideographic"},
    160655: {"Unified_Ideograph", "Ideographic"},
    160656: {"Unified_Ideograph", "Ideographic"},
    160657: {"Unified_Ideograph", "Ideographic"},
    160658: {"Unified_Ideograph", "Ideographic"},
    160659: {"Unified_Ideograph", "Ideographic"},
    160660: {"Unified_Ideograph", "Ideographic"},
    160661: {"Unified_Ideograph", "Ideographic"},
    160662: {"Unified_Ideograph", "Ideographic"},
    160663: {"Unified_Ideograph", "Ideographic"},
    160664: {"Unified_Ideograph", "Ideographic"},
    160665: {"Unified_Ideograph", "Ideographic"},
    160666: {"Unified_Ideograph", "Ideographic"},
    160667: {"Unified_Ideograph", "Ideographic"},
    160668: {"Unified_Ideograph", "Ideographic"},
    160669: {"Unified_Ideograph", "Ideographic"},
    160670: {"Unified_Ideograph", "Ideographic"},
    160671: {"Unified_Ideograph", "Ideographic"},
    160672: {"Unified_Ideograph", "Ideographic"},
    160673: {"Unified_Ideograph", "Ideographic"},
    160674: {"Unified_Ideograph", "Ideographic"},
    160675: {"Unified_Ideograph", "Ideographic"},
    160676: {"Unified_Ideograph", "Ideographic"},
    160677: {"Unified_Ideograph", "Ideographic"},
    160678: {"Unified_Ideograph", "Ideographic"},
    160679: {"Unified_Ideograph", "Ideographic"},
    160680: {"Unified_Ideograph", "Ideographic"},
    160681: {"Unified_Ideograph", "Ideographic"},
    160682: {"Unified_Ideograph", "Ideographic"},
    160683: {"Unified_Ideograph", "Ideographic"},
    160684: {"Unified_Ideograph", "Ideographic"},
    160685: {"Unified_Ideograph", "Ideographic"},
    160686: {"Unified_Ideograph", "Ideographic"},
    160687: {"Unified_Ideograph", "Ideographic"},
    160688: {"Unified_Ideograph", "Ideographic"},
    160689: {"Unified_Ideograph", "Ideographic"},
    160690: {"Unified_Ideograph", "Ideographic"},
    160691: {"Unified_Ideograph", "Ideographic"},
    160692: {"Unified_Ideograph", "Ideographic"},
    160693: {"Unified_Ideograph", "Ideographic"},
    160694: {"Unified_Ideograph", "Ideographic"},
    160695: {"Unified_Ideograph", "Ideographic"},
    160696: {"Unified_Ideograph", "Ideographic"},
    160697: {"Unified_Ideograph", "Ideographic"},
    160698: {"Unified_Ideograph", "Ideographic"},
    160699: {"Unified_Ideograph", "Ideographic"},
    160700: {"Unified_Ideograph", "Ideographic"},
    160701: {"Unified_Ideograph", "Ideographic"},
    160702: {"Unified_Ideograph", "Ideographic"},
    160703: {"Unified_Ideograph", "Ideographic"},
    160704: {"Unified_Ideograph", "Ideographic"},
    160705: {"Unified_Ideograph", "Ideographic"},
    160706: {"Unified_Ideograph", "Ideographic"},
    160707: {"Unified_Ideograph", "Ideographic"},
    160708: {"Unified_Ideograph", "Ideographic"},
    160709: {"Unified_Ideograph", "Ideographic"},
    160710: {"Unified_Ideograph", "Ideographic"},
    160711: {"Unified_Ideograph", "Ideographic"},
    160712: {"Unified_Ideograph", "Ideographic"},
    160713: {"Unified_Ideograph", "Ideographic"},
    160714: {"Unified_Ideograph", "Ideographic"},
    160715: {"Unified_Ideograph", "Ideographic"},
    160716: {"Unified_Ideograph", "Ideographic"},
    160717: {"Unified_Ideograph", "Ideographic"},
    160718: {"Unified_Ideograph", "Ideographic"},
    160719: {"Unified_Ideograph", "Ideographic"},
    160720: {"Unified_Ideograph", "Ideographic"},
    160721: {"Unified_Ideograph", "Ideographic"},
    160722: {"Unified_Ideograph", "Ideographic"},
    160723: {"Unified_Ideograph", "Ideographic"},
    160724: {"Unified_Ideograph", "Ideographic"},
    160725: {"Unified_Ideograph", "Ideographic"},
    160726: {"Unified_Ideograph", "Ideographic"},
    160727: {"Unified_Ideograph", "Ideographic"},
    160728: {"Unified_Ideograph", "Ideographic"},
    160729: {"Unified_Ideograph", "Ideographic"},
    160730: {"Unified_Ideograph", "Ideographic"},
    160731: {"Unified_Ideograph", "Ideographic"},
    160732: {"Unified_Ideograph", "Ideographic"},
    160733: {"Unified_Ideograph", "Ideographic"},
    160734: {"Unified_Ideograph", "Ideographic"},
    160735: {"Unified_Ideograph", "Ideographic"},
    160736: {"Unified_Ideograph", "Ideographic"},
    160737: {"Unified_Ideograph", "Ideographic"},
    160738: {"Unified_Ideograph", "Ideographic"},
    160739: {"Unified_Ideograph", "Ideographic"},
    160740: {"Unified_Ideograph", "Ideographic"},
    160741: {"Unified_Ideograph", "Ideographic"},
    160742: {"Unified_Ideograph", "Ideographic"},
    160743: {"Unified_Ideograph", "Ideographic"},
    160744: {"Unified_Ideograph", "Ideographic"},
    160745: {"Unified_Ideograph", "Ideographic"},
    160746: {"Unified_Ideograph", "Ideographic"},
    160747: {"Unified_Ideograph", "Ideographic"},
    160748: {"Unified_Ideograph", "Ideographic"},
    160749: {"Unified_Ideograph", "Ideographic"},
    160750: {"Unified_Ideograph", "Ideographic"},
    160751: {"Unified_Ideograph", "Ideographic"},
    160752: {"Unified_Ideograph", "Ideographic"},
    160753: {"Unified_Ideograph", "Ideographic"},
    160754: {"Unified_Ideograph", "Ideographic"},
    160755: {"Unified_Ideograph", "Ideographic"},
    160756: {"Unified_Ideograph", "Ideographic"},
    160757: {"Unified_Ideograph", "Ideographic"},
    160758: {"Unified_Ideograph", "Ideographic"},
    160759: {"Unified_Ideograph", "Ideographic"},
    160760: {"Unified_Ideograph", "Ideographic"},
    160761: {"Unified_Ideograph", "Ideographic"},
    160762: {"Unified_Ideograph", "Ideographic"},
    160763: {"Unified_Ideograph", "Ideographic"},
    160764: {"Unified_Ideograph", "Ideographic"},
    160765: {"Unified_Ideograph", "Ideographic"},
    160766: {"Unified_Ideograph", "Ideographic"},
    160767: {"Unified_Ideograph", "Ideographic"},
    160768: {"Unified_Ideograph", "Ideographic"},
    160769: {"Unified_Ideograph", "Ideographic"},
    160770: {"Unified_Ideograph", "Ideographic"},
    160771: {"Unified_Ideograph", "Ideographic"},
    160772: {"Unified_Ideograph", "Ideographic"},
    160773: {"Unified_Ideograph", "Ideographic"},
    160774: {"Unified_Ideograph", "Ideographic"},
    160775: {"Unified_Ideograph", "Ideographic"},
    160776: {"Unified_Ideograph", "Ideographic"},
    160777: {"Unified_Ideograph", "Ideographic"},
    160778: {"Unified_Ideograph", "Ideographic"},
    160779: {"Unified_Ideograph", "Ideographic"},
    160780: {"Unified_Ideograph", "Ideographic"},
    160781: {"Unified_Ideograph", "Ideographic"},
    160782: {"Unified_Ideograph", "Ideographic"},
    160783: {"Unified_Ideograph", "Ideographic"},
    160784: {"Unified_Ideograph", "Ideographic"},
    160785: {"Unified_Ideograph", "Ideographic"},
    160786: {"Unified_Ideograph", "Ideographic"},
    160787: {"Unified_Ideograph", "Ideographic"},
    160788: {"Unified_Ideograph", "Ideographic"},
    160789: {"Unified_Ideograph", "Ideographic"},
    160790: {"Unified_Ideograph", "Ideographic"},
    160791: {"Unified_Ideograph", "Ideographic"},
    160792: {"Unified_Ideograph", "Ideographic"},
    160793: {"Unified_Ideograph", "Ideographic"},
    160794: {"Unified_Ideograph", "Ideographic"},
    160795: {"Unified_Ideograph", "Ideographic"},
    160796: {"Unified_Ideograph", "Ideographic"},
    160797: {"Unified_Ideograph", "Ideographic"},
    160798: {"Unified_Ideograph", "Ideographic"},
    160799: {"Unified_Ideograph", "Ideographic"},
    160800: {"Unified_Ideograph", "Ideographic"},
    160801: {"Unified_Ideograph", "Ideographic"},
    160802: {"Unified_Ideograph", "Ideographic"},
    160803: {"Unified_Ideograph", "Ideographic"},
    160804: {"Unified_Ideograph", "Ideographic"},
    160805: {"Unified_Ideograph", "Ideographic"},
    160806: {"Unified_Ideograph", "Ideographic"},
    160807: {"Unified_Ideograph", "Ideographic"},
    160808: {"Unified_Ideograph", "Ideographic"},
    160809: {"Unified_Ideograph", "Ideographic"},
    160810: {"Unified_Ideograph", "Ideographic"},
    160811: {"Unified_Ideograph", "Ideographic"},
    160812: {"Unified_Ideograph", "Ideographic"},
    160813: {"Unified_Ideograph", "Ideographic"},
    160814: {"Unified_Ideograph", "Ideographic"},
    160815: {"Unified_Ideograph", "Ideographic"},
    160816: {"Unified_Ideograph", "Ideographic"},
    160817: {"Unified_Ideograph", "Ideographic"},
    160818: {"Unified_Ideograph", "Ideographic"},
    160819: {"Unified_Ideograph", "Ideographic"},
    160820: {"Unified_Ideograph", "Ideographic"},
    160821: {"Unified_Ideograph", "Ideographic"},
    160822: {"Unified_Ideograph", "Ideographic"},
    160823: {"Unified_Ideograph", "Ideographic"},
    160824: {"Unified_Ideograph", "Ideographic"},
    160825: {"Unified_Ideograph", "Ideographic"},
    160826: {"Unified_Ideograph", "Ideographic"},
    160827: {"Unified_Ideograph", "Ideographic"},
    160828: {"Unified_Ideograph", "Ideographic"},
    160829: {"Unified_Ideograph", "Ideographic"},
    160830: {"Unified_Ideograph", "Ideographic"},
    160831: {"Unified_Ideograph", "Ideographic"},
    160832: {"Unified_Ideograph", "Ideographic"},
    160833: {"Unified_Ideograph", "Ideographic"},
    160834: {"Unified_Ideograph", "Ideographic"},
    160835: {"Unified_Ideograph", "Ideographic"},
    160836: {"Unified_Ideograph", "Ideographic"},
    160837: {"Unified_Ideograph", "Ideographic"},
    160838: {"Unified_Ideograph", "Ideographic"},
    160839: {"Unified_Ideograph", "Ideographic"},
    160840: {"Unified_Ideograph", "Ideographic"},
    160841: {"Unified_Ideograph", "Ideographic"},
    160842: {"Unified_Ideograph", "Ideographic"},
    160843: {"Unified_Ideograph", "Ideographic"},
    160844: {"Unified_Ideograph", "Ideographic"},
    160845: {"Unified_Ideograph", "Ideographic"},
    160846: {"Unified_Ideograph", "Ideographic"},
    160847: {"Unified_Ideograph", "Ideographic"},
    160848: {"Unified_Ideograph", "Ideographic"},
    160849: {"Unified_Ideograph", "Ideographic"},
    160850: {"Unified_Ideograph", "Ideographic"},
    160851: {"Unified_Ideograph", "Ideographic"},
    160852: {"Unified_Ideograph", "Ideographic"},
    160853: {"Unified_Ideograph", "Ideographic"},
    160854: {"Unified_Ideograph", "Ideographic"},
    160855: {"Unified_Ideograph", "Ideographic"},
    160856: {"Unified_Ideograph", "Ideographic"},
    160857: {"Unified_Ideograph", "Ideographic"},
    160858: {"Unified_Ideograph", "Ideographic"},
    160859: {"Unified_Ideograph", "Ideographic"},
    160860: {"Unified_Ideograph", "Ideographic"},
    160861: {"Unified_Ideograph", "Ideographic"},
    160862: {"Unified_Ideograph", "Ideographic"},
    160863: {"Unified_Ideograph", "Ideographic"},
    160864: {"Unified_Ideograph", "Ideographic"},
    160865: {"Unified_Ideograph", "Ideographic"},
    160866: {"Unified_Ideograph", "Ideographic"},
    160867: {"Unified_Ideograph", "Ideographic"},
    160868: {"Unified_Ideograph", "Ideographic"},
    160869: {"Unified_Ideograph", "Ideographic"},
    160870: {"Unified_Ideograph", "Ideographic"},
    160871: {"Unified_Ideograph", "Ideographic"},
    160872: {"Unified_Ideograph", "Ideographic"},
    160873: {"Unified_Ideograph", "Ideographic"},
    160874: {"Unified_Ideograph", "Ideographic"},
    160875: {"Unified_Ideograph", "Ideographic"},
    160876: {"Unified_Ideograph", "Ideographic"},
    160877: {"Unified_Ideograph", "Ideographic"},
    160878: {"Unified_Ideograph", "Ideographic"},
    160879: {"Unified_Ideograph", "Ideographic"},
    160880: {"Unified_Ideograph", "Ideographic"},
    160881: {"Unified_Ideograph", "Ideographic"},
    160882: {"Unified_Ideograph", "Ideographic"},
    160883: {"Unified_Ideograph", "Ideographic"},
    160884: {"Unified_Ideograph", "Ideographic"},
    160885: {"Unified_Ideograph", "Ideographic"},
    160886: {"Unified_Ideograph", "Ideographic"},
    160887: {"Unified_Ideograph", "Ideographic"},
    160888: {"Unified_Ideograph", "Ideographic"},
    160889: {"Unified_Ideograph", "Ideographic"},
    160890: {"Unified_Ideograph", "Ideographic"},
    160891: {"Unified_Ideograph", "Ideographic"},
    160892: {"Unified_Ideograph", "Ideographic"},
    160893: {"Unified_Ideograph", "Ideographic"},
    160894: {"Unified_Ideograph", "Ideographic"},
    160895: {"Unified_Ideograph", "Ideographic"},
    160896: {"Unified_Ideograph", "Ideographic"},
    160897: {"Unified_Ideograph", "Ideographic"},
    160898: {"Unified_Ideograph", "Ideographic"},
    160899: {"Unified_Ideograph", "Ideographic"},
    160900: {"Unified_Ideograph", "Ideographic"},
    160901: {"Unified_Ideograph", "Ideographic"},
    160902: {"Unified_Ideograph", "Ideographic"},
    160903: {"Unified_Ideograph", "Ideographic"},
    160904: {"Unified_Ideograph", "Ideographic"},
    160905: {"Unified_Ideograph", "Ideographic"},
    160906: {"Unified_Ideograph", "Ideographic"},
    160907: {"Unified_Ideograph", "Ideographic"},
    160908: {"Unified_Ideograph", "Ideographic"},
    160909: {"Unified_Ideograph", "Ideographic"},
    160910: {"Unified_Ideograph", "Ideographic"},
    160911: {"Unified_Ideograph", "Ideographic"},
    160912: {"Unified_Ideograph", "Ideographic"},
    160913: {"Unified_Ideograph", "Ideographic"},
    160914: {"Unified_Ideograph", "Ideographic"},
    160915: {"Unified_Ideograph", "Ideographic"},
    160916: {"Unified_Ideograph", "Ideographic"},
    160917: {"Unified_Ideograph", "Ideographic"},
    160918: {"Unified_Ideograph", "Ideographic"},
    160919: {"Unified_Ideograph", "Ideographic"},
    160920: {"Unified_Ideograph", "Ideographic"},
    160921: {"Unified_Ideograph", "Ideographic"},
    160922: {"Unified_Ideograph", "Ideographic"},
    160923: {"Unified_Ideograph", "Ideographic"},
    160924: {"Unified_Ideograph", "Ideographic"},
    160925: {"Unified_Ideograph", "Ideographic"},
    160926: {"Unified_Ideograph", "Ideographic"},
    160927: {"Unified_Ideograph", "Ideographic"},
    160928: {"Unified_Ideograph", "Ideographic"},
    160929: {"Unified_Ideograph", "Ideographic"},
    160930: {"Unified_Ideograph", "Ideographic"},
    160931: {"Unified_Ideograph", "Ideographic"},
    160932: {"Unified_Ideograph", "Ideographic"},
    160933: {"Unified_Ideograph", "Ideographic"},
    160934: {"Unified_Ideograph", "Ideographic"},
    160935: {"Unified_Ideograph", "Ideographic"},
    160936: {"Unified_Ideograph", "Ideographic"},
    160937: {"Unified_Ideograph", "Ideographic"},
    160938: {"Unified_Ideograph", "Ideographic"},
    160939: {"Unified_Ideograph", "Ideographic"},
    160940: {"Unified_Ideograph", "Ideographic"},
    160941: {"Unified_Ideograph", "Ideographic"},
    160942: {"Unified_Ideograph", "Ideographic"},
    160943: {"Unified_Ideograph", "Ideographic"},
    160944: {"Unified_Ideograph", "Ideographic"},
    160945: {"Unified_Ideograph", "Ideographic"},
    160946: {"Unified_Ideograph", "Ideographic"},
    160947: {"Unified_Ideograph", "Ideographic"},
    160948: {"Unified_Ideograph", "Ideographic"},
    160949: {"Unified_Ideograph", "Ideographic"},
    160950: {"Unified_Ideograph", "Ideographic"},
    160951: {"Unified_Ideograph", "Ideographic"},
    160952: {"Unified_Ideograph", "Ideographic"},
    160953: {"Unified_Ideograph", "Ideographic"},
    160954: {"Unified_Ideograph", "Ideographic"},
    160955: {"Unified_Ideograph", "Ideographic"},
    160956: {"Unified_Ideograph", "Ideographic"},
    160957: {"Unified_Ideograph", "Ideographic"},
    160958: {"Unified_Ideograph", "Ideographic"},
    160959: {"Unified_Ideograph", "Ideographic"},
    160960: {"Unified_Ideograph", "Ideographic"},
    160961: {"Unified_Ideograph", "Ideographic"},
    160962: {"Unified_Ideograph", "Ideographic"},
    160963: {"Unified_Ideograph", "Ideographic"},
    160964: {"Unified_Ideograph", "Ideographic"},
    160965: {"Unified_Ideograph", "Ideographic"},
    160966: {"Unified_Ideograph", "Ideographic"},
    160967: {"Unified_Ideograph", "Ideographic"},
    160968: {"Unified_Ideograph", "Ideographic"},
    160969: {"Unified_Ideograph", "Ideographic"},
    160970: {"Unified_Ideograph", "Ideographic"},
    160971: {"Unified_Ideograph", "Ideographic"},
    160972: {"Unified_Ideograph", "Ideographic"},
    160973: {"Unified_Ideograph", "Ideographic"},
    160974: {"Unified_Ideograph", "Ideographic"},
    160975: {"Unified_Ideograph", "Ideographic"},
    160976: {"Unified_Ideograph", "Ideographic"},
    160977: {"Unified_Ideograph", "Ideographic"},
    160978: {"Unified_Ideograph", "Ideographic"},
    160979: {"Unified_Ideograph", "Ideographic"},
    160980: {"Unified_Ideograph", "Ideographic"},
    160981: {"Unified_Ideograph", "Ideographic"},
    160982: {"Unified_Ideograph", "Ideographic"},
    160983: {"Unified_Ideograph", "Ideographic"},
    160984: {"Unified_Ideograph", "Ideographic"},
    160985: {"Unified_Ideograph", "Ideographic"},
    160986: {"Unified_Ideograph", "Ideographic"},
    160987: {"Unified_Ideograph", "Ideographic"},
    160988: {"Unified_Ideograph", "Ideographic"},
    160989: {"Unified_Ideograph", "Ideographic"},
    160990: {"Unified_Ideograph", "Ideographic"},
    160991: {"Unified_Ideograph", "Ideographic"},
    160992: {"Unified_Ideograph", "Ideographic"},
    160993: {"Unified_Ideograph", "Ideographic"},
    160994: {"Unified_Ideograph", "Ideographic"},
    160995: {"Unified_Ideograph", "Ideographic"},
    160996: {"Unified_Ideograph", "Ideographic"},
    160997: {"Unified_Ideograph", "Ideographic"},
    160998: {"Unified_Ideograph", "Ideographic"},
    160999: {"Unified_Ideograph", "Ideographic"},
    161000: {"Unified_Ideograph", "Ideographic"},
    161001: {"Unified_Ideograph", "Ideographic"},
    161002: {"Unified_Ideograph", "Ideographic"},
    161003: {"Unified_Ideograph", "Ideographic"},
    161004: {"Unified_Ideograph", "Ideographic"},
    161005: {"Unified_Ideograph", "Ideographic"},
    161006: {"Unified_Ideograph", "Ideographic"},
    161007: {"Unified_Ideograph", "Ideographic"},
    161008: {"Unified_Ideograph", "Ideographic"},
    161009: {"Unified_Ideograph", "Ideographic"},
    161010: {"Unified_Ideograph", "Ideographic"},
    161011: {"Unified_Ideograph", "Ideographic"},
    161012: {"Unified_Ideograph", "Ideographic"},
    161013: {"Unified_Ideograph", "Ideographic"},
    161014: {"Unified_Ideograph", "Ideographic"},
    161015: {"Unified_Ideograph", "Ideographic"},
    161016: {"Unified_Ideograph", "Ideographic"},
    161017: {"Unified_Ideograph", "Ideographic"},
    161018: {"Unified_Ideograph", "Ideographic"},
    161019: {"Unified_Ideograph", "Ideographic"},
    161020: {"Unified_Ideograph", "Ideographic"},
    161021: {"Unified_Ideograph", "Ideographic"},
    161022: {"Unified_Ideograph", "Ideographic"},
    161023: {"Unified_Ideograph", "Ideographic"},
    161024: {"Unified_Ideograph", "Ideographic"},
    161025: {"Unified_Ideograph", "Ideographic"},
    161026: {"Unified_Ideograph", "Ideographic"},
    161027: {"Unified_Ideograph", "Ideographic"},
    161028: {"Unified_Ideograph", "Ideographic"},
    161029: {"Unified_Ideograph", "Ideographic"},
    161030: {"Unified_Ideograph", "Ideographic"},
    161031: {"Unified_Ideograph", "Ideographic"},
    161032: {"Unified_Ideograph", "Ideographic"},
    161033: {"Unified_Ideograph", "Ideographic"},
    161034: {"Unified_Ideograph", "Ideographic"},
    161035: {"Unified_Ideograph", "Ideographic"},
    161036: {"Unified_Ideograph", "Ideographic"},
    161037: {"Unified_Ideograph", "Ideographic"},
    161038: {"Unified_Ideograph", "Ideographic"},
    161039: {"Unified_Ideograph", "Ideographic"},
    161040: {"Unified_Ideograph", "Ideographic"},
    161041: {"Unified_Ideograph", "Ideographic"},
    161042: {"Unified_Ideograph", "Ideographic"},
    161043: {"Unified_Ideograph", "Ideographic"},
    161044: {"Unified_Ideograph", "Ideographic"},
    161045: {"Unified_Ideograph", "Ideographic"},
    161046: {"Unified_Ideograph", "Ideographic"},
    161047: {"Unified_Ideograph", "Ideographic"},
    161048: {"Unified_Ideograph", "Ideographic"},
    161049: {"Unified_Ideograph", "Ideographic"},
    161050: {"Unified_Ideograph", "Ideographic"},
    161051: {"Unified_Ideograph", "Ideographic"},
    161052: {"Unified_Ideograph", "Ideographic"},
    161053: {"Unified_Ideograph", "Ideographic"},
    161054: {"Unified_Ideograph", "Ideographic"},
    161055: {"Unified_Ideograph", "Ideographic"},
    161056: {"Unified_Ideograph", "Ideographic"},
    161057: {"Unified_Ideograph", "Ideographic"},
    161058: {"Unified_Ideograph", "Ideographic"},
    161059: {"Unified_Ideograph", "Ideographic"},
    161060: {"Unified_Ideograph", "Ideographic"},
    161061: {"Unified_Ideograph", "Ideographic"},
    161062: {"Unified_Ideograph", "Ideographic"},
    161063: {"Unified_Ideograph", "Ideographic"},
    161064: {"Unified_Ideograph", "Ideographic"},
    161065: {"Unified_Ideograph", "Ideographic"},
    161066: {"Unified_Ideograph", "Ideographic"},
    161067: {"Unified_Ideograph", "Ideographic"},
    161068: {"Unified_Ideograph", "Ideographic"},
    161069: {"Unified_Ideograph", "Ideographic"},
    161070: {"Unified_Ideograph", "Ideographic"},
    161071: {"Unified_Ideograph", "Ideographic"},
    161072: {"Unified_Ideograph", "Ideographic"},
    161073: {"Unified_Ideograph", "Ideographic"},
    161074: {"Unified_Ideograph", "Ideographic"},
    161075: {"Unified_Ideograph", "Ideographic"},
    161076: {"Unified_Ideograph", "Ideographic"},
    161077: {"Unified_Ideograph", "Ideographic"},
    161078: {"Unified_Ideograph", "Ideographic"},
    161079: {"Unified_Ideograph", "Ideographic"},
    161080: {"Unified_Ideograph", "Ideographic"},
    161081: {"Unified_Ideograph", "Ideographic"},
    161082: {"Unified_Ideograph", "Ideographic"},
    161083: {"Unified_Ideograph", "Ideographic"},
    161084: {"Unified_Ideograph", "Ideographic"},
    161085: {"Unified_Ideograph", "Ideographic"},
    161086: {"Unified_Ideograph", "Ideographic"},
    161087: {"Unified_Ideograph", "Ideographic"},
    161088: {"Unified_Ideograph", "Ideographic"},
    161089: {"Unified_Ideograph", "Ideographic"},
    161090: {"Unified_Ideograph", "Ideographic"},
    161091: {"Unified_Ideograph", "Ideographic"},
    161092: {"Unified_Ideograph", "Ideographic"},
    161093: {"Unified_Ideograph", "Ideographic"},
    161094: {"Unified_Ideograph", "Ideographic"},
    161095: {"Unified_Ideograph", "Ideographic"},
    161096: {"Unified_Ideograph", "Ideographic"},
    161097: {"Unified_Ideograph", "Ideographic"},
    161098: {"Unified_Ideograph", "Ideographic"},
    161099: {"Unified_Ideograph", "Ideographic"},
    161100: {"Unified_Ideograph", "Ideographic"},
    161101: {"Unified_Ideograph", "Ideographic"},
    161102: {"Unified_Ideograph", "Ideographic"},
    161103: {"Unified_Ideograph", "Ideographic"},
    161104: {"Unified_Ideograph", "Ideographic"},
    161105: {"Unified_Ideograph", "Ideographic"},
    161106: {"Unified_Ideograph", "Ideographic"},
    161107: {"Unified_Ideograph", "Ideographic"},
    161108: {"Unified_Ideograph", "Ideographic"},
    161109: {"Unified_Ideograph", "Ideographic"},
    161110: {"Unified_Ideograph", "Ideographic"},
    161111: {"Unified_Ideograph", "Ideographic"},
    161112: {"Unified_Ideograph", "Ideographic"},
    161113: {"Unified_Ideograph", "Ideographic"},
    161114: {"Unified_Ideograph", "Ideographic"},
    161115: {"Unified_Ideograph", "Ideographic"},
    161116: {"Unified_Ideograph", "Ideographic"},
    161117: {"Unified_Ideograph", "Ideographic"},
    161118: {"Unified_Ideograph", "Ideographic"},
    161119: {"Unified_Ideograph", "Ideographic"},
    161120: {"Unified_Ideograph", "Ideographic"},
    161121: {"Unified_Ideograph", "Ideographic"},
    161122: {"Unified_Ideograph", "Ideographic"},
    161123: {"Unified_Ideograph", "Ideographic"},
    161124: {"Unified_Ideograph", "Ideographic"},
    161125: {"Unified_Ideograph", "Ideographic"},
    161126: {"Unified_Ideograph", "Ideographic"},
    161127: {"Unified_Ideograph", "Ideographic"},
    161128: {"Unified_Ideograph", "Ideographic"},
    161129: {"Unified_Ideograph", "Ideographic"},
    161130: {"Unified_Ideograph", "Ideographic"},
    161131: {"Unified_Ideograph", "Ideographic"},
    161132: {"Unified_Ideograph", "Ideographic"},
    161133: {"Unified_Ideograph", "Ideographic"},
    161134: {"Unified_Ideograph", "Ideographic"},
    161135: {"Unified_Ideograph", "Ideographic"},
    161136: {"Unified_Ideograph", "Ideographic"},
    161137: {"Unified_Ideograph", "Ideographic"},
    161138: {"Unified_Ideograph", "Ideographic"},
    161139: {"Unified_Ideograph", "Ideographic"},
    161140: {"Unified_Ideograph", "Ideographic"},
    161141: {"Unified_Ideograph", "Ideographic"},
    161142: {"Unified_Ideograph", "Ideographic"},
    161143: {"Unified_Ideograph", "Ideographic"},
    161144: {"Unified_Ideograph", "Ideographic"},
    161145: {"Unified_Ideograph", "Ideographic"},
    161146: {"Unified_Ideograph", "Ideographic"},
    161147: {"Unified_Ideograph", "Ideographic"},
    161148: {"Unified_Ideograph", "Ideographic"},
    161149: {"Unified_Ideograph", "Ideographic"},
    161150: {"Unified_Ideograph", "Ideographic"},
    161151: {"Unified_Ideograph", "Ideographic"},
    161152: {"Unified_Ideograph", "Ideographic"},
    161153: {"Unified_Ideograph", "Ideographic"},
    161154: {"Unified_Ideograph", "Ideographic"},
    161155: {"Unified_Ideograph", "Ideographic"},
    161156: {"Unified_Ideograph", "Ideographic"},
    161157: {"Unified_Ideograph", "Ideographic"},
    161158: {"Unified_Ideograph", "Ideographic"},
    161159: {"Unified_Ideograph", "Ideographic"},
    161160: {"Unified_Ideograph", "Ideographic"},
    161161: {"Unified_Ideograph", "Ideographic"},
    161162: {"Unified_Ideograph", "Ideographic"},
    161163: {"Unified_Ideograph", "Ideographic"},
    161164: {"Unified_Ideograph", "Ideographic"},
    161165: {"Unified_Ideograph", "Ideographic"},
    161166: {"Unified_Ideograph", "Ideographic"},
    161167: {"Unified_Ideograph", "Ideographic"},
    161168: {"Unified_Ideograph", "Ideographic"},
    161169: {"Unified_Ideograph", "Ideographic"},
    161170: {"Unified_Ideograph", "Ideographic"},
    161171: {"Unified_Ideograph", "Ideographic"},
    161172: {"Unified_Ideograph", "Ideographic"},
    161173: {"Unified_Ideograph", "Ideographic"},
    161174: {"Unified_Ideograph", "Ideographic"},
    161175: {"Unified_Ideograph", "Ideographic"},
    161176: {"Unified_Ideograph", "Ideographic"},
    161177: {"Unified_Ideograph", "Ideographic"},
    161178: {"Unified_Ideograph", "Ideographic"},
    161179: {"Unified_Ideograph", "Ideographic"},
    161180: {"Unified_Ideograph", "Ideographic"},
    161181: {"Unified_Ideograph", "Ideographic"},
    161182: {"Unified_Ideograph", "Ideographic"},
    161183: {"Unified_Ideograph", "Ideographic"},
    161184: {"Unified_Ideograph", "Ideographic"},
    161185: {"Unified_Ideograph", "Ideographic"},
    161186: {"Unified_Ideograph", "Ideographic"},
    161187: {"Unified_Ideograph", "Ideographic"},
    161188: {"Unified_Ideograph", "Ideographic"},
    161189: {"Unified_Ideograph", "Ideographic"},
    161190: {"Unified_Ideograph", "Ideographic"},
    161191: {"Unified_Ideograph", "Ideographic"},
    161192: {"Unified_Ideograph", "Ideographic"},
    161193: {"Unified_Ideograph", "Ideographic"},
    161194: {"Unified_Ideograph", "Ideographic"},
    161195: {"Unified_Ideograph", "Ideographic"},
    161196: {"Unified_Ideograph", "Ideographic"},
    161197: {"Unified_Ideograph", "Ideographic"},
    161198: {"Unified_Ideograph", "Ideographic"},
    161199: {"Unified_Ideograph", "Ideographic"},
    161200: {"Unified_Ideograph", "Ideographic"},
    161201: {"Unified_Ideograph", "Ideographic"},
    161202: {"Unified_Ideograph", "Ideographic"},
    161203: {"Unified_Ideograph", "Ideographic"},
    161204: {"Unified_Ideograph", "Ideographic"},
    161205: {"Unified_Ideograph", "Ideographic"},
    161206: {"Unified_Ideograph", "Ideographic"},
    161207: {"Unified_Ideograph", "Ideographic"},
    161208: {"Unified_Ideograph", "Ideographic"},
    161209: {"Unified_Ideograph", "Ideographic"},
    161210: {"Unified_Ideograph", "Ideographic"},
    161211: {"Unified_Ideograph", "Ideographic"},
    161212: {"Unified_Ideograph", "Ideographic"},
    161213: {"Unified_Ideograph", "Ideographic"},
    161214: {"Unified_Ideograph", "Ideographic"},
    161215: {"Unified_Ideograph", "Ideographic"},
    161216: {"Unified_Ideograph", "Ideographic"},
    161217: {"Unified_Ideograph", "Ideographic"},
    161218: {"Unified_Ideograph", "Ideographic"},
    161219: {"Unified_Ideograph", "Ideographic"},
    161220: {"Unified_Ideograph", "Ideographic"},
    161221: {"Unified_Ideograph", "Ideographic"},
    161222: {"Unified_Ideograph", "Ideographic"},
    161223: {"Unified_Ideograph", "Ideographic"},
    161224: {"Unified_Ideograph", "Ideographic"},
    161225: {"Unified_Ideograph", "Ideographic"},
    161226: {"Unified_Ideograph", "Ideographic"},
    161227: {"Unified_Ideograph", "Ideographic"},
    161228: {"Unified_Ideograph", "Ideographic"},
    161229: {"Unified_Ideograph", "Ideographic"},
    161230: {"Unified_Ideograph", "Ideographic"},
    161231: {"Unified_Ideograph", "Ideographic"},
    161232: {"Unified_Ideograph", "Ideographic"},
    161233: {"Unified_Ideograph", "Ideographic"},
    161234: {"Unified_Ideograph", "Ideographic"},
    161235: {"Unified_Ideograph", "Ideographic"},
    161236: {"Unified_Ideograph", "Ideographic"},
    161237: {"Unified_Ideograph", "Ideographic"},
    161238: {"Unified_Ideograph", "Ideographic"},
    161239: {"Unified_Ideograph", "Ideographic"},
    161240: {"Unified_Ideograph", "Ideographic"},
    161241: {"Unified_Ideograph", "Ideographic"},
    161242: {"Unified_Ideograph", "Ideographic"},
    161243: {"Unified_Ideograph", "Ideographic"},
    161244: {"Unified_Ideograph", "Ideographic"},
    161245: {"Unified_Ideograph", "Ideographic"},
    161246: {"Unified_Ideograph", "Ideographic"},
    161247: {"Unified_Ideograph", "Ideographic"},
    161248: {"Unified_Ideograph", "Ideographic"},
    161249: {"Unified_Ideograph", "Ideographic"},
    161250: {"Unified_Ideograph", "Ideographic"},
    161251: {"Unified_Ideograph", "Ideographic"},
    161252: {"Unified_Ideograph", "Ideographic"},
    161253: {"Unified_Ideograph", "Ideographic"},
    161254: {"Unified_Ideograph", "Ideographic"},
    161255: {"Unified_Ideograph", "Ideographic"},
    161256: {"Unified_Ideograph", "Ideographic"},
    161257: {"Unified_Ideograph", "Ideographic"},
    161258: {"Unified_Ideograph", "Ideographic"},
    161259: {"Unified_Ideograph", "Ideographic"},
    161260: {"Unified_Ideograph", "Ideographic"},
    161261: {"Unified_Ideograph", "Ideographic"},
    161262: {"Unified_Ideograph", "Ideographic"},
    161263: {"Unified_Ideograph", "Ideographic"},
    161264: {"Unified_Ideograph", "Ideographic"},
    161265: {"Unified_Ideograph", "Ideographic"},
    161266: {"Unified_Ideograph", "Ideographic"},
    161267: {"Unified_Ideograph", "Ideographic"},
    161268: {"Unified_Ideograph", "Ideographic"},
    161269: {"Unified_Ideograph", "Ideographic"},
    161270: {"Unified_Ideograph", "Ideographic"},
    161271: {"Unified_Ideograph", "Ideographic"},
    161272: {"Unified_Ideograph", "Ideographic"},
    161273: {"Unified_Ideograph", "Ideographic"},
    161274: {"Unified_Ideograph", "Ideographic"},
    161275: {"Unified_Ideograph", "Ideographic"},
    161276: {"Unified_Ideograph", "Ideographic"},
    161277: {"Unified_Ideograph", "Ideographic"},
    161278: {"Unified_Ideograph", "Ideographic"},
    161279: {"Unified_Ideograph", "Ideographic"},
    161280: {"Unified_Ideograph", "Ideographic"},
    161281: {"Unified_Ideograph", "Ideographic"},
    161282: {"Unified_Ideograph", "Ideographic"},
    161283: {"Unified_Ideograph", "Ideographic"},
    161284: {"Unified_Ideograph", "Ideographic"},
    161285: {"Unified_Ideograph", "Ideographic"},
    161286: {"Unified_Ideograph", "Ideographic"},
    161287: {"Unified_Ideograph", "Ideographic"},
    161288: {"Unified_Ideograph", "Ideographic"},
    161289: {"Unified_Ideograph", "Ideographic"},
    161290: {"Unified_Ideograph", "Ideographic"},
    161291: {"Unified_Ideograph", "Ideographic"},
    161292: {"Unified_Ideograph", "Ideographic"},
    161293: {"Unified_Ideograph", "Ideographic"},
    161294: {"Unified_Ideograph", "Ideographic"},
    161295: {"Unified_Ideograph", "Ideographic"},
    161296: {"Unified_Ideograph", "Ideographic"},
    161297: {"Unified_Ideograph", "Ideographic"},
    161298: {"Unified_Ideograph", "Ideographic"},
    161299: {"Unified_Ideograph", "Ideographic"},
    161300: {"Unified_Ideograph", "Ideographic"},
    161301: {"Unified_Ideograph", "Ideographic"},
    161302: {"Unified_Ideograph", "Ideographic"},
    161303: {"Unified_Ideograph", "Ideographic"},
    161304: {"Unified_Ideograph", "Ideographic"},
    161305: {"Unified_Ideograph", "Ideographic"},
    161306: {"Unified_Ideograph", "Ideographic"},
    161307: {"Unified_Ideograph", "Ideographic"},
    161308: {"Unified_Ideograph", "Ideographic"},
    161309: {"Unified_Ideograph", "Ideographic"},
    161310: {"Unified_Ideograph", "Ideographic"},
    161311: {"Unified_Ideograph", "Ideographic"},
    161312: {"Unified_Ideograph", "Ideographic"},
    161313: {"Unified_Ideograph", "Ideographic"},
    161314: {"Unified_Ideograph", "Ideographic"},
    161315: {"Unified_Ideograph", "Ideographic"},
    161316: {"Unified_Ideograph", "Ideographic"},
    161317: {"Unified_Ideograph", "Ideographic"},
    161318: {"Unified_Ideograph", "Ideographic"},
    161319: {"Unified_Ideograph", "Ideographic"},
    161320: {"Unified_Ideograph", "Ideographic"},
    161321: {"Unified_Ideograph", "Ideographic"},
    161322: {"Unified_Ideograph", "Ideographic"},
    161323: {"Unified_Ideograph", "Ideographic"},
    161324: {"Unified_Ideograph", "Ideographic"},
    161325: {"Unified_Ideograph", "Ideographic"},
    161326: {"Unified_Ideograph", "Ideographic"},
    161327: {"Unified_Ideograph", "Ideographic"},
    161328: {"Unified_Ideograph", "Ideographic"},
    161329: {"Unified_Ideograph", "Ideographic"},
    161330: {"Unified_Ideograph", "Ideographic"},
    161331: {"Unified_Ideograph", "Ideographic"},
    161332: {"Unified_Ideograph", "Ideographic"},
    161333: {"Unified_Ideograph", "Ideographic"},
    161334: {"Unified_Ideograph", "Ideographic"},
    161335: {"Unified_Ideograph", "Ideographic"},
    161336: {"Unified_Ideograph", "Ideographic"},
    161337: {"Unified_Ideograph", "Ideographic"},
    161338: {"Unified_Ideograph", "Ideographic"},
    161339: {"Unified_Ideograph", "Ideographic"},
    161340: {"Unified_Ideograph", "Ideographic"},
    161341: {"Unified_Ideograph", "Ideographic"},
    161342: {"Unified_Ideograph", "Ideographic"},
    161343: {"Unified_Ideograph", "Ideographic"},
    161344: {"Unified_Ideograph", "Ideographic"},
    161345: {"Unified_Ideograph", "Ideographic"},
    161346: {"Unified_Ideograph", "Ideographic"},
    161347: {"Unified_Ideograph", "Ideographic"},
    161348: {"Unified_Ideograph", "Ideographic"},
    161349: {"Unified_Ideograph", "Ideographic"},
    161350: {"Unified_Ideograph", "Ideographic"},
    161351: {"Unified_Ideograph", "Ideographic"},
    161352: {"Unified_Ideograph", "Ideographic"},
    161353: {"Unified_Ideograph", "Ideographic"},
    161354: {"Unified_Ideograph", "Ideographic"},
    161355: {"Unified_Ideograph", "Ideographic"},
    161356: {"Unified_Ideograph", "Ideographic"},
    161357: {"Unified_Ideograph", "Ideographic"},
    161358: {"Unified_Ideograph", "Ideographic"},
    161359: {"Unified_Ideograph", "Ideographic"},
    161360: {"Unified_Ideograph", "Ideographic"},
    161361: {"Unified_Ideograph", "Ideographic"},
    161362: {"Unified_Ideograph", "Ideographic"},
    161363: {"Unified_Ideograph", "Ideographic"},
    161364: {"Unified_Ideograph", "Ideographic"},
    161365: {"Unified_Ideograph", "Ideographic"},
    161366: {"Unified_Ideograph", "Ideographic"},
    161367: {"Unified_Ideograph", "Ideographic"},
    161368: {"Unified_Ideograph", "Ideographic"},
    161369: {"Unified_Ideograph", "Ideographic"},
    161370: {"Unified_Ideograph", "Ideographic"},
    161371: {"Unified_Ideograph", "Ideographic"},
    161372: {"Unified_Ideograph", "Ideographic"},
    161373: {"Unified_Ideograph", "Ideographic"},
    161374: {"Unified_Ideograph", "Ideographic"},
    161375: {"Unified_Ideograph", "Ideographic"},
    161376: {"Unified_Ideograph", "Ideographic"},
    161377: {"Unified_Ideograph", "Ideographic"},
    161378: {"Unified_Ideograph", "Ideographic"},
    161379: {"Unified_Ideograph", "Ideographic"},
    161380: {"Unified_Ideograph", "Ideographic"},
    161381: {"Unified_Ideograph", "Ideographic"},
    161382: {"Unified_Ideograph", "Ideographic"},
    161383: {"Unified_Ideograph", "Ideographic"},
    161384: {"Unified_Ideograph", "Ideographic"},
    161385: {"Unified_Ideograph", "Ideographic"},
    161386: {"Unified_Ideograph", "Ideographic"},
    161387: {"Unified_Ideograph", "Ideographic"},
    161388: {"Unified_Ideograph", "Ideographic"},
    161389: {"Unified_Ideograph", "Ideographic"},
    161390: {"Unified_Ideograph", "Ideographic"},
    161391: {"Unified_Ideograph", "Ideographic"},
    161392: {"Unified_Ideograph", "Ideographic"},
    161393: {"Unified_Ideograph", "Ideographic"},
    161394: {"Unified_Ideograph", "Ideographic"},
    161395: {"Unified_Ideograph", "Ideographic"},
    161396: {"Unified_Ideograph", "Ideographic"},
    161397: {"Unified_Ideograph", "Ideographic"},
    161398: {"Unified_Ideograph", "Ideographic"},
    161399: {"Unified_Ideograph", "Ideographic"},
    161400: {"Unified_Ideograph", "Ideographic"},
    161401: {"Unified_Ideograph", "Ideographic"},
    161402: {"Unified_Ideograph", "Ideographic"},
    161403: {"Unified_Ideograph", "Ideographic"},
    161404: {"Unified_Ideograph", "Ideographic"},
    161405: {"Unified_Ideograph", "Ideographic"},
    161406: {"Unified_Ideograph", "Ideographic"},
    161407: {"Unified_Ideograph", "Ideographic"},
    161408: {"Unified_Ideograph", "Ideographic"},
    161409: {"Unified_Ideograph", "Ideographic"},
    161410: {"Unified_Ideograph", "Ideographic"},
    161411: {"Unified_Ideograph", "Ideographic"},
    161412: {"Unified_Ideograph", "Ideographic"},
    161413: {"Unified_Ideograph", "Ideographic"},
    161414: {"Unified_Ideograph", "Ideographic"},
    161415: {"Unified_Ideograph", "Ideographic"},
    161416: {"Unified_Ideograph", "Ideographic"},
    161417: {"Unified_Ideograph", "Ideographic"},
    161418: {"Unified_Ideograph", "Ideographic"},
    161419: {"Unified_Ideograph", "Ideographic"},
    161420: {"Unified_Ideograph", "Ideographic"},
    161421: {"Unified_Ideograph", "Ideographic"},
    161422: {"Unified_Ideograph", "Ideographic"},
    161423: {"Unified_Ideograph", "Ideographic"},
    161424: {"Unified_Ideograph", "Ideographic"},
    161425: {"Unified_Ideograph", "Ideographic"},
    161426: {"Unified_Ideograph", "Ideographic"},
    161427: {"Unified_Ideograph", "Ideographic"},
    161428: {"Unified_Ideograph", "Ideographic"},
    161429: {"Unified_Ideograph", "Ideographic"},
    161430: {"Unified_Ideograph", "Ideographic"},
    161431: {"Unified_Ideograph", "Ideographic"},
    161432: {"Unified_Ideograph", "Ideographic"},
    161433: {"Unified_Ideograph", "Ideographic"},
    161434: {"Unified_Ideograph", "Ideographic"},
    161435: {"Unified_Ideograph", "Ideographic"},
    161436: {"Unified_Ideograph", "Ideographic"},
    161437: {"Unified_Ideograph", "Ideographic"},
    161438: {"Unified_Ideograph", "Ideographic"},
    161439: {"Unified_Ideograph", "Ideographic"},
    161440: {"Unified_Ideograph", "Ideographic"},
    161441: {"Unified_Ideograph", "Ideographic"},
    161442: {"Unified_Ideograph", "Ideographic"},
    161443: {"Unified_Ideograph", "Ideographic"},
    161444: {"Unified_Ideograph", "Ideographic"},
    161445: {"Unified_Ideograph", "Ideographic"},
    161446: {"Unified_Ideograph", "Ideographic"},
    161447: {"Unified_Ideograph", "Ideographic"},
    161448: {"Unified_Ideograph", "Ideographic"},
    161449: {"Unified_Ideograph", "Ideographic"},
    161450: {"Unified_Ideograph", "Ideographic"},
    161451: {"Unified_Ideograph", "Ideographic"},
    161452: {"Unified_Ideograph", "Ideographic"},
    161453: {"Unified_Ideograph", "Ideographic"},
    161454: {"Unified_Ideograph", "Ideographic"},
    161455: {"Unified_Ideograph", "Ideographic"},
    161456: {"Unified_Ideograph", "Ideographic"},
    161457: {"Unified_Ideograph", "Ideographic"},
    161458: {"Unified_Ideograph", "Ideographic"},
    161459: {"Unified_Ideograph", "Ideographic"},
    161460: {"Unified_Ideograph", "Ideographic"},
    161461: {"Unified_Ideograph", "Ideographic"},
    161462: {"Unified_Ideograph", "Ideographic"},
    161463: {"Unified_Ideograph", "Ideographic"},
    161464: {"Unified_Ideograph", "Ideographic"},
    161465: {"Unified_Ideograph", "Ideographic"},
    161466: {"Unified_Ideograph", "Ideographic"},
    161467: {"Unified_Ideograph", "Ideographic"},
    161468: {"Unified_Ideograph", "Ideographic"},
    161469: {"Unified_Ideograph", "Ideographic"},
    161470: {"Unified_Ideograph", "Ideographic"},
    161471: {"Unified_Ideograph", "Ideographic"},
    161472: {"Unified_Ideograph", "Ideographic"},
    161473: {"Unified_Ideograph", "Ideographic"},
    161474: {"Unified_Ideograph", "Ideographic"},
    161475: {"Unified_Ideograph", "Ideographic"},
    161476: {"Unified_Ideograph", "Ideographic"},
    161477: {"Unified_Ideograph", "Ideographic"},
    161478: {"Unified_Ideograph", "Ideographic"},
    161479: {"Unified_Ideograph", "Ideographic"},
    161480: {"Unified_Ideograph", "Ideographic"},
    161481: {"Unified_Ideograph", "Ideographic"},
    161482: {"Unified_Ideograph", "Ideographic"},
    161483: {"Unified_Ideograph", "Ideographic"},
    161484: {"Unified_Ideograph", "Ideographic"},
    161485: {"Unified_Ideograph", "Ideographic"},
    161486: {"Unified_Ideograph", "Ideographic"},
    161487: {"Unified_Ideograph", "Ideographic"},
    161488: {"Unified_Ideograph", "Ideographic"},
    161489: {"Unified_Ideograph", "Ideographic"},
    161490: {"Unified_Ideograph", "Ideographic"},
    161491: {"Unified_Ideograph", "Ideographic"},
    161492: {"Unified_Ideograph", "Ideographic"},
    161493: {"Unified_Ideograph", "Ideographic"},
    161494: {"Unified_Ideograph", "Ideographic"},
    161495: {"Unified_Ideograph", "Ideographic"},
    161496: {"Unified_Ideograph", "Ideographic"},
    161497: {"Unified_Ideograph", "Ideographic"},
    161498: {"Unified_Ideograph", "Ideographic"},
    161499: {"Unified_Ideograph", "Ideographic"},
    161500: {"Unified_Ideograph", "Ideographic"},
    161501: {"Unified_Ideograph", "Ideographic"},
    161502: {"Unified_Ideograph", "Ideographic"},
    161503: {"Unified_Ideograph", "Ideographic"},
    161504: {"Unified_Ideograph", "Ideographic"},
    161505: {"Unified_Ideograph", "Ideographic"},
    161506: {"Unified_Ideograph", "Ideographic"},
    161507: {"Unified_Ideograph", "Ideographic"},
    161508: {"Unified_Ideograph", "Ideographic"},
    161509: {"Unified_Ideograph", "Ideographic"},
    161510: {"Unified_Ideograph", "Ideographic"},
    161511: {"Unified_Ideograph", "Ideographic"},
    161512: {"Unified_Ideograph", "Ideographic"},
    161513: {"Unified_Ideograph", "Ideographic"},
    161514: {"Unified_Ideograph", "Ideographic"},
    161515: {"Unified_Ideograph", "Ideographic"},
    161516: {"Unified_Ideograph", "Ideographic"},
    161517: {"Unified_Ideograph", "Ideographic"},
    161518: {"Unified_Ideograph", "Ideographic"},
    161519: {"Unified_Ideograph", "Ideographic"},
    161520: {"Unified_Ideograph", "Ideographic"},
    161521: {"Unified_Ideograph", "Ideographic"},
    161522: {"Unified_Ideograph", "Ideographic"},
    161523: {"Unified_Ideograph", "Ideographic"},
    161524: {"Unified_Ideograph", "Ideographic"},
    161525: {"Unified_Ideograph", "Ideographic"},
    161526: {"Unified_Ideograph", "Ideographic"},
    161527: {"Unified_Ideograph", "Ideographic"},
    161528: {"Unified_Ideograph", "Ideographic"},
    161529: {"Unified_Ideograph", "Ideographic"},
    161530: {"Unified_Ideograph", "Ideographic"},
    161531: {"Unified_Ideograph", "Ideographic"},
    161532: {"Unified_Ideograph", "Ideographic"},
    161533: {"Unified_Ideograph", "Ideographic"},
    161534: {"Unified_Ideograph", "Ideographic"},
    161535: {"Unified_Ideograph", "Ideographic"},
    161536: {"Unified_Ideograph", "Ideographic"},
    161537: {"Unified_Ideograph", "Ideographic"},
    161538: {"Unified_Ideograph", "Ideographic"},
    161539: {"Unified_Ideograph", "Ideographic"},
    161540: {"Unified_Ideograph", "Ideographic"},
    161541: {"Unified_Ideograph", "Ideographic"},
    161542: {"Unified_Ideograph", "Ideographic"},
    161543: {"Unified_Ideograph", "Ideographic"},
    161544: {"Unified_Ideograph", "Ideographic"},
    161545: {"Unified_Ideograph", "Ideographic"},
    161546: {"Unified_Ideograph", "Ideographic"},
    161547: {"Unified_Ideograph", "Ideographic"},
    161548: {"Unified_Ideograph", "Ideographic"},
    161549: {"Unified_Ideograph", "Ideographic"},
    161550: {"Unified_Ideograph", "Ideographic"},
    161551: {"Unified_Ideograph", "Ideographic"},
    161552: {"Unified_Ideograph", "Ideographic"},
    161553: {"Unified_Ideograph", "Ideographic"},
    161554: {"Unified_Ideograph", "Ideographic"},
    161555: {"Unified_Ideograph", "Ideographic"},
    161556: {"Unified_Ideograph", "Ideographic"},
    161557: {"Unified_Ideograph", "Ideographic"},
    161558: {"Unified_Ideograph", "Ideographic"},
    161559: {"Unified_Ideograph", "Ideographic"},
    161560: {"Unified_Ideograph", "Ideographic"},
    161561: {"Unified_Ideograph", "Ideographic"},
    161562: {"Unified_Ideograph", "Ideographic"},
    161563: {"Unified_Ideograph", "Ideographic"},
    161564: {"Unified_Ideograph", "Ideographic"},
    161565: {"Unified_Ideograph", "Ideographic"},
    161566: {"Unified_Ideograph", "Ideographic"},
    161567: {"Unified_Ideograph", "Ideographic"},
    161568: {"Unified_Ideograph", "Ideographic"},
    161569: {"Unified_Ideograph", "Ideographic"},
    161570: {"Unified_Ideograph", "Ideographic"},
    161571: {"Unified_Ideograph", "Ideographic"},
    161572: {"Unified_Ideograph", "Ideographic"},
    161573: {"Unified_Ideograph", "Ideographic"},
    161574: {"Unified_Ideograph", "Ideographic"},
    161575: {"Unified_Ideograph", "Ideographic"},
    161576: {"Unified_Ideograph", "Ideographic"},
    161577: {"Unified_Ideograph", "Ideographic"},
    161578: {"Unified_Ideograph", "Ideographic"},
    161579: {"Unified_Ideograph", "Ideographic"},
    161580: {"Unified_Ideograph", "Ideographic"},
    161581: {"Unified_Ideograph", "Ideographic"},
    161582: {"Unified_Ideograph", "Ideographic"},
    161583: {"Unified_Ideograph", "Ideographic"},
    161584: {"Unified_Ideograph", "Ideographic"},
    161585: {"Unified_Ideograph", "Ideographic"},
    161586: {"Unified_Ideograph", "Ideographic"},
    161587: {"Unified_Ideograph", "Ideographic"},
    161588: {"Unified_Ideograph", "Ideographic"},
    161589: {"Unified_Ideograph", "Ideographic"},
    161590: {"Unified_Ideograph", "Ideographic"},
    161591: {"Unified_Ideograph", "Ideographic"},
    161592: {"Unified_Ideograph", "Ideographic"},
    161593: {"Unified_Ideograph", "Ideographic"},
    161594: {"Unified_Ideograph", "Ideographic"},
    161595: {"Unified_Ideograph", "Ideographic"},
    161596: {"Unified_Ideograph", "Ideographic"},
    161597: {"Unified_Ideograph", "Ideographic"},
    161598: {"Unified_Ideograph", "Ideographic"},
    161599: {"Unified_Ideograph", "Ideographic"},
    161600: {"Unified_Ideograph", "Ideographic"},
    161601: {"Unified_Ideograph", "Ideographic"},
    161602: {"Unified_Ideograph", "Ideographic"},
    161603: {"Unified_Ideograph", "Ideographic"},
    161604: {"Unified_Ideograph", "Ideographic"},
    161605: {"Unified_Ideograph", "Ideographic"},
    161606: {"Unified_Ideograph", "Ideographic"},
    161607: {"Unified_Ideograph", "Ideographic"},
    161608: {"Unified_Ideograph", "Ideographic"},
    161609: {"Unified_Ideograph", "Ideographic"},
    161610: {"Unified_Ideograph", "Ideographic"},
    161611: {"Unified_Ideograph", "Ideographic"},
    161612: {"Unified_Ideograph", "Ideographic"},
    161613: {"Unified_Ideograph", "Ideographic"},
    161614: {"Unified_Ideograph", "Ideographic"},
    161615: {"Unified_Ideograph", "Ideographic"},
    161616: {"Unified_Ideograph", "Ideographic"},
    161617: {"Unified_Ideograph", "Ideographic"},
    161618: {"Unified_Ideograph", "Ideographic"},
    161619: {"Unified_Ideograph", "Ideographic"},
    161620: {"Unified_Ideograph", "Ideographic"},
    161621: {"Unified_Ideograph", "Ideographic"},
    161622: {"Unified_Ideograph", "Ideographic"},
    161623: {"Unified_Ideograph", "Ideographic"},
    161624: {"Unified_Ideograph", "Ideographic"},
    161625: {"Unified_Ideograph", "Ideographic"},
    161626: {"Unified_Ideograph", "Ideographic"},
    161627: {"Unified_Ideograph", "Ideographic"},
    161628: {"Unified_Ideograph", "Ideographic"},
    161629: {"Unified_Ideograph", "Ideographic"},
    161630: {"Unified_Ideograph", "Ideographic"},
    161631: {"Unified_Ideograph", "Ideographic"},
    161632: {"Unified_Ideograph", "Ideographic"},
    161633: {"Unified_Ideograph", "Ideographic"},
    161634: {"Unified_Ideograph", "Ideographic"},
    161635: {"Unified_Ideograph", "Ideographic"},
    161636: {"Unified_Ideograph", "Ideographic"},
    161637: {"Unified_Ideograph", "Ideographic"},
    161638: {"Unified_Ideograph", "Ideographic"},
    161639: {"Unified_Ideograph", "Ideographic"},
    161640: {"Unified_Ideograph", "Ideographic"},
    161641: {"Unified_Ideograph", "Ideographic"},
    161642: {"Unified_Ideograph", "Ideographic"},
    161643: {"Unified_Ideograph", "Ideographic"},
    161644: {"Unified_Ideograph", "Ideographic"},
    161645: {"Unified_Ideograph", "Ideographic"},
    161646: {"Unified_Ideograph", "Ideographic"},
    161647: {"Unified_Ideograph", "Ideographic"},
    161648: {"Unified_Ideograph", "Ideographic"},
    161649: {"Unified_Ideograph", "Ideographic"},
    161650: {"Unified_Ideograph", "Ideographic"},
    161651: {"Unified_Ideograph", "Ideographic"},
    161652: {"Unified_Ideograph", "Ideographic"},
    161653: {"Unified_Ideograph", "Ideographic"},
    161654: {"Unified_Ideograph", "Ideographic"},
    161655: {"Unified_Ideograph", "Ideographic"},
    161656: {"Unified_Ideograph", "Ideographic"},
    161657: {"Unified_Ideograph", "Ideographic"},
    161658: {"Unified_Ideograph", "Ideographic"},
    161659: {"Unified_Ideograph", "Ideographic"},
    161660: {"Unified_Ideograph", "Ideographic"},
    161661: {"Unified_Ideograph", "Ideographic"},
    161662: {"Unified_Ideograph", "Ideographic"},
    161663: {"Unified_Ideograph", "Ideographic"},
    161664: {"Unified_Ideograph", "Ideographic"},
    161665: {"Unified_Ideograph", "Ideographic"},
    161666: {"Unified_Ideograph", "Ideographic"},
    161667: {"Unified_Ideograph", "Ideographic"},
    161668: {"Unified_Ideograph", "Ideographic"},
    161669: {"Unified_Ideograph", "Ideographic"},
    161670: {"Unified_Ideograph", "Ideographic"},
    161671: {"Unified_Ideograph", "Ideographic"},
    161672: {"Unified_Ideograph", "Ideographic"},
    161673: {"Unified_Ideograph", "Ideographic"},
    161674: {"Unified_Ideograph", "Ideographic"},
    161675: {"Unified_Ideograph", "Ideographic"},
    161676: {"Unified_Ideograph", "Ideographic"},
    161677: {"Unified_Ideograph", "Ideographic"},
    161678: {"Unified_Ideograph", "Ideographic"},
    161679: {"Unified_Ideograph", "Ideographic"},
    161680: {"Unified_Ideograph", "Ideographic"},
    161681: {"Unified_Ideograph", "Ideographic"},
    161682: {"Unified_Ideograph", "Ideographic"},
    161683: {"Unified_Ideograph", "Ideographic"},
    161684: {"Unified_Ideograph", "Ideographic"},
    161685: {"Unified_Ideograph", "Ideographic"},
    161686: {"Unified_Ideograph", "Ideographic"},
    161687: {"Unified_Ideograph", "Ideographic"},
    161688: {"Unified_Ideograph", "Ideographic"},
    161689: {"Unified_Ideograph", "Ideographic"},
    161690: {"Unified_Ideograph", "Ideographic"},
    161691: {"Unified_Ideograph", "Ideographic"},
    161692: {"Unified_Ideograph", "Ideographic"},
    161693: {"Unified_Ideograph", "Ideographic"},
    161694: {"Unified_Ideograph", "Ideographic"},
    161695: {"Unified_Ideograph", "Ideographic"},
    161696: {"Unified_Ideograph", "Ideographic"},
    161697: {"Unified_Ideograph", "Ideographic"},
    161698: {"Unified_Ideograph", "Ideographic"},
    161699: {"Unified_Ideograph", "Ideographic"},
    161700: {"Unified_Ideograph", "Ideographic"},
    161701: {"Unified_Ideograph", "Ideographic"},
    161702: {"Unified_Ideograph", "Ideographic"},
    161703: {"Unified_Ideograph", "Ideographic"},
    161704: {"Unified_Ideograph", "Ideographic"},
    161705: {"Unified_Ideograph", "Ideographic"},
    161706: {"Unified_Ideograph", "Ideographic"},
    161707: {"Unified_Ideograph", "Ideographic"},
    161708: {"Unified_Ideograph", "Ideographic"},
    161709: {"Unified_Ideograph", "Ideographic"},
    161710: {"Unified_Ideograph", "Ideographic"},
    161711: {"Unified_Ideograph", "Ideographic"},
    161712: {"Unified_Ideograph", "Ideographic"},
    161713: {"Unified_Ideograph", "Ideographic"},
    161714: {"Unified_Ideograph", "Ideographic"},
    161715: {"Unified_Ideograph", "Ideographic"},
    161716: {"Unified_Ideograph", "Ideographic"},
    161717: {"Unified_Ideograph", "Ideographic"},
    161718: {"Unified_Ideograph", "Ideographic"},
    161719: {"Unified_Ideograph", "Ideographic"},
    161720: {"Unified_Ideograph", "Ideographic"},
    161721: {"Unified_Ideograph", "Ideographic"},
    161722: {"Unified_Ideograph", "Ideographic"},
    161723: {"Unified_Ideograph", "Ideographic"},
    161724: {"Unified_Ideograph", "Ideographic"},
    161725: {"Unified_Ideograph", "Ideographic"},
    161726: {"Unified_Ideograph", "Ideographic"},
    161727: {"Unified_Ideograph", "Ideographic"},
    161728: {"Unified_Ideograph", "Ideographic"},
    161729: {"Unified_Ideograph", "Ideographic"},
    161730: {"Unified_Ideograph", "Ideographic"},
    161731: {"Unified_Ideograph", "Ideographic"},
    161732: {"Unified_Ideograph", "Ideographic"},
    161733: {"Unified_Ideograph", "Ideographic"},
    161734: {"Unified_Ideograph", "Ideographic"},
    161735: {"Unified_Ideograph", "Ideographic"},
    161736: {"Unified_Ideograph", "Ideographic"},
    161737: {"Unified_Ideograph", "Ideographic"},
    161738: {"Unified_Ideograph", "Ideographic"},
    161739: {"Unified_Ideograph", "Ideographic"},
    161740: {"Unified_Ideograph", "Ideographic"},
    161741: {"Unified_Ideograph", "Ideographic"},
    161742: {"Unified_Ideograph", "Ideographic"},
    161743: {"Unified_Ideograph", "Ideographic"},
    161744: {"Unified_Ideograph", "Ideographic"},
    161745: {"Unified_Ideograph", "Ideographic"},
    161746: {"Unified_Ideograph", "Ideographic"},
    161747: {"Unified_Ideograph", "Ideographic"},
    161748: {"Unified_Ideograph", "Ideographic"},
    161749: {"Unified_Ideograph", "Ideographic"},
    161750: {"Unified_Ideograph", "Ideographic"},
    161751: {"Unified_Ideograph", "Ideographic"},
    161752: {"Unified_Ideograph", "Ideographic"},
    161753: {"Unified_Ideograph", "Ideographic"},
    161754: {"Unified_Ideograph", "Ideographic"},
    161755: {"Unified_Ideograph", "Ideographic"},
    161756: {"Unified_Ideograph", "Ideographic"},
    161757: {"Unified_Ideograph", "Ideographic"},
    161758: {"Unified_Ideograph", "Ideographic"},
    161759: {"Unified_Ideograph", "Ideographic"},
    161760: {"Unified_Ideograph", "Ideographic"},
    161761: {"Unified_Ideograph", "Ideographic"},
    161762: {"Unified_Ideograph", "Ideographic"},
    161763: {"Unified_Ideograph", "Ideographic"},
    161764: {"Unified_Ideograph", "Ideographic"},
    161765: {"Unified_Ideograph", "Ideographic"},
    161766: {"Unified_Ideograph", "Ideographic"},
    161767: {"Unified_Ideograph", "Ideographic"},
    161768: {"Unified_Ideograph", "Ideographic"},
    161769: {"Unified_Ideograph", "Ideographic"},
    161770: {"Unified_Ideograph", "Ideographic"},
    161771: {"Unified_Ideograph", "Ideographic"},
    161772: {"Unified_Ideograph", "Ideographic"},
    161773: {"Unified_Ideograph", "Ideographic"},
    161774: {"Unified_Ideograph", "Ideographic"},
    161775: {"Unified_Ideograph", "Ideographic"},
    161776: {"Unified_Ideograph", "Ideographic"},
    161777: {"Unified_Ideograph", "Ideographic"},
    161778: {"Unified_Ideograph", "Ideographic"},
    161779: {"Unified_Ideograph", "Ideographic"},
    161780: {"Unified_Ideograph", "Ideographic"},
    161781: {"Unified_Ideograph", "Ideographic"},
    161782: {"Unified_Ideograph", "Ideographic"},
    161783: {"Unified_Ideograph", "Ideographic"},
    161784: {"Unified_Ideograph", "Ideographic"},
    161785: {"Unified_Ideograph", "Ideographic"},
    161786: {"Unified_Ideograph", "Ideographic"},
    161787: {"Unified_Ideograph", "Ideographic"},
    161788: {"Unified_Ideograph", "Ideographic"},
    161789: {"Unified_Ideograph", "Ideographic"},
    161790: {"Unified_Ideograph", "Ideographic"},
    161791: {"Unified_Ideograph", "Ideographic"},
    161792: {"Unified_Ideograph", "Ideographic"},
    161793: {"Unified_Ideograph", "Ideographic"},
    161794: {"Unified_Ideograph", "Ideographic"},
    161795: {"Unified_Ideograph", "Ideographic"},
    161796: {"Unified_Ideograph", "Ideographic"},
    161797: {"Unified_Ideograph", "Ideographic"},
    161798: {"Unified_Ideograph", "Ideographic"},
    161799: {"Unified_Ideograph", "Ideographic"},
    161800: {"Unified_Ideograph", "Ideographic"},
    161801: {"Unified_Ideograph", "Ideographic"},
    161802: {"Unified_Ideograph", "Ideographic"},
    161803: {"Unified_Ideograph", "Ideographic"},
    161804: {"Unified_Ideograph", "Ideographic"},
    161805: {"Unified_Ideograph", "Ideographic"},
    161806: {"Unified_Ideograph", "Ideographic"},
    161807: {"Unified_Ideograph", "Ideographic"},
    161808: {"Unified_Ideograph", "Ideographic"},
    161809: {"Unified_Ideograph", "Ideographic"},
    161810: {"Unified_Ideograph", "Ideographic"},
    161811: {"Unified_Ideograph", "Ideographic"},
    161812: {"Unified_Ideograph", "Ideographic"},
    161813: {"Unified_Ideograph", "Ideographic"},
    161814: {"Unified_Ideograph", "Ideographic"},
    161815: {"Unified_Ideograph", "Ideographic"},
    161816: {"Unified_Ideograph", "Ideographic"},
    161817: {"Unified_Ideograph", "Ideographic"},
    161818: {"Unified_Ideograph", "Ideographic"},
    161819: {"Unified_Ideograph", "Ideographic"},
    161820: {"Unified_Ideograph", "Ideographic"},
    161821: {"Unified_Ideograph", "Ideographic"},
    161822: {"Unified_Ideograph", "Ideographic"},
    161823: {"Unified_Ideograph", "Ideographic"},
    161824: {"Unified_Ideograph", "Ideographic"},
    161825: {"Unified_Ideograph", "Ideographic"},
    161826: {"Unified_Ideograph", "Ideographic"},
    161827: {"Unified_Ideograph", "Ideographic"},
    161828: {"Unified_Ideograph", "Ideographic"},
    161829: {"Unified_Ideograph", "Ideographic"},
    161830: {"Unified_Ideograph", "Ideographic"},
    161831: {"Unified_Ideograph", "Ideographic"},
    161832: {"Unified_Ideograph", "Ideographic"},
    161833: {"Unified_Ideograph", "Ideographic"},
    161834: {"Unified_Ideograph", "Ideographic"},
    161835: {"Unified_Ideograph", "Ideographic"},
    161836: {"Unified_Ideograph", "Ideographic"},
    161837: {"Unified_Ideograph", "Ideographic"},
    161838: {"Unified_Ideograph", "Ideographic"},
    161839: {"Unified_Ideograph", "Ideographic"},
    161840: {"Unified_Ideograph", "Ideographic"},
    161841: {"Unified_Ideograph", "Ideographic"},
    161842: {"Unified_Ideograph", "Ideographic"},
    161843: {"Unified_Ideograph", "Ideographic"},
    161844: {"Unified_Ideograph", "Ideographic"},
    161845: {"Unified_Ideograph", "Ideographic"},
    161846: {"Unified_Ideograph", "Ideographic"},
    161847: {"Unified_Ideograph", "Ideographic"},
    161848: {"Unified_Ideograph", "Ideographic"},
    161849: {"Unified_Ideograph", "Ideographic"},
    161850: {"Unified_Ideograph", "Ideographic"},
    161851: {"Unified_Ideograph", "Ideographic"},
    161852: {"Unified_Ideograph", "Ideographic"},
    161853: {"Unified_Ideograph", "Ideographic"},
    161854: {"Unified_Ideograph", "Ideographic"},
    161855: {"Unified_Ideograph", "Ideographic"},
    161856: {"Unified_Ideograph", "Ideographic"},
    161857: {"Unified_Ideograph", "Ideographic"},
    161858: {"Unified_Ideograph", "Ideographic"},
    161859: {"Unified_Ideograph", "Ideographic"},
    161860: {"Unified_Ideograph", "Ideographic"},
    161861: {"Unified_Ideograph", "Ideographic"},
    161862: {"Unified_Ideograph", "Ideographic"},
    161863: {"Unified_Ideograph", "Ideographic"},
    161864: {"Unified_Ideograph", "Ideographic"},
    161865: {"Unified_Ideograph", "Ideographic"},
    161866: {"Unified_Ideograph", "Ideographic"},
    161867: {"Unified_Ideograph", "Ideographic"},
    161868: {"Unified_Ideograph", "Ideographic"},
    161869: {"Unified_Ideograph", "Ideographic"},
    161870: {"Unified_Ideograph", "Ideographic"},
    161871: {"Unified_Ideograph", "Ideographic"},
    161872: {"Unified_Ideograph", "Ideographic"},
    161873: {"Unified_Ideograph", "Ideographic"},
    161874: {"Unified_Ideograph", "Ideographic"},
    161875: {"Unified_Ideograph", "Ideographic"},
    161876: {"Unified_Ideograph", "Ideographic"},
    161877: {"Unified_Ideograph", "Ideographic"},
    161878: {"Unified_Ideograph", "Ideographic"},
    161879: {"Unified_Ideograph", "Ideographic"},
    161880: {"Unified_Ideograph", "Ideographic"},
    161881: {"Unified_Ideograph", "Ideographic"},
    161882: {"Unified_Ideograph", "Ideographic"},
    161883: {"Unified_Ideograph", "Ideographic"},
    161884: {"Unified_Ideograph", "Ideographic"},
    161885: {"Unified_Ideograph", "Ideographic"},
    161886: {"Unified_Ideograph", "Ideographic"},
    161887: {"Unified_Ideograph", "Ideographic"},
    161888: {"Unified_Ideograph", "Ideographic"},
    161889: {"Unified_Ideograph", "Ideographic"},
    161890: {"Unified_Ideograph", "Ideographic"},
    161891: {"Unified_Ideograph", "Ideographic"},
    161892: {"Unified_Ideograph", "Ideographic"},
    161893: {"Unified_Ideograph", "Ideographic"},
    161894: {"Unified_Ideograph", "Ideographic"},
    161895: {"Unified_Ideograph", "Ideographic"},
    161896: {"Unified_Ideograph", "Ideographic"},
    161897: {"Unified_Ideograph", "Ideographic"},
    161898: {"Unified_Ideograph", "Ideographic"},
    161899: {"Unified_Ideograph", "Ideographic"},
    161900: {"Unified_Ideograph", "Ideographic"},
    161901: {"Unified_Ideograph", "Ideographic"},
    161902: {"Unified_Ideograph", "Ideographic"},
    161903: {"Unified_Ideograph", "Ideographic"},
    161904: {"Unified_Ideograph", "Ideographic"},
    161905: {"Unified_Ideograph", "Ideographic"},
    161906: {"Unified_Ideograph", "Ideographic"},
    161907: {"Unified_Ideograph", "Ideographic"},
    161908: {"Unified_Ideograph", "Ideographic"},
    161909: {"Unified_Ideograph", "Ideographic"},
    161910: {"Unified_Ideograph", "Ideographic"},
    161911: {"Unified_Ideograph", "Ideographic"},
    161912: {"Unified_Ideograph", "Ideographic"},
    161913: {"Unified_Ideograph", "Ideographic"},
    161914: {"Unified_Ideograph", "Ideographic"},
    161915: {"Unified_Ideograph", "Ideographic"},
    161916: {"Unified_Ideograph", "Ideographic"},
    161917: {"Unified_Ideograph", "Ideographic"},
    161918: {"Unified_Ideograph", "Ideographic"},
    161919: {"Unified_Ideograph", "Ideographic"},
    161920: {"Unified_Ideograph", "Ideographic"},
    161921: {"Unified_Ideograph", "Ideographic"},
    161922: {"Unified_Ideograph", "Ideographic"},
    161923: {"Unified_Ideograph", "Ideographic"},
    161924: {"Unified_Ideograph", "Ideographic"},
    161925: {"Unified_Ideograph", "Ideographic"},
    161926: {"Unified_Ideograph", "Ideographic"},
    161927: {"Unified_Ideograph", "Ideographic"},
    161928: {"Unified_Ideograph", "Ideographic"},
    161929: {"Unified_Ideograph", "Ideographic"},
    161930: {"Unified_Ideograph", "Ideographic"},
    161931: {"Unified_Ideograph", "Ideographic"},
    161932: {"Unified_Ideograph", "Ideographic"},
    161933: {"Unified_Ideograph", "Ideographic"},
    161934: {"Unified_Ideograph", "Ideographic"},
    161935: {"Unified_Ideograph", "Ideographic"},
    161936: {"Unified_Ideograph", "Ideographic"},
    161937: {"Unified_Ideograph", "Ideographic"},
    161938: {"Unified_Ideograph", "Ideographic"},
    161939: {"Unified_Ideograph", "Ideographic"},
    161940: {"Unified_Ideograph", "Ideographic"},
    161941: {"Unified_Ideograph", "Ideographic"},
    161942: {"Unified_Ideograph", "Ideographic"},
    161943: {"Unified_Ideograph", "Ideographic"},
    161944: {"Unified_Ideograph", "Ideographic"},
    161945: {"Unified_Ideograph", "Ideographic"},
    161946: {"Unified_Ideograph", "Ideographic"},
    161947: {"Unified_Ideograph", "Ideographic"},
    161948: {"Unified_Ideograph", "Ideographic"},
    161949: {"Unified_Ideograph", "Ideographic"},
    161950: {"Unified_Ideograph", "Ideographic"},
    161951: {"Unified_Ideograph", "Ideographic"},
    161952: {"Unified_Ideograph", "Ideographic"},
    161953: {"Unified_Ideograph", "Ideographic"},
    161954: {"Unified_Ideograph", "Ideographic"},
    161955: {"Unified_Ideograph", "Ideographic"},
    161956: {"Unified_Ideograph", "Ideographic"},
    161957: {"Unified_Ideograph", "Ideographic"},
    161958: {"Unified_Ideograph", "Ideographic"},
    161959: {"Unified_Ideograph", "Ideographic"},
    161960: {"Unified_Ideograph", "Ideographic"},
    161961: {"Unified_Ideograph", "Ideographic"},
    161962: {"Unified_Ideograph", "Ideographic"},
    161963: {"Unified_Ideograph", "Ideographic"},
    161964: {"Unified_Ideograph", "Ideographic"},
    161965: {"Unified_Ideograph", "Ideographic"},
    161966: {"Unified_Ideograph", "Ideographic"},
    161967: {"Unified_Ideograph", "Ideographic"},
    161968: {"Unified_Ideograph", "Ideographic"},
    161969: {"Unified_Ideograph", "Ideographic"},
    161970: {"Unified_Ideograph", "Ideographic"},
    161971: {"Unified_Ideograph", "Ideographic"},
    161972: {"Unified_Ideograph", "Ideographic"},
    161973: {"Unified_Ideograph", "Ideographic"},
    161974: {"Unified_Ideograph", "Ideographic"},
    161975: {"Unified_Ideograph", "Ideographic"},
    161976: {"Unified_Ideograph", "Ideographic"},
    161977: {"Unified_Ideograph", "Ideographic"},
    161978: {"Unified_Ideograph", "Ideographic"},
    161979: {"Unified_Ideograph", "Ideographic"},
    161980: {"Unified_Ideograph", "Ideographic"},
    161981: {"Unified_Ideograph", "Ideographic"},
    161982: {"Unified_Ideograph", "Ideographic"},
    161983: {"Unified_Ideograph", "Ideographic"},
    161984: {"Unified_Ideograph", "Ideographic"},
    161985: {"Unified_Ideograph", "Ideographic"},
    161986: {"Unified_Ideograph", "Ideographic"},
    161987: {"Unified_Ideograph", "Ideographic"},
    161988: {"Unified_Ideograph", "Ideographic"},
    161989: {"Unified_Ideograph", "Ideographic"},
    161990: {"Unified_Ideograph", "Ideographic"},
    161991: {"Unified_Ideograph", "Ideographic"},
    161992: {"Unified_Ideograph", "Ideographic"},
    161993: {"Unified_Ideograph", "Ideographic"},
    161994: {"Unified_Ideograph", "Ideographic"},
    161995: {"Unified_Ideograph", "Ideographic"},
    161996: {"Unified_Ideograph", "Ideographic"},
    161997: {"Unified_Ideograph", "Ideographic"},
    161998: {"Unified_Ideograph", "Ideographic"},
    161999: {"Unified_Ideograph", "Ideographic"},
    162000: {"Unified_Ideograph", "Ideographic"},
    162001: {"Unified_Ideograph", "Ideographic"},
    162002: {"Unified_Ideograph", "Ideographic"},
    162003: {"Unified_Ideograph", "Ideographic"},
    162004: {"Unified_Ideograph", "Ideographic"},
    162005: {"Unified_Ideograph", "Ideographic"},
    162006: {"Unified_Ideograph", "Ideographic"},
    162007: {"Unified_Ideograph", "Ideographic"},
    162008: {"Unified_Ideograph", "Ideographic"},
    162009: {"Unified_Ideograph", "Ideographic"},
    162010: {"Unified_Ideograph", "Ideographic"},
    162011: {"Unified_Ideograph", "Ideographic"},
    162012: {"Unified_Ideograph", "Ideographic"},
    162013: {"Unified_Ideograph", "Ideographic"},
    162014: {"Unified_Ideograph", "Ideographic"},
    162015: {"Unified_Ideograph", "Ideographic"},
    162016: {"Unified_Ideograph", "Ideographic"},
    162017: {"Unified_Ideograph", "Ideographic"},
    162018: {"Unified_Ideograph", "Ideographic"},
    162019: {"Unified_Ideograph", "Ideographic"},
    162020: {"Unified_Ideograph", "Ideographic"},
    162021: {"Unified_Ideograph", "Ideographic"},
    162022: {"Unified_Ideograph", "Ideographic"},
    162023: {"Unified_Ideograph", "Ideographic"},
    162024: {"Unified_Ideograph", "Ideographic"},
    162025: {"Unified_Ideograph", "Ideographic"},
    162026: {"Unified_Ideograph", "Ideographic"},
    162027: {"Unified_Ideograph", "Ideographic"},
    162028: {"Unified_Ideograph", "Ideographic"},
    162029: {"Unified_Ideograph", "Ideographic"},
    162030: {"Unified_Ideograph", "Ideographic"},
    162031: {"Unified_Ideograph", "Ideographic"},
    162032: {"Unified_Ideograph", "Ideographic"},
    162033: {"Unified_Ideograph", "Ideographic"},
    162034: {"Unified_Ideograph", "Ideographic"},
    162035: {"Unified_Ideograph", "Ideographic"},
    162036: {"Unified_Ideograph", "Ideographic"},
    162037: {"Unified_Ideograph", "Ideographic"},
    162038: {"Unified_Ideograph", "Ideographic"},
    162039: {"Unified_Ideograph", "Ideographic"},
    162040: {"Unified_Ideograph", "Ideographic"},
    162041: {"Unified_Ideograph", "Ideographic"},
    162042: {"Unified_Ideograph", "Ideographic"},
    162043: {"Unified_Ideograph", "Ideographic"},
    162044: {"Unified_Ideograph", "Ideographic"},
    162045: {"Unified_Ideograph", "Ideographic"},
    162046: {"Unified_Ideograph", "Ideographic"},
    162047: {"Unified_Ideograph", "Ideographic"},
    162048: {"Unified_Ideograph", "Ideographic"},
    162049: {"Unified_Ideograph", "Ideographic"},
    162050: {"Unified_Ideograph", "Ideographic"},
    162051: {"Unified_Ideograph", "Ideographic"},
    162052: {"Unified_Ideograph", "Ideographic"},
    162053: {"Unified_Ideograph", "Ideographic"},
    162054: {"Unified_Ideograph", "Ideographic"},
    162055: {"Unified_Ideograph", "Ideographic"},
    162056: {"Unified_Ideograph", "Ideographic"},
    162057: {"Unified_Ideograph", "Ideographic"},
    162058: {"Unified_Ideograph", "Ideographic"},
    162059: {"Unified_Ideograph", "Ideographic"},
    162060: {"Unified_Ideograph", "Ideographic"},
    162061: {"Unified_Ideograph", "Ideographic"},
    162062: {"Unified_Ideograph", "Ideographic"},
    162063: {"Unified_Ideograph", "Ideographic"},
    162064: {"Unified_Ideograph", "Ideographic"},
    162065: {"Unified_Ideograph", "Ideographic"},
    162066: {"Unified_Ideograph", "Ideographic"},
    162067: {"Unified_Ideograph", "Ideographic"},
    162068: {"Unified_Ideograph", "Ideographic"},
    162069: {"Unified_Ideograph", "Ideographic"},
    162070: {"Unified_Ideograph", "Ideographic"},
    162071: {"Unified_Ideograph", "Ideographic"},
    162072: {"Unified_Ideograph", "Ideographic"},
    162073: {"Unified_Ideograph", "Ideographic"},
    162074: {"Unified_Ideograph", "Ideographic"},
    162075: {"Unified_Ideograph", "Ideographic"},
    162076: {"Unified_Ideograph", "Ideographic"},
    162077: {"Unified_Ideograph", "Ideographic"},
    162078: {"Unified_Ideograph", "Ideographic"},
    162079: {"Unified_Ideograph", "Ideographic"},
    162080: {"Unified_Ideograph", "Ideographic"},
    162081: {"Unified_Ideograph", "Ideographic"},
    162082: {"Unified_Ideograph", "Ideographic"},
    162083: {"Unified_Ideograph", "Ideographic"},
    162084: {"Unified_Ideograph", "Ideographic"},
    162085: {"Unified_Ideograph", "Ideographic"},
    162086: {"Unified_Ideograph", "Ideographic"},
    162087: {"Unified_Ideograph", "Ideographic"},
    162088: {"Unified_Ideograph", "Ideographic"},
    162089: {"Unified_Ideograph", "Ideographic"},
    162090: {"Unified_Ideograph", "Ideographic"},
    162091: {"Unified_Ideograph", "Ideographic"},
    162092: {"Unified_Ideograph", "Ideographic"},
    162093: {"Unified_Ideograph", "Ideographic"},
    162094: {"Unified_Ideograph", "Ideographic"},
    162095: {"Unified_Ideograph", "Ideographic"},
    162096: {"Unified_Ideograph", "Ideographic"},
    162097: {"Unified_Ideograph", "Ideographic"},
    162098: {"Unified_Ideograph", "Ideographic"},
    162099: {"Unified_Ideograph", "Ideographic"},
    162100: {"Unified_Ideograph", "Ideographic"},
    162101: {"Unified_Ideograph", "Ideographic"},
    162102: {"Unified_Ideograph", "Ideographic"},
    162103: {"Unified_Ideograph", "Ideographic"},
    162104: {"Unified_Ideograph", "Ideographic"},
    162105: {"Unified_Ideograph", "Ideographic"},
    162106: {"Unified_Ideograph", "Ideographic"},
    162107: {"Unified_Ideograph", "Ideographic"},
    162108: {"Unified_Ideograph", "Ideographic"},
    162109: {"Unified_Ideograph", "Ideographic"},
    162110: {"Unified_Ideograph", "Ideographic"},
    162111: {"Unified_Ideograph", "Ideographic"},
    162112: {"Unified_Ideograph", "Ideographic"},
    162113: {"Unified_Ideograph", "Ideographic"},
    162114: {"Unified_Ideograph", "Ideographic"},
    162115: {"Unified_Ideograph", "Ideographic"},
    162116: {"Unified_Ideograph", "Ideographic"},
    162117: {"Unified_Ideograph", "Ideographic"},
    162118: {"Unified_Ideograph", "Ideographic"},
    162119: {"Unified_Ideograph", "Ideographic"},
    162120: {"Unified_Ideograph", "Ideographic"},
    162121: {"Unified_Ideograph", "Ideographic"},
    162122: {"Unified_Ideograph", "Ideographic"},
    162123: {"Unified_Ideograph", "Ideographic"},
    162124: {"Unified_Ideograph", "Ideographic"},
    162125: {"Unified_Ideograph", "Ideographic"},
    162126: {"Unified_Ideograph", "Ideographic"},
    162127: {"Unified_Ideograph", "Ideographic"},
    162128: {"Unified_Ideograph", "Ideographic"},
    162129: {"Unified_Ideograph", "Ideographic"},
    162130: {"Unified_Ideograph", "Ideographic"},
    162131: {"Unified_Ideograph", "Ideographic"},
    162132: {"Unified_Ideograph", "Ideographic"},
    162133: {"Unified_Ideograph", "Ideographic"},
    162134: {"Unified_Ideograph", "Ideographic"},
    162135: {"Unified_Ideograph", "Ideographic"},
    162136: {"Unified_Ideograph", "Ideographic"},
    162137: {"Unified_Ideograph", "Ideographic"},
    162138: {"Unified_Ideograph", "Ideographic"},
    162139: {"Unified_Ideograph", "Ideographic"},
    162140: {"Unified_Ideograph", "Ideographic"},
    162141: {"Unified_Ideograph", "Ideographic"},
    162142: {"Unified_Ideograph", "Ideographic"},
    162143: {"Unified_Ideograph", "Ideographic"},
    162144: {"Unified_Ideograph", "Ideographic"},
    162145: {"Unified_Ideograph", "Ideographic"},
    162146: {"Unified_Ideograph", "Ideographic"},
    162147: {"Unified_Ideograph", "Ideographic"},
    162148: {"Unified_Ideograph", "Ideographic"},
    162149: {"Unified_Ideograph", "Ideographic"},
    162150: {"Unified_Ideograph", "Ideographic"},
    162151: {"Unified_Ideograph", "Ideographic"},
    162152: {"Unified_Ideograph", "Ideographic"},
    162153: {"Unified_Ideograph", "Ideographic"},
    162154: {"Unified_Ideograph", "Ideographic"},
    162155: {"Unified_Ideograph", "Ideographic"},
    162156: {"Unified_Ideograph", "Ideographic"},
    162157: {"Unified_Ideograph", "Ideographic"},
    162158: {"Unified_Ideograph", "Ideographic"},
    162159: {"Unified_Ideograph", "Ideographic"},
    162160: {"Unified_Ideograph", "Ideographic"},
    162161: {"Unified_Ideograph", "Ideographic"},
    162162: {"Unified_Ideograph", "Ideographic"},
    162163: {"Unified_Ideograph", "Ideographic"},
    162164: {"Unified_Ideograph", "Ideographic"},
    162165: {"Unified_Ideograph", "Ideographic"},
    162166: {"Unified_Ideograph", "Ideographic"},
    162167: {"Unified_Ideograph", "Ideographic"},
    162168: {"Unified_Ideograph", "Ideographic"},
    162169: {"Unified_Ideograph", "Ideographic"},
    162170: {"Unified_Ideograph", "Ideographic"},
    162171: {"Unified_Ideograph", "Ideographic"},
    162172: {"Unified_Ideograph", "Ideographic"},
    162173: {"Unified_Ideograph", "Ideographic"},
    162174: {"Unified_Ideograph", "Ideographic"},
    162175: {"Unified_Ideograph", "Ideographic"},
    162176: {"Unified_Ideograph", "Ideographic"},
    162177: {"Unified_Ideograph", "Ideographic"},
    162178: {"Unified_Ideograph", "Ideographic"},
    162179: {"Unified_Ideograph", "Ideographic"},
    162180: {"Unified_Ideograph", "Ideographic"},
    162181: {"Unified_Ideograph", "Ideographic"},
    162182: {"Unified_Ideograph", "Ideographic"},
    162183: {"Unified_Ideograph", "Ideographic"},
    162184: {"Unified_Ideograph", "Ideographic"},
    162185: {"Unified_Ideograph", "Ideographic"},
    162186: {"Unified_Ideograph", "Ideographic"},
    162187: {"Unified_Ideograph", "Ideographic"},
    162188: {"Unified_Ideograph", "Ideographic"},
    162189: {"Unified_Ideograph", "Ideographic"},
    162190: {"Unified_Ideograph", "Ideographic"},
    162191: {"Unified_Ideograph", "Ideographic"},
    162192: {"Unified_Ideograph", "Ideographic"},
    162193: {"Unified_Ideograph", "Ideographic"},
    162194: {"Unified_Ideograph", "Ideographic"},
    162195: {"Unified_Ideograph", "Ideographic"},
    162196: {"Unified_Ideograph", "Ideographic"},
    162197: {"Unified_Ideograph", "Ideographic"},
    162198: {"Unified_Ideograph", "Ideographic"},
    162199: {"Unified_Ideograph", "Ideographic"},
    162200: {"Unified_Ideograph", "Ideographic"},
    162201: {"Unified_Ideograph", "Ideographic"},
    162202: {"Unified_Ideograph", "Ideographic"},
    162203: {"Unified_Ideograph", "Ideographic"},
    162204: {"Unified_Ideograph", "Ideographic"},
    162205: {"Unified_Ideograph", "Ideographic"},
    162206: {"Unified_Ideograph", "Ideographic"},
    162207: {"Unified_Ideograph", "Ideographic"},
    162208: {"Unified_Ideograph", "Ideographic"},
    162209: {"Unified_Ideograph", "Ideographic"},
    162210: {"Unified_Ideograph", "Ideographic"},
    162211: {"Unified_Ideograph", "Ideographic"},
    162212: {"Unified_Ideograph", "Ideographic"},
    162213: {"Unified_Ideograph", "Ideographic"},
    162214: {"Unified_Ideograph", "Ideographic"},
    162215: {"Unified_Ideograph", "Ideographic"},
    162216: {"Unified_Ideograph", "Ideographic"},
    162217: {"Unified_Ideograph", "Ideographic"},
    162218: {"Unified_Ideograph", "Ideographic"},
    162219: {"Unified_Ideograph", "Ideographic"},
    162220: {"Unified_Ideograph", "Ideographic"},
    162221: {"Unified_Ideograph", "Ideographic"},
    162222: {"Unified_Ideograph", "Ideographic"},
    162223: {"Unified_Ideograph", "Ideographic"},
    162224: {"Unified_Ideograph", "Ideographic"},
    162225: {"Unified_Ideograph", "Ideographic"},
    162226: {"Unified_Ideograph", "Ideographic"},
    162227: {"Unified_Ideograph", "Ideographic"},
    162228: {"Unified_Ideograph", "Ideographic"},
    162229: {"Unified_Ideograph", "Ideographic"},
    162230: {"Unified_Ideograph", "Ideographic"},
    162231: {"Unified_Ideograph", "Ideographic"},
    162232: {"Unified_Ideograph", "Ideographic"},
    162233: {"Unified_Ideograph", "Ideographic"},
    162234: {"Unified_Ideograph", "Ideographic"},
    162235: {"Unified_Ideograph", "Ideographic"},
    162236: {"Unified_Ideograph", "Ideographic"},
    162237: {"Unified_Ideograph", "Ideographic"},
    162238: {"Unified_Ideograph", "Ideographic"},
    162239: {"Unified_Ideograph", "Ideographic"},
    162240: {"Unified_Ideograph", "Ideographic"},
    162241: {"Unified_Ideograph", "Ideographic"},
    162242: {"Unified_Ideograph", "Ideographic"},
    162243: {"Unified_Ideograph", "Ideographic"},
    162244: {"Unified_Ideograph", "Ideographic"},
    162245: {"Unified_Ideograph", "Ideographic"},
    162246: {"Unified_Ideograph", "Ideographic"},
    162247: {"Unified_Ideograph", "Ideographic"},
    162248: {"Unified_Ideograph", "Ideographic"},
    162249: {"Unified_Ideograph", "Ideographic"},
    162250: {"Unified_Ideograph", "Ideographic"},
    162251: {"Unified_Ideograph", "Ideographic"},
    162252: {"Unified_Ideograph", "Ideographic"},
    162253: {"Unified_Ideograph", "Ideographic"},
    162254: {"Unified_Ideograph", "Ideographic"},
    162255: {"Unified_Ideograph", "Ideographic"},
    162256: {"Unified_Ideograph", "Ideographic"},
    162257: {"Unified_Ideograph", "Ideographic"},
    162258: {"Unified_Ideograph", "Ideographic"},
    162259: {"Unified_Ideograph", "Ideographic"},
    162260: {"Unified_Ideograph", "Ideographic"},
    162261: {"Unified_Ideograph", "Ideographic"},
    162262: {"Unified_Ideograph", "Ideographic"},
    162263: {"Unified_Ideograph", "Ideographic"},
    162264: {"Unified_Ideograph", "Ideographic"},
    162265: {"Unified_Ideograph", "Ideographic"},
    162266: {"Unified_Ideograph", "Ideographic"},
    162267: {"Unified_Ideograph", "Ideographic"},
    162268: {"Unified_Ideograph", "Ideographic"},
    162269: {"Unified_Ideograph", "Ideographic"},
    162270: {"Unified_Ideograph", "Ideographic"},
    162271: {"Unified_Ideograph", "Ideographic"},
    162272: {"Unified_Ideograph", "Ideographic"},
    162273: {"Unified_Ideograph", "Ideographic"},
    162274: {"Unified_Ideograph", "Ideographic"},
    162275: {"Unified_Ideograph", "Ideographic"},
    162276: {"Unified_Ideograph", "Ideographic"},
    162277: {"Unified_Ideograph", "Ideographic"},
    162278: {"Unified_Ideograph", "Ideographic"},
    162279: {"Unified_Ideograph", "Ideographic"},
    162280: {"Unified_Ideograph", "Ideographic"},
    162281: {"Unified_Ideograph", "Ideographic"},
    162282: {"Unified_Ideograph", "Ideographic"},
    162283: {"Unified_Ideograph", "Ideographic"},
    162284: {"Unified_Ideograph", "Ideographic"},
    162285: {"Unified_Ideograph", "Ideographic"},
    162286: {"Unified_Ideograph", "Ideographic"},
    162287: {"Unified_Ideograph", "Ideographic"},
    162288: {"Unified_Ideograph", "Ideographic"},
    162289: {"Unified_Ideograph", "Ideographic"},
    162290: {"Unified_Ideograph", "Ideographic"},
    162291: {"Unified_Ideograph", "Ideographic"},
    162292: {"Unified_Ideograph", "Ideographic"},
    162293: {"Unified_Ideograph", "Ideographic"},
    162294: {"Unified_Ideograph", "Ideographic"},
    162295: {"Unified_Ideograph", "Ideographic"},
    162296: {"Unified_Ideograph", "Ideographic"},
    162297: {"Unified_Ideograph", "Ideographic"},
    162298: {"Unified_Ideograph", "Ideographic"},
    162299: {"Unified_Ideograph", "Ideographic"},
    162300: {"Unified_Ideograph", "Ideographic"},
    162301: {"Unified_Ideograph", "Ideographic"},
    162302: {"Unified_Ideograph", "Ideographic"},
    162303: {"Unified_Ideograph", "Ideographic"},
    162304: {"Unified_Ideograph", "Ideographic"},
    162305: {"Unified_Ideograph", "Ideographic"},
    162306: {"Unified_Ideograph", "Ideographic"},
    162307: {"Unified_Ideograph", "Ideographic"},
    162308: {"Unified_Ideograph", "Ideographic"},
    162309: {"Unified_Ideograph", "Ideographic"},
    162310: {"Unified_Ideograph", "Ideographic"},
    162311: {"Unified_Ideograph", "Ideographic"},
    162312: {"Unified_Ideograph", "Ideographic"},
    162313: {"Unified_Ideograph", "Ideographic"},
    162314: {"Unified_Ideograph", "Ideographic"},
    162315: {"Unified_Ideograph", "Ideographic"},
    162316: {"Unified_Ideograph", "Ideographic"},
    162317: {"Unified_Ideograph", "Ideographic"},
    162318: {"Unified_Ideograph", "Ideographic"},
    162319: {"Unified_Ideograph", "Ideographic"},
    162320: {"Unified_Ideograph", "Ideographic"},
    162321: {"Unified_Ideograph", "Ideographic"},
    162322: {"Unified_Ideograph", "Ideographic"},
    162323: {"Unified_Ideograph", "Ideographic"},
    162324: {"Unified_Ideograph", "Ideographic"},
    162325: {"Unified_Ideograph", "Ideographic"},
    162326: {"Unified_Ideograph", "Ideographic"},
    162327: {"Unified_Ideograph", "Ideographic"},
    162328: {"Unified_Ideograph", "Ideographic"},
    162329: {"Unified_Ideograph", "Ideographic"},
    162330: {"Unified_Ideograph", "Ideographic"},
    162331: {"Unified_Ideograph", "Ideographic"},
    162332: {"Unified_Ideograph", "Ideographic"},
    162333: {"Unified_Ideograph", "Ideographic"},
    162334: {"Unified_Ideograph", "Ideographic"},
    162335: {"Unified_Ideograph", "Ideographic"},
    162336: {"Unified_Ideograph", "Ideographic"},
    162337: {"Unified_Ideograph", "Ideographic"},
    162338: {"Unified_Ideograph", "Ideographic"},
    162339: {"Unified_Ideograph", "Ideographic"},
    162340: {"Unified_Ideograph", "Ideographic"},
    162341: {"Unified_Ideograph", "Ideographic"},
    162342: {"Unified_Ideograph", "Ideographic"},
    162343: {"Unified_Ideograph", "Ideographic"},
    162344: {"Unified_Ideograph", "Ideographic"},
    162345: {"Unified_Ideograph", "Ideographic"},
    162346: {"Unified_Ideograph", "Ideographic"},
    162347: {"Unified_Ideograph", "Ideographic"},
    162348: {"Unified_Ideograph", "Ideographic"},
    162349: {"Unified_Ideograph", "Ideographic"},
    162350: {"Unified_Ideograph", "Ideographic"},
    162351: {"Unified_Ideograph", "Ideographic"},
    162352: {"Unified_Ideograph", "Ideographic"},
    162353: {"Unified_Ideograph", "Ideographic"},
    162354: {"Unified_Ideograph", "Ideographic"},
    162355: {"Unified_Ideograph", "Ideographic"},
    162356: {"Unified_Ideograph", "Ideographic"},
    162357: {"Unified_Ideograph", "Ideographic"},
    162358: {"Unified_Ideograph", "Ideographic"},
    162359: {"Unified_Ideograph", "Ideographic"},
    162360: {"Unified_Ideograph", "Ideographic"},
    162361: {"Unified_Ideograph", "Ideographic"},
    162362: {"Unified_Ideograph", "Ideographic"},
    162363: {"Unified_Ideograph", "Ideographic"},
    162364: {"Unified_Ideograph", "Ideographic"},
    162365: {"Unified_Ideograph", "Ideographic"},
    162366: {"Unified_Ideograph", "Ideographic"},
    162367: {"Unified_Ideograph", "Ideographic"},
    162368: {"Unified_Ideograph", "Ideographic"},
    162369: {"Unified_Ideograph", "Ideographic"},
    162370: {"Unified_Ideograph", "Ideographic"},
    162371: {"Unified_Ideograph", "Ideographic"},
    162372: {"Unified_Ideograph", "Ideographic"},
    162373: {"Unified_Ideograph", "Ideographic"},
    162374: {"Unified_Ideograph", "Ideographic"},
    162375: {"Unified_Ideograph", "Ideographic"},
    162376: {"Unified_Ideograph", "Ideographic"},
    162377: {"Unified_Ideograph", "Ideographic"},
    162378: {"Unified_Ideograph", "Ideographic"},
    162379: {"Unified_Ideograph", "Ideographic"},
    162380: {"Unified_Ideograph", "Ideographic"},
    162381: {"Unified_Ideograph", "Ideographic"},
    162382: {"Unified_Ideograph", "Ideographic"},
    162383: {"Unified_Ideograph", "Ideographic"},
    162384: {"Unified_Ideograph", "Ideographic"},
    162385: {"Unified_Ideograph", "Ideographic"},
    162386: {"Unified_Ideograph", "Ideographic"},
    162387: {"Unified_Ideograph", "Ideographic"},
    162388: {"Unified_Ideograph", "Ideographic"},
    162389: {"Unified_Ideograph", "Ideographic"},
    162390: {"Unified_Ideograph", "Ideographic"},
    162391: {"Unified_Ideograph", "Ideographic"},
    162392: {"Unified_Ideograph", "Ideographic"},
    162393: {"Unified_Ideograph", "Ideographic"},
    162394: {"Unified_Ideograph", "Ideographic"},
    162395: {"Unified_Ideograph", "Ideographic"},
    162396: {"Unified_Ideograph", "Ideographic"},
    162397: {"Unified_Ideograph", "Ideographic"},
    162398: {"Unified_Ideograph", "Ideographic"},
    162399: {"Unified_Ideograph", "Ideographic"},
    162400: {"Unified_Ideograph", "Ideographic"},
    162401: {"Unified_Ideograph", "Ideographic"},
    162402: {"Unified_Ideograph", "Ideographic"},
    162403: {"Unified_Ideograph", "Ideographic"},
    162404: {"Unified_Ideograph", "Ideographic"},
    162405: {"Unified_Ideograph", "Ideographic"},
    162406: {"Unified_Ideograph", "Ideographic"},
    162407: {"Unified_Ideograph", "Ideographic"},
    162408: {"Unified_Ideograph", "Ideographic"},
    162409: {"Unified_Ideograph", "Ideographic"},
    162410: {"Unified_Ideograph", "Ideographic"},
    162411: {"Unified_Ideograph", "Ideographic"},
    162412: {"Unified_Ideograph", "Ideographic"},
    162413: {"Unified_Ideograph", "Ideographic"},
    162414: {"Unified_Ideograph", "Ideographic"},
    162415: {"Unified_Ideograph", "Ideographic"},
    162416: {"Unified_Ideograph", "Ideographic"},
    162417: {"Unified_Ideograph", "Ideographic"},
    162418: {"Unified_Ideograph", "Ideographic"},
    162419: {"Unified_Ideograph", "Ideographic"},
    162420: {"Unified_Ideograph", "Ideographic"},
    162421: {"Unified_Ideograph", "Ideographic"},
    162422: {"Unified_Ideograph", "Ideographic"},
    162423: {"Unified_Ideograph", "Ideographic"},
    162424: {"Unified_Ideograph", "Ideographic"},
    162425: {"Unified_Ideograph", "Ideographic"},
    162426: {"Unified_Ideograph", "Ideographic"},
    162427: {"Unified_Ideograph", "Ideographic"},
    162428: {"Unified_Ideograph", "Ideographic"},
    162429: {"Unified_Ideograph", "Ideographic"},
    162430: {"Unified_Ideograph", "Ideographic"},
    162431: {"Unified_Ideograph", "Ideographic"},
    162432: {"Unified_Ideograph", "Ideographic"},
    162433: {"Unified_Ideograph", "Ideographic"},
    162434: {"Unified_Ideograph", "Ideographic"},
    162435: {"Unified_Ideograph", "Ideographic"},
    162436: {"Unified_Ideograph", "Ideographic"},
    162437: {"Unified_Ideograph", "Ideographic"},
    162438: {"Unified_Ideograph", "Ideographic"},
    162439: {"Unified_Ideograph", "Ideographic"},
    162440: {"Unified_Ideograph", "Ideographic"},
    162441: {"Unified_Ideograph", "Ideographic"},
    162442: {"Unified_Ideograph", "Ideographic"},
    162443: {"Unified_Ideograph", "Ideographic"},
    162444: {"Unified_Ideograph", "Ideographic"},
    162445: {"Unified_Ideograph", "Ideographic"},
    162446: {"Unified_Ideograph", "Ideographic"},
    162447: {"Unified_Ideograph", "Ideographic"},
    162448: {"Unified_Ideograph", "Ideographic"},
    162449: {"Unified_Ideograph", "Ideographic"},
    162450: {"Unified_Ideograph", "Ideographic"},
    162451: {"Unified_Ideograph", "Ideographic"},
    162452: {"Unified_Ideograph", "Ideographic"},
    162453: {"Unified_Ideograph", "Ideographic"},
    162454: {"Unified_Ideograph", "Ideographic"},
    162455: {"Unified_Ideograph", "Ideographic"},
    162456: {"Unified_Ideograph", "Ideographic"},
    162457: {"Unified_Ideograph", "Ideographic"},
    162458: {"Unified_Ideograph", "Ideographic"},
    162459: {"Unified_Ideograph", "Ideographic"},
    162460: {"Unified_Ideograph", "Ideographic"},
    162461: {"Unified_Ideograph", "Ideographic"},
    162462: {"Unified_Ideograph", "Ideographic"},
    162463: {"Unified_Ideograph", "Ideographic"},
    162464: {"Unified_Ideograph", "Ideographic"},
    162465: {"Unified_Ideograph", "Ideographic"},
    162466: {"Unified_Ideograph", "Ideographic"},
    162467: {"Unified_Ideograph", "Ideographic"},
    162468: {"Unified_Ideograph", "Ideographic"},
    162469: {"Unified_Ideograph", "Ideographic"},
    162470: {"Unified_Ideograph", "Ideographic"},
    162471: {"Unified_Ideograph", "Ideographic"},
    162472: {"Unified_Ideograph", "Ideographic"},
    162473: {"Unified_Ideograph", "Ideographic"},
    162474: {"Unified_Ideograph", "Ideographic"},
    162475: {"Unified_Ideograph", "Ideographic"},
    162476: {"Unified_Ideograph", "Ideographic"},
    162477: {"Unified_Ideograph", "Ideographic"},
    162478: {"Unified_Ideograph", "Ideographic"},
    162479: {"Unified_Ideograph", "Ideographic"},
    162480: {"Unified_Ideograph", "Ideographic"},
    162481: {"Unified_Ideograph", "Ideographic"},
    162482: {"Unified_Ideograph", "Ideographic"},
    162483: {"Unified_Ideograph", "Ideographic"},
    162484: {"Unified_Ideograph", "Ideographic"},
    162485: {"Unified_Ideograph", "Ideographic"},
    162486: {"Unified_Ideograph", "Ideographic"},
    162487: {"Unified_Ideograph", "Ideographic"},
    162488: {"Unified_Ideograph", "Ideographic"},
    162489: {"Unified_Ideograph", "Ideographic"},
    162490: {"Unified_Ideograph", "Ideographic"},
    162491: {"Unified_Ideograph", "Ideographic"},
    162492: {"Unified_Ideograph", "Ideographic"},
    162493: {"Unified_Ideograph", "Ideographic"},
    162494: {"Unified_Ideograph", "Ideographic"},
    162495: {"Unified_Ideograph", "Ideographic"},
    162496: {"Unified_Ideograph", "Ideographic"},
    162497: {"Unified_Ideograph", "Ideographic"},
    162498: {"Unified_Ideograph", "Ideographic"},
    162499: {"Unified_Ideograph", "Ideographic"},
    162500: {"Unified_Ideograph", "Ideographic"},
    162501: {"Unified_Ideograph", "Ideographic"},
    162502: {"Unified_Ideograph", "Ideographic"},
    162503: {"Unified_Ideograph", "Ideographic"},
    162504: {"Unified_Ideograph", "Ideographic"},
    162505: {"Unified_Ideograph", "Ideographic"},
    162506: {"Unified_Ideograph", "Ideographic"},
    162507: {"Unified_Ideograph", "Ideographic"},
    162508: {"Unified_Ideograph", "Ideographic"},
    162509: {"Unified_Ideograph", "Ideographic"},
    162510: {"Unified_Ideograph", "Ideographic"},
    162511: {"Unified_Ideograph", "Ideographic"},
    162512: {"Unified_Ideograph", "Ideographic"},
    162513: {"Unified_Ideograph", "Ideographic"},
    162514: {"Unified_Ideograph", "Ideographic"},
    162515: {"Unified_Ideograph", "Ideographic"},
    162516: {"Unified_Ideograph", "Ideographic"},
    162517: {"Unified_Ideograph", "Ideographic"},
    162518: {"Unified_Ideograph", "Ideographic"},
    162519: {"Unified_Ideograph", "Ideographic"},
    162520: {"Unified_Ideograph", "Ideographic"},
    162521: {"Unified_Ideograph", "Ideographic"},
    162522: {"Unified_Ideograph", "Ideographic"},
    162523: {"Unified_Ideograph", "Ideographic"},
    162524: {"Unified_Ideograph", "Ideographic"},
    162525: {"Unified_Ideograph", "Ideographic"},
    162526: {"Unified_Ideograph", "Ideographic"},
    162527: {"Unified_Ideograph", "Ideographic"},
    162528: {"Unified_Ideograph", "Ideographic"},
    162529: {"Unified_Ideograph", "Ideographic"},
    162530: {"Unified_Ideograph", "Ideographic"},
    162531: {"Unified_Ideograph", "Ideographic"},
    162532: {"Unified_Ideograph", "Ideographic"},
    162533: {"Unified_Ideograph", "Ideographic"},
    162534: {"Unified_Ideograph", "Ideographic"},
    162535: {"Unified_Ideograph", "Ideographic"},
    162536: {"Unified_Ideograph", "Ideographic"},
    162537: {"Unified_Ideograph", "Ideographic"},
    162538: {"Unified_Ideograph", "Ideographic"},
    162539: {"Unified_Ideograph", "Ideographic"},
    162540: {"Unified_Ideograph", "Ideographic"},
    162541: {"Unified_Ideograph", "Ideographic"},
    162542: {"Unified_Ideograph", "Ideographic"},
    162543: {"Unified_Ideograph", "Ideographic"},
    162544: {"Unified_Ideograph", "Ideographic"},
    162545: {"Unified_Ideograph", "Ideographic"},
    162546: {"Unified_Ideograph", "Ideographic"},
    162547: {"Unified_Ideograph", "Ideographic"},
    162548: {"Unified_Ideograph", "Ideographic"},
    162549: {"Unified_Ideograph", "Ideographic"},
    162550: {"Unified_Ideograph", "Ideographic"},
    162551: {"Unified_Ideograph", "Ideographic"},
    162552: {"Unified_Ideograph", "Ideographic"},
    162553: {"Unified_Ideograph", "Ideographic"},
    162554: {"Unified_Ideograph", "Ideographic"},
    162555: {"Unified_Ideograph", "Ideographic"},
    162556: {"Unified_Ideograph", "Ideographic"},
    162557: {"Unified_Ideograph", "Ideographic"},
    162558: {"Unified_Ideograph", "Ideographic"},
    162559: {"Unified_Ideograph", "Ideographic"},
    162560: {"Unified_Ideograph", "Ideographic"},
    162561: {"Unified_Ideograph", "Ideographic"},
    162562: {"Unified_Ideograph", "Ideographic"},
    162563: {"Unified_Ideograph", "Ideographic"},
    162564: {"Unified_Ideograph", "Ideographic"},
    162565: {"Unified_Ideograph", "Ideographic"},
    162566: {"Unified_Ideograph", "Ideographic"},
    162567: {"Unified_Ideograph", "Ideographic"},
    162568: {"Unified_Ideograph", "Ideographic"},
    162569: {"Unified_Ideograph", "Ideographic"},
    162570: {"Unified_Ideograph", "Ideographic"},
    162571: {"Unified_Ideograph", "Ideographic"},
    162572: {"Unified_Ideograph", "Ideographic"},
    162573: {"Unified_Ideograph", "Ideographic"},
    162574: {"Unified_Ideograph", "Ideographic"},
    162575: {"Unified_Ideograph", "Ideographic"},
    162576: {"Unified_Ideograph", "Ideographic"},
    162577: {"Unified_Ideograph", "Ideographic"},
    162578: {"Unified_Ideograph", "Ideographic"},
    162579: {"Unified_Ideograph", "Ideographic"},
    162580: {"Unified_Ideograph", "Ideographic"},
    162581: {"Unified_Ideograph", "Ideographic"},
    162582: {"Unified_Ideograph", "Ideographic"},
    162583: {"Unified_Ideograph", "Ideographic"},
    162584: {"Unified_Ideograph", "Ideographic"},
    162585: {"Unified_Ideograph", "Ideographic"},
    162586: {"Unified_Ideograph", "Ideographic"},
    162587: {"Unified_Ideograph", "Ideographic"},
    162588: {"Unified_Ideograph", "Ideographic"},
    162589: {"Unified_Ideograph", "Ideographic"},
    162590: {"Unified_Ideograph", "Ideographic"},
    162591: {"Unified_Ideograph", "Ideographic"},
    162592: {"Unified_Ideograph", "Ideographic"},
    162593: {"Unified_Ideograph", "Ideographic"},
    162594: {"Unified_Ideograph", "Ideographic"},
    162595: {"Unified_Ideograph", "Ideographic"},
    162596: {"Unified_Ideograph", "Ideographic"},
    162597: {"Unified_Ideograph", "Ideographic"},
    162598: {"Unified_Ideograph", "Ideographic"},
    162599: {"Unified_Ideograph", "Ideographic"},
    162600: {"Unified_Ideograph", "Ideographic"},
    162601: {"Unified_Ideograph", "Ideographic"},
    162602: {"Unified_Ideograph", "Ideographic"},
    162603: {"Unified_Ideograph", "Ideographic"},
    162604: {"Unified_Ideograph", "Ideographic"},
    162605: {"Unified_Ideograph", "Ideographic"},
    162606: {"Unified_Ideograph", "Ideographic"},
    162607: {"Unified_Ideograph", "Ideographic"},
    162608: {"Unified_Ideograph", "Ideographic"},
    162609: {"Unified_Ideograph", "Ideographic"},
    162610: {"Unified_Ideograph", "Ideographic"},
    162611: {"Unified_Ideograph", "Ideographic"},
    162612: {"Unified_Ideograph", "Ideographic"},
    162613: {"Unified_Ideograph", "Ideographic"},
    162614: {"Unified_Ideograph", "Ideographic"},
    162615: {"Unified_Ideograph", "Ideographic"},
    162616: {"Unified_Ideograph", "Ideographic"},
    162617: {"Unified_Ideograph", "Ideographic"},
    162618: {"Unified_Ideograph", "Ideographic"},
    162619: {"Unified_Ideograph", "Ideographic"},
    162620: {"Unified_Ideograph", "Ideographic"},
    162621: {"Unified_Ideograph", "Ideographic"},
    162622: {"Unified_Ideograph", "Ideographic"},
    162623: {"Unified_Ideograph", "Ideographic"},
    162624: {"Unified_Ideograph", "Ideographic"},
    162625: {"Unified_Ideograph", "Ideographic"},
    162626: {"Unified_Ideograph", "Ideographic"},
    162627: {"Unified_Ideograph", "Ideographic"},
    162628: {"Unified_Ideograph", "Ideographic"},
    162629: {"Unified_Ideograph", "Ideographic"},
    162630: {"Unified_Ideograph", "Ideographic"},
    162631: {"Unified_Ideograph", "Ideographic"},
    162632: {"Unified_Ideograph", "Ideographic"},
    162633: {"Unified_Ideograph", "Ideographic"},
    162634: {"Unified_Ideograph", "Ideographic"},
    162635: {"Unified_Ideograph", "Ideographic"},
    162636: {"Unified_Ideograph", "Ideographic"},
    162637: {"Unified_Ideograph", "Ideographic"},
    162638: {"Unified_Ideograph", "Ideographic"},
    162639: {"Unified_Ideograph", "Ideographic"},
    162640: {"Unified_Ideograph", "Ideographic"},
    162641: {"Unified_Ideograph", "Ideographic"},
    162642: {"Unified_Ideograph", "Ideographic"},
    162643: {"Unified_Ideograph", "Ideographic"},
    162644: {"Unified_Ideograph", "Ideographic"},
    162645: {"Unified_Ideograph", "Ideographic"},
    162646: {"Unified_Ideograph", "Ideographic"},
    162647: {"Unified_Ideograph", "Ideographic"},
    162648: {"Unified_Ideograph", "Ideographic"},
    162649: {"Unified_Ideograph", "Ideographic"},
    162650: {"Unified_Ideograph", "Ideographic"},
    162651: {"Unified_Ideograph", "Ideographic"},
    162652: {"Unified_Ideograph", "Ideographic"},
    162653: {"Unified_Ideograph", "Ideographic"},
    162654: {"Unified_Ideograph", "Ideographic"},
    162655: {"Unified_Ideograph", "Ideographic"},
    162656: {"Unified_Ideograph", "Ideographic"},
    162657: {"Unified_Ideograph", "Ideographic"},
    162658: {"Unified_Ideograph", "Ideographic"},
    162659: {"Unified_Ideograph", "Ideographic"},
    162660: {"Unified_Ideograph", "Ideographic"},
    162661: {"Unified_Ideograph", "Ideographic"},
    162662: {"Unified_Ideograph", "Ideographic"},
    162663: {"Unified_Ideograph", "Ideographic"},
    162664: {"Unified_Ideograph", "Ideographic"},
    162665: {"Unified_Ideograph", "Ideographic"},
    162666: {"Unified_Ideograph", "Ideographic"},
    162667: {"Unified_Ideograph", "Ideographic"},
    162668: {"Unified_Ideograph", "Ideographic"},
    162669: {"Unified_Ideograph", "Ideographic"},
    162670: {"Unified_Ideograph", "Ideographic"},
    162671: {"Unified_Ideograph", "Ideographic"},
    162672: {"Unified_Ideograph", "Ideographic"},
    162673: {"Unified_Ideograph", "Ideographic"},
    162674: {"Unified_Ideograph", "Ideographic"},
    162675: {"Unified_Ideograph", "Ideographic"},
    162676: {"Unified_Ideograph", "Ideographic"},
    162677: {"Unified_Ideograph", "Ideographic"},
    162678: {"Unified_Ideograph", "Ideographic"},
    162679: {"Unified_Ideograph", "Ideographic"},
    162680: {"Unified_Ideograph", "Ideographic"},
    162681: {"Unified_Ideograph", "Ideographic"},
    162682: {"Unified_Ideograph", "Ideographic"},
    162683: {"Unified_Ideograph", "Ideographic"},
    162684: {"Unified_Ideograph", "Ideographic"},
    162685: {"Unified_Ideograph", "Ideographic"},
    162686: {"Unified_Ideograph", "Ideographic"},
    162687: {"Unified_Ideograph", "Ideographic"},
    162688: {"Unified_Ideograph", "Ideographic"},
    162689: {"Unified_Ideograph", "Ideographic"},
    162690: {"Unified_Ideograph", "Ideographic"},
    162691: {"Unified_Ideograph", "Ideographic"},
    162692: {"Unified_Ideograph", "Ideographic"},
    162693: {"Unified_Ideograph", "Ideographic"},
    162694: {"Unified_Ideograph", "Ideographic"},
    162695: {"Unified_Ideograph", "Ideographic"},
    162696: {"Unified_Ideograph", "Ideographic"},
    162697: {"Unified_Ideograph", "Ideographic"},
    162698: {"Unified_Ideograph", "Ideographic"},
    162699: {"Unified_Ideograph", "Ideographic"},
    162700: {"Unified_Ideograph", "Ideographic"},
    162701: {"Unified_Ideograph", "Ideographic"},
    162702: {"Unified_Ideograph", "Ideographic"},
    162703: {"Unified_Ideograph", "Ideographic"},
    162704: {"Unified_Ideograph", "Ideographic"},
    162705: {"Unified_Ideograph", "Ideographic"},
    162706: {"Unified_Ideograph", "Ideographic"},
    162707: {"Unified_Ideograph", "Ideographic"},
    162708: {"Unified_Ideograph", "Ideographic"},
    162709: {"Unified_Ideograph", "Ideographic"},
    162710: {"Unified_Ideograph", "Ideographic"},
    162711: {"Unified_Ideograph", "Ideographic"},
    162712: {"Unified_Ideograph", "Ideographic"},
    162713: {"Unified_Ideograph", "Ideographic"},
    162714: {"Unified_Ideograph", "Ideographic"},
    162715: {"Unified_Ideograph", "Ideographic"},
    162716: {"Unified_Ideograph", "Ideographic"},
    162717: {"Unified_Ideograph", "Ideographic"},
    162718: {"Unified_Ideograph", "Ideographic"},
    162719: {"Unified_Ideograph", "Ideographic"},
    162720: {"Unified_Ideograph", "Ideographic"},
    162721: {"Unified_Ideograph", "Ideographic"},
    162722: {"Unified_Ideograph", "Ideographic"},
    162723: {"Unified_Ideograph", "Ideographic"},
    162724: {"Unified_Ideograph", "Ideographic"},
    162725: {"Unified_Ideograph", "Ideographic"},
    162726: {"Unified_Ideograph", "Ideographic"},
    162727: {"Unified_Ideograph", "Ideographic"},
    162728: {"Unified_Ideograph", "Ideographic"},
    162729: {"Unified_Ideograph", "Ideographic"},
    162730: {"Unified_Ideograph", "Ideographic"},
    162731: {"Unified_Ideograph", "Ideographic"},
    162732: {"Unified_Ideograph", "Ideographic"},
    162733: {"Unified_Ideograph", "Ideographic"},
    162734: {"Unified_Ideograph", "Ideographic"},
    162735: {"Unified_Ideograph", "Ideographic"},
    162736: {"Unified_Ideograph", "Ideographic"},
    162737: {"Unified_Ideograph", "Ideographic"},
    162738: {"Unified_Ideograph", "Ideographic"},
    162739: {"Unified_Ideograph", "Ideographic"},
    162740: {"Unified_Ideograph", "Ideographic"},
    162741: {"Unified_Ideograph", "Ideographic"},
    162742: {"Unified_Ideograph", "Ideographic"},
    162743: {"Unified_Ideograph", "Ideographic"},
    162744: {"Unified_Ideograph", "Ideographic"},
    162745: {"Unified_Ideograph", "Ideographic"},
    162746: {"Unified_Ideograph", "Ideographic"},
    162747: {"Unified_Ideograph", "Ideographic"},
    162748: {"Unified_Ideograph", "Ideographic"},
    162749: {"Unified_Ideograph", "Ideographic"},
    162750: {"Unified_Ideograph", "Ideographic"},
    162751: {"Unified_Ideograph", "Ideographic"},
    162752: {"Unified_Ideograph", "Ideographic"},
    162753: {"Unified_Ideograph", "Ideographic"},
    162754: {"Unified_Ideograph", "Ideographic"},
    162755: {"Unified_Ideograph", "Ideographic"},
    162756: {"Unified_Ideograph", "Ideographic"},
    162757: {"Unified_Ideograph", "Ideographic"},
    162758: {"Unified_Ideograph", "Ideographic"},
    162759: {"Unified_Ideograph", "Ideographic"},
    162760: {"Unified_Ideograph", "Ideographic"},
    162761: {"Unified_Ideograph", "Ideographic"},
    162762: {"Unified_Ideograph", "Ideographic"},
    162763: {"Unified_Ideograph", "Ideographic"},
    162764: {"Unified_Ideograph", "Ideographic"},
    162765: {"Unified_Ideograph", "Ideographic"},
    162766: {"Unified_Ideograph", "Ideographic"},
    162767: {"Unified_Ideograph", "Ideographic"},
    162768: {"Unified_Ideograph", "Ideographic"},
    162769: {"Unified_Ideograph", "Ideographic"},
    162770: {"Unified_Ideograph", "Ideographic"},
    162771: {"Unified_Ideograph", "Ideographic"},
    162772: {"Unified_Ideograph", "Ideographic"},
    162773: {"Unified_Ideograph", "Ideographic"},
    162774: {"Unified_Ideograph", "Ideographic"},
    162775: {"Unified_Ideograph", "Ideographic"},
    162776: {"Unified_Ideograph", "Ideographic"},
    162777: {"Unified_Ideograph", "Ideographic"},
    162778: {"Unified_Ideograph", "Ideographic"},
    162779: {"Unified_Ideograph", "Ideographic"},
    162780: {"Unified_Ideograph", "Ideographic"},
    162781: {"Unified_Ideograph", "Ideographic"},
    162782: {"Unified_Ideograph", "Ideographic"},
    162783: {"Unified_Ideograph", "Ideographic"},
    162784: {"Unified_Ideograph", "Ideographic"},
    162785: {"Unified_Ideograph", "Ideographic"},
    162786: {"Unified_Ideograph", "Ideographic"},
    162787: {"Unified_Ideograph", "Ideographic"},
    162788: {"Unified_Ideograph", "Ideographic"},
    162789: {"Unified_Ideograph", "Ideographic"},
    162790: {"Unified_Ideograph", "Ideographic"},
    162791: {"Unified_Ideograph", "Ideographic"},
    162792: {"Unified_Ideograph", "Ideographic"},
    162793: {"Unified_Ideograph", "Ideographic"},
    162794: {"Unified_Ideograph", "Ideographic"},
    162795: {"Unified_Ideograph", "Ideographic"},
    162796: {"Unified_Ideograph", "Ideographic"},
    162797: {"Unified_Ideograph", "Ideographic"},
    162798: {"Unified_Ideograph", "Ideographic"},
    162799: {"Unified_Ideograph", "Ideographic"},
    162800: {"Unified_Ideograph", "Ideographic"},
    162801: {"Unified_Ideograph", "Ideographic"},
    162802: {"Unified_Ideograph", "Ideographic"},
    162803: {"Unified_Ideograph", "Ideographic"},
    162804: {"Unified_Ideograph", "Ideographic"},
    162805: {"Unified_Ideograph", "Ideographic"},
    162806: {"Unified_Ideograph", "Ideographic"},
    162807: {"Unified_Ideograph", "Ideographic"},
    162808: {"Unified_Ideograph", "Ideographic"},
    162809: {"Unified_Ideograph", "Ideographic"},
    162810: {"Unified_Ideograph", "Ideographic"},
    162811: {"Unified_Ideograph", "Ideographic"},
    162812: {"Unified_Ideograph", "Ideographic"},
    162813: {"Unified_Ideograph", "Ideographic"},
    162814: {"Unified_Ideograph", "Ideographic"},
    162815: {"Unified_Ideograph", "Ideographic"},
    162816: {"Unified_Ideograph", "Ideographic"},
    162817: {"Unified_Ideograph", "Ideographic"},
    162818: {"Unified_Ideograph", "Ideographic"},
    162819: {"Unified_Ideograph", "Ideographic"},
    162820: {"Unified_Ideograph", "Ideographic"},
    162821: {"Unified_Ideograph", "Ideographic"},
    162822: {"Unified_Ideograph", "Ideographic"},
    162823: {"Unified_Ideograph", "Ideographic"},
    162824: {"Unified_Ideograph", "Ideographic"},
    162825: {"Unified_Ideograph", "Ideographic"},
    162826: {"Unified_Ideograph", "Ideographic"},
    162827: {"Unified_Ideograph", "Ideographic"},
    162828: {"Unified_Ideograph", "Ideographic"},
    162829: {"Unified_Ideograph", "Ideographic"},
    162830: {"Unified_Ideograph", "Ideographic"},
    162831: {"Unified_Ideograph", "Ideographic"},
    162832: {"Unified_Ideograph", "Ideographic"},
    162833: {"Unified_Ideograph", "Ideographic"},
    162834: {"Unified_Ideograph", "Ideographic"},
    162835: {"Unified_Ideograph", "Ideographic"},
    162836: {"Unified_Ideograph", "Ideographic"},
    162837: {"Unified_Ideograph", "Ideographic"},
    162838: {"Unified_Ideograph", "Ideographic"},
    162839: {"Unified_Ideograph", "Ideographic"},
    162840: {"Unified_Ideograph", "Ideographic"},
    162841: {"Unified_Ideograph", "Ideographic"},
    162842: {"Unified_Ideograph", "Ideographic"},
    162843: {"Unified_Ideograph", "Ideographic"},
    162844: {"Unified_Ideograph", "Ideographic"},
    162845: {"Unified_Ideograph", "Ideographic"},
    162846: {"Unified_Ideograph", "Ideographic"},
    162847: {"Unified_Ideograph", "Ideographic"},
    162848: {"Unified_Ideograph", "Ideographic"},
    162849: {"Unified_Ideograph", "Ideographic"},
    162850: {"Unified_Ideograph", "Ideographic"},
    162851: {"Unified_Ideograph", "Ideographic"},
    162852: {"Unified_Ideograph", "Ideographic"},
    162853: {"Unified_Ideograph", "Ideographic"},
    162854: {"Unified_Ideograph", "Ideographic"},
    162855: {"Unified_Ideograph", "Ideographic"},
    162856: {"Unified_Ideograph", "Ideographic"},
    162857: {"Unified_Ideograph", "Ideographic"},
    162858: {"Unified_Ideograph", "Ideographic"},
    162859: {"Unified_Ideograph", "Ideographic"},
    162860: {"Unified_Ideograph", "Ideographic"},
    162861: {"Unified_Ideograph", "Ideographic"},
    162862: {"Unified_Ideograph", "Ideographic"},
    162863: {"Unified_Ideograph", "Ideographic"},
    162864: {"Unified_Ideograph", "Ideographic"},
    162865: {"Unified_Ideograph", "Ideographic"},
    162866: {"Unified_Ideograph", "Ideographic"},
    162867: {"Unified_Ideograph", "Ideographic"},
    162868: {"Unified_Ideograph", "Ideographic"},
    162869: {"Unified_Ideograph", "Ideographic"},
    162870: {"Unified_Ideograph", "Ideographic"},
    162871: {"Unified_Ideograph", "Ideographic"},
    162872: {"Unified_Ideograph", "Ideographic"},
    162873: {"Unified_Ideograph", "Ideographic"},
    162874: {"Unified_Ideograph", "Ideographic"},
    162875: {"Unified_Ideograph", "Ideographic"},
    162876: {"Unified_Ideograph", "Ideographic"},
    162877: {"Unified_Ideograph", "Ideographic"},
    162878: {"Unified_Ideograph", "Ideographic"},
    162879: {"Unified_Ideograph", "Ideographic"},
    162880: {"Unified_Ideograph", "Ideographic"},
    162881: {"Unified_Ideograph", "Ideographic"},
    162882: {"Unified_Ideograph", "Ideographic"},
    162883: {"Unified_Ideograph", "Ideographic"},
    162884: {"Unified_Ideograph", "Ideographic"},
    162885: {"Unified_Ideograph", "Ideographic"},
    162886: {"Unified_Ideograph", "Ideographic"},
    162887: {"Unified_Ideograph", "Ideographic"},
    162888: {"Unified_Ideograph", "Ideographic"},
    162889: {"Unified_Ideograph", "Ideographic"},
    162890: {"Unified_Ideograph", "Ideographic"},
    162891: {"Unified_Ideograph", "Ideographic"},
    162892: {"Unified_Ideograph", "Ideographic"},
    162893: {"Unified_Ideograph", "Ideographic"},
    162894: {"Unified_Ideograph", "Ideographic"},
    162895: {"Unified_Ideograph", "Ideographic"},
    162896: {"Unified_Ideograph", "Ideographic"},
    162897: {"Unified_Ideograph", "Ideographic"},
    162898: {"Unified_Ideograph", "Ideographic"},
    162899: {"Unified_Ideograph", "Ideographic"},
    162900: {"Unified_Ideograph", "Ideographic"},
    162901: {"Unified_Ideograph", "Ideographic"},
    162902: {"Unified_Ideograph", "Ideographic"},
    162903: {"Unified_Ideograph", "Ideographic"},
    162904: {"Unified_Ideograph", "Ideographic"},
    162905: {"Unified_Ideograph", "Ideographic"},
    162906: {"Unified_Ideograph", "Ideographic"},
    162907: {"Unified_Ideograph", "Ideographic"},
    162908: {"Unified_Ideograph", "Ideographic"},
    162909: {"Unified_Ideograph", "Ideographic"},
    162910: {"Unified_Ideograph", "Ideographic"},
    162911: {"Unified_Ideograph", "Ideographic"},
    162912: {"Unified_Ideograph", "Ideographic"},
    162913: {"Unified_Ideograph", "Ideographic"},
    162914: {"Unified_Ideograph", "Ideographic"},
    162915: {"Unified_Ideograph", "Ideographic"},
    162916: {"Unified_Ideograph", "Ideographic"},
    162917: {"Unified_Ideograph", "Ideographic"},
    162918: {"Unified_Ideograph", "Ideographic"},
    162919: {"Unified_Ideograph", "Ideographic"},
    162920: {"Unified_Ideograph", "Ideographic"},
    162921: {"Unified_Ideograph", "Ideographic"},
    162922: {"Unified_Ideograph", "Ideographic"},
    162923: {"Unified_Ideograph", "Ideographic"},
    162924: {"Unified_Ideograph", "Ideographic"},
    162925: {"Unified_Ideograph", "Ideographic"},
    162926: {"Unified_Ideograph", "Ideographic"},
    162927: {"Unified_Ideograph", "Ideographic"},
    162928: {"Unified_Ideograph", "Ideographic"},
    162929: {"Unified_Ideograph", "Ideographic"},
    162930: {"Unified_Ideograph", "Ideographic"},
    162931: {"Unified_Ideograph", "Ideographic"},
    162932: {"Unified_Ideograph", "Ideographic"},
    162933: {"Unified_Ideograph", "Ideographic"},
    162934: {"Unified_Ideograph", "Ideographic"},
    162935: {"Unified_Ideograph", "Ideographic"},
    162936: {"Unified_Ideograph", "Ideographic"},
    162937: {"Unified_Ideograph", "Ideographic"},
    162938: {"Unified_Ideograph", "Ideographic"},
    162939: {"Unified_Ideograph", "Ideographic"},
    162940: {"Unified_Ideograph", "Ideographic"},
    162941: {"Unified_Ideograph", "Ideographic"},
    162942: {"Unified_Ideograph", "Ideographic"},
    162943: {"Unified_Ideograph", "Ideographic"},
    162944: {"Unified_Ideograph", "Ideographic"},
    162945: {"Unified_Ideograph", "Ideographic"},
    162946: {"Unified_Ideograph", "Ideographic"},
    162947: {"Unified_Ideograph", "Ideographic"},
    162948: {"Unified_Ideograph", "Ideographic"},
    162949: {"Unified_Ideograph", "Ideographic"},
    162950: {"Unified_Ideograph", "Ideographic"},
    162951: {"Unified_Ideograph", "Ideographic"},
    162952: {"Unified_Ideograph", "Ideographic"},
    162953: {"Unified_Ideograph", "Ideographic"},
    162954: {"Unified_Ideograph", "Ideographic"},
    162955: {"Unified_Ideograph", "Ideographic"},
    162956: {"Unified_Ideograph", "Ideographic"},
    162957: {"Unified_Ideograph", "Ideographic"},
    162958: {"Unified_Ideograph", "Ideographic"},
    162959: {"Unified_Ideograph", "Ideographic"},
    162960: {"Unified_Ideograph", "Ideographic"},
    162961: {"Unified_Ideograph", "Ideographic"},
    162962: {"Unified_Ideograph", "Ideographic"},
    162963: {"Unified_Ideograph", "Ideographic"},
    162964: {"Unified_Ideograph", "Ideographic"},
    162965: {"Unified_Ideograph", "Ideographic"},
    162966: {"Unified_Ideograph", "Ideographic"},
    162967: {"Unified_Ideograph", "Ideographic"},
    162968: {"Unified_Ideograph", "Ideographic"},
    162969: {"Unified_Ideograph", "Ideographic"},
    162970: {"Unified_Ideograph", "Ideographic"},
    162971: {"Unified_Ideograph", "Ideographic"},
    162972: {"Unified_Ideograph", "Ideographic"},
    162973: {"Unified_Ideograph", "Ideographic"},
    162974: {"Unified_Ideograph", "Ideographic"},
    162975: {"Unified_Ideograph", "Ideographic"},
    162976: {"Unified_Ideograph", "Ideographic"},
    162977: {"Unified_Ideograph", "Ideographic"},
    162978: {"Unified_Ideograph", "Ideographic"},
    162979: {"Unified_Ideograph", "Ideographic"},
    162980: {"Unified_Ideograph", "Ideographic"},
    162981: {"Unified_Ideograph", "Ideographic"},
    162982: {"Unified_Ideograph", "Ideographic"},
    162983: {"Unified_Ideograph", "Ideographic"},
    162984: {"Unified_Ideograph", "Ideographic"},
    162985: {"Unified_Ideograph", "Ideographic"},
    162986: {"Unified_Ideograph", "Ideographic"},
    162987: {"Unified_Ideograph", "Ideographic"},
    162988: {"Unified_Ideograph", "Ideographic"},
    162989: {"Unified_Ideograph", "Ideographic"},
    162990: {"Unified_Ideograph", "Ideographic"},
    162991: {"Unified_Ideograph", "Ideographic"},
    162992: {"Unified_Ideograph", "Ideographic"},
    162993: {"Unified_Ideograph", "Ideographic"},
    162994: {"Unified_Ideograph", "Ideographic"},
    162995: {"Unified_Ideograph", "Ideographic"},
    162996: {"Unified_Ideograph", "Ideographic"},
    162997: {"Unified_Ideograph", "Ideographic"},
    162998: {"Unified_Ideograph", "Ideographic"},
    162999: {"Unified_Ideograph", "Ideographic"},
    163000: {"Unified_Ideograph", "Ideographic"},
    163001: {"Unified_Ideograph", "Ideographic"},
    163002: {"Unified_Ideograph", "Ideographic"},
    163003: {"Unified_Ideograph", "Ideographic"},
    163004: {"Unified_Ideograph", "Ideographic"},
    163005: {"Unified_Ideograph", "Ideographic"},
    163006: {"Unified_Ideograph", "Ideographic"},
    163007: {"Unified_Ideograph", "Ideographic"},
    163008: {"Unified_Ideograph", "Ideographic"},
    163009: {"Unified_Ideograph", "Ideographic"},
    163010: {"Unified_Ideograph", "Ideographic"},
    163011: {"Unified_Ideograph", "Ideographic"},
    163012: {"Unified_Ideograph", "Ideographic"},
    163013: {"Unified_Ideograph", "Ideographic"},
    163014: {"Unified_Ideograph", "Ideographic"},
    163015: {"Unified_Ideograph", "Ideographic"},
    163016: {"Unified_Ideograph", "Ideographic"},
    163017: {"Unified_Ideograph", "Ideographic"},
    163018: {"Unified_Ideograph", "Ideographic"},
    163019: {"Unified_Ideograph", "Ideographic"},
    163020: {"Unified_Ideograph", "Ideographic"},
    163021: {"Unified_Ideograph", "Ideographic"},
    163022: {"Unified_Ideograph", "Ideographic"},
    163023: {"Unified_Ideograph", "Ideographic"},
    163024: {"Unified_Ideograph", "Ideographic"},
    163025: {"Unified_Ideograph", "Ideographic"},
    163026: {"Unified_Ideograph", "Ideographic"},
    163027: {"Unified_Ideograph", "Ideographic"},
    163028: {"Unified_Ideograph", "Ideographic"},
    163029: {"Unified_Ideograph", "Ideographic"},
    163030: {"Unified_Ideograph", "Ideographic"},
    163031: {"Unified_Ideograph", "Ideographic"},
    163032: {"Unified_Ideograph", "Ideographic"},
    163033: {"Unified_Ideograph", "Ideographic"},
    163034: {"Unified_Ideograph", "Ideographic"},
    163035: {"Unified_Ideograph", "Ideographic"},
    163036: {"Unified_Ideograph", "Ideographic"},
    163037: {"Unified_Ideograph", "Ideographic"},
    163038: {"Unified_Ideograph", "Ideographic"},
    163039: {"Unified_Ideograph", "Ideographic"},
    163040: {"Unified_Ideograph", "Ideographic"},
    163041: {"Unified_Ideograph", "Ideographic"},
    163042: {"Unified_Ideograph", "Ideographic"},
    163043: {"Unified_Ideograph", "Ideographic"},
    163044: {"Unified_Ideograph", "Ideographic"},
    163045: {"Unified_Ideograph", "Ideographic"},
    163046: {"Unified_Ideograph", "Ideographic"},
    163047: {"Unified_Ideograph", "Ideographic"},
    163048: {"Unified_Ideograph", "Ideographic"},
    163049: {"Unified_Ideograph", "Ideographic"},
    163050: {"Unified_Ideograph", "Ideographic"},
    163051: {"Unified_Ideograph", "Ideographic"},
    163052: {"Unified_Ideograph", "Ideographic"},
    163053: {"Unified_Ideograph", "Ideographic"},
    163054: {"Unified_Ideograph", "Ideographic"},
    163055: {"Unified_Ideograph", "Ideographic"},
    163056: {"Unified_Ideograph", "Ideographic"},
    163057: {"Unified_Ideograph", "Ideographic"},
    163058: {"Unified_Ideograph", "Ideographic"},
    163059: {"Unified_Ideograph", "Ideographic"},
    163060: {"Unified_Ideograph", "Ideographic"},
    163061: {"Unified_Ideograph", "Ideographic"},
    163062: {"Unified_Ideograph", "Ideographic"},
    163063: {"Unified_Ideograph", "Ideographic"},
    163064: {"Unified_Ideograph", "Ideographic"},
    163065: {"Unified_Ideograph", "Ideographic"},
    163066: {"Unified_Ideograph", "Ideographic"},
    163067: {"Unified_Ideograph", "Ideographic"},
    163068: {"Unified_Ideograph", "Ideographic"},
    163069: {"Unified_Ideograph", "Ideographic"},
    163070: {"Unified_Ideograph", "Ideographic"},
    163071: {"Unified_Ideograph", "Ideographic"},
    163072: {"Unified_Ideograph", "Ideographic"},
    163073: {"Unified_Ideograph", "Ideographic"},
    163074: {"Unified_Ideograph", "Ideographic"},
    163075: {"Unified_Ideograph", "Ideographic"},
    163076: {"Unified_Ideograph", "Ideographic"},
    163077: {"Unified_Ideograph", "Ideographic"},
    163078: {"Unified_Ideograph", "Ideographic"},
    163079: {"Unified_Ideograph", "Ideographic"},
    163080: {"Unified_Ideograph", "Ideographic"},
    163081: {"Unified_Ideograph", "Ideographic"},
    163082: {"Unified_Ideograph", "Ideographic"},
    163083: {"Unified_Ideograph", "Ideographic"},
    163084: {"Unified_Ideograph", "Ideographic"},
    163085: {"Unified_Ideograph", "Ideographic"},
    163086: {"Unified_Ideograph", "Ideographic"},
    163087: {"Unified_Ideograph", "Ideographic"},
    163088: {"Unified_Ideograph", "Ideographic"},
    163089: {"Unified_Ideograph", "Ideographic"},
    163090: {"Unified_Ideograph", "Ideographic"},
    163091: {"Unified_Ideograph", "Ideographic"},
    163092: {"Unified_Ideograph", "Ideographic"},
    163093: {"Unified_Ideograph", "Ideographic"},
    163094: {"Unified_Ideograph", "Ideographic"},
    163095: {"Unified_Ideograph", "Ideographic"},
    163096: {"Unified_Ideograph", "Ideographic"},
    163097: {"Unified_Ideograph", "Ideographic"},
    163098: {"Unified_Ideograph", "Ideographic"},
    163099: {"Unified_Ideograph", "Ideographic"},
    163100: {"Unified_Ideograph", "Ideographic"},
    163101: {"Unified_Ideograph", "Ideographic"},
    163102: {"Unified_Ideograph", "Ideographic"},
    163103: {"Unified_Ideograph", "Ideographic"},
    163104: {"Unified_Ideograph", "Ideographic"},
    163105: {"Unified_Ideograph", "Ideographic"},
    163106: {"Unified_Ideograph", "Ideographic"},
    163107: {"Unified_Ideograph", "Ideographic"},
    163108: {"Unified_Ideograph", "Ideographic"},
    163109: {"Unified_Ideograph", "Ideographic"},
    163110: {"Unified_Ideograph", "Ideographic"},
    163111: {"Unified_Ideograph", "Ideographic"},
    163112: {"Unified_Ideograph", "Ideographic"},
    163113: {"Unified_Ideograph", "Ideographic"},
    163114: {"Unified_Ideograph", "Ideographic"},
    163115: {"Unified_Ideograph", "Ideographic"},
    163116: {"Unified_Ideograph", "Ideographic"},
    163117: {"Unified_Ideograph", "Ideographic"},
    163118: {"Unified_Ideograph", "Ideographic"},
    163119: {"Unified_Ideograph", "Ideographic"},
    163120: {"Unified_Ideograph", "Ideographic"},
    163121: {"Unified_Ideograph", "Ideographic"},
    163122: {"Unified_Ideograph", "Ideographic"},
    163123: {"Unified_Ideograph", "Ideographic"},
    163124: {"Unified_Ideograph", "Ideographic"},
    163125: {"Unified_Ideograph", "Ideographic"},
    163126: {"Unified_Ideograph", "Ideographic"},
    163127: {"Unified_Ideograph", "Ideographic"},
    163128: {"Unified_Ideograph", "Ideographic"},
    163129: {"Unified_Ideograph", "Ideographic"},
    163130: {"Unified_Ideograph", "Ideographic"},
    163131: {"Unified_Ideograph", "Ideographic"},
    163132: {"Unified_Ideograph", "Ideographic"},
    163133: {"Unified_Ideograph", "Ideographic"},
    163134: {"Unified_Ideograph", "Ideographic"},
    163135: {"Unified_Ideograph", "Ideographic"},
    163136: {"Unified_Ideograph", "Ideographic"},
    163137: {"Unified_Ideograph", "Ideographic"},
    163138: {"Unified_Ideograph", "Ideographic"},
    163139: {"Unified_Ideograph", "Ideographic"},
    163140: {"Unified_Ideograph", "Ideographic"},
    163141: {"Unified_Ideograph", "Ideographic"},
    163142: {"Unified_Ideograph", "Ideographic"},
    163143: {"Unified_Ideograph", "Ideographic"},
    163144: {"Unified_Ideograph", "Ideographic"},
    163145: {"Unified_Ideograph", "Ideographic"},
    163146: {"Unified_Ideograph", "Ideographic"},
    163147: {"Unified_Ideograph", "Ideographic"},
    163148: {"Unified_Ideograph", "Ideographic"},
    163149: {"Unified_Ideograph", "Ideographic"},
    163150: {"Unified_Ideograph", "Ideographic"},
    163151: {"Unified_Ideograph", "Ideographic"},
    163152: {"Unified_Ideograph", "Ideographic"},
    163153: {"Unified_Ideograph", "Ideographic"},
    163154: {"Unified_Ideograph", "Ideographic"},
    163155: {"Unified_Ideograph", "Ideographic"},
    163156: {"Unified_Ideograph", "Ideographic"},
    163157: {"Unified_Ideograph", "Ideographic"},
    163158: {"Unified_Ideograph", "Ideographic"},
    163159: {"Unified_Ideograph", "Ideographic"},
    163160: {"Unified_Ideograph", "Ideographic"},
    163161: {"Unified_Ideograph", "Ideographic"},
    163162: {"Unified_Ideograph", "Ideographic"},
    163163: {"Unified_Ideograph", "Ideographic"},
    163164: {"Unified_Ideograph", "Ideographic"},
    163165: {"Unified_Ideograph", "Ideographic"},
    163166: {"Unified_Ideograph", "Ideographic"},
    163167: {"Unified_Ideograph", "Ideographic"},
    163168: {"Unified_Ideograph", "Ideographic"},
    163169: {"Unified_Ideograph", "Ideographic"},
    163170: {"Unified_Ideograph", "Ideographic"},
    163171: {"Unified_Ideograph", "Ideographic"},
    163172: {"Unified_Ideograph", "Ideographic"},
    163173: {"Unified_Ideograph", "Ideographic"},
    163174: {"Unified_Ideograph", "Ideographic"},
    163175: {"Unified_Ideograph", "Ideographic"},
    163176: {"Unified_Ideograph", "Ideographic"},
    163177: {"Unified_Ideograph", "Ideographic"},
    163178: {"Unified_Ideograph", "Ideographic"},
    163179: {"Unified_Ideograph", "Ideographic"},
    163180: {"Unified_Ideograph", "Ideographic"},
    163181: {"Unified_Ideograph", "Ideographic"},
    163182: {"Unified_Ideograph", "Ideographic"},
    163183: {"Unified_Ideograph", "Ideographic"},
    163184: {"Unified_Ideograph", "Ideographic"},
    163185: {"Unified_Ideograph", "Ideographic"},
    163186: {"Unified_Ideograph", "Ideographic"},
    163187: {"Unified_Ideograph", "Ideographic"},
    163188: {"Unified_Ideograph", "Ideographic"},
    163189: {"Unified_Ideograph", "Ideographic"},
    163190: {"Unified_Ideograph", "Ideographic"},
    163191: {"Unified_Ideograph", "Ideographic"},
    163192: {"Unified_Ideograph", "Ideographic"},
    163193: {"Unified_Ideograph", "Ideographic"},
    163194: {"Unified_Ideograph", "Ideographic"},
    163195: {"Unified_Ideograph", "Ideographic"},
    163196: {"Unified_Ideograph", "Ideographic"},
    163197: {"Unified_Ideograph", "Ideographic"},
    163198: {"Unified_Ideograph", "Ideographic"},
    163199: {"Unified_Ideograph", "Ideographic"},
    163200: {"Unified_Ideograph", "Ideographic"},
    163201: {"Unified_Ideograph", "Ideographic"},
    163202: {"Unified_Ideograph", "Ideographic"},
    163203: {"Unified_Ideograph", "Ideographic"},
    163204: {"Unified_Ideograph", "Ideographic"},
    163205: {"Unified_Ideograph", "Ideographic"},
    163206: {"Unified_Ideograph", "Ideographic"},
    163207: {"Unified_Ideograph", "Ideographic"},
    163208: {"Unified_Ideograph", "Ideographic"},
    163209: {"Unified_Ideograph", "Ideographic"},
    163210: {"Unified_Ideograph", "Ideographic"},
    163211: {"Unified_Ideograph", "Ideographic"},
    163212: {"Unified_Ideograph", "Ideographic"},
    163213: {"Unified_Ideograph", "Ideographic"},
    163214: {"Unified_Ideograph", "Ideographic"},
    163215: {"Unified_Ideograph", "Ideographic"},
    163216: {"Unified_Ideograph", "Ideographic"},
    163217: {"Unified_Ideograph", "Ideographic"},
    163218: {"Unified_Ideograph", "Ideographic"},
    163219: {"Unified_Ideograph", "Ideographic"},
    163220: {"Unified_Ideograph", "Ideographic"},
    163221: {"Unified_Ideograph", "Ideographic"},
    163222: {"Unified_Ideograph", "Ideographic"},
    163223: {"Unified_Ideograph", "Ideographic"},
    163224: {"Unified_Ideograph", "Ideographic"},
    163225: {"Unified_Ideograph", "Ideographic"},
    163226: {"Unified_Ideograph", "Ideographic"},
    163227: {"Unified_Ideograph", "Ideographic"},
    163228: {"Unified_Ideograph", "Ideographic"},
    163229: {"Unified_Ideograph", "Ideographic"},
    163230: {"Unified_Ideograph", "Ideographic"},
    163231: {"Unified_Ideograph", "Ideographic"},
    163232: {"Unified_Ideograph", "Ideographic"},
    163233: {"Unified_Ideograph", "Ideographic"},
    163234: {"Unified_Ideograph", "Ideographic"},
    163235: {"Unified_Ideograph", "Ideographic"},
    163236: {"Unified_Ideograph", "Ideographic"},
    163237: {"Unified_Ideograph", "Ideographic"},
    163238: {"Unified_Ideograph", "Ideographic"},
    163239: {"Unified_Ideograph", "Ideographic"},
    163240: {"Unified_Ideograph", "Ideographic"},
    163241: {"Unified_Ideograph", "Ideographic"},
    163242: {"Unified_Ideograph", "Ideographic"},
    163243: {"Unified_Ideograph", "Ideographic"},
    163244: {"Unified_Ideograph", "Ideographic"},
    163245: {"Unified_Ideograph", "Ideographic"},
    163246: {"Unified_Ideograph", "Ideographic"},
    163247: {"Unified_Ideograph", "Ideographic"},
    163248: {"Unified_Ideograph", "Ideographic"},
    163249: {"Unified_Ideograph", "Ideographic"},
    163250: {"Unified_Ideograph", "Ideographic"},
    163251: {"Unified_Ideograph", "Ideographic"},
    163252: {"Unified_Ideograph", "Ideographic"},
    163253: {"Unified_Ideograph", "Ideographic"},
    163254: {"Unified_Ideograph", "Ideographic"},
    163255: {"Unified_Ideograph", "Ideographic"},
    163256: {"Unified_Ideograph", "Ideographic"},
    163257: {"Unified_Ideograph", "Ideographic"},
    163258: {"Unified_Ideograph", "Ideographic"},
    163259: {"Unified_Ideograph", "Ideographic"},
    163260: {"Unified_Ideograph", "Ideographic"},
    163261: {"Unified_Ideograph", "Ideographic"},
    163262: {"Unified_Ideograph", "Ideographic"},
    163263: {"Unified_Ideograph", "Ideographic"},
    163264: {"Unified_Ideograph", "Ideographic"},
    163265: {"Unified_Ideograph", "Ideographic"},
    163266: {"Unified_Ideograph", "Ideographic"},
    163267: {"Unified_Ideograph", "Ideographic"},
    163268: {"Unified_Ideograph", "Ideographic"},
    163269: {"Unified_Ideograph", "Ideographic"},
    163270: {"Unified_Ideograph", "Ideographic"},
    163271: {"Unified_Ideograph", "Ideographic"},
    163272: {"Unified_Ideograph", "Ideographic"},
    163273: {"Unified_Ideograph", "Ideographic"},
    163274: {"Unified_Ideograph", "Ideographic"},
    163275: {"Unified_Ideograph", "Ideographic"},
    163276: {"Unified_Ideograph", "Ideographic"},
    163277: {"Unified_Ideograph", "Ideographic"},
    163278: {"Unified_Ideograph", "Ideographic"},
    163279: {"Unified_Ideograph", "Ideographic"},
    163280: {"Unified_Ideograph", "Ideographic"},
    163281: {"Unified_Ideograph", "Ideographic"},
    163282: {"Unified_Ideograph", "Ideographic"},
    163283: {"Unified_Ideograph", "Ideographic"},
    163284: {"Unified_Ideograph", "Ideographic"},
    163285: {"Unified_Ideograph", "Ideographic"},
    163286: {"Unified_Ideograph", "Ideographic"},
    163287: {"Unified_Ideograph", "Ideographic"},
    163288: {"Unified_Ideograph", "Ideographic"},
    163289: {"Unified_Ideograph", "Ideographic"},
    163290: {"Unified_Ideograph", "Ideographic"},
    163291: {"Unified_Ideograph", "Ideographic"},
    163292: {"Unified_Ideograph", "Ideographic"},
    163293: {"Unified_Ideograph", "Ideographic"},
    163294: {"Unified_Ideograph", "Ideographic"},
    163295: {"Unified_Ideograph", "Ideographic"},
    163296: {"Unified_Ideograph", "Ideographic"},
    163297: {"Unified_Ideograph", "Ideographic"},
    163298: {"Unified_Ideograph", "Ideographic"},
    163299: {"Unified_Ideograph", "Ideographic"},
    163300: {"Unified_Ideograph", "Ideographic"},
    163301: {"Unified_Ideograph", "Ideographic"},
    163302: {"Unified_Ideograph", "Ideographic"},
    163303: {"Unified_Ideograph", "Ideographic"},
    163304: {"Unified_Ideograph", "Ideographic"},
    163305: {"Unified_Ideograph", "Ideographic"},
    163306: {"Unified_Ideograph", "Ideographic"},
    163307: {"Unified_Ideograph", "Ideographic"},
    163308: {"Unified_Ideograph", "Ideographic"},
    163309: {"Unified_Ideograph", "Ideographic"},
    163310: {"Unified_Ideograph", "Ideographic"},
    163311: {"Unified_Ideograph", "Ideographic"},
    163312: {"Unified_Ideograph", "Ideographic"},
    163313: {"Unified_Ideograph", "Ideographic"},
    163314: {"Unified_Ideograph", "Ideographic"},
    163315: {"Unified_Ideograph", "Ideographic"},
    163316: {"Unified_Ideograph", "Ideographic"},
    163317: {"Unified_Ideograph", "Ideographic"},
    163318: {"Unified_Ideograph", "Ideographic"},
    163319: {"Unified_Ideograph", "Ideographic"},
    163320: {"Unified_Ideograph", "Ideographic"},
    163321: {"Unified_Ideograph", "Ideographic"},
    163322: {"Unified_Ideograph", "Ideographic"},
    163323: {"Unified_Ideograph", "Ideographic"},
    163324: {"Unified_Ideograph", "Ideographic"},
    163325: {"Unified_Ideograph", "Ideographic"},
    163326: {"Unified_Ideograph", "Ideographic"},
    163327: {"Unified_Ideograph", "Ideographic"},
    163328: {"Unified_Ideograph", "Ideographic"},
    163329: {"Unified_Ideograph", "Ideographic"},
    163330: {"Unified_Ideograph", "Ideographic"},
    163331: {"Unified_Ideograph", "Ideographic"},
    163332: {"Unified_Ideograph", "Ideographic"},
    163333: {"Unified_Ideograph", "Ideographic"},
    163334: {"Unified_Ideograph", "Ideographic"},
    163335: {"Unified_Ideograph", "Ideographic"},
    163336: {"Unified_Ideograph", "Ideographic"},
    163337: {"Unified_Ideograph", "Ideographic"},
    163338: {"Unified_Ideograph", "Ideographic"},
    163339: {"Unified_Ideograph", "Ideographic"},
    163340: {"Unified_Ideograph", "Ideographic"},
    163341: {"Unified_Ideograph", "Ideographic"},
    163342: {"Unified_Ideograph", "Ideographic"},
    163343: {"Unified_Ideograph", "Ideographic"},
    163344: {"Unified_Ideograph", "Ideographic"},
    163345: {"Unified_Ideograph", "Ideographic"},
    163346: {"Unified_Ideograph", "Ideographic"},
    163347: {"Unified_Ideograph", "Ideographic"},
    163348: {"Unified_Ideograph", "Ideographic"},
    163349: {"Unified_Ideograph", "Ideographic"},
    163350: {"Unified_Ideograph", "Ideographic"},
    163351: {"Unified_Ideograph", "Ideographic"},
    163352: {"Unified_Ideograph", "Ideographic"},
    163353: {"Unified_Ideograph", "Ideographic"},
    163354: {"Unified_Ideograph", "Ideographic"},
    163355: {"Unified_Ideograph", "Ideographic"},
    163356: {"Unified_Ideograph", "Ideographic"},
    163357: {"Unified_Ideograph", "Ideographic"},
    163358: {"Unified_Ideograph", "Ideographic"},
    163359: {"Unified_Ideograph", "Ideographic"},
    163360: {"Unified_Ideograph", "Ideographic"},
    163361: {"Unified_Ideograph", "Ideographic"},
    163362: {"Unified_Ideograph", "Ideographic"},
    163363: {"Unified_Ideograph", "Ideographic"},
    163364: {"Unified_Ideograph", "Ideographic"},
    163365: {"Unified_Ideograph", "Ideographic"},
    163366: {"Unified_Ideograph", "Ideographic"},
    163367: {"Unified_Ideograph", "Ideographic"},
    163368: {"Unified_Ideograph", "Ideographic"},
    163369: {"Unified_Ideograph", "Ideographic"},
    163370: {"Unified_Ideograph", "Ideographic"},
    163371: {"Unified_Ideograph", "Ideographic"},
    163372: {"Unified_Ideograph", "Ideographic"},
    163373: {"Unified_Ideograph", "Ideographic"},
    163374: {"Unified_Ideograph", "Ideographic"},
    163375: {"Unified_Ideograph", "Ideographic"},
    163376: {"Unified_Ideograph", "Ideographic"},
    163377: {"Unified_Ideograph", "Ideographic"},
    163378: {"Unified_Ideograph", "Ideographic"},
    163379: {"Unified_Ideograph", "Ideographic"},
    163380: {"Unified_Ideograph", "Ideographic"},
    163381: {"Unified_Ideograph", "Ideographic"},
    163382: {"Unified_Ideograph", "Ideographic"},
    163383: {"Unified_Ideograph", "Ideographic"},
    163384: {"Unified_Ideograph", "Ideographic"},
    163385: {"Unified_Ideograph", "Ideographic"},
    163386: {"Unified_Ideograph", "Ideographic"},
    163387: {"Unified_Ideograph", "Ideographic"},
    163388: {"Unified_Ideograph", "Ideographic"},
    163389: {"Unified_Ideograph", "Ideographic"},
    163390: {"Unified_Ideograph", "Ideographic"},
    163391: {"Unified_Ideograph", "Ideographic"},
    163392: {"Unified_Ideograph", "Ideographic"},
    163393: {"Unified_Ideograph", "Ideographic"},
    163394: {"Unified_Ideograph", "Ideographic"},
    163395: {"Unified_Ideograph", "Ideographic"},
    163396: {"Unified_Ideograph", "Ideographic"},
    163397: {"Unified_Ideograph", "Ideographic"},
    163398: {"Unified_Ideograph", "Ideographic"},
    163399: {"Unified_Ideograph", "Ideographic"},
    163400: {"Unified_Ideograph", "Ideographic"},
    163401: {"Unified_Ideograph", "Ideographic"},
    163402: {"Unified_Ideograph", "Ideographic"},
    163403: {"Unified_Ideograph", "Ideographic"},
    163404: {"Unified_Ideograph", "Ideographic"},
    163405: {"Unified_Ideograph", "Ideographic"},
    163406: {"Unified_Ideograph", "Ideographic"},
    163407: {"Unified_Ideograph", "Ideographic"},
    163408: {"Unified_Ideograph", "Ideographic"},
    163409: {"Unified_Ideograph", "Ideographic"},
    163410: {"Unified_Ideograph", "Ideographic"},
    163411: {"Unified_Ideograph", "Ideographic"},
    163412: {"Unified_Ideograph", "Ideographic"},
    163413: {"Unified_Ideograph", "Ideographic"},
    163414: {"Unified_Ideograph", "Ideographic"},
    163415: {"Unified_Ideograph", "Ideographic"},
    163416: {"Unified_Ideograph", "Ideographic"},
    163417: {"Unified_Ideograph", "Ideographic"},
    163418: {"Unified_Ideograph", "Ideographic"},
    163419: {"Unified_Ideograph", "Ideographic"},
    163420: {"Unified_Ideograph", "Ideographic"},
    163421: {"Unified_Ideograph", "Ideographic"},
    163422: {"Unified_Ideograph", "Ideographic"},
    163423: {"Unified_Ideograph", "Ideographic"},
    163424: {"Unified_Ideograph", "Ideographic"},
    163425: {"Unified_Ideograph", "Ideographic"},
    163426: {"Unified_Ideograph", "Ideographic"},
    163427: {"Unified_Ideograph", "Ideographic"},
    163428: {"Unified_Ideograph", "Ideographic"},
    163429: {"Unified_Ideograph", "Ideographic"},
    163430: {"Unified_Ideograph", "Ideographic"},
    163431: {"Unified_Ideograph", "Ideographic"},
    163432: {"Unified_Ideograph", "Ideographic"},
    163433: {"Unified_Ideograph", "Ideographic"},
    163434: {"Unified_Ideograph", "Ideographic"},
    163435: {"Unified_Ideograph", "Ideographic"},
    163436: {"Unified_Ideograph", "Ideographic"},
    163437: {"Unified_Ideograph", "Ideographic"},
    163438: {"Unified_Ideograph", "Ideographic"},
    163439: {"Unified_Ideograph", "Ideographic"},
    163440: {"Unified_Ideograph", "Ideographic"},
    163441: {"Unified_Ideograph", "Ideographic"},
    163442: {"Unified_Ideograph", "Ideographic"},
    163443: {"Unified_Ideograph", "Ideographic"},
    163444: {"Unified_Ideograph", "Ideographic"},
    163445: {"Unified_Ideograph", "Ideographic"},
    163446: {"Unified_Ideograph", "Ideographic"},
    163447: {"Unified_Ideograph", "Ideographic"},
    163448: {"Unified_Ideograph", "Ideographic"},
    163449: {"Unified_Ideograph", "Ideographic"},
    163450: {"Unified_Ideograph", "Ideographic"},
    163451: {"Unified_Ideograph", "Ideographic"},
    163452: {"Unified_Ideograph", "Ideographic"},
    163453: {"Unified_Ideograph", "Ideographic"},
    163454: {"Unified_Ideograph", "Ideographic"},
    163455: {"Unified_Ideograph", "Ideographic"},
    163456: {"Unified_Ideograph", "Ideographic"},
    163457: {"Unified_Ideograph", "Ideographic"},
    163458: {"Unified_Ideograph", "Ideographic"},
    163459: {"Unified_Ideograph", "Ideographic"},
    163460: {"Unified_Ideograph", "Ideographic"},
    163461: {"Unified_Ideograph", "Ideographic"},
    163462: {"Unified_Ideograph", "Ideographic"},
    163463: {"Unified_Ideograph", "Ideographic"},
    163464: {"Unified_Ideograph", "Ideographic"},
    163465: {"Unified_Ideograph", "Ideographic"},
    163466: {"Unified_Ideograph", "Ideographic"},
    163467: {"Unified_Ideograph", "Ideographic"},
    163468: {"Unified_Ideograph", "Ideographic"},
    163469: {"Unified_Ideograph", "Ideographic"},
    163470: {"Unified_Ideograph", "Ideographic"},
    163471: {"Unified_Ideograph", "Ideographic"},
    163472: {"Unified_Ideograph", "Ideographic"},
    163473: {"Unified_Ideograph", "Ideographic"},
    163474: {"Unified_Ideograph", "Ideographic"},
    163475: {"Unified_Ideograph", "Ideographic"},
    163476: {"Unified_Ideograph", "Ideographic"},
    163477: {"Unified_Ideograph", "Ideographic"},
    163478: {"Unified_Ideograph", "Ideographic"},
    163479: {"Unified_Ideograph", "Ideographic"},
    163480: {"Unified_Ideograph", "Ideographic"},
    163481: {"Unified_Ideograph", "Ideographic"},
    163482: {"Unified_Ideograph", "Ideographic"},
    163483: {"Unified_Ideograph", "Ideographic"},
    163484: {"Unified_Ideograph", "Ideographic"},
    163485: {"Unified_Ideograph", "Ideographic"},
    163486: {"Unified_Ideograph", "Ideographic"},
    163487: {"Unified_Ideograph", "Ideographic"},
    163488: {"Unified_Ideograph", "Ideographic"},
    163489: {"Unified_Ideograph", "Ideographic"},
    163490: {"Unified_Ideograph", "Ideographic"},
    163491: {"Unified_Ideograph", "Ideographic"},
    163492: {"Unified_Ideograph", "Ideographic"},
    163493: {"Unified_Ideograph", "Ideographic"},
    163494: {"Unified_Ideograph", "Ideographic"},
    163495: {"Unified_Ideograph", "Ideographic"},
    163496: {"Unified_Ideograph", "Ideographic"},
    163497: {"Unified_Ideograph", "Ideographic"},
    163498: {"Unified_Ideograph", "Ideographic"},
    163499: {"Unified_Ideograph", "Ideographic"},
    163500: {"Unified_Ideograph", "Ideographic"},
    163501: {"Unified_Ideograph", "Ideographic"},
    163502: {"Unified_Ideograph", "Ideographic"},
    163503: {"Unified_Ideograph", "Ideographic"},
    163504: {"Unified_Ideograph", "Ideographic"},
    163505: {"Unified_Ideograph", "Ideographic"},
    163506: {"Unified_Ideograph", "Ideographic"},
    163507: {"Unified_Ideograph", "Ideographic"},
    163508: {"Unified_Ideograph", "Ideographic"},
    163509: {"Unified_Ideograph", "Ideographic"},
    163510: {"Unified_Ideograph", "Ideographic"},
    163511: {"Unified_Ideograph", "Ideographic"},
    163512: {"Unified_Ideograph", "Ideographic"},
    163513: {"Unified_Ideograph", "Ideographic"},
    163514: {"Unified_Ideograph", "Ideographic"},
    163515: {"Unified_Ideograph", "Ideographic"},
    163516: {"Unified_Ideograph", "Ideographic"},
    163517: {"Unified_Ideograph", "Ideographic"},
    163518: {"Unified_Ideograph", "Ideographic"},
    163519: {"Unified_Ideograph", "Ideographic"},
    163520: {"Unified_Ideograph", "Ideographic"},
    163521: {"Unified_Ideograph", "Ideographic"},
    163522: {"Unified_Ideograph", "Ideographic"},
    163523: {"Unified_Ideograph", "Ideographic"},
    163524: {"Unified_Ideograph", "Ideographic"},
    163525: {"Unified_Ideograph", "Ideographic"},
    163526: {"Unified_Ideograph", "Ideographic"},
    163527: {"Unified_Ideograph", "Ideographic"},
    163528: {"Unified_Ideograph", "Ideographic"},
    163529: {"Unified_Ideograph", "Ideographic"},
    163530: {"Unified_Ideograph", "Ideographic"},
    163531: {"Unified_Ideograph", "Ideographic"},
    163532: {"Unified_Ideograph", "Ideographic"},
    163533: {"Unified_Ideograph", "Ideographic"},
    163534: {"Unified_Ideograph", "Ideographic"},
    163535: {"Unified_Ideograph", "Ideographic"},
    163536: {"Unified_Ideograph", "Ideographic"},
    163537: {"Unified_Ideograph", "Ideographic"},
    163538: {"Unified_Ideograph", "Ideographic"},
    163539: {"Unified_Ideograph", "Ideographic"},
    163540: {"Unified_Ideograph", "Ideographic"},
    163541: {"Unified_Ideograph", "Ideographic"},
    163542: {"Unified_Ideograph", "Ideographic"},
    163543: {"Unified_Ideograph", "Ideographic"},
    163544: {"Unified_Ideograph", "Ideographic"},
    163545: {"Unified_Ideograph", "Ideographic"},
    163546: {"Unified_Ideograph", "Ideographic"},
    163547: {"Unified_Ideograph", "Ideographic"},
    163548: {"Unified_Ideograph", "Ideographic"},
    163549: {"Unified_Ideograph", "Ideographic"},
    163550: {"Unified_Ideograph", "Ideographic"},
    163551: {"Unified_Ideograph", "Ideographic"},
    163552: {"Unified_Ideograph", "Ideographic"},
    163553: {"Unified_Ideograph", "Ideographic"},
    163554: {"Unified_Ideograph", "Ideographic"},
    163555: {"Unified_Ideograph", "Ideographic"},
    163556: {"Unified_Ideograph", "Ideographic"},
    163557: {"Unified_Ideograph", "Ideographic"},
    163558: {"Unified_Ideograph", "Ideographic"},
    163559: {"Unified_Ideograph", "Ideographic"},
    163560: {"Unified_Ideograph", "Ideographic"},
    163561: {"Unified_Ideograph", "Ideographic"},
    163562: {"Unified_Ideograph", "Ideographic"},
    163563: {"Unified_Ideograph", "Ideographic"},
    163564: {"Unified_Ideograph", "Ideographic"},
    163565: {"Unified_Ideograph", "Ideographic"},
    163566: {"Unified_Ideograph", "Ideographic"},
    163567: {"Unified_Ideograph", "Ideographic"},
    163568: {"Unified_Ideograph", "Ideographic"},
    163569: {"Unified_Ideograph", "Ideographic"},
    163570: {"Unified_Ideograph", "Ideographic"},
    163571: {"Unified_Ideograph", "Ideographic"},
    163572: {"Unified_Ideograph", "Ideographic"},
    163573: {"Unified_Ideograph", "Ideographic"},
    163574: {"Unified_Ideograph", "Ideographic"},
    163575: {"Unified_Ideograph", "Ideographic"},
    163576: {"Unified_Ideograph", "Ideographic"},
    163577: {"Unified_Ideograph", "Ideographic"},
    163578: {"Unified_Ideograph", "Ideographic"},
    163579: {"Unified_Ideograph", "Ideographic"},
    163580: {"Unified_Ideograph", "Ideographic"},
    163581: {"Unified_Ideograph", "Ideographic"},
    163582: {"Unified_Ideograph", "Ideographic"},
    163583: {"Unified_Ideograph", "Ideographic"},
    163584: {"Unified_Ideograph", "Ideographic"},
    163585: {"Unified_Ideograph", "Ideographic"},
    163586: {"Unified_Ideograph", "Ideographic"},
    163587: {"Unified_Ideograph", "Ideographic"},
    163588: {"Unified_Ideograph", "Ideographic"},
    163589: {"Unified_Ideograph", "Ideographic"},
    163590: {"Unified_Ideograph", "Ideographic"},
    163591: {"Unified_Ideograph", "Ideographic"},
    163592: {"Unified_Ideograph", "Ideographic"},
    163593: {"Unified_Ideograph", "Ideographic"},
    163594: {"Unified_Ideograph", "Ideographic"},
    163595: {"Unified_Ideograph", "Ideographic"},
    163596: {"Unified_Ideograph", "Ideographic"},
    163597: {"Unified_Ideograph", "Ideographic"},
    163598: {"Unified_Ideograph", "Ideographic"},
    163599: {"Unified_Ideograph", "Ideographic"},
    163600: {"Unified_Ideograph", "Ideographic"},
    163601: {"Unified_Ideograph", "Ideographic"},
    163602: {"Unified_Ideograph", "Ideographic"},
    163603: {"Unified_Ideograph", "Ideographic"},
    163604: {"Unified_Ideograph", "Ideographic"},
    163605: {"Unified_Ideograph", "Ideographic"},
    163606: {"Unified_Ideograph", "Ideographic"},
    163607: {"Unified_Ideograph", "Ideographic"},
    163608: {"Unified_Ideograph", "Ideographic"},
    163609: {"Unified_Ideograph", "Ideographic"},
    163610: {"Unified_Ideograph", "Ideographic"},
    163611: {"Unified_Ideograph", "Ideographic"},
    163612: {"Unified_Ideograph", "Ideographic"},
    163613: {"Unified_Ideograph", "Ideographic"},
    163614: {"Unified_Ideograph", "Ideographic"},
    163615: {"Unified_Ideograph", "Ideographic"},
    163616: {"Unified_Ideograph", "Ideographic"},
    163617: {"Unified_Ideograph", "Ideographic"},
    163618: {"Unified_Ideograph", "Ideographic"},
    163619: {"Unified_Ideograph", "Ideographic"},
    163620: {"Unified_Ideograph", "Ideographic"},
    163621: {"Unified_Ideograph", "Ideographic"},
    163622: {"Unified_Ideograph", "Ideographic"},
    163623: {"Unified_Ideograph", "Ideographic"},
    163624: {"Unified_Ideograph", "Ideographic"},
    163625: {"Unified_Ideograph", "Ideographic"},
    163626: {"Unified_Ideograph", "Ideographic"},
    163627: {"Unified_Ideograph", "Ideographic"},
    163628: {"Unified_Ideograph", "Ideographic"},
    163629: {"Unified_Ideograph", "Ideographic"},
    163630: {"Unified_Ideograph", "Ideographic"},
    163631: {"Unified_Ideograph", "Ideographic"},
    163632: {"Unified_Ideograph", "Ideographic"},
    163633: {"Unified_Ideograph", "Ideographic"},
    163634: {"Unified_Ideograph", "Ideographic"},
    163635: {"Unified_Ideograph", "Ideographic"},
    163636: {"Unified_Ideograph", "Ideographic"},
    163637: {"Unified_Ideograph", "Ideographic"},
    163638: {"Unified_Ideograph", "Ideographic"},
    163639: {"Unified_Ideograph", "Ideographic"},
    163640: {"Unified_Ideograph", "Ideographic"},
    163641: {"Unified_Ideograph", "Ideographic"},
    163642: {"Unified_Ideograph", "Ideographic"},
    163643: {"Unified_Ideograph", "Ideographic"},
    163644: {"Unified_Ideograph", "Ideographic"},
    163645: {"Unified_Ideograph", "Ideographic"},
    163646: {"Unified_Ideograph", "Ideographic"},
    163647: {"Unified_Ideograph", "Ideographic"},
    163648: {"Unified_Ideograph", "Ideographic"},
    163649: {"Unified_Ideograph", "Ideographic"},
    163650: {"Unified_Ideograph", "Ideographic"},
    163651: {"Unified_Ideograph", "Ideographic"},
    163652: {"Unified_Ideograph", "Ideographic"},
    163653: {"Unified_Ideograph", "Ideographic"},
    163654: {"Unified_Ideograph", "Ideographic"},
    163655: {"Unified_Ideograph", "Ideographic"},
    163656: {"Unified_Ideograph", "Ideographic"},
    163657: {"Unified_Ideograph", "Ideographic"},
    163658: {"Unified_Ideograph", "Ideographic"},
    163659: {"Unified_Ideograph", "Ideographic"},
    163660: {"Unified_Ideograph", "Ideographic"},
    163661: {"Unified_Ideograph", "Ideographic"},
    163662: {"Unified_Ideograph", "Ideographic"},
    163663: {"Unified_Ideograph", "Ideographic"},
    163664: {"Unified_Ideograph", "Ideographic"},
    163665: {"Unified_Ideograph", "Ideographic"},
    163666: {"Unified_Ideograph", "Ideographic"},
    163667: {"Unified_Ideograph", "Ideographic"},
    163668: {"Unified_Ideograph", "Ideographic"},
    163669: {"Unified_Ideograph", "Ideographic"},
    163670: {"Unified_Ideograph", "Ideographic"},
    163671: {"Unified_Ideograph", "Ideographic"},
    163672: {"Unified_Ideograph", "Ideographic"},
    163673: {"Unified_Ideograph", "Ideographic"},
    163674: {"Unified_Ideograph", "Ideographic"},
    163675: {"Unified_Ideograph", "Ideographic"},
    163676: {"Unified_Ideograph", "Ideographic"},
    163677: {"Unified_Ideograph", "Ideographic"},
    163678: {"Unified_Ideograph", "Ideographic"},
    163679: {"Unified_Ideograph", "Ideographic"},
    163680: {"Unified_Ideograph", "Ideographic"},
    163681: {"Unified_Ideograph", "Ideographic"},
    163682: {"Unified_Ideograph", "Ideographic"},
    163683: {"Unified_Ideograph", "Ideographic"},
    163684: {"Unified_Ideograph", "Ideographic"},
    163685: {"Unified_Ideograph", "Ideographic"},
    163686: {"Unified_Ideograph", "Ideographic"},
    163687: {"Unified_Ideograph", "Ideographic"},
    163688: {"Unified_Ideograph", "Ideographic"},
    163689: {"Unified_Ideograph", "Ideographic"},
    163690: {"Unified_Ideograph", "Ideographic"},
    163691: {"Unified_Ideograph", "Ideographic"},
    163692: {"Unified_Ideograph", "Ideographic"},
    163693: {"Unified_Ideograph", "Ideographic"},
    163694: {"Unified_Ideograph", "Ideographic"},
    163695: {"Unified_Ideograph", "Ideographic"},
    163696: {"Unified_Ideograph", "Ideographic"},
    163697: {"Unified_Ideograph", "Ideographic"},
    163698: {"Unified_Ideograph", "Ideographic"},
    163699: {"Unified_Ideograph", "Ideographic"},
    163700: {"Unified_Ideograph", "Ideographic"},
    163701: {"Unified_Ideograph", "Ideographic"},
    163702: {"Unified_Ideograph", "Ideographic"},
    163703: {"Unified_Ideograph", "Ideographic"},
    163704: {"Unified_Ideograph", "Ideographic"},
    163705: {"Unified_Ideograph", "Ideographic"},
    163706: {"Unified_Ideograph", "Ideographic"},
    163707: {"Unified_Ideograph", "Ideographic"},
    163708: {"Unified_Ideograph", "Ideographic"},
    163709: {"Unified_Ideograph", "Ideographic"},
    163710: {"Unified_Ideograph", "Ideographic"},
    163711: {"Unified_Ideograph", "Ideographic"},
    163712: {"Unified_Ideograph", "Ideographic"},
    163713: {"Unified_Ideograph", "Ideographic"},
    163714: {"Unified_Ideograph", "Ideographic"},
    163715: {"Unified_Ideograph", "Ideographic"},
    163716: {"Unified_Ideograph", "Ideographic"},
    163717: {"Unified_Ideograph", "Ideographic"},
    163718: {"Unified_Ideograph", "Ideographic"},
    163719: {"Unified_Ideograph", "Ideographic"},
    163720: {"Unified_Ideograph", "Ideographic"},
    163721: {"Unified_Ideograph", "Ideographic"},
    163722: {"Unified_Ideograph", "Ideographic"},
    163723: {"Unified_Ideograph", "Ideographic"},
    163724: {"Unified_Ideograph", "Ideographic"},
    163725: {"Unified_Ideograph", "Ideographic"},
    163726: {"Unified_Ideograph", "Ideographic"},
    163727: {"Unified_Ideograph", "Ideographic"},
    163728: {"Unified_Ideograph", "Ideographic"},
    163729: {"Unified_Ideograph", "Ideographic"},
    163730: {"Unified_Ideograph", "Ideographic"},
    163731: {"Unified_Ideograph", "Ideographic"},
    163732: {"Unified_Ideograph", "Ideographic"},
    163733: {"Unified_Ideograph", "Ideographic"},
    163734: {"Unified_Ideograph", "Ideographic"},
    163735: {"Unified_Ideograph", "Ideographic"},
    163736: {"Unified_Ideograph", "Ideographic"},
    163737: {"Unified_Ideograph", "Ideographic"},
    163738: {"Unified_Ideograph", "Ideographic"},
    163739: {"Unified_Ideograph", "Ideographic"},
    163740: {"Unified_Ideograph", "Ideographic"},
    163741: {"Unified_Ideograph", "Ideographic"},
    163742: {"Unified_Ideograph", "Ideographic"},
    163743: {"Unified_Ideograph", "Ideographic"},
    163744: {"Unified_Ideograph", "Ideographic"},
    163745: {"Unified_Ideograph", "Ideographic"},
    163746: {"Unified_Ideograph", "Ideographic"},
    163747: {"Unified_Ideograph", "Ideographic"},
    163748: {"Unified_Ideograph", "Ideographic"},
    163749: {"Unified_Ideograph", "Ideographic"},
    163750: {"Unified_Ideograph", "Ideographic"},
    163751: {"Unified_Ideograph", "Ideographic"},
    163752: {"Unified_Ideograph", "Ideographic"},
    163753: {"Unified_Ideograph", "Ideographic"},
    163754: {"Unified_Ideograph", "Ideographic"},
    163755: {"Unified_Ideograph", "Ideographic"},
    163756: {"Unified_Ideograph", "Ideographic"},
    163757: {"Unified_Ideograph", "Ideographic"},
    163758: {"Unified_Ideograph", "Ideographic"},
    163759: {"Unified_Ideograph", "Ideographic"},
    163760: {"Unified_Ideograph", "Ideographic"},
    163761: {"Unified_Ideograph", "Ideographic"},
    163762: {"Unified_Ideograph", "Ideographic"},
    163763: {"Unified_Ideograph", "Ideographic"},
    163764: {"Unified_Ideograph", "Ideographic"},
    163765: {"Unified_Ideograph", "Ideographic"},
    163766: {"Unified_Ideograph", "Ideographic"},
    163767: {"Unified_Ideograph", "Ideographic"},
    163768: {"Unified_Ideograph", "Ideographic"},
    163769: {"Unified_Ideograph", "Ideographic"},
    163770: {"Unified_Ideograph", "Ideographic"},
    163771: {"Unified_Ideograph", "Ideographic"},
    163772: {"Unified_Ideograph", "Ideographic"},
    163773: {"Unified_Ideograph", "Ideographic"},
    163774: {"Unified_Ideograph", "Ideographic"},
    163775: {"Unified_Ideograph", "Ideographic"},
    163776: {"Unified_Ideograph", "Ideographic"},
    163777: {"Unified_Ideograph", "Ideographic"},
    163778: {"Unified_Ideograph", "Ideographic"},
    163779: {"Unified_Ideograph", "Ideographic"},
    163780: {"Unified_Ideograph", "Ideographic"},
    163781: {"Unified_Ideograph", "Ideographic"},
    163782: {"Unified_Ideograph", "Ideographic"},
    163783: {"Unified_Ideograph", "Ideographic"},
    163784: {"Unified_Ideograph", "Ideographic"},
    163785: {"Unified_Ideograph", "Ideographic"},
    163786: {"Unified_Ideograph", "Ideographic"},
    163787: {"Unified_Ideograph", "Ideographic"},
    163788: {"Unified_Ideograph", "Ideographic"},
    163789: {"Unified_Ideograph", "Ideographic"},
    163790: {"Unified_Ideograph", "Ideographic"},
    163791: {"Unified_Ideograph", "Ideographic"},
    163792: {"Unified_Ideograph", "Ideographic"},
    163793: {"Unified_Ideograph", "Ideographic"},
    163794: {"Unified_Ideograph", "Ideographic"},
    163795: {"Unified_Ideograph", "Ideographic"},
    163796: {"Unified_Ideograph", "Ideographic"},
    163797: {"Unified_Ideograph", "Ideographic"},
    163798: {"Unified_Ideograph", "Ideographic"},
    163799: {"Unified_Ideograph", "Ideographic"},
    163800: {"Unified_Ideograph", "Ideographic"},
    163801: {"Unified_Ideograph", "Ideographic"},
    163802: {"Unified_Ideograph", "Ideographic"},
    163803: {"Unified_Ideograph", "Ideographic"},
    163804: {"Unified_Ideograph", "Ideographic"},
    163805: {"Unified_Ideograph", "Ideographic"},
    163806: {"Unified_Ideograph", "Ideographic"},
    163807: {"Unified_Ideograph", "Ideographic"},
    163808: {"Unified_Ideograph", "Ideographic"},
    163809: {"Unified_Ideograph", "Ideographic"},
    163810: {"Unified_Ideograph", "Ideographic"},
    163811: {"Unified_Ideograph", "Ideographic"},
    163812: {"Unified_Ideograph", "Ideographic"},
    163813: {"Unified_Ideograph", "Ideographic"},
    163814: {"Unified_Ideograph", "Ideographic"},
    163815: {"Unified_Ideograph", "Ideographic"},
    163816: {"Unified_Ideograph", "Ideographic"},
    163817: {"Unified_Ideograph", "Ideographic"},
    163818: {"Unified_Ideograph", "Ideographic"},
    163819: {"Unified_Ideograph", "Ideographic"},
    163820: {"Unified_Ideograph", "Ideographic"},
    163821: {"Unified_Ideograph", "Ideographic"},
    163822: {"Unified_Ideograph", "Ideographic"},
    163823: {"Unified_Ideograph", "Ideographic"},
    163824: {"Unified_Ideograph", "Ideographic"},
    163825: {"Unified_Ideograph", "Ideographic"},
    163826: {"Unified_Ideograph", "Ideographic"},
    163827: {"Unified_Ideograph", "Ideographic"},
    163828: {"Unified_Ideograph", "Ideographic"},
    163829: {"Unified_Ideograph", "Ideographic"},
    163830: {"Unified_Ideograph", "Ideographic"},
    163831: {"Unified_Ideograph", "Ideographic"},
    163832: {"Unified_Ideograph", "Ideographic"},
    163833: {"Unified_Ideograph", "Ideographic"},
    163834: {"Unified_Ideograph", "Ideographic"},
    163835: {"Unified_Ideograph", "Ideographic"},
    163836: {"Unified_Ideograph", "Ideographic"},
    163837: {"Unified_Ideograph", "Ideographic"},
    163838: {"Unified_Ideograph", "Ideographic"},
    163839: {"Unified_Ideograph", "Ideographic"},
    163840: {"Unified_Ideograph", "Ideographic"},
    163841: {"Unified_Ideograph", "Ideographic"},
    163842: {"Unified_Ideograph", "Ideographic"},
    163843: {"Unified_Ideograph", "Ideographic"},
    163844: {"Unified_Ideograph", "Ideographic"},
    163845: {"Unified_Ideograph", "Ideographic"},
    163846: {"Unified_Ideograph", "Ideographic"},
    163847: {"Unified_Ideograph", "Ideographic"},
    163848: {"Unified_Ideograph", "Ideographic"},
    163849: {"Unified_Ideograph", "Ideographic"},
    163850: {"Unified_Ideograph", "Ideographic"},
    163851: {"Unified_Ideograph", "Ideographic"},
    163852: {"Unified_Ideograph", "Ideographic"},
    163853: {"Unified_Ideograph", "Ideographic"},
    163854: {"Unified_Ideograph", "Ideographic"},
    163855: {"Unified_Ideograph", "Ideographic"},
    163856: {"Unified_Ideograph", "Ideographic"},
    163857: {"Unified_Ideograph", "Ideographic"},
    163858: {"Unified_Ideograph", "Ideographic"},
    163859: {"Unified_Ideograph", "Ideographic"},
    163860: {"Unified_Ideograph", "Ideographic"},
    163861: {"Unified_Ideograph", "Ideographic"},
    163862: {"Unified_Ideograph", "Ideographic"},
    163863: {"Unified_Ideograph", "Ideographic"},
    163864: {"Unified_Ideograph", "Ideographic"},
    163865: {"Unified_Ideograph", "Ideographic"},
    163866: {"Unified_Ideograph", "Ideographic"},
    163867: {"Unified_Ideograph", "Ideographic"},
    163868: {"Unified_Ideograph", "Ideographic"},
    163869: {"Unified_Ideograph", "Ideographic"},
    163870: {"Unified_Ideograph", "Ideographic"},
    163871: {"Unified_Ideograph", "Ideographic"},
    163872: {"Unified_Ideograph", "Ideographic"},
    163873: {"Unified_Ideograph", "Ideographic"},
    163874: {"Unified_Ideograph", "Ideographic"},
    163875: {"Unified_Ideograph", "Ideographic"},
    163876: {"Unified_Ideograph", "Ideographic"},
    163877: {"Unified_Ideograph", "Ideographic"},
    163878: {"Unified_Ideograph", "Ideographic"},
    163879: {"Unified_Ideograph", "Ideographic"},
    163880: {"Unified_Ideograph", "Ideographic"},
    163881: {"Unified_Ideograph", "Ideographic"},
    163882: {"Unified_Ideograph", "Ideographic"},
    163883: {"Unified_Ideograph", "Ideographic"},
    163884: {"Unified_Ideograph", "Ideographic"},
    163885: {"Unified_Ideograph", "Ideographic"},
    163886: {"Unified_Ideograph", "Ideographic"},
    163887: {"Unified_Ideograph", "Ideographic"},
    163888: {"Unified_Ideograph", "Ideographic"},
    163889: {"Unified_Ideograph", "Ideographic"},
    163890: {"Unified_Ideograph", "Ideographic"},
    163891: {"Unified_Ideograph", "Ideographic"},
    163892: {"Unified_Ideograph", "Ideographic"},
    163893: {"Unified_Ideograph", "Ideographic"},
    163894: {"Unified_Ideograph", "Ideographic"},
    163895: {"Unified_Ideograph", "Ideographic"},
    163896: {"Unified_Ideograph", "Ideographic"},
    163897: {"Unified_Ideograph", "Ideographic"},
    163898: {"Unified_Ideograph", "Ideographic"},
    163899: {"Unified_Ideograph", "Ideographic"},
    163900: {"Unified_Ideograph", "Ideographic"},
    163901: {"Unified_Ideograph", "Ideographic"},
    163902: {"Unified_Ideograph", "Ideographic"},
    163903: {"Unified_Ideograph", "Ideographic"},
    163904: {"Unified_Ideograph", "Ideographic"},
    163905: {"Unified_Ideograph", "Ideographic"},
    163906: {"Unified_Ideograph", "Ideographic"},
    163907: {"Unified_Ideograph", "Ideographic"},
    163908: {"Unified_Ideograph", "Ideographic"},
    163909: {"Unified_Ideograph", "Ideographic"},
    163910: {"Unified_Ideograph", "Ideographic"},
    163911: {"Unified_Ideograph", "Ideographic"},
    163912: {"Unified_Ideograph", "Ideographic"},
    163913: {"Unified_Ideograph", "Ideographic"},
    163914: {"Unified_Ideograph", "Ideographic"},
    163915: {"Unified_Ideograph", "Ideographic"},
    163916: {"Unified_Ideograph", "Ideographic"},
    163917: {"Unified_Ideograph", "Ideographic"},
    163918: {"Unified_Ideograph", "Ideographic"},
    163919: {"Unified_Ideograph", "Ideographic"},
    163920: {"Unified_Ideograph", "Ideographic"},
    163921: {"Unified_Ideograph", "Ideographic"},
    163922: {"Unified_Ideograph", "Ideographic"},
    163923: {"Unified_Ideograph", "Ideographic"},
    163924: {"Unified_Ideograph", "Ideographic"},
    163925: {"Unified_Ideograph", "Ideographic"},
    163926: {"Unified_Ideograph", "Ideographic"},
    163927: {"Unified_Ideograph", "Ideographic"},
    163928: {"Unified_Ideograph", "Ideographic"},
    163929: {"Unified_Ideograph", "Ideographic"},
    163930: {"Unified_Ideograph", "Ideographic"},
    163931: {"Unified_Ideograph", "Ideographic"},
    163932: {"Unified_Ideograph", "Ideographic"},
    163933: {"Unified_Ideograph", "Ideographic"},
    163934: {"Unified_Ideograph", "Ideographic"},
    163935: {"Unified_Ideograph", "Ideographic"},
    163936: {"Unified_Ideograph", "Ideographic"},
    163937: {"Unified_Ideograph", "Ideographic"},
    163938: {"Unified_Ideograph", "Ideographic"},
    163939: {"Unified_Ideograph", "Ideographic"},
    163940: {"Unified_Ideograph", "Ideographic"},
    163941: {"Unified_Ideograph", "Ideographic"},
    163942: {"Unified_Ideograph", "Ideographic"},
    163943: {"Unified_Ideograph", "Ideographic"},
    163944: {"Unified_Ideograph", "Ideographic"},
    163945: {"Unified_Ideograph", "Ideographic"},
    163946: {"Unified_Ideograph", "Ideographic"},
    163947: {"Unified_Ideograph", "Ideographic"},
    163948: {"Unified_Ideograph", "Ideographic"},
    163949: {"Unified_Ideograph", "Ideographic"},
    163950: {"Unified_Ideograph", "Ideographic"},
    163951: {"Unified_Ideograph", "Ideographic"},
    163952: {"Unified_Ideograph", "Ideographic"},
    163953: {"Unified_Ideograph", "Ideographic"},
    163954: {"Unified_Ideograph", "Ideographic"},
    163955: {"Unified_Ideograph", "Ideographic"},
    163956: {"Unified_Ideograph", "Ideographic"},
    163957: {"Unified_Ideograph", "Ideographic"},
    163958: {"Unified_Ideograph", "Ideographic"},
    163959: {"Unified_Ideograph", "Ideographic"},
    163960: {"Unified_Ideograph", "Ideographic"},
    163961: {"Unified_Ideograph", "Ideographic"},
    163962: {"Unified_Ideograph", "Ideographic"},
    163963: {"Unified_Ideograph", "Ideographic"},
    163964: {"Unified_Ideograph", "Ideographic"},
    163965: {"Unified_Ideograph", "Ideographic"},
    163966: {"Unified_Ideograph", "Ideographic"},
    163967: {"Unified_Ideograph", "Ideographic"},
    163968: {"Unified_Ideograph", "Ideographic"},
    163969: {"Unified_Ideograph", "Ideographic"},
    163970: {"Unified_Ideograph", "Ideographic"},
    163971: {"Unified_Ideograph", "Ideographic"},
    163972: {"Unified_Ideograph", "Ideographic"},
    163973: {"Unified_Ideograph", "Ideographic"},
    163974: {"Unified_Ideograph", "Ideographic"},
    163975: {"Unified_Ideograph", "Ideographic"},
    163976: {"Unified_Ideograph", "Ideographic"},
    163977: {"Unified_Ideograph", "Ideographic"},
    163978: {"Unified_Ideograph", "Ideographic"},
    163979: {"Unified_Ideograph", "Ideographic"},
    163980: {"Unified_Ideograph", "Ideographic"},
    163981: {"Unified_Ideograph", "Ideographic"},
    163982: {"Unified_Ideograph", "Ideographic"},
    163983: {"Unified_Ideograph", "Ideographic"},
    163984: {"Unified_Ideograph", "Ideographic"},
    163985: {"Unified_Ideograph", "Ideographic"},
    163986: {"Unified_Ideograph", "Ideographic"},
    163987: {"Unified_Ideograph", "Ideographic"},
    163988: {"Unified_Ideograph", "Ideographic"},
    163989: {"Unified_Ideograph", "Ideographic"},
    163990: {"Unified_Ideograph", "Ideographic"},
    163991: {"Unified_Ideograph", "Ideographic"},
    163992: {"Unified_Ideograph", "Ideographic"},
    163993: {"Unified_Ideograph", "Ideographic"},
    163994: {"Unified_Ideograph", "Ideographic"},
    163995: {"Unified_Ideograph", "Ideographic"},
    163996: {"Unified_Ideograph", "Ideographic"},
    163997: {"Unified_Ideograph", "Ideographic"},
    163998: {"Unified_Ideograph", "Ideographic"},
    163999: {"Unified_Ideograph", "Ideographic"},
    164000: {"Unified_Ideograph", "Ideographic"},
    164001: {"Unified_Ideograph", "Ideographic"},
    164002: {"Unified_Ideograph", "Ideographic"},
    164003: {"Unified_Ideograph", "Ideographic"},
    164004: {"Unified_Ideograph", "Ideographic"},
    164005: {"Unified_Ideograph", "Ideographic"},
    164006: {"Unified_Ideograph", "Ideographic"},
    164007: {"Unified_Ideograph", "Ideographic"},
    164008: {"Unified_Ideograph", "Ideographic"},
    164009: {"Unified_Ideograph", "Ideographic"},
    164010: {"Unified_Ideograph", "Ideographic"},
    164011: {"Unified_Ideograph", "Ideographic"},
    164012: {"Unified_Ideograph", "Ideographic"},
    164013: {"Unified_Ideograph", "Ideographic"},
    164014: {"Unified_Ideograph", "Ideographic"},
    164015: {"Unified_Ideograph", "Ideographic"},
    164016: {"Unified_Ideograph", "Ideographic"},
    164017: {"Unified_Ideograph", "Ideographic"},
    164018: {"Unified_Ideograph", "Ideographic"},
    164019: {"Unified_Ideograph", "Ideographic"},
    164020: {"Unified_Ideograph", "Ideographic"},
    164021: {"Unified_Ideograph", "Ideographic"},
    164022: {"Unified_Ideograph", "Ideographic"},
    164023: {"Unified_Ideograph", "Ideographic"},
    164024: {"Unified_Ideograph", "Ideographic"},
    164025: {"Unified_Ideograph", "Ideographic"},
    164026: {"Unified_Ideograph", "Ideographic"},
    164027: {"Unified_Ideograph", "Ideographic"},
    164028: {"Unified_Ideograph", "Ideographic"},
    164029: {"Unified_Ideograph", "Ideographic"},
    164030: {"Unified_Ideograph", "Ideographic"},
    164031: {"Unified_Ideograph", "Ideographic"},
    164032: {"Unified_Ideograph", "Ideographic"},
    164033: {"Unified_Ideograph", "Ideographic"},
    164034: {"Unified_Ideograph", "Ideographic"},
    164035: {"Unified_Ideograph", "Ideographic"},
    164036: {"Unified_Ideograph", "Ideographic"},
    164037: {"Unified_Ideograph", "Ideographic"},
    164038: {"Unified_Ideograph", "Ideographic"},
    164039: {"Unified_Ideograph", "Ideographic"},
    164040: {"Unified_Ideograph", "Ideographic"},
    164041: {"Unified_Ideograph", "Ideographic"},
    164042: {"Unified_Ideograph", "Ideographic"},
    164043: {"Unified_Ideograph", "Ideographic"},
    164044: {"Unified_Ideograph", "Ideographic"},
    164045: {"Unified_Ideograph", "Ideographic"},
    164046: {"Unified_Ideograph", "Ideographic"},
    164047: {"Unified_Ideograph", "Ideographic"},
    164048: {"Unified_Ideograph", "Ideographic"},
    164049: {"Unified_Ideograph", "Ideographic"},
    164050: {"Unified_Ideograph", "Ideographic"},
    164051: {"Unified_Ideograph", "Ideographic"},
    164052: {"Unified_Ideograph", "Ideographic"},
    164053: {"Unified_Ideograph", "Ideographic"},
    164054: {"Unified_Ideograph", "Ideographic"},
    164055: {"Unified_Ideograph", "Ideographic"},
    164056: {"Unified_Ideograph", "Ideographic"},
    164057: {"Unified_Ideograph", "Ideographic"},
    164058: {"Unified_Ideograph", "Ideographic"},
    164059: {"Unified_Ideograph", "Ideographic"},
    164060: {"Unified_Ideograph", "Ideographic"},
    164061: {"Unified_Ideograph", "Ideographic"},
    164062: {"Unified_Ideograph", "Ideographic"},
    164063: {"Unified_Ideograph", "Ideographic"},
    164064: {"Unified_Ideograph", "Ideographic"},
    164065: {"Unified_Ideograph", "Ideographic"},
    164066: {"Unified_Ideograph", "Ideographic"},
    164067: {"Unified_Ideograph", "Ideographic"},
    164068: {"Unified_Ideograph", "Ideographic"},
    164069: {"Unified_Ideograph", "Ideographic"},
    164070: {"Unified_Ideograph", "Ideographic"},
    164071: {"Unified_Ideograph", "Ideographic"},
    164072: {"Unified_Ideograph", "Ideographic"},
    164073: {"Unified_Ideograph", "Ideographic"},
    164074: {"Unified_Ideograph", "Ideographic"},
    164075: {"Unified_Ideograph", "Ideographic"},
    164076: {"Unified_Ideograph", "Ideographic"},
    164077: {"Unified_Ideograph", "Ideographic"},
    164078: {"Unified_Ideograph", "Ideographic"},
    164079: {"Unified_Ideograph", "Ideographic"},
    164080: {"Unified_Ideograph", "Ideographic"},
    164081: {"Unified_Ideograph", "Ideographic"},
    164082: {"Unified_Ideograph", "Ideographic"},
    164083: {"Unified_Ideograph", "Ideographic"},
    164084: {"Unified_Ideograph", "Ideographic"},
    164085: {"Unified_Ideograph", "Ideographic"},
    164086: {"Unified_Ideograph", "Ideographic"},
    164087: {"Unified_Ideograph", "Ideographic"},
    164088: {"Unified_Ideograph", "Ideographic"},
    164089: {"Unified_Ideograph", "Ideographic"},
    164090: {"Unified_Ideograph", "Ideographic"},
    164091: {"Unified_Ideograph", "Ideographic"},
    164092: {"Unified_Ideograph", "Ideographic"},
    164093: {"Unified_Ideograph", "Ideographic"},
    164094: {"Unified_Ideograph", "Ideographic"},
    164095: {"Unified_Ideograph", "Ideographic"},
    164096: {"Unified_Ideograph", "Ideographic"},
    164097: {"Unified_Ideograph", "Ideographic"},
    164098: {"Unified_Ideograph", "Ideographic"},
    164099: {"Unified_Ideograph", "Ideographic"},
    164100: {"Unified_Ideograph", "Ideographic"},
    164101: {"Unified_Ideograph", "Ideographic"},
    164102: {"Unified_Ideograph", "Ideographic"},
    164103: {"Unified_Ideograph", "Ideographic"},
    164104: {"Unified_Ideograph", "Ideographic"},
    164105: {"Unified_Ideograph", "Ideographic"},
    164106: {"Unified_Ideograph", "Ideographic"},
    164107: {"Unified_Ideograph", "Ideographic"},
    164108: {"Unified_Ideograph", "Ideographic"},
    164109: {"Unified_Ideograph", "Ideographic"},
    164110: {"Unified_Ideograph", "Ideographic"},
    164111: {"Unified_Ideograph", "Ideographic"},
    164112: {"Unified_Ideograph", "Ideographic"},
    164113: {"Unified_Ideograph", "Ideographic"},
    164114: {"Unified_Ideograph", "Ideographic"},
    164115: {"Unified_Ideograph", "Ideographic"},
    164116: {"Unified_Ideograph", "Ideographic"},
    164117: {"Unified_Ideograph", "Ideographic"},
    164118: {"Unified_Ideograph", "Ideographic"},
    164119: {"Unified_Ideograph", "Ideographic"},
    164120: {"Unified_Ideograph", "Ideographic"},
    164121: {"Unified_Ideograph", "Ideographic"},
    164122: {"Unified_Ideograph", "Ideographic"},
    164123: {"Unified_Ideograph", "Ideographic"},
    164124: {"Unified_Ideograph", "Ideographic"},
    164125: {"Unified_Ideograph", "Ideographic"},
    164126: {"Unified_Ideograph", "Ideographic"},
    164127: {"Unified_Ideograph", "Ideographic"},
    164128: {"Unified_Ideograph", "Ideographic"},
    164129: {"Unified_Ideograph", "Ideographic"},
    164130: {"Unified_Ideograph", "Ideographic"},
    164131: {"Unified_Ideograph", "Ideographic"},
    164132: {"Unified_Ideograph", "Ideographic"},
    164133: {"Unified_Ideograph", "Ideographic"},
    164134: {"Unified_Ideograph", "Ideographic"},
    164135: {"Unified_Ideograph", "Ideographic"},
    164136: {"Unified_Ideograph", "Ideographic"},
    164137: {"Unified_Ideograph", "Ideographic"},
    164138: {"Unified_Ideograph", "Ideographic"},
    164139: {"Unified_Ideograph", "Ideographic"},
    164140: {"Unified_Ideograph", "Ideographic"},
    164141: {"Unified_Ideograph", "Ideographic"},
    164142: {"Unified_Ideograph", "Ideographic"},
    164143: {"Unified_Ideograph", "Ideographic"},
    164144: {"Unified_Ideograph", "Ideographic"},
    164145: {"Unified_Ideograph", "Ideographic"},
    164146: {"Unified_Ideograph", "Ideographic"},
    164147: {"Unified_Ideograph", "Ideographic"},
    164148: {"Unified_Ideograph", "Ideographic"},
    164149: {"Unified_Ideograph", "Ideographic"},
    164150: {"Unified_Ideograph", "Ideographic"},
    164151: {"Unified_Ideograph", "Ideographic"},
    164152: {"Unified_Ideograph", "Ideographic"},
    164153: {"Unified_Ideograph", "Ideographic"},
    164154: {"Unified_Ideograph", "Ideographic"},
    164155: {"Unified_Ideograph", "Ideographic"},
    164156: {"Unified_Ideograph", "Ideographic"},
    164157: {"Unified_Ideograph", "Ideographic"},
    164158: {"Unified_Ideograph", "Ideographic"},
    164159: {"Unified_Ideograph", "Ideographic"},
    164160: {"Unified_Ideograph", "Ideographic"},
    164161: {"Unified_Ideograph", "Ideographic"},
    164162: {"Unified_Ideograph", "Ideographic"},
    164163: {"Unified_Ideograph", "Ideographic"},
    164164: {"Unified_Ideograph", "Ideographic"},
    164165: {"Unified_Ideograph", "Ideographic"},
    164166: {"Unified_Ideograph", "Ideographic"},
    164167: {"Unified_Ideograph", "Ideographic"},
    164168: {"Unified_Ideograph", "Ideographic"},
    164169: {"Unified_Ideograph", "Ideographic"},
    164170: {"Unified_Ideograph", "Ideographic"},
    164171: {"Unified_Ideograph", "Ideographic"},
    164172: {"Unified_Ideograph", "Ideographic"},
    164173: {"Unified_Ideograph", "Ideographic"},
    164174: {"Unified_Ideograph", "Ideographic"},
    164175: {"Unified_Ideograph", "Ideographic"},
    164176: {"Unified_Ideograph", "Ideographic"},
    164177: {"Unified_Ideograph", "Ideographic"},
    164178: {"Unified_Ideograph", "Ideographic"},
    164179: {"Unified_Ideograph", "Ideographic"},
    164180: {"Unified_Ideograph", "Ideographic"},
    164181: {"Unified_Ideograph", "Ideographic"},
    164182: {"Unified_Ideograph", "Ideographic"},
    164183: {"Unified_Ideograph", "Ideographic"},
    164184: {"Unified_Ideograph", "Ideographic"},
    164185: {"Unified_Ideograph", "Ideographic"},
    164186: {"Unified_Ideograph", "Ideographic"},
    164187: {"Unified_Ideograph", "Ideographic"},
    164188: {"Unified_Ideograph", "Ideographic"},
    164189: {"Unified_Ideograph", "Ideographic"},
    164190: {"Unified_Ideograph", "Ideographic"},
    164191: {"Unified_Ideograph", "Ideographic"},
    164192: {"Unified_Ideograph", "Ideographic"},
    164193: {"Unified_Ideograph", "Ideographic"},
    164194: {"Unified_Ideograph", "Ideographic"},
    164195: {"Unified_Ideograph", "Ideographic"},
    164196: {"Unified_Ideograph", "Ideographic"},
    164197: {"Unified_Ideograph", "Ideographic"},
    164198: {"Unified_Ideograph", "Ideographic"},
    164199: {"Unified_Ideograph", "Ideographic"},
    164200: {"Unified_Ideograph", "Ideographic"},
    164201: {"Unified_Ideograph", "Ideographic"},
    164202: {"Unified_Ideograph", "Ideographic"},
    164203: {"Unified_Ideograph", "Ideographic"},
    164204: {"Unified_Ideograph", "Ideographic"},
    164205: {"Unified_Ideograph", "Ideographic"},
    164206: {"Unified_Ideograph", "Ideographic"},
    164207: {"Unified_Ideograph", "Ideographic"},
    164208: {"Unified_Ideograph", "Ideographic"},
    164209: {"Unified_Ideograph", "Ideographic"},
    164210: {"Unified_Ideograph", "Ideographic"},
    164211: {"Unified_Ideograph", "Ideographic"},
    164212: {"Unified_Ideograph", "Ideographic"},
    164213: {"Unified_Ideograph", "Ideographic"},
    164214: {"Unified_Ideograph", "Ideographic"},
    164215: {"Unified_Ideograph", "Ideographic"},
    164216: {"Unified_Ideograph", "Ideographic"},
    164217: {"Unified_Ideograph", "Ideographic"},
    164218: {"Unified_Ideograph", "Ideographic"},
    164219: {"Unified_Ideograph", "Ideographic"},
    164220: {"Unified_Ideograph", "Ideographic"},
    164221: {"Unified_Ideograph", "Ideographic"},
    164222: {"Unified_Ideograph", "Ideographic"},
    164223: {"Unified_Ideograph", "Ideographic"},
    164224: {"Unified_Ideograph", "Ideographic"},
    164225: {"Unified_Ideograph", "Ideographic"},
    164226: {"Unified_Ideograph", "Ideographic"},
    164227: {"Unified_Ideograph", "Ideographic"},
    164228: {"Unified_Ideograph", "Ideographic"},
    164229: {"Unified_Ideograph", "Ideographic"},
    164230: {"Unified_Ideograph", "Ideographic"},
    164231: {"Unified_Ideograph", "Ideographic"},
    164232: {"Unified_Ideograph", "Ideographic"},
    164233: {"Unified_Ideograph", "Ideographic"},
    164234: {"Unified_Ideograph", "Ideographic"},
    164235: {"Unified_Ideograph", "Ideographic"},
    164236: {"Unified_Ideograph", "Ideographic"},
    164237: {"Unified_Ideograph", "Ideographic"},
    164238: {"Unified_Ideograph", "Ideographic"},
    164239: {"Unified_Ideograph", "Ideographic"},
    164240: {"Unified_Ideograph", "Ideographic"},
    164241: {"Unified_Ideograph", "Ideographic"},
    164242: {"Unified_Ideograph", "Ideographic"},
    164243: {"Unified_Ideograph", "Ideographic"},
    164244: {"Unified_Ideograph", "Ideographic"},
    164245: {"Unified_Ideograph", "Ideographic"},
    164246: {"Unified_Ideograph", "Ideographic"},
    164247: {"Unified_Ideograph", "Ideographic"},
    164248: {"Unified_Ideograph", "Ideographic"},
    164249: {"Unified_Ideograph", "Ideographic"},
    164250: {"Unified_Ideograph", "Ideographic"},
    164251: {"Unified_Ideograph", "Ideographic"},
    164252: {"Unified_Ideograph", "Ideographic"},
    164253: {"Unified_Ideograph", "Ideographic"},
    164254: {"Unified_Ideograph", "Ideographic"},
    164255: {"Unified_Ideograph", "Ideographic"},
    164256: {"Unified_Ideograph", "Ideographic"},
    164257: {"Unified_Ideograph", "Ideographic"},
    164258: {"Unified_Ideograph", "Ideographic"},
    164259: {"Unified_Ideograph", "Ideographic"},
    164260: {"Unified_Ideograph", "Ideographic"},
    164261: {"Unified_Ideograph", "Ideographic"},
    164262: {"Unified_Ideograph", "Ideographic"},
    164263: {"Unified_Ideograph", "Ideographic"},
    164264: {"Unified_Ideograph", "Ideographic"},
    164265: {"Unified_Ideograph", "Ideographic"},
    164266: {"Unified_Ideograph", "Ideographic"},
    164267: {"Unified_Ideograph", "Ideographic"},
    164268: {"Unified_Ideograph", "Ideographic"},
    164269: {"Unified_Ideograph", "Ideographic"},
    164270: {"Unified_Ideograph", "Ideographic"},
    164271: {"Unified_Ideograph", "Ideographic"},
    164272: {"Unified_Ideograph", "Ideographic"},
    164273: {"Unified_Ideograph", "Ideographic"},
    164274: {"Unified_Ideograph", "Ideographic"},
    164275: {"Unified_Ideograph", "Ideographic"},
    164276: {"Unified_Ideograph", "Ideographic"},
    164277: {"Unified_Ideograph", "Ideographic"},
    164278: {"Unified_Ideograph", "Ideographic"},
    164279: {"Unified_Ideograph", "Ideographic"},
    164280: {"Unified_Ideograph", "Ideographic"},
    164281: {"Unified_Ideograph", "Ideographic"},
    164282: {"Unified_Ideograph", "Ideographic"},
    164283: {"Unified_Ideograph", "Ideographic"},
    164284: {"Unified_Ideograph", "Ideographic"},
    164285: {"Unified_Ideograph", "Ideographic"},
    164286: {"Unified_Ideograph", "Ideographic"},
    164287: {"Unified_Ideograph", "Ideographic"},
    164288: {"Unified_Ideograph", "Ideographic"},
    164289: {"Unified_Ideograph", "Ideographic"},
    164290: {"Unified_Ideograph", "Ideographic"},
    164291: {"Unified_Ideograph", "Ideographic"},
    164292: {"Unified_Ideograph", "Ideographic"},
    164293: {"Unified_Ideograph", "Ideographic"},
    164294: {"Unified_Ideograph", "Ideographic"},
    164295: {"Unified_Ideograph", "Ideographic"},
    164296: {"Unified_Ideograph", "Ideographic"},
    164297: {"Unified_Ideograph", "Ideographic"},
    164298: {"Unified_Ideograph", "Ideographic"},
    164299: {"Unified_Ideograph", "Ideographic"},
    164300: {"Unified_Ideograph", "Ideographic"},
    164301: {"Unified_Ideograph", "Ideographic"},
    164302: {"Unified_Ideograph", "Ideographic"},
    164303: {"Unified_Ideograph", "Ideographic"},
    164304: {"Unified_Ideograph", "Ideographic"},
    164305: {"Unified_Ideograph", "Ideographic"},
    164306: {"Unified_Ideograph", "Ideographic"},
    164307: {"Unified_Ideograph", "Ideographic"},
    164308: {"Unified_Ideograph", "Ideographic"},
    164309: {"Unified_Ideograph", "Ideographic"},
    164310: {"Unified_Ideograph", "Ideographic"},
    164311: {"Unified_Ideograph", "Ideographic"},
    164312: {"Unified_Ideograph", "Ideographic"},
    164313: {"Unified_Ideograph", "Ideographic"},
    164314: {"Unified_Ideograph", "Ideographic"},
    164315: {"Unified_Ideograph", "Ideographic"},
    164316: {"Unified_Ideograph", "Ideographic"},
    164317: {"Unified_Ideograph", "Ideographic"},
    164318: {"Unified_Ideograph", "Ideographic"},
    164319: {"Unified_Ideograph", "Ideographic"},
    164320: {"Unified_Ideograph", "Ideographic"},
    164321: {"Unified_Ideograph", "Ideographic"},
    164322: {"Unified_Ideograph", "Ideographic"},
    164323: {"Unified_Ideograph", "Ideographic"},
    164324: {"Unified_Ideograph", "Ideographic"},
    164325: {"Unified_Ideograph", "Ideographic"},
    164326: {"Unified_Ideograph", "Ideographic"},
    164327: {"Unified_Ideograph", "Ideographic"},
    164328: {"Unified_Ideograph", "Ideographic"},
    164329: {"Unified_Ideograph", "Ideographic"},
    164330: {"Unified_Ideograph", "Ideographic"},
    164331: {"Unified_Ideograph", "Ideographic"},
    164332: {"Unified_Ideograph", "Ideographic"},
    164333: {"Unified_Ideograph", "Ideographic"},
    164334: {"Unified_Ideograph", "Ideographic"},
    164335: {"Unified_Ideograph", "Ideographic"},
    164336: {"Unified_Ideograph", "Ideographic"},
    164337: {"Unified_Ideograph", "Ideographic"},
    164338: {"Unified_Ideograph", "Ideographic"},
    164339: {"Unified_Ideograph", "Ideographic"},
    164340: {"Unified_Ideograph", "Ideographic"},
    164341: {"Unified_Ideograph", "Ideographic"},
    164342: {"Unified_Ideograph", "Ideographic"},
    164343: {"Unified_Ideograph", "Ideographic"},
    164344: {"Unified_Ideograph", "Ideographic"},
    164345: {"Unified_Ideograph", "Ideographic"},
    164346: {"Unified_Ideograph", "Ideographic"},
    164347: {"Unified_Ideograph", "Ideographic"},
    164348: {"Unified_Ideograph", "Ideographic"},
    164349: {"Unified_Ideograph", "Ideographic"},
    164350: {"Unified_Ideograph", "Ideographic"},
    164351: {"Unified_Ideograph", "Ideographic"},
    164352: {"Unified_Ideograph", "Ideographic"},
    164353: {"Unified_Ideograph", "Ideographic"},
    164354: {"Unified_Ideograph", "Ideographic"},
    164355: {"Unified_Ideograph", "Ideographic"},
    164356: {"Unified_Ideograph", "Ideographic"},
    164357: {"Unified_Ideograph", "Ideographic"},
    164358: {"Unified_Ideograph", "Ideographic"},
    164359: {"Unified_Ideograph", "Ideographic"},
    164360: {"Unified_Ideograph", "Ideographic"},
    164361: {"Unified_Ideograph", "Ideographic"},
    164362: {"Unified_Ideograph", "Ideographic"},
    164363: {"Unified_Ideograph", "Ideographic"},
    164364: {"Unified_Ideograph", "Ideographic"},
    164365: {"Unified_Ideograph", "Ideographic"},
    164366: {"Unified_Ideograph", "Ideographic"},
    164367: {"Unified_Ideograph", "Ideographic"},
    164368: {"Unified_Ideograph", "Ideographic"},
    164369: {"Unified_Ideograph", "Ideographic"},
    164370: {"Unified_Ideograph", "Ideographic"},
    164371: {"Unified_Ideograph", "Ideographic"},
    164372: {"Unified_Ideograph", "Ideographic"},
    164373: {"Unified_Ideograph", "Ideographic"},
    164374: {"Unified_Ideograph", "Ideographic"},
    164375: {"Unified_Ideograph", "Ideographic"},
    164376: {"Unified_Ideograph", "Ideographic"},
    164377: {"Unified_Ideograph", "Ideographic"},
    164378: {"Unified_Ideograph", "Ideographic"},
    164379: {"Unified_Ideograph", "Ideographic"},
    164380: {"Unified_Ideograph", "Ideographic"},
    164381: {"Unified_Ideograph", "Ideographic"},
    164382: {"Unified_Ideograph", "Ideographic"},
    164383: {"Unified_Ideograph", "Ideographic"},
    164384: {"Unified_Ideograph", "Ideographic"},
    164385: {"Unified_Ideograph", "Ideographic"},
    164386: {"Unified_Ideograph", "Ideographic"},
    164387: {"Unified_Ideograph", "Ideographic"},
    164388: {"Unified_Ideograph", "Ideographic"},
    164389: {"Unified_Ideograph", "Ideographic"},
    164390: {"Unified_Ideograph", "Ideographic"},
    164391: {"Unified_Ideograph", "Ideographic"},
    164392: {"Unified_Ideograph", "Ideographic"},
    164393: {"Unified_Ideograph", "Ideographic"},
    164394: {"Unified_Ideograph", "Ideographic"},
    164395: {"Unified_Ideograph", "Ideographic"},
    164396: {"Unified_Ideograph", "Ideographic"},
    164397: {"Unified_Ideograph", "Ideographic"},
    164398: {"Unified_Ideograph", "Ideographic"},
    164399: {"Unified_Ideograph", "Ideographic"},
    164400: {"Unified_Ideograph", "Ideographic"},
    164401: {"Unified_Ideograph", "Ideographic"},
    164402: {"Unified_Ideograph", "Ideographic"},
    164403: {"Unified_Ideograph", "Ideographic"},
    164404: {"Unified_Ideograph", "Ideographic"},
    164405: {"Unified_Ideograph", "Ideographic"},
    164406: {"Unified_Ideograph", "Ideographic"},
    164407: {"Unified_Ideograph", "Ideographic"},
    164408: {"Unified_Ideograph", "Ideographic"},
    164409: {"Unified_Ideograph", "Ideographic"},
    164410: {"Unified_Ideograph", "Ideographic"},
    164411: {"Unified_Ideograph", "Ideographic"},
    164412: {"Unified_Ideograph", "Ideographic"},
    164413: {"Unified_Ideograph", "Ideographic"},
    164414: {"Unified_Ideograph", "Ideographic"},
    164415: {"Unified_Ideograph", "Ideographic"},
    164416: {"Unified_Ideograph", "Ideographic"},
    164417: {"Unified_Ideograph", "Ideographic"},
    164418: {"Unified_Ideograph", "Ideographic"},
    164419: {"Unified_Ideograph", "Ideographic"},
    164420: {"Unified_Ideograph", "Ideographic"},
    164421: {"Unified_Ideograph", "Ideographic"},
    164422: {"Unified_Ideograph", "Ideographic"},
    164423: {"Unified_Ideograph", "Ideographic"},
    164424: {"Unified_Ideograph", "Ideographic"},
    164425: {"Unified_Ideograph", "Ideographic"},
    164426: {"Unified_Ideograph", "Ideographic"},
    164427: {"Unified_Ideograph", "Ideographic"},
    164428: {"Unified_Ideograph", "Ideographic"},
    164429: {"Unified_Ideograph", "Ideographic"},
    164430: {"Unified_Ideograph", "Ideographic"},
    164431: {"Unified_Ideograph", "Ideographic"},
    164432: {"Unified_Ideograph", "Ideographic"},
    164433: {"Unified_Ideograph", "Ideographic"},
    164434: {"Unified_Ideograph", "Ideographic"},
    164435: {"Unified_Ideograph", "Ideographic"},
    164436: {"Unified_Ideograph", "Ideographic"},
    164437: {"Unified_Ideograph", "Ideographic"},
    164438: {"Unified_Ideograph", "Ideographic"},
    164439: {"Unified_Ideograph", "Ideographic"},
    164440: {"Unified_Ideograph", "Ideographic"},
    164441: {"Unified_Ideograph", "Ideographic"},
    164442: {"Unified_Ideograph", "Ideographic"},
    164443: {"Unified_Ideograph", "Ideographic"},
    164444: {"Unified_Ideograph", "Ideographic"},
    164445: {"Unified_Ideograph", "Ideographic"},
    164446: {"Unified_Ideograph", "Ideographic"},
    164447: {"Unified_Ideograph", "Ideographic"},
    164448: {"Unified_Ideograph", "Ideographic"},
    164449: {"Unified_Ideograph", "Ideographic"},
    164450: {"Unified_Ideograph", "Ideographic"},
    164451: {"Unified_Ideograph", "Ideographic"},
    164452: {"Unified_Ideograph", "Ideographic"},
    164453: {"Unified_Ideograph", "Ideographic"},
    164454: {"Unified_Ideograph", "Ideographic"},
    164455: {"Unified_Ideograph", "Ideographic"},
    164456: {"Unified_Ideograph", "Ideographic"},
    164457: {"Unified_Ideograph", "Ideographic"},
    164458: {"Unified_Ideograph", "Ideographic"},
    164459: {"Unified_Ideograph", "Ideographic"},
    164460: {"Unified_Ideograph", "Ideographic"},
    164461: {"Unified_Ideograph", "Ideographic"},
    164462: {"Unified_Ideograph", "Ideographic"},
    164463: {"Unified_Ideograph", "Ideographic"},
    164464: {"Unified_Ideograph", "Ideographic"},
    164465: {"Unified_Ideograph", "Ideographic"},
    164466: {"Unified_Ideograph", "Ideographic"},
    164467: {"Unified_Ideograph", "Ideographic"},
    164468: {"Unified_Ideograph", "Ideographic"},
    164469: {"Unified_Ideograph", "Ideographic"},
    164470: {"Unified_Ideograph", "Ideographic"},
    164471: {"Unified_Ideograph", "Ideographic"},
    164472: {"Unified_Ideograph", "Ideographic"},
    164473: {"Unified_Ideograph", "Ideographic"},
    164474: {"Unified_Ideograph", "Ideographic"},
    164475: {"Unified_Ideograph", "Ideographic"},
    164476: {"Unified_Ideograph", "Ideographic"},
    164477: {"Unified_Ideograph", "Ideographic"},
    164478: {"Unified_Ideograph", "Ideographic"},
    164479: {"Unified_Ideograph", "Ideographic"},
    164480: {"Unified_Ideograph", "Ideographic"},
    164481: {"Unified_Ideograph", "Ideographic"},
    164482: {"Unified_Ideograph", "Ideographic"},
    164483: {"Unified_Ideograph", "Ideographic"},
    164484: {"Unified_Ideograph", "Ideographic"},
    164485: {"Unified_Ideograph", "Ideographic"},
    164486: {"Unified_Ideograph", "Ideographic"},
    164487: {"Unified_Ideograph", "Ideographic"},
    164488: {"Unified_Ideograph", "Ideographic"},
    164489: {"Unified_Ideograph", "Ideographic"},
    164490: {"Unified_Ideograph", "Ideographic"},
    164491: {"Unified_Ideograph", "Ideographic"},
    164492: {"Unified_Ideograph", "Ideographic"},
    164493: {"Unified_Ideograph", "Ideographic"},
    164494: {"Unified_Ideograph", "Ideographic"},
    164495: {"Unified_Ideograph", "Ideographic"},
    164496: {"Unified_Ideograph", "Ideographic"},
    164497: {"Unified_Ideograph", "Ideographic"},
    164498: {"Unified_Ideograph", "Ideographic"},
    164499: {"Unified_Ideograph", "Ideographic"},
    164500: {"Unified_Ideograph", "Ideographic"},
    164501: {"Unified_Ideograph", "Ideographic"},
    164502: {"Unified_Ideograph", "Ideographic"},
    164503: {"Unified_Ideograph", "Ideographic"},
    164504: {"Unified_Ideograph", "Ideographic"},
    164505: {"Unified_Ideograph", "Ideographic"},
    164506: {"Unified_Ideograph", "Ideographic"},
    164507: {"Unified_Ideograph", "Ideographic"},
    164508: {"Unified_Ideograph", "Ideographic"},
    164509: {"Unified_Ideograph", "Ideographic"},
    164510: {"Unified_Ideograph", "Ideographic"},
    164511: {"Unified_Ideograph", "Ideographic"},
    164512: {"Unified_Ideograph", "Ideographic"},
    164513: {"Unified_Ideograph", "Ideographic"},
    164514: {"Unified_Ideograph", "Ideographic"},
    164515: {"Unified_Ideograph", "Ideographic"},
    164516: {"Unified_Ideograph", "Ideographic"},
    164517: {"Unified_Ideograph", "Ideographic"},
    164518: {"Unified_Ideograph", "Ideographic"},
    164519: {"Unified_Ideograph", "Ideographic"},
    164520: {"Unified_Ideograph", "Ideographic"},
    164521: {"Unified_Ideograph", "Ideographic"},
    164522: {"Unified_Ideograph", "Ideographic"},
    164523: {"Unified_Ideograph", "Ideographic"},
    164524: {"Unified_Ideograph", "Ideographic"},
    164525: {"Unified_Ideograph", "Ideographic"},
    164526: {"Unified_Ideograph", "Ideographic"},
    164527: {"Unified_Ideograph", "Ideographic"},
    164528: {"Unified_Ideograph", "Ideographic"},
    164529: {"Unified_Ideograph", "Ideographic"},
    164530: {"Unified_Ideograph", "Ideographic"},
    164531: {"Unified_Ideograph", "Ideographic"},
    164532: {"Unified_Ideograph", "Ideographic"},
    164533: {"Unified_Ideograph", "Ideographic"},
    164534: {"Unified_Ideograph", "Ideographic"},
    164535: {"Unified_Ideograph", "Ideographic"},
    164536: {"Unified_Ideograph", "Ideographic"},
    164537: {"Unified_Ideograph", "Ideographic"},
    164538: {"Unified_Ideograph", "Ideographic"},
    164539: {"Unified_Ideograph", "Ideographic"},
    164540: {"Unified_Ideograph", "Ideographic"},
    164541: {"Unified_Ideograph", "Ideographic"},
    164542: {"Unified_Ideograph", "Ideographic"},
    164543: {"Unified_Ideograph", "Ideographic"},
    164544: {"Unified_Ideograph", "Ideographic"},
    164545: {"Unified_Ideograph", "Ideographic"},
    164546: {"Unified_Ideograph", "Ideographic"},
    164547: {"Unified_Ideograph", "Ideographic"},
    164548: {"Unified_Ideograph", "Ideographic"},
    164549: {"Unified_Ideograph", "Ideographic"},
    164550: {"Unified_Ideograph", "Ideographic"},
    164551: {"Unified_Ideograph", "Ideographic"},
    164552: {"Unified_Ideograph", "Ideographic"},
    164553: {"Unified_Ideograph", "Ideographic"},
    164554: {"Unified_Ideograph", "Ideographic"},
    164555: {"Unified_Ideograph", "Ideographic"},
    164556: {"Unified_Ideograph", "Ideographic"},
    164557: {"Unified_Ideograph", "Ideographic"},
    164558: {"Unified_Ideograph", "Ideographic"},
    164559: {"Unified_Ideograph", "Ideographic"},
    164560: {"Unified_Ideograph", "Ideographic"},
    164561: {"Unified_Ideograph", "Ideographic"},
    164562: {"Unified_Ideograph", "Ideographic"},
    164563: {"Unified_Ideograph", "Ideographic"},
    164564: {"Unified_Ideograph", "Ideographic"},
    164565: {"Unified_Ideograph", "Ideographic"},
    164566: {"Unified_Ideograph", "Ideographic"},
    164567: {"Unified_Ideograph", "Ideographic"},
    164568: {"Unified_Ideograph", "Ideographic"},
    164569: {"Unified_Ideograph", "Ideographic"},
    164570: {"Unified_Ideograph", "Ideographic"},
    164571: {"Unified_Ideograph", "Ideographic"},
    164572: {"Unified_Ideograph", "Ideographic"},
    164573: {"Unified_Ideograph", "Ideographic"},
    164574: {"Unified_Ideograph", "Ideographic"},
    164575: {"Unified_Ideograph", "Ideographic"},
    164576: {"Unified_Ideograph", "Ideographic"},
    164577: {"Unified_Ideograph", "Ideographic"},
    164578: {"Unified_Ideograph", "Ideographic"},
    164579: {"Unified_Ideograph", "Ideographic"},
    164580: {"Unified_Ideograph", "Ideographic"},
    164581: {"Unified_Ideograph", "Ideographic"},
    164582: {"Unified_Ideograph", "Ideographic"},
    164583: {"Unified_Ideograph", "Ideographic"},
    164584: {"Unified_Ideograph", "Ideographic"},
    164585: {"Unified_Ideograph", "Ideographic"},
    164586: {"Unified_Ideograph", "Ideographic"},
    164587: {"Unified_Ideograph", "Ideographic"},
    164588: {"Unified_Ideograph", "Ideographic"},
    164589: {"Unified_Ideograph", "Ideographic"},
    164590: {"Unified_Ideograph", "Ideographic"},
    164591: {"Unified_Ideograph", "Ideographic"},
    164592: {"Unified_Ideograph", "Ideographic"},
    164593: {"Unified_Ideograph", "Ideographic"},
    164594: {"Unified_Ideograph", "Ideographic"},
    164595: {"Unified_Ideograph", "Ideographic"},
    164596: {"Unified_Ideograph", "Ideographic"},
    164597: {"Unified_Ideograph", "Ideographic"},
    164598: {"Unified_Ideograph", "Ideographic"},
    164599: {"Unified_Ideograph", "Ideographic"},
    164600: {"Unified_Ideograph", "Ideographic"},
    164601: {"Unified_Ideograph", "Ideographic"},
    164602: {"Unified_Ideograph", "Ideographic"},
    164603: {"Unified_Ideograph", "Ideographic"},
    164604: {"Unified_Ideograph", "Ideographic"},
    164605: {"Unified_Ideograph", "Ideographic"},
    164606: {"Unified_Ideograph", "Ideographic"},
    164607: {"Unified_Ideograph", "Ideographic"},
    164608: {"Unified_Ideograph", "Ideographic"},
    164609: {"Unified_Ideograph", "Ideographic"},
    164610: {"Unified_Ideograph", "Ideographic"},
    164611: {"Unified_Ideograph", "Ideographic"},
    164612: {"Unified_Ideograph", "Ideographic"},
    164613: {"Unified_Ideograph", "Ideographic"},
    164614: {"Unified_Ideograph", "Ideographic"},
    164615: {"Unified_Ideograph", "Ideographic"},
    164616: {"Unified_Ideograph", "Ideographic"},
    164617: {"Unified_Ideograph", "Ideographic"},
    164618: {"Unified_Ideograph", "Ideographic"},
    164619: {"Unified_Ideograph", "Ideographic"},
    164620: {"Unified_Ideograph", "Ideographic"},
    164621: {"Unified_Ideograph", "Ideographic"},
    164622: {"Unified_Ideograph", "Ideographic"},
    164623: {"Unified_Ideograph", "Ideographic"},
    164624: {"Unified_Ideograph", "Ideographic"},
    164625: {"Unified_Ideograph", "Ideographic"},
    164626: {"Unified_Ideograph", "Ideographic"},
    164627: {"Unified_Ideograph", "Ideographic"},
    164628: {"Unified_Ideograph", "Ideographic"},
    164629: {"Unified_Ideograph", "Ideographic"},
    164630: {"Unified_Ideograph", "Ideographic"},
    164631: {"Unified_Ideograph", "Ideographic"},
    164632: {"Unified_Ideograph", "Ideographic"},
    164633: {"Unified_Ideograph", "Ideographic"},
    164634: {"Unified_Ideograph", "Ideographic"},
    164635: {"Unified_Ideograph", "Ideographic"},
    164636: {"Unified_Ideograph", "Ideographic"},
    164637: {"Unified_Ideograph", "Ideographic"},
    164638: {"Unified_Ideograph", "Ideographic"},
    164639: {"Unified_Ideograph", "Ideographic"},
    164640: {"Unified_Ideograph", "Ideographic"},
    164641: {"Unified_Ideograph", "Ideographic"},
    164642: {"Unified_Ideograph", "Ideographic"},
    164643: {"Unified_Ideograph", "Ideographic"},
    164644: {"Unified_Ideograph", "Ideographic"},
    164645: {"Unified_Ideograph", "Ideographic"},
    164646: {"Unified_Ideograph", "Ideographic"},
    164647: {"Unified_Ideograph", "Ideographic"},
    164648: {"Unified_Ideograph", "Ideographic"},
    164649: {"Unified_Ideograph", "Ideographic"},
    164650: {"Unified_Ideograph", "Ideographic"},
    164651: {"Unified_Ideograph", "Ideographic"},
    164652: {"Unified_Ideograph", "Ideographic"},
    164653: {"Unified_Ideograph", "Ideographic"},
    164654: {"Unified_Ideograph", "Ideographic"},
    164655: {"Unified_Ideograph", "Ideographic"},
    164656: {"Unified_Ideograph", "Ideographic"},
    164657: {"Unified_Ideograph", "Ideographic"},
    164658: {"Unified_Ideograph", "Ideographic"},
    164659: {"Unified_Ideograph", "Ideographic"},
    164660: {"Unified_Ideograph", "Ideographic"},
    164661: {"Unified_Ideograph", "Ideographic"},
    164662: {"Unified_Ideograph", "Ideographic"},
    164663: {"Unified_Ideograph", "Ideographic"},
    164664: {"Unified_Ideograph", "Ideographic"},
    164665: {"Unified_Ideograph", "Ideographic"},
    164666: {"Unified_Ideograph", "Ideographic"},
    164667: {"Unified_Ideograph", "Ideographic"},
    164668: {"Unified_Ideograph", "Ideographic"},
    164669: {"Unified_Ideograph", "Ideographic"},
    164670: {"Unified_Ideograph", "Ideographic"},
    164671: {"Unified_Ideograph", "Ideographic"},
    164672: {"Unified_Ideograph", "Ideographic"},
    164673: {"Unified_Ideograph", "Ideographic"},
    164674: {"Unified_Ideograph", "Ideographic"},
    164675: {"Unified_Ideograph", "Ideographic"},
    164676: {"Unified_Ideograph", "Ideographic"},
    164677: {"Unified_Ideograph", "Ideographic"},
    164678: {"Unified_Ideograph", "Ideographic"},
    164679: {"Unified_Ideograph", "Ideographic"},
    164680: {"Unified_Ideograph", "Ideographic"},
    164681: {"Unified_Ideograph", "Ideographic"},
    164682: {"Unified_Ideograph", "Ideographic"},
    164683: {"Unified_Ideograph", "Ideographic"},
    164684: {"Unified_Ideograph", "Ideographic"},
    164685: {"Unified_Ideograph", "Ideographic"},
    164686: {"Unified_Ideograph", "Ideographic"},
    164687: {"Unified_Ideograph", "Ideographic"},
    164688: {"Unified_Ideograph", "Ideographic"},
    164689: {"Unified_Ideograph", "Ideographic"},
    164690: {"Unified_Ideograph", "Ideographic"},
    164691: {"Unified_Ideograph", "Ideographic"},
    164692: {"Unified_Ideograph", "Ideographic"},
    164693: {"Unified_Ideograph", "Ideographic"},
    164694: {"Unified_Ideograph", "Ideographic"},
    164695: {"Unified_Ideograph", "Ideographic"},
    164696: {"Unified_Ideograph", "Ideographic"},
    164697: {"Unified_Ideograph", "Ideographic"},
    164698: {"Unified_Ideograph", "Ideographic"},
    164699: {"Unified_Ideograph", "Ideographic"},
    164700: {"Unified_Ideograph", "Ideographic"},
    164701: {"Unified_Ideograph", "Ideographic"},
    164702: {"Unified_Ideograph", "Ideographic"},
    164703: {"Unified_Ideograph", "Ideographic"},
    164704: {"Unified_Ideograph", "Ideographic"},
    164705: {"Unified_Ideograph", "Ideographic"},
    164706: {"Unified_Ideograph", "Ideographic"},
    164707: {"Unified_Ideograph", "Ideographic"},
    164708: {"Unified_Ideograph", "Ideographic"},
    164709: {"Unified_Ideograph", "Ideographic"},
    164710: {"Unified_Ideograph", "Ideographic"},
    164711: {"Unified_Ideograph", "Ideographic"},
    164712: {"Unified_Ideograph", "Ideographic"},
    164713: {"Unified_Ideograph", "Ideographic"},
    164714: {"Unified_Ideograph", "Ideographic"},
    164715: {"Unified_Ideograph", "Ideographic"},
    164716: {"Unified_Ideograph", "Ideographic"},
    164717: {"Unified_Ideograph", "Ideographic"},
    164718: {"Unified_Ideograph", "Ideographic"},
    164719: {"Unified_Ideograph", "Ideographic"},
    164720: {"Unified_Ideograph", "Ideographic"},
    164721: {"Unified_Ideograph", "Ideographic"},
    164722: {"Unified_Ideograph", "Ideographic"},
    164723: {"Unified_Ideograph", "Ideographic"},
    164724: {"Unified_Ideograph", "Ideographic"},
    164725: {"Unified_Ideograph", "Ideographic"},
    164726: {"Unified_Ideograph", "Ideographic"},
    164727: {"Unified_Ideograph", "Ideographic"},
    164728: {"Unified_Ideograph", "Ideographic"},
    164729: {"Unified_Ideograph", "Ideographic"},
    164730: {"Unified_Ideograph", "Ideographic"},
    164731: {"Unified_Ideograph", "Ideographic"},
    164732: {"Unified_Ideograph", "Ideographic"},
    164733: {"Unified_Ideograph", "Ideographic"},
    164734: {"Unified_Ideograph", "Ideographic"},
    164735: {"Unified_Ideograph", "Ideographic"},
    164736: {"Unified_Ideograph", "Ideographic"},
    164737: {"Unified_Ideograph", "Ideographic"},
    164738: {"Unified_Ideograph", "Ideographic"},
    164739: {"Unified_Ideograph", "Ideographic"},
    164740: {"Unified_Ideograph", "Ideographic"},
    164741: {"Unified_Ideograph", "Ideographic"},
    164742: {"Unified_Ideograph", "Ideographic"},
    164743: {"Unified_Ideograph", "Ideographic"},
    164744: {"Unified_Ideograph", "Ideographic"},
    164745: {"Unified_Ideograph", "Ideographic"},
    164746: {"Unified_Ideograph", "Ideographic"},
    164747: {"Unified_Ideograph", "Ideographic"},
    164748: {"Unified_Ideograph", "Ideographic"},
    164749: {"Unified_Ideograph", "Ideographic"},
    164750: {"Unified_Ideograph", "Ideographic"},
    164751: {"Unified_Ideograph", "Ideographic"},
    164752: {"Unified_Ideograph", "Ideographic"},
    164753: {"Unified_Ideograph", "Ideographic"},
    164754: {"Unified_Ideograph", "Ideographic"},
    164755: {"Unified_Ideograph", "Ideographic"},
    164756: {"Unified_Ideograph", "Ideographic"},
    164757: {"Unified_Ideograph", "Ideographic"},
    164758: {"Unified_Ideograph", "Ideographic"},
    164759: {"Unified_Ideograph", "Ideographic"},
    164760: {"Unified_Ideograph", "Ideographic"},
    164761: {"Unified_Ideograph", "Ideographic"},
    164762: {"Unified_Ideograph", "Ideographic"},
    164763: {"Unified_Ideograph", "Ideographic"},
    164764: {"Unified_Ideograph", "Ideographic"},
    164765: {"Unified_Ideograph", "Ideographic"},
    164766: {"Unified_Ideograph", "Ideographic"},
    164767: {"Unified_Ideograph", "Ideographic"},
    164768: {"Unified_Ideograph", "Ideographic"},
    164769: {"Unified_Ideograph", "Ideographic"},
    164770: {"Unified_Ideograph", "Ideographic"},
    164771: {"Unified_Ideograph", "Ideographic"},
    164772: {"Unified_Ideograph", "Ideographic"},
    164773: {"Unified_Ideograph", "Ideographic"},
    164774: {"Unified_Ideograph", "Ideographic"},
    164775: {"Unified_Ideograph", "Ideographic"},
    164776: {"Unified_Ideograph", "Ideographic"},
    164777: {"Unified_Ideograph", "Ideographic"},
    164778: {"Unified_Ideograph", "Ideographic"},
    164779: {"Unified_Ideograph", "Ideographic"},
    164780: {"Unified_Ideograph", "Ideographic"},
    164781: {"Unified_Ideograph", "Ideographic"},
    164782: {"Unified_Ideograph", "Ideographic"},
    164783: {"Unified_Ideograph", "Ideographic"},
    164784: {"Unified_Ideograph", "Ideographic"},
    164785: {"Unified_Ideograph", "Ideographic"},
    164786: {"Unified_Ideograph", "Ideographic"},
    164787: {"Unified_Ideograph", "Ideographic"},
    164788: {"Unified_Ideograph", "Ideographic"},
    164789: {"Unified_Ideograph", "Ideographic"},
    164790: {"Unified_Ideograph", "Ideographic"},
    164791: {"Unified_Ideograph", "Ideographic"},
    164792: {"Unified_Ideograph", "Ideographic"},
    164793: {"Unified_Ideograph", "Ideographic"},
    164794: {"Unified_Ideograph", "Ideographic"},
    164795: {"Unified_Ideograph", "Ideographic"},
    164796: {"Unified_Ideograph", "Ideographic"},
    164797: {"Unified_Ideograph", "Ideographic"},
    164798: {"Unified_Ideograph", "Ideographic"},
    164799: {"Unified_Ideograph", "Ideographic"},
    164800: {"Unified_Ideograph", "Ideographic"},
    164801: {"Unified_Ideograph", "Ideographic"},
    164802: {"Unified_Ideograph", "Ideographic"},
    164803: {"Unified_Ideograph", "Ideographic"},
    164804: {"Unified_Ideograph", "Ideographic"},
    164805: {"Unified_Ideograph", "Ideographic"},
    164806: {"Unified_Ideograph", "Ideographic"},
    164807: {"Unified_Ideograph", "Ideographic"},
    164808: {"Unified_Ideograph", "Ideographic"},
    164809: {"Unified_Ideograph", "Ideographic"},
    164810: {"Unified_Ideograph", "Ideographic"},
    164811: {"Unified_Ideograph", "Ideographic"},
    164812: {"Unified_Ideograph", "Ideographic"},
    164813: {"Unified_Ideograph", "Ideographic"},
    164814: {"Unified_Ideograph", "Ideographic"},
    164815: {"Unified_Ideograph", "Ideographic"},
    164816: {"Unified_Ideograph", "Ideographic"},
    164817: {"Unified_Ideograph", "Ideographic"},
    164818: {"Unified_Ideograph", "Ideographic"},
    164819: {"Unified_Ideograph", "Ideographic"},
    164820: {"Unified_Ideograph", "Ideographic"},
    164821: {"Unified_Ideograph", "Ideographic"},
    164822: {"Unified_Ideograph", "Ideographic"},
    164823: {"Unified_Ideograph", "Ideographic"},
    164824: {"Unified_Ideograph", "Ideographic"},
    164825: {"Unified_Ideograph", "Ideographic"},
    164826: {"Unified_Ideograph", "Ideographic"},
    164827: {"Unified_Ideograph", "Ideographic"},
    164828: {"Unified_Ideograph", "Ideographic"},
    164829: {"Unified_Ideograph", "Ideographic"},
    164830: {"Unified_Ideograph", "Ideographic"},
    164831: {"Unified_Ideograph", "Ideographic"},
    164832: {"Unified_Ideograph", "Ideographic"},
    164833: {"Unified_Ideograph", "Ideographic"},
    164834: {"Unified_Ideograph", "Ideographic"},
    164835: {"Unified_Ideograph", "Ideographic"},
    164836: {"Unified_Ideograph", "Ideographic"},
    164837: {"Unified_Ideograph", "Ideographic"},
    164838: {"Unified_Ideograph", "Ideographic"},
    164839: {"Unified_Ideograph", "Ideographic"},
    164840: {"Unified_Ideograph", "Ideographic"},
    164841: {"Unified_Ideograph", "Ideographic"},
    164842: {"Unified_Ideograph", "Ideographic"},
    164843: {"Unified_Ideograph", "Ideographic"},
    164844: {"Unified_Ideograph", "Ideographic"},
    164845: {"Unified_Ideograph", "Ideographic"},
    164846: {"Unified_Ideograph", "Ideographic"},
    164847: {"Unified_Ideograph", "Ideographic"},
    164848: {"Unified_Ideograph", "Ideographic"},
    164849: {"Unified_Ideograph", "Ideographic"},
    164850: {"Unified_Ideograph", "Ideographic"},
    164851: {"Unified_Ideograph", "Ideographic"},
    164852: {"Unified_Ideograph", "Ideographic"},
    164853: {"Unified_Ideograph", "Ideographic"},
    164854: {"Unified_Ideograph", "Ideographic"},
    164855: {"Unified_Ideograph", "Ideographic"},
    164856: {"Unified_Ideograph", "Ideographic"},
    164857: {"Unified_Ideograph", "Ideographic"},
    164858: {"Unified_Ideograph", "Ideographic"},
    164859: {"Unified_Ideograph", "Ideographic"},
    164860: {"Unified_Ideograph", "Ideographic"},
    164861: {"Unified_Ideograph", "Ideographic"},
    164862: {"Unified_Ideograph", "Ideographic"},
    164863: {"Unified_Ideograph", "Ideographic"},
    164864: {"Unified_Ideograph", "Ideographic"},
    164865: {"Unified_Ideograph", "Ideographic"},
    164866: {"Unified_Ideograph", "Ideographic"},
    164867: {"Unified_Ideograph", "Ideographic"},
    164868: {"Unified_Ideograph", "Ideographic"},
    164869: {"Unified_Ideograph", "Ideographic"},
    164870: {"Unified_Ideograph", "Ideographic"},
    164871: {"Unified_Ideograph", "Ideographic"},
    164872: {"Unified_Ideograph", "Ideographic"},
    164873: {"Unified_Ideograph", "Ideographic"},
    164874: {"Unified_Ideograph", "Ideographic"},
    164875: {"Unified_Ideograph", "Ideographic"},
    164876: {"Unified_Ideograph", "Ideographic"},
    164877: {"Unified_Ideograph", "Ideographic"},
    164878: {"Unified_Ideograph", "Ideographic"},
    164879: {"Unified_Ideograph", "Ideographic"},
    164880: {"Unified_Ideograph", "Ideographic"},
    164881: {"Unified_Ideograph", "Ideographic"},
    164882: {"Unified_Ideograph", "Ideographic"},
    164883: {"Unified_Ideograph", "Ideographic"},
    164884: {"Unified_Ideograph", "Ideographic"},
    164885: {"Unified_Ideograph", "Ideographic"},
    164886: {"Unified_Ideograph", "Ideographic"},
    164887: {"Unified_Ideograph", "Ideographic"},
    164888: {"Unified_Ideograph", "Ideographic"},
    164889: {"Unified_Ideograph", "Ideographic"},
    164890: {"Unified_Ideograph", "Ideographic"},
    164891: {"Unified_Ideograph", "Ideographic"},
    164892: {"Unified_Ideograph", "Ideographic"},
    164893: {"Unified_Ideograph", "Ideographic"},
    164894: {"Unified_Ideograph", "Ideographic"},
    164895: {"Unified_Ideograph", "Ideographic"},
    164896: {"Unified_Ideograph", "Ideographic"},
    164897: {"Unified_Ideograph", "Ideographic"},
    164898: {"Unified_Ideograph", "Ideographic"},
    164899: {"Unified_Ideograph", "Ideographic"},
    164900: {"Unified_Ideograph", "Ideographic"},
    164901: {"Unified_Ideograph", "Ideographic"},
    164902: {"Unified_Ideograph", "Ideographic"},
    164903: {"Unified_Ideograph", "Ideographic"},
    164904: {"Unified_Ideograph", "Ideographic"},
    164905: {"Unified_Ideograph", "Ideographic"},
    164906: {"Unified_Ideograph", "Ideographic"},
    164907: {"Unified_Ideograph", "Ideographic"},
    164908: {"Unified_Ideograph", "Ideographic"},
    164909: {"Unified_Ideograph", "Ideographic"},
    164910: {"Unified_Ideograph", "Ideographic"},
    164911: {"Unified_Ideograph", "Ideographic"},
    164912: {"Unified_Ideograph", "Ideographic"},
    164913: {"Unified_Ideograph", "Ideographic"},
    164914: {"Unified_Ideograph", "Ideographic"},
    164915: {"Unified_Ideograph", "Ideographic"},
    164916: {"Unified_Ideograph", "Ideographic"},
    164917: {"Unified_Ideograph", "Ideographic"},
    164918: {"Unified_Ideograph", "Ideographic"},
    164919: {"Unified_Ideograph", "Ideographic"},
    164920: {"Unified_Ideograph", "Ideographic"},
    164921: {"Unified_Ideograph", "Ideographic"},
    164922: {"Unified_Ideograph", "Ideographic"},
    164923: {"Unified_Ideograph", "Ideographic"},
    164924: {"Unified_Ideograph", "Ideographic"},
    164925: {"Unified_Ideograph", "Ideographic"},
    164926: {"Unified_Ideograph", "Ideographic"},
    164927: {"Unified_Ideograph", "Ideographic"},
    164928: {"Unified_Ideograph", "Ideographic"},
    164929: {"Unified_Ideograph", "Ideographic"},
    164930: {"Unified_Ideograph", "Ideographic"},
    164931: {"Unified_Ideograph", "Ideographic"},
    164932: {"Unified_Ideograph", "Ideographic"},
    164933: {"Unified_Ideograph", "Ideographic"},
    164934: {"Unified_Ideograph", "Ideographic"},
    164935: {"Unified_Ideograph", "Ideographic"},
    164936: {"Unified_Ideograph", "Ideographic"},
    164937: {"Unified_Ideograph", "Ideographic"},
    164938: {"Unified_Ideograph", "Ideographic"},
    164939: {"Unified_Ideograph", "Ideographic"},
    164940: {"Unified_Ideograph", "Ideographic"},
    164941: {"Unified_Ideograph", "Ideographic"},
    164942: {"Unified_Ideograph", "Ideographic"},
    164943: {"Unified_Ideograph", "Ideographic"},
    164944: {"Unified_Ideograph", "Ideographic"},
    164945: {"Unified_Ideograph", "Ideographic"},
    164946: {"Unified_Ideograph", "Ideographic"},
    164947: {"Unified_Ideograph", "Ideographic"},
    164948: {"Unified_Ideograph", "Ideographic"},
    164949: {"Unified_Ideograph", "Ideographic"},
    164950: {"Unified_Ideograph", "Ideographic"},
    164951: {"Unified_Ideograph", "Ideographic"},
    164952: {"Unified_Ideograph", "Ideographic"},
    164953: {"Unified_Ideograph", "Ideographic"},
    164954: {"Unified_Ideograph", "Ideographic"},
    164955: {"Unified_Ideograph", "Ideographic"},
    164956: {"Unified_Ideograph", "Ideographic"},
    164957: {"Unified_Ideograph", "Ideographic"},
    164958: {"Unified_Ideograph", "Ideographic"},
    164959: {"Unified_Ideograph", "Ideographic"},
    164960: {"Unified_Ideograph", "Ideographic"},
    164961: {"Unified_Ideograph", "Ideographic"},
    164962: {"Unified_Ideograph", "Ideographic"},
    164963: {"Unified_Ideograph", "Ideographic"},
    164964: {"Unified_Ideograph", "Ideographic"},
    164965: {"Unified_Ideograph", "Ideographic"},
    164966: {"Unified_Ideograph", "Ideographic"},
    164967: {"Unified_Ideograph", "Ideographic"},
    164968: {"Unified_Ideograph", "Ideographic"},
    164969: {"Unified_Ideograph", "Ideographic"},
    164970: {"Unified_Ideograph", "Ideographic"},
    164971: {"Unified_Ideograph", "Ideographic"},
    164972: {"Unified_Ideograph", "Ideographic"},
    164973: {"Unified_Ideograph", "Ideographic"},
    164974: {"Unified_Ideograph", "Ideographic"},
    164975: {"Unified_Ideograph", "Ideographic"},
    164976: {"Unified_Ideograph", "Ideographic"},
    164977: {"Unified_Ideograph", "Ideographic"},
    164978: {"Unified_Ideograph", "Ideographic"},
    164979: {"Unified_Ideograph", "Ideographic"},
    164980: {"Unified_Ideograph", "Ideographic"},
    164981: {"Unified_Ideograph", "Ideographic"},
    164982: {"Unified_Ideograph", "Ideographic"},
    164983: {"Unified_Ideograph", "Ideographic"},
    164984: {"Unified_Ideograph", "Ideographic"},
    164985: {"Unified_Ideograph", "Ideographic"},
    164986: {"Unified_Ideograph", "Ideographic"},
    164987: {"Unified_Ideograph", "Ideographic"},
    164988: {"Unified_Ideograph", "Ideographic"},
    164989: {"Unified_Ideograph", "Ideographic"},
    164990: {"Unified_Ideograph", "Ideographic"},
    164991: {"Unified_Ideograph", "Ideographic"},
    164992: {"Unified_Ideograph", "Ideographic"},
    164993: {"Unified_Ideograph", "Ideographic"},
    164994: {"Unified_Ideograph", "Ideographic"},
    164995: {"Unified_Ideograph", "Ideographic"},
    164996: {"Unified_Ideograph", "Ideographic"},
    164997: {"Unified_Ideograph", "Ideographic"},
    164998: {"Unified_Ideograph", "Ideographic"},
    164999: {"Unified_Ideograph", "Ideographic"},
    165000: {"Unified_Ideograph", "Ideographic"},
    165001: {"Unified_Ideograph", "Ideographic"},
    165002: {"Unified_Ideograph", "Ideographic"},
    165003: {"Unified_Ideograph", "Ideographic"},
    165004: {"Unified_Ideograph", "Ideographic"},
    165005: {"Unified_Ideograph", "Ideographic"},
    165006: {"Unified_Ideograph", "Ideographic"},
    165007: {"Unified_Ideograph", "Ideographic"},
    165008: {"Unified_Ideograph", "Ideographic"},
    165009: {"Unified_Ideograph", "Ideographic"},
    165010: {"Unified_Ideograph", "Ideographic"},
    165011: {"Unified_Ideograph", "Ideographic"},
    165012: {"Unified_Ideograph", "Ideographic"},
    165013: {"Unified_Ideograph", "Ideographic"},
    165014: {"Unified_Ideograph", "Ideographic"},
    165015: {"Unified_Ideograph", "Ideographic"},
    165016: {"Unified_Ideograph", "Ideographic"},
    165017: {"Unified_Ideograph", "Ideographic"},
    165018: {"Unified_Ideograph", "Ideographic"},
    165019: {"Unified_Ideograph", "Ideographic"},
    165020: {"Unified_Ideograph", "Ideographic"},
    165021: {"Unified_Ideograph", "Ideographic"},
    165022: {"Unified_Ideograph", "Ideographic"},
    165023: {"Unified_Ideograph", "Ideographic"},
    165024: {"Unified_Ideograph", "Ideographic"},
    165025: {"Unified_Ideograph", "Ideographic"},
    165026: {"Unified_Ideograph", "Ideographic"},
    165027: {"Unified_Ideograph", "Ideographic"},
    165028: {"Unified_Ideograph", "Ideographic"},
    165029: {"Unified_Ideograph", "Ideographic"},
    165030: {"Unified_Ideograph", "Ideographic"},
    165031: {"Unified_Ideograph", "Ideographic"},
    165032: {"Unified_Ideograph", "Ideographic"},
    165033: {"Unified_Ideograph", "Ideographic"},
    165034: {"Unified_Ideograph", "Ideographic"},
    165035: {"Unified_Ideograph", "Ideographic"},
    165036: {"Unified_Ideograph", "Ideographic"},
    165037: {"Unified_Ideograph", "Ideographic"},
    165038: {"Unified_Ideograph", "Ideographic"},
    165039: {"Unified_Ideograph", "Ideographic"},
    165040: {"Unified_Ideograph", "Ideographic"},
    165041: {"Unified_Ideograph", "Ideographic"},
    165042: {"Unified_Ideograph", "Ideographic"},
    165043: {"Unified_Ideograph", "Ideographic"},
    165044: {"Unified_Ideograph", "Ideographic"},
    165045: {"Unified_Ideograph", "Ideographic"},
    165046: {"Unified_Ideograph", "Ideographic"},
    165047: {"Unified_Ideograph", "Ideographic"},
    165048: {"Unified_Ideograph", "Ideographic"},
    165049: {"Unified_Ideograph", "Ideographic"},
    165050: {"Unified_Ideograph", "Ideographic"},
    165051: {"Unified_Ideograph", "Ideographic"},
    165052: {"Unified_Ideograph", "Ideographic"},
    165053: {"Unified_Ideograph", "Ideographic"},
    165054: {"Unified_Ideograph", "Ideographic"},
    165055: {"Unified_Ideograph", "Ideographic"},
    165056: {"Unified_Ideograph", "Ideographic"},
    165057: {"Unified_Ideograph", "Ideographic"},
    165058: {"Unified_Ideograph", "Ideographic"},
    165059: {"Unified_Ideograph", "Ideographic"},
    165060: {"Unified_Ideograph", "Ideographic"},
    165061: {"Unified_Ideograph", "Ideographic"},
    165062: {"Unified_Ideograph", "Ideographic"},
    165063: {"Unified_Ideograph", "Ideographic"},
    165064: {"Unified_Ideograph", "Ideographic"},
    165065: {"Unified_Ideograph", "Ideographic"},
    165066: {"Unified_Ideograph", "Ideographic"},
    165067: {"Unified_Ideograph", "Ideographic"},
    165068: {"Unified_Ideograph", "Ideographic"},
    165069: {"Unified_Ideograph", "Ideographic"},
    165070: {"Unified_Ideograph", "Ideographic"},
    165071: {"Unified_Ideograph", "Ideographic"},
    165072: {"Unified_Ideograph", "Ideographic"},
    165073: {"Unified_Ideograph", "Ideographic"},
    165074: {"Unified_Ideograph", "Ideographic"},
    165075: {"Unified_Ideograph", "Ideographic"},
    165076: {"Unified_Ideograph", "Ideographic"},
    165077: {"Unified_Ideograph", "Ideographic"},
    165078: {"Unified_Ideograph", "Ideographic"},
    165079: {"Unified_Ideograph", "Ideographic"},
    165080: {"Unified_Ideograph", "Ideographic"},
    165081: {"Unified_Ideograph", "Ideographic"},
    165082: {"Unified_Ideograph", "Ideographic"},
    165083: {"Unified_Ideograph", "Ideographic"},
    165084: {"Unified_Ideograph", "Ideographic"},
    165085: {"Unified_Ideograph", "Ideographic"},
    165086: {"Unified_Ideograph", "Ideographic"},
    165087: {"Unified_Ideograph", "Ideographic"},
    165088: {"Unified_Ideograph", "Ideographic"},
    165089: {"Unified_Ideograph", "Ideographic"},
    165090: {"Unified_Ideograph", "Ideographic"},
    165091: {"Unified_Ideograph", "Ideographic"},
    165092: {"Unified_Ideograph", "Ideographic"},
    165093: {"Unified_Ideograph", "Ideographic"},
    165094: {"Unified_Ideograph", "Ideographic"},
    165095: {"Unified_Ideograph", "Ideographic"},
    165096: {"Unified_Ideograph", "Ideographic"},
    165097: {"Unified_Ideograph", "Ideographic"},
    165098: {"Unified_Ideograph", "Ideographic"},
    165099: {"Unified_Ideograph", "Ideographic"},
    165100: {"Unified_Ideograph", "Ideographic"},
    165101: {"Unified_Ideograph", "Ideographic"},
    165102: {"Unified_Ideograph", "Ideographic"},
    165103: {"Unified_Ideograph", "Ideographic"},
    165104: {"Unified_Ideograph", "Ideographic"},
    165105: {"Unified_Ideograph", "Ideographic"},
    165106: {"Unified_Ideograph", "Ideographic"},
    165107: {"Unified_Ideograph", "Ideographic"},
    165108: {"Unified_Ideograph", "Ideographic"},
    165109: {"Unified_Ideograph", "Ideographic"},
    165110: {"Unified_Ideograph", "Ideographic"},
    165111: {"Unified_Ideograph", "Ideographic"},
    165112: {"Unified_Ideograph", "Ideographic"},
    165113: {"Unified_Ideograph", "Ideographic"},
    165114: {"Unified_Ideograph", "Ideographic"},
    165115: {"Unified_Ideograph", "Ideographic"},
    165116: {"Unified_Ideograph", "Ideographic"},
    165117: {"Unified_Ideograph", "Ideographic"},
    165118: {"Unified_Ideograph", "Ideographic"},
    165119: {"Unified_Ideograph", "Ideographic"},
    165120: {"Unified_Ideograph", "Ideographic"},
    165121: {"Unified_Ideograph", "Ideographic"},
    165122: {"Unified_Ideograph", "Ideographic"},
    165123: {"Unified_Ideograph", "Ideographic"},
    165124: {"Unified_Ideograph", "Ideographic"},
    165125: {"Unified_Ideograph", "Ideographic"},
    165126: {"Unified_Ideograph", "Ideographic"},
    165127: {"Unified_Ideograph", "Ideographic"},
    165128: {"Unified_Ideograph", "Ideographic"},
    165129: {"Unified_Ideograph", "Ideographic"},
    165130: {"Unified_Ideograph", "Ideographic"},
    165131: {"Unified_Ideograph", "Ideographic"},
    165132: {"Unified_Ideograph", "Ideographic"},
    165133: {"Unified_Ideograph", "Ideographic"},
    165134: {"Unified_Ideograph", "Ideographic"},
    165135: {"Unified_Ideograph", "Ideographic"},
    165136: {"Unified_Ideograph", "Ideographic"},
    165137: {"Unified_Ideograph", "Ideographic"},
    165138: {"Unified_Ideograph", "Ideographic"},
    165139: {"Unified_Ideograph", "Ideographic"},
    165140: {"Unified_Ideograph", "Ideographic"},
    165141: {"Unified_Ideograph", "Ideographic"},
    165142: {"Unified_Ideograph", "Ideographic"},
    165143: {"Unified_Ideograph", "Ideographic"},
    165144: {"Unified_Ideograph", "Ideographic"},
    165145: {"Unified_Ideograph", "Ideographic"},
    165146: {"Unified_Ideograph", "Ideographic"},
    165147: {"Unified_Ideograph", "Ideographic"},
    165148: {"Unified_Ideograph", "Ideographic"},
    165149: {"Unified_Ideograph", "Ideographic"},
    165150: {"Unified_Ideograph", "Ideographic"},
    165151: {"Unified_Ideograph", "Ideographic"},
    165152: {"Unified_Ideograph", "Ideographic"},
    165153: {"Unified_Ideograph", "Ideographic"},
    165154: {"Unified_Ideograph", "Ideographic"},
    165155: {"Unified_Ideograph", "Ideographic"},
    165156: {"Unified_Ideograph", "Ideographic"},
    165157: {"Unified_Ideograph", "Ideographic"},
    165158: {"Unified_Ideograph", "Ideographic"},
    165159: {"Unified_Ideograph", "Ideographic"},
    165160: {"Unified_Ideograph", "Ideographic"},
    165161: {"Unified_Ideograph", "Ideographic"},
    165162: {"Unified_Ideograph", "Ideographic"},
    165163: {"Unified_Ideograph", "Ideographic"},
    165164: {"Unified_Ideograph", "Ideographic"},
    165165: {"Unified_Ideograph", "Ideographic"},
    165166: {"Unified_Ideograph", "Ideographic"},
    165167: {"Unified_Ideograph", "Ideographic"},
    165168: {"Unified_Ideograph", "Ideographic"},
    165169: {"Unified_Ideograph", "Ideographic"},
    165170: {"Unified_Ideograph", "Ideographic"},
    165171: {"Unified_Ideograph", "Ideographic"},
    165172: {"Unified_Ideograph", "Ideographic"},
    165173: {"Unified_Ideograph", "Ideographic"},
    165174: {"Unified_Ideograph", "Ideographic"},
    165175: {"Unified_Ideograph", "Ideographic"},
    165176: {"Unified_Ideograph", "Ideographic"},
    165177: {"Unified_Ideograph", "Ideographic"},
    165178: {"Unified_Ideograph", "Ideographic"},
    165179: {"Unified_Ideograph", "Ideographic"},
    165180: {"Unified_Ideograph", "Ideographic"},
    165181: {"Unified_Ideograph", "Ideographic"},
    165182: {"Unified_Ideograph", "Ideographic"},
    165183: {"Unified_Ideograph", "Ideographic"},
    165184: {"Unified_Ideograph", "Ideographic"},
    165185: {"Unified_Ideograph", "Ideographic"},
    165186: {"Unified_Ideograph", "Ideographic"},
    165187: {"Unified_Ideograph", "Ideographic"},
    165188: {"Unified_Ideograph", "Ideographic"},
    165189: {"Unified_Ideograph", "Ideographic"},
    165190: {"Unified_Ideograph", "Ideographic"},
    165191: {"Unified_Ideograph", "Ideographic"},
    165192: {"Unified_Ideograph", "Ideographic"},
    165193: {"Unified_Ideograph", "Ideographic"},
    165194: {"Unified_Ideograph", "Ideographic"},
    165195: {"Unified_Ideograph", "Ideographic"},
    165196: {"Unified_Ideograph", "Ideographic"},
    165197: {"Unified_Ideograph", "Ideographic"},
    165198: {"Unified_Ideograph", "Ideographic"},
    165199: {"Unified_Ideograph", "Ideographic"},
    165200: {"Unified_Ideograph", "Ideographic"},
    165201: {"Unified_Ideograph", "Ideographic"},
    165202: {"Unified_Ideograph", "Ideographic"},
    165203: {"Unified_Ideograph", "Ideographic"},
    165204: {"Unified_Ideograph", "Ideographic"},
    165205: {"Unified_Ideograph", "Ideographic"},
    165206: {"Unified_Ideograph", "Ideographic"},
    165207: {"Unified_Ideograph", "Ideographic"},
    165208: {"Unified_Ideograph", "Ideographic"},
    165209: {"Unified_Ideograph", "Ideographic"},
    165210: {"Unified_Ideograph", "Ideographic"},
    165211: {"Unified_Ideograph", "Ideographic"},
    165212: {"Unified_Ideograph", "Ideographic"},
    165213: {"Unified_Ideograph", "Ideographic"},
    165214: {"Unified_Ideograph", "Ideographic"},
    165215: {"Unified_Ideograph", "Ideographic"},
    165216: {"Unified_Ideograph", "Ideographic"},
    165217: {"Unified_Ideograph", "Ideographic"},
    165218: {"Unified_Ideograph", "Ideographic"},
    165219: {"Unified_Ideograph", "Ideographic"},
    165220: {"Unified_Ideograph", "Ideographic"},
    165221: {"Unified_Ideograph", "Ideographic"},
    165222: {"Unified_Ideograph", "Ideographic"},
    165223: {"Unified_Ideograph", "Ideographic"},
    165224: {"Unified_Ideograph", "Ideographic"},
    165225: {"Unified_Ideograph", "Ideographic"},
    165226: {"Unified_Ideograph", "Ideographic"},
    165227: {"Unified_Ideograph", "Ideographic"},
    165228: {"Unified_Ideograph", "Ideographic"},
    165229: {"Unified_Ideograph", "Ideographic"},
    165230: {"Unified_Ideograph", "Ideographic"},
    165231: {"Unified_Ideograph", "Ideographic"},
    165232: {"Unified_Ideograph", "Ideographic"},
    165233: {"Unified_Ideograph", "Ideographic"},
    165234: {"Unified_Ideograph", "Ideographic"},
    165235: {"Unified_Ideograph", "Ideographic"},
    165236: {"Unified_Ideograph", "Ideographic"},
    165237: {"Unified_Ideograph", "Ideographic"},
    165238: {"Unified_Ideograph", "Ideographic"},
    165239: {"Unified_Ideograph", "Ideographic"},
    165240: {"Unified_Ideograph", "Ideographic"},
    165241: {"Unified_Ideograph", "Ideographic"},
    165242: {"Unified_Ideograph", "Ideographic"},
    165243: {"Unified_Ideograph", "Ideographic"},
    165244: {"Unified_Ideograph", "Ideographic"},
    165245: {"Unified_Ideograph", "Ideographic"},
    165246: {"Unified_Ideograph", "Ideographic"},
    165247: {"Unified_Ideograph", "Ideographic"},
    165248: {"Unified_Ideograph", "Ideographic"},
    165249: {"Unified_Ideograph", "Ideographic"},
    165250: {"Unified_Ideograph", "Ideographic"},
    165251: {"Unified_Ideograph", "Ideographic"},
    165252: {"Unified_Ideograph", "Ideographic"},
    165253: {"Unified_Ideograph", "Ideographic"},
    165254: {"Unified_Ideograph", "Ideographic"},
    165255: {"Unified_Ideograph", "Ideographic"},
    165256: {"Unified_Ideograph", "Ideographic"},
    165257: {"Unified_Ideograph", "Ideographic"},
    165258: {"Unified_Ideograph", "Ideographic"},
    165259: {"Unified_Ideograph", "Ideographic"},
    165260: {"Unified_Ideograph", "Ideographic"},
    165261: {"Unified_Ideograph", "Ideographic"},
    165262: {"Unified_Ideograph", "Ideographic"},
    165263: {"Unified_Ideograph", "Ideographic"},
    165264: {"Unified_Ideograph", "Ideographic"},
    165265: {"Unified_Ideograph", "Ideographic"},
    165266: {"Unified_Ideograph", "Ideographic"},
    165267: {"Unified_Ideograph", "Ideographic"},
    165268: {"Unified_Ideograph", "Ideographic"},
    165269: {"Unified_Ideograph", "Ideographic"},
    165270: {"Unified_Ideograph", "Ideographic"},
    165271: {"Unified_Ideograph", "Ideographic"},
    165272: {"Unified_Ideograph", "Ideographic"},
    165273: {"Unified_Ideograph", "Ideographic"},
    165274: {"Unified_Ideograph", "Ideographic"},
    165275: {"Unified_Ideograph", "Ideographic"},
    165276: {"Unified_Ideograph", "Ideographic"},
    165277: {"Unified_Ideograph", "Ideographic"},
    165278: {"Unified_Ideograph", "Ideographic"},
    165279: {"Unified_Ideograph", "Ideographic"},
    165280: {"Unified_Ideograph", "Ideographic"},
    165281: {"Unified_Ideograph", "Ideographic"},
    165282: {"Unified_Ideograph", "Ideographic"},
    165283: {"Unified_Ideograph", "Ideographic"},
    165284: {"Unified_Ideograph", "Ideographic"},
    165285: {"Unified_Ideograph", "Ideographic"},
    165286: {"Unified_Ideograph", "Ideographic"},
    165287: {"Unified_Ideograph", "Ideographic"},
    165288: {"Unified_Ideograph", "Ideographic"},
    165289: {"Unified_Ideograph", "Ideographic"},
    165290: {"Unified_Ideograph", "Ideographic"},
    165291: {"Unified_Ideograph", "Ideographic"},
    165292: {"Unified_Ideograph", "Ideographic"},
    165293: {"Unified_Ideograph", "Ideographic"},
    165294: {"Unified_Ideograph", "Ideographic"},
    165295: {"Unified_Ideograph", "Ideographic"},
    165296: {"Unified_Ideograph", "Ideographic"},
    165297: {"Unified_Ideograph", "Ideographic"},
    165298: {"Unified_Ideograph", "Ideographic"},
    165299: {"Unified_Ideograph", "Ideographic"},
    165300: {"Unified_Ideograph", "Ideographic"},
    165301: {"Unified_Ideograph", "Ideographic"},
    165302: {"Unified_Ideograph", "Ideographic"},
    165303: {"Unified_Ideograph", "Ideographic"},
    165304: {"Unified_Ideograph", "Ideographic"},
    165305: {"Unified_Ideograph", "Ideographic"},
    165306: {"Unified_Ideograph", "Ideographic"},
    165307: {"Unified_Ideograph", "Ideographic"},
    165308: {"Unified_Ideograph", "Ideographic"},
    165309: {"Unified_Ideograph", "Ideographic"},
    165310: {"Unified_Ideograph", "Ideographic"},
    165311: {"Unified_Ideograph", "Ideographic"},
    165312: {"Unified_Ideograph", "Ideographic"},
    165313: {"Unified_Ideograph", "Ideographic"},
    165314: {"Unified_Ideograph", "Ideographic"},
    165315: {"Unified_Ideograph", "Ideographic"},
    165316: {"Unified_Ideograph", "Ideographic"},
    165317: {"Unified_Ideograph", "Ideographic"},
    165318: {"Unified_Ideograph", "Ideographic"},
    165319: {"Unified_Ideograph", "Ideographic"},
    165320: {"Unified_Ideograph", "Ideographic"},
    165321: {"Unified_Ideograph", "Ideographic"},
    165322: {"Unified_Ideograph", "Ideographic"},
    165323: {"Unified_Ideograph", "Ideographic"},
    165324: {"Unified_Ideograph", "Ideographic"},
    165325: {"Unified_Ideograph", "Ideographic"},
    165326: {"Unified_Ideograph", "Ideographic"},
    165327: {"Unified_Ideograph", "Ideographic"},
    165328: {"Unified_Ideograph", "Ideographic"},
    165329: {"Unified_Ideograph", "Ideographic"},
    165330: {"Unified_Ideograph", "Ideographic"},
    165331: {"Unified_Ideograph", "Ideographic"},
    165332: {"Unified_Ideograph", "Ideographic"},
    165333: {"Unified_Ideograph", "Ideographic"},
    165334: {"Unified_Ideograph", "Ideographic"},
    165335: {"Unified_Ideograph", "Ideographic"},
    165336: {"Unified_Ideograph", "Ideographic"},
    165337: {"Unified_Ideograph", "Ideographic"},
    165338: {"Unified_Ideograph", "Ideographic"},
    165339: {"Unified_Ideograph", "Ideographic"},
    165340: {"Unified_Ideograph", "Ideographic"},
    165341: {"Unified_Ideograph", "Ideographic"},
    165342: {"Unified_Ideograph", "Ideographic"},
    165343: {"Unified_Ideograph", "Ideographic"},
    165344: {"Unified_Ideograph", "Ideographic"},
    165345: {"Unified_Ideograph", "Ideographic"},
    165346: {"Unified_Ideograph", "Ideographic"},
    165347: {"Unified_Ideograph", "Ideographic"},
    165348: {"Unified_Ideograph", "Ideographic"},
    165349: {"Unified_Ideograph", "Ideographic"},
    165350: {"Unified_Ideograph", "Ideographic"},
    165351: {"Unified_Ideograph", "Ideographic"},
    165352: {"Unified_Ideograph", "Ideographic"},
    165353: {"Unified_Ideograph", "Ideographic"},
    165354: {"Unified_Ideograph", "Ideographic"},
    165355: {"Unified_Ideograph", "Ideographic"},
    165356: {"Unified_Ideograph", "Ideographic"},
    165357: {"Unified_Ideograph", "Ideographic"},
    165358: {"Unified_Ideograph", "Ideographic"},
    165359: {"Unified_Ideograph", "Ideographic"},
    165360: {"Unified_Ideograph", "Ideographic"},
    165361: {"Unified_Ideograph", "Ideographic"},
    165362: {"Unified_Ideograph", "Ideographic"},
    165363: {"Unified_Ideograph", "Ideographic"},
    165364: {"Unified_Ideograph", "Ideographic"},
    165365: {"Unified_Ideograph", "Ideographic"},
    165366: {"Unified_Ideograph", "Ideographic"},
    165367: {"Unified_Ideograph", "Ideographic"},
    165368: {"Unified_Ideograph", "Ideographic"},
    165369: {"Unified_Ideograph", "Ideographic"},
    165370: {"Unified_Ideograph", "Ideographic"},
    165371: {"Unified_Ideograph", "Ideographic"},
    165372: {"Unified_Ideograph", "Ideographic"},
    165373: {"Unified_Ideograph", "Ideographic"},
    165374: {"Unified_Ideograph", "Ideographic"},
    165375: {"Unified_Ideograph", "Ideographic"},
    165376: {"Unified_Ideograph", "Ideographic"},
    165377: {"Unified_Ideograph", "Ideographic"},
    165378: {"Unified_Ideograph", "Ideographic"},
    165379: {"Unified_Ideograph", "Ideographic"},
    165380: {"Unified_Ideograph", "Ideographic"},
    165381: {"Unified_Ideograph", "Ideographic"},
    165382: {"Unified_Ideograph", "Ideographic"},
    165383: {"Unified_Ideograph", "Ideographic"},
    165384: {"Unified_Ideograph", "Ideographic"},
    165385: {"Unified_Ideograph", "Ideographic"},
    165386: {"Unified_Ideograph", "Ideographic"},
    165387: {"Unified_Ideograph", "Ideographic"},
    165388: {"Unified_Ideograph", "Ideographic"},
    165389: {"Unified_Ideograph", "Ideographic"},
    165390: {"Unified_Ideograph", "Ideographic"},
    165391: {"Unified_Ideograph", "Ideographic"},
    165392: {"Unified_Ideograph", "Ideographic"},
    165393: {"Unified_Ideograph", "Ideographic"},
    165394: {"Unified_Ideograph", "Ideographic"},
    165395: {"Unified_Ideograph", "Ideographic"},
    165396: {"Unified_Ideograph", "Ideographic"},
    165397: {"Unified_Ideograph", "Ideographic"},
    165398: {"Unified_Ideograph", "Ideographic"},
    165399: {"Unified_Ideograph", "Ideographic"},
    165400: {"Unified_Ideograph", "Ideographic"},
    165401: {"Unified_Ideograph", "Ideographic"},
    165402: {"Unified_Ideograph", "Ideographic"},
    165403: {"Unified_Ideograph", "Ideographic"},
    165404: {"Unified_Ideograph", "Ideographic"},
    165405: {"Unified_Ideograph", "Ideographic"},
    165406: {"Unified_Ideograph", "Ideographic"},
    165407: {"Unified_Ideograph", "Ideographic"},
    165408: {"Unified_Ideograph", "Ideographic"},
    165409: {"Unified_Ideograph", "Ideographic"},
    165410: {"Unified_Ideograph", "Ideographic"},
    165411: {"Unified_Ideograph", "Ideographic"},
    165412: {"Unified_Ideograph", "Ideographic"},
    165413: {"Unified_Ideograph", "Ideographic"},
    165414: {"Unified_Ideograph", "Ideographic"},
    165415: {"Unified_Ideograph", "Ideographic"},
    165416: {"Unified_Ideograph", "Ideographic"},
    165417: {"Unified_Ideograph", "Ideographic"},
    165418: {"Unified_Ideograph", "Ideographic"},
    165419: {"Unified_Ideograph", "Ideographic"},
    165420: {"Unified_Ideograph", "Ideographic"},
    165421: {"Unified_Ideograph", "Ideographic"},
    165422: {"Unified_Ideograph", "Ideographic"},
    165423: {"Unified_Ideograph", "Ideographic"},
    165424: {"Unified_Ideograph", "Ideographic"},
    165425: {"Unified_Ideograph", "Ideographic"},
    165426: {"Unified_Ideograph", "Ideographic"},
    165427: {"Unified_Ideograph", "Ideographic"},
    165428: {"Unified_Ideograph", "Ideographic"},
    165429: {"Unified_Ideograph", "Ideographic"},
    165430: {"Unified_Ideograph", "Ideographic"},
    165431: {"Unified_Ideograph", "Ideographic"},
    165432: {"Unified_Ideograph", "Ideographic"},
    165433: {"Unified_Ideograph", "Ideographic"},
    165434: {"Unified_Ideograph", "Ideographic"},
    165435: {"Unified_Ideograph", "Ideographic"},
    165436: {"Unified_Ideograph", "Ideographic"},
    165437: {"Unified_Ideograph", "Ideographic"},
    165438: {"Unified_Ideograph", "Ideographic"},
    165439: {"Unified_Ideograph", "Ideographic"},
    165440: {"Unified_Ideograph", "Ideographic"},
    165441: {"Unified_Ideograph", "Ideographic"},
    165442: {"Unified_Ideograph", "Ideographic"},
    165443: {"Unified_Ideograph", "Ideographic"},
    165444: {"Unified_Ideograph", "Ideographic"},
    165445: {"Unified_Ideograph", "Ideographic"},
    165446: {"Unified_Ideograph", "Ideographic"},
    165447: {"Unified_Ideograph", "Ideographic"},
    165448: {"Unified_Ideograph", "Ideographic"},
    165449: {"Unified_Ideograph", "Ideographic"},
    165450: {"Unified_Ideograph", "Ideographic"},
    165451: {"Unified_Ideograph", "Ideographic"},
    165452: {"Unified_Ideograph", "Ideographic"},
    165453: {"Unified_Ideograph", "Ideographic"},
    165454: {"Unified_Ideograph", "Ideographic"},
    165455: {"Unified_Ideograph", "Ideographic"},
    165456: {"Unified_Ideograph", "Ideographic"},
    165457: {"Unified_Ideograph", "Ideographic"},
    165458: {"Unified_Ideograph", "Ideographic"},
    165459: {"Unified_Ideograph", "Ideographic"},
    165460: {"Unified_Ideograph", "Ideographic"},
    165461: {"Unified_Ideograph", "Ideographic"},
    165462: {"Unified_Ideograph", "Ideographic"},
    165463: {"Unified_Ideograph", "Ideographic"},
    165464: {"Unified_Ideograph", "Ideographic"},
    165465: {"Unified_Ideograph", "Ideographic"},
    165466: {"Unified_Ideograph", "Ideographic"},
    165467: {"Unified_Ideograph", "Ideographic"},
    165468: {"Unified_Ideograph", "Ideographic"},
    165469: {"Unified_Ideograph", "Ideographic"},
    165470: {"Unified_Ideograph", "Ideographic"},
    165471: {"Unified_Ideograph", "Ideographic"},
    165472: {"Unified_Ideograph", "Ideographic"},
    165473: {"Unified_Ideograph", "Ideographic"},
    165474: {"Unified_Ideograph", "Ideographic"},
    165475: {"Unified_Ideograph", "Ideographic"},
    165476: {"Unified_Ideograph", "Ideographic"},
    165477: {"Unified_Ideograph", "Ideographic"},
    165478: {"Unified_Ideograph", "Ideographic"},
    165479: {"Unified_Ideograph", "Ideographic"},
    165480: {"Unified_Ideograph", "Ideographic"},
    165481: {"Unified_Ideograph", "Ideographic"},
    165482: {"Unified_Ideograph", "Ideographic"},
    165483: {"Unified_Ideograph", "Ideographic"},
    165484: {"Unified_Ideograph", "Ideographic"},
    165485: {"Unified_Ideograph", "Ideographic"},
    165486: {"Unified_Ideograph", "Ideographic"},
    165487: {"Unified_Ideograph", "Ideographic"},
    165488: {"Unified_Ideograph", "Ideographic"},
    165489: {"Unified_Ideograph", "Ideographic"},
    165490: {"Unified_Ideograph", "Ideographic"},
    165491: {"Unified_Ideograph", "Ideographic"},
    165492: {"Unified_Ideograph", "Ideographic"},
    165493: {"Unified_Ideograph", "Ideographic"},
    165494: {"Unified_Ideograph", "Ideographic"},
    165495: {"Unified_Ideograph", "Ideographic"},
    165496: {"Unified_Ideograph", "Ideographic"},
    165497: {"Unified_Ideograph", "Ideographic"},
    165498: {"Unified_Ideograph", "Ideographic"},
    165499: {"Unified_Ideograph", "Ideographic"},
    165500: {"Unified_Ideograph", "Ideographic"},
    165501: {"Unified_Ideograph", "Ideographic"},
    165502: {"Unified_Ideograph", "Ideographic"},
    165503: {"Unified_Ideograph", "Ideographic"},
    165504: {"Unified_Ideograph", "Ideographic"},
    165505: {"Unified_Ideograph", "Ideographic"},
    165506: {"Unified_Ideograph", "Ideographic"},
    165507: {"Unified_Ideograph", "Ideographic"},
    165508: {"Unified_Ideograph", "Ideographic"},
    165509: {"Unified_Ideograph", "Ideographic"},
    165510: {"Unified_Ideograph", "Ideographic"},
    165511: {"Unified_Ideograph", "Ideographic"},
    165512: {"Unified_Ideograph", "Ideographic"},
    165513: {"Unified_Ideograph", "Ideographic"},
    165514: {"Unified_Ideograph", "Ideographic"},
    165515: {"Unified_Ideograph", "Ideographic"},
    165516: {"Unified_Ideograph", "Ideographic"},
    165517: {"Unified_Ideograph", "Ideographic"},
    165518: {"Unified_Ideograph", "Ideographic"},
    165519: {"Unified_Ideograph", "Ideographic"},
    165520: {"Unified_Ideograph", "Ideographic"},
    165521: {"Unified_Ideograph", "Ideographic"},
    165522: {"Unified_Ideograph", "Ideographic"},
    165523: {"Unified_Ideograph", "Ideographic"},
    165524: {"Unified_Ideograph", "Ideographic"},
    165525: {"Unified_Ideograph", "Ideographic"},
    165526: {"Unified_Ideograph", "Ideographic"},
    165527: {"Unified_Ideograph", "Ideographic"},
    165528: {"Unified_Ideograph", "Ideographic"},
    165529: {"Unified_Ideograph", "Ideographic"},
    165530: {"Unified_Ideograph", "Ideographic"},
    165531: {"Unified_Ideograph", "Ideographic"},
    165532: {"Unified_Ideograph", "Ideographic"},
    165533: {"Unified_Ideograph", "Ideographic"},
    165534: {"Unified_Ideograph", "Ideographic"},
    165535: {"Unified_Ideograph", "Ideographic"},
    165536: {"Unified_Ideograph", "Ideographic"},
    165537: {"Unified_Ideograph", "Ideographic"},
    165538: {"Unified_Ideograph", "Ideographic"},
    165539: {"Unified_Ideograph", "Ideographic"},
    165540: {"Unified_Ideograph", "Ideographic"},
    165541: {"Unified_Ideograph", "Ideographic"},
    165542: {"Unified_Ideograph", "Ideographic"},
    165543: {"Unified_Ideograph", "Ideographic"},
    165544: {"Unified_Ideograph", "Ideographic"},
    165545: {"Unified_Ideograph", "Ideographic"},
    165546: {"Unified_Ideograph", "Ideographic"},
    165547: {"Unified_Ideograph", "Ideographic"},
    165548: {"Unified_Ideograph", "Ideographic"},
    165549: {"Unified_Ideograph", "Ideographic"},
    165550: {"Unified_Ideograph", "Ideographic"},
    165551: {"Unified_Ideograph", "Ideographic"},
    165552: {"Unified_Ideograph", "Ideographic"},
    165553: {"Unified_Ideograph", "Ideographic"},
    165554: {"Unified_Ideograph", "Ideographic"},
    165555: {"Unified_Ideograph", "Ideographic"},
    165556: {"Unified_Ideograph", "Ideographic"},
    165557: {"Unified_Ideograph", "Ideographic"},
    165558: {"Unified_Ideograph", "Ideographic"},
    165559: {"Unified_Ideograph", "Ideographic"},
    165560: {"Unified_Ideograph", "Ideographic"},
    165561: {"Unified_Ideograph", "Ideographic"},
    165562: {"Unified_Ideograph", "Ideographic"},
    165563: {"Unified_Ideograph", "Ideographic"},
    165564: {"Unified_Ideograph", "Ideographic"},
    165565: {"Unified_Ideograph", "Ideographic"},
    165566: {"Unified_Ideograph", "Ideographic"},
    165567: {"Unified_Ideograph", "Ideographic"},
    165568: {"Unified_Ideograph", "Ideographic"},
    165569: {"Unified_Ideograph", "Ideographic"},
    165570: {"Unified_Ideograph", "Ideographic"},
    165571: {"Unified_Ideograph", "Ideographic"},
    165572: {"Unified_Ideograph", "Ideographic"},
    165573: {"Unified_Ideograph", "Ideographic"},
    165574: {"Unified_Ideograph", "Ideographic"},
    165575: {"Unified_Ideograph", "Ideographic"},
    165576: {"Unified_Ideograph", "Ideographic"},
    165577: {"Unified_Ideograph", "Ideographic"},
    165578: {"Unified_Ideograph", "Ideographic"},
    165579: {"Unified_Ideograph", "Ideographic"},
    165580: {"Unified_Ideograph", "Ideographic"},
    165581: {"Unified_Ideograph", "Ideographic"},
    165582: {"Unified_Ideograph", "Ideographic"},
    165583: {"Unified_Ideograph", "Ideographic"},
    165584: {"Unified_Ideograph", "Ideographic"},
    165585: {"Unified_Ideograph", "Ideographic"},
    165586: {"Unified_Ideograph", "Ideographic"},
    165587: {"Unified_Ideograph", "Ideographic"},
    165588: {"Unified_Ideograph", "Ideographic"},
    165589: {"Unified_Ideograph", "Ideographic"},
    165590: {"Unified_Ideograph", "Ideographic"},
    165591: {"Unified_Ideograph", "Ideographic"},
    165592: {"Unified_Ideograph", "Ideographic"},
    165593: {"Unified_Ideograph", "Ideographic"},
    165594: {"Unified_Ideograph", "Ideographic"},
    165595: {"Unified_Ideograph", "Ideographic"},
    165596: {"Unified_Ideograph", "Ideographic"},
    165597: {"Unified_Ideograph", "Ideographic"},
    165598: {"Unified_Ideograph", "Ideographic"},
    165599: {"Unified_Ideograph", "Ideographic"},
    165600: {"Unified_Ideograph", "Ideographic"},
    165601: {"Unified_Ideograph", "Ideographic"},
    165602: {"Unified_Ideograph", "Ideographic"},
    165603: {"Unified_Ideograph", "Ideographic"},
    165604: {"Unified_Ideograph", "Ideographic"},
    165605: {"Unified_Ideograph", "Ideographic"},
    165606: {"Unified_Ideograph", "Ideographic"},
    165607: {"Unified_Ideograph", "Ideographic"},
    165608: {"Unified_Ideograph", "Ideographic"},
    165609: {"Unified_Ideograph", "Ideographic"},
    165610: {"Unified_Ideograph", "Ideographic"},
    165611: {"Unified_Ideograph", "Ideographic"},
    165612: {"Unified_Ideograph", "Ideographic"},
    165613: {"Unified_Ideograph", "Ideographic"},
    165614: {"Unified_Ideograph", "Ideographic"},
    165615: {"Unified_Ideograph", "Ideographic"},
    165616: {"Unified_Ideograph", "Ideographic"},
    165617: {"Unified_Ideograph", "Ideographic"},
    165618: {"Unified_Ideograph", "Ideographic"},
    165619: {"Unified_Ideograph", "Ideographic"},
    165620: {"Unified_Ideograph", "Ideographic"},
    165621: {"Unified_Ideograph", "Ideographic"},
    165622: {"Unified_Ideograph", "Ideographic"},
    165623: {"Unified_Ideograph", "Ideographic"},
    165624: {"Unified_Ideograph", "Ideographic"},
    165625: {"Unified_Ideograph", "Ideographic"},
    165626: {"Unified_Ideograph", "Ideographic"},
    165627: {"Unified_Ideograph", "Ideographic"},
    165628: {"Unified_Ideograph", "Ideographic"},
    165629: {"Unified_Ideograph", "Ideographic"},
    165630: {"Unified_Ideograph", "Ideographic"},
    165631: {"Unified_Ideograph", "Ideographic"},
    165632: {"Unified_Ideograph", "Ideographic"},
    165633: {"Unified_Ideograph", "Ideographic"},
    165634: {"Unified_Ideograph", "Ideographic"},
    165635: {"Unified_Ideograph", "Ideographic"},
    165636: {"Unified_Ideograph", "Ideographic"},
    165637: {"Unified_Ideograph", "Ideographic"},
    165638: {"Unified_Ideograph", "Ideographic"},
    165639: {"Unified_Ideograph", "Ideographic"},
    165640: {"Unified_Ideograph", "Ideographic"},
    165641: {"Unified_Ideograph", "Ideographic"},
    165642: {"Unified_Ideograph", "Ideographic"},
    165643: {"Unified_Ideograph", "Ideographic"},
    165644: {"Unified_Ideograph", "Ideographic"},
    165645: {"Unified_Ideograph", "Ideographic"},
    165646: {"Unified_Ideograph", "Ideographic"},
    165647: {"Unified_Ideograph", "Ideographic"},
    165648: {"Unified_Ideograph", "Ideographic"},
    165649: {"Unified_Ideograph", "Ideographic"},
    165650: {"Unified_Ideograph", "Ideographic"},
    165651: {"Unified_Ideograph", "Ideographic"},
    165652: {"Unified_Ideograph", "Ideographic"},
    165653: {"Unified_Ideograph", "Ideographic"},
    165654: {"Unified_Ideograph", "Ideographic"},
    165655: {"Unified_Ideograph", "Ideographic"},
    165656: {"Unified_Ideograph", "Ideographic"},
    165657: {"Unified_Ideograph", "Ideographic"},
    165658: {"Unified_Ideograph", "Ideographic"},
    165659: {"Unified_Ideograph", "Ideographic"},
    165660: {"Unified_Ideograph", "Ideographic"},
    165661: {"Unified_Ideograph", "Ideographic"},
    165662: {"Unified_Ideograph", "Ideographic"},
    165663: {"Unified_Ideograph", "Ideographic"},
    165664: {"Unified_Ideograph", "Ideographic"},
    165665: {"Unified_Ideograph", "Ideographic"},
    165666: {"Unified_Ideograph", "Ideographic"},
    165667: {"Unified_Ideograph", "Ideographic"},
    165668: {"Unified_Ideograph", "Ideographic"},
    165669: {"Unified_Ideograph", "Ideographic"},
    165670: {"Unified_Ideograph", "Ideographic"},
    165671: {"Unified_Ideograph", "Ideographic"},
    165672: {"Unified_Ideograph", "Ideographic"},
    165673: {"Unified_Ideograph", "Ideographic"},
    165674: {"Unified_Ideograph", "Ideographic"},
    165675: {"Unified_Ideograph", "Ideographic"},
    165676: {"Unified_Ideograph", "Ideographic"},
    165677: {"Unified_Ideograph", "Ideographic"},
    165678: {"Unified_Ideograph", "Ideographic"},
    165679: {"Unified_Ideograph", "Ideographic"},
    165680: {"Unified_Ideograph", "Ideographic"},
    165681: {"Unified_Ideograph", "Ideographic"},
    165682: {"Unified_Ideograph", "Ideographic"},
    165683: {"Unified_Ideograph", "Ideographic"},
    165684: {"Unified_Ideograph", "Ideographic"},
    165685: {"Unified_Ideograph", "Ideographic"},
    165686: {"Unified_Ideograph", "Ideographic"},
    165687: {"Unified_Ideograph", "Ideographic"},
    165688: {"Unified_Ideograph", "Ideographic"},
    165689: {"Unified_Ideograph", "Ideographic"},
    165690: {"Unified_Ideograph", "Ideographic"},
    165691: {"Unified_Ideograph", "Ideographic"},
    165692: {"Unified_Ideograph", "Ideographic"},
    165693: {"Unified_Ideograph", "Ideographic"},
    165694: {"Unified_Ideograph", "Ideographic"},
    165695: {"Unified_Ideograph", "Ideographic"},
    165696: {"Unified_Ideograph", "Ideographic"},
    165697: {"Unified_Ideograph", "Ideographic"},
    165698: {"Unified_Ideograph", "Ideographic"},
    165699: {"Unified_Ideograph", "Ideographic"},
    165700: {"Unified_Ideograph", "Ideographic"},
    165701: {"Unified_Ideograph", "Ideographic"},
    165702: {"Unified_Ideograph", "Ideographic"},
    165703: {"Unified_Ideograph", "Ideographic"},
    165704: {"Unified_Ideograph", "Ideographic"},
    165705: {"Unified_Ideograph", "Ideographic"},
    165706: {"Unified_Ideograph", "Ideographic"},
    165707: {"Unified_Ideograph", "Ideographic"},
    165708: {"Unified_Ideograph", "Ideographic"},
    165709: {"Unified_Ideograph", "Ideographic"},
    165710: {"Unified_Ideograph", "Ideographic"},
    165711: {"Unified_Ideograph", "Ideographic"},
    165712: {"Unified_Ideograph", "Ideographic"},
    165713: {"Unified_Ideograph", "Ideographic"},
    165714: {"Unified_Ideograph", "Ideographic"},
    165715: {"Unified_Ideograph", "Ideographic"},
    165716: {"Unified_Ideograph", "Ideographic"},
    165717: {"Unified_Ideograph", "Ideographic"},
    165718: {"Unified_Ideograph", "Ideographic"},
    165719: {"Unified_Ideograph", "Ideographic"},
    165720: {"Unified_Ideograph", "Ideographic"},
    165721: {"Unified_Ideograph", "Ideographic"},
    165722: {"Unified_Ideograph", "Ideographic"},
    165723: {"Unified_Ideograph", "Ideographic"},
    165724: {"Unified_Ideograph", "Ideographic"},
    165725: {"Unified_Ideograph", "Ideographic"},
    165726: {"Unified_Ideograph", "Ideographic"},
    165727: {"Unified_Ideograph", "Ideographic"},
    165728: {"Unified_Ideograph", "Ideographic"},
    165729: {"Unified_Ideograph", "Ideographic"},
    165730: {"Unified_Ideograph", "Ideographic"},
    165731: {"Unified_Ideograph", "Ideographic"},
    165732: {"Unified_Ideograph", "Ideographic"},
    165733: {"Unified_Ideograph", "Ideographic"},
    165734: {"Unified_Ideograph", "Ideographic"},
    165735: {"Unified_Ideograph", "Ideographic"},
    165736: {"Unified_Ideograph", "Ideographic"},
    165737: {"Unified_Ideograph", "Ideographic"},
    165738: {"Unified_Ideograph", "Ideographic"},
    165739: {"Unified_Ideograph", "Ideographic"},
    165740: {"Unified_Ideograph", "Ideographic"},
    165741: {"Unified_Ideograph", "Ideographic"},
    165742: {"Unified_Ideograph", "Ideographic"},
    165743: {"Unified_Ideograph", "Ideographic"},
    165744: {"Unified_Ideograph", "Ideographic"},
    165745: {"Unified_Ideograph", "Ideographic"},
    165746: {"Unified_Ideograph", "Ideographic"},
    165747: {"Unified_Ideograph", "Ideographic"},
    165748: {"Unified_Ideograph", "Ideographic"},
    165749: {"Unified_Ideograph", "Ideographic"},
    165750: {"Unified_Ideograph", "Ideographic"},
    165751: {"Unified_Ideograph", "Ideographic"},
    165752: {"Unified_Ideograph", "Ideographic"},
    165753: {"Unified_Ideograph", "Ideographic"},
    165754: {"Unified_Ideograph", "Ideographic"},
    165755: {"Unified_Ideograph", "Ideographic"},
    165756: {"Unified_Ideograph", "Ideographic"},
    165757: {"Unified_Ideograph", "Ideographic"},
    165758: {"Unified_Ideograph", "Ideographic"},
    165759: {"Unified_Ideograph", "Ideographic"},
    165760: {"Unified_Ideograph", "Ideographic"},
    165761: {"Unified_Ideograph", "Ideographic"},
    165762: {"Unified_Ideograph", "Ideographic"},
    165763: {"Unified_Ideograph", "Ideographic"},
    165764: {"Unified_Ideograph", "Ideographic"},
    165765: {"Unified_Ideograph", "Ideographic"},
    165766: {"Unified_Ideograph", "Ideographic"},
    165767: {"Unified_Ideograph", "Ideographic"},
    165768: {"Unified_Ideograph", "Ideographic"},
    165769: {"Unified_Ideograph", "Ideographic"},
    165770: {"Unified_Ideograph", "Ideographic"},
    165771: {"Unified_Ideograph", "Ideographic"},
    165772: {"Unified_Ideograph", "Ideographic"},
    165773: {"Unified_Ideograph", "Ideographic"},
    165774: {"Unified_Ideograph", "Ideographic"},
    165775: {"Unified_Ideograph", "Ideographic"},
    165776: {"Unified_Ideograph", "Ideographic"},
    165777: {"Unified_Ideograph", "Ideographic"},
    165778: {"Unified_Ideograph", "Ideographic"},
    165779: {"Unified_Ideograph", "Ideographic"},
    165780: {"Unified_Ideograph", "Ideographic"},
    165781: {"Unified_Ideograph", "Ideographic"},
    165782: {"Unified_Ideograph", "Ideographic"},
    165783: {"Unified_Ideograph", "Ideographic"},
    165784: {"Unified_Ideograph", "Ideographic"},
    165785: {"Unified_Ideograph", "Ideographic"},
    165786: {"Unified_Ideograph", "Ideographic"},
    165787: {"Unified_Ideograph", "Ideographic"},
    165788: {"Unified_Ideograph", "Ideographic"},
    165789: {"Unified_Ideograph", "Ideographic"},
    165790: {"Unified_Ideograph", "Ideographic"},
    165791: {"Unified_Ideograph", "Ideographic"},
    165792: {"Unified_Ideograph", "Ideographic"},
    165793: {"Unified_Ideograph", "Ideographic"},
    165794: {"Unified_Ideograph", "Ideographic"},
    165795: {"Unified_Ideograph", "Ideographic"},
    165796: {"Unified_Ideograph", "Ideographic"},
    165797: {"Unified_Ideograph", "Ideographic"},
    165798: {"Unified_Ideograph", "Ideographic"},
    165799: {"Unified_Ideograph", "Ideographic"},
    165800: {"Unified_Ideograph", "Ideographic"},
    165801: {"Unified_Ideograph", "Ideographic"},
    165802: {"Unified_Ideograph", "Ideographic"},
    165803: {"Unified_Ideograph", "Ideographic"},
    165804: {"Unified_Ideograph", "Ideographic"},
    165805: {"Unified_Ideograph", "Ideographic"},
    165806: {"Unified_Ideograph", "Ideographic"},
    165807: {"Unified_Ideograph", "Ideographic"},
    165808: {"Unified_Ideograph", "Ideographic"},
    165809: {"Unified_Ideograph", "Ideographic"},
    165810: {"Unified_Ideograph", "Ideographic"},
    165811: {"Unified_Ideograph", "Ideographic"},
    165812: {"Unified_Ideograph", "Ideographic"},
    165813: {"Unified_Ideograph", "Ideographic"},
    165814: {"Unified_Ideograph", "Ideographic"},
    165815: {"Unified_Ideograph", "Ideographic"},
    165816: {"Unified_Ideograph", "Ideographic"},
    165817: {"Unified_Ideograph", "Ideographic"},
    165818: {"Unified_Ideograph", "Ideographic"},
    165819: {"Unified_Ideograph", "Ideographic"},
    165820: {"Unified_Ideograph", "Ideographic"},
    165821: {"Unified_Ideograph", "Ideographic"},
    165822: {"Unified_Ideograph", "Ideographic"},
    165823: {"Unified_Ideograph", "Ideographic"},
    165824: {"Unified_Ideograph", "Ideographic"},
    165825: {"Unified_Ideograph", "Ideographic"},
    165826: {"Unified_Ideograph", "Ideographic"},
    165827: {"Unified_Ideograph", "Ideographic"},
    165828: {"Unified_Ideograph", "Ideographic"},
    165829: {"Unified_Ideograph", "Ideographic"},
    165830: {"Unified_Ideograph", "Ideographic"},
    165831: {"Unified_Ideograph", "Ideographic"},
    165832: {"Unified_Ideograph", "Ideographic"},
    165833: {"Unified_Ideograph", "Ideographic"},
    165834: {"Unified_Ideograph", "Ideographic"},
    165835: {"Unified_Ideograph", "Ideographic"},
    165836: {"Unified_Ideograph", "Ideographic"},
    165837: {"Unified_Ideograph", "Ideographic"},
    165838: {"Unified_Ideograph", "Ideographic"},
    165839: {"Unified_Ideograph", "Ideographic"},
    165840: {"Unified_Ideograph", "Ideographic"},
    165841: {"Unified_Ideograph", "Ideographic"},
    165842: {"Unified_Ideograph", "Ideographic"},
    165843: {"Unified_Ideograph", "Ideographic"},
    165844: {"Unified_Ideograph", "Ideographic"},
    165845: {"Unified_Ideograph", "Ideographic"},
    165846: {"Unified_Ideograph", "Ideographic"},
    165847: {"Unified_Ideograph", "Ideographic"},
    165848: {"Unified_Ideograph", "Ideographic"},
    165849: {"Unified_Ideograph", "Ideographic"},
    165850: {"Unified_Ideograph", "Ideographic"},
    165851: {"Unified_Ideograph", "Ideographic"},
    165852: {"Unified_Ideograph", "Ideographic"},
    165853: {"Unified_Ideograph", "Ideographic"},
    165854: {"Unified_Ideograph", "Ideographic"},
    165855: {"Unified_Ideograph", "Ideographic"},
    165856: {"Unified_Ideograph", "Ideographic"},
    165857: {"Unified_Ideograph", "Ideographic"},
    165858: {"Unified_Ideograph", "Ideographic"},
    165859: {"Unified_Ideograph", "Ideographic"},
    165860: {"Unified_Ideograph", "Ideographic"},
    165861: {"Unified_Ideograph", "Ideographic"},
    165862: {"Unified_Ideograph", "Ideographic"},
    165863: {"Unified_Ideograph", "Ideographic"},
    165864: {"Unified_Ideograph", "Ideographic"},
    165865: {"Unified_Ideograph", "Ideographic"},
    165866: {"Unified_Ideograph", "Ideographic"},
    165867: {"Unified_Ideograph", "Ideographic"},
    165868: {"Unified_Ideograph", "Ideographic"},
    165869: {"Unified_Ideograph", "Ideographic"},
    165870: {"Unified_Ideograph", "Ideographic"},
    165871: {"Unified_Ideograph", "Ideographic"},
    165872: {"Unified_Ideograph", "Ideographic"},
    165873: {"Unified_Ideograph", "Ideographic"},
    165874: {"Unified_Ideograph", "Ideographic"},
    165875: {"Unified_Ideograph", "Ideographic"},
    165876: {"Unified_Ideograph", "Ideographic"},
    165877: {"Unified_Ideograph", "Ideographic"},
    165878: {"Unified_Ideograph", "Ideographic"},
    165879: {"Unified_Ideograph", "Ideographic"},
    165880: {"Unified_Ideograph", "Ideographic"},
    165881: {"Unified_Ideograph", "Ideographic"},
    165882: {"Unified_Ideograph", "Ideographic"},
    165883: {"Unified_Ideograph", "Ideographic"},
    165884: {"Unified_Ideograph", "Ideographic"},
    165885: {"Unified_Ideograph", "Ideographic"},
    165886: {"Unified_Ideograph", "Ideographic"},
    165887: {"Unified_Ideograph", "Ideographic"},
    165888: {"Unified_Ideograph", "Ideographic"},
    165889: {"Unified_Ideograph", "Ideographic"},
    165890: {"Unified_Ideograph", "Ideographic"},
    165891: {"Unified_Ideograph", "Ideographic"},
    165892: {"Unified_Ideograph", "Ideographic"},
    165893: {"Unified_Ideograph", "Ideographic"},
    165894: {"Unified_Ideograph", "Ideographic"},
    165895: {"Unified_Ideograph", "Ideographic"},
    165896: {"Unified_Ideograph", "Ideographic"},
    165897: {"Unified_Ideograph", "Ideographic"},
    165898: {"Unified_Ideograph", "Ideographic"},
    165899: {"Unified_Ideograph", "Ideographic"},
    165900: {"Unified_Ideograph", "Ideographic"},
    165901: {"Unified_Ideograph", "Ideographic"},
    165902: {"Unified_Ideograph", "Ideographic"},
    165903: {"Unified_Ideograph", "Ideographic"},
    165904: {"Unified_Ideograph", "Ideographic"},
    165905: {"Unified_Ideograph", "Ideographic"},
    165906: {"Unified_Ideograph", "Ideographic"},
    165907: {"Unified_Ideograph", "Ideographic"},
    165908: {"Unified_Ideograph", "Ideographic"},
    165909: {"Unified_Ideograph", "Ideographic"},
    165910: {"Unified_Ideograph", "Ideographic"},
    165911: {"Unified_Ideograph", "Ideographic"},
    165912: {"Unified_Ideograph", "Ideographic"},
    165913: {"Unified_Ideograph", "Ideographic"},
    165914: {"Unified_Ideograph", "Ideographic"},
    165915: {"Unified_Ideograph", "Ideographic"},
    165916: {"Unified_Ideograph", "Ideographic"},
    165917: {"Unified_Ideograph", "Ideographic"},
    165918: {"Unified_Ideograph", "Ideographic"},
    165919: {"Unified_Ideograph", "Ideographic"},
    165920: {"Unified_Ideograph", "Ideographic"},
    165921: {"Unified_Ideograph", "Ideographic"},
    165922: {"Unified_Ideograph", "Ideographic"},
    165923: {"Unified_Ideograph", "Ideographic"},
    165924: {"Unified_Ideograph", "Ideographic"},
    165925: {"Unified_Ideograph", "Ideographic"},
    165926: {"Unified_Ideograph", "Ideographic"},
    165927: {"Unified_Ideograph", "Ideographic"},
    165928: {"Unified_Ideograph", "Ideographic"},
    165929: {"Unified_Ideograph", "Ideographic"},
    165930: {"Unified_Ideograph", "Ideographic"},
    165931: {"Unified_Ideograph", "Ideographic"},
    165932: {"Unified_Ideograph", "Ideographic"},
    165933: {"Unified_Ideograph", "Ideographic"},
    165934: {"Unified_Ideograph", "Ideographic"},
    165935: {"Unified_Ideograph", "Ideographic"},
    165936: {"Unified_Ideograph", "Ideographic"},
    165937: {"Unified_Ideograph", "Ideographic"},
    165938: {"Unified_Ideograph", "Ideographic"},
    165939: {"Unified_Ideograph", "Ideographic"},
    165940: {"Unified_Ideograph", "Ideographic"},
    165941: {"Unified_Ideograph", "Ideographic"},
    165942: {"Unified_Ideograph", "Ideographic"},
    165943: {"Unified_Ideograph", "Ideographic"},
    165944: {"Unified_Ideograph", "Ideographic"},
    165945: {"Unified_Ideograph", "Ideographic"},
    165946: {"Unified_Ideograph", "Ideographic"},
    165947: {"Unified_Ideograph", "Ideographic"},
    165948: {"Unified_Ideograph", "Ideographic"},
    165949: {"Unified_Ideograph", "Ideographic"},
    165950: {"Unified_Ideograph", "Ideographic"},
    165951: {"Unified_Ideograph", "Ideographic"},
    165952: {"Unified_Ideograph", "Ideographic"},
    165953: {"Unified_Ideograph", "Ideographic"},
    165954: {"Unified_Ideograph", "Ideographic"},
    165955: {"Unified_Ideograph", "Ideographic"},
    165956: {"Unified_Ideograph", "Ideographic"},
    165957: {"Unified_Ideograph", "Ideographic"},
    165958: {"Unified_Ideograph", "Ideographic"},
    165959: {"Unified_Ideograph", "Ideographic"},
    165960: {"Unified_Ideograph", "Ideographic"},
    165961: {"Unified_Ideograph", "Ideographic"},
    165962: {"Unified_Ideograph", "Ideographic"},
    165963: {"Unified_Ideograph", "Ideographic"},
    165964: {"Unified_Ideograph", "Ideographic"},
    165965: {"Unified_Ideograph", "Ideographic"},
    165966: {"Unified_Ideograph", "Ideographic"},
    165967: {"Unified_Ideograph", "Ideographic"},
    165968: {"Unified_Ideograph", "Ideographic"},
    165969: {"Unified_Ideograph", "Ideographic"},
    165970: {"Unified_Ideograph", "Ideographic"},
    165971: {"Unified_Ideograph", "Ideographic"},
    165972: {"Unified_Ideograph", "Ideographic"},
    165973: {"Unified_Ideograph", "Ideographic"},
    165974: {"Unified_Ideograph", "Ideographic"},
    165975: {"Unified_Ideograph", "Ideographic"},
    165976: {"Unified_Ideograph", "Ideographic"},
    165977: {"Unified_Ideograph", "Ideographic"},
    165978: {"Unified_Ideograph", "Ideographic"},
    165979: {"Unified_Ideograph", "Ideographic"},
    165980: {"Unified_Ideograph", "Ideographic"},
    165981: {"Unified_Ideograph", "Ideographic"},
    165982: {"Unified_Ideograph", "Ideographic"},
    165983: {"Unified_Ideograph", "Ideographic"},
    165984: {"Unified_Ideograph", "Ideographic"},
    165985: {"Unified_Ideograph", "Ideographic"},
    165986: {"Unified_Ideograph", "Ideographic"},
    165987: {"Unified_Ideograph", "Ideographic"},
    165988: {"Unified_Ideograph", "Ideographic"},
    165989: {"Unified_Ideograph", "Ideographic"},
    165990: {"Unified_Ideograph", "Ideographic"},
    165991: {"Unified_Ideograph", "Ideographic"},
    165992: {"Unified_Ideograph", "Ideographic"},
    165993: {"Unified_Ideograph", "Ideographic"},
    165994: {"Unified_Ideograph", "Ideographic"},
    165995: {"Unified_Ideograph", "Ideographic"},
    165996: {"Unified_Ideograph", "Ideographic"},
    165997: {"Unified_Ideograph", "Ideographic"},
    165998: {"Unified_Ideograph", "Ideographic"},
    165999: {"Unified_Ideograph", "Ideographic"},
    166000: {"Unified_Ideograph", "Ideographic"},
    166001: {"Unified_Ideograph", "Ideographic"},
    166002: {"Unified_Ideograph", "Ideographic"},
    166003: {"Unified_Ideograph", "Ideographic"},
    166004: {"Unified_Ideograph", "Ideographic"},
    166005: {"Unified_Ideograph", "Ideographic"},
    166006: {"Unified_Ideograph", "Ideographic"},
    166007: {"Unified_Ideograph", "Ideographic"},
    166008: {"Unified_Ideograph", "Ideographic"},
    166009: {"Unified_Ideograph", "Ideographic"},
    166010: {"Unified_Ideograph", "Ideographic"},
    166011: {"Unified_Ideograph", "Ideographic"},
    166012: {"Unified_Ideograph", "Ideographic"},
    166013: {"Unified_Ideograph", "Ideographic"},
    166014: {"Unified_Ideograph", "Ideographic"},
    166015: {"Unified_Ideograph", "Ideographic"},
    166016: {"Unified_Ideograph", "Ideographic"},
    166017: {"Unified_Ideograph", "Ideographic"},
    166018: {"Unified_Ideograph", "Ideographic"},
    166019: {"Unified_Ideograph", "Ideographic"},
    166020: {"Unified_Ideograph", "Ideographic"},
    166021: {"Unified_Ideograph", "Ideographic"},
    166022: {"Unified_Ideograph", "Ideographic"},
    166023: {"Unified_Ideograph", "Ideographic"},
    166024: {"Unified_Ideograph", "Ideographic"},
    166025: {"Unified_Ideograph", "Ideographic"},
    166026: {"Unified_Ideograph", "Ideographic"},
    166027: {"Unified_Ideograph", "Ideographic"},
    166028: {"Unified_Ideograph", "Ideographic"},
    166029: {"Unified_Ideograph", "Ideographic"},
    166030: {"Unified_Ideograph", "Ideographic"},
    166031: {"Unified_Ideograph", "Ideographic"},
    166032: {"Unified_Ideograph", "Ideographic"},
    166033: {"Unified_Ideograph", "Ideographic"},
    166034: {"Unified_Ideograph", "Ideographic"},
    166035: {"Unified_Ideograph", "Ideographic"},
    166036: {"Unified_Ideograph", "Ideographic"},
    166037: {"Unified_Ideograph", "Ideographic"},
    166038: {"Unified_Ideograph", "Ideographic"},
    166039: {"Unified_Ideograph", "Ideographic"},
    166040: {"Unified_Ideograph", "Ideographic"},
    166041: {"Unified_Ideograph", "Ideographic"},
    166042: {"Unified_Ideograph", "Ideographic"},
    166043: {"Unified_Ideograph", "Ideographic"},
    166044: {"Unified_Ideograph", "Ideographic"},
    166045: {"Unified_Ideograph", "Ideographic"},
    166046: {"Unified_Ideograph", "Ideographic"},
    166047: {"Unified_Ideograph", "Ideographic"},
    166048: {"Unified_Ideograph", "Ideographic"},
    166049: {"Unified_Ideograph", "Ideographic"},
    166050: {"Unified_Ideograph", "Ideographic"},
    166051: {"Unified_Ideograph", "Ideographic"},
    166052: {"Unified_Ideograph", "Ideographic"},
    166053: {"Unified_Ideograph", "Ideographic"},
    166054: {"Unified_Ideograph", "Ideographic"},
    166055: {"Unified_Ideograph", "Ideographic"},
    166056: {"Unified_Ideograph", "Ideographic"},
    166057: {"Unified_Ideograph", "Ideographic"},
    166058: {"Unified_Ideograph", "Ideographic"},
    166059: {"Unified_Ideograph", "Ideographic"},
    166060: {"Unified_Ideograph", "Ideographic"},
    166061: {"Unified_Ideograph", "Ideographic"},
    166062: {"Unified_Ideograph", "Ideographic"},
    166063: {"Unified_Ideograph", "Ideographic"},
    166064: {"Unified_Ideograph", "Ideographic"},
    166065: {"Unified_Ideograph", "Ideographic"},
    166066: {"Unified_Ideograph", "Ideographic"},
    166067: {"Unified_Ideograph", "Ideographic"},
    166068: {"Unified_Ideograph", "Ideographic"},
    166069: {"Unified_Ideograph", "Ideographic"},
    166070: {"Unified_Ideograph", "Ideographic"},
    166071: {"Unified_Ideograph", "Ideographic"},
    166072: {"Unified_Ideograph", "Ideographic"},
    166073: {"Unified_Ideograph", "Ideographic"},
    166074: {"Unified_Ideograph", "Ideographic"},
    166075: {"Unified_Ideograph", "Ideographic"},
    166076: {"Unified_Ideograph", "Ideographic"},
    166077: {"Unified_Ideograph", "Ideographic"},
    166078: {"Unified_Ideograph", "Ideographic"},
    166079: {"Unified_Ideograph", "Ideographic"},
    166080: {"Unified_Ideograph", "Ideographic"},
    166081: {"Unified_Ideograph", "Ideographic"},
    166082: {"Unified_Ideograph", "Ideographic"},
    166083: {"Unified_Ideograph", "Ideographic"},
    166084: {"Unified_Ideograph", "Ideographic"},
    166085: {"Unified_Ideograph", "Ideographic"},
    166086: {"Unified_Ideograph", "Ideographic"},
    166087: {"Unified_Ideograph", "Ideographic"},
    166088: {"Unified_Ideograph", "Ideographic"},
    166089: {"Unified_Ideograph", "Ideographic"},
    166090: {"Unified_Ideograph", "Ideographic"},
    166091: {"Unified_Ideograph", "Ideographic"},
    166092: {"Unified_Ideograph", "Ideographic"},
    166093: {"Unified_Ideograph", "Ideographic"},
    166094: {"Unified_Ideograph", "Ideographic"},
    166095: {"Unified_Ideograph", "Ideographic"},
    166096: {"Unified_Ideograph", "Ideographic"},
    166097: {"Unified_Ideograph", "Ideographic"},
    166098: {"Unified_Ideograph", "Ideographic"},
    166099: {"Unified_Ideograph", "Ideographic"},
    166100: {"Unified_Ideograph", "Ideographic"},
    166101: {"Unified_Ideograph", "Ideographic"},
    166102: {"Unified_Ideograph", "Ideographic"},
    166103: {"Unified_Ideograph", "Ideographic"},
    166104: {"Unified_Ideograph", "Ideographic"},
    166105: {"Unified_Ideograph", "Ideographic"},
    166106: {"Unified_Ideograph", "Ideographic"},
    166107: {"Unified_Ideograph", "Ideographic"},
    166108: {"Unified_Ideograph", "Ideographic"},
    166109: {"Unified_Ideograph", "Ideographic"},
    166110: {"Unified_Ideograph", "Ideographic"},
    166111: {"Unified_Ideograph", "Ideographic"},
    166112: {"Unified_Ideograph", "Ideographic"},
    166113: {"Unified_Ideograph", "Ideographic"},
    166114: {"Unified_Ideograph", "Ideographic"},
    166115: {"Unified_Ideograph", "Ideographic"},
    166116: {"Unified_Ideograph", "Ideographic"},
    166117: {"Unified_Ideograph", "Ideographic"},
    166118: {"Unified_Ideograph", "Ideographic"},
    166119: {"Unified_Ideograph", "Ideographic"},
    166120: {"Unified_Ideograph", "Ideographic"},
    166121: {"Unified_Ideograph", "Ideographic"},
    166122: {"Unified_Ideograph", "Ideographic"},
    166123: {"Unified_Ideograph", "Ideographic"},
    166124: {"Unified_Ideograph", "Ideographic"},
    166125: {"Unified_Ideograph", "Ideographic"},
    166126: {"Unified_Ideograph", "Ideographic"},
    166127: {"Unified_Ideograph", "Ideographic"},
    166128: {"Unified_Ideograph", "Ideographic"},
    166129: {"Unified_Ideograph", "Ideographic"},
    166130: {"Unified_Ideograph", "Ideographic"},
    166131: {"Unified_Ideograph", "Ideographic"},
    166132: {"Unified_Ideograph", "Ideographic"},
    166133: {"Unified_Ideograph", "Ideographic"},
    166134: {"Unified_Ideograph", "Ideographic"},
    166135: {"Unified_Ideograph", "Ideographic"},
    166136: {"Unified_Ideograph", "Ideographic"},
    166137: {"Unified_Ideograph", "Ideographic"},
    166138: {"Unified_Ideograph", "Ideographic"},
    166139: {"Unified_Ideograph", "Ideographic"},
    166140: {"Unified_Ideograph", "Ideographic"},
    166141: {"Unified_Ideograph", "Ideographic"},
    166142: {"Unified_Ideograph", "Ideographic"},
    166143: {"Unified_Ideograph", "Ideographic"},
    166144: {"Unified_Ideograph", "Ideographic"},
    166145: {"Unified_Ideograph", "Ideographic"},
    166146: {"Unified_Ideograph", "Ideographic"},
    166147: {"Unified_Ideograph", "Ideographic"},
    166148: {"Unified_Ideograph", "Ideographic"},
    166149: {"Unified_Ideograph", "Ideographic"},
    166150: {"Unified_Ideograph", "Ideographic"},
    166151: {"Unified_Ideograph", "Ideographic"},
    166152: {"Unified_Ideograph", "Ideographic"},
    166153: {"Unified_Ideograph", "Ideographic"},
    166154: {"Unified_Ideograph", "Ideographic"},
    166155: {"Unified_Ideograph", "Ideographic"},
    166156: {"Unified_Ideograph", "Ideographic"},
    166157: {"Unified_Ideograph", "Ideographic"},
    166158: {"Unified_Ideograph", "Ideographic"},
    166159: {"Unified_Ideograph", "Ideographic"},
    166160: {"Unified_Ideograph", "Ideographic"},
    166161: {"Unified_Ideograph", "Ideographic"},
    166162: {"Unified_Ideograph", "Ideographic"},
    166163: {"Unified_Ideograph", "Ideographic"},
    166164: {"Unified_Ideograph", "Ideographic"},
    166165: {"Unified_Ideograph", "Ideographic"},
    166166: {"Unified_Ideograph", "Ideographic"},
    166167: {"Unified_Ideograph", "Ideographic"},
    166168: {"Unified_Ideograph", "Ideographic"},
    166169: {"Unified_Ideograph", "Ideographic"},
    166170: {"Unified_Ideograph", "Ideographic"},
    166171: {"Unified_Ideograph", "Ideographic"},
    166172: {"Unified_Ideograph", "Ideographic"},
    166173: {"Unified_Ideograph", "Ideographic"},
    166174: {"Unified_Ideograph", "Ideographic"},
    166175: {"Unified_Ideograph", "Ideographic"},
    166176: {"Unified_Ideograph", "Ideographic"},
    166177: {"Unified_Ideograph", "Ideographic"},
    166178: {"Unified_Ideograph", "Ideographic"},
    166179: {"Unified_Ideograph", "Ideographic"},
    166180: {"Unified_Ideograph", "Ideographic"},
    166181: {"Unified_Ideograph", "Ideographic"},
    166182: {"Unified_Ideograph", "Ideographic"},
    166183: {"Unified_Ideograph", "Ideographic"},
    166184: {"Unified_Ideograph", "Ideographic"},
    166185: {"Unified_Ideograph", "Ideographic"},
    166186: {"Unified_Ideograph", "Ideographic"},
    166187: {"Unified_Ideograph", "Ideographic"},
    166188: {"Unified_Ideograph", "Ideographic"},
    166189: {"Unified_Ideograph", "Ideographic"},
    166190: {"Unified_Ideograph", "Ideographic"},
    166191: {"Unified_Ideograph", "Ideographic"},
    166192: {"Unified_Ideograph", "Ideographic"},
    166193: {"Unified_Ideograph", "Ideographic"},
    166194: {"Unified_Ideograph", "Ideographic"},
    166195: {"Unified_Ideograph", "Ideographic"},
    166196: {"Unified_Ideograph", "Ideographic"},
    166197: {"Unified_Ideograph", "Ideographic"},
    166198: {"Unified_Ideograph", "Ideographic"},
    166199: {"Unified_Ideograph", "Ideographic"},
    166200: {"Unified_Ideograph", "Ideographic"},
    166201: {"Unified_Ideograph", "Ideographic"},
    166202: {"Unified_Ideograph", "Ideographic"},
    166203: {"Unified_Ideograph", "Ideographic"},
    166204: {"Unified_Ideograph", "Ideographic"},
    166205: {"Unified_Ideograph", "Ideographic"},
    166206: {"Unified_Ideograph", "Ideographic"},
    166207: {"Unified_Ideograph", "Ideographic"},
    166208: {"Unified_Ideograph", "Ideographic"},
    166209: {"Unified_Ideograph", "Ideographic"},
    166210: {"Unified_Ideograph", "Ideographic"},
    166211: {"Unified_Ideograph", "Ideographic"},
    166212: {"Unified_Ideograph", "Ideographic"},
    166213: {"Unified_Ideograph", "Ideographic"},
    166214: {"Unified_Ideograph", "Ideographic"},
    166215: {"Unified_Ideograph", "Ideographic"},
    166216: {"Unified_Ideograph", "Ideographic"},
    166217: {"Unified_Ideograph", "Ideographic"},
    166218: {"Unified_Ideograph", "Ideographic"},
    166219: {"Unified_Ideograph", "Ideographic"},
    166220: {"Unified_Ideograph", "Ideographic"},
    166221: {"Unified_Ideograph", "Ideographic"},
    166222: {"Unified_Ideograph", "Ideographic"},
    166223: {"Unified_Ideograph", "Ideographic"},
    166224: {"Unified_Ideograph", "Ideographic"},
    166225: {"Unified_Ideograph", "Ideographic"},
    166226: {"Unified_Ideograph", "Ideographic"},
    166227: {"Unified_Ideograph", "Ideographic"},
    166228: {"Unified_Ideograph", "Ideographic"},
    166229: {"Unified_Ideograph", "Ideographic"},
    166230: {"Unified_Ideograph", "Ideographic"},
    166231: {"Unified_Ideograph", "Ideographic"},
    166232: {"Unified_Ideograph", "Ideographic"},
    166233: {"Unified_Ideograph", "Ideographic"},
    166234: {"Unified_Ideograph", "Ideographic"},
    166235: {"Unified_Ideograph", "Ideographic"},
    166236: {"Unified_Ideograph", "Ideographic"},
    166237: {"Unified_Ideograph", "Ideographic"},
    166238: {"Unified_Ideograph", "Ideographic"},
    166239: {"Unified_Ideograph", "Ideographic"},
    166240: {"Unified_Ideograph", "Ideographic"},
    166241: {"Unified_Ideograph", "Ideographic"},
    166242: {"Unified_Ideograph", "Ideographic"},
    166243: {"Unified_Ideograph", "Ideographic"},
    166244: {"Unified_Ideograph", "Ideographic"},
    166245: {"Unified_Ideograph", "Ideographic"},
    166246: {"Unified_Ideograph", "Ideographic"},
    166247: {"Unified_Ideograph", "Ideographic"},
    166248: {"Unified_Ideograph", "Ideographic"},
    166249: {"Unified_Ideograph", "Ideographic"},
    166250: {"Unified_Ideograph", "Ideographic"},
    166251: {"Unified_Ideograph", "Ideographic"},
    166252: {"Unified_Ideograph", "Ideographic"},
    166253: {"Unified_Ideograph", "Ideographic"},
    166254: {"Unified_Ideograph", "Ideographic"},
    166255: {"Unified_Ideograph", "Ideographic"},
    166256: {"Unified_Ideograph", "Ideographic"},
    166257: {"Unified_Ideograph", "Ideographic"},
    166258: {"Unified_Ideograph", "Ideographic"},
    166259: {"Unified_Ideograph", "Ideographic"},
    166260: {"Unified_Ideograph", "Ideographic"},
    166261: {"Unified_Ideograph", "Ideographic"},
    166262: {"Unified_Ideograph", "Ideographic"},
    166263: {"Unified_Ideograph", "Ideographic"},
    166264: {"Unified_Ideograph", "Ideographic"},
    166265: {"Unified_Ideograph", "Ideographic"},
    166266: {"Unified_Ideograph", "Ideographic"},
    166267: {"Unified_Ideograph", "Ideographic"},
    166268: {"Unified_Ideograph", "Ideographic"},
    166269: {"Unified_Ideograph", "Ideographic"},
    166270: {"Unified_Ideograph", "Ideographic"},
    166271: {"Unified_Ideograph", "Ideographic"},
    166272: {"Unified_Ideograph", "Ideographic"},
    166273: {"Unified_Ideograph", "Ideographic"},
    166274: {"Unified_Ideograph", "Ideographic"},
    166275: {"Unified_Ideograph", "Ideographic"},
    166276: {"Unified_Ideograph", "Ideographic"},
    166277: {"Unified_Ideograph", "Ideographic"},
    166278: {"Unified_Ideograph", "Ideographic"},
    166279: {"Unified_Ideograph", "Ideographic"},
    166280: {"Unified_Ideograph", "Ideographic"},
    166281: {"Unified_Ideograph", "Ideographic"},
    166282: {"Unified_Ideograph", "Ideographic"},
    166283: {"Unified_Ideograph", "Ideographic"},
    166284: {"Unified_Ideograph", "Ideographic"},
    166285: {"Unified_Ideograph", "Ideographic"},
    166286: {"Unified_Ideograph", "Ideographic"},
    166287: {"Unified_Ideograph", "Ideographic"},
    166288: {"Unified_Ideograph", "Ideographic"},
    166289: {"Unified_Ideograph", "Ideographic"},
    166290: {"Unified_Ideograph", "Ideographic"},
    166291: {"Unified_Ideograph", "Ideographic"},
    166292: {"Unified_Ideograph", "Ideographic"},
    166293: {"Unified_Ideograph", "Ideographic"},
    166294: {"Unified_Ideograph", "Ideographic"},
    166295: {"Unified_Ideograph", "Ideographic"},
    166296: {"Unified_Ideograph", "Ideographic"},
    166297: {"Unified_Ideograph", "Ideographic"},
    166298: {"Unified_Ideograph", "Ideographic"},
    166299: {"Unified_Ideograph", "Ideographic"},
    166300: {"Unified_Ideograph", "Ideographic"},
    166301: {"Unified_Ideograph", "Ideographic"},
    166302: {"Unified_Ideograph", "Ideographic"},
    166303: {"Unified_Ideograph", "Ideographic"},
    166304: {"Unified_Ideograph", "Ideographic"},
    166305: {"Unified_Ideograph", "Ideographic"},
    166306: {"Unified_Ideograph", "Ideographic"},
    166307: {"Unified_Ideograph", "Ideographic"},
    166308: {"Unified_Ideograph", "Ideographic"},
    166309: {"Unified_Ideograph", "Ideographic"},
    166310: {"Unified_Ideograph", "Ideographic"},
    166311: {"Unified_Ideograph", "Ideographic"},
    166312: {"Unified_Ideograph", "Ideographic"},
    166313: {"Unified_Ideograph", "Ideographic"},
    166314: {"Unified_Ideograph", "Ideographic"},
    166315: {"Unified_Ideograph", "Ideographic"},
    166316: {"Unified_Ideograph", "Ideographic"},
    166317: {"Unified_Ideograph", "Ideographic"},
    166318: {"Unified_Ideograph", "Ideographic"},
    166319: {"Unified_Ideograph", "Ideographic"},
    166320: {"Unified_Ideograph", "Ideographic"},
    166321: {"Unified_Ideograph", "Ideographic"},
    166322: {"Unified_Ideograph", "Ideographic"},
    166323: {"Unified_Ideograph", "Ideographic"},
    166324: {"Unified_Ideograph", "Ideographic"},
    166325: {"Unified_Ideograph", "Ideographic"},
    166326: {"Unified_Ideograph", "Ideographic"},
    166327: {"Unified_Ideograph", "Ideographic"},
    166328: {"Unified_Ideograph", "Ideographic"},
    166329: {"Unified_Ideograph", "Ideographic"},
    166330: {"Unified_Ideograph", "Ideographic"},
    166331: {"Unified_Ideograph", "Ideographic"},
    166332: {"Unified_Ideograph", "Ideographic"},
    166333: {"Unified_Ideograph", "Ideographic"},
    166334: {"Unified_Ideograph", "Ideographic"},
    166335: {"Unified_Ideograph", "Ideographic"},
    166336: {"Unified_Ideograph", "Ideographic"},
    166337: {"Unified_Ideograph", "Ideographic"},
    166338: {"Unified_Ideograph", "Ideographic"},
    166339: {"Unified_Ideograph", "Ideographic"},
    166340: {"Unified_Ideograph", "Ideographic"},
    166341: {"Unified_Ideograph", "Ideographic"},
    166342: {"Unified_Ideograph", "Ideographic"},
    166343: {"Unified_Ideograph", "Ideographic"},
    166344: {"Unified_Ideograph", "Ideographic"},
    166345: {"Unified_Ideograph", "Ideographic"},
    166346: {"Unified_Ideograph", "Ideographic"},
    166347: {"Unified_Ideograph", "Ideographic"},
    166348: {"Unified_Ideograph", "Ideographic"},
    166349: {"Unified_Ideograph", "Ideographic"},
    166350: {"Unified_Ideograph", "Ideographic"},
    166351: {"Unified_Ideograph", "Ideographic"},
    166352: {"Unified_Ideograph", "Ideographic"},
    166353: {"Unified_Ideograph", "Ideographic"},
    166354: {"Unified_Ideograph", "Ideographic"},
    166355: {"Unified_Ideograph", "Ideographic"},
    166356: {"Unified_Ideograph", "Ideographic"},
    166357: {"Unified_Ideograph", "Ideographic"},
    166358: {"Unified_Ideograph", "Ideographic"},
    166359: {"Unified_Ideograph", "Ideographic"},
    166360: {"Unified_Ideograph", "Ideographic"},
    166361: {"Unified_Ideograph", "Ideographic"},
    166362: {"Unified_Ideograph", "Ideographic"},
    166363: {"Unified_Ideograph", "Ideographic"},
    166364: {"Unified_Ideograph", "Ideographic"},
    166365: {"Unified_Ideograph", "Ideographic"},
    166366: {"Unified_Ideograph", "Ideographic"},
    166367: {"Unified_Ideograph", "Ideographic"},
    166368: {"Unified_Ideograph", "Ideographic"},
    166369: {"Unified_Ideograph", "Ideographic"},
    166370: {"Unified_Ideograph", "Ideographic"},
    166371: {"Unified_Ideograph", "Ideographic"},
    166372: {"Unified_Ideograph", "Ideographic"},
    166373: {"Unified_Ideograph", "Ideographic"},
    166374: {"Unified_Ideograph", "Ideographic"},
    166375: {"Unified_Ideograph", "Ideographic"},
    166376: {"Unified_Ideograph", "Ideographic"},
    166377: {"Unified_Ideograph", "Ideographic"},
    166378: {"Unified_Ideograph", "Ideographic"},
    166379: {"Unified_Ideograph", "Ideographic"},
    166380: {"Unified_Ideograph", "Ideographic"},
    166381: {"Unified_Ideograph", "Ideographic"},
    166382: {"Unified_Ideograph", "Ideographic"},
    166383: {"Unified_Ideograph", "Ideographic"},
    166384: {"Unified_Ideograph", "Ideographic"},
    166385: {"Unified_Ideograph", "Ideographic"},
    166386: {"Unified_Ideograph", "Ideographic"},
    166387: {"Unified_Ideograph", "Ideographic"},
    166388: {"Unified_Ideograph", "Ideographic"},
    166389: {"Unified_Ideograph", "Ideographic"},
    166390: {"Unified_Ideograph", "Ideographic"},
    166391: {"Unified_Ideograph", "Ideographic"},
    166392: {"Unified_Ideograph", "Ideographic"},
    166393: {"Unified_Ideograph", "Ideographic"},
    166394: {"Unified_Ideograph", "Ideographic"},
    166395: {"Unified_Ideograph", "Ideographic"},
    166396: {"Unified_Ideograph", "Ideographic"},
    166397: {"Unified_Ideograph", "Ideographic"},
    166398: {"Unified_Ideograph", "Ideographic"},
    166399: {"Unified_Ideograph", "Ideographic"},
    166400: {"Unified_Ideograph", "Ideographic"},
    166401: {"Unified_Ideograph", "Ideographic"},
    166402: {"Unified_Ideograph", "Ideographic"},
    166403: {"Unified_Ideograph", "Ideographic"},
    166404: {"Unified_Ideograph", "Ideographic"},
    166405: {"Unified_Ideograph", "Ideographic"},
    166406: {"Unified_Ideograph", "Ideographic"},
    166407: {"Unified_Ideograph", "Ideographic"},
    166408: {"Unified_Ideograph", "Ideographic"},
    166409: {"Unified_Ideograph", "Ideographic"},
    166410: {"Unified_Ideograph", "Ideographic"},
    166411: {"Unified_Ideograph", "Ideographic"},
    166412: {"Unified_Ideograph", "Ideographic"},
    166413: {"Unified_Ideograph", "Ideographic"},
    166414: {"Unified_Ideograph", "Ideographic"},
    166415: {"Unified_Ideograph", "Ideographic"},
    166416: {"Unified_Ideograph", "Ideographic"},
    166417: {"Unified_Ideograph", "Ideographic"},
    166418: {"Unified_Ideograph", "Ideographic"},
    166419: {"Unified_Ideograph", "Ideographic"},
    166420: {"Unified_Ideograph", "Ideographic"},
    166421: {"Unified_Ideograph", "Ideographic"},
    166422: {"Unified_Ideograph", "Ideographic"},
    166423: {"Unified_Ideograph", "Ideographic"},
    166424: {"Unified_Ideograph", "Ideographic"},
    166425: {"Unified_Ideograph", "Ideographic"},
    166426: {"Unified_Ideograph", "Ideographic"},
    166427: {"Unified_Ideograph", "Ideographic"},
    166428: {"Unified_Ideograph", "Ideographic"},
    166429: {"Unified_Ideograph", "Ideographic"},
    166430: {"Unified_Ideograph", "Ideographic"},
    166431: {"Unified_Ideograph", "Ideographic"},
    166432: {"Unified_Ideograph", "Ideographic"},
    166433: {"Unified_Ideograph", "Ideographic"},
    166434: {"Unified_Ideograph", "Ideographic"},
    166435: {"Unified_Ideograph", "Ideographic"},
    166436: {"Unified_Ideograph", "Ideographic"},
    166437: {"Unified_Ideograph", "Ideographic"},
    166438: {"Unified_Ideograph", "Ideographic"},
    166439: {"Unified_Ideograph", "Ideographic"},
    166440: {"Unified_Ideograph", "Ideographic"},
    166441: {"Unified_Ideograph", "Ideographic"},
    166442: {"Unified_Ideograph", "Ideographic"},
    166443: {"Unified_Ideograph", "Ideographic"},
    166444: {"Unified_Ideograph", "Ideographic"},
    166445: {"Unified_Ideograph", "Ideographic"},
    166446: {"Unified_Ideograph", "Ideographic"},
    166447: {"Unified_Ideograph", "Ideographic"},
    166448: {"Unified_Ideograph", "Ideographic"},
    166449: {"Unified_Ideograph", "Ideographic"},
    166450: {"Unified_Ideograph", "Ideographic"},
    166451: {"Unified_Ideograph", "Ideographic"},
    166452: {"Unified_Ideograph", "Ideographic"},
    166453: {"Unified_Ideograph", "Ideographic"},
    166454: {"Unified_Ideograph", "Ideographic"},
    166455: {"Unified_Ideograph", "Ideographic"},
    166456: {"Unified_Ideograph", "Ideographic"},
    166457: {"Unified_Ideograph", "Ideographic"},
    166458: {"Unified_Ideograph", "Ideographic"},
    166459: {"Unified_Ideograph", "Ideographic"},
    166460: {"Unified_Ideograph", "Ideographic"},
    166461: {"Unified_Ideograph", "Ideographic"},
    166462: {"Unified_Ideograph", "Ideographic"},
    166463: {"Unified_Ideograph", "Ideographic"},
    166464: {"Unified_Ideograph", "Ideographic"},
    166465: {"Unified_Ideograph", "Ideographic"},
    166466: {"Unified_Ideograph", "Ideographic"},
    166467: {"Unified_Ideograph", "Ideographic"},
    166468: {"Unified_Ideograph", "Ideographic"},
    166469: {"Unified_Ideograph", "Ideographic"},
    166470: {"Unified_Ideograph", "Ideographic"},
    166471: {"Unified_Ideograph", "Ideographic"},
    166472: {"Unified_Ideograph", "Ideographic"},
    166473: {"Unified_Ideograph", "Ideographic"},
    166474: {"Unified_Ideograph", "Ideographic"},
    166475: {"Unified_Ideograph", "Ideographic"},
    166476: {"Unified_Ideograph", "Ideographic"},
    166477: {"Unified_Ideograph", "Ideographic"},
    166478: {"Unified_Ideograph", "Ideographic"},
    166479: {"Unified_Ideograph", "Ideographic"},
    166480: {"Unified_Ideograph", "Ideographic"},
    166481: {"Unified_Ideograph", "Ideographic"},
    166482: {"Unified_Ideograph", "Ideographic"},
    166483: {"Unified_Ideograph", "Ideographic"},
    166484: {"Unified_Ideograph", "Ideographic"},
    166485: {"Unified_Ideograph", "Ideographic"},
    166486: {"Unified_Ideograph", "Ideographic"},
    166487: {"Unified_Ideograph", "Ideographic"},
    166488: {"Unified_Ideograph", "Ideographic"},
    166489: {"Unified_Ideograph", "Ideographic"},
    166490: {"Unified_Ideograph", "Ideographic"},
    166491: {"Unified_Ideograph", "Ideographic"},
    166492: {"Unified_Ideograph", "Ideographic"},
    166493: {"Unified_Ideograph", "Ideographic"},
    166494: {"Unified_Ideograph", "Ideographic"},
    166495: {"Unified_Ideograph", "Ideographic"},
    166496: {"Unified_Ideograph", "Ideographic"},
    166497: {"Unified_Ideograph", "Ideographic"},
    166498: {"Unified_Ideograph", "Ideographic"},
    166499: {"Unified_Ideograph", "Ideographic"},
    166500: {"Unified_Ideograph", "Ideographic"},
    166501: {"Unified_Ideograph", "Ideographic"},
    166502: {"Unified_Ideograph", "Ideographic"},
    166503: {"Unified_Ideograph", "Ideographic"},
    166504: {"Unified_Ideograph", "Ideographic"},
    166505: {"Unified_Ideograph", "Ideographic"},
    166506: {"Unified_Ideograph", "Ideographic"},
    166507: {"Unified_Ideograph", "Ideographic"},
    166508: {"Unified_Ideograph", "Ideographic"},
    166509: {"Unified_Ideograph", "Ideographic"},
    166510: {"Unified_Ideograph", "Ideographic"},
    166511: {"Unified_Ideograph", "Ideographic"},
    166512: {"Unified_Ideograph", "Ideographic"},
    166513: {"Unified_Ideograph", "Ideographic"},
    166514: {"Unified_Ideograph", "Ideographic"},
    166515: {"Unified_Ideograph", "Ideographic"},
    166516: {"Unified_Ideograph", "Ideographic"},
    166517: {"Unified_Ideograph", "Ideographic"},
    166518: {"Unified_Ideograph", "Ideographic"},
    166519: {"Unified_Ideograph", "Ideographic"},
    166520: {"Unified_Ideograph", "Ideographic"},
    166521: {"Unified_Ideograph", "Ideographic"},
    166522: {"Unified_Ideograph", "Ideographic"},
    166523: {"Unified_Ideograph", "Ideographic"},
    166524: {"Unified_Ideograph", "Ideographic"},
    166525: {"Unified_Ideograph", "Ideographic"},
    166526: {"Unified_Ideograph", "Ideographic"},
    166527: {"Unified_Ideograph", "Ideographic"},
    166528: {"Unified_Ideograph", "Ideographic"},
    166529: {"Unified_Ideograph", "Ideographic"},
    166530: {"Unified_Ideograph", "Ideographic"},
    166531: {"Unified_Ideograph", "Ideographic"},
    166532: {"Unified_Ideograph", "Ideographic"},
    166533: {"Unified_Ideograph", "Ideographic"},
    166534: {"Unified_Ideograph", "Ideographic"},
    166535: {"Unified_Ideograph", "Ideographic"},
    166536: {"Unified_Ideograph", "Ideographic"},
    166537: {"Unified_Ideograph", "Ideographic"},
    166538: {"Unified_Ideograph", "Ideographic"},
    166539: {"Unified_Ideograph", "Ideographic"},
    166540: {"Unified_Ideograph", "Ideographic"},
    166541: {"Unified_Ideograph", "Ideographic"},
    166542: {"Unified_Ideograph", "Ideographic"},
    166543: {"Unified_Ideograph", "Ideographic"},
    166544: {"Unified_Ideograph", "Ideographic"},
    166545: {"Unified_Ideograph", "Ideographic"},
    166546: {"Unified_Ideograph", "Ideographic"},
    166547: {"Unified_Ideograph", "Ideographic"},
    166548: {"Unified_Ideograph", "Ideographic"},
    166549: {"Unified_Ideograph", "Ideographic"},
    166550: {"Unified_Ideograph", "Ideographic"},
    166551: {"Unified_Ideograph", "Ideographic"},
    166552: {"Unified_Ideograph", "Ideographic"},
    166553: {"Unified_Ideograph", "Ideographic"},
    166554: {"Unified_Ideograph", "Ideographic"},
    166555: {"Unified_Ideograph", "Ideographic"},
    166556: {"Unified_Ideograph", "Ideographic"},
    166557: {"Unified_Ideograph", "Ideographic"},
    166558: {"Unified_Ideograph", "Ideographic"},
    166559: {"Unified_Ideograph", "Ideographic"},
    166560: {"Unified_Ideograph", "Ideographic"},
    166561: {"Unified_Ideograph", "Ideographic"},
    166562: {"Unified_Ideograph", "Ideographic"},
    166563: {"Unified_Ideograph", "Ideographic"},
    166564: {"Unified_Ideograph", "Ideographic"},
    166565: {"Unified_Ideograph", "Ideographic"},
    166566: {"Unified_Ideograph", "Ideographic"},
    166567: {"Unified_Ideograph", "Ideographic"},
    166568: {"Unified_Ideograph", "Ideographic"},
    166569: {"Unified_Ideograph", "Ideographic"},
    166570: {"Unified_Ideograph", "Ideographic"},
    166571: {"Unified_Ideograph", "Ideographic"},
    166572: {"Unified_Ideograph", "Ideographic"},
    166573: {"Unified_Ideograph", "Ideographic"},
    166574: {"Unified_Ideograph", "Ideographic"},
    166575: {"Unified_Ideograph", "Ideographic"},
    166576: {"Unified_Ideograph", "Ideographic"},
    166577: {"Unified_Ideograph", "Ideographic"},
    166578: {"Unified_Ideograph", "Ideographic"},
    166579: {"Unified_Ideograph", "Ideographic"},
    166580: {"Unified_Ideograph", "Ideographic"},
    166581: {"Unified_Ideograph", "Ideographic"},
    166582: {"Unified_Ideograph", "Ideographic"},
    166583: {"Unified_Ideograph", "Ideographic"},
    166584: {"Unified_Ideograph", "Ideographic"},
    166585: {"Unified_Ideograph", "Ideographic"},
    166586: {"Unified_Ideograph", "Ideographic"},
    166587: {"Unified_Ideograph", "Ideographic"},
    166588: {"Unified_Ideograph", "Ideographic"},
    166589: {"Unified_Ideograph", "Ideographic"},
    166590: {"Unified_Ideograph", "Ideographic"},
    166591: {"Unified_Ideograph", "Ideographic"},
    166592: {"Unified_Ideograph", "Ideographic"},
    166593: {"Unified_Ideograph", "Ideographic"},
    166594: {"Unified_Ideograph", "Ideographic"},
    166595: {"Unified_Ideograph", "Ideographic"},
    166596: {"Unified_Ideograph", "Ideographic"},
    166597: {"Unified_Ideograph", "Ideographic"},
    166598: {"Unified_Ideograph", "Ideographic"},
    166599: {"Unified_Ideograph", "Ideographic"},
    166600: {"Unified_Ideograph", "Ideographic"},
    166601: {"Unified_Ideograph", "Ideographic"},
    166602: {"Unified_Ideograph", "Ideographic"},
    166603: {"Unified_Ideograph", "Ideographic"},
    166604: {"Unified_Ideograph", "Ideographic"},
    166605: {"Unified_Ideograph", "Ideographic"},
    166606: {"Unified_Ideograph", "Ideographic"},
    166607: {"Unified_Ideograph", "Ideographic"},
    166608: {"Unified_Ideograph", "Ideographic"},
    166609: {"Unified_Ideograph", "Ideographic"},
    166610: {"Unified_Ideograph", "Ideographic"},
    166611: {"Unified_Ideograph", "Ideographic"},
    166612: {"Unified_Ideograph", "Ideographic"},
    166613: {"Unified_Ideograph", "Ideographic"},
    166614: {"Unified_Ideograph", "Ideographic"},
    166615: {"Unified_Ideograph", "Ideographic"},
    166616: {"Unified_Ideograph", "Ideographic"},
    166617: {"Unified_Ideograph", "Ideographic"},
    166618: {"Unified_Ideograph", "Ideographic"},
    166619: {"Unified_Ideograph", "Ideographic"},
    166620: {"Unified_Ideograph", "Ideographic"},
    166621: {"Unified_Ideograph", "Ideographic"},
    166622: {"Unified_Ideograph", "Ideographic"},
    166623: {"Unified_Ideograph", "Ideographic"},
    166624: {"Unified_Ideograph", "Ideographic"},
    166625: {"Unified_Ideograph", "Ideographic"},
    166626: {"Unified_Ideograph", "Ideographic"},
    166627: {"Unified_Ideograph", "Ideographic"},
    166628: {"Unified_Ideograph", "Ideographic"},
    166629: {"Unified_Ideograph", "Ideographic"},
    166630: {"Unified_Ideograph", "Ideographic"},
    166631: {"Unified_Ideograph", "Ideographic"},
    166632: {"Unified_Ideograph", "Ideographic"},
    166633: {"Unified_Ideograph", "Ideographic"},
    166634: {"Unified_Ideograph", "Ideographic"},
    166635: {"Unified_Ideograph", "Ideographic"},
    166636: {"Unified_Ideograph", "Ideographic"},
    166637: {"Unified_Ideograph", "Ideographic"},
    166638: {"Unified_Ideograph", "Ideographic"},
    166639: {"Unified_Ideograph", "Ideographic"},
    166640: {"Unified_Ideograph", "Ideographic"},
    166641: {"Unified_Ideograph", "Ideographic"},
    166642: {"Unified_Ideograph", "Ideographic"},
    166643: {"Unified_Ideograph", "Ideographic"},
    166644: {"Unified_Ideograph", "Ideographic"},
    166645: {"Unified_Ideograph", "Ideographic"},
    166646: {"Unified_Ideograph", "Ideographic"},
    166647: {"Unified_Ideograph", "Ideographic"},
    166648: {"Unified_Ideograph", "Ideographic"},
    166649: {"Unified_Ideograph", "Ideographic"},
    166650: {"Unified_Ideograph", "Ideographic"},
    166651: {"Unified_Ideograph", "Ideographic"},
    166652: {"Unified_Ideograph", "Ideographic"},
    166653: {"Unified_Ideograph", "Ideographic"},
    166654: {"Unified_Ideograph", "Ideographic"},
    166655: {"Unified_Ideograph", "Ideographic"},
    166656: {"Unified_Ideograph", "Ideographic"},
    166657: {"Unified_Ideograph", "Ideographic"},
    166658: {"Unified_Ideograph", "Ideographic"},
    166659: {"Unified_Ideograph", "Ideographic"},
    166660: {"Unified_Ideograph", "Ideographic"},
    166661: {"Unified_Ideograph", "Ideographic"},
    166662: {"Unified_Ideograph", "Ideographic"},
    166663: {"Unified_Ideograph", "Ideographic"},
    166664: {"Unified_Ideograph", "Ideographic"},
    166665: {"Unified_Ideograph", "Ideographic"},
    166666: {"Unified_Ideograph", "Ideographic"},
    166667: {"Unified_Ideograph", "Ideographic"},
    166668: {"Unified_Ideograph", "Ideographic"},
    166669: {"Unified_Ideograph", "Ideographic"},
    166670: {"Unified_Ideograph", "Ideographic"},
    166671: {"Unified_Ideograph", "Ideographic"},
    166672: {"Unified_Ideograph", "Ideographic"},
    166673: {"Unified_Ideograph", "Ideographic"},
    166674: {"Unified_Ideograph", "Ideographic"},
    166675: {"Unified_Ideograph", "Ideographic"},
    166676: {"Unified_Ideograph", "Ideographic"},
    166677: {"Unified_Ideograph", "Ideographic"},
    166678: {"Unified_Ideograph", "Ideographic"},
    166679: {"Unified_Ideograph", "Ideographic"},
    166680: {"Unified_Ideograph", "Ideographic"},
    166681: {"Unified_Ideograph", "Ideographic"},
    166682: {"Unified_Ideograph", "Ideographic"},
    166683: {"Unified_Ideograph", "Ideographic"},
    166684: {"Unified_Ideograph", "Ideographic"},
    166685: {"Unified_Ideograph", "Ideographic"},
    166686: {"Unified_Ideograph", "Ideographic"},
    166687: {"Unified_Ideograph", "Ideographic"},
    166688: {"Unified_Ideograph", "Ideographic"},
    166689: {"Unified_Ideograph", "Ideographic"},
    166690: {"Unified_Ideograph", "Ideographic"},
    166691: {"Unified_Ideograph", "Ideographic"},
    166692: {"Unified_Ideograph", "Ideographic"},
    166693: {"Unified_Ideograph", "Ideographic"},
    166694: {"Unified_Ideograph", "Ideographic"},
    166695: {"Unified_Ideograph", "Ideographic"},
    166696: {"Unified_Ideograph", "Ideographic"},
    166697: {"Unified_Ideograph", "Ideographic"},
    166698: {"Unified_Ideograph", "Ideographic"},
    166699: {"Unified_Ideograph", "Ideographic"},
    166700: {"Unified_Ideograph", "Ideographic"},
    166701: {"Unified_Ideograph", "Ideographic"},
    166702: {"Unified_Ideograph", "Ideographic"},
    166703: {"Unified_Ideograph", "Ideographic"},
    166704: {"Unified_Ideograph", "Ideographic"},
    166705: {"Unified_Ideograph", "Ideographic"},
    166706: {"Unified_Ideograph", "Ideographic"},
    166707: {"Unified_Ideograph", "Ideographic"},
    166708: {"Unified_Ideograph", "Ideographic"},
    166709: {"Unified_Ideograph", "Ideographic"},
    166710: {"Unified_Ideograph", "Ideographic"},
    166711: {"Unified_Ideograph", "Ideographic"},
    166712: {"Unified_Ideograph", "Ideographic"},
    166713: {"Unified_Ideograph", "Ideographic"},
    166714: {"Unified_Ideograph", "Ideographic"},
    166715: {"Unified_Ideograph", "Ideographic"},
    166716: {"Unified_Ideograph", "Ideographic"},
    166717: {"Unified_Ideograph", "Ideographic"},
    166718: {"Unified_Ideograph", "Ideographic"},
    166719: {"Unified_Ideograph", "Ideographic"},
    166720: {"Unified_Ideograph", "Ideographic"},
    166721: {"Unified_Ideograph", "Ideographic"},
    166722: {"Unified_Ideograph", "Ideographic"},
    166723: {"Unified_Ideograph", "Ideographic"},
    166724: {"Unified_Ideograph", "Ideographic"},
    166725: {"Unified_Ideograph", "Ideographic"},
    166726: {"Unified_Ideograph", "Ideographic"},
    166727: {"Unified_Ideograph", "Ideographic"},
    166728: {"Unified_Ideograph", "Ideographic"},
    166729: {"Unified_Ideograph", "Ideographic"},
    166730: {"Unified_Ideograph", "Ideographic"},
    166731: {"Unified_Ideograph", "Ideographic"},
    166732: {"Unified_Ideograph", "Ideographic"},
    166733: {"Unified_Ideograph", "Ideographic"},
    166734: {"Unified_Ideograph", "Ideographic"},
    166735: {"Unified_Ideograph", "Ideographic"},
    166736: {"Unified_Ideograph", "Ideographic"},
    166737: {"Unified_Ideograph", "Ideographic"},
    166738: {"Unified_Ideograph", "Ideographic"},
    166739: {"Unified_Ideograph", "Ideographic"},
    166740: {"Unified_Ideograph", "Ideographic"},
    166741: {"Unified_Ideograph", "Ideographic"},
    166742: {"Unified_Ideograph", "Ideographic"},
    166743: {"Unified_Ideograph", "Ideographic"},
    166744: {"Unified_Ideograph", "Ideographic"},
    166745: {"Unified_Ideograph", "Ideographic"},
    166746: {"Unified_Ideograph", "Ideographic"},
    166747: {"Unified_Ideograph", "Ideographic"},
    166748: {"Unified_Ideograph", "Ideographic"},
    166749: {"Unified_Ideograph", "Ideographic"},
    166750: {"Unified_Ideograph", "Ideographic"},
    166751: {"Unified_Ideograph", "Ideographic"},
    166752: {"Unified_Ideograph", "Ideographic"},
    166753: {"Unified_Ideograph", "Ideographic"},
    166754: {"Unified_Ideograph", "Ideographic"},
    166755: {"Unified_Ideograph", "Ideographic"},
    166756: {"Unified_Ideograph", "Ideographic"},
    166757: {"Unified_Ideograph", "Ideographic"},
    166758: {"Unified_Ideograph", "Ideographic"},
    166759: {"Unified_Ideograph", "Ideographic"},
    166760: {"Unified_Ideograph", "Ideographic"},
    166761: {"Unified_Ideograph", "Ideographic"},
    166762: {"Unified_Ideograph", "Ideographic"},
    166763: {"Unified_Ideograph", "Ideographic"},
    166764: {"Unified_Ideograph", "Ideographic"},
    166765: {"Unified_Ideograph", "Ideographic"},
    166766: {"Unified_Ideograph", "Ideographic"},
    166767: {"Unified_Ideograph", "Ideographic"},
    166768: {"Unified_Ideograph", "Ideographic"},
    166769: {"Unified_Ideograph", "Ideographic"},
    166770: {"Unified_Ideograph", "Ideographic"},
    166771: {"Unified_Ideograph", "Ideographic"},
    166772: {"Unified_Ideograph", "Ideographic"},
    166773: {"Unified_Ideograph", "Ideographic"},
    166774: {"Unified_Ideograph", "Ideographic"},
    166775: {"Unified_Ideograph", "Ideographic"},
    166776: {"Unified_Ideograph", "Ideographic"},
    166777: {"Unified_Ideograph", "Ideographic"},
    166778: {"Unified_Ideograph", "Ideographic"},
    166779: {"Unified_Ideograph", "Ideographic"},
    166780: {"Unified_Ideograph", "Ideographic"},
    166781: {"Unified_Ideograph", "Ideographic"},
    166782: {"Unified_Ideograph", "Ideographic"},
    166783: {"Unified_Ideograph", "Ideographic"},
    166784: {"Unified_Ideograph", "Ideographic"},
    166785: {"Unified_Ideograph", "Ideographic"},
    166786: {"Unified_Ideograph", "Ideographic"},
    166787: {"Unified_Ideograph", "Ideographic"},
    166788: {"Unified_Ideograph", "Ideographic"},
    166789: {"Unified_Ideograph", "Ideographic"},
    166790: {"Unified_Ideograph", "Ideographic"},
    166791: {"Unified_Ideograph", "Ideographic"},
    166792: {"Unified_Ideograph", "Ideographic"},
    166793: {"Unified_Ideograph", "Ideographic"},
    166794: {"Unified_Ideograph", "Ideographic"},
    166795: {"Unified_Ideograph", "Ideographic"},
    166796: {"Unified_Ideograph", "Ideographic"},
    166797: {"Unified_Ideograph", "Ideographic"},
    166798: {"Unified_Ideograph", "Ideographic"},
    166799: {"Unified_Ideograph", "Ideographic"},
    166800: {"Unified_Ideograph", "Ideographic"},
    166801: {"Unified_Ideograph", "Ideographic"},
    166802: {"Unified_Ideograph", "Ideographic"},
    166803: {"Unified_Ideograph", "Ideographic"},
    166804: {"Unified_Ideograph", "Ideographic"},
    166805: {"Unified_Ideograph", "Ideographic"},
    166806: {"Unified_Ideograph", "Ideographic"},
    166807: {"Unified_Ideograph", "Ideographic"},
    166808: {"Unified_Ideograph", "Ideographic"},
    166809: {"Unified_Ideograph", "Ideographic"},
    166810: {"Unified_Ideograph", "Ideographic"},
    166811: {"Unified_Ideograph", "Ideographic"},
    166812: {"Unified_Ideograph", "Ideographic"},
    166813: {"Unified_Ideograph", "Ideographic"},
    166814: {"Unified_Ideograph", "Ideographic"},
    166815: {"Unified_Ideograph", "Ideographic"},
    166816: {"Unified_Ideograph", "Ideographic"},
    166817: {"Unified_Ideograph", "Ideographic"},
    166818: {"Unified_Ideograph", "Ideographic"},
    166819: {"Unified_Ideograph", "Ideographic"},
    166820: {"Unified_Ideograph", "Ideographic"},
    166821: {"Unified_Ideograph", "Ideographic"},
    166822: {"Unified_Ideograph", "Ideographic"},
    166823: {"Unified_Ideograph", "Ideographic"},
    166824: {"Unified_Ideograph", "Ideographic"},
    166825: {"Unified_Ideograph", "Ideographic"},
    166826: {"Unified_Ideograph", "Ideographic"},
    166827: {"Unified_Ideograph", "Ideographic"},
    166828: {"Unified_Ideograph", "Ideographic"},
    166829: {"Unified_Ideograph", "Ideographic"},
    166830: {"Unified_Ideograph", "Ideographic"},
    166831: {"Unified_Ideograph", "Ideographic"},
    166832: {"Unified_Ideograph", "Ideographic"},
    166833: {"Unified_Ideograph", "Ideographic"},
    166834: {"Unified_Ideograph", "Ideographic"},
    166835: {"Unified_Ideograph", "Ideographic"},
    166836: {"Unified_Ideograph", "Ideographic"},
    166837: {"Unified_Ideograph", "Ideographic"},
    166838: {"Unified_Ideograph", "Ideographic"},
    166839: {"Unified_Ideograph", "Ideographic"},
    166840: {"Unified_Ideograph", "Ideographic"},
    166841: {"Unified_Ideograph", "Ideographic"},
    166842: {"Unified_Ideograph", "Ideographic"},
    166843: {"Unified_Ideograph", "Ideographic"},
    166844: {"Unified_Ideograph", "Ideographic"},
    166845: {"Unified_Ideograph", "Ideographic"},
    166846: {"Unified_Ideograph", "Ideographic"},
    166847: {"Unified_Ideograph", "Ideographic"},
    166848: {"Unified_Ideograph", "Ideographic"},
    166849: {"Unified_Ideograph", "Ideographic"},
    166850: {"Unified_Ideograph", "Ideographic"},
    166851: {"Unified_Ideograph", "Ideographic"},
    166852: {"Unified_Ideograph", "Ideographic"},
    166853: {"Unified_Ideograph", "Ideographic"},
    166854: {"Unified_Ideograph", "Ideographic"},
    166855: {"Unified_Ideograph", "Ideographic"},
    166856: {"Unified_Ideograph", "Ideographic"},
    166857: {"Unified_Ideograph", "Ideographic"},
    166858: {"Unified_Ideograph", "Ideographic"},
    166859: {"Unified_Ideograph", "Ideographic"},
    166860: {"Unified_Ideograph", "Ideographic"},
    166861: {"Unified_Ideograph", "Ideographic"},
    166862: {"Unified_Ideograph", "Ideographic"},
    166863: {"Unified_Ideograph", "Ideographic"},
    166864: {"Unified_Ideograph", "Ideographic"},
    166865: {"Unified_Ideograph", "Ideographic"},
    166866: {"Unified_Ideograph", "Ideographic"},
    166867: {"Unified_Ideograph", "Ideographic"},
    166868: {"Unified_Ideograph", "Ideographic"},
    166869: {"Unified_Ideograph", "Ideographic"},
    166870: {"Unified_Ideograph", "Ideographic"},
    166871: {"Unified_Ideograph", "Ideographic"},
    166872: {"Unified_Ideograph", "Ideographic"},
    166873: {"Unified_Ideograph", "Ideographic"},
    166874: {"Unified_Ideograph", "Ideographic"},
    166875: {"Unified_Ideograph", "Ideographic"},
    166876: {"Unified_Ideograph", "Ideographic"},
    166877: {"Unified_Ideograph", "Ideographic"},
    166878: {"Unified_Ideograph", "Ideographic"},
    166879: {"Unified_Ideograph", "Ideographic"},
    166880: {"Unified_Ideograph", "Ideographic"},
    166881: {"Unified_Ideograph", "Ideographic"},
    166882: {"Unified_Ideograph", "Ideographic"},
    166883: {"Unified_Ideograph", "Ideographic"},
    166884: {"Unified_Ideograph", "Ideographic"},
    166885: {"Unified_Ideograph", "Ideographic"},
    166886: {"Unified_Ideograph", "Ideographic"},
    166887: {"Unified_Ideograph", "Ideographic"},
    166888: {"Unified_Ideograph", "Ideographic"},
    166889: {"Unified_Ideograph", "Ideographic"},
    166890: {"Unified_Ideograph", "Ideographic"},
    166891: {"Unified_Ideograph", "Ideographic"},
    166892: {"Unified_Ideograph", "Ideographic"},
    166893: {"Unified_Ideograph", "Ideographic"},
    166894: {"Unified_Ideograph", "Ideographic"},
    166895: {"Unified_Ideograph", "Ideographic"},
    166896: {"Unified_Ideograph", "Ideographic"},
    166897: {"Unified_Ideograph", "Ideographic"},
    166898: {"Unified_Ideograph", "Ideographic"},
    166899: {"Unified_Ideograph", "Ideographic"},
    166900: {"Unified_Ideograph", "Ideographic"},
    166901: {"Unified_Ideograph", "Ideographic"},
    166902: {"Unified_Ideograph", "Ideographic"},
    166903: {"Unified_Ideograph", "Ideographic"},
    166904: {"Unified_Ideograph", "Ideographic"},
    166905: {"Unified_Ideograph", "Ideographic"},
    166906: {"Unified_Ideograph", "Ideographic"},
    166907: {"Unified_Ideograph", "Ideographic"},
    166908: {"Unified_Ideograph", "Ideographic"},
    166909: {"Unified_Ideograph", "Ideographic"},
    166910: {"Unified_Ideograph", "Ideographic"},
    166911: {"Unified_Ideograph", "Ideographic"},
    166912: {"Unified_Ideograph", "Ideographic"},
    166913: {"Unified_Ideograph", "Ideographic"},
    166914: {"Unified_Ideograph", "Ideographic"},
    166915: {"Unified_Ideograph", "Ideographic"},
    166916: {"Unified_Ideograph", "Ideographic"},
    166917: {"Unified_Ideograph", "Ideographic"},
    166918: {"Unified_Ideograph", "Ideographic"},
    166919: {"Unified_Ideograph", "Ideographic"},
    166920: {"Unified_Ideograph", "Ideographic"},
    166921: {"Unified_Ideograph", "Ideographic"},
    166922: {"Unified_Ideograph", "Ideographic"},
    166923: {"Unified_Ideograph", "Ideographic"},
    166924: {"Unified_Ideograph", "Ideographic"},
    166925: {"Unified_Ideograph", "Ideographic"},
    166926: {"Unified_Ideograph", "Ideographic"},
    166927: {"Unified_Ideograph", "Ideographic"},
    166928: {"Unified_Ideograph", "Ideographic"},
    166929: {"Unified_Ideograph", "Ideographic"},
    166930: {"Unified_Ideograph", "Ideographic"},
    166931: {"Unified_Ideograph", "Ideographic"},
    166932: {"Unified_Ideograph", "Ideographic"},
    166933: {"Unified_Ideograph", "Ideographic"},
    166934: {"Unified_Ideograph", "Ideographic"},
    166935: {"Unified_Ideograph", "Ideographic"},
    166936: {"Unified_Ideograph", "Ideographic"},
    166937: {"Unified_Ideograph", "Ideographic"},
    166938: {"Unified_Ideograph", "Ideographic"},
    166939: {"Unified_Ideograph", "Ideographic"},
    166940: {"Unified_Ideograph", "Ideographic"},
    166941: {"Unified_Ideograph", "Ideographic"},
    166942: {"Unified_Ideograph", "Ideographic"},
    166943: {"Unified_Ideograph", "Ideographic"},
    166944: {"Unified_Ideograph", "Ideographic"},
    166945: {"Unified_Ideograph", "Ideographic"},
    166946: {"Unified_Ideograph", "Ideographic"},
    166947: {"Unified_Ideograph", "Ideographic"},
    166948: {"Unified_Ideograph", "Ideographic"},
    166949: {"Unified_Ideograph", "Ideographic"},
    166950: {"Unified_Ideograph", "Ideographic"},
    166951: {"Unified_Ideograph", "Ideographic"},
    166952: {"Unified_Ideograph", "Ideographic"},
    166953: {"Unified_Ideograph", "Ideographic"},
    166954: {"Unified_Ideograph", "Ideographic"},
    166955: {"Unified_Ideograph", "Ideographic"},
    166956: {"Unified_Ideograph", "Ideographic"},
    166957: {"Unified_Ideograph", "Ideographic"},
    166958: {"Unified_Ideograph", "Ideographic"},
    166959: {"Unified_Ideograph", "Ideographic"},
    166960: {"Unified_Ideograph", "Ideographic"},
    166961: {"Unified_Ideograph", "Ideographic"},
    166962: {"Unified_Ideograph", "Ideographic"},
    166963: {"Unified_Ideograph", "Ideographic"},
    166964: {"Unified_Ideograph", "Ideographic"},
    166965: {"Unified_Ideograph", "Ideographic"},
    166966: {"Unified_Ideograph", "Ideographic"},
    166967: {"Unified_Ideograph", "Ideographic"},
    166968: {"Unified_Ideograph", "Ideographic"},
    166969: {"Unified_Ideograph", "Ideographic"},
    166970: {"Unified_Ideograph", "Ideographic"},
    166971: {"Unified_Ideograph", "Ideographic"},
    166972: {"Unified_Ideograph", "Ideographic"},
    166973: {"Unified_Ideograph", "Ideographic"},
    166974: {"Unified_Ideograph", "Ideographic"},
    166975: {"Unified_Ideograph", "Ideographic"},
    166976: {"Unified_Ideograph", "Ideographic"},
    166977: {"Unified_Ideograph", "Ideographic"},
    166978: {"Unified_Ideograph", "Ideographic"},
    166979: {"Unified_Ideograph", "Ideographic"},
    166980: {"Unified_Ideograph", "Ideographic"},
    166981: {"Unified_Ideograph", "Ideographic"},
    166982: {"Unified_Ideograph", "Ideographic"},
    166983: {"Unified_Ideograph", "Ideographic"},
    166984: {"Unified_Ideograph", "Ideographic"},
    166985: {"Unified_Ideograph", "Ideographic"},
    166986: {"Unified_Ideograph", "Ideographic"},
    166987: {"Unified_Ideograph", "Ideographic"},
    166988: {"Unified_Ideograph", "Ideographic"},
    166989: {"Unified_Ideograph", "Ideographic"},
    166990: {"Unified_Ideograph", "Ideographic"},
    166991: {"Unified_Ideograph", "Ideographic"},
    166992: {"Unified_Ideograph", "Ideographic"},
    166993: {"Unified_Ideograph", "Ideographic"},
    166994: {"Unified_Ideograph", "Ideographic"},
    166995: {"Unified_Ideograph", "Ideographic"},
    166996: {"Unified_Ideograph", "Ideographic"},
    166997: {"Unified_Ideograph", "Ideographic"},
    166998: {"Unified_Ideograph", "Ideographic"},
    166999: {"Unified_Ideograph", "Ideographic"},
    167000: {"Unified_Ideograph", "Ideographic"},
    167001: {"Unified_Ideograph", "Ideographic"},
    167002: {"Unified_Ideograph", "Ideographic"},
    167003: {"Unified_Ideograph", "Ideographic"},
    167004: {"Unified_Ideograph", "Ideographic"},
    167005: {"Unified_Ideograph", "Ideographic"},
    167006: {"Unified_Ideograph", "Ideographic"},
    167007: {"Unified_Ideograph", "Ideographic"},
    167008: {"Unified_Ideograph", "Ideographic"},
    167009: {"Unified_Ideograph", "Ideographic"},
    167010: {"Unified_Ideograph", "Ideographic"},
    167011: {"Unified_Ideograph", "Ideographic"},
    167012: {"Unified_Ideograph", "Ideographic"},
    167013: {"Unified_Ideograph", "Ideographic"},
    167014: {"Unified_Ideograph", "Ideographic"},
    167015: {"Unified_Ideograph", "Ideographic"},
    167016: {"Unified_Ideograph", "Ideographic"},
    167017: {"Unified_Ideograph", "Ideographic"},
    167018: {"Unified_Ideograph", "Ideographic"},
    167019: {"Unified_Ideograph", "Ideographic"},
    167020: {"Unified_Ideograph", "Ideographic"},
    167021: {"Unified_Ideograph", "Ideographic"},
    167022: {"Unified_Ideograph", "Ideographic"},
    167023: {"Unified_Ideograph", "Ideographic"},
    167024: {"Unified_Ideograph", "Ideographic"},
    167025: {"Unified_Ideograph", "Ideographic"},
    167026: {"Unified_Ideograph", "Ideographic"},
    167027: {"Unified_Ideograph", "Ideographic"},
    167028: {"Unified_Ideograph", "Ideographic"},
    167029: {"Unified_Ideograph", "Ideographic"},
    167030: {"Unified_Ideograph", "Ideographic"},
    167031: {"Unified_Ideograph", "Ideographic"},
    167032: {"Unified_Ideograph", "Ideographic"},
    167033: {"Unified_Ideograph", "Ideographic"},
    167034: {"Unified_Ideograph", "Ideographic"},
    167035: {"Unified_Ideograph", "Ideographic"},
    167036: {"Unified_Ideograph", "Ideographic"},
    167037: {"Unified_Ideograph", "Ideographic"},
    167038: {"Unified_Ideograph", "Ideographic"},
    167039: {"Unified_Ideograph", "Ideographic"},
    167040: {"Unified_Ideograph", "Ideographic"},
    167041: {"Unified_Ideograph", "Ideographic"},
    167042: {"Unified_Ideograph", "Ideographic"},
    167043: {"Unified_Ideograph", "Ideographic"},
    167044: {"Unified_Ideograph", "Ideographic"},
    167045: {"Unified_Ideograph", "Ideographic"},
    167046: {"Unified_Ideograph", "Ideographic"},
    167047: {"Unified_Ideograph", "Ideographic"},
    167048: {"Unified_Ideograph", "Ideographic"},
    167049: {"Unified_Ideograph", "Ideographic"},
    167050: {"Unified_Ideograph", "Ideographic"},
    167051: {"Unified_Ideograph", "Ideographic"},
    167052: {"Unified_Ideograph", "Ideographic"},
    167053: {"Unified_Ideograph", "Ideographic"},
    167054: {"Unified_Ideograph", "Ideographic"},
    167055: {"Unified_Ideograph", "Ideographic"},
    167056: {"Unified_Ideograph", "Ideographic"},
    167057: {"Unified_Ideograph", "Ideographic"},
    167058: {"Unified_Ideograph", "Ideographic"},
    167059: {"Unified_Ideograph", "Ideographic"},
    167060: {"Unified_Ideograph", "Ideographic"},
    167061: {"Unified_Ideograph", "Ideographic"},
    167062: {"Unified_Ideograph", "Ideographic"},
    167063: {"Unified_Ideograph", "Ideographic"},
    167064: {"Unified_Ideograph", "Ideographic"},
    167065: {"Unified_Ideograph", "Ideographic"},
    167066: {"Unified_Ideograph", "Ideographic"},
    167067: {"Unified_Ideograph", "Ideographic"},
    167068: {"Unified_Ideograph", "Ideographic"},
    167069: {"Unified_Ideograph", "Ideographic"},
    167070: {"Unified_Ideograph", "Ideographic"},
    167071: {"Unified_Ideograph", "Ideographic"},
    167072: {"Unified_Ideograph", "Ideographic"},
    167073: {"Unified_Ideograph", "Ideographic"},
    167074: {"Unified_Ideograph", "Ideographic"},
    167075: {"Unified_Ideograph", "Ideographic"},
    167076: {"Unified_Ideograph", "Ideographic"},
    167077: {"Unified_Ideograph", "Ideographic"},
    167078: {"Unified_Ideograph", "Ideographic"},
    167079: {"Unified_Ideograph", "Ideographic"},
    167080: {"Unified_Ideograph", "Ideographic"},
    167081: {"Unified_Ideograph", "Ideographic"},
    167082: {"Unified_Ideograph", "Ideographic"},
    167083: {"Unified_Ideograph", "Ideographic"},
    167084: {"Unified_Ideograph", "Ideographic"},
    167085: {"Unified_Ideograph", "Ideographic"},
    167086: {"Unified_Ideograph", "Ideographic"},
    167087: {"Unified_Ideograph", "Ideographic"},
    167088: {"Unified_Ideograph", "Ideographic"},
    167089: {"Unified_Ideograph", "Ideographic"},
    167090: {"Unified_Ideograph", "Ideographic"},
    167091: {"Unified_Ideograph", "Ideographic"},
    167092: {"Unified_Ideograph", "Ideographic"},
    167093: {"Unified_Ideograph", "Ideographic"},
    167094: {"Unified_Ideograph", "Ideographic"},
    167095: {"Unified_Ideograph", "Ideographic"},
    167096: {"Unified_Ideograph", "Ideographic"},
    167097: {"Unified_Ideograph", "Ideographic"},
    167098: {"Unified_Ideograph", "Ideographic"},
    167099: {"Unified_Ideograph", "Ideographic"},
    167100: {"Unified_Ideograph", "Ideographic"},
    167101: {"Unified_Ideograph", "Ideographic"},
    167102: {"Unified_Ideograph", "Ideographic"},
    167103: {"Unified_Ideograph", "Ideographic"},
    167104: {"Unified_Ideograph", "Ideographic"},
    167105: {"Unified_Ideograph", "Ideographic"},
    167106: {"Unified_Ideograph", "Ideographic"},
    167107: {"Unified_Ideograph", "Ideographic"},
    167108: {"Unified_Ideograph", "Ideographic"},
    167109: {"Unified_Ideograph", "Ideographic"},
    167110: {"Unified_Ideograph", "Ideographic"},
    167111: {"Unified_Ideograph", "Ideographic"},
    167112: {"Unified_Ideograph", "Ideographic"},
    167113: {"Unified_Ideograph", "Ideographic"},
    167114: {"Unified_Ideograph", "Ideographic"},
    167115: {"Unified_Ideograph", "Ideographic"},
    167116: {"Unified_Ideograph", "Ideographic"},
    167117: {"Unified_Ideograph", "Ideographic"},
    167118: {"Unified_Ideograph", "Ideographic"},
    167119: {"Unified_Ideograph", "Ideographic"},
    167120: {"Unified_Ideograph", "Ideographic"},
    167121: {"Unified_Ideograph", "Ideographic"},
    167122: {"Unified_Ideograph", "Ideographic"},
    167123: {"Unified_Ideograph", "Ideographic"},
    167124: {"Unified_Ideograph", "Ideographic"},
    167125: {"Unified_Ideograph", "Ideographic"},
    167126: {"Unified_Ideograph", "Ideographic"},
    167127: {"Unified_Ideograph", "Ideographic"},
    167128: {"Unified_Ideograph", "Ideographic"},
    167129: {"Unified_Ideograph", "Ideographic"},
    167130: {"Unified_Ideograph", "Ideographic"},
    167131: {"Unified_Ideograph", "Ideographic"},
    167132: {"Unified_Ideograph", "Ideographic"},
    167133: {"Unified_Ideograph", "Ideographic"},
    167134: {"Unified_Ideograph", "Ideographic"},
    167135: {"Unified_Ideograph", "Ideographic"},
    167136: {"Unified_Ideograph", "Ideographic"},
    167137: {"Unified_Ideograph", "Ideographic"},
    167138: {"Unified_Ideograph", "Ideographic"},
    167139: {"Unified_Ideograph", "Ideographic"},
    167140: {"Unified_Ideograph", "Ideographic"},
    167141: {"Unified_Ideograph", "Ideographic"},
    167142: {"Unified_Ideograph", "Ideographic"},
    167143: {"Unified_Ideograph", "Ideographic"},
    167144: {"Unified_Ideograph", "Ideographic"},
    167145: {"Unified_Ideograph", "Ideographic"},
    167146: {"Unified_Ideograph", "Ideographic"},
    167147: {"Unified_Ideograph", "Ideographic"},
    167148: {"Unified_Ideograph", "Ideographic"},
    167149: {"Unified_Ideograph", "Ideographic"},
    167150: {"Unified_Ideograph", "Ideographic"},
    167151: {"Unified_Ideograph", "Ideographic"},
    167152: {"Unified_Ideograph", "Ideographic"},
    167153: {"Unified_Ideograph", "Ideographic"},
    167154: {"Unified_Ideograph", "Ideographic"},
    167155: {"Unified_Ideograph", "Ideographic"},
    167156: {"Unified_Ideograph", "Ideographic"},
    167157: {"Unified_Ideograph", "Ideographic"},
    167158: {"Unified_Ideograph", "Ideographic"},
    167159: {"Unified_Ideograph", "Ideographic"},
    167160: {"Unified_Ideograph", "Ideographic"},
    167161: {"Unified_Ideograph", "Ideographic"},
    167162: {"Unified_Ideograph", "Ideographic"},
    167163: {"Unified_Ideograph", "Ideographic"},
    167164: {"Unified_Ideograph", "Ideographic"},
    167165: {"Unified_Ideograph", "Ideographic"},
    167166: {"Unified_Ideograph", "Ideographic"},
    167167: {"Unified_Ideograph", "Ideographic"},
    167168: {"Unified_Ideograph", "Ideographic"},
    167169: {"Unified_Ideograph", "Ideographic"},
    167170: {"Unified_Ideograph", "Ideographic"},
    167171: {"Unified_Ideograph", "Ideographic"},
    167172: {"Unified_Ideograph", "Ideographic"},
    167173: {"Unified_Ideograph", "Ideographic"},
    167174: {"Unified_Ideograph", "Ideographic"},
    167175: {"Unified_Ideograph", "Ideographic"},
    167176: {"Unified_Ideograph", "Ideographic"},
    167177: {"Unified_Ideograph", "Ideographic"},
    167178: {"Unified_Ideograph", "Ideographic"},
    167179: {"Unified_Ideograph", "Ideographic"},
    167180: {"Unified_Ideograph", "Ideographic"},
    167181: {"Unified_Ideograph", "Ideographic"},
    167182: {"Unified_Ideograph", "Ideographic"},
    167183: {"Unified_Ideograph", "Ideographic"},
    167184: {"Unified_Ideograph", "Ideographic"},
    167185: {"Unified_Ideograph", "Ideographic"},
    167186: {"Unified_Ideograph", "Ideographic"},
    167187: {"Unified_Ideograph", "Ideographic"},
    167188: {"Unified_Ideograph", "Ideographic"},
    167189: {"Unified_Ideograph", "Ideographic"},
    167190: {"Unified_Ideograph", "Ideographic"},
    167191: {"Unified_Ideograph", "Ideographic"},
    167192: {"Unified_Ideograph", "Ideographic"},
    167193: {"Unified_Ideograph", "Ideographic"},
    167194: {"Unified_Ideograph", "Ideographic"},
    167195: {"Unified_Ideograph", "Ideographic"},
    167196: {"Unified_Ideograph", "Ideographic"},
    167197: {"Unified_Ideograph", "Ideographic"},
    167198: {"Unified_Ideograph", "Ideographic"},
    167199: {"Unified_Ideograph", "Ideographic"},
    167200: {"Unified_Ideograph", "Ideographic"},
    167201: {"Unified_Ideograph", "Ideographic"},
    167202: {"Unified_Ideograph", "Ideographic"},
    167203: {"Unified_Ideograph", "Ideographic"},
    167204: {"Unified_Ideograph", "Ideographic"},
    167205: {"Unified_Ideograph", "Ideographic"},
    167206: {"Unified_Ideograph", "Ideographic"},
    167207: {"Unified_Ideograph", "Ideographic"},
    167208: {"Unified_Ideograph", "Ideographic"},
    167209: {"Unified_Ideograph", "Ideographic"},
    167210: {"Unified_Ideograph", "Ideographic"},
    167211: {"Unified_Ideograph", "Ideographic"},
    167212: {"Unified_Ideograph", "Ideographic"},
    167213: {"Unified_Ideograph", "Ideographic"},
    167214: {"Unified_Ideograph", "Ideographic"},
    167215: {"Unified_Ideograph", "Ideographic"},
    167216: {"Unified_Ideograph", "Ideographic"},
    167217: {"Unified_Ideograph", "Ideographic"},
    167218: {"Unified_Ideograph", "Ideographic"},
    167219: {"Unified_Ideograph", "Ideographic"},
    167220: {"Unified_Ideograph", "Ideographic"},
    167221: {"Unified_Ideograph", "Ideographic"},
    167222: {"Unified_Ideograph", "Ideographic"},
    167223: {"Unified_Ideograph", "Ideographic"},
    167224: {"Unified_Ideograph", "Ideographic"},
    167225: {"Unified_Ideograph", "Ideographic"},
    167226: {"Unified_Ideograph", "Ideographic"},
    167227: {"Unified_Ideograph", "Ideographic"},
    167228: {"Unified_Ideograph", "Ideographic"},
    167229: {"Unified_Ideograph", "Ideographic"},
    167230: {"Unified_Ideograph", "Ideographic"},
    167231: {"Unified_Ideograph", "Ideographic"},
    167232: {"Unified_Ideograph", "Ideographic"},
    167233: {"Unified_Ideograph", "Ideographic"},
    167234: {"Unified_Ideograph", "Ideographic"},
    167235: {"Unified_Ideograph", "Ideographic"},
    167236: {"Unified_Ideograph", "Ideographic"},
    167237: {"Unified_Ideograph", "Ideographic"},
    167238: {"Unified_Ideograph", "Ideographic"},
    167239: {"Unified_Ideograph", "Ideographic"},
    167240: {"Unified_Ideograph", "Ideographic"},
    167241: {"Unified_Ideograph", "Ideographic"},
    167242: {"Unified_Ideograph", "Ideographic"},
    167243: {"Unified_Ideograph", "Ideographic"},
    167244: {"Unified_Ideograph", "Ideographic"},
    167245: {"Unified_Ideograph", "Ideographic"},
    167246: {"Unified_Ideograph", "Ideographic"},
    167247: {"Unified_Ideograph", "Ideographic"},
    167248: {"Unified_Ideograph", "Ideographic"},
    167249: {"Unified_Ideograph", "Ideographic"},
    167250: {"Unified_Ideograph", "Ideographic"},
    167251: {"Unified_Ideograph", "Ideographic"},
    167252: {"Unified_Ideograph", "Ideographic"},
    167253: {"Unified_Ideograph", "Ideographic"},
    167254: {"Unified_Ideograph", "Ideographic"},
    167255: {"Unified_Ideograph", "Ideographic"},
    167256: {"Unified_Ideograph", "Ideographic"},
    167257: {"Unified_Ideograph", "Ideographic"},
    167258: {"Unified_Ideograph", "Ideographic"},
    167259: {"Unified_Ideograph", "Ideographic"},
    167260: {"Unified_Ideograph", "Ideographic"},
    167261: {"Unified_Ideograph", "Ideographic"},
    167262: {"Unified_Ideograph", "Ideographic"},
    167263: {"Unified_Ideograph", "Ideographic"},
    167264: {"Unified_Ideograph", "Ideographic"},
    167265: {"Unified_Ideograph", "Ideographic"},
    167266: {"Unified_Ideograph", "Ideographic"},
    167267: {"Unified_Ideograph", "Ideographic"},
    167268: {"Unified_Ideograph", "Ideographic"},
    167269: {"Unified_Ideograph", "Ideographic"},
    167270: {"Unified_Ideograph", "Ideographic"},
    167271: {"Unified_Ideograph", "Ideographic"},
    167272: {"Unified_Ideograph", "Ideographic"},
    167273: {"Unified_Ideograph", "Ideographic"},
    167274: {"Unified_Ideograph", "Ideographic"},
    167275: {"Unified_Ideograph", "Ideographic"},
    167276: {"Unified_Ideograph", "Ideographic"},
    167277: {"Unified_Ideograph", "Ideographic"},
    167278: {"Unified_Ideograph", "Ideographic"},
    167279: {"Unified_Ideograph", "Ideographic"},
    167280: {"Unified_Ideograph", "Ideographic"},
    167281: {"Unified_Ideograph", "Ideographic"},
    167282: {"Unified_Ideograph", "Ideographic"},
    167283: {"Unified_Ideograph", "Ideographic"},
    167284: {"Unified_Ideograph", "Ideographic"},
    167285: {"Unified_Ideograph", "Ideographic"},
    167286: {"Unified_Ideograph", "Ideographic"},
    167287: {"Unified_Ideograph", "Ideographic"},
    167288: {"Unified_Ideograph", "Ideographic"},
    167289: {"Unified_Ideograph", "Ideographic"},
    167290: {"Unified_Ideograph", "Ideographic"},
    167291: {"Unified_Ideograph", "Ideographic"},
    167292: {"Unified_Ideograph", "Ideographic"},
    167293: {"Unified_Ideograph", "Ideographic"},
    167294: {"Unified_Ideograph", "Ideographic"},
    167295: {"Unified_Ideograph", "Ideographic"},
    167296: {"Unified_Ideograph", "Ideographic"},
    167297: {"Unified_Ideograph", "Ideographic"},
    167298: {"Unified_Ideograph", "Ideographic"},
    167299: {"Unified_Ideograph", "Ideographic"},
    167300: {"Unified_Ideograph", "Ideographic"},
    167301: {"Unified_Ideograph", "Ideographic"},
    167302: {"Unified_Ideograph", "Ideographic"},
    167303: {"Unified_Ideograph", "Ideographic"},
    167304: {"Unified_Ideograph", "Ideographic"},
    167305: {"Unified_Ideograph", "Ideographic"},
    167306: {"Unified_Ideograph", "Ideographic"},
    167307: {"Unified_Ideograph", "Ideographic"},
    167308: {"Unified_Ideograph", "Ideographic"},
    167309: {"Unified_Ideograph", "Ideographic"},
    167310: {"Unified_Ideograph", "Ideographic"},
    167311: {"Unified_Ideograph", "Ideographic"},
    167312: {"Unified_Ideograph", "Ideographic"},
    167313: {"Unified_Ideograph", "Ideographic"},
    167314: {"Unified_Ideograph", "Ideographic"},
    167315: {"Unified_Ideograph", "Ideographic"},
    167316: {"Unified_Ideograph", "Ideographic"},
    167317: {"Unified_Ideograph", "Ideographic"},
    167318: {"Unified_Ideograph", "Ideographic"},
    167319: {"Unified_Ideograph", "Ideographic"},
    167320: {"Unified_Ideograph", "Ideographic"},
    167321: {"Unified_Ideograph", "Ideographic"},
    167322: {"Unified_Ideograph", "Ideographic"},
    167323: {"Unified_Ideograph", "Ideographic"},
    167324: {"Unified_Ideograph", "Ideographic"},
    167325: {"Unified_Ideograph", "Ideographic"},
    167326: {"Unified_Ideograph", "Ideographic"},
    167327: {"Unified_Ideograph", "Ideographic"},
    167328: {"Unified_Ideograph", "Ideographic"},
    167329: {"Unified_Ideograph", "Ideographic"},
    167330: {"Unified_Ideograph", "Ideographic"},
    167331: {"Unified_Ideograph", "Ideographic"},
    167332: {"Unified_Ideograph", "Ideographic"},
    167333: {"Unified_Ideograph", "Ideographic"},
    167334: {"Unified_Ideograph", "Ideographic"},
    167335: {"Unified_Ideograph", "Ideographic"},
    167336: {"Unified_Ideograph", "Ideographic"},
    167337: {"Unified_Ideograph", "Ideographic"},
    167338: {"Unified_Ideograph", "Ideographic"},
    167339: {"Unified_Ideograph", "Ideographic"},
    167340: {"Unified_Ideograph", "Ideographic"},
    167341: {"Unified_Ideograph", "Ideographic"},
    167342: {"Unified_Ideograph", "Ideographic"},
    167343: {"Unified_Ideograph", "Ideographic"},
    167344: {"Unified_Ideograph", "Ideographic"},
    167345: {"Unified_Ideograph", "Ideographic"},
    167346: {"Unified_Ideograph", "Ideographic"},
    167347: {"Unified_Ideograph", "Ideographic"},
    167348: {"Unified_Ideograph", "Ideographic"},
    167349: {"Unified_Ideograph", "Ideographic"},
    167350: {"Unified_Ideograph", "Ideographic"},
    167351: {"Unified_Ideograph", "Ideographic"},
    167352: {"Unified_Ideograph", "Ideographic"},
    167353: {"Unified_Ideograph", "Ideographic"},
    167354: {"Unified_Ideograph", "Ideographic"},
    167355: {"Unified_Ideograph", "Ideographic"},
    167356: {"Unified_Ideograph", "Ideographic"},
    167357: {"Unified_Ideograph", "Ideographic"},
    167358: {"Unified_Ideograph", "Ideographic"},
    167359: {"Unified_Ideograph", "Ideographic"},
    167360: {"Unified_Ideograph", "Ideographic"},
    167361: {"Unified_Ideograph", "Ideographic"},
    167362: {"Unified_Ideograph", "Ideographic"},
    167363: {"Unified_Ideograph", "Ideographic"},
    167364: {"Unified_Ideograph", "Ideographic"},
    167365: {"Unified_Ideograph", "Ideographic"},
    167366: {"Unified_Ideograph", "Ideographic"},
    167367: {"Unified_Ideograph", "Ideographic"},
    167368: {"Unified_Ideograph", "Ideographic"},
    167369: {"Unified_Ideograph", "Ideographic"},
    167370: {"Unified_Ideograph", "Ideographic"},
    167371: {"Unified_Ideograph", "Ideographic"},
    167372: {"Unified_Ideograph", "Ideographic"},
    167373: {"Unified_Ideograph", "Ideographic"},
    167374: {"Unified_Ideograph", "Ideographic"},
    167375: {"Unified_Ideograph", "Ideographic"},
    167376: {"Unified_Ideograph", "Ideographic"},
    167377: {"Unified_Ideograph", "Ideographic"},
    167378: {"Unified_Ideograph", "Ideographic"},
    167379: {"Unified_Ideograph", "Ideographic"},
    167380: {"Unified_Ideograph", "Ideographic"},
    167381: {"Unified_Ideograph", "Ideographic"},
    167382: {"Unified_Ideograph", "Ideographic"},
    167383: {"Unified_Ideograph", "Ideographic"},
    167384: {"Unified_Ideograph", "Ideographic"},
    167385: {"Unified_Ideograph", "Ideographic"},
    167386: {"Unified_Ideograph", "Ideographic"},
    167387: {"Unified_Ideograph", "Ideographic"},
    167388: {"Unified_Ideograph", "Ideographic"},
    167389: {"Unified_Ideograph", "Ideographic"},
    167390: {"Unified_Ideograph", "Ideographic"},
    167391: {"Unified_Ideograph", "Ideographic"},
    167392: {"Unified_Ideograph", "Ideographic"},
    167393: {"Unified_Ideograph", "Ideographic"},
    167394: {"Unified_Ideograph", "Ideographic"},
    167395: {"Unified_Ideograph", "Ideographic"},
    167396: {"Unified_Ideograph", "Ideographic"},
    167397: {"Unified_Ideograph", "Ideographic"},
    167398: {"Unified_Ideograph", "Ideographic"},
    167399: {"Unified_Ideograph", "Ideographic"},
    167400: {"Unified_Ideograph", "Ideographic"},
    167401: {"Unified_Ideograph", "Ideographic"},
    167402: {"Unified_Ideograph", "Ideographic"},
    167403: {"Unified_Ideograph", "Ideographic"},
    167404: {"Unified_Ideograph", "Ideographic"},
    167405: {"Unified_Ideograph", "Ideographic"},
    167406: {"Unified_Ideograph", "Ideographic"},
    167407: {"Unified_Ideograph", "Ideographic"},
    167408: {"Unified_Ideograph", "Ideographic"},
    167409: {"Unified_Ideograph", "Ideographic"},
    167410: {"Unified_Ideograph", "Ideographic"},
    167411: {"Unified_Ideograph", "Ideographic"},
    167412: {"Unified_Ideograph", "Ideographic"},
    167413: {"Unified_Ideograph", "Ideographic"},
    167414: {"Unified_Ideograph", "Ideographic"},
    167415: {"Unified_Ideograph", "Ideographic"},
    167416: {"Unified_Ideograph", "Ideographic"},
    167417: {"Unified_Ideograph", "Ideographic"},
    167418: {"Unified_Ideograph", "Ideographic"},
    167419: {"Unified_Ideograph", "Ideographic"},
    167420: {"Unified_Ideograph", "Ideographic"},
    167421: {"Unified_Ideograph", "Ideographic"},
    167422: {"Unified_Ideograph", "Ideographic"},
    167423: {"Unified_Ideograph", "Ideographic"},
    167424: {"Unified_Ideograph", "Ideographic"},
    167425: {"Unified_Ideograph", "Ideographic"},
    167426: {"Unified_Ideograph", "Ideographic"},
    167427: {"Unified_Ideograph", "Ideographic"},
    167428: {"Unified_Ideograph", "Ideographic"},
    167429: {"Unified_Ideograph", "Ideographic"},
    167430: {"Unified_Ideograph", "Ideographic"},
    167431: {"Unified_Ideograph", "Ideographic"},
    167432: {"Unified_Ideograph", "Ideographic"},
    167433: {"Unified_Ideograph", "Ideographic"},
    167434: {"Unified_Ideograph", "Ideographic"},
    167435: {"Unified_Ideograph", "Ideographic"},
    167436: {"Unified_Ideograph", "Ideographic"},
    167437: {"Unified_Ideograph", "Ideographic"},
    167438: {"Unified_Ideograph", "Ideographic"},
    167439: {"Unified_Ideograph", "Ideographic"},
    167440: {"Unified_Ideograph", "Ideographic"},
    167441: {"Unified_Ideograph", "Ideographic"},
    167442: {"Unified_Ideograph", "Ideographic"},
    167443: {"Unified_Ideograph", "Ideographic"},
    167444: {"Unified_Ideograph", "Ideographic"},
    167445: {"Unified_Ideograph", "Ideographic"},
    167446: {"Unified_Ideograph", "Ideographic"},
    167447: {"Unified_Ideograph", "Ideographic"},
    167448: {"Unified_Ideograph", "Ideographic"},
    167449: {"Unified_Ideograph", "Ideographic"},
    167450: {"Unified_Ideograph", "Ideographic"},
    167451: {"Unified_Ideograph", "Ideographic"},
    167452: {"Unified_Ideograph", "Ideographic"},
    167453: {"Unified_Ideograph", "Ideographic"},
    167454: {"Unified_Ideograph", "Ideographic"},
    167455: {"Unified_Ideograph", "Ideographic"},
    167456: {"Unified_Ideograph", "Ideographic"},
    167457: {"Unified_Ideograph", "Ideographic"},
    167458: {"Unified_Ideograph", "Ideographic"},
    167459: {"Unified_Ideograph", "Ideographic"},
    167460: {"Unified_Ideograph", "Ideographic"},
    167461: {"Unified_Ideograph", "Ideographic"},
    167462: {"Unified_Ideograph", "Ideographic"},
    167463: {"Unified_Ideograph", "Ideographic"},
    167464: {"Unified_Ideograph", "Ideographic"},
    167465: {"Unified_Ideograph", "Ideographic"},
    167466: {"Unified_Ideograph", "Ideographic"},
    167467: {"Unified_Ideograph", "Ideographic"},
    167468: {"Unified_Ideograph", "Ideographic"},
    167469: {"Unified_Ideograph", "Ideographic"},
    167470: {"Unified_Ideograph", "Ideographic"},
    167471: {"Unified_Ideograph", "Ideographic"},
    167472: {"Unified_Ideograph", "Ideographic"},
    167473: {"Unified_Ideograph", "Ideographic"},
    167474: {"Unified_Ideograph", "Ideographic"},
    167475: {"Unified_Ideograph", "Ideographic"},
    167476: {"Unified_Ideograph", "Ideographic"},
    167477: {"Unified_Ideograph", "Ideographic"},
    167478: {"Unified_Ideograph", "Ideographic"},
    167479: {"Unified_Ideograph", "Ideographic"},
    167480: {"Unified_Ideograph", "Ideographic"},
    167481: {"Unified_Ideograph", "Ideographic"},
    167482: {"Unified_Ideograph", "Ideographic"},
    167483: {"Unified_Ideograph", "Ideographic"},
    167484: {"Unified_Ideograph", "Ideographic"},
    167485: {"Unified_Ideograph", "Ideographic"},
    167486: {"Unified_Ideograph", "Ideographic"},
    167487: {"Unified_Ideograph", "Ideographic"},
    167488: {"Unified_Ideograph", "Ideographic"},
    167489: {"Unified_Ideograph", "Ideographic"},
    167490: {"Unified_Ideograph", "Ideographic"},
    167491: {"Unified_Ideograph", "Ideographic"},
    167492: {"Unified_Ideograph", "Ideographic"},
    167493: {"Unified_Ideograph", "Ideographic"},
    167494: {"Unified_Ideograph", "Ideographic"},
    167495: {"Unified_Ideograph", "Ideographic"},
    167496: {"Unified_Ideograph", "Ideographic"},
    167497: {"Unified_Ideograph", "Ideographic"},
    167498: {"Unified_Ideograph", "Ideographic"},
    167499: {"Unified_Ideograph", "Ideographic"},
    167500: {"Unified_Ideograph", "Ideographic"},
    167501: {"Unified_Ideograph", "Ideographic"},
    167502: {"Unified_Ideograph", "Ideographic"},
    167503: {"Unified_Ideograph", "Ideographic"},
    167504: {"Unified_Ideograph", "Ideographic"},
    167505: {"Unified_Ideograph", "Ideographic"},
    167506: {"Unified_Ideograph", "Ideographic"},
    167507: {"Unified_Ideograph", "Ideographic"},
    167508: {"Unified_Ideograph", "Ideographic"},
    167509: {"Unified_Ideograph", "Ideographic"},
    167510: {"Unified_Ideograph", "Ideographic"},
    167511: {"Unified_Ideograph", "Ideographic"},
    167512: {"Unified_Ideograph", "Ideographic"},
    167513: {"Unified_Ideograph", "Ideographic"},
    167514: {"Unified_Ideograph", "Ideographic"},
    167515: {"Unified_Ideograph", "Ideographic"},
    167516: {"Unified_Ideograph", "Ideographic"},
    167517: {"Unified_Ideograph", "Ideographic"},
    167518: {"Unified_Ideograph", "Ideographic"},
    167519: {"Unified_Ideograph", "Ideographic"},
    167520: {"Unified_Ideograph", "Ideographic"},
    167521: {"Unified_Ideograph", "Ideographic"},
    167522: {"Unified_Ideograph", "Ideographic"},
    167523: {"Unified_Ideograph", "Ideographic"},
    167524: {"Unified_Ideograph", "Ideographic"},
    167525: {"Unified_Ideograph", "Ideographic"},
    167526: {"Unified_Ideograph", "Ideographic"},
    167527: {"Unified_Ideograph", "Ideographic"},
    167528: {"Unified_Ideograph", "Ideographic"},
    167529: {"Unified_Ideograph", "Ideographic"},
    167530: {"Unified_Ideograph", "Ideographic"},
    167531: {"Unified_Ideograph", "Ideographic"},
    167532: {"Unified_Ideograph", "Ideographic"},
    167533: {"Unified_Ideograph", "Ideographic"},
    167534: {"Unified_Ideograph", "Ideographic"},
    167535: {"Unified_Ideograph", "Ideographic"},
    167536: {"Unified_Ideograph", "Ideographic"},
    167537: {"Unified_Ideograph", "Ideographic"},
    167538: {"Unified_Ideograph", "Ideographic"},
    167539: {"Unified_Ideograph", "Ideographic"},
    167540: {"Unified_Ideograph", "Ideographic"},
    167541: {"Unified_Ideograph", "Ideographic"},
    167542: {"Unified_Ideograph", "Ideographic"},
    167543: {"Unified_Ideograph", "Ideographic"},
    167544: {"Unified_Ideograph", "Ideographic"},
    167545: {"Unified_Ideograph", "Ideographic"},
    167546: {"Unified_Ideograph", "Ideographic"},
    167547: {"Unified_Ideograph", "Ideographic"},
    167548: {"Unified_Ideograph", "Ideographic"},
    167549: {"Unified_Ideograph", "Ideographic"},
    167550: {"Unified_Ideograph", "Ideographic"},
    167551: {"Unified_Ideograph", "Ideographic"},
    167552: {"Unified_Ideograph", "Ideographic"},
    167553: {"Unified_Ideograph", "Ideographic"},
    167554: {"Unified_Ideograph", "Ideographic"},
    167555: {"Unified_Ideograph", "Ideographic"},
    167556: {"Unified_Ideograph", "Ideographic"},
    167557: {"Unified_Ideograph", "Ideographic"},
    167558: {"Unified_Ideograph", "Ideographic"},
    167559: {"Unified_Ideograph", "Ideographic"},
    167560: {"Unified_Ideograph", "Ideographic"},
    167561: {"Unified_Ideograph", "Ideographic"},
    167562: {"Unified_Ideograph", "Ideographic"},
    167563: {"Unified_Ideograph", "Ideographic"},
    167564: {"Unified_Ideograph", "Ideographic"},
    167565: {"Unified_Ideograph", "Ideographic"},
    167566: {"Unified_Ideograph", "Ideographic"},
    167567: {"Unified_Ideograph", "Ideographic"},
    167568: {"Unified_Ideograph", "Ideographic"},
    167569: {"Unified_Ideograph", "Ideographic"},
    167570: {"Unified_Ideograph", "Ideographic"},
    167571: {"Unified_Ideograph", "Ideographic"},
    167572: {"Unified_Ideograph", "Ideographic"},
    167573: {"Unified_Ideograph", "Ideographic"},
    167574: {"Unified_Ideograph", "Ideographic"},
    167575: {"Unified_Ideograph", "Ideographic"},
    167576: {"Unified_Ideograph", "Ideographic"},
    167577: {"Unified_Ideograph", "Ideographic"},
    167578: {"Unified_Ideograph", "Ideographic"},
    167579: {"Unified_Ideograph", "Ideographic"},
    167580: {"Unified_Ideograph", "Ideographic"},
    167581: {"Unified_Ideograph", "Ideographic"},
    167582: {"Unified_Ideograph", "Ideographic"},
    167583: {"Unified_Ideograph", "Ideographic"},
    167584: {"Unified_Ideograph", "Ideographic"},
    167585: {"Unified_Ideograph", "Ideographic"},
    167586: {"Unified_Ideograph", "Ideographic"},
    167587: {"Unified_Ideograph", "Ideographic"},
    167588: {"Unified_Ideograph", "Ideographic"},
    167589: {"Unified_Ideograph", "Ideographic"},
    167590: {"Unified_Ideograph", "Ideographic"},
    167591: {"Unified_Ideograph", "Ideographic"},
    167592: {"Unified_Ideograph", "Ideographic"},
    167593: {"Unified_Ideograph", "Ideographic"},
    167594: {"Unified_Ideograph", "Ideographic"},
    167595: {"Unified_Ideograph", "Ideographic"},
    167596: {"Unified_Ideograph", "Ideographic"},
    167597: {"Unified_Ideograph", "Ideographic"},
    167598: {"Unified_Ideograph", "Ideographic"},
    167599: {"Unified_Ideograph", "Ideographic"},
    167600: {"Unified_Ideograph", "Ideographic"},
    167601: {"Unified_Ideograph", "Ideographic"},
    167602: {"Unified_Ideograph", "Ideographic"},
    167603: {"Unified_Ideograph", "Ideographic"},
    167604: {"Unified_Ideograph", "Ideographic"},
    167605: {"Unified_Ideograph", "Ideographic"},
    167606: {"Unified_Ideograph", "Ideographic"},
    167607: {"Unified_Ideograph", "Ideographic"},
    167608: {"Unified_Ideograph", "Ideographic"},
    167609: {"Unified_Ideograph", "Ideographic"},
    167610: {"Unified_Ideograph", "Ideographic"},
    167611: {"Unified_Ideograph", "Ideographic"},
    167612: {"Unified_Ideograph", "Ideographic"},
    167613: {"Unified_Ideograph", "Ideographic"},
    167614: {"Unified_Ideograph", "Ideographic"},
    167615: {"Unified_Ideograph", "Ideographic"},
    167616: {"Unified_Ideograph", "Ideographic"},
    167617: {"Unified_Ideograph", "Ideographic"},
    167618: {"Unified_Ideograph", "Ideographic"},
    167619: {"Unified_Ideograph", "Ideographic"},
    167620: {"Unified_Ideograph", "Ideographic"},
    167621: {"Unified_Ideograph", "Ideographic"},
    167622: {"Unified_Ideograph", "Ideographic"},
    167623: {"Unified_Ideograph", "Ideographic"},
    167624: {"Unified_Ideograph", "Ideographic"},
    167625: {"Unified_Ideograph", "Ideographic"},
    167626: {"Unified_Ideograph", "Ideographic"},
    167627: {"Unified_Ideograph", "Ideographic"},
    167628: {"Unified_Ideograph", "Ideographic"},
    167629: {"Unified_Ideograph", "Ideographic"},
    167630: {"Unified_Ideograph", "Ideographic"},
    167631: {"Unified_Ideograph", "Ideographic"},
    167632: {"Unified_Ideograph", "Ideographic"},
    167633: {"Unified_Ideograph", "Ideographic"},
    167634: {"Unified_Ideograph", "Ideographic"},
    167635: {"Unified_Ideograph", "Ideographic"},
    167636: {"Unified_Ideograph", "Ideographic"},
    167637: {"Unified_Ideograph", "Ideographic"},
    167638: {"Unified_Ideograph", "Ideographic"},
    167639: {"Unified_Ideograph", "Ideographic"},
    167640: {"Unified_Ideograph", "Ideographic"},
    167641: {"Unified_Ideograph", "Ideographic"},
    167642: {"Unified_Ideograph", "Ideographic"},
    167643: {"Unified_Ideograph", "Ideographic"},
    167644: {"Unified_Ideograph", "Ideographic"},
    167645: {"Unified_Ideograph", "Ideographic"},
    167646: {"Unified_Ideograph", "Ideographic"},
    167647: {"Unified_Ideograph", "Ideographic"},
    167648: {"Unified_Ideograph", "Ideographic"},
    167649: {"Unified_Ideograph", "Ideographic"},
    167650: {"Unified_Ideograph", "Ideographic"},
    167651: {"Unified_Ideograph", "Ideographic"},
    167652: {"Unified_Ideograph", "Ideographic"},
    167653: {"Unified_Ideograph", "Ideographic"},
    167654: {"Unified_Ideograph", "Ideographic"},
    167655: {"Unified_Ideograph", "Ideographic"},
    167656: {"Unified_Ideograph", "Ideographic"},
    167657: {"Unified_Ideograph", "Ideographic"},
    167658: {"Unified_Ideograph", "Ideographic"},
    167659: {"Unified_Ideograph", "Ideographic"},
    167660: {"Unified_Ideograph", "Ideographic"},
    167661: {"Unified_Ideograph", "Ideographic"},
    167662: {"Unified_Ideograph", "Ideographic"},
    167663: {"Unified_Ideograph", "Ideographic"},
    167664: {"Unified_Ideograph", "Ideographic"},
    167665: {"Unified_Ideograph", "Ideographic"},
    167666: {"Unified_Ideograph", "Ideographic"},
    167667: {"Unified_Ideograph", "Ideographic"},
    167668: {"Unified_Ideograph", "Ideographic"},
    167669: {"Unified_Ideograph", "Ideographic"},
    167670: {"Unified_Ideograph", "Ideographic"},
    167671: {"Unified_Ideograph", "Ideographic"},
    167672: {"Unified_Ideograph", "Ideographic"},
    167673: {"Unified_Ideograph", "Ideographic"},
    167674: {"Unified_Ideograph", "Ideographic"},
    167675: {"Unified_Ideograph", "Ideographic"},
    167676: {"Unified_Ideograph", "Ideographic"},
    167677: {"Unified_Ideograph", "Ideographic"},
    167678: {"Unified_Ideograph", "Ideographic"},
    167679: {"Unified_Ideograph", "Ideographic"},
    167680: {"Unified_Ideograph", "Ideographic"},
    167681: {"Unified_Ideograph", "Ideographic"},
    167682: {"Unified_Ideograph", "Ideographic"},
    167683: {"Unified_Ideograph", "Ideographic"},
    167684: {"Unified_Ideograph", "Ideographic"},
    167685: {"Unified_Ideograph", "Ideographic"},
    167686: {"Unified_Ideograph", "Ideographic"},
    167687: {"Unified_Ideograph", "Ideographic"},
    167688: {"Unified_Ideograph", "Ideographic"},
    167689: {"Unified_Ideograph", "Ideographic"},
    167690: {"Unified_Ideograph", "Ideographic"},
    167691: {"Unified_Ideograph", "Ideographic"},
    167692: {"Unified_Ideograph", "Ideographic"},
    167693: {"Unified_Ideograph", "Ideographic"},
    167694: {"Unified_Ideograph", "Ideographic"},
    167695: {"Unified_Ideograph", "Ideographic"},
    167696: {"Unified_Ideograph", "Ideographic"},
    167697: {"Unified_Ideograph", "Ideographic"},
    167698: {"Unified_Ideograph", "Ideographic"},
    167699: {"Unified_Ideograph", "Ideographic"},
    167700: {"Unified_Ideograph", "Ideographic"},
    167701: {"Unified_Ideograph", "Ideographic"},
    167702: {"Unified_Ideograph", "Ideographic"},
    167703: {"Unified_Ideograph", "Ideographic"},
    167704: {"Unified_Ideograph", "Ideographic"},
    167705: {"Unified_Ideograph", "Ideographic"},
    167706: {"Unified_Ideograph", "Ideographic"},
    167707: {"Unified_Ideograph", "Ideographic"},
    167708: {"Unified_Ideograph", "Ideographic"},
    167709: {"Unified_Ideograph", "Ideographic"},
    167710: {"Unified_Ideograph", "Ideographic"},
    167711: {"Unified_Ideograph", "Ideographic"},
    167712: {"Unified_Ideograph", "Ideographic"},
    167713: {"Unified_Ideograph", "Ideographic"},
    167714: {"Unified_Ideograph", "Ideographic"},
    167715: {"Unified_Ideograph", "Ideographic"},
    167716: {"Unified_Ideograph", "Ideographic"},
    167717: {"Unified_Ideograph", "Ideographic"},
    167718: {"Unified_Ideograph", "Ideographic"},
    167719: {"Unified_Ideograph", "Ideographic"},
    167720: {"Unified_Ideograph", "Ideographic"},
    167721: {"Unified_Ideograph", "Ideographic"},
    167722: {"Unified_Ideograph", "Ideographic"},
    167723: {"Unified_Ideograph", "Ideographic"},
    167724: {"Unified_Ideograph", "Ideographic"},
    167725: {"Unified_Ideograph", "Ideographic"},
    167726: {"Unified_Ideograph", "Ideographic"},
    167727: {"Unified_Ideograph", "Ideographic"},
    167728: {"Unified_Ideograph", "Ideographic"},
    167729: {"Unified_Ideograph", "Ideographic"},
    167730: {"Unified_Ideograph", "Ideographic"},
    167731: {"Unified_Ideograph", "Ideographic"},
    167732: {"Unified_Ideograph", "Ideographic"},
    167733: {"Unified_Ideograph", "Ideographic"},
    167734: {"Unified_Ideograph", "Ideographic"},
    167735: {"Unified_Ideograph", "Ideographic"},
    167736: {"Unified_Ideograph", "Ideographic"},
    167737: {"Unified_Ideograph", "Ideographic"},
    167738: {"Unified_Ideograph", "Ideographic"},
    167739: {"Unified_Ideograph", "Ideographic"},
    167740: {"Unified_Ideograph", "Ideographic"},
    167741: {"Unified_Ideograph", "Ideographic"},
    167742: {"Unified_Ideograph", "Ideographic"},
    167743: {"Unified_Ideograph", "Ideographic"},
    167744: {"Unified_Ideograph", "Ideographic"},
    167745: {"Unified_Ideograph", "Ideographic"},
    167746: {"Unified_Ideograph", "Ideographic"},
    167747: {"Unified_Ideograph", "Ideographic"},
    167748: {"Unified_Ideograph", "Ideographic"},
    167749: {"Unified_Ideograph", "Ideographic"},
    167750: {"Unified_Ideograph", "Ideographic"},
    167751: {"Unified_Ideograph", "Ideographic"},
    167752: {"Unified_Ideograph", "Ideographic"},
    167753: {"Unified_Ideograph", "Ideographic"},
    167754: {"Unified_Ideograph", "Ideographic"},
    167755: {"Unified_Ideograph", "Ideographic"},
    167756: {"Unified_Ideograph", "Ideographic"},
    167757: {"Unified_Ideograph", "Ideographic"},
    167758: {"Unified_Ideograph", "Ideographic"},
    167759: {"Unified_Ideograph", "Ideographic"},
    167760: {"Unified_Ideograph", "Ideographic"},
    167761: {"Unified_Ideograph", "Ideographic"},
    167762: {"Unified_Ideograph", "Ideographic"},
    167763: {"Unified_Ideograph", "Ideographic"},
    167764: {"Unified_Ideograph", "Ideographic"},
    167765: {"Unified_Ideograph", "Ideographic"},
    167766: {"Unified_Ideograph", "Ideographic"},
    167767: {"Unified_Ideograph", "Ideographic"},
    167768: {"Unified_Ideograph", "Ideographic"},
    167769: {"Unified_Ideograph", "Ideographic"},
    167770: {"Unified_Ideograph", "Ideographic"},
    167771: {"Unified_Ideograph", "Ideographic"},
    167772: {"Unified_Ideograph", "Ideographic"},
    167773: {"Unified_Ideograph", "Ideographic"},
    167774: {"Unified_Ideograph", "Ideographic"},
    167775: {"Unified_Ideograph", "Ideographic"},
    167776: {"Unified_Ideograph", "Ideographic"},
    167777: {"Unified_Ideograph", "Ideographic"},
    167778: {"Unified_Ideograph", "Ideographic"},
    167779: {"Unified_Ideograph", "Ideographic"},
    167780: {"Unified_Ideograph", "Ideographic"},
    167781: {"Unified_Ideograph", "Ideographic"},
    167782: {"Unified_Ideograph", "Ideographic"},
    167783: {"Unified_Ideograph", "Ideographic"},
    167784: {"Unified_Ideograph", "Ideographic"},
    167785: {"Unified_Ideograph", "Ideographic"},
    167786: {"Unified_Ideograph", "Ideographic"},
    167787: {"Unified_Ideograph", "Ideographic"},
    167788: {"Unified_Ideograph", "Ideographic"},
    167789: {"Unified_Ideograph", "Ideographic"},
    167790: {"Unified_Ideograph", "Ideographic"},
    167791: {"Unified_Ideograph", "Ideographic"},
    167792: {"Unified_Ideograph", "Ideographic"},
    167793: {"Unified_Ideograph", "Ideographic"},
    167794: {"Unified_Ideograph", "Ideographic"},
    167795: {"Unified_Ideograph", "Ideographic"},
    167796: {"Unified_Ideograph", "Ideographic"},
    167797: {"Unified_Ideograph", "Ideographic"},
    167798: {"Unified_Ideograph", "Ideographic"},
    167799: {"Unified_Ideograph", "Ideographic"},
    167800: {"Unified_Ideograph", "Ideographic"},
    167801: {"Unified_Ideograph", "Ideographic"},
    167802: {"Unified_Ideograph", "Ideographic"},
    167803: {"Unified_Ideograph", "Ideographic"},
    167804: {"Unified_Ideograph", "Ideographic"},
    167805: {"Unified_Ideograph", "Ideographic"},
    167806: {"Unified_Ideograph", "Ideographic"},
    167807: {"Unified_Ideograph", "Ideographic"},
    167808: {"Unified_Ideograph", "Ideographic"},
    167809: {"Unified_Ideograph", "Ideographic"},
    167810: {"Unified_Ideograph", "Ideographic"},
    167811: {"Unified_Ideograph", "Ideographic"},
    167812: {"Unified_Ideograph", "Ideographic"},
    167813: {"Unified_Ideograph", "Ideographic"},
    167814: {"Unified_Ideograph", "Ideographic"},
    167815: {"Unified_Ideograph", "Ideographic"},
    167816: {"Unified_Ideograph", "Ideographic"},
    167817: {"Unified_Ideograph", "Ideographic"},
    167818: {"Unified_Ideograph", "Ideographic"},
    167819: {"Unified_Ideograph", "Ideographic"},
    167820: {"Unified_Ideograph", "Ideographic"},
    167821: {"Unified_Ideograph", "Ideographic"},
    167822: {"Unified_Ideograph", "Ideographic"},
    167823: {"Unified_Ideograph", "Ideographic"},
    167824: {"Unified_Ideograph", "Ideographic"},
    167825: {"Unified_Ideograph", "Ideographic"},
    167826: {"Unified_Ideograph", "Ideographic"},
    167827: {"Unified_Ideograph", "Ideographic"},
    167828: {"Unified_Ideograph", "Ideographic"},
    167829: {"Unified_Ideograph", "Ideographic"},
    167830: {"Unified_Ideograph", "Ideographic"},
    167831: {"Unified_Ideograph", "Ideographic"},
    167832: {"Unified_Ideograph", "Ideographic"},
    167833: {"Unified_Ideograph", "Ideographic"},
    167834: {"Unified_Ideograph", "Ideographic"},
    167835: {"Unified_Ideograph", "Ideographic"},
    167836: {"Unified_Ideograph", "Ideographic"},
    167837: {"Unified_Ideograph", "Ideographic"},
    167838: {"Unified_Ideograph", "Ideographic"},
    167839: {"Unified_Ideograph", "Ideographic"},
    167840: {"Unified_Ideograph", "Ideographic"},
    167841: {"Unified_Ideograph", "Ideographic"},
    167842: {"Unified_Ideograph", "Ideographic"},
    167843: {"Unified_Ideograph", "Ideographic"},
    167844: {"Unified_Ideograph", "Ideographic"},
    167845: {"Unified_Ideograph", "Ideographic"},
    167846: {"Unified_Ideograph", "Ideographic"},
    167847: {"Unified_Ideograph", "Ideographic"},
    167848: {"Unified_Ideograph", "Ideographic"},
    167849: {"Unified_Ideograph", "Ideographic"},
    167850: {"Unified_Ideograph", "Ideographic"},
    167851: {"Unified_Ideograph", "Ideographic"},
    167852: {"Unified_Ideograph", "Ideographic"},
    167853: {"Unified_Ideograph", "Ideographic"},
    167854: {"Unified_Ideograph", "Ideographic"},
    167855: {"Unified_Ideograph", "Ideographic"},
    167856: {"Unified_Ideograph", "Ideographic"},
    167857: {"Unified_Ideograph", "Ideographic"},
    167858: {"Unified_Ideograph", "Ideographic"},
    167859: {"Unified_Ideograph", "Ideographic"},
    167860: {"Unified_Ideograph", "Ideographic"},
    167861: {"Unified_Ideograph", "Ideographic"},
    167862: {"Unified_Ideograph", "Ideographic"},
    167863: {"Unified_Ideograph", "Ideographic"},
    167864: {"Unified_Ideograph", "Ideographic"},
    167865: {"Unified_Ideograph", "Ideographic"},
    167866: {"Unified_Ideograph", "Ideographic"},
    167867: {"Unified_Ideograph", "Ideographic"},
    167868: {"Unified_Ideograph", "Ideographic"},
    167869: {"Unified_Ideograph", "Ideographic"},
    167870: {"Unified_Ideograph", "Ideographic"},
    167871: {"Unified_Ideograph", "Ideographic"},
    167872: {"Unified_Ideograph", "Ideographic"},
    167873: {"Unified_Ideograph", "Ideographic"},
    167874: {"Unified_Ideograph", "Ideographic"},
    167875: {"Unified_Ideograph", "Ideographic"},
    167876: {"Unified_Ideograph", "Ideographic"},
    167877: {"Unified_Ideograph", "Ideographic"},
    167878: {"Unified_Ideograph", "Ideographic"},
    167879: {"Unified_Ideograph", "Ideographic"},
    167880: {"Unified_Ideograph", "Ideographic"},
    167881: {"Unified_Ideograph", "Ideographic"},
    167882: {"Unified_Ideograph", "Ideographic"},
    167883: {"Unified_Ideograph", "Ideographic"},
    167884: {"Unified_Ideograph", "Ideographic"},
    167885: {"Unified_Ideograph", "Ideographic"},
    167886: {"Unified_Ideograph", "Ideographic"},
    167887: {"Unified_Ideograph", "Ideographic"},
    167888: {"Unified_Ideograph", "Ideographic"},
    167889: {"Unified_Ideograph", "Ideographic"},
    167890: {"Unified_Ideograph", "Ideographic"},
    167891: {"Unified_Ideograph", "Ideographic"},
    167892: {"Unified_Ideograph", "Ideographic"},
    167893: {"Unified_Ideograph", "Ideographic"},
    167894: {"Unified_Ideograph", "Ideographic"},
    167895: {"Unified_Ideograph", "Ideographic"},
    167896: {"Unified_Ideograph", "Ideographic"},
    167897: {"Unified_Ideograph", "Ideographic"},
    167898: {"Unified_Ideograph", "Ideographic"},
    167899: {"Unified_Ideograph", "Ideographic"},
    167900: {"Unified_Ideograph", "Ideographic"},
    167901: {"Unified_Ideograph", "Ideographic"},
    167902: {"Unified_Ideograph", "Ideographic"},
    167903: {"Unified_Ideograph", "Ideographic"},
    167904: {"Unified_Ideograph", "Ideographic"},
    167905: {"Unified_Ideograph", "Ideographic"},
    167906: {"Unified_Ideograph", "Ideographic"},
    167907: {"Unified_Ideograph", "Ideographic"},
    167908: {"Unified_Ideograph", "Ideographic"},
    167909: {"Unified_Ideograph", "Ideographic"},
    167910: {"Unified_Ideograph", "Ideographic"},
    167911: {"Unified_Ideograph", "Ideographic"},
    167912: {"Unified_Ideograph", "Ideographic"},
    167913: {"Unified_Ideograph", "Ideographic"},
    167914: {"Unified_Ideograph", "Ideographic"},
    167915: {"Unified_Ideograph", "Ideographic"},
    167916: {"Unified_Ideograph", "Ideographic"},
    167917: {"Unified_Ideograph", "Ideographic"},
    167918: {"Unified_Ideograph", "Ideographic"},
    167919: {"Unified_Ideograph", "Ideographic"},
    167920: {"Unified_Ideograph", "Ideographic"},
    167921: {"Unified_Ideograph", "Ideographic"},
    167922: {"Unified_Ideograph", "Ideographic"},
    167923: {"Unified_Ideograph", "Ideographic"},
    167924: {"Unified_Ideograph", "Ideographic"},
    167925: {"Unified_Ideograph", "Ideographic"},
    167926: {"Unified_Ideograph", "Ideographic"},
    167927: {"Unified_Ideograph", "Ideographic"},
    167928: {"Unified_Ideograph", "Ideographic"},
    167929: {"Unified_Ideograph", "Ideographic"},
    167930: {"Unified_Ideograph", "Ideographic"},
    167931: {"Unified_Ideograph", "Ideographic"},
    167932: {"Unified_Ideograph", "Ideographic"},
    167933: {"Unified_Ideograph", "Ideographic"},
    167934: {"Unified_Ideograph", "Ideographic"},
    167935: {"Unified_Ideograph", "Ideographic"},
    167936: {"Unified_Ideograph", "Ideographic"},
    167937: {"Unified_Ideograph", "Ideographic"},
    167938: {"Unified_Ideograph", "Ideographic"},
    167939: {"Unified_Ideograph", "Ideographic"},
    167940: {"Unified_Ideograph", "Ideographic"},
    167941: {"Unified_Ideograph", "Ideographic"},
    167942: {"Unified_Ideograph", "Ideographic"},
    167943: {"Unified_Ideograph", "Ideographic"},
    167944: {"Unified_Ideograph", "Ideographic"},
    167945: {"Unified_Ideograph", "Ideographic"},
    167946: {"Unified_Ideograph", "Ideographic"},
    167947: {"Unified_Ideograph", "Ideographic"},
    167948: {"Unified_Ideograph", "Ideographic"},
    167949: {"Unified_Ideograph", "Ideographic"},
    167950: {"Unified_Ideograph", "Ideographic"},
    167951: {"Unified_Ideograph", "Ideographic"},
    167952: {"Unified_Ideograph", "Ideographic"},
    167953: {"Unified_Ideograph", "Ideographic"},
    167954: {"Unified_Ideograph", "Ideographic"},
    167955: {"Unified_Ideograph", "Ideographic"},
    167956: {"Unified_Ideograph", "Ideographic"},
    167957: {"Unified_Ideograph", "Ideographic"},
    167958: {"Unified_Ideograph", "Ideographic"},
    167959: {"Unified_Ideograph", "Ideographic"},
    167960: {"Unified_Ideograph", "Ideographic"},
    167961: {"Unified_Ideograph", "Ideographic"},
    167962: {"Unified_Ideograph", "Ideographic"},
    167963: {"Unified_Ideograph", "Ideographic"},
    167964: {"Unified_Ideograph", "Ideographic"},
    167965: {"Unified_Ideograph", "Ideographic"},
    167966: {"Unified_Ideograph", "Ideographic"},
    167967: {"Unified_Ideograph", "Ideographic"},
    167968: {"Unified_Ideograph", "Ideographic"},
    167969: {"Unified_Ideograph", "Ideographic"},
    167970: {"Unified_Ideograph", "Ideographic"},
    167971: {"Unified_Ideograph", "Ideographic"},
    167972: {"Unified_Ideograph", "Ideographic"},
    167973: {"Unified_Ideograph", "Ideographic"},
    167974: {"Unified_Ideograph", "Ideographic"},
    167975: {"Unified_Ideograph", "Ideographic"},
    167976: {"Unified_Ideograph", "Ideographic"},
    167977: {"Unified_Ideograph", "Ideographic"},
    167978: {"Unified_Ideograph", "Ideographic"},
    167979: {"Unified_Ideograph", "Ideographic"},
    167980: {"Unified_Ideograph", "Ideographic"},
    167981: {"Unified_Ideograph", "Ideographic"},
    167982: {"Unified_Ideograph", "Ideographic"},
    167983: {"Unified_Ideograph", "Ideographic"},
    167984: {"Unified_Ideograph", "Ideographic"},
    167985: {"Unified_Ideograph", "Ideographic"},
    167986: {"Unified_Ideograph", "Ideographic"},
    167987: {"Unified_Ideograph", "Ideographic"},
    167988: {"Unified_Ideograph", "Ideographic"},
    167989: {"Unified_Ideograph", "Ideographic"},
    167990: {"Unified_Ideograph", "Ideographic"},
    167991: {"Unified_Ideograph", "Ideographic"},
    167992: {"Unified_Ideograph", "Ideographic"},
    167993: {"Unified_Ideograph", "Ideographic"},
    167994: {"Unified_Ideograph", "Ideographic"},
    167995: {"Unified_Ideograph", "Ideographic"},
    167996: {"Unified_Ideograph", "Ideographic"},
    167997: {"Unified_Ideograph", "Ideographic"},
    167998: {"Unified_Ideograph", "Ideographic"},
    167999: {"Unified_Ideograph", "Ideographic"},
    168000: {"Unified_Ideograph", "Ideographic"},
    168001: {"Unified_Ideograph", "Ideographic"},
    168002: {"Unified_Ideograph", "Ideographic"},
    168003: {"Unified_Ideograph", "Ideographic"},
    168004: {"Unified_Ideograph", "Ideographic"},
    168005: {"Unified_Ideograph", "Ideographic"},
    168006: {"Unified_Ideograph", "Ideographic"},
    168007: {"Unified_Ideograph", "Ideographic"},
    168008: {"Unified_Ideograph", "Ideographic"},
    168009: {"Unified_Ideograph", "Ideographic"},
    168010: {"Unified_Ideograph", "Ideographic"},
    168011: {"Unified_Ideograph", "Ideographic"},
    168012: {"Unified_Ideograph", "Ideographic"},
    168013: {"Unified_Ideograph", "Ideographic"},
    168014: {"Unified_Ideograph", "Ideographic"},
    168015: {"Unified_Ideograph", "Ideographic"},
    168016: {"Unified_Ideograph", "Ideographic"},
    168017: {"Unified_Ideograph", "Ideographic"},
    168018: {"Unified_Ideograph", "Ideographic"},
    168019: {"Unified_Ideograph", "Ideographic"},
    168020: {"Unified_Ideograph", "Ideographic"},
    168021: {"Unified_Ideograph", "Ideographic"},
    168022: {"Unified_Ideograph", "Ideographic"},
    168023: {"Unified_Ideograph", "Ideographic"},
    168024: {"Unified_Ideograph", "Ideographic"},
    168025: {"Unified_Ideograph", "Ideographic"},
    168026: {"Unified_Ideograph", "Ideographic"},
    168027: {"Unified_Ideograph", "Ideographic"},
    168028: {"Unified_Ideograph", "Ideographic"},
    168029: {"Unified_Ideograph", "Ideographic"},
    168030: {"Unified_Ideograph", "Ideographic"},
    168031: {"Unified_Ideograph", "Ideographic"},
    168032: {"Unified_Ideograph", "Ideographic"},
    168033: {"Unified_Ideograph", "Ideographic"},
    168034: {"Unified_Ideograph", "Ideographic"},
    168035: {"Unified_Ideograph", "Ideographic"},
    168036: {"Unified_Ideograph", "Ideographic"},
    168037: {"Unified_Ideograph", "Ideographic"},
    168038: {"Unified_Ideograph", "Ideographic"},
    168039: {"Unified_Ideograph", "Ideographic"},
    168040: {"Unified_Ideograph", "Ideographic"},
    168041: {"Unified_Ideograph", "Ideographic"},
    168042: {"Unified_Ideograph", "Ideographic"},
    168043: {"Unified_Ideograph", "Ideographic"},
    168044: {"Unified_Ideograph", "Ideographic"},
    168045: {"Unified_Ideograph", "Ideographic"},
    168046: {"Unified_Ideograph", "Ideographic"},
    168047: {"Unified_Ideograph", "Ideographic"},
    168048: {"Unified_Ideograph", "Ideographic"},
    168049: {"Unified_Ideograph", "Ideographic"},
    168050: {"Unified_Ideograph", "Ideographic"},
    168051: {"Unified_Ideograph", "Ideographic"},
    168052: {"Unified_Ideograph", "Ideographic"},
    168053: {"Unified_Ideograph", "Ideographic"},
    168054: {"Unified_Ideograph", "Ideographic"},
    168055: {"Unified_Ideograph", "Ideographic"},
    168056: {"Unified_Ideograph", "Ideographic"},
    168057: {"Unified_Ideograph", "Ideographic"},
    168058: {"Unified_Ideograph", "Ideographic"},
    168059: {"Unified_Ideograph", "Ideographic"},
    168060: {"Unified_Ideograph", "Ideographic"},
    168061: {"Unified_Ideograph", "Ideographic"},
    168062: {"Unified_Ideograph", "Ideographic"},
    168063: {"Unified_Ideograph", "Ideographic"},
    168064: {"Unified_Ideograph", "Ideographic"},
    168065: {"Unified_Ideograph", "Ideographic"},
    168066: {"Unified_Ideograph", "Ideographic"},
    168067: {"Unified_Ideograph", "Ideographic"},
    168068: {"Unified_Ideograph", "Ideographic"},
    168069: {"Unified_Ideograph", "Ideographic"},
    168070: {"Unified_Ideograph", "Ideographic"},
    168071: {"Unified_Ideograph", "Ideographic"},
    168072: {"Unified_Ideograph", "Ideographic"},
    168073: {"Unified_Ideograph", "Ideographic"},
    168074: {"Unified_Ideograph", "Ideographic"},
    168075: {"Unified_Ideograph", "Ideographic"},
    168076: {"Unified_Ideograph", "Ideographic"},
    168077: {"Unified_Ideograph", "Ideographic"},
    168078: {"Unified_Ideograph", "Ideographic"},
    168079: {"Unified_Ideograph", "Ideographic"},
    168080: {"Unified_Ideograph", "Ideographic"},
    168081: {"Unified_Ideograph", "Ideographic"},
    168082: {"Unified_Ideograph", "Ideographic"},
    168083: {"Unified_Ideograph", "Ideographic"},
    168084: {"Unified_Ideograph", "Ideographic"},
    168085: {"Unified_Ideograph", "Ideographic"},
    168086: {"Unified_Ideograph", "Ideographic"},
    168087: {"Unified_Ideograph", "Ideographic"},
    168088: {"Unified_Ideograph", "Ideographic"},
    168089: {"Unified_Ideograph", "Ideographic"},
    168090: {"Unified_Ideograph", "Ideographic"},
    168091: {"Unified_Ideograph", "Ideographic"},
    168092: {"Unified_Ideograph", "Ideographic"},
    168093: {"Unified_Ideograph", "Ideographic"},
    168094: {"Unified_Ideograph", "Ideographic"},
    168095: {"Unified_Ideograph", "Ideographic"},
    168096: {"Unified_Ideograph", "Ideographic"},
    168097: {"Unified_Ideograph", "Ideographic"},
    168098: {"Unified_Ideograph", "Ideographic"},
    168099: {"Unified_Ideograph", "Ideographic"},
    168100: {"Unified_Ideograph", "Ideographic"},
    168101: {"Unified_Ideograph", "Ideographic"},
    168102: {"Unified_Ideograph", "Ideographic"},
    168103: {"Unified_Ideograph", "Ideographic"},
    168104: {"Unified_Ideograph", "Ideographic"},
    168105: {"Unified_Ideograph", "Ideographic"},
    168106: {"Unified_Ideograph", "Ideographic"},
    168107: {"Unified_Ideograph", "Ideographic"},
    168108: {"Unified_Ideograph", "Ideographic"},
    168109: {"Unified_Ideograph", "Ideographic"},
    168110: {"Unified_Ideograph", "Ideographic"},
    168111: {"Unified_Ideograph", "Ideographic"},
    168112: {"Unified_Ideograph", "Ideographic"},
    168113: {"Unified_Ideograph", "Ideographic"},
    168114: {"Unified_Ideograph", "Ideographic"},
    168115: {"Unified_Ideograph", "Ideographic"},
    168116: {"Unified_Ideograph", "Ideographic"},
    168117: {"Unified_Ideograph", "Ideographic"},
    168118: {"Unified_Ideograph", "Ideographic"},
    168119: {"Unified_Ideograph", "Ideographic"},
    168120: {"Unified_Ideograph", "Ideographic"},
    168121: {"Unified_Ideograph", "Ideographic"},
    168122: {"Unified_Ideograph", "Ideographic"},
    168123: {"Unified_Ideograph", "Ideographic"},
    168124: {"Unified_Ideograph", "Ideographic"},
    168125: {"Unified_Ideograph", "Ideographic"},
    168126: {"Unified_Ideograph", "Ideographic"},
    168127: {"Unified_Ideograph", "Ideographic"},
    168128: {"Unified_Ideograph", "Ideographic"},
    168129: {"Unified_Ideograph", "Ideographic"},
    168130: {"Unified_Ideograph", "Ideographic"},
    168131: {"Unified_Ideograph", "Ideographic"},
    168132: {"Unified_Ideograph", "Ideographic"},
    168133: {"Unified_Ideograph", "Ideographic"},
    168134: {"Unified_Ideograph", "Ideographic"},
    168135: {"Unified_Ideograph", "Ideographic"},
    168136: {"Unified_Ideograph", "Ideographic"},
    168137: {"Unified_Ideograph", "Ideographic"},
    168138: {"Unified_Ideograph", "Ideographic"},
    168139: {"Unified_Ideograph", "Ideographic"},
    168140: {"Unified_Ideograph", "Ideographic"},
    168141: {"Unified_Ideograph", "Ideographic"},
    168142: {"Unified_Ideograph", "Ideographic"},
    168143: {"Unified_Ideograph", "Ideographic"},
    168144: {"Unified_Ideograph", "Ideographic"},
    168145: {"Unified_Ideograph", "Ideographic"},
    168146: {"Unified_Ideograph", "Ideographic"},
    168147: {"Unified_Ideograph", "Ideographic"},
    168148: {"Unified_Ideograph", "Ideographic"},
    168149: {"Unified_Ideograph", "Ideographic"},
    168150: {"Unified_Ideograph", "Ideographic"},
    168151: {"Unified_Ideograph", "Ideographic"},
    168152: {"Unified_Ideograph", "Ideographic"},
    168153: {"Unified_Ideograph", "Ideographic"},
    168154: {"Unified_Ideograph", "Ideographic"},
    168155: {"Unified_Ideograph", "Ideographic"},
    168156: {"Unified_Ideograph", "Ideographic"},
    168157: {"Unified_Ideograph", "Ideographic"},
    168158: {"Unified_Ideograph", "Ideographic"},
    168159: {"Unified_Ideograph", "Ideographic"},
    168160: {"Unified_Ideograph", "Ideographic"},
    168161: {"Unified_Ideograph", "Ideographic"},
    168162: {"Unified_Ideograph", "Ideographic"},
    168163: {"Unified_Ideograph", "Ideographic"},
    168164: {"Unified_Ideograph", "Ideographic"},
    168165: {"Unified_Ideograph", "Ideographic"},
    168166: {"Unified_Ideograph", "Ideographic"},
    168167: {"Unified_Ideograph", "Ideographic"},
    168168: {"Unified_Ideograph", "Ideographic"},
    168169: {"Unified_Ideograph", "Ideographic"},
    168170: {"Unified_Ideograph", "Ideographic"},
    168171: {"Unified_Ideograph", "Ideographic"},
    168172: {"Unified_Ideograph", "Ideographic"},
    168173: {"Unified_Ideograph", "Ideographic"},
    168174: {"Unified_Ideograph", "Ideographic"},
    168175: {"Unified_Ideograph", "Ideographic"},
    168176: {"Unified_Ideograph", "Ideographic"},
    168177: {"Unified_Ideograph", "Ideographic"},
    168178: {"Unified_Ideograph", "Ideographic"},
    168179: {"Unified_Ideograph", "Ideographic"},
    168180: {"Unified_Ideograph", "Ideographic"},
    168181: {"Unified_Ideograph", "Ideographic"},
    168182: {"Unified_Ideograph", "Ideographic"},
    168183: {"Unified_Ideograph", "Ideographic"},
    168184: {"Unified_Ideograph", "Ideographic"},
    168185: {"Unified_Ideograph", "Ideographic"},
    168186: {"Unified_Ideograph", "Ideographic"},
    168187: {"Unified_Ideograph", "Ideographic"},
    168188: {"Unified_Ideograph", "Ideographic"},
    168189: {"Unified_Ideograph", "Ideographic"},
    168190: {"Unified_Ideograph", "Ideographic"},
    168191: {"Unified_Ideograph", "Ideographic"},
    168192: {"Unified_Ideograph", "Ideographic"},
    168193: {"Unified_Ideograph", "Ideographic"},
    168194: {"Unified_Ideograph", "Ideographic"},
    168195: {"Unified_Ideograph", "Ideographic"},
    168196: {"Unified_Ideograph", "Ideographic"},
    168197: {"Unified_Ideograph", "Ideographic"},
    168198: {"Unified_Ideograph", "Ideographic"},
    168199: {"Unified_Ideograph", "Ideographic"},
    168200: {"Unified_Ideograph", "Ideographic"},
    168201: {"Unified_Ideograph", "Ideographic"},
    168202: {"Unified_Ideograph", "Ideographic"},
    168203: {"Unified_Ideograph", "Ideographic"},
    168204: {"Unified_Ideograph", "Ideographic"},
    168205: {"Unified_Ideograph", "Ideographic"},
    168206: {"Unified_Ideograph", "Ideographic"},
    168207: {"Unified_Ideograph", "Ideographic"},
    168208: {"Unified_Ideograph", "Ideographic"},
    168209: {"Unified_Ideograph", "Ideographic"},
    168210: {"Unified_Ideograph", "Ideographic"},
    168211: {"Unified_Ideograph", "Ideographic"},
    168212: {"Unified_Ideograph", "Ideographic"},
    168213: {"Unified_Ideograph", "Ideographic"},
    168214: {"Unified_Ideograph", "Ideographic"},
    168215: {"Unified_Ideograph", "Ideographic"},
    168216: {"Unified_Ideograph", "Ideographic"},
    168217: {"Unified_Ideograph", "Ideographic"},
    168218: {"Unified_Ideograph", "Ideographic"},
    168219: {"Unified_Ideograph", "Ideographic"},
    168220: {"Unified_Ideograph", "Ideographic"},
    168221: {"Unified_Ideograph", "Ideographic"},
    168222: {"Unified_Ideograph", "Ideographic"},
    168223: {"Unified_Ideograph", "Ideographic"},
    168224: {"Unified_Ideograph", "Ideographic"},
    168225: {"Unified_Ideograph", "Ideographic"},
    168226: {"Unified_Ideograph", "Ideographic"},
    168227: {"Unified_Ideograph", "Ideographic"},
    168228: {"Unified_Ideograph", "Ideographic"},
    168229: {"Unified_Ideograph", "Ideographic"},
    168230: {"Unified_Ideograph", "Ideographic"},
    168231: {"Unified_Ideograph", "Ideographic"},
    168232: {"Unified_Ideograph", "Ideographic"},
    168233: {"Unified_Ideograph", "Ideographic"},
    168234: {"Unified_Ideograph", "Ideographic"},
    168235: {"Unified_Ideograph", "Ideographic"},
    168236: {"Unified_Ideograph", "Ideographic"},
    168237: {"Unified_Ideograph", "Ideographic"},
    168238: {"Unified_Ideograph", "Ideographic"},
    168239: {"Unified_Ideograph", "Ideographic"},
    168240: {"Unified_Ideograph", "Ideographic"},
    168241: {"Unified_Ideograph", "Ideographic"},
    168242: {"Unified_Ideograph", "Ideographic"},
    168243: {"Unified_Ideograph", "Ideographic"},
    168244: {"Unified_Ideograph", "Ideographic"},
    168245: {"Unified_Ideograph", "Ideographic"},
    168246: {"Unified_Ideograph", "Ideographic"},
    168247: {"Unified_Ideograph", "Ideographic"},
    168248: {"Unified_Ideograph", "Ideographic"},
    168249: {"Unified_Ideograph", "Ideographic"},
    168250: {"Unified_Ideograph", "Ideographic"},
    168251: {"Unified_Ideograph", "Ideographic"},
    168252: {"Unified_Ideograph", "Ideographic"},
    168253: {"Unified_Ideograph", "Ideographic"},
    168254: {"Unified_Ideograph", "Ideographic"},
    168255: {"Unified_Ideograph", "Ideographic"},
    168256: {"Unified_Ideograph", "Ideographic"},
    168257: {"Unified_Ideograph", "Ideographic"},
    168258: {"Unified_Ideograph", "Ideographic"},
    168259: {"Unified_Ideograph", "Ideographic"},
    168260: {"Unified_Ideograph", "Ideographic"},
    168261: {"Unified_Ideograph", "Ideographic"},
    168262: {"Unified_Ideograph", "Ideographic"},
    168263: {"Unified_Ideograph", "Ideographic"},
    168264: {"Unified_Ideograph", "Ideographic"},
    168265: {"Unified_Ideograph", "Ideographic"},
    168266: {"Unified_Ideograph", "Ideographic"},
    168267: {"Unified_Ideograph", "Ideographic"},
    168268: {"Unified_Ideograph", "Ideographic"},
    168269: {"Unified_Ideograph", "Ideographic"},
    168270: {"Unified_Ideograph", "Ideographic"},
    168271: {"Unified_Ideograph", "Ideographic"},
    168272: {"Unified_Ideograph", "Ideographic"},
    168273: {"Unified_Ideograph", "Ideographic"},
    168274: {"Unified_Ideograph", "Ideographic"},
    168275: {"Unified_Ideograph", "Ideographic"},
    168276: {"Unified_Ideograph", "Ideographic"},
    168277: {"Unified_Ideograph", "Ideographic"},
    168278: {"Unified_Ideograph", "Ideographic"},
    168279: {"Unified_Ideograph", "Ideographic"},
    168280: {"Unified_Ideograph", "Ideographic"},
    168281: {"Unified_Ideograph", "Ideographic"},
    168282: {"Unified_Ideograph", "Ideographic"},
    168283: {"Unified_Ideograph", "Ideographic"},
    168284: {"Unified_Ideograph", "Ideographic"},
    168285: {"Unified_Ideograph", "Ideographic"},
    168286: {"Unified_Ideograph", "Ideographic"},
    168287: {"Unified_Ideograph", "Ideographic"},
    168288: {"Unified_Ideograph", "Ideographic"},
    168289: {"Unified_Ideograph", "Ideographic"},
    168290: {"Unified_Ideograph", "Ideographic"},
    168291: {"Unified_Ideograph", "Ideographic"},
    168292: {"Unified_Ideograph", "Ideographic"},
    168293: {"Unified_Ideograph", "Ideographic"},
    168294: {"Unified_Ideograph", "Ideographic"},
    168295: {"Unified_Ideograph", "Ideographic"},
    168296: {"Unified_Ideograph", "Ideographic"},
    168297: {"Unified_Ideograph", "Ideographic"},
    168298: {"Unified_Ideograph", "Ideographic"},
    168299: {"Unified_Ideograph", "Ideographic"},
    168300: {"Unified_Ideograph", "Ideographic"},
    168301: {"Unified_Ideograph", "Ideographic"},
    168302: {"Unified_Ideograph", "Ideographic"},
    168303: {"Unified_Ideograph", "Ideographic"},
    168304: {"Unified_Ideograph", "Ideographic"},
    168305: {"Unified_Ideograph", "Ideographic"},
    168306: {"Unified_Ideograph", "Ideographic"},
    168307: {"Unified_Ideograph", "Ideographic"},
    168308: {"Unified_Ideograph", "Ideographic"},
    168309: {"Unified_Ideograph", "Ideographic"},
    168310: {"Unified_Ideograph", "Ideographic"},
    168311: {"Unified_Ideograph", "Ideographic"},
    168312: {"Unified_Ideograph", "Ideographic"},
    168313: {"Unified_Ideograph", "Ideographic"},
    168314: {"Unified_Ideograph", "Ideographic"},
    168315: {"Unified_Ideograph", "Ideographic"},
    168316: {"Unified_Ideograph", "Ideographic"},
    168317: {"Unified_Ideograph", "Ideographic"},
    168318: {"Unified_Ideograph", "Ideographic"},
    168319: {"Unified_Ideograph", "Ideographic"},
    168320: {"Unified_Ideograph", "Ideographic"},
    168321: {"Unified_Ideograph", "Ideographic"},
    168322: {"Unified_Ideograph", "Ideographic"},
    168323: {"Unified_Ideograph", "Ideographic"},
    168324: {"Unified_Ideograph", "Ideographic"},
    168325: {"Unified_Ideograph", "Ideographic"},
    168326: {"Unified_Ideograph", "Ideographic"},
    168327: {"Unified_Ideograph", "Ideographic"},
    168328: {"Unified_Ideograph", "Ideographic"},
    168329: {"Unified_Ideograph", "Ideographic"},
    168330: {"Unified_Ideograph", "Ideographic"},
    168331: {"Unified_Ideograph", "Ideographic"},
    168332: {"Unified_Ideograph", "Ideographic"},
    168333: {"Unified_Ideograph", "Ideographic"},
    168334: {"Unified_Ideograph", "Ideographic"},
    168335: {"Unified_Ideograph", "Ideographic"},
    168336: {"Unified_Ideograph", "Ideographic"},
    168337: {"Unified_Ideograph", "Ideographic"},
    168338: {"Unified_Ideograph", "Ideographic"},
    168339: {"Unified_Ideograph", "Ideographic"},
    168340: {"Unified_Ideograph", "Ideographic"},
    168341: {"Unified_Ideograph", "Ideographic"},
    168342: {"Unified_Ideograph", "Ideographic"},
    168343: {"Unified_Ideograph", "Ideographic"},
    168344: {"Unified_Ideograph", "Ideographic"},
    168345: {"Unified_Ideograph", "Ideographic"},
    168346: {"Unified_Ideograph", "Ideographic"},
    168347: {"Unified_Ideograph", "Ideographic"},
    168348: {"Unified_Ideograph", "Ideographic"},
    168349: {"Unified_Ideograph", "Ideographic"},
    168350: {"Unified_Ideograph", "Ideographic"},
    168351: {"Unified_Ideograph", "Ideographic"},
    168352: {"Unified_Ideograph", "Ideographic"},
    168353: {"Unified_Ideograph", "Ideographic"},
    168354: {"Unified_Ideograph", "Ideographic"},
    168355: {"Unified_Ideograph", "Ideographic"},
    168356: {"Unified_Ideograph", "Ideographic"},
    168357: {"Unified_Ideograph", "Ideographic"},
    168358: {"Unified_Ideograph", "Ideographic"},
    168359: {"Unified_Ideograph", "Ideographic"},
    168360: {"Unified_Ideograph", "Ideographic"},
    168361: {"Unified_Ideograph", "Ideographic"},
    168362: {"Unified_Ideograph", "Ideographic"},
    168363: {"Unified_Ideograph", "Ideographic"},
    168364: {"Unified_Ideograph", "Ideographic"},
    168365: {"Unified_Ideograph", "Ideographic"},
    168366: {"Unified_Ideograph", "Ideographic"},
    168367: {"Unified_Ideograph", "Ideographic"},
    168368: {"Unified_Ideograph", "Ideographic"},
    168369: {"Unified_Ideograph", "Ideographic"},
    168370: {"Unified_Ideograph", "Ideographic"},
    168371: {"Unified_Ideograph", "Ideographic"},
    168372: {"Unified_Ideograph", "Ideographic"},
    168373: {"Unified_Ideograph", "Ideographic"},
    168374: {"Unified_Ideograph", "Ideographic"},
    168375: {"Unified_Ideograph", "Ideographic"},
    168376: {"Unified_Ideograph", "Ideographic"},
    168377: {"Unified_Ideograph", "Ideographic"},
    168378: {"Unified_Ideograph", "Ideographic"},
    168379: {"Unified_Ideograph", "Ideographic"},
    168380: {"Unified_Ideograph", "Ideographic"},
    168381: {"Unified_Ideograph", "Ideographic"},
    168382: {"Unified_Ideograph", "Ideographic"},
    168383: {"Unified_Ideograph", "Ideographic"},
    168384: {"Unified_Ideograph", "Ideographic"},
    168385: {"Unified_Ideograph", "Ideographic"},
    168386: {"Unified_Ideograph", "Ideographic"},
    168387: {"Unified_Ideograph", "Ideographic"},
    168388: {"Unified_Ideograph", "Ideographic"},
    168389: {"Unified_Ideograph", "Ideographic"},
    168390: {"Unified_Ideograph", "Ideographic"},
    168391: {"Unified_Ideograph", "Ideographic"},
    168392: {"Unified_Ideograph", "Ideographic"},
    168393: {"Unified_Ideograph", "Ideographic"},
    168394: {"Unified_Ideograph", "Ideographic"},
    168395: {"Unified_Ideograph", "Ideographic"},
    168396: {"Unified_Ideograph", "Ideographic"},
    168397: {"Unified_Ideograph", "Ideographic"},
    168398: {"Unified_Ideograph", "Ideographic"},
    168399: {"Unified_Ideograph", "Ideographic"},
    168400: {"Unified_Ideograph", "Ideographic"},
    168401: {"Unified_Ideograph", "Ideographic"},
    168402: {"Unified_Ideograph", "Ideographic"},
    168403: {"Unified_Ideograph", "Ideographic"},
    168404: {"Unified_Ideograph", "Ideographic"},
    168405: {"Unified_Ideograph", "Ideographic"},
    168406: {"Unified_Ideograph", "Ideographic"},
    168407: {"Unified_Ideograph", "Ideographic"},
    168408: {"Unified_Ideograph", "Ideographic"},
    168409: {"Unified_Ideograph", "Ideographic"},
    168410: {"Unified_Ideograph", "Ideographic"},
    168411: {"Unified_Ideograph", "Ideographic"},
    168412: {"Unified_Ideograph", "Ideographic"},
    168413: {"Unified_Ideograph", "Ideographic"},
    168414: {"Unified_Ideograph", "Ideographic"},
    168415: {"Unified_Ideograph", "Ideographic"},
    168416: {"Unified_Ideograph", "Ideographic"},
    168417: {"Unified_Ideograph", "Ideographic"},
    168418: {"Unified_Ideograph", "Ideographic"},
    168419: {"Unified_Ideograph", "Ideographic"},
    168420: {"Unified_Ideograph", "Ideographic"},
    168421: {"Unified_Ideograph", "Ideographic"},
    168422: {"Unified_Ideograph", "Ideographic"},
    168423: {"Unified_Ideograph", "Ideographic"},
    168424: {"Unified_Ideograph", "Ideographic"},
    168425: {"Unified_Ideograph", "Ideographic"},
    168426: {"Unified_Ideograph", "Ideographic"},
    168427: {"Unified_Ideograph", "Ideographic"},
    168428: {"Unified_Ideograph", "Ideographic"},
    168429: {"Unified_Ideograph", "Ideographic"},
    168430: {"Unified_Ideograph", "Ideographic"},
    168431: {"Unified_Ideograph", "Ideographic"},
    168432: {"Unified_Ideograph", "Ideographic"},
    168433: {"Unified_Ideograph", "Ideographic"},
    168434: {"Unified_Ideograph", "Ideographic"},
    168435: {"Unified_Ideograph", "Ideographic"},
    168436: {"Unified_Ideograph", "Ideographic"},
    168437: {"Unified_Ideograph", "Ideographic"},
    168438: {"Unified_Ideograph", "Ideographic"},
    168439: {"Unified_Ideograph", "Ideographic"},
    168440: {"Unified_Ideograph", "Ideographic"},
    168441: {"Unified_Ideograph", "Ideographic"},
    168442: {"Unified_Ideograph", "Ideographic"},
    168443: {"Unified_Ideograph", "Ideographic"},
    168444: {"Unified_Ideograph", "Ideographic"},
    168445: {"Unified_Ideograph", "Ideographic"},
    168446: {"Unified_Ideograph", "Ideographic"},
    168447: {"Unified_Ideograph", "Ideographic"},
    168448: {"Unified_Ideograph", "Ideographic"},
    168449: {"Unified_Ideograph", "Ideographic"},
    168450: {"Unified_Ideograph", "Ideographic"},
    168451: {"Unified_Ideograph", "Ideographic"},
    168452: {"Unified_Ideograph", "Ideographic"},
    168453: {"Unified_Ideograph", "Ideographic"},
    168454: {"Unified_Ideograph", "Ideographic"},
    168455: {"Unified_Ideograph", "Ideographic"},
    168456: {"Unified_Ideograph", "Ideographic"},
    168457: {"Unified_Ideograph", "Ideographic"},
    168458: {"Unified_Ideograph", "Ideographic"},
    168459: {"Unified_Ideograph", "Ideographic"},
    168460: {"Unified_Ideograph", "Ideographic"},
    168461: {"Unified_Ideograph", "Ideographic"},
    168462: {"Unified_Ideograph", "Ideographic"},
    168463: {"Unified_Ideograph", "Ideographic"},
    168464: {"Unified_Ideograph", "Ideographic"},
    168465: {"Unified_Ideograph", "Ideographic"},
    168466: {"Unified_Ideograph", "Ideographic"},
    168467: {"Unified_Ideograph", "Ideographic"},
    168468: {"Unified_Ideograph", "Ideographic"},
    168469: {"Unified_Ideograph", "Ideographic"},
    168470: {"Unified_Ideograph", "Ideographic"},
    168471: {"Unified_Ideograph", "Ideographic"},
    168472: {"Unified_Ideograph", "Ideographic"},
    168473: {"Unified_Ideograph", "Ideographic"},
    168474: {"Unified_Ideograph", "Ideographic"},
    168475: {"Unified_Ideograph", "Ideographic"},
    168476: {"Unified_Ideograph", "Ideographic"},
    168477: {"Unified_Ideograph", "Ideographic"},
    168478: {"Unified_Ideograph", "Ideographic"},
    168479: {"Unified_Ideograph", "Ideographic"},
    168480: {"Unified_Ideograph", "Ideographic"},
    168481: {"Unified_Ideograph", "Ideographic"},
    168482: {"Unified_Ideograph", "Ideographic"},
    168483: {"Unified_Ideograph", "Ideographic"},
    168484: {"Unified_Ideograph", "Ideographic"},
    168485: {"Unified_Ideograph", "Ideographic"},
    168486: {"Unified_Ideograph", "Ideographic"},
    168487: {"Unified_Ideograph", "Ideographic"},
    168488: {"Unified_Ideograph", "Ideographic"},
    168489: {"Unified_Ideograph", "Ideographic"},
    168490: {"Unified_Ideograph", "Ideographic"},
    168491: {"Unified_Ideograph", "Ideographic"},
    168492: {"Unified_Ideograph", "Ideographic"},
    168493: {"Unified_Ideograph", "Ideographic"},
    168494: {"Unified_Ideograph", "Ideographic"},
    168495: {"Unified_Ideograph", "Ideographic"},
    168496: {"Unified_Ideograph", "Ideographic"},
    168497: {"Unified_Ideograph", "Ideographic"},
    168498: {"Unified_Ideograph", "Ideographic"},
    168499: {"Unified_Ideograph", "Ideographic"},
    168500: {"Unified_Ideograph", "Ideographic"},
    168501: {"Unified_Ideograph", "Ideographic"},
    168502: {"Unified_Ideograph", "Ideographic"},
    168503: {"Unified_Ideograph", "Ideographic"},
    168504: {"Unified_Ideograph", "Ideographic"},
    168505: {"Unified_Ideograph", "Ideographic"},
    168506: {"Unified_Ideograph", "Ideographic"},
    168507: {"Unified_Ideograph", "Ideographic"},
    168508: {"Unified_Ideograph", "Ideographic"},
    168509: {"Unified_Ideograph", "Ideographic"},
    168510: {"Unified_Ideograph", "Ideographic"},
    168511: {"Unified_Ideograph", "Ideographic"},
    168512: {"Unified_Ideograph", "Ideographic"},
    168513: {"Unified_Ideograph", "Ideographic"},
    168514: {"Unified_Ideograph", "Ideographic"},
    168515: {"Unified_Ideograph", "Ideographic"},
    168516: {"Unified_Ideograph", "Ideographic"},
    168517: {"Unified_Ideograph", "Ideographic"},
    168518: {"Unified_Ideograph", "Ideographic"},
    168519: {"Unified_Ideograph", "Ideographic"},
    168520: {"Unified_Ideograph", "Ideographic"},
    168521: {"Unified_Ideograph", "Ideographic"},
    168522: {"Unified_Ideograph", "Ideographic"},
    168523: {"Unified_Ideograph", "Ideographic"},
    168524: {"Unified_Ideograph", "Ideographic"},
    168525: {"Unified_Ideograph", "Ideographic"},
    168526: {"Unified_Ideograph", "Ideographic"},
    168527: {"Unified_Ideograph", "Ideographic"},
    168528: {"Unified_Ideograph", "Ideographic"},
    168529: {"Unified_Ideograph", "Ideographic"},
    168530: {"Unified_Ideograph", "Ideographic"},
    168531: {"Unified_Ideograph", "Ideographic"},
    168532: {"Unified_Ideograph", "Ideographic"},
    168533: {"Unified_Ideograph", "Ideographic"},
    168534: {"Unified_Ideograph", "Ideographic"},
    168535: {"Unified_Ideograph", "Ideographic"},
    168536: {"Unified_Ideograph", "Ideographic"},
    168537: {"Unified_Ideograph", "Ideographic"},
    168538: {"Unified_Ideograph", "Ideographic"},
    168539: {"Unified_Ideograph", "Ideographic"},
    168540: {"Unified_Ideograph", "Ideographic"},
    168541: {"Unified_Ideograph", "Ideographic"},
    168542: {"Unified_Ideograph", "Ideographic"},
    168543: {"Unified_Ideograph", "Ideographic"},
    168544: {"Unified_Ideograph", "Ideographic"},
    168545: {"Unified_Ideograph", "Ideographic"},
    168546: {"Unified_Ideograph", "Ideographic"},
    168547: {"Unified_Ideograph", "Ideographic"},
    168548: {"Unified_Ideograph", "Ideographic"},
    168549: {"Unified_Ideograph", "Ideographic"},
    168550: {"Unified_Ideograph", "Ideographic"},
    168551: {"Unified_Ideograph", "Ideographic"},
    168552: {"Unified_Ideograph", "Ideographic"},
    168553: {"Unified_Ideograph", "Ideographic"},
    168554: {"Unified_Ideograph", "Ideographic"},
    168555: {"Unified_Ideograph", "Ideographic"},
    168556: {"Unified_Ideograph", "Ideographic"},
    168557: {"Unified_Ideograph", "Ideographic"},
    168558: {"Unified_Ideograph", "Ideographic"},
    168559: {"Unified_Ideograph", "Ideographic"},
    168560: {"Unified_Ideograph", "Ideographic"},
    168561: {"Unified_Ideograph", "Ideographic"},
    168562: {"Unified_Ideograph", "Ideographic"},
    168563: {"Unified_Ideograph", "Ideographic"},
    168564: {"Unified_Ideograph", "Ideographic"},
    168565: {"Unified_Ideograph", "Ideographic"},
    168566: {"Unified_Ideograph", "Ideographic"},
    168567: {"Unified_Ideograph", "Ideographic"},
    168568: {"Unified_Ideograph", "Ideographic"},
    168569: {"Unified_Ideograph", "Ideographic"},
    168570: {"Unified_Ideograph", "Ideographic"},
    168571: {"Unified_Ideograph", "Ideographic"},
    168572: {"Unified_Ideograph", "Ideographic"},
    168573: {"Unified_Ideograph", "Ideographic"},
    168574: {"Unified_Ideograph", "Ideographic"},
    168575: {"Unified_Ideograph", "Ideographic"},
    168576: {"Unified_Ideograph", "Ideographic"},
    168577: {"Unified_Ideograph", "Ideographic"},
    168578: {"Unified_Ideograph", "Ideographic"},
    168579: {"Unified_Ideograph", "Ideographic"},
    168580: {"Unified_Ideograph", "Ideographic"},
    168581: {"Unified_Ideograph", "Ideographic"},
    168582: {"Unified_Ideograph", "Ideographic"},
    168583: {"Unified_Ideograph", "Ideographic"},
    168584: {"Unified_Ideograph", "Ideographic"},
    168585: {"Unified_Ideograph", "Ideographic"},
    168586: {"Unified_Ideograph", "Ideographic"},
    168587: {"Unified_Ideograph", "Ideographic"},
    168588: {"Unified_Ideograph", "Ideographic"},
    168589: {"Unified_Ideograph", "Ideographic"},
    168590: {"Unified_Ideograph", "Ideographic"},
    168591: {"Unified_Ideograph", "Ideographic"},
    168592: {"Unified_Ideograph", "Ideographic"},
    168593: {"Unified_Ideograph", "Ideographic"},
    168594: {"Unified_Ideograph", "Ideographic"},
    168595: {"Unified_Ideograph", "Ideographic"},
    168596: {"Unified_Ideograph", "Ideographic"},
    168597: {"Unified_Ideograph", "Ideographic"},
    168598: {"Unified_Ideograph", "Ideographic"},
    168599: {"Unified_Ideograph", "Ideographic"},
    168600: {"Unified_Ideograph", "Ideographic"},
    168601: {"Unified_Ideograph", "Ideographic"},
    168602: {"Unified_Ideograph", "Ideographic"},
    168603: {"Unified_Ideograph", "Ideographic"},
    168604: {"Unified_Ideograph", "Ideographic"},
    168605: {"Unified_Ideograph", "Ideographic"},
    168606: {"Unified_Ideograph", "Ideographic"},
    168607: {"Unified_Ideograph", "Ideographic"},
    168608: {"Unified_Ideograph", "Ideographic"},
    168609: {"Unified_Ideograph", "Ideographic"},
    168610: {"Unified_Ideograph", "Ideographic"},
    168611: {"Unified_Ideograph", "Ideographic"},
    168612: {"Unified_Ideograph", "Ideographic"},
    168613: {"Unified_Ideograph", "Ideographic"},
    168614: {"Unified_Ideograph", "Ideographic"},
    168615: {"Unified_Ideograph", "Ideographic"},
    168616: {"Unified_Ideograph", "Ideographic"},
    168617: {"Unified_Ideograph", "Ideographic"},
    168618: {"Unified_Ideograph", "Ideographic"},
    168619: {"Unified_Ideograph", "Ideographic"},
    168620: {"Unified_Ideograph", "Ideographic"},
    168621: {"Unified_Ideograph", "Ideographic"},
    168622: {"Unified_Ideograph", "Ideographic"},
    168623: {"Unified_Ideograph", "Ideographic"},
    168624: {"Unified_Ideograph", "Ideographic"},
    168625: {"Unified_Ideograph", "Ideographic"},
    168626: {"Unified_Ideograph", "Ideographic"},
    168627: {"Unified_Ideograph", "Ideographic"},
    168628: {"Unified_Ideograph", "Ideographic"},
    168629: {"Unified_Ideograph", "Ideographic"},
    168630: {"Unified_Ideograph", "Ideographic"},
    168631: {"Unified_Ideograph", "Ideographic"},
    168632: {"Unified_Ideograph", "Ideographic"},
    168633: {"Unified_Ideograph", "Ideographic"},
    168634: {"Unified_Ideograph", "Ideographic"},
    168635: {"Unified_Ideograph", "Ideographic"},
    168636: {"Unified_Ideograph", "Ideographic"},
    168637: {"Unified_Ideograph", "Ideographic"},
    168638: {"Unified_Ideograph", "Ideographic"},
    168639: {"Unified_Ideograph", "Ideographic"},
    168640: {"Unified_Ideograph", "Ideographic"},
    168641: {"Unified_Ideograph", "Ideographic"},
    168642: {"Unified_Ideograph", "Ideographic"},
    168643: {"Unified_Ideograph", "Ideographic"},
    168644: {"Unified_Ideograph", "Ideographic"},
    168645: {"Unified_Ideograph", "Ideographic"},
    168646: {"Unified_Ideograph", "Ideographic"},
    168647: {"Unified_Ideograph", "Ideographic"},
    168648: {"Unified_Ideograph", "Ideographic"},
    168649: {"Unified_Ideograph", "Ideographic"},
    168650: {"Unified_Ideograph", "Ideographic"},
    168651: {"Unified_Ideograph", "Ideographic"},
    168652: {"Unified_Ideograph", "Ideographic"},
    168653: {"Unified_Ideograph", "Ideographic"},
    168654: {"Unified_Ideograph", "Ideographic"},
    168655: {"Unified_Ideograph", "Ideographic"},
    168656: {"Unified_Ideograph", "Ideographic"},
    168657: {"Unified_Ideograph", "Ideographic"},
    168658: {"Unified_Ideograph", "Ideographic"},
    168659: {"Unified_Ideograph", "Ideographic"},
    168660: {"Unified_Ideograph", "Ideographic"},
    168661: {"Unified_Ideograph", "Ideographic"},
    168662: {"Unified_Ideograph", "Ideographic"},
    168663: {"Unified_Ideograph", "Ideographic"},
    168664: {"Unified_Ideograph", "Ideographic"},
    168665: {"Unified_Ideograph", "Ideographic"},
    168666: {"Unified_Ideograph", "Ideographic"},
    168667: {"Unified_Ideograph", "Ideographic"},
    168668: {"Unified_Ideograph", "Ideographic"},
    168669: {"Unified_Ideograph", "Ideographic"},
    168670: {"Unified_Ideograph", "Ideographic"},
    168671: {"Unified_Ideograph", "Ideographic"},
    168672: {"Unified_Ideograph", "Ideographic"},
    168673: {"Unified_Ideograph", "Ideographic"},
    168674: {"Unified_Ideograph", "Ideographic"},
    168675: {"Unified_Ideograph", "Ideographic"},
    168676: {"Unified_Ideograph", "Ideographic"},
    168677: {"Unified_Ideograph", "Ideographic"},
    168678: {"Unified_Ideograph", "Ideographic"},
    168679: {"Unified_Ideograph", "Ideographic"},
    168680: {"Unified_Ideograph", "Ideographic"},
    168681: {"Unified_Ideograph", "Ideographic"},
    168682: {"Unified_Ideograph", "Ideographic"},
    168683: {"Unified_Ideograph", "Ideographic"},
    168684: {"Unified_Ideograph", "Ideographic"},
    168685: {"Unified_Ideograph", "Ideographic"},
    168686: {"Unified_Ideograph", "Ideographic"},
    168687: {"Unified_Ideograph", "Ideographic"},
    168688: {"Unified_Ideograph", "Ideographic"},
    168689: {"Unified_Ideograph", "Ideographic"},
    168690: {"Unified_Ideograph", "Ideographic"},
    168691: {"Unified_Ideograph", "Ideographic"},
    168692: {"Unified_Ideograph", "Ideographic"},
    168693: {"Unified_Ideograph", "Ideographic"},
    168694: {"Unified_Ideograph", "Ideographic"},
    168695: {"Unified_Ideograph", "Ideographic"},
    168696: {"Unified_Ideograph", "Ideographic"},
    168697: {"Unified_Ideograph", "Ideographic"},
    168698: {"Unified_Ideograph", "Ideographic"},
    168699: {"Unified_Ideograph", "Ideographic"},
    168700: {"Unified_Ideograph", "Ideographic"},
    168701: {"Unified_Ideograph", "Ideographic"},
    168702: {"Unified_Ideograph", "Ideographic"},
    168703: {"Unified_Ideograph", "Ideographic"},
    168704: {"Unified_Ideograph", "Ideographic"},
    168705: {"Unified_Ideograph", "Ideographic"},
    168706: {"Unified_Ideograph", "Ideographic"},
    168707: {"Unified_Ideograph", "Ideographic"},
    168708: {"Unified_Ideograph", "Ideographic"},
    168709: {"Unified_Ideograph", "Ideographic"},
    168710: {"Unified_Ideograph", "Ideographic"},
    168711: {"Unified_Ideograph", "Ideographic"},
    168712: {"Unified_Ideograph", "Ideographic"},
    168713: {"Unified_Ideograph", "Ideographic"},
    168714: {"Unified_Ideograph", "Ideographic"},
    168715: {"Unified_Ideograph", "Ideographic"},
    168716: {"Unified_Ideograph", "Ideographic"},
    168717: {"Unified_Ideograph", "Ideographic"},
    168718: {"Unified_Ideograph", "Ideographic"},
    168719: {"Unified_Ideograph", "Ideographic"},
    168720: {"Unified_Ideograph", "Ideographic"},
    168721: {"Unified_Ideograph", "Ideographic"},
    168722: {"Unified_Ideograph", "Ideographic"},
    168723: {"Unified_Ideograph", "Ideographic"},
    168724: {"Unified_Ideograph", "Ideographic"},
    168725: {"Unified_Ideograph", "Ideographic"},
    168726: {"Unified_Ideograph", "Ideographic"},
    168727: {"Unified_Ideograph", "Ideographic"},
    168728: {"Unified_Ideograph", "Ideographic"},
    168729: {"Unified_Ideograph", "Ideographic"},
    168730: {"Unified_Ideograph", "Ideographic"},
    168731: {"Unified_Ideograph", "Ideographic"},
    168732: {"Unified_Ideograph", "Ideographic"},
    168733: {"Unified_Ideograph", "Ideographic"},
    168734: {"Unified_Ideograph", "Ideographic"},
    168735: {"Unified_Ideograph", "Ideographic"},
    168736: {"Unified_Ideograph", "Ideographic"},
    168737: {"Unified_Ideograph", "Ideographic"},
    168738: {"Unified_Ideograph", "Ideographic"},
    168739: {"Unified_Ideograph", "Ideographic"},
    168740: {"Unified_Ideograph", "Ideographic"},
    168741: {"Unified_Ideograph", "Ideographic"},
    168742: {"Unified_Ideograph", "Ideographic"},
    168743: {"Unified_Ideograph", "Ideographic"},
    168744: {"Unified_Ideograph", "Ideographic"},
    168745: {"Unified_Ideograph", "Ideographic"},
    168746: {"Unified_Ideograph", "Ideographic"},
    168747: {"Unified_Ideograph", "Ideographic"},
    168748: {"Unified_Ideograph", "Ideographic"},
    168749: {"Unified_Ideograph", "Ideographic"},
    168750: {"Unified_Ideograph", "Ideographic"},
    168751: {"Unified_Ideograph", "Ideographic"},
    168752: {"Unified_Ideograph", "Ideographic"},
    168753: {"Unified_Ideograph", "Ideographic"},
    168754: {"Unified_Ideograph", "Ideographic"},
    168755: {"Unified_Ideograph", "Ideographic"},
    168756: {"Unified_Ideograph", "Ideographic"},
    168757: {"Unified_Ideograph", "Ideographic"},
    168758: {"Unified_Ideograph", "Ideographic"},
    168759: {"Unified_Ideograph", "Ideographic"},
    168760: {"Unified_Ideograph", "Ideographic"},
    168761: {"Unified_Ideograph", "Ideographic"},
    168762: {"Unified_Ideograph", "Ideographic"},
    168763: {"Unified_Ideograph", "Ideographic"},
    168764: {"Unified_Ideograph", "Ideographic"},
    168765: {"Unified_Ideograph", "Ideographic"},
    168766: {"Unified_Ideograph", "Ideographic"},
    168767: {"Unified_Ideograph", "Ideographic"},
    168768: {"Unified_Ideograph", "Ideographic"},
    168769: {"Unified_Ideograph", "Ideographic"},
    168770: {"Unified_Ideograph", "Ideographic"},
    168771: {"Unified_Ideograph", "Ideographic"},
    168772: {"Unified_Ideograph", "Ideographic"},
    168773: {"Unified_Ideograph", "Ideographic"},
    168774: {"Unified_Ideograph", "Ideographic"},
    168775: {"Unified_Ideograph", "Ideographic"},
    168776: {"Unified_Ideograph", "Ideographic"},
    168777: {"Unified_Ideograph", "Ideographic"},
    168778: {"Unified_Ideograph", "Ideographic"},
    168779: {"Unified_Ideograph", "Ideographic"},
    168780: {"Unified_Ideograph", "Ideographic"},
    168781: {"Unified_Ideograph", "Ideographic"},
    168782: {"Unified_Ideograph", "Ideographic"},
    168783: {"Unified_Ideograph", "Ideographic"},
    168784: {"Unified_Ideograph", "Ideographic"},
    168785: {"Unified_Ideograph", "Ideographic"},
    168786: {"Unified_Ideograph", "Ideographic"},
    168787: {"Unified_Ideograph", "Ideographic"},
    168788: {"Unified_Ideograph", "Ideographic"},
    168789: {"Unified_Ideograph", "Ideographic"},
    168790: {"Unified_Ideograph", "Ideographic"},
    168791: {"Unified_Ideograph", "Ideographic"},
    168792: {"Unified_Ideograph", "Ideographic"},
    168793: {"Unified_Ideograph", "Ideographic"},
    168794: {"Unified_Ideograph", "Ideographic"},
    168795: {"Unified_Ideograph", "Ideographic"},
    168796: {"Unified_Ideograph", "Ideographic"},
    168797: {"Unified_Ideograph", "Ideographic"},
    168798: {"Unified_Ideograph", "Ideographic"},
    168799: {"Unified_Ideograph", "Ideographic"},
    168800: {"Unified_Ideograph", "Ideographic"},
    168801: {"Unified_Ideograph", "Ideographic"},
    168802: {"Unified_Ideograph", "Ideographic"},
    168803: {"Unified_Ideograph", "Ideographic"},
    168804: {"Unified_Ideograph", "Ideographic"},
    168805: {"Unified_Ideograph", "Ideographic"},
    168806: {"Unified_Ideograph", "Ideographic"},
    168807: {"Unified_Ideograph", "Ideographic"},
    168808: {"Unified_Ideograph", "Ideographic"},
    168809: {"Unified_Ideograph", "Ideographic"},
    168810: {"Unified_Ideograph", "Ideographic"},
    168811: {"Unified_Ideograph", "Ideographic"},
    168812: {"Unified_Ideograph", "Ideographic"},
    168813: {"Unified_Ideograph", "Ideographic"},
    168814: {"Unified_Ideograph", "Ideographic"},
    168815: {"Unified_Ideograph", "Ideographic"},
    168816: {"Unified_Ideograph", "Ideographic"},
    168817: {"Unified_Ideograph", "Ideographic"},
    168818: {"Unified_Ideograph", "Ideographic"},
    168819: {"Unified_Ideograph", "Ideographic"},
    168820: {"Unified_Ideograph", "Ideographic"},
    168821: {"Unified_Ideograph", "Ideographic"},
    168822: {"Unified_Ideograph", "Ideographic"},
    168823: {"Unified_Ideograph", "Ideographic"},
    168824: {"Unified_Ideograph", "Ideographic"},
    168825: {"Unified_Ideograph", "Ideographic"},
    168826: {"Unified_Ideograph", "Ideographic"},
    168827: {"Unified_Ideograph", "Ideographic"},
    168828: {"Unified_Ideograph", "Ideographic"},
    168829: {"Unified_Ideograph", "Ideographic"},
    168830: {"Unified_Ideograph", "Ideographic"},
    168831: {"Unified_Ideograph", "Ideographic"},
    168832: {"Unified_Ideograph", "Ideographic"},
    168833: {"Unified_Ideograph", "Ideographic"},
    168834: {"Unified_Ideograph", "Ideographic"},
    168835: {"Unified_Ideograph", "Ideographic"},
    168836: {"Unified_Ideograph", "Ideographic"},
    168837: {"Unified_Ideograph", "Ideographic"},
    168838: {"Unified_Ideograph", "Ideographic"},
    168839: {"Unified_Ideograph", "Ideographic"},
    168840: {"Unified_Ideograph", "Ideographic"},
    168841: {"Unified_Ideograph", "Ideographic"},
    168842: {"Unified_Ideograph", "Ideographic"},
    168843: {"Unified_Ideograph", "Ideographic"},
    168844: {"Unified_Ideograph", "Ideographic"},
    168845: {"Unified_Ideograph", "Ideographic"},
    168846: {"Unified_Ideograph", "Ideographic"},
    168847: {"Unified_Ideograph", "Ideographic"},
    168848: {"Unified_Ideograph", "Ideographic"},
    168849: {"Unified_Ideograph", "Ideographic"},
    168850: {"Unified_Ideograph", "Ideographic"},
    168851: {"Unified_Ideograph", "Ideographic"},
    168852: {"Unified_Ideograph", "Ideographic"},
    168853: {"Unified_Ideograph", "Ideographic"},
    168854: {"Unified_Ideograph", "Ideographic"},
    168855: {"Unified_Ideograph", "Ideographic"},
    168856: {"Unified_Ideograph", "Ideographic"},
    168857: {"Unified_Ideograph", "Ideographic"},
    168858: {"Unified_Ideograph", "Ideographic"},
    168859: {"Unified_Ideograph", "Ideographic"},
    168860: {"Unified_Ideograph", "Ideographic"},
    168861: {"Unified_Ideograph", "Ideographic"},
    168862: {"Unified_Ideograph", "Ideographic"},
    168863: {"Unified_Ideograph", "Ideographic"},
    168864: {"Unified_Ideograph", "Ideographic"},
    168865: {"Unified_Ideograph", "Ideographic"},
    168866: {"Unified_Ideograph", "Ideographic"},
    168867: {"Unified_Ideograph", "Ideographic"},
    168868: {"Unified_Ideograph", "Ideographic"},
    168869: {"Unified_Ideograph", "Ideographic"},
    168870: {"Unified_Ideograph", "Ideographic"},
    168871: {"Unified_Ideograph", "Ideographic"},
    168872: {"Unified_Ideograph", "Ideographic"},
    168873: {"Unified_Ideograph", "Ideographic"},
    168874: {"Unified_Ideograph", "Ideographic"},
    168875: {"Unified_Ideograph", "Ideographic"},
    168876: {"Unified_Ideograph", "Ideographic"},
    168877: {"Unified_Ideograph", "Ideographic"},
    168878: {"Unified_Ideograph", "Ideographic"},
    168879: {"Unified_Ideograph", "Ideographic"},
    168880: {"Unified_Ideograph", "Ideographic"},
    168881: {"Unified_Ideograph", "Ideographic"},
    168882: {"Unified_Ideograph", "Ideographic"},
    168883: {"Unified_Ideograph", "Ideographic"},
    168884: {"Unified_Ideograph", "Ideographic"},
    168885: {"Unified_Ideograph", "Ideographic"},
    168886: {"Unified_Ideograph", "Ideographic"},
    168887: {"Unified_Ideograph", "Ideographic"},
    168888: {"Unified_Ideograph", "Ideographic"},
    168889: {"Unified_Ideograph", "Ideographic"},
    168890: {"Unified_Ideograph", "Ideographic"},
    168891: {"Unified_Ideograph", "Ideographic"},
    168892: {"Unified_Ideograph", "Ideographic"},
    168893: {"Unified_Ideograph", "Ideographic"},
    168894: {"Unified_Ideograph", "Ideographic"},
    168895: {"Unified_Ideograph", "Ideographic"},
    168896: {"Unified_Ideograph", "Ideographic"},
    168897: {"Unified_Ideograph", "Ideographic"},
    168898: {"Unified_Ideograph", "Ideographic"},
    168899: {"Unified_Ideograph", "Ideographic"},
    168900: {"Unified_Ideograph", "Ideographic"},
    168901: {"Unified_Ideograph", "Ideographic"},
    168902: {"Unified_Ideograph", "Ideographic"},
    168903: {"Unified_Ideograph", "Ideographic"},
    168904: {"Unified_Ideograph", "Ideographic"},
    168905: {"Unified_Ideograph", "Ideographic"},
    168906: {"Unified_Ideograph", "Ideographic"},
    168907: {"Unified_Ideograph", "Ideographic"},
    168908: {"Unified_Ideograph", "Ideographic"},
    168909: {"Unified_Ideograph", "Ideographic"},
    168910: {"Unified_Ideograph", "Ideographic"},
    168911: {"Unified_Ideograph", "Ideographic"},
    168912: {"Unified_Ideograph", "Ideographic"},
    168913: {"Unified_Ideograph", "Ideographic"},
    168914: {"Unified_Ideograph", "Ideographic"},
    168915: {"Unified_Ideograph", "Ideographic"},
    168916: {"Unified_Ideograph", "Ideographic"},
    168917: {"Unified_Ideograph", "Ideographic"},
    168918: {"Unified_Ideograph", "Ideographic"},
    168919: {"Unified_Ideograph", "Ideographic"},
    168920: {"Unified_Ideograph", "Ideographic"},
    168921: {"Unified_Ideograph", "Ideographic"},
    168922: {"Unified_Ideograph", "Ideographic"},
    168923: {"Unified_Ideograph", "Ideographic"},
    168924: {"Unified_Ideograph", "Ideographic"},
    168925: {"Unified_Ideograph", "Ideographic"},
    168926: {"Unified_Ideograph", "Ideographic"},
    168927: {"Unified_Ideograph", "Ideographic"},
    168928: {"Unified_Ideograph", "Ideographic"},
    168929: {"Unified_Ideograph", "Ideographic"},
    168930: {"Unified_Ideograph", "Ideographic"},
    168931: {"Unified_Ideograph", "Ideographic"},
    168932: {"Unified_Ideograph", "Ideographic"},
    168933: {"Unified_Ideograph", "Ideographic"},
    168934: {"Unified_Ideograph", "Ideographic"},
    168935: {"Unified_Ideograph", "Ideographic"},
    168936: {"Unified_Ideograph", "Ideographic"},
    168937: {"Unified_Ideograph", "Ideographic"},
    168938: {"Unified_Ideograph", "Ideographic"},
    168939: {"Unified_Ideograph", "Ideographic"},
    168940: {"Unified_Ideograph", "Ideographic"},
    168941: {"Unified_Ideograph", "Ideographic"},
    168942: {"Unified_Ideograph", "Ideographic"},
    168943: {"Unified_Ideograph", "Ideographic"},
    168944: {"Unified_Ideograph", "Ideographic"},
    168945: {"Unified_Ideograph", "Ideographic"},
    168946: {"Unified_Ideograph", "Ideographic"},
    168947: {"Unified_Ideograph", "Ideographic"},
    168948: {"Unified_Ideograph", "Ideographic"},
    168949: {"Unified_Ideograph", "Ideographic"},
    168950: {"Unified_Ideograph", "Ideographic"},
    168951: {"Unified_Ideograph", "Ideographic"},
    168952: {"Unified_Ideograph", "Ideographic"},
    168953: {"Unified_Ideograph", "Ideographic"},
    168954: {"Unified_Ideograph", "Ideographic"},
    168955: {"Unified_Ideograph", "Ideographic"},
    168956: {"Unified_Ideograph", "Ideographic"},
    168957: {"Unified_Ideograph", "Ideographic"},
    168958: {"Unified_Ideograph", "Ideographic"},
    168959: {"Unified_Ideograph", "Ideographic"},
    168960: {"Unified_Ideograph", "Ideographic"},
    168961: {"Unified_Ideograph", "Ideographic"},
    168962: {"Unified_Ideograph", "Ideographic"},
    168963: {"Unified_Ideograph", "Ideographic"},
    168964: {"Unified_Ideograph", "Ideographic"},
    168965: {"Unified_Ideograph", "Ideographic"},
    168966: {"Unified_Ideograph", "Ideographic"},
    168967: {"Unified_Ideograph", "Ideographic"},
    168968: {"Unified_Ideograph", "Ideographic"},
    168969: {"Unified_Ideograph", "Ideographic"},
    168970: {"Unified_Ideograph", "Ideographic"},
    168971: {"Unified_Ideograph", "Ideographic"},
    168972: {"Unified_Ideograph", "Ideographic"},
    168973: {"Unified_Ideograph", "Ideographic"},
    168974: {"Unified_Ideograph", "Ideographic"},
    168975: {"Unified_Ideograph", "Ideographic"},
    168976: {"Unified_Ideograph", "Ideographic"},
    168977: {"Unified_Ideograph", "Ideographic"},
    168978: {"Unified_Ideograph", "Ideographic"},
    168979: {"Unified_Ideograph", "Ideographic"},
    168980: {"Unified_Ideograph", "Ideographic"},
    168981: {"Unified_Ideograph", "Ideographic"},
    168982: {"Unified_Ideograph", "Ideographic"},
    168983: {"Unified_Ideograph", "Ideographic"},
    168984: {"Unified_Ideograph", "Ideographic"},
    168985: {"Unified_Ideograph", "Ideographic"},
    168986: {"Unified_Ideograph", "Ideographic"},
    168987: {"Unified_Ideograph", "Ideographic"},
    168988: {"Unified_Ideograph", "Ideographic"},
    168989: {"Unified_Ideograph", "Ideographic"},
    168990: {"Unified_Ideograph", "Ideographic"},
    168991: {"Unified_Ideograph", "Ideographic"},
    168992: {"Unified_Ideograph", "Ideographic"},
    168993: {"Unified_Ideograph", "Ideographic"},
    168994: {"Unified_Ideograph", "Ideographic"},
    168995: {"Unified_Ideograph", "Ideographic"},
    168996: {"Unified_Ideograph", "Ideographic"},
    168997: {"Unified_Ideograph", "Ideographic"},
    168998: {"Unified_Ideograph", "Ideographic"},
    168999: {"Unified_Ideograph", "Ideographic"},
    169000: {"Unified_Ideograph", "Ideographic"},
    169001: {"Unified_Ideograph", "Ideographic"},
    169002: {"Unified_Ideograph", "Ideographic"},
    169003: {"Unified_Ideograph", "Ideographic"},
    169004: {"Unified_Ideograph", "Ideographic"},
    169005: {"Unified_Ideograph", "Ideographic"},
    169006: {"Unified_Ideograph", "Ideographic"},
    169007: {"Unified_Ideograph", "Ideographic"},
    169008: {"Unified_Ideograph", "Ideographic"},
    169009: {"Unified_Ideograph", "Ideographic"},
    169010: {"Unified_Ideograph", "Ideographic"},
    169011: {"Unified_Ideograph", "Ideographic"},
    169012: {"Unified_Ideograph", "Ideographic"},
    169013: {"Unified_Ideograph", "Ideographic"},
    169014: {"Unified_Ideograph", "Ideographic"},
    169015: {"Unified_Ideograph", "Ideographic"},
    169016: {"Unified_Ideograph", "Ideographic"},
    169017: {"Unified_Ideograph", "Ideographic"},
    169018: {"Unified_Ideograph", "Ideographic"},
    169019: {"Unified_Ideograph", "Ideographic"},
    169020: {"Unified_Ideograph", "Ideographic"},
    169021: {"Unified_Ideograph", "Ideographic"},
    169022: {"Unified_Ideograph", "Ideographic"},
    169023: {"Unified_Ideograph", "Ideographic"},
    169024: {"Unified_Ideograph", "Ideographic"},
    169025: {"Unified_Ideograph", "Ideographic"},
    169026: {"Unified_Ideograph", "Ideographic"},
    169027: {"Unified_Ideograph", "Ideographic"},
    169028: {"Unified_Ideograph", "Ideographic"},
    169029: {"Unified_Ideograph", "Ideographic"},
    169030: {"Unified_Ideograph", "Ideographic"},
    169031: {"Unified_Ideograph", "Ideographic"},
    169032: {"Unified_Ideograph", "Ideographic"},
    169033: {"Unified_Ideograph", "Ideographic"},
    169034: {"Unified_Ideograph", "Ideographic"},
    169035: {"Unified_Ideograph", "Ideographic"},
    169036: {"Unified_Ideograph", "Ideographic"},
    169037: {"Unified_Ideograph", "Ideographic"},
    169038: {"Unified_Ideograph", "Ideographic"},
    169039: {"Unified_Ideograph", "Ideographic"},
    169040: {"Unified_Ideograph", "Ideographic"},
    169041: {"Unified_Ideograph", "Ideographic"},
    169042: {"Unified_Ideograph", "Ideographic"},
    169043: {"Unified_Ideograph", "Ideographic"},
    169044: {"Unified_Ideograph", "Ideographic"},
    169045: {"Unified_Ideograph", "Ideographic"},
    169046: {"Unified_Ideograph", "Ideographic"},
    169047: {"Unified_Ideograph", "Ideographic"},
    169048: {"Unified_Ideograph", "Ideographic"},
    169049: {"Unified_Ideograph", "Ideographic"},
    169050: {"Unified_Ideograph", "Ideographic"},
    169051: {"Unified_Ideograph", "Ideographic"},
    169052: {"Unified_Ideograph", "Ideographic"},
    169053: {"Unified_Ideograph", "Ideographic"},
    169054: {"Unified_Ideograph", "Ideographic"},
    169055: {"Unified_Ideograph", "Ideographic"},
    169056: {"Unified_Ideograph", "Ideographic"},
    169057: {"Unified_Ideograph", "Ideographic"},
    169058: {"Unified_Ideograph", "Ideographic"},
    169059: {"Unified_Ideograph", "Ideographic"},
    169060: {"Unified_Ideograph", "Ideographic"},
    169061: {"Unified_Ideograph", "Ideographic"},
    169062: {"Unified_Ideograph", "Ideographic"},
    169063: {"Unified_Ideograph", "Ideographic"},
    169064: {"Unified_Ideograph", "Ideographic"},
    169065: {"Unified_Ideograph", "Ideographic"},
    169066: {"Unified_Ideograph", "Ideographic"},
    169067: {"Unified_Ideograph", "Ideographic"},
    169068: {"Unified_Ideograph", "Ideographic"},
    169069: {"Unified_Ideograph", "Ideographic"},
    169070: {"Unified_Ideograph", "Ideographic"},
    169071: {"Unified_Ideograph", "Ideographic"},
    169072: {"Unified_Ideograph", "Ideographic"},
    169073: {"Unified_Ideograph", "Ideographic"},
    169074: {"Unified_Ideograph", "Ideographic"},
    169075: {"Unified_Ideograph", "Ideographic"},
    169076: {"Unified_Ideograph", "Ideographic"},
    169077: {"Unified_Ideograph", "Ideographic"},
    169078: {"Unified_Ideograph", "Ideographic"},
    169079: {"Unified_Ideograph", "Ideographic"},
    169080: {"Unified_Ideograph", "Ideographic"},
    169081: {"Unified_Ideograph", "Ideographic"},
    169082: {"Unified_Ideograph", "Ideographic"},
    169083: {"Unified_Ideograph", "Ideographic"},
    169084: {"Unified_Ideograph", "Ideographic"},
    169085: {"Unified_Ideograph", "Ideographic"},
    169086: {"Unified_Ideograph", "Ideographic"},
    169087: {"Unified_Ideograph", "Ideographic"},
    169088: {"Unified_Ideograph", "Ideographic"},
    169089: {"Unified_Ideograph", "Ideographic"},
    169090: {"Unified_Ideograph", "Ideographic"},
    169091: {"Unified_Ideograph", "Ideographic"},
    169092: {"Unified_Ideograph", "Ideographic"},
    169093: {"Unified_Ideograph", "Ideographic"},
    169094: {"Unified_Ideograph", "Ideographic"},
    169095: {"Unified_Ideograph", "Ideographic"},
    169096: {"Unified_Ideograph", "Ideographic"},
    169097: {"Unified_Ideograph", "Ideographic"},
    169098: {"Unified_Ideograph", "Ideographic"},
    169099: {"Unified_Ideograph", "Ideographic"},
    169100: {"Unified_Ideograph", "Ideographic"},
    169101: {"Unified_Ideograph", "Ideographic"},
    169102: {"Unified_Ideograph", "Ideographic"},
    169103: {"Unified_Ideograph", "Ideographic"},
    169104: {"Unified_Ideograph", "Ideographic"},
    169105: {"Unified_Ideograph", "Ideographic"},
    169106: {"Unified_Ideograph", "Ideographic"},
    169107: {"Unified_Ideograph", "Ideographic"},
    169108: {"Unified_Ideograph", "Ideographic"},
    169109: {"Unified_Ideograph", "Ideographic"},
    169110: {"Unified_Ideograph", "Ideographic"},
    169111: {"Unified_Ideograph", "Ideographic"},
    169112: {"Unified_Ideograph", "Ideographic"},
    169113: {"Unified_Ideograph", "Ideographic"},
    169114: {"Unified_Ideograph", "Ideographic"},
    169115: {"Unified_Ideograph", "Ideographic"},
    169116: {"Unified_Ideograph", "Ideographic"},
    169117: {"Unified_Ideograph", "Ideographic"},
    169118: {"Unified_Ideograph", "Ideographic"},
    169119: {"Unified_Ideograph", "Ideographic"},
    169120: {"Unified_Ideograph", "Ideographic"},
    169121: {"Unified_Ideograph", "Ideographic"},
    169122: {"Unified_Ideograph", "Ideographic"},
    169123: {"Unified_Ideograph", "Ideographic"},
    169124: {"Unified_Ideograph", "Ideographic"},
    169125: {"Unified_Ideograph", "Ideographic"},
    169126: {"Unified_Ideograph", "Ideographic"},
    169127: {"Unified_Ideograph", "Ideographic"},
    169128: {"Unified_Ideograph", "Ideographic"},
    169129: {"Unified_Ideograph", "Ideographic"},
    169130: {"Unified_Ideograph", "Ideographic"},
    169131: {"Unified_Ideograph", "Ideographic"},
    169132: {"Unified_Ideograph", "Ideographic"},
    169133: {"Unified_Ideograph", "Ideographic"},
    169134: {"Unified_Ideograph", "Ideographic"},
    169135: {"Unified_Ideograph", "Ideographic"},
    169136: {"Unified_Ideograph", "Ideographic"},
    169137: {"Unified_Ideograph", "Ideographic"},
    169138: {"Unified_Ideograph", "Ideographic"},
    169139: {"Unified_Ideograph", "Ideographic"},
    169140: {"Unified_Ideograph", "Ideographic"},
    169141: {"Unified_Ideograph", "Ideographic"},
    169142: {"Unified_Ideograph", "Ideographic"},
    169143: {"Unified_Ideograph", "Ideographic"},
    169144: {"Unified_Ideograph", "Ideographic"},
    169145: {"Unified_Ideograph", "Ideographic"},
    169146: {"Unified_Ideograph", "Ideographic"},
    169147: {"Unified_Ideograph", "Ideographic"},
    169148: {"Unified_Ideograph", "Ideographic"},
    169149: {"Unified_Ideograph", "Ideographic"},
    169150: {"Unified_Ideograph", "Ideographic"},
    169151: {"Unified_Ideograph", "Ideographic"},
    169152: {"Unified_Ideograph", "Ideographic"},
    169153: {"Unified_Ideograph", "Ideographic"},
    169154: {"Unified_Ideograph", "Ideographic"},
    169155: {"Unified_Ideograph", "Ideographic"},
    169156: {"Unified_Ideograph", "Ideographic"},
    169157: {"Unified_Ideograph", "Ideographic"},
    169158: {"Unified_Ideograph", "Ideographic"},
    169159: {"Unified_Ideograph", "Ideographic"},
    169160: {"Unified_Ideograph", "Ideographic"},
    169161: {"Unified_Ideograph", "Ideographic"},
    169162: {"Unified_Ideograph", "Ideographic"},
    169163: {"Unified_Ideograph", "Ideographic"},
    169164: {"Unified_Ideograph", "Ideographic"},
    169165: {"Unified_Ideograph", "Ideographic"},
    169166: {"Unified_Ideograph", "Ideographic"},
    169167: {"Unified_Ideograph", "Ideographic"},
    169168: {"Unified_Ideograph", "Ideographic"},
    169169: {"Unified_Ideograph", "Ideographic"},
    169170: {"Unified_Ideograph", "Ideographic"},
    169171: {"Unified_Ideograph", "Ideographic"},
    169172: {"Unified_Ideograph", "Ideographic"},
    169173: {"Unified_Ideograph", "Ideographic"},
    169174: {"Unified_Ideograph", "Ideographic"},
    169175: {"Unified_Ideograph", "Ideographic"},
    169176: {"Unified_Ideograph", "Ideographic"},
    169177: {"Unified_Ideograph", "Ideographic"},
    169178: {"Unified_Ideograph", "Ideographic"},
    169179: {"Unified_Ideograph", "Ideographic"},
    169180: {"Unified_Ideograph", "Ideographic"},
    169181: {"Unified_Ideograph", "Ideographic"},
    169182: {"Unified_Ideograph", "Ideographic"},
    169183: {"Unified_Ideograph", "Ideographic"},
    169184: {"Unified_Ideograph", "Ideographic"},
    169185: {"Unified_Ideograph", "Ideographic"},
    169186: {"Unified_Ideograph", "Ideographic"},
    169187: {"Unified_Ideograph", "Ideographic"},
    169188: {"Unified_Ideograph", "Ideographic"},
    169189: {"Unified_Ideograph", "Ideographic"},
    169190: {"Unified_Ideograph", "Ideographic"},
    169191: {"Unified_Ideograph", "Ideographic"},
    169192: {"Unified_Ideograph", "Ideographic"},
    169193: {"Unified_Ideograph", "Ideographic"},
    169194: {"Unified_Ideograph", "Ideographic"},
    169195: {"Unified_Ideograph", "Ideographic"},
    169196: {"Unified_Ideograph", "Ideographic"},
    169197: {"Unified_Ideograph", "Ideographic"},
    169198: {"Unified_Ideograph", "Ideographic"},
    169199: {"Unified_Ideograph", "Ideographic"},
    169200: {"Unified_Ideograph", "Ideographic"},
    169201: {"Unified_Ideograph", "Ideographic"},
    169202: {"Unified_Ideograph", "Ideographic"},
    169203: {"Unified_Ideograph", "Ideographic"},
    169204: {"Unified_Ideograph", "Ideographic"},
    169205: {"Unified_Ideograph", "Ideographic"},
    169206: {"Unified_Ideograph", "Ideographic"},
    169207: {"Unified_Ideograph", "Ideographic"},
    169208: {"Unified_Ideograph", "Ideographic"},
    169209: {"Unified_Ideograph", "Ideographic"},
    169210: {"Unified_Ideograph", "Ideographic"},
    169211: {"Unified_Ideograph", "Ideographic"},
    169212: {"Unified_Ideograph", "Ideographic"},
    169213: {"Unified_Ideograph", "Ideographic"},
    169214: {"Unified_Ideograph", "Ideographic"},
    169215: {"Unified_Ideograph", "Ideographic"},
    169216: {"Unified_Ideograph", "Ideographic"},
    169217: {"Unified_Ideograph", "Ideographic"},
    169218: {"Unified_Ideograph", "Ideographic"},
    169219: {"Unified_Ideograph", "Ideographic"},
    169220: {"Unified_Ideograph", "Ideographic"},
    169221: {"Unified_Ideograph", "Ideographic"},
    169222: {"Unified_Ideograph", "Ideographic"},
    169223: {"Unified_Ideograph", "Ideographic"},
    169224: {"Unified_Ideograph", "Ideographic"},
    169225: {"Unified_Ideograph", "Ideographic"},
    169226: {"Unified_Ideograph", "Ideographic"},
    169227: {"Unified_Ideograph", "Ideographic"},
    169228: {"Unified_Ideograph", "Ideographic"},
    169229: {"Unified_Ideograph", "Ideographic"},
    169230: {"Unified_Ideograph", "Ideographic"},
    169231: {"Unified_Ideograph", "Ideographic"},
    169232: {"Unified_Ideograph", "Ideographic"},
    169233: {"Unified_Ideograph", "Ideographic"},
    169234: {"Unified_Ideograph", "Ideographic"},
    169235: {"Unified_Ideograph", "Ideographic"},
    169236: {"Unified_Ideograph", "Ideographic"},
    169237: {"Unified_Ideograph", "Ideographic"},
    169238: {"Unified_Ideograph", "Ideographic"},
    169239: {"Unified_Ideograph", "Ideographic"},
    169240: {"Unified_Ideograph", "Ideographic"},
    169241: {"Unified_Ideograph", "Ideographic"},
    169242: {"Unified_Ideograph", "Ideographic"},
    169243: {"Unified_Ideograph", "Ideographic"},
    169244: {"Unified_Ideograph", "Ideographic"},
    169245: {"Unified_Ideograph", "Ideographic"},
    169246: {"Unified_Ideograph", "Ideographic"},
    169247: {"Unified_Ideograph", "Ideographic"},
    169248: {"Unified_Ideograph", "Ideographic"},
    169249: {"Unified_Ideograph", "Ideographic"},
    169250: {"Unified_Ideograph", "Ideographic"},
    169251: {"Unified_Ideograph", "Ideographic"},
    169252: {"Unified_Ideograph", "Ideographic"},
    169253: {"Unified_Ideograph", "Ideographic"},
    169254: {"Unified_Ideograph", "Ideographic"},
    169255: {"Unified_Ideograph", "Ideographic"},
    169256: {"Unified_Ideograph", "Ideographic"},
    169257: {"Unified_Ideograph", "Ideographic"},
    169258: {"Unified_Ideograph", "Ideographic"},
    169259: {"Unified_Ideograph", "Ideographic"},
    169260: {"Unified_Ideograph", "Ideographic"},
    169261: {"Unified_Ideograph", "Ideographic"},
    169262: {"Unified_Ideograph", "Ideographic"},
    169263: {"Unified_Ideograph", "Ideographic"},
    169264: {"Unified_Ideograph", "Ideographic"},
    169265: {"Unified_Ideograph", "Ideographic"},
    169266: {"Unified_Ideograph", "Ideographic"},
    169267: {"Unified_Ideograph", "Ideographic"},
    169268: {"Unified_Ideograph", "Ideographic"},
    169269: {"Unified_Ideograph", "Ideographic"},
    169270: {"Unified_Ideograph", "Ideographic"},
    169271: {"Unified_Ideograph", "Ideographic"},
    169272: {"Unified_Ideograph", "Ideographic"},
    169273: {"Unified_Ideograph", "Ideographic"},
    169274: {"Unified_Ideograph", "Ideographic"},
    169275: {"Unified_Ideograph", "Ideographic"},
    169276: {"Unified_Ideograph", "Ideographic"},
    169277: {"Unified_Ideograph", "Ideographic"},
    169278: {"Unified_Ideograph", "Ideographic"},
    169279: {"Unified_Ideograph", "Ideographic"},
    169280: {"Unified_Ideograph", "Ideographic"},
    169281: {"Unified_Ideograph", "Ideographic"},
    169282: {"Unified_Ideograph", "Ideographic"},
    169283: {"Unified_Ideograph", "Ideographic"},
    169284: {"Unified_Ideograph", "Ideographic"},
    169285: {"Unified_Ideograph", "Ideographic"},
    169286: {"Unified_Ideograph", "Ideographic"},
    169287: {"Unified_Ideograph", "Ideographic"},
    169288: {"Unified_Ideograph", "Ideographic"},
    169289: {"Unified_Ideograph", "Ideographic"},
    169290: {"Unified_Ideograph", "Ideographic"},
    169291: {"Unified_Ideograph", "Ideographic"},
    169292: {"Unified_Ideograph", "Ideographic"},
    169293: {"Unified_Ideograph", "Ideographic"},
    169294: {"Unified_Ideograph", "Ideographic"},
    169295: {"Unified_Ideograph", "Ideographic"},
    169296: {"Unified_Ideograph", "Ideographic"},
    169297: {"Unified_Ideograph", "Ideographic"},
    169298: {"Unified_Ideograph", "Ideographic"},
    169299: {"Unified_Ideograph", "Ideographic"},
    169300: {"Unified_Ideograph", "Ideographic"},
    169301: {"Unified_Ideograph", "Ideographic"},
    169302: {"Unified_Ideograph", "Ideographic"},
    169303: {"Unified_Ideograph", "Ideographic"},
    169304: {"Unified_Ideograph", "Ideographic"},
    169305: {"Unified_Ideograph", "Ideographic"},
    169306: {"Unified_Ideograph", "Ideographic"},
    169307: {"Unified_Ideograph", "Ideographic"},
    169308: {"Unified_Ideograph", "Ideographic"},
    169309: {"Unified_Ideograph", "Ideographic"},
    169310: {"Unified_Ideograph", "Ideographic"},
    169311: {"Unified_Ideograph", "Ideographic"},
    169312: {"Unified_Ideograph", "Ideographic"},
    169313: {"Unified_Ideograph", "Ideographic"},
    169314: {"Unified_Ideograph", "Ideographic"},
    169315: {"Unified_Ideograph", "Ideographic"},
    169316: {"Unified_Ideograph", "Ideographic"},
    169317: {"Unified_Ideograph", "Ideographic"},
    169318: {"Unified_Ideograph", "Ideographic"},
    169319: {"Unified_Ideograph", "Ideographic"},
    169320: {"Unified_Ideograph", "Ideographic"},
    169321: {"Unified_Ideograph", "Ideographic"},
    169322: {"Unified_Ideograph", "Ideographic"},
    169323: {"Unified_Ideograph", "Ideographic"},
    169324: {"Unified_Ideograph", "Ideographic"},
    169325: {"Unified_Ideograph", "Ideographic"},
    169326: {"Unified_Ideograph", "Ideographic"},
    169327: {"Unified_Ideograph", "Ideographic"},
    169328: {"Unified_Ideograph", "Ideographic"},
    169329: {"Unified_Ideograph", "Ideographic"},
    169330: {"Unified_Ideograph", "Ideographic"},
    169331: {"Unified_Ideograph", "Ideographic"},
    169332: {"Unified_Ideograph", "Ideographic"},
    169333: {"Unified_Ideograph", "Ideographic"},
    169334: {"Unified_Ideograph", "Ideographic"},
    169335: {"Unified_Ideograph", "Ideographic"},
    169336: {"Unified_Ideograph", "Ideographic"},
    169337: {"Unified_Ideograph", "Ideographic"},
    169338: {"Unified_Ideograph", "Ideographic"},
    169339: {"Unified_Ideograph", "Ideographic"},
    169340: {"Unified_Ideograph", "Ideographic"},
    169341: {"Unified_Ideograph", "Ideographic"},
    169342: {"Unified_Ideograph", "Ideographic"},
    169343: {"Unified_Ideograph", "Ideographic"},
    169344: {"Unified_Ideograph", "Ideographic"},
    169345: {"Unified_Ideograph", "Ideographic"},
    169346: {"Unified_Ideograph", "Ideographic"},
    169347: {"Unified_Ideograph", "Ideographic"},
    169348: {"Unified_Ideograph", "Ideographic"},
    169349: {"Unified_Ideograph", "Ideographic"},
    169350: {"Unified_Ideograph", "Ideographic"},
    169351: {"Unified_Ideograph", "Ideographic"},
    169352: {"Unified_Ideograph", "Ideographic"},
    169353: {"Unified_Ideograph", "Ideographic"},
    169354: {"Unified_Ideograph", "Ideographic"},
    169355: {"Unified_Ideograph", "Ideographic"},
    169356: {"Unified_Ideograph", "Ideographic"},
    169357: {"Unified_Ideograph", "Ideographic"},
    169358: {"Unified_Ideograph", "Ideographic"},
    169359: {"Unified_Ideograph", "Ideographic"},
    169360: {"Unified_Ideograph", "Ideographic"},
    169361: {"Unified_Ideograph", "Ideographic"},
    169362: {"Unified_Ideograph", "Ideographic"},
    169363: {"Unified_Ideograph", "Ideographic"},
    169364: {"Unified_Ideograph", "Ideographic"},
    169365: {"Unified_Ideograph", "Ideographic"},
    169366: {"Unified_Ideograph", "Ideographic"},
    169367: {"Unified_Ideograph", "Ideographic"},
    169368: {"Unified_Ideograph", "Ideographic"},
    169369: {"Unified_Ideograph", "Ideographic"},
    169370: {"Unified_Ideograph", "Ideographic"},
    169371: {"Unified_Ideograph", "Ideographic"},
    169372: {"Unified_Ideograph", "Ideographic"},
    169373: {"Unified_Ideograph", "Ideographic"},
    169374: {"Unified_Ideograph", "Ideographic"},
    169375: {"Unified_Ideograph", "Ideographic"},
    169376: {"Unified_Ideograph", "Ideographic"},
    169377: {"Unified_Ideograph", "Ideographic"},
    169378: {"Unified_Ideograph", "Ideographic"},
    169379: {"Unified_Ideograph", "Ideographic"},
    169380: {"Unified_Ideograph", "Ideographic"},
    169381: {"Unified_Ideograph", "Ideographic"},
    169382: {"Unified_Ideograph", "Ideographic"},
    169383: {"Unified_Ideograph", "Ideographic"},
    169384: {"Unified_Ideograph", "Ideographic"},
    169385: {"Unified_Ideograph", "Ideographic"},
    169386: {"Unified_Ideograph", "Ideographic"},
    169387: {"Unified_Ideograph", "Ideographic"},
    169388: {"Unified_Ideograph", "Ideographic"},
    169389: {"Unified_Ideograph", "Ideographic"},
    169390: {"Unified_Ideograph", "Ideographic"},
    169391: {"Unified_Ideograph", "Ideographic"},
    169392: {"Unified_Ideograph", "Ideographic"},
    169393: {"Unified_Ideograph", "Ideographic"},
    169394: {"Unified_Ideograph", "Ideographic"},
    169395: {"Unified_Ideograph", "Ideographic"},
    169396: {"Unified_Ideograph", "Ideographic"},
    169397: {"Unified_Ideograph", "Ideographic"},
    169398: {"Unified_Ideograph", "Ideographic"},
    169399: {"Unified_Ideograph", "Ideographic"},
    169400: {"Unified_Ideograph", "Ideographic"},
    169401: {"Unified_Ideograph", "Ideographic"},
    169402: {"Unified_Ideograph", "Ideographic"},
    169403: {"Unified_Ideograph", "Ideographic"},
    169404: {"Unified_Ideograph", "Ideographic"},
    169405: {"Unified_Ideograph", "Ideographic"},
    169406: {"Unified_Ideograph", "Ideographic"},
    169407: {"Unified_Ideograph", "Ideographic"},
    169408: {"Unified_Ideograph", "Ideographic"},
    169409: {"Unified_Ideograph", "Ideographic"},
    169410: {"Unified_Ideograph", "Ideographic"},
    169411: {"Unified_Ideograph", "Ideographic"},
    169412: {"Unified_Ideograph", "Ideographic"},
    169413: {"Unified_Ideograph", "Ideographic"},
    169414: {"Unified_Ideograph", "Ideographic"},
    169415: {"Unified_Ideograph", "Ideographic"},
    169416: {"Unified_Ideograph", "Ideographic"},
    169417: {"Unified_Ideograph", "Ideographic"},
    169418: {"Unified_Ideograph", "Ideographic"},
    169419: {"Unified_Ideograph", "Ideographic"},
    169420: {"Unified_Ideograph", "Ideographic"},
    169421: {"Unified_Ideograph", "Ideographic"},
    169422: {"Unified_Ideograph", "Ideographic"},
    169423: {"Unified_Ideograph", "Ideographic"},
    169424: {"Unified_Ideograph", "Ideographic"},
    169425: {"Unified_Ideograph", "Ideographic"},
    169426: {"Unified_Ideograph", "Ideographic"},
    169427: {"Unified_Ideograph", "Ideographic"},
    169428: {"Unified_Ideograph", "Ideographic"},
    169429: {"Unified_Ideograph", "Ideographic"},
    169430: {"Unified_Ideograph", "Ideographic"},
    169431: {"Unified_Ideograph", "Ideographic"},
    169432: {"Unified_Ideograph", "Ideographic"},
    169433: {"Unified_Ideograph", "Ideographic"},
    169434: {"Unified_Ideograph", "Ideographic"},
    169435: {"Unified_Ideograph", "Ideographic"},
    169436: {"Unified_Ideograph", "Ideographic"},
    169437: {"Unified_Ideograph", "Ideographic"},
    169438: {"Unified_Ideograph", "Ideographic"},
    169439: {"Unified_Ideograph", "Ideographic"},
    169440: {"Unified_Ideograph", "Ideographic"},
    169441: {"Unified_Ideograph", "Ideographic"},
    169442: {"Unified_Ideograph", "Ideographic"},
    169443: {"Unified_Ideograph", "Ideographic"},
    169444: {"Unified_Ideograph", "Ideographic"},
    169445: {"Unified_Ideograph", "Ideographic"},
    169446: {"Unified_Ideograph", "Ideographic"},
    169447: {"Unified_Ideograph", "Ideographic"},
    169448: {"Unified_Ideograph", "Ideographic"},
    169449: {"Unified_Ideograph", "Ideographic"},
    169450: {"Unified_Ideograph", "Ideographic"},
    169451: {"Unified_Ideograph", "Ideographic"},
    169452: {"Unified_Ideograph", "Ideographic"},
    169453: {"Unified_Ideograph", "Ideographic"},
    169454: {"Unified_Ideograph", "Ideographic"},
    169455: {"Unified_Ideograph", "Ideographic"},
    169456: {"Unified_Ideograph", "Ideographic"},
    169457: {"Unified_Ideograph", "Ideographic"},
    169458: {"Unified_Ideograph", "Ideographic"},
    169459: {"Unified_Ideograph", "Ideographic"},
    169460: {"Unified_Ideograph", "Ideographic"},
    169461: {"Unified_Ideograph", "Ideographic"},
    169462: {"Unified_Ideograph", "Ideographic"},
    169463: {"Unified_Ideograph", "Ideographic"},
    169464: {"Unified_Ideograph", "Ideographic"},
    169465: {"Unified_Ideograph", "Ideographic"},
    169466: {"Unified_Ideograph", "Ideographic"},
    169467: {"Unified_Ideograph", "Ideographic"},
    169468: {"Unified_Ideograph", "Ideographic"},
    169469: {"Unified_Ideograph", "Ideographic"},
    169470: {"Unified_Ideograph", "Ideographic"},
    169471: {"Unified_Ideograph", "Ideographic"},
    169472: {"Unified_Ideograph", "Ideographic"},
    169473: {"Unified_Ideograph", "Ideographic"},
    169474: {"Unified_Ideograph", "Ideographic"},
    169475: {"Unified_Ideograph", "Ideographic"},
    169476: {"Unified_Ideograph", "Ideographic"},
    169477: {"Unified_Ideograph", "Ideographic"},
    169478: {"Unified_Ideograph", "Ideographic"},
    169479: {"Unified_Ideograph", "Ideographic"},
    169480: {"Unified_Ideograph", "Ideographic"},
    169481: {"Unified_Ideograph", "Ideographic"},
    169482: {"Unified_Ideograph", "Ideographic"},
    169483: {"Unified_Ideograph", "Ideographic"},
    169484: {"Unified_Ideograph", "Ideographic"},
    169485: {"Unified_Ideograph", "Ideographic"},
    169486: {"Unified_Ideograph", "Ideographic"},
    169487: {"Unified_Ideograph", "Ideographic"},
    169488: {"Unified_Ideograph", "Ideographic"},
    169489: {"Unified_Ideograph", "Ideographic"},
    169490: {"Unified_Ideograph", "Ideographic"},
    169491: {"Unified_Ideograph", "Ideographic"},
    169492: {"Unified_Ideograph", "Ideographic"},
    169493: {"Unified_Ideograph", "Ideographic"},
    169494: {"Unified_Ideograph", "Ideographic"},
    169495: {"Unified_Ideograph", "Ideographic"},
    169496: {"Unified_Ideograph", "Ideographic"},
    169497: {"Unified_Ideograph", "Ideographic"},
    169498: {"Unified_Ideograph", "Ideographic"},
    169499: {"Unified_Ideograph", "Ideographic"},
    169500: {"Unified_Ideograph", "Ideographic"},
    169501: {"Unified_Ideograph", "Ideographic"},
    169502: {"Unified_Ideograph", "Ideographic"},
    169503: {"Unified_Ideograph", "Ideographic"},
    169504: {"Unified_Ideograph", "Ideographic"},
    169505: {"Unified_Ideograph", "Ideographic"},
    169506: {"Unified_Ideograph", "Ideographic"},
    169507: {"Unified_Ideograph", "Ideographic"},
    169508: {"Unified_Ideograph", "Ideographic"},
    169509: {"Unified_Ideograph", "Ideographic"},
    169510: {"Unified_Ideograph", "Ideographic"},
    169511: {"Unified_Ideograph", "Ideographic"},
    169512: {"Unified_Ideograph", "Ideographic"},
    169513: {"Unified_Ideograph", "Ideographic"},
    169514: {"Unified_Ideograph", "Ideographic"},
    169515: {"Unified_Ideograph", "Ideographic"},
    169516: {"Unified_Ideograph", "Ideographic"},
    169517: {"Unified_Ideograph", "Ideographic"},
    169518: {"Unified_Ideograph", "Ideographic"},
    169519: {"Unified_Ideograph", "Ideographic"},
    169520: {"Unified_Ideograph", "Ideographic"},
    169521: {"Unified_Ideograph", "Ideographic"},
    169522: {"Unified_Ideograph", "Ideographic"},
    169523: {"Unified_Ideograph", "Ideographic"},
    169524: {"Unified_Ideograph", "Ideographic"},
    169525: {"Unified_Ideograph", "Ideographic"},
    169526: {"Unified_Ideograph", "Ideographic"},
    169527: {"Unified_Ideograph", "Ideographic"},
    169528: {"Unified_Ideograph", "Ideographic"},
    169529: {"Unified_Ideograph", "Ideographic"},
    169530: {"Unified_Ideograph", "Ideographic"},
    169531: {"Unified_Ideograph", "Ideographic"},
    169532: {"Unified_Ideograph", "Ideographic"},
    169533: {"Unified_Ideograph", "Ideographic"},
    169534: {"Unified_Ideograph", "Ideographic"},
    169535: {"Unified_Ideograph", "Ideographic"},
    169536: {"Unified_Ideograph", "Ideographic"},
    169537: {"Unified_Ideograph", "Ideographic"},
    169538: {"Unified_Ideograph", "Ideographic"},
    169539: {"Unified_Ideograph", "Ideographic"},
    169540: {"Unified_Ideograph", "Ideographic"},
    169541: {"Unified_Ideograph", "Ideographic"},
    169542: {"Unified_Ideograph", "Ideographic"},
    169543: {"Unified_Ideograph", "Ideographic"},
    169544: {"Unified_Ideograph", "Ideographic"},
    169545: {"Unified_Ideograph", "Ideographic"},
    169546: {"Unified_Ideograph", "Ideographic"},
    169547: {"Unified_Ideograph", "Ideographic"},
    169548: {"Unified_Ideograph", "Ideographic"},
    169549: {"Unified_Ideograph", "Ideographic"},
    169550: {"Unified_Ideograph", "Ideographic"},
    169551: {"Unified_Ideograph", "Ideographic"},
    169552: {"Unified_Ideograph", "Ideographic"},
    169553: {"Unified_Ideograph", "Ideographic"},
    169554: {"Unified_Ideograph", "Ideographic"},
    169555: {"Unified_Ideograph", "Ideographic"},
    169556: {"Unified_Ideograph", "Ideographic"},
    169557: {"Unified_Ideograph", "Ideographic"},
    169558: {"Unified_Ideograph", "Ideographic"},
    169559: {"Unified_Ideograph", "Ideographic"},
    169560: {"Unified_Ideograph", "Ideographic"},
    169561: {"Unified_Ideograph", "Ideographic"},
    169562: {"Unified_Ideograph", "Ideographic"},
    169563: {"Unified_Ideograph", "Ideographic"},
    169564: {"Unified_Ideograph", "Ideographic"},
    169565: {"Unified_Ideograph", "Ideographic"},
    169566: {"Unified_Ideograph", "Ideographic"},
    169567: {"Unified_Ideograph", "Ideographic"},
    169568: {"Unified_Ideograph", "Ideographic"},
    169569: {"Unified_Ideograph", "Ideographic"},
    169570: {"Unified_Ideograph", "Ideographic"},
    169571: {"Unified_Ideograph", "Ideographic"},
    169572: {"Unified_Ideograph", "Ideographic"},
    169573: {"Unified_Ideograph", "Ideographic"},
    169574: {"Unified_Ideograph", "Ideographic"},
    169575: {"Unified_Ideograph", "Ideographic"},
    169576: {"Unified_Ideograph", "Ideographic"},
    169577: {"Unified_Ideograph", "Ideographic"},
    169578: {"Unified_Ideograph", "Ideographic"},
    169579: {"Unified_Ideograph", "Ideographic"},
    169580: {"Unified_Ideograph", "Ideographic"},
    169581: {"Unified_Ideograph", "Ideographic"},
    169582: {"Unified_Ideograph", "Ideographic"},
    169583: {"Unified_Ideograph", "Ideographic"},
    169584: {"Unified_Ideograph", "Ideographic"},
    169585: {"Unified_Ideograph", "Ideographic"},
    169586: {"Unified_Ideograph", "Ideographic"},
    169587: {"Unified_Ideograph", "Ideographic"},
    169588: {"Unified_Ideograph", "Ideographic"},
    169589: {"Unified_Ideograph", "Ideographic"},
    169590: {"Unified_Ideograph", "Ideographic"},
    169591: {"Unified_Ideograph", "Ideographic"},
    169592: {"Unified_Ideograph", "Ideographic"},
    169593: {"Unified_Ideograph", "Ideographic"},
    169594: {"Unified_Ideograph", "Ideographic"},
    169595: {"Unified_Ideograph", "Ideographic"},
    169596: {"Unified_Ideograph", "Ideographic"},
    169597: {"Unified_Ideograph", "Ideographic"},
    169598: {"Unified_Ideograph", "Ideographic"},
    169599: {"Unified_Ideograph", "Ideographic"},
    169600: {"Unified_Ideograph", "Ideographic"},
    169601: {"Unified_Ideograph", "Ideographic"},
    169602: {"Unified_Ideograph", "Ideographic"},
    169603: {"Unified_Ideograph", "Ideographic"},
    169604: {"Unified_Ideograph", "Ideographic"},
    169605: {"Unified_Ideograph", "Ideographic"},
    169606: {"Unified_Ideograph", "Ideographic"},
    169607: {"Unified_Ideograph", "Ideographic"},
    169608: {"Unified_Ideograph", "Ideographic"},
    169609: {"Unified_Ideograph", "Ideographic"},
    169610: {"Unified_Ideograph", "Ideographic"},
    169611: {"Unified_Ideograph", "Ideographic"},
    169612: {"Unified_Ideograph", "Ideographic"},
    169613: {"Unified_Ideograph", "Ideographic"},
    169614: {"Unified_Ideograph", "Ideographic"},
    169615: {"Unified_Ideograph", "Ideographic"},
    169616: {"Unified_Ideograph", "Ideographic"},
    169617: {"Unified_Ideograph", "Ideographic"},
    169618: {"Unified_Ideograph", "Ideographic"},
    169619: {"Unified_Ideograph", "Ideographic"},
    169620: {"Unified_Ideograph", "Ideographic"},
    169621: {"Unified_Ideograph", "Ideographic"},
    169622: {"Unified_Ideograph", "Ideographic"},
    169623: {"Unified_Ideograph", "Ideographic"},
    169624: {"Unified_Ideograph", "Ideographic"},
    169625: {"Unified_Ideograph", "Ideographic"},
    169626: {"Unified_Ideograph", "Ideographic"},
    169627: {"Unified_Ideograph", "Ideographic"},
    169628: {"Unified_Ideograph", "Ideographic"},
    169629: {"Unified_Ideograph", "Ideographic"},
    169630: {"Unified_Ideograph", "Ideographic"},
    169631: {"Unified_Ideograph", "Ideographic"},
    169632: {"Unified_Ideograph", "Ideographic"},
    169633: {"Unified_Ideograph", "Ideographic"},
    169634: {"Unified_Ideograph", "Ideographic"},
    169635: {"Unified_Ideograph", "Ideographic"},
    169636: {"Unified_Ideograph", "Ideographic"},
    169637: {"Unified_Ideograph", "Ideographic"},
    169638: {"Unified_Ideograph", "Ideographic"},
    169639: {"Unified_Ideograph", "Ideographic"},
    169640: {"Unified_Ideograph", "Ideographic"},
    169641: {"Unified_Ideograph", "Ideographic"},
    169642: {"Unified_Ideograph", "Ideographic"},
    169643: {"Unified_Ideograph", "Ideographic"},
    169644: {"Unified_Ideograph", "Ideographic"},
    169645: {"Unified_Ideograph", "Ideographic"},
    169646: {"Unified_Ideograph", "Ideographic"},
    169647: {"Unified_Ideograph", "Ideographic"},
    169648: {"Unified_Ideograph", "Ideographic"},
    169649: {"Unified_Ideograph", "Ideographic"},
    169650: {"Unified_Ideograph", "Ideographic"},
    169651: {"Unified_Ideograph", "Ideographic"},
    169652: {"Unified_Ideograph", "Ideographic"},
    169653: {"Unified_Ideograph", "Ideographic"},
    169654: {"Unified_Ideograph", "Ideographic"},
    169655: {"Unified_Ideograph", "Ideographic"},
    169656: {"Unified_Ideograph", "Ideographic"},
    169657: {"Unified_Ideograph", "Ideographic"},
    169658: {"Unified_Ideograph", "Ideographic"},
    169659: {"Unified_Ideograph", "Ideographic"},
    169660: {"Unified_Ideograph", "Ideographic"},
    169661: {"Unified_Ideograph", "Ideographic"},
    169662: {"Unified_Ideograph", "Ideographic"},
    169663: {"Unified_Ideograph", "Ideographic"},
    169664: {"Unified_Ideograph", "Ideographic"},
    169665: {"Unified_Ideograph", "Ideographic"},
    169666: {"Unified_Ideograph", "Ideographic"},
    169667: {"Unified_Ideograph", "Ideographic"},
    169668: {"Unified_Ideograph", "Ideographic"},
    169669: {"Unified_Ideograph", "Ideographic"},
    169670: {"Unified_Ideograph", "Ideographic"},
    169671: {"Unified_Ideograph", "Ideographic"},
    169672: {"Unified_Ideograph", "Ideographic"},
    169673: {"Unified_Ideograph", "Ideographic"},
    169674: {"Unified_Ideograph", "Ideographic"},
    169675: {"Unified_Ideograph", "Ideographic"},
    169676: {"Unified_Ideograph", "Ideographic"},
    169677: {"Unified_Ideograph", "Ideographic"},
    169678: {"Unified_Ideograph", "Ideographic"},
    169679: {"Unified_Ideograph", "Ideographic"},
    169680: {"Unified_Ideograph", "Ideographic"},
    169681: {"Unified_Ideograph", "Ideographic"},
    169682: {"Unified_Ideograph", "Ideographic"},
    169683: {"Unified_Ideograph", "Ideographic"},
    169684: {"Unified_Ideograph", "Ideographic"},
    169685: {"Unified_Ideograph", "Ideographic"},
    169686: {"Unified_Ideograph", "Ideographic"},
    169687: {"Unified_Ideograph", "Ideographic"},
    169688: {"Unified_Ideograph", "Ideographic"},
    169689: {"Unified_Ideograph", "Ideographic"},
    169690: {"Unified_Ideograph", "Ideographic"},
    169691: {"Unified_Ideograph", "Ideographic"},
    169692: {"Unified_Ideograph", "Ideographic"},
    169693: {"Unified_Ideograph", "Ideographic"},
    169694: {"Unified_Ideograph", "Ideographic"},
    169695: {"Unified_Ideograph", "Ideographic"},
    169696: {"Unified_Ideograph", "Ideographic"},
    169697: {"Unified_Ideograph", "Ideographic"},
    169698: {"Unified_Ideograph", "Ideographic"},
    169699: {"Unified_Ideograph", "Ideographic"},
    169700: {"Unified_Ideograph", "Ideographic"},
    169701: {"Unified_Ideograph", "Ideographic"},
    169702: {"Unified_Ideograph", "Ideographic"},
    169703: {"Unified_Ideograph", "Ideographic"},
    169704: {"Unified_Ideograph", "Ideographic"},
    169705: {"Unified_Ideograph", "Ideographic"},
    169706: {"Unified_Ideograph", "Ideographic"},
    169707: {"Unified_Ideograph", "Ideographic"},
    169708: {"Unified_Ideograph", "Ideographic"},
    169709: {"Unified_Ideograph", "Ideographic"},
    169710: {"Unified_Ideograph", "Ideographic"},
    169711: {"Unified_Ideograph", "Ideographic"},
    169712: {"Unified_Ideograph", "Ideographic"},
    169713: {"Unified_Ideograph", "Ideographic"},
    169714: {"Unified_Ideograph", "Ideographic"},
    169715: {"Unified_Ideograph", "Ideographic"},
    169716: {"Unified_Ideograph", "Ideographic"},
    169717: {"Unified_Ideograph", "Ideographic"},
    169718: {"Unified_Ideograph", "Ideographic"},
    169719: {"Unified_Ideograph", "Ideographic"},
    169720: {"Unified_Ideograph", "Ideographic"},
    169721: {"Unified_Ideograph", "Ideographic"},
    169722: {"Unified_Ideograph", "Ideographic"},
    169723: {"Unified_Ideograph", "Ideographic"},
    169724: {"Unified_Ideograph", "Ideographic"},
    169725: {"Unified_Ideograph", "Ideographic"},
    169726: {"Unified_Ideograph", "Ideographic"},
    169727: {"Unified_Ideograph", "Ideographic"},
    169728: {"Unified_Ideograph", "Ideographic"},
    169729: {"Unified_Ideograph", "Ideographic"},
    169730: {"Unified_Ideograph", "Ideographic"},
    169731: {"Unified_Ideograph", "Ideographic"},
    169732: {"Unified_Ideograph", "Ideographic"},
    169733: {"Unified_Ideograph", "Ideographic"},
    169734: {"Unified_Ideograph", "Ideographic"},
    169735: {"Unified_Ideograph", "Ideographic"},
    169736: {"Unified_Ideograph", "Ideographic"},
    169737: {"Unified_Ideograph", "Ideographic"},
    169738: {"Unified_Ideograph", "Ideographic"},
    169739: {"Unified_Ideograph", "Ideographic"},
    169740: {"Unified_Ideograph", "Ideographic"},
    169741: {"Unified_Ideograph", "Ideographic"},
    169742: {"Unified_Ideograph", "Ideographic"},
    169743: {"Unified_Ideograph", "Ideographic"},
    169744: {"Unified_Ideograph", "Ideographic"},
    169745: {"Unified_Ideograph", "Ideographic"},
    169746: {"Unified_Ideograph", "Ideographic"},
    169747: {"Unified_Ideograph", "Ideographic"},
    169748: {"Unified_Ideograph", "Ideographic"},
    169749: {"Unified_Ideograph", "Ideographic"},
    169750: {"Unified_Ideograph", "Ideographic"},
    169751: {"Unified_Ideograph", "Ideographic"},
    169752: {"Unified_Ideograph", "Ideographic"},
    169753: {"Unified_Ideograph", "Ideographic"},
    169754: {"Unified_Ideograph", "Ideographic"},
    169755: {"Unified_Ideograph", "Ideographic"},
    169756: {"Unified_Ideograph", "Ideographic"},
    169757: {"Unified_Ideograph", "Ideographic"},
    169758: {"Unified_Ideograph", "Ideographic"},
    169759: {"Unified_Ideograph", "Ideographic"},
    169760: {"Unified_Ideograph", "Ideographic"},
    169761: {"Unified_Ideograph", "Ideographic"},
    169762: {"Unified_Ideograph", "Ideographic"},
    169763: {"Unified_Ideograph", "Ideographic"},
    169764: {"Unified_Ideograph", "Ideographic"},
    169765: {"Unified_Ideograph", "Ideographic"},
    169766: {"Unified_Ideograph", "Ideographic"},
    169767: {"Unified_Ideograph", "Ideographic"},
    169768: {"Unified_Ideograph", "Ideographic"},
    169769: {"Unified_Ideograph", "Ideographic"},
    169770: {"Unified_Ideograph", "Ideographic"},
    169771: {"Unified_Ideograph", "Ideographic"},
    169772: {"Unified_Ideograph", "Ideographic"},
    169773: {"Unified_Ideograph", "Ideographic"},
    169774: {"Unified_Ideograph", "Ideographic"},
    169775: {"Unified_Ideograph", "Ideographic"},
    169776: {"Unified_Ideograph", "Ideographic"},
    169777: {"Unified_Ideograph", "Ideographic"},
    169778: {"Unified_Ideograph", "Ideographic"},
    169779: {"Unified_Ideograph", "Ideographic"},
    169780: {"Unified_Ideograph", "Ideographic"},
    169781: {"Unified_Ideograph", "Ideographic"},
    169782: {"Unified_Ideograph", "Ideographic"},
    169783: {"Unified_Ideograph", "Ideographic"},
    169784: {"Unified_Ideograph", "Ideographic"},
    169785: {"Unified_Ideograph", "Ideographic"},
    169786: {"Unified_Ideograph", "Ideographic"},
    169787: {"Unified_Ideograph", "Ideographic"},
    169788: {"Unified_Ideograph", "Ideographic"},
    169789: {"Unified_Ideograph", "Ideographic"},
    169790: {"Unified_Ideograph", "Ideographic"},
    169791: {"Unified_Ideograph", "Ideographic"},
    169792: {"Unified_Ideograph", "Ideographic"},
    169793: {"Unified_Ideograph", "Ideographic"},
    169794: {"Unified_Ideograph", "Ideographic"},
    169795: {"Unified_Ideograph", "Ideographic"},
    169796: {"Unified_Ideograph", "Ideographic"},
    169797: {"Unified_Ideograph", "Ideographic"},
    169798: {"Unified_Ideograph", "Ideographic"},
    169799: {"Unified_Ideograph", "Ideographic"},
    169800: {"Unified_Ideograph", "Ideographic"},
    169801: {"Unified_Ideograph", "Ideographic"},
    169802: {"Unified_Ideograph", "Ideographic"},
    169803: {"Unified_Ideograph", "Ideographic"},
    169804: {"Unified_Ideograph", "Ideographic"},
    169805: {"Unified_Ideograph", "Ideographic"},
    169806: {"Unified_Ideograph", "Ideographic"},
    169807: {"Unified_Ideograph", "Ideographic"},
    169808: {"Unified_Ideograph", "Ideographic"},
    169809: {"Unified_Ideograph", "Ideographic"},
    169810: {"Unified_Ideograph", "Ideographic"},
    169811: {"Unified_Ideograph", "Ideographic"},
    169812: {"Unified_Ideograph", "Ideographic"},
    169813: {"Unified_Ideograph", "Ideographic"},
    169814: {"Unified_Ideograph", "Ideographic"},
    169815: {"Unified_Ideograph", "Ideographic"},
    169816: {"Unified_Ideograph", "Ideographic"},
    169817: {"Unified_Ideograph", "Ideographic"},
    169818: {"Unified_Ideograph", "Ideographic"},
    169819: {"Unified_Ideograph", "Ideographic"},
    169820: {"Unified_Ideograph", "Ideographic"},
    169821: {"Unified_Ideograph", "Ideographic"},
    169822: {"Unified_Ideograph", "Ideographic"},
    169823: {"Unified_Ideograph", "Ideographic"},
    169824: {"Unified_Ideograph", "Ideographic"},
    169825: {"Unified_Ideograph", "Ideographic"},
    169826: {"Unified_Ideograph", "Ideographic"},
    169827: {"Unified_Ideograph", "Ideographic"},
    169828: {"Unified_Ideograph", "Ideographic"},
    169829: {"Unified_Ideograph", "Ideographic"},
    169830: {"Unified_Ideograph", "Ideographic"},
    169831: {"Unified_Ideograph", "Ideographic"},
    169832: {"Unified_Ideograph", "Ideographic"},
    169833: {"Unified_Ideograph", "Ideographic"},
    169834: {"Unified_Ideograph", "Ideographic"},
    169835: {"Unified_Ideograph", "Ideographic"},
    169836: {"Unified_Ideograph", "Ideographic"},
    169837: {"Unified_Ideograph", "Ideographic"},
    169838: {"Unified_Ideograph", "Ideographic"},
    169839: {"Unified_Ideograph", "Ideographic"},
    169840: {"Unified_Ideograph", "Ideographic"},
    169841: {"Unified_Ideograph", "Ideographic"},
    169842: {"Unified_Ideograph", "Ideographic"},
    169843: {"Unified_Ideograph", "Ideographic"},
    169844: {"Unified_Ideograph", "Ideographic"},
    169845: {"Unified_Ideograph", "Ideographic"},
    169846: {"Unified_Ideograph", "Ideographic"},
    169847: {"Unified_Ideograph", "Ideographic"},
    169848: {"Unified_Ideograph", "Ideographic"},
    169849: {"Unified_Ideograph", "Ideographic"},
    169850: {"Unified_Ideograph", "Ideographic"},
    169851: {"Unified_Ideograph", "Ideographic"},
    169852: {"Unified_Ideograph", "Ideographic"},
    169853: {"Unified_Ideograph", "Ideographic"},
    169854: {"Unified_Ideograph", "Ideographic"},
    169855: {"Unified_Ideograph", "Ideographic"},
    169856: {"Unified_Ideograph", "Ideographic"},
    169857: {"Unified_Ideograph", "Ideographic"},
    169858: {"Unified_Ideograph", "Ideographic"},
    169859: {"Unified_Ideograph", "Ideographic"},
    169860: {"Unified_Ideograph", "Ideographic"},
    169861: {"Unified_Ideograph", "Ideographic"},
    169862: {"Unified_Ideograph", "Ideographic"},
    169863: {"Unified_Ideograph", "Ideographic"},
    169864: {"Unified_Ideograph", "Ideographic"},
    169865: {"Unified_Ideograph", "Ideographic"},
    169866: {"Unified_Ideograph", "Ideographic"},
    169867: {"Unified_Ideograph", "Ideographic"},
    169868: {"Unified_Ideograph", "Ideographic"},
    169869: {"Unified_Ideograph", "Ideographic"},
    169870: {"Unified_Ideograph", "Ideographic"},
    169871: {"Unified_Ideograph", "Ideographic"},
    169872: {"Unified_Ideograph", "Ideographic"},
    169873: {"Unified_Ideograph", "Ideographic"},
    169874: {"Unified_Ideograph", "Ideographic"},
    169875: {"Unified_Ideograph", "Ideographic"},
    169876: {"Unified_Ideograph", "Ideographic"},
    169877: {"Unified_Ideograph", "Ideographic"},
    169878: {"Unified_Ideograph", "Ideographic"},
    169879: {"Unified_Ideograph", "Ideographic"},
    169880: {"Unified_Ideograph", "Ideographic"},
    169881: {"Unified_Ideograph", "Ideographic"},
    169882: {"Unified_Ideograph", "Ideographic"},
    169883: {"Unified_Ideograph", "Ideographic"},
    169884: {"Unified_Ideograph", "Ideographic"},
    169885: {"Unified_Ideograph", "Ideographic"},
    169886: {"Unified_Ideograph", "Ideographic"},
    169887: {"Unified_Ideograph", "Ideographic"},
    169888: {"Unified_Ideograph", "Ideographic"},
    169889: {"Unified_Ideograph", "Ideographic"},
    169890: {"Unified_Ideograph", "Ideographic"},
    169891: {"Unified_Ideograph", "Ideographic"},
    169892: {"Unified_Ideograph", "Ideographic"},
    169893: {"Unified_Ideograph", "Ideographic"},
    169894: {"Unified_Ideograph", "Ideographic"},
    169895: {"Unified_Ideograph", "Ideographic"},
    169896: {"Unified_Ideograph", "Ideographic"},
    169897: {"Unified_Ideograph", "Ideographic"},
    169898: {"Unified_Ideograph", "Ideographic"},
    169899: {"Unified_Ideograph", "Ideographic"},
    169900: {"Unified_Ideograph", "Ideographic"},
    169901: {"Unified_Ideograph", "Ideographic"},
    169902: {"Unified_Ideograph", "Ideographic"},
    169903: {"Unified_Ideograph", "Ideographic"},
    169904: {"Unified_Ideograph", "Ideographic"},
    169905: {"Unified_Ideograph", "Ideographic"},
    169906: {"Unified_Ideograph", "Ideographic"},
    169907: {"Unified_Ideograph", "Ideographic"},
    169908: {"Unified_Ideograph", "Ideographic"},
    169909: {"Unified_Ideograph", "Ideographic"},
    169910: {"Unified_Ideograph", "Ideographic"},
    169911: {"Unified_Ideograph", "Ideographic"},
    169912: {"Unified_Ideograph", "Ideographic"},
    169913: {"Unified_Ideograph", "Ideographic"},
    169914: {"Unified_Ideograph", "Ideographic"},
    169915: {"Unified_Ideograph", "Ideographic"},
    169916: {"Unified_Ideograph", "Ideographic"},
    169917: {"Unified_Ideograph", "Ideographic"},
    169918: {"Unified_Ideograph", "Ideographic"},
    169919: {"Unified_Ideograph", "Ideographic"},
    169920: {"Unified_Ideograph", "Ideographic"},
    169921: {"Unified_Ideograph", "Ideographic"},
    169922: {"Unified_Ideograph", "Ideographic"},
    169923: {"Unified_Ideograph", "Ideographic"},
    169924: {"Unified_Ideograph", "Ideographic"},
    169925: {"Unified_Ideograph", "Ideographic"},
    169926: {"Unified_Ideograph", "Ideographic"},
    169927: {"Unified_Ideograph", "Ideographic"},
    169928: {"Unified_Ideograph", "Ideographic"},
    169929: {"Unified_Ideograph", "Ideographic"},
    169930: {"Unified_Ideograph", "Ideographic"},
    169931: {"Unified_Ideograph", "Ideographic"},
    169932: {"Unified_Ideograph", "Ideographic"},
    169933: {"Unified_Ideograph", "Ideographic"},
    169934: {"Unified_Ideograph", "Ideographic"},
    169935: {"Unified_Ideograph", "Ideographic"},
    169936: {"Unified_Ideograph", "Ideographic"},
    169937: {"Unified_Ideograph", "Ideographic"},
    169938: {"Unified_Ideograph", "Ideographic"},
    169939: {"Unified_Ideograph", "Ideographic"},
    169940: {"Unified_Ideograph", "Ideographic"},
    169941: {"Unified_Ideograph", "Ideographic"},
    169942: {"Unified_Ideograph", "Ideographic"},
    169943: {"Unified_Ideograph", "Ideographic"},
    169944: {"Unified_Ideograph", "Ideographic"},
    169945: {"Unified_Ideograph", "Ideographic"},
    169946: {"Unified_Ideograph", "Ideographic"},
    169947: {"Unified_Ideograph", "Ideographic"},
    169948: {"Unified_Ideograph", "Ideographic"},
    169949: {"Unified_Ideograph", "Ideographic"},
    169950: {"Unified_Ideograph", "Ideographic"},
    169951: {"Unified_Ideograph", "Ideographic"},
    169952: {"Unified_Ideograph", "Ideographic"},
    169953: {"Unified_Ideograph", "Ideographic"},
    169954: {"Unified_Ideograph", "Ideographic"},
    169955: {"Unified_Ideograph", "Ideographic"},
    169956: {"Unified_Ideograph", "Ideographic"},
    169957: {"Unified_Ideograph", "Ideographic"},
    169958: {"Unified_Ideograph", "Ideographic"},
    169959: {"Unified_Ideograph", "Ideographic"},
    169960: {"Unified_Ideograph", "Ideographic"},
    169961: {"Unified_Ideograph", "Ideographic"},
    169962: {"Unified_Ideograph", "Ideographic"},
    169963: {"Unified_Ideograph", "Ideographic"},
    169964: {"Unified_Ideograph", "Ideographic"},
    169965: {"Unified_Ideograph", "Ideographic"},
    169966: {"Unified_Ideograph", "Ideographic"},
    169967: {"Unified_Ideograph", "Ideographic"},
    169968: {"Unified_Ideograph", "Ideographic"},
    169969: {"Unified_Ideograph", "Ideographic"},
    169970: {"Unified_Ideograph", "Ideographic"},
    169971: {"Unified_Ideograph", "Ideographic"},
    169972: {"Unified_Ideograph", "Ideographic"},
    169973: {"Unified_Ideograph", "Ideographic"},
    169974: {"Unified_Ideograph", "Ideographic"},
    169975: {"Unified_Ideograph", "Ideographic"},
    169976: {"Unified_Ideograph", "Ideographic"},
    169977: {"Unified_Ideograph", "Ideographic"},
    169978: {"Unified_Ideograph", "Ideographic"},
    169979: {"Unified_Ideograph", "Ideographic"},
    169980: {"Unified_Ideograph", "Ideographic"},
    169981: {"Unified_Ideograph", "Ideographic"},
    169982: {"Unified_Ideograph", "Ideographic"},
    169983: {"Unified_Ideograph", "Ideographic"},
    169984: {"Unified_Ideograph", "Ideographic"},
    169985: {"Unified_Ideograph", "Ideographic"},
    169986: {"Unified_Ideograph", "Ideographic"},
    169987: {"Unified_Ideograph", "Ideographic"},
    169988: {"Unified_Ideograph", "Ideographic"},
    169989: {"Unified_Ideograph", "Ideographic"},
    169990: {"Unified_Ideograph", "Ideographic"},
    169991: {"Unified_Ideograph", "Ideographic"},
    169992: {"Unified_Ideograph", "Ideographic"},
    169993: {"Unified_Ideograph", "Ideographic"},
    169994: {"Unified_Ideograph", "Ideographic"},
    169995: {"Unified_Ideograph", "Ideographic"},
    169996: {"Unified_Ideograph", "Ideographic"},
    169997: {"Unified_Ideograph", "Ideographic"},
    169998: {"Unified_Ideograph", "Ideographic"},
    169999: {"Unified_Ideograph", "Ideographic"},
    170000: {"Unified_Ideograph", "Ideographic"},
    170001: {"Unified_Ideograph", "Ideographic"},
    170002: {"Unified_Ideograph", "Ideographic"},
    170003: {"Unified_Ideograph", "Ideographic"},
    170004: {"Unified_Ideograph", "Ideographic"},
    170005: {"Unified_Ideograph", "Ideographic"},
    170006: {"Unified_Ideograph", "Ideographic"},
    170007: {"Unified_Ideograph", "Ideographic"},
    170008: {"Unified_Ideograph", "Ideographic"},
    170009: {"Unified_Ideograph", "Ideographic"},
    170010: {"Unified_Ideograph", "Ideographic"},
    170011: {"Unified_Ideograph", "Ideographic"},
    170012: {"Unified_Ideograph", "Ideographic"},
    170013: {"Unified_Ideograph", "Ideographic"},
    170014: {"Unified_Ideograph", "Ideographic"},
    170015: {"Unified_Ideograph", "Ideographic"},
    170016: {"Unified_Ideograph", "Ideographic"},
    170017: {"Unified_Ideograph", "Ideographic"},
    170018: {"Unified_Ideograph", "Ideographic"},
    170019: {"Unified_Ideograph", "Ideographic"},
    170020: {"Unified_Ideograph", "Ideographic"},
    170021: {"Unified_Ideograph", "Ideographic"},
    170022: {"Unified_Ideograph", "Ideographic"},
    170023: {"Unified_Ideograph", "Ideographic"},
    170024: {"Unified_Ideograph", "Ideographic"},
    170025: {"Unified_Ideograph", "Ideographic"},
    170026: {"Unified_Ideograph", "Ideographic"},
    170027: {"Unified_Ideograph", "Ideographic"},
    170028: {"Unified_Ideograph", "Ideographic"},
    170029: {"Unified_Ideograph", "Ideographic"},
    170030: {"Unified_Ideograph", "Ideographic"},
    170031: {"Unified_Ideograph", "Ideographic"},
    170032: {"Unified_Ideograph", "Ideographic"},
    170033: {"Unified_Ideograph", "Ideographic"},
    170034: {"Unified_Ideograph", "Ideographic"},
    170035: {"Unified_Ideograph", "Ideographic"},
    170036: {"Unified_Ideograph", "Ideographic"},
    170037: {"Unified_Ideograph", "Ideographic"},
    170038: {"Unified_Ideograph", "Ideographic"},
    170039: {"Unified_Ideograph", "Ideographic"},
    170040: {"Unified_Ideograph", "Ideographic"},
    170041: {"Unified_Ideograph", "Ideographic"},
    170042: {"Unified_Ideograph", "Ideographic"},
    170043: {"Unified_Ideograph", "Ideographic"},
    170044: {"Unified_Ideograph", "Ideographic"},
    170045: {"Unified_Ideograph", "Ideographic"},
    170046: {"Unified_Ideograph", "Ideographic"},
    170047: {"Unified_Ideograph", "Ideographic"},
    170048: {"Unified_Ideograph", "Ideographic"},
    170049: {"Unified_Ideograph", "Ideographic"},
    170050: {"Unified_Ideograph", "Ideographic"},
    170051: {"Unified_Ideograph", "Ideographic"},
    170052: {"Unified_Ideograph", "Ideographic"},
    170053: {"Unified_Ideograph", "Ideographic"},
    170054: {"Unified_Ideograph", "Ideographic"},
    170055: {"Unified_Ideograph", "Ideographic"},
    170056: {"Unified_Ideograph", "Ideographic"},
    170057: {"Unified_Ideograph", "Ideographic"},
    170058: {"Unified_Ideograph", "Ideographic"},
    170059: {"Unified_Ideograph", "Ideographic"},
    170060: {"Unified_Ideograph", "Ideographic"},
    170061: {"Unified_Ideograph", "Ideographic"},
    170062: {"Unified_Ideograph", "Ideographic"},
    170063: {"Unified_Ideograph", "Ideographic"},
    170064: {"Unified_Ideograph", "Ideographic"},
    170065: {"Unified_Ideograph", "Ideographic"},
    170066: {"Unified_Ideograph", "Ideographic"},
    170067: {"Unified_Ideograph", "Ideographic"},
    170068: {"Unified_Ideograph", "Ideographic"},
    170069: {"Unified_Ideograph", "Ideographic"},
    170070: {"Unified_Ideograph", "Ideographic"},
    170071: {"Unified_Ideograph", "Ideographic"},
    170072: {"Unified_Ideograph", "Ideographic"},
    170073: {"Unified_Ideograph", "Ideographic"},
    170074: {"Unified_Ideograph", "Ideographic"},
    170075: {"Unified_Ideograph", "Ideographic"},
    170076: {"Unified_Ideograph", "Ideographic"},
    170077: {"Unified_Ideograph", "Ideographic"},
    170078: {"Unified_Ideograph", "Ideographic"},
    170079: {"Unified_Ideograph", "Ideographic"},
    170080: {"Unified_Ideograph", "Ideographic"},
    170081: {"Unified_Ideograph", "Ideographic"},
    170082: {"Unified_Ideograph", "Ideographic"},
    170083: {"Unified_Ideograph", "Ideographic"},
    170084: {"Unified_Ideograph", "Ideographic"},
    170085: {"Unified_Ideograph", "Ideographic"},
    170086: {"Unified_Ideograph", "Ideographic"},
    170087: {"Unified_Ideograph", "Ideographic"},
    170088: {"Unified_Ideograph", "Ideographic"},
    170089: {"Unified_Ideograph", "Ideographic"},
    170090: {"Unified_Ideograph", "Ideographic"},
    170091: {"Unified_Ideograph", "Ideographic"},
    170092: {"Unified_Ideograph", "Ideographic"},
    170093: {"Unified_Ideograph", "Ideographic"},
    170094: {"Unified_Ideograph", "Ideographic"},
    170095: {"Unified_Ideograph", "Ideographic"},
    170096: {"Unified_Ideograph", "Ideographic"},
    170097: {"Unified_Ideograph", "Ideographic"},
    170098: {"Unified_Ideograph", "Ideographic"},
    170099: {"Unified_Ideograph", "Ideographic"},
    170100: {"Unified_Ideograph", "Ideographic"},
    170101: {"Unified_Ideograph", "Ideographic"},
    170102: {"Unified_Ideograph", "Ideographic"},
    170103: {"Unified_Ideograph", "Ideographic"},
    170104: {"Unified_Ideograph", "Ideographic"},
    170105: {"Unified_Ideograph", "Ideographic"},
    170106: {"Unified_Ideograph", "Ideographic"},
    170107: {"Unified_Ideograph", "Ideographic"},
    170108: {"Unified_Ideograph", "Ideographic"},
    170109: {"Unified_Ideograph", "Ideographic"},
    170110: {"Unified_Ideograph", "Ideographic"},
    170111: {"Unified_Ideograph", "Ideographic"},
    170112: {"Unified_Ideograph", "Ideographic"},
    170113: {"Unified_Ideograph", "Ideographic"},
    170114: {"Unified_Ideograph", "Ideographic"},
    170115: {"Unified_Ideograph", "Ideographic"},
    170116: {"Unified_Ideograph", "Ideographic"},
    170117: {"Unified_Ideograph", "Ideographic"},
    170118: {"Unified_Ideograph", "Ideographic"},
    170119: {"Unified_Ideograph", "Ideographic"},
    170120: {"Unified_Ideograph", "Ideographic"},
    170121: {"Unified_Ideograph", "Ideographic"},
    170122: {"Unified_Ideograph", "Ideographic"},
    170123: {"Unified_Ideograph", "Ideographic"},
    170124: {"Unified_Ideograph", "Ideographic"},
    170125: {"Unified_Ideograph", "Ideographic"},
    170126: {"Unified_Ideograph", "Ideographic"},
    170127: {"Unified_Ideograph", "Ideographic"},
    170128: {"Unified_Ideograph", "Ideographic"},
    170129: {"Unified_Ideograph", "Ideographic"},
    170130: {"Unified_Ideograph", "Ideographic"},
    170131: {"Unified_Ideograph", "Ideographic"},
    170132: {"Unified_Ideograph", "Ideographic"},
    170133: {"Unified_Ideograph", "Ideographic"},
    170134: {"Unified_Ideograph", "Ideographic"},
    170135: {"Unified_Ideograph", "Ideographic"},
    170136: {"Unified_Ideograph", "Ideographic"},
    170137: {"Unified_Ideograph", "Ideographic"},
    170138: {"Unified_Ideograph", "Ideographic"},
    170139: {"Unified_Ideograph", "Ideographic"},
    170140: {"Unified_Ideograph", "Ideographic"},
    170141: {"Unified_Ideograph", "Ideographic"},
    170142: {"Unified_Ideograph", "Ideographic"},
    170143: {"Unified_Ideograph", "Ideographic"},
    170144: {"Unified_Ideograph", "Ideographic"},
    170145: {"Unified_Ideograph", "Ideographic"},
    170146: {"Unified_Ideograph", "Ideographic"},
    170147: {"Unified_Ideograph", "Ideographic"},
    170148: {"Unified_Ideograph", "Ideographic"},
    170149: {"Unified_Ideograph", "Ideographic"},
    170150: {"Unified_Ideograph", "Ideographic"},
    170151: {"Unified_Ideograph", "Ideographic"},
    170152: {"Unified_Ideograph", "Ideographic"},
    170153: {"Unified_Ideograph", "Ideographic"},
    170154: {"Unified_Ideograph", "Ideographic"},
    170155: {"Unified_Ideograph", "Ideographic"},
    170156: {"Unified_Ideograph", "Ideographic"},
    170157: {"Unified_Ideograph", "Ideographic"},
    170158: {"Unified_Ideograph", "Ideographic"},
    170159: {"Unified_Ideograph", "Ideographic"},
    170160: {"Unified_Ideograph", "Ideographic"},
    170161: {"Unified_Ideograph", "Ideographic"},
    170162: {"Unified_Ideograph", "Ideographic"},
    170163: {"Unified_Ideograph", "Ideographic"},
    170164: {"Unified_Ideograph", "Ideographic"},
    170165: {"Unified_Ideograph", "Ideographic"},
    170166: {"Unified_Ideograph", "Ideographic"},
    170167: {"Unified_Ideograph", "Ideographic"},
    170168: {"Unified_Ideograph", "Ideographic"},
    170169: {"Unified_Ideograph", "Ideographic"},
    170170: {"Unified_Ideograph", "Ideographic"},
    170171: {"Unified_Ideograph", "Ideographic"},
    170172: {"Unified_Ideograph", "Ideographic"},
    170173: {"Unified_Ideograph", "Ideographic"},
    170174: {"Unified_Ideograph", "Ideographic"},
    170175: {"Unified_Ideograph", "Ideographic"},
    170176: {"Unified_Ideograph", "Ideographic"},
    170177: {"Unified_Ideograph", "Ideographic"},
    170178: {"Unified_Ideograph", "Ideographic"},
    170179: {"Unified_Ideograph", "Ideographic"},
    170180: {"Unified_Ideograph", "Ideographic"},
    170181: {"Unified_Ideograph", "Ideographic"},
    170182: {"Unified_Ideograph", "Ideographic"},
    170183: {"Unified_Ideograph", "Ideographic"},
    170184: {"Unified_Ideograph", "Ideographic"},
    170185: {"Unified_Ideograph", "Ideographic"},
    170186: {"Unified_Ideograph", "Ideographic"},
    170187: {"Unified_Ideograph", "Ideographic"},
    170188: {"Unified_Ideograph", "Ideographic"},
    170189: {"Unified_Ideograph", "Ideographic"},
    170190: {"Unified_Ideograph", "Ideographic"},
    170191: {"Unified_Ideograph", "Ideographic"},
    170192: {"Unified_Ideograph", "Ideographic"},
    170193: {"Unified_Ideograph", "Ideographic"},
    170194: {"Unified_Ideograph", "Ideographic"},
    170195: {"Unified_Ideograph", "Ideographic"},
    170196: {"Unified_Ideograph", "Ideographic"},
    170197: {"Unified_Ideograph", "Ideographic"},
    170198: {"Unified_Ideograph", "Ideographic"},
    170199: {"Unified_Ideograph", "Ideographic"},
    170200: {"Unified_Ideograph", "Ideographic"},
    170201: {"Unified_Ideograph", "Ideographic"},
    170202: {"Unified_Ideograph", "Ideographic"},
    170203: {"Unified_Ideograph", "Ideographic"},
    170204: {"Unified_Ideograph", "Ideographic"},
    170205: {"Unified_Ideograph", "Ideographic"},
    170206: {"Unified_Ideograph", "Ideographic"},
    170207: {"Unified_Ideograph", "Ideographic"},
    170208: {"Unified_Ideograph", "Ideographic"},
    170209: {"Unified_Ideograph", "Ideographic"},
    170210: {"Unified_Ideograph", "Ideographic"},
    170211: {"Unified_Ideograph", "Ideographic"},
    170212: {"Unified_Ideograph", "Ideographic"},
    170213: {"Unified_Ideograph", "Ideographic"},
    170214: {"Unified_Ideograph", "Ideographic"},
    170215: {"Unified_Ideograph", "Ideographic"},
    170216: {"Unified_Ideograph", "Ideographic"},
    170217: {"Unified_Ideograph", "Ideographic"},
    170218: {"Unified_Ideograph", "Ideographic"},
    170219: {"Unified_Ideograph", "Ideographic"},
    170220: {"Unified_Ideograph", "Ideographic"},
    170221: {"Unified_Ideograph", "Ideographic"},
    170222: {"Unified_Ideograph", "Ideographic"},
    170223: {"Unified_Ideograph", "Ideographic"},
    170224: {"Unified_Ideograph", "Ideographic"},
    170225: {"Unified_Ideograph", "Ideographic"},
    170226: {"Unified_Ideograph", "Ideographic"},
    170227: {"Unified_Ideograph", "Ideographic"},
    170228: {"Unified_Ideograph", "Ideographic"},
    170229: {"Unified_Ideograph", "Ideographic"},
    170230: {"Unified_Ideograph", "Ideographic"},
    170231: {"Unified_Ideograph", "Ideographic"},
    170232: {"Unified_Ideograph", "Ideographic"},
    170233: {"Unified_Ideograph", "Ideographic"},
    170234: {"Unified_Ideograph", "Ideographic"},
    170235: {"Unified_Ideograph", "Ideographic"},
    170236: {"Unified_Ideograph", "Ideographic"},
    170237: {"Unified_Ideograph", "Ideographic"},
    170238: {"Unified_Ideograph", "Ideographic"},
    170239: {"Unified_Ideograph", "Ideographic"},
    170240: {"Unified_Ideograph", "Ideographic"},
    170241: {"Unified_Ideograph", "Ideographic"},
    170242: {"Unified_Ideograph", "Ideographic"},
    170243: {"Unified_Ideograph", "Ideographic"},
    170244: {"Unified_Ideograph", "Ideographic"},
    170245: {"Unified_Ideograph", "Ideographic"},
    170246: {"Unified_Ideograph", "Ideographic"},
    170247: {"Unified_Ideograph", "Ideographic"},
    170248: {"Unified_Ideograph", "Ideographic"},
    170249: {"Unified_Ideograph", "Ideographic"},
    170250: {"Unified_Ideograph", "Ideographic"},
    170251: {"Unified_Ideograph", "Ideographic"},
    170252: {"Unified_Ideograph", "Ideographic"},
    170253: {"Unified_Ideograph", "Ideographic"},
    170254: {"Unified_Ideograph", "Ideographic"},
    170255: {"Unified_Ideograph", "Ideographic"},
    170256: {"Unified_Ideograph", "Ideographic"},
    170257: {"Unified_Ideograph", "Ideographic"},
    170258: {"Unified_Ideograph", "Ideographic"},
    170259: {"Unified_Ideograph", "Ideographic"},
    170260: {"Unified_Ideograph", "Ideographic"},
    170261: {"Unified_Ideograph", "Ideographic"},
    170262: {"Unified_Ideograph", "Ideographic"},
    170263: {"Unified_Ideograph", "Ideographic"},
    170264: {"Unified_Ideograph", "Ideographic"},
    170265: {"Unified_Ideograph", "Ideographic"},
    170266: {"Unified_Ideograph", "Ideographic"},
    170267: {"Unified_Ideograph", "Ideographic"},
    170268: {"Unified_Ideograph", "Ideographic"},
    170269: {"Unified_Ideograph", "Ideographic"},
    170270: {"Unified_Ideograph", "Ideographic"},
    170271: {"Unified_Ideograph", "Ideographic"},
    170272: {"Unified_Ideograph", "Ideographic"},
    170273: {"Unified_Ideograph", "Ideographic"},
    170274: {"Unified_Ideograph", "Ideographic"},
    170275: {"Unified_Ideograph", "Ideographic"},
    170276: {"Unified_Ideograph", "Ideographic"},
    170277: {"Unified_Ideograph", "Ideographic"},
    170278: {"Unified_Ideograph", "Ideographic"},
    170279: {"Unified_Ideograph", "Ideographic"},
    170280: {"Unified_Ideograph", "Ideographic"},
    170281: {"Unified_Ideograph", "Ideographic"},
    170282: {"Unified_Ideograph", "Ideographic"},
    170283: {"Unified_Ideograph", "Ideographic"},
    170284: {"Unified_Ideograph", "Ideographic"},
    170285: {"Unified_Ideograph", "Ideographic"},
    170286: {"Unified_Ideograph", "Ideographic"},
    170287: {"Unified_Ideograph", "Ideographic"},
    170288: {"Unified_Ideograph", "Ideographic"},
    170289: {"Unified_Ideograph", "Ideographic"},
    170290: {"Unified_Ideograph", "Ideographic"},
    170291: {"Unified_Ideograph", "Ideographic"},
    170292: {"Unified_Ideograph", "Ideographic"},
    170293: {"Unified_Ideograph", "Ideographic"},
    170294: {"Unified_Ideograph", "Ideographic"},
    170295: {"Unified_Ideograph", "Ideographic"},
    170296: {"Unified_Ideograph", "Ideographic"},
    170297: {"Unified_Ideograph", "Ideographic"},
    170298: {"Unified_Ideograph", "Ideographic"},
    170299: {"Unified_Ideograph", "Ideographic"},
    170300: {"Unified_Ideograph", "Ideographic"},
    170301: {"Unified_Ideograph", "Ideographic"},
    170302: {"Unified_Ideograph", "Ideographic"},
    170303: {"Unified_Ideograph", "Ideographic"},
    170304: {"Unified_Ideograph", "Ideographic"},
    170305: {"Unified_Ideograph", "Ideographic"},
    170306: {"Unified_Ideograph", "Ideographic"},
    170307: {"Unified_Ideograph", "Ideographic"},
    170308: {"Unified_Ideograph", "Ideographic"},
    170309: {"Unified_Ideograph", "Ideographic"},
    170310: {"Unified_Ideograph", "Ideographic"},
    170311: {"Unified_Ideograph", "Ideographic"},
    170312: {"Unified_Ideograph", "Ideographic"},
    170313: {"Unified_Ideograph", "Ideographic"},
    170314: {"Unified_Ideograph", "Ideographic"},
    170315: {"Unified_Ideograph", "Ideographic"},
    170316: {"Unified_Ideograph", "Ideographic"},
    170317: {"Unified_Ideograph", "Ideographic"},
    170318: {"Unified_Ideograph", "Ideographic"},
    170319: {"Unified_Ideograph", "Ideographic"},
    170320: {"Unified_Ideograph", "Ideographic"},
    170321: {"Unified_Ideograph", "Ideographic"},
    170322: {"Unified_Ideograph", "Ideographic"},
    170323: {"Unified_Ideograph", "Ideographic"},
    170324: {"Unified_Ideograph", "Ideographic"},
    170325: {"Unified_Ideograph", "Ideographic"},
    170326: {"Unified_Ideograph", "Ideographic"},
    170327: {"Unified_Ideograph", "Ideographic"},
    170328: {"Unified_Ideograph", "Ideographic"},
    170329: {"Unified_Ideograph", "Ideographic"},
    170330: {"Unified_Ideograph", "Ideographic"},
    170331: {"Unified_Ideograph", "Ideographic"},
    170332: {"Unified_Ideograph", "Ideographic"},
    170333: {"Unified_Ideograph", "Ideographic"},
    170334: {"Unified_Ideograph", "Ideographic"},
    170335: {"Unified_Ideograph", "Ideographic"},
    170336: {"Unified_Ideograph", "Ideographic"},
    170337: {"Unified_Ideograph", "Ideographic"},
    170338: {"Unified_Ideograph", "Ideographic"},
    170339: {"Unified_Ideograph", "Ideographic"},
    170340: {"Unified_Ideograph", "Ideographic"},
    170341: {"Unified_Ideograph", "Ideographic"},
    170342: {"Unified_Ideograph", "Ideographic"},
    170343: {"Unified_Ideograph", "Ideographic"},
    170344: {"Unified_Ideograph", "Ideographic"},
    170345: {"Unified_Ideograph", "Ideographic"},
    170346: {"Unified_Ideograph", "Ideographic"},
    170347: {"Unified_Ideograph", "Ideographic"},
    170348: {"Unified_Ideograph", "Ideographic"},
    170349: {"Unified_Ideograph", "Ideographic"},
    170350: {"Unified_Ideograph", "Ideographic"},
    170351: {"Unified_Ideograph", "Ideographic"},
    170352: {"Unified_Ideograph", "Ideographic"},
    170353: {"Unified_Ideograph", "Ideographic"},
    170354: {"Unified_Ideograph", "Ideographic"},
    170355: {"Unified_Ideograph", "Ideographic"},
    170356: {"Unified_Ideograph", "Ideographic"},
    170357: {"Unified_Ideograph", "Ideographic"},
    170358: {"Unified_Ideograph", "Ideographic"},
    170359: {"Unified_Ideograph", "Ideographic"},
    170360: {"Unified_Ideograph", "Ideographic"},
    170361: {"Unified_Ideograph", "Ideographic"},
    170362: {"Unified_Ideograph", "Ideographic"},
    170363: {"Unified_Ideograph", "Ideographic"},
    170364: {"Unified_Ideograph", "Ideographic"},
    170365: {"Unified_Ideograph", "Ideographic"},
    170366: {"Unified_Ideograph", "Ideographic"},
    170367: {"Unified_Ideograph", "Ideographic"},
    170368: {"Unified_Ideograph", "Ideographic"},
    170369: {"Unified_Ideograph", "Ideographic"},
    170370: {"Unified_Ideograph", "Ideographic"},
    170371: {"Unified_Ideograph", "Ideographic"},
    170372: {"Unified_Ideograph", "Ideographic"},
    170373: {"Unified_Ideograph", "Ideographic"},
    170374: {"Unified_Ideograph", "Ideographic"},
    170375: {"Unified_Ideograph", "Ideographic"},
    170376: {"Unified_Ideograph", "Ideographic"},
    170377: {"Unified_Ideograph", "Ideographic"},
    170378: {"Unified_Ideograph", "Ideographic"},
    170379: {"Unified_Ideograph", "Ideographic"},
    170380: {"Unified_Ideograph", "Ideographic"},
    170381: {"Unified_Ideograph", "Ideographic"},
    170382: {"Unified_Ideograph", "Ideographic"},
    170383: {"Unified_Ideograph", "Ideographic"},
    170384: {"Unified_Ideograph", "Ideographic"},
    170385: {"Unified_Ideograph", "Ideographic"},
    170386: {"Unified_Ideograph", "Ideographic"},
    170387: {"Unified_Ideograph", "Ideographic"},
    170388: {"Unified_Ideograph", "Ideographic"},
    170389: {"Unified_Ideograph", "Ideographic"},
    170390: {"Unified_Ideograph", "Ideographic"},
    170391: {"Unified_Ideograph", "Ideographic"},
    170392: {"Unified_Ideograph", "Ideographic"},
    170393: {"Unified_Ideograph", "Ideographic"},
    170394: {"Unified_Ideograph", "Ideographic"},
    170395: {"Unified_Ideograph", "Ideographic"},
    170396: {"Unified_Ideograph", "Ideographic"},
    170397: {"Unified_Ideograph", "Ideographic"},
    170398: {"Unified_Ideograph", "Ideographic"},
    170399: {"Unified_Ideograph", "Ideographic"},
    170400: {"Unified_Ideograph", "Ideographic"},
    170401: {"Unified_Ideograph", "Ideographic"},
    170402: {"Unified_Ideograph", "Ideographic"},
    170403: {"Unified_Ideograph", "Ideographic"},
    170404: {"Unified_Ideograph", "Ideographic"},
    170405: {"Unified_Ideograph", "Ideographic"},
    170406: {"Unified_Ideograph", "Ideographic"},
    170407: {"Unified_Ideograph", "Ideographic"},
    170408: {"Unified_Ideograph", "Ideographic"},
    170409: {"Unified_Ideograph", "Ideographic"},
    170410: {"Unified_Ideograph", "Ideographic"},
    170411: {"Unified_Ideograph", "Ideographic"},
    170412: {"Unified_Ideograph", "Ideographic"},
    170413: {"Unified_Ideograph", "Ideographic"},
    170414: {"Unified_Ideograph", "Ideographic"},
    170415: {"Unified_Ideograph", "Ideographic"},
    170416: {"Unified_Ideograph", "Ideographic"},
    170417: {"Unified_Ideograph", "Ideographic"},
    170418: {"Unified_Ideograph", "Ideographic"},
    170419: {"Unified_Ideograph", "Ideographic"},
    170420: {"Unified_Ideograph", "Ideographic"},
    170421: {"Unified_Ideograph", "Ideographic"},
    170422: {"Unified_Ideograph", "Ideographic"},
    170423: {"Unified_Ideograph", "Ideographic"},
    170424: {"Unified_Ideograph", "Ideographic"},
    170425: {"Unified_Ideograph", "Ideographic"},
    170426: {"Unified_Ideograph", "Ideographic"},
    170427: {"Unified_Ideograph", "Ideographic"},
    170428: {"Unified_Ideograph", "Ideographic"},
    170429: {"Unified_Ideograph", "Ideographic"},
    170430: {"Unified_Ideograph", "Ideographic"},
    170431: {"Unified_Ideograph", "Ideographic"},
    170432: {"Unified_Ideograph", "Ideographic"},
    170433: {"Unified_Ideograph", "Ideographic"},
    170434: {"Unified_Ideograph", "Ideographic"},
    170435: {"Unified_Ideograph", "Ideographic"},
    170436: {"Unified_Ideograph", "Ideographic"},
    170437: {"Unified_Ideograph", "Ideographic"},
    170438: {"Unified_Ideograph", "Ideographic"},
    170439: {"Unified_Ideograph", "Ideographic"},
    170440: {"Unified_Ideograph", "Ideographic"},
    170441: {"Unified_Ideograph", "Ideographic"},
    170442: {"Unified_Ideograph", "Ideographic"},
    170443: {"Unified_Ideograph", "Ideographic"},
    170444: {"Unified_Ideograph", "Ideographic"},
    170445: {"Unified_Ideograph", "Ideographic"},
    170446: {"Unified_Ideograph", "Ideographic"},
    170447: {"Unified_Ideograph", "Ideographic"},
    170448: {"Unified_Ideograph", "Ideographic"},
    170449: {"Unified_Ideograph", "Ideographic"},
    170450: {"Unified_Ideograph", "Ideographic"},
    170451: {"Unified_Ideograph", "Ideographic"},
    170452: {"Unified_Ideograph", "Ideographic"},
    170453: {"Unified_Ideograph", "Ideographic"},
    170454: {"Unified_Ideograph", "Ideographic"},
    170455: {"Unified_Ideograph", "Ideographic"},
    170456: {"Unified_Ideograph", "Ideographic"},
    170457: {"Unified_Ideograph", "Ideographic"},
    170458: {"Unified_Ideograph", "Ideographic"},
    170459: {"Unified_Ideograph", "Ideographic"},
    170460: {"Unified_Ideograph", "Ideographic"},
    170461: {"Unified_Ideograph", "Ideographic"},
    170462: {"Unified_Ideograph", "Ideographic"},
    170463: {"Unified_Ideograph", "Ideographic"},
    170464: {"Unified_Ideograph", "Ideographic"},
    170465: {"Unified_Ideograph", "Ideographic"},
    170466: {"Unified_Ideograph", "Ideographic"},
    170467: {"Unified_Ideograph", "Ideographic"},
    170468: {"Unified_Ideograph", "Ideographic"},
    170469: {"Unified_Ideograph", "Ideographic"},
    170470: {"Unified_Ideograph", "Ideographic"},
    170471: {"Unified_Ideograph", "Ideographic"},
    170472: {"Unified_Ideograph", "Ideographic"},
    170473: {"Unified_Ideograph", "Ideographic"},
    170474: {"Unified_Ideograph", "Ideographic"},
    170475: {"Unified_Ideograph", "Ideographic"},
    170476: {"Unified_Ideograph", "Ideographic"},
    170477: {"Unified_Ideograph", "Ideographic"},
    170478: {"Unified_Ideograph", "Ideographic"},
    170479: {"Unified_Ideograph", "Ideographic"},
    170480: {"Unified_Ideograph", "Ideographic"},
    170481: {"Unified_Ideograph", "Ideographic"},
    170482: {"Unified_Ideograph", "Ideographic"},
    170483: {"Unified_Ideograph", "Ideographic"},
    170484: {"Unified_Ideograph", "Ideographic"},
    170485: {"Unified_Ideograph", "Ideographic"},
    170486: {"Unified_Ideograph", "Ideographic"},
    170487: {"Unified_Ideograph", "Ideographic"},
    170488: {"Unified_Ideograph", "Ideographic"},
    170489: {"Unified_Ideograph", "Ideographic"},
    170490: {"Unified_Ideograph", "Ideographic"},
    170491: {"Unified_Ideograph", "Ideographic"},
    170492: {"Unified_Ideograph", "Ideographic"},
    170493: {"Unified_Ideograph", "Ideographic"},
    170494: {"Unified_Ideograph", "Ideographic"},
    170495: {"Unified_Ideograph", "Ideographic"},
    170496: {"Unified_Ideograph", "Ideographic"},
    170497: {"Unified_Ideograph", "Ideographic"},
    170498: {"Unified_Ideograph", "Ideographic"},
    170499: {"Unified_Ideograph", "Ideographic"},
    170500: {"Unified_Ideograph", "Ideographic"},
    170501: {"Unified_Ideograph", "Ideographic"},
    170502: {"Unified_Ideograph", "Ideographic"},
    170503: {"Unified_Ideograph", "Ideographic"},
    170504: {"Unified_Ideograph", "Ideographic"},
    170505: {"Unified_Ideograph", "Ideographic"},
    170506: {"Unified_Ideograph", "Ideographic"},
    170507: {"Unified_Ideograph", "Ideographic"},
    170508: {"Unified_Ideograph", "Ideographic"},
    170509: {"Unified_Ideograph", "Ideographic"},
    170510: {"Unified_Ideograph", "Ideographic"},
    170511: {"Unified_Ideograph", "Ideographic"},
    170512: {"Unified_Ideograph", "Ideographic"},
    170513: {"Unified_Ideograph", "Ideographic"},
    170514: {"Unified_Ideograph", "Ideographic"},
    170515: {"Unified_Ideograph", "Ideographic"},
    170516: {"Unified_Ideograph", "Ideographic"},
    170517: {"Unified_Ideograph", "Ideographic"},
    170518: {"Unified_Ideograph", "Ideographic"},
    170519: {"Unified_Ideograph", "Ideographic"},
    170520: {"Unified_Ideograph", "Ideographic"},
    170521: {"Unified_Ideograph", "Ideographic"},
    170522: {"Unified_Ideograph", "Ideographic"},
    170523: {"Unified_Ideograph", "Ideographic"},
    170524: {"Unified_Ideograph", "Ideographic"},
    170525: {"Unified_Ideograph", "Ideographic"},
    170526: {"Unified_Ideograph", "Ideographic"},
    170527: {"Unified_Ideograph", "Ideographic"},
    170528: {"Unified_Ideograph", "Ideographic"},
    170529: {"Unified_Ideograph", "Ideographic"},
    170530: {"Unified_Ideograph", "Ideographic"},
    170531: {"Unified_Ideograph", "Ideographic"},
    170532: {"Unified_Ideograph", "Ideographic"},
    170533: {"Unified_Ideograph", "Ideographic"},
    170534: {"Unified_Ideograph", "Ideographic"},
    170535: {"Unified_Ideograph", "Ideographic"},
    170536: {"Unified_Ideograph", "Ideographic"},
    170537: {"Unified_Ideograph", "Ideographic"},
    170538: {"Unified_Ideograph", "Ideographic"},
    170539: {"Unified_Ideograph", "Ideographic"},
    170540: {"Unified_Ideograph", "Ideographic"},
    170541: {"Unified_Ideograph", "Ideographic"},
    170542: {"Unified_Ideograph", "Ideographic"},
    170543: {"Unified_Ideograph", "Ideographic"},
    170544: {"Unified_Ideograph", "Ideographic"},
    170545: {"Unified_Ideograph", "Ideographic"},
    170546: {"Unified_Ideograph", "Ideographic"},
    170547: {"Unified_Ideograph", "Ideographic"},
    170548: {"Unified_Ideograph", "Ideographic"},
    170549: {"Unified_Ideograph", "Ideographic"},
    170550: {"Unified_Ideograph", "Ideographic"},
    170551: {"Unified_Ideograph", "Ideographic"},
    170552: {"Unified_Ideograph", "Ideographic"},
    170553: {"Unified_Ideograph", "Ideographic"},
    170554: {"Unified_Ideograph", "Ideographic"},
    170555: {"Unified_Ideograph", "Ideographic"},
    170556: {"Unified_Ideograph", "Ideographic"},
    170557: {"Unified_Ideograph", "Ideographic"},
    170558: {"Unified_Ideograph", "Ideographic"},
    170559: {"Unified_Ideograph", "Ideographic"},
    170560: {"Unified_Ideograph", "Ideographic"},
    170561: {"Unified_Ideograph", "Ideographic"},
    170562: {"Unified_Ideograph", "Ideographic"},
    170563: {"Unified_Ideograph", "Ideographic"},
    170564: {"Unified_Ideograph", "Ideographic"},
    170565: {"Unified_Ideograph", "Ideographic"},
    170566: {"Unified_Ideograph", "Ideographic"},
    170567: {"Unified_Ideograph", "Ideographic"},
    170568: {"Unified_Ideograph", "Ideographic"},
    170569: {"Unified_Ideograph", "Ideographic"},
    170570: {"Unified_Ideograph", "Ideographic"},
    170571: {"Unified_Ideograph", "Ideographic"},
    170572: {"Unified_Ideograph", "Ideographic"},
    170573: {"Unified_Ideograph", "Ideographic"},
    170574: {"Unified_Ideograph", "Ideographic"},
    170575: {"Unified_Ideograph", "Ideographic"},
    170576: {"Unified_Ideograph", "Ideographic"},
    170577: {"Unified_Ideograph", "Ideographic"},
    170578: {"Unified_Ideograph", "Ideographic"},
    170579: {"Unified_Ideograph", "Ideographic"},
    170580: {"Unified_Ideograph", "Ideographic"},
    170581: {"Unified_Ideograph", "Ideographic"},
    170582: {"Unified_Ideograph", "Ideographic"},
    170583: {"Unified_Ideograph", "Ideographic"},
    170584: {"Unified_Ideograph", "Ideographic"},
    170585: {"Unified_Ideograph", "Ideographic"},
    170586: {"Unified_Ideograph", "Ideographic"},
    170587: {"Unified_Ideograph", "Ideographic"},
    170588: {"Unified_Ideograph", "Ideographic"},
    170589: {"Unified_Ideograph", "Ideographic"},
    170590: {"Unified_Ideograph", "Ideographic"},
    170591: {"Unified_Ideograph", "Ideographic"},
    170592: {"Unified_Ideograph", "Ideographic"},
    170593: {"Unified_Ideograph", "Ideographic"},
    170594: {"Unified_Ideograph", "Ideographic"},
    170595: {"Unified_Ideograph", "Ideographic"},
    170596: {"Unified_Ideograph", "Ideographic"},
    170597: {"Unified_Ideograph", "Ideographic"},
    170598: {"Unified_Ideograph", "Ideographic"},
    170599: {"Unified_Ideograph", "Ideographic"},
    170600: {"Unified_Ideograph", "Ideographic"},
    170601: {"Unified_Ideograph", "Ideographic"},
    170602: {"Unified_Ideograph", "Ideographic"},
    170603: {"Unified_Ideograph", "Ideographic"},
    170604: {"Unified_Ideograph", "Ideographic"},
    170605: {"Unified_Ideograph", "Ideographic"},
    170606: {"Unified_Ideograph", "Ideographic"},
    170607: {"Unified_Ideograph", "Ideographic"},
    170608: {"Unified_Ideograph", "Ideographic"},
    170609: {"Unified_Ideograph", "Ideographic"},
    170610: {"Unified_Ideograph", "Ideographic"},
    170611: {"Unified_Ideograph", "Ideographic"},
    170612: {"Unified_Ideograph", "Ideographic"},
    170613: {"Unified_Ideograph", "Ideographic"},
    170614: {"Unified_Ideograph", "Ideographic"},
    170615: {"Unified_Ideograph", "Ideographic"},
    170616: {"Unified_Ideograph", "Ideographic"},
    170617: {"Unified_Ideograph", "Ideographic"},
    170618: {"Unified_Ideograph", "Ideographic"},
    170619: {"Unified_Ideograph", "Ideographic"},
    170620: {"Unified_Ideograph", "Ideographic"},
    170621: {"Unified_Ideograph", "Ideographic"},
    170622: {"Unified_Ideograph", "Ideographic"},
    170623: {"Unified_Ideograph", "Ideographic"},
    170624: {"Unified_Ideograph", "Ideographic"},
    170625: {"Unified_Ideograph", "Ideographic"},
    170626: {"Unified_Ideograph", "Ideographic"},
    170627: {"Unified_Ideograph", "Ideographic"},
    170628: {"Unified_Ideograph", "Ideographic"},
    170629: {"Unified_Ideograph", "Ideographic"},
    170630: {"Unified_Ideograph", "Ideographic"},
    170631: {"Unified_Ideograph", "Ideographic"},
    170632: {"Unified_Ideograph", "Ideographic"},
    170633: {"Unified_Ideograph", "Ideographic"},
    170634: {"Unified_Ideograph", "Ideographic"},
    170635: {"Unified_Ideograph", "Ideographic"},
    170636: {"Unified_Ideograph", "Ideographic"},
    170637: {"Unified_Ideograph", "Ideographic"},
    170638: {"Unified_Ideograph", "Ideographic"},
    170639: {"Unified_Ideograph", "Ideographic"},
    170640: {"Unified_Ideograph", "Ideographic"},
    170641: {"Unified_Ideograph", "Ideographic"},
    170642: {"Unified_Ideograph", "Ideographic"},
    170643: {"Unified_Ideograph", "Ideographic"},
    170644: {"Unified_Ideograph", "Ideographic"},
    170645: {"Unified_Ideograph", "Ideographic"},
    170646: {"Unified_Ideograph", "Ideographic"},
    170647: {"Unified_Ideograph", "Ideographic"},
    170648: {"Unified_Ideograph", "Ideographic"},
    170649: {"Unified_Ideograph", "Ideographic"},
    170650: {"Unified_Ideograph", "Ideographic"},
    170651: {"Unified_Ideograph", "Ideographic"},
    170652: {"Unified_Ideograph", "Ideographic"},
    170653: {"Unified_Ideograph", "Ideographic"},
    170654: {"Unified_Ideograph", "Ideographic"},
    170655: {"Unified_Ideograph", "Ideographic"},
    170656: {"Unified_Ideograph", "Ideographic"},
    170657: {"Unified_Ideograph", "Ideographic"},
    170658: {"Unified_Ideograph", "Ideographic"},
    170659: {"Unified_Ideograph", "Ideographic"},
    170660: {"Unified_Ideograph", "Ideographic"},
    170661: {"Unified_Ideograph", "Ideographic"},
    170662: {"Unified_Ideograph", "Ideographic"},
    170663: {"Unified_Ideograph", "Ideographic"},
    170664: {"Unified_Ideograph", "Ideographic"},
    170665: {"Unified_Ideograph", "Ideographic"},
    170666: {"Unified_Ideograph", "Ideographic"},
    170667: {"Unified_Ideograph", "Ideographic"},
    170668: {"Unified_Ideograph", "Ideographic"},
    170669: {"Unified_Ideograph", "Ideographic"},
    170670: {"Unified_Ideograph", "Ideographic"},
    170671: {"Unified_Ideograph", "Ideographic"},
    170672: {"Unified_Ideograph", "Ideographic"},
    170673: {"Unified_Ideograph", "Ideographic"},
    170674: {"Unified_Ideograph", "Ideographic"},
    170675: {"Unified_Ideograph", "Ideographic"},
    170676: {"Unified_Ideograph", "Ideographic"},
    170677: {"Unified_Ideograph", "Ideographic"},
    170678: {"Unified_Ideograph", "Ideographic"},
    170679: {"Unified_Ideograph", "Ideographic"},
    170680: {"Unified_Ideograph", "Ideographic"},
    170681: {"Unified_Ideograph", "Ideographic"},
    170682: {"Unified_Ideograph", "Ideographic"},
    170683: {"Unified_Ideograph", "Ideographic"},
    170684: {"Unified_Ideograph", "Ideographic"},
    170685: {"Unified_Ideograph", "Ideographic"},
    170686: {"Unified_Ideograph", "Ideographic"},
    170687: {"Unified_Ideograph", "Ideographic"},
    170688: {"Unified_Ideograph", "Ideographic"},
    170689: {"Unified_Ideograph", "Ideographic"},
    170690: {"Unified_Ideograph", "Ideographic"},
    170691: {"Unified_Ideograph", "Ideographic"},
    170692: {"Unified_Ideograph", "Ideographic"},
    170693: {"Unified_Ideograph", "Ideographic"},
    170694: {"Unified_Ideograph", "Ideographic"},
    170695: {"Unified_Ideograph", "Ideographic"},
    170696: {"Unified_Ideograph", "Ideographic"},
    170697: {"Unified_Ideograph", "Ideographic"},
    170698: {"Unified_Ideograph", "Ideographic"},
    170699: {"Unified_Ideograph", "Ideographic"},
    170700: {"Unified_Ideograph", "Ideographic"},
    170701: {"Unified_Ideograph", "Ideographic"},
    170702: {"Unified_Ideograph", "Ideographic"},
    170703: {"Unified_Ideograph", "Ideographic"},
    170704: {"Unified_Ideograph", "Ideographic"},
    170705: {"Unified_Ideograph", "Ideographic"},
    170706: {"Unified_Ideograph", "Ideographic"},
    170707: {"Unified_Ideograph", "Ideographic"},
    170708: {"Unified_Ideograph", "Ideographic"},
    170709: {"Unified_Ideograph", "Ideographic"},
    170710: {"Unified_Ideograph", "Ideographic"},
    170711: {"Unified_Ideograph", "Ideographic"},
    170712: {"Unified_Ideograph", "Ideographic"},
    170713: {"Unified_Ideograph", "Ideographic"},
    170714: {"Unified_Ideograph", "Ideographic"},
    170715: {"Unified_Ideograph", "Ideographic"},
    170716: {"Unified_Ideograph", "Ideographic"},
    170717: {"Unified_Ideograph", "Ideographic"},
    170718: {"Unified_Ideograph", "Ideographic"},
    170719: {"Unified_Ideograph", "Ideographic"},
    170720: {"Unified_Ideograph", "Ideographic"},
    170721: {"Unified_Ideograph", "Ideographic"},
    170722: {"Unified_Ideograph", "Ideographic"},
    170723: {"Unified_Ideograph", "Ideographic"},
    170724: {"Unified_Ideograph", "Ideographic"},
    170725: {"Unified_Ideograph", "Ideographic"},
    170726: {"Unified_Ideograph", "Ideographic"},
    170727: {"Unified_Ideograph", "Ideographic"},
    170728: {"Unified_Ideograph", "Ideographic"},
    170729: {"Unified_Ideograph", "Ideographic"},
    170730: {"Unified_Ideograph", "Ideographic"},
    170731: {"Unified_Ideograph", "Ideographic"},
    170732: {"Unified_Ideograph", "Ideographic"},
    170733: {"Unified_Ideograph", "Ideographic"},
    170734: {"Unified_Ideograph", "Ideographic"},
    170735: {"Unified_Ideograph", "Ideographic"},
    170736: {"Unified_Ideograph", "Ideographic"},
    170737: {"Unified_Ideograph", "Ideographic"},
    170738: {"Unified_Ideograph", "Ideographic"},
    170739: {"Unified_Ideograph", "Ideographic"},
    170740: {"Unified_Ideograph", "Ideographic"},
    170741: {"Unified_Ideograph", "Ideographic"},
    170742: {"Unified_Ideograph", "Ideographic"},
    170743: {"Unified_Ideograph", "Ideographic"},
    170744: {"Unified_Ideograph", "Ideographic"},
    170745: {"Unified_Ideograph", "Ideographic"},
    170746: {"Unified_Ideograph", "Ideographic"},
    170747: {"Unified_Ideograph", "Ideographic"},
    170748: {"Unified_Ideograph", "Ideographic"},
    170749: {"Unified_Ideograph", "Ideographic"},
    170750: {"Unified_Ideograph", "Ideographic"},
    170751: {"Unified_Ideograph", "Ideographic"},
    170752: {"Unified_Ideograph", "Ideographic"},
    170753: {"Unified_Ideograph", "Ideographic"},
    170754: {"Unified_Ideograph", "Ideographic"},
    170755: {"Unified_Ideograph", "Ideographic"},
    170756: {"Unified_Ideograph", "Ideographic"},
    170757: {"Unified_Ideograph", "Ideographic"},
    170758: {"Unified_Ideograph", "Ideographic"},
    170759: {"Unified_Ideograph", "Ideographic"},
    170760: {"Unified_Ideograph", "Ideographic"},
    170761: {"Unified_Ideograph", "Ideographic"},
    170762: {"Unified_Ideograph", "Ideographic"},
    170763: {"Unified_Ideograph", "Ideographic"},
    170764: {"Unified_Ideograph", "Ideographic"},
    170765: {"Unified_Ideograph", "Ideographic"},
    170766: {"Unified_Ideograph", "Ideographic"},
    170767: {"Unified_Ideograph", "Ideographic"},
    170768: {"Unified_Ideograph", "Ideographic"},
    170769: {"Unified_Ideograph", "Ideographic"},
    170770: {"Unified_Ideograph", "Ideographic"},
    170771: {"Unified_Ideograph", "Ideographic"},
    170772: {"Unified_Ideograph", "Ideographic"},
    170773: {"Unified_Ideograph", "Ideographic"},
    170774: {"Unified_Ideograph", "Ideographic"},
    170775: {"Unified_Ideograph", "Ideographic"},
    170776: {"Unified_Ideograph", "Ideographic"},
    170777: {"Unified_Ideograph", "Ideographic"},
    170778: {"Unified_Ideograph", "Ideographic"},
    170779: {"Unified_Ideograph", "Ideographic"},
    170780: {"Unified_Ideograph", "Ideographic"},
    170781: {"Unified_Ideograph", "Ideographic"},
    170782: {"Unified_Ideograph", "Ideographic"},
    170783: {"Unified_Ideograph", "Ideographic"},
    170784: {"Unified_Ideograph", "Ideographic"},
    170785: {"Unified_Ideograph", "Ideographic"},
    170786: {"Unified_Ideograph", "Ideographic"},
    170787: {"Unified_Ideograph", "Ideographic"},
    170788: {"Unified_Ideograph", "Ideographic"},
    170789: {"Unified_Ideograph", "Ideographic"},
    170790: {"Unified_Ideograph", "Ideographic"},
    170791: {"Unified_Ideograph", "Ideographic"},
    170792: {"Unified_Ideograph", "Ideographic"},
    170793: {"Unified_Ideograph", "Ideographic"},
    170794: {"Unified_Ideograph", "Ideographic"},
    170795: {"Unified_Ideograph", "Ideographic"},
    170796: {"Unified_Ideograph", "Ideographic"},
    170797: {"Unified_Ideograph", "Ideographic"},
    170798: {"Unified_Ideograph", "Ideographic"},
    170799: {"Unified_Ideograph", "Ideographic"},
    170800: {"Unified_Ideograph", "Ideographic"},
    170801: {"Unified_Ideograph", "Ideographic"},
    170802: {"Unified_Ideograph", "Ideographic"},
    170803: {"Unified_Ideograph", "Ideographic"},
    170804: {"Unified_Ideograph", "Ideographic"},
    170805: {"Unified_Ideograph", "Ideographic"},
    170806: {"Unified_Ideograph", "Ideographic"},
    170807: {"Unified_Ideograph", "Ideographic"},
    170808: {"Unified_Ideograph", "Ideographic"},
    170809: {"Unified_Ideograph", "Ideographic"},
    170810: {"Unified_Ideograph", "Ideographic"},
    170811: {"Unified_Ideograph", "Ideographic"},
    170812: {"Unified_Ideograph", "Ideographic"},
    170813: {"Unified_Ideograph", "Ideographic"},
    170814: {"Unified_Ideograph", "Ideographic"},
    170815: {"Unified_Ideograph", "Ideographic"},
    170816: {"Unified_Ideograph", "Ideographic"},
    170817: {"Unified_Ideograph", "Ideographic"},
    170818: {"Unified_Ideograph", "Ideographic"},
    170819: {"Unified_Ideograph", "Ideographic"},
    170820: {"Unified_Ideograph", "Ideographic"},
    170821: {"Unified_Ideograph", "Ideographic"},
    170822: {"Unified_Ideograph", "Ideographic"},
    170823: {"Unified_Ideograph", "Ideographic"},
    170824: {"Unified_Ideograph", "Ideographic"},
    170825: {"Unified_Ideograph", "Ideographic"},
    170826: {"Unified_Ideograph", "Ideographic"},
    170827: {"Unified_Ideograph", "Ideographic"},
    170828: {"Unified_Ideograph", "Ideographic"},
    170829: {"Unified_Ideograph", "Ideographic"},
    170830: {"Unified_Ideograph", "Ideographic"},
    170831: {"Unified_Ideograph", "Ideographic"},
    170832: {"Unified_Ideograph", "Ideographic"},
    170833: {"Unified_Ideograph", "Ideographic"},
    170834: {"Unified_Ideograph", "Ideographic"},
    170835: {"Unified_Ideograph", "Ideographic"},
    170836: {"Unified_Ideograph", "Ideographic"},
    170837: {"Unified_Ideograph", "Ideographic"},
    170838: {"Unified_Ideograph", "Ideographic"},
    170839: {"Unified_Ideograph", "Ideographic"},
    170840: {"Unified_Ideograph", "Ideographic"},
    170841: {"Unified_Ideograph", "Ideographic"},
    170842: {"Unified_Ideograph", "Ideographic"},
    170843: {"Unified_Ideograph", "Ideographic"},
    170844: {"Unified_Ideograph", "Ideographic"},
    170845: {"Unified_Ideograph", "Ideographic"},
    170846: {"Unified_Ideograph", "Ideographic"},
    170847: {"Unified_Ideograph", "Ideographic"},
    170848: {"Unified_Ideograph", "Ideographic"},
    170849: {"Unified_Ideograph", "Ideographic"},
    170850: {"Unified_Ideograph", "Ideographic"},
    170851: {"Unified_Ideograph", "Ideographic"},
    170852: {"Unified_Ideograph", "Ideographic"},
    170853: {"Unified_Ideograph", "Ideographic"},
    170854: {"Unified_Ideograph", "Ideographic"},
    170855: {"Unified_Ideograph", "Ideographic"},
    170856: {"Unified_Ideograph", "Ideographic"},
    170857: {"Unified_Ideograph", "Ideographic"},
    170858: {"Unified_Ideograph", "Ideographic"},
    170859: {"Unified_Ideograph", "Ideographic"},
    170860: {"Unified_Ideograph", "Ideographic"},
    170861: {"Unified_Ideograph", "Ideographic"},
    170862: {"Unified_Ideograph", "Ideographic"},
    170863: {"Unified_Ideograph", "Ideographic"},
    170864: {"Unified_Ideograph", "Ideographic"},
    170865: {"Unified_Ideograph", "Ideographic"},
    170866: {"Unified_Ideograph", "Ideographic"},
    170867: {"Unified_Ideograph", "Ideographic"},
    170868: {"Unified_Ideograph", "Ideographic"},
    170869: {"Unified_Ideograph", "Ideographic"},
    170870: {"Unified_Ideograph", "Ideographic"},
    170871: {"Unified_Ideograph", "Ideographic"},
    170872: {"Unified_Ideograph", "Ideographic"},
    170873: {"Unified_Ideograph", "Ideographic"},
    170874: {"Unified_Ideograph", "Ideographic"},
    170875: {"Unified_Ideograph", "Ideographic"},
    170876: {"Unified_Ideograph", "Ideographic"},
    170877: {"Unified_Ideograph", "Ideographic"},
    170878: {"Unified_Ideograph", "Ideographic"},
    170879: {"Unified_Ideograph", "Ideographic"},
    170880: {"Unified_Ideograph", "Ideographic"},
    170881: {"Unified_Ideograph", "Ideographic"},
    170882: {"Unified_Ideograph", "Ideographic"},
    170883: {"Unified_Ideograph", "Ideographic"},
    170884: {"Unified_Ideograph", "Ideographic"},
    170885: {"Unified_Ideograph", "Ideographic"},
    170886: {"Unified_Ideograph", "Ideographic"},
    170887: {"Unified_Ideograph", "Ideographic"},
    170888: {"Unified_Ideograph", "Ideographic"},
    170889: {"Unified_Ideograph", "Ideographic"},
    170890: {"Unified_Ideograph", "Ideographic"},
    170891: {"Unified_Ideograph", "Ideographic"},
    170892: {"Unified_Ideograph", "Ideographic"},
    170893: {"Unified_Ideograph", "Ideographic"},
    170894: {"Unified_Ideograph", "Ideographic"},
    170895: {"Unified_Ideograph", "Ideographic"},
    170896: {"Unified_Ideograph", "Ideographic"},
    170897: {"Unified_Ideograph", "Ideographic"},
    170898: {"Unified_Ideograph", "Ideographic"},
    170899: {"Unified_Ideograph", "Ideographic"},
    170900: {"Unified_Ideograph", "Ideographic"},
    170901: {"Unified_Ideograph", "Ideographic"},
    170902: {"Unified_Ideograph", "Ideographic"},
    170903: {"Unified_Ideograph", "Ideographic"},
    170904: {"Unified_Ideograph", "Ideographic"},
    170905: {"Unified_Ideograph", "Ideographic"},
    170906: {"Unified_Ideograph", "Ideographic"},
    170907: {"Unified_Ideograph", "Ideographic"},
    170908: {"Unified_Ideograph", "Ideographic"},
    170909: {"Unified_Ideograph", "Ideographic"},
    170910: {"Unified_Ideograph", "Ideographic"},
    170911: {"Unified_Ideograph", "Ideographic"},
    170912: {"Unified_Ideograph", "Ideographic"},
    170913: {"Unified_Ideograph", "Ideographic"},
    170914: {"Unified_Ideograph", "Ideographic"},
    170915: {"Unified_Ideograph", "Ideographic"},
    170916: {"Unified_Ideograph", "Ideographic"},
    170917: {"Unified_Ideograph", "Ideographic"},
    170918: {"Unified_Ideograph", "Ideographic"},
    170919: {"Unified_Ideograph", "Ideographic"},
    170920: {"Unified_Ideograph", "Ideographic"},
    170921: {"Unified_Ideograph", "Ideographic"},
    170922: {"Unified_Ideograph", "Ideographic"},
    170923: {"Unified_Ideograph", "Ideographic"},
    170924: {"Unified_Ideograph", "Ideographic"},
    170925: {"Unified_Ideograph", "Ideographic"},
    170926: {"Unified_Ideograph", "Ideographic"},
    170927: {"Unified_Ideograph", "Ideographic"},
    170928: {"Unified_Ideograph", "Ideographic"},
    170929: {"Unified_Ideograph", "Ideographic"},
    170930: {"Unified_Ideograph", "Ideographic"},
    170931: {"Unified_Ideograph", "Ideographic"},
    170932: {"Unified_Ideograph", "Ideographic"},
    170933: {"Unified_Ideograph", "Ideographic"},
    170934: {"Unified_Ideograph", "Ideographic"},
    170935: {"Unified_Ideograph", "Ideographic"},
    170936: {"Unified_Ideograph", "Ideographic"},
    170937: {"Unified_Ideograph", "Ideographic"},
    170938: {"Unified_Ideograph", "Ideographic"},
    170939: {"Unified_Ideograph", "Ideographic"},
    170940: {"Unified_Ideograph", "Ideographic"},
    170941: {"Unified_Ideograph", "Ideographic"},
    170942: {"Unified_Ideograph", "Ideographic"},
    170943: {"Unified_Ideograph", "Ideographic"},
    170944: {"Unified_Ideograph", "Ideographic"},
    170945: {"Unified_Ideograph", "Ideographic"},
    170946: {"Unified_Ideograph", "Ideographic"},
    170947: {"Unified_Ideograph", "Ideographic"},
    170948: {"Unified_Ideograph", "Ideographic"},
    170949: {"Unified_Ideograph", "Ideographic"},
    170950: {"Unified_Ideograph", "Ideographic"},
    170951: {"Unified_Ideograph", "Ideographic"},
    170952: {"Unified_Ideograph", "Ideographic"},
    170953: {"Unified_Ideograph", "Ideographic"},
    170954: {"Unified_Ideograph", "Ideographic"},
    170955: {"Unified_Ideograph", "Ideographic"},
    170956: {"Unified_Ideograph", "Ideographic"},
    170957: {"Unified_Ideograph", "Ideographic"},
    170958: {"Unified_Ideograph", "Ideographic"},
    170959: {"Unified_Ideograph", "Ideographic"},
    170960: {"Unified_Ideograph", "Ideographic"},
    170961: {"Unified_Ideograph", "Ideographic"},
    170962: {"Unified_Ideograph", "Ideographic"},
    170963: {"Unified_Ideograph", "Ideographic"},
    170964: {"Unified_Ideograph", "Ideographic"},
    170965: {"Unified_Ideograph", "Ideographic"},
    170966: {"Unified_Ideograph", "Ideographic"},
    170967: {"Unified_Ideograph", "Ideographic"},
    170968: {"Unified_Ideograph", "Ideographic"},
    170969: {"Unified_Ideograph", "Ideographic"},
    170970: {"Unified_Ideograph", "Ideographic"},
    170971: {"Unified_Ideograph", "Ideographic"},
    170972: {"Unified_Ideograph", "Ideographic"},
    170973: {"Unified_Ideograph", "Ideographic"},
    170974: {"Unified_Ideograph", "Ideographic"},
    170975: {"Unified_Ideograph", "Ideographic"},
    170976: {"Unified_Ideograph", "Ideographic"},
    170977: {"Unified_Ideograph", "Ideographic"},
    170978: {"Unified_Ideograph", "Ideographic"},
    170979: {"Unified_Ideograph", "Ideographic"},
    170980: {"Unified_Ideograph", "Ideographic"},
    170981: {"Unified_Ideograph", "Ideographic"},
    170982: {"Unified_Ideograph", "Ideographic"},
    170983: {"Unified_Ideograph", "Ideographic"},
    170984: {"Unified_Ideograph", "Ideographic"},
    170985: {"Unified_Ideograph", "Ideographic"},
    170986: {"Unified_Ideograph", "Ideographic"},
    170987: {"Unified_Ideograph", "Ideographic"},
    170988: {"Unified_Ideograph", "Ideographic"},
    170989: {"Unified_Ideograph", "Ideographic"},
    170990: {"Unified_Ideograph", "Ideographic"},
    170991: {"Unified_Ideograph", "Ideographic"},
    170992: {"Unified_Ideograph", "Ideographic"},
    170993: {"Unified_Ideograph", "Ideographic"},
    170994: {"Unified_Ideograph", "Ideographic"},
    170995: {"Unified_Ideograph", "Ideographic"},
    170996: {"Unified_Ideograph", "Ideographic"},
    170997: {"Unified_Ideograph", "Ideographic"},
    170998: {"Unified_Ideograph", "Ideographic"},
    170999: {"Unified_Ideograph", "Ideographic"},
    171000: {"Unified_Ideograph", "Ideographic"},
    171001: {"Unified_Ideograph", "Ideographic"},
    171002: {"Unified_Ideograph", "Ideographic"},
    171003: {"Unified_Ideograph", "Ideographic"},
    171004: {"Unified_Ideograph", "Ideographic"},
    171005: {"Unified_Ideograph", "Ideographic"},
    171006: {"Unified_Ideograph", "Ideographic"},
    171007: {"Unified_Ideograph", "Ideographic"},
    171008: {"Unified_Ideograph", "Ideographic"},
    171009: {"Unified_Ideograph", "Ideographic"},
    171010: {"Unified_Ideograph", "Ideographic"},
    171011: {"Unified_Ideograph", "Ideographic"},
    171012: {"Unified_Ideograph", "Ideographic"},
    171013: {"Unified_Ideograph", "Ideographic"},
    171014: {"Unified_Ideograph", "Ideographic"},
    171015: {"Unified_Ideograph", "Ideographic"},
    171016: {"Unified_Ideograph", "Ideographic"},
    171017: {"Unified_Ideograph", "Ideographic"},
    171018: {"Unified_Ideograph", "Ideographic"},
    171019: {"Unified_Ideograph", "Ideographic"},
    171020: {"Unified_Ideograph", "Ideographic"},
    171021: {"Unified_Ideograph", "Ideographic"},
    171022: {"Unified_Ideograph", "Ideographic"},
    171023: {"Unified_Ideograph", "Ideographic"},
    171024: {"Unified_Ideograph", "Ideographic"},
    171025: {"Unified_Ideograph", "Ideographic"},
    171026: {"Unified_Ideograph", "Ideographic"},
    171027: {"Unified_Ideograph", "Ideographic"},
    171028: {"Unified_Ideograph", "Ideographic"},
    171029: {"Unified_Ideograph", "Ideographic"},
    171030: {"Unified_Ideograph", "Ideographic"},
    171031: {"Unified_Ideograph", "Ideographic"},
    171032: {"Unified_Ideograph", "Ideographic"},
    171033: {"Unified_Ideograph", "Ideographic"},
    171034: {"Unified_Ideograph", "Ideographic"},
    171035: {"Unified_Ideograph", "Ideographic"},
    171036: {"Unified_Ideograph", "Ideographic"},
    171037: {"Unified_Ideograph", "Ideographic"},
    171038: {"Unified_Ideograph", "Ideographic"},
    171039: {"Unified_Ideograph", "Ideographic"},
    171040: {"Unified_Ideograph", "Ideographic"},
    171041: {"Unified_Ideograph", "Ideographic"},
    171042: {"Unified_Ideograph", "Ideographic"},
    171043: {"Unified_Ideograph", "Ideographic"},
    171044: {"Unified_Ideograph", "Ideographic"},
    171045: {"Unified_Ideograph", "Ideographic"},
    171046: {"Unified_Ideograph", "Ideographic"},
    171047: {"Unified_Ideograph", "Ideographic"},
    171048: {"Unified_Ideograph", "Ideographic"},
    171049: {"Unified_Ideograph", "Ideographic"},
    171050: {"Unified_Ideograph", "Ideographic"},
    171051: {"Unified_Ideograph", "Ideographic"},
    171052: {"Unified_Ideograph", "Ideographic"},
    171053: {"Unified_Ideograph", "Ideographic"},
    171054: {"Unified_Ideograph", "Ideographic"},
    171055: {"Unified_Ideograph", "Ideographic"},
    171056: {"Unified_Ideograph", "Ideographic"},
    171057: {"Unified_Ideograph", "Ideographic"},
    171058: {"Unified_Ideograph", "Ideographic"},
    171059: {"Unified_Ideograph", "Ideographic"},
    171060: {"Unified_Ideograph", "Ideographic"},
    171061: {"Unified_Ideograph", "Ideographic"},
    171062: {"Unified_Ideograph", "Ideographic"},
    171063: {"Unified_Ideograph", "Ideographic"},
    171064: {"Unified_Ideograph", "Ideographic"},
    171065: {"Unified_Ideograph", "Ideographic"},
    171066: {"Unified_Ideograph", "Ideographic"},
    171067: {"Unified_Ideograph", "Ideographic"},
    171068: {"Unified_Ideograph", "Ideographic"},
    171069: {"Unified_Ideograph", "Ideographic"},
    171070: {"Unified_Ideograph", "Ideographic"},
    171071: {"Unified_Ideograph", "Ideographic"},
    171072: {"Unified_Ideograph", "Ideographic"},
    171073: {"Unified_Ideograph", "Ideographic"},
    171074: {"Unified_Ideograph", "Ideographic"},
    171075: {"Unified_Ideograph", "Ideographic"},
    171076: {"Unified_Ideograph", "Ideographic"},
    171077: {"Unified_Ideograph", "Ideographic"},
    171078: {"Unified_Ideograph", "Ideographic"},
    171079: {"Unified_Ideograph", "Ideographic"},
    171080: {"Unified_Ideograph", "Ideographic"},
    171081: {"Unified_Ideograph", "Ideographic"},
    171082: {"Unified_Ideograph", "Ideographic"},
    171083: {"Unified_Ideograph", "Ideographic"},
    171084: {"Unified_Ideograph", "Ideographic"},
    171085: {"Unified_Ideograph", "Ideographic"},
    171086: {"Unified_Ideograph", "Ideographic"},
    171087: {"Unified_Ideograph", "Ideographic"},
    171088: {"Unified_Ideograph", "Ideographic"},
    171089: {"Unified_Ideograph", "Ideographic"},
    171090: {"Unified_Ideograph", "Ideographic"},
    171091: {"Unified_Ideograph", "Ideographic"},
    171092: {"Unified_Ideograph", "Ideographic"},
    171093: {"Unified_Ideograph", "Ideographic"},
    171094: {"Unified_Ideograph", "Ideographic"},
    171095: {"Unified_Ideograph", "Ideographic"},
    171096: {"Unified_Ideograph", "Ideographic"},
    171097: {"Unified_Ideograph", "Ideographic"},
    171098: {"Unified_Ideograph", "Ideographic"},
    171099: {"Unified_Ideograph", "Ideographic"},
    171100: {"Unified_Ideograph", "Ideographic"},
    171101: {"Unified_Ideograph", "Ideographic"},
    171102: {"Unified_Ideograph", "Ideographic"},
    171103: {"Unified_Ideograph", "Ideographic"},
    171104: {"Unified_Ideograph", "Ideographic"},
    171105: {"Unified_Ideograph", "Ideographic"},
    171106: {"Unified_Ideograph", "Ideographic"},
    171107: {"Unified_Ideograph", "Ideographic"},
    171108: {"Unified_Ideograph", "Ideographic"},
    171109: {"Unified_Ideograph", "Ideographic"},
    171110: {"Unified_Ideograph", "Ideographic"},
    171111: {"Unified_Ideograph", "Ideographic"},
    171112: {"Unified_Ideograph", "Ideographic"},
    171113: {"Unified_Ideograph", "Ideographic"},
    171114: {"Unified_Ideograph", "Ideographic"},
    171115: {"Unified_Ideograph", "Ideographic"},
    171116: {"Unified_Ideograph", "Ideographic"},
    171117: {"Unified_Ideograph", "Ideographic"},
    171118: {"Unified_Ideograph", "Ideographic"},
    171119: {"Unified_Ideograph", "Ideographic"},
    171120: {"Unified_Ideograph", "Ideographic"},
    171121: {"Unified_Ideograph", "Ideographic"},
    171122: {"Unified_Ideograph", "Ideographic"},
    171123: {"Unified_Ideograph", "Ideographic"},
    171124: {"Unified_Ideograph", "Ideographic"},
    171125: {"Unified_Ideograph", "Ideographic"},
    171126: {"Unified_Ideograph", "Ideographic"},
    171127: {"Unified_Ideograph", "Ideographic"},
    171128: {"Unified_Ideograph", "Ideographic"},
    171129: {"Unified_Ideograph", "Ideographic"},
    171130: {"Unified_Ideograph", "Ideographic"},
    171131: {"Unified_Ideograph", "Ideographic"},
    171132: {"Unified_Ideograph", "Ideographic"},
    171133: {"Unified_Ideograph", "Ideographic"},
    171134: {"Unified_Ideograph", "Ideographic"},
    171135: {"Unified_Ideograph", "Ideographic"},
    171136: {"Unified_Ideograph", "Ideographic"},
    171137: {"Unified_Ideograph", "Ideographic"},
    171138: {"Unified_Ideograph", "Ideographic"},
    171139: {"Unified_Ideograph", "Ideographic"},
    171140: {"Unified_Ideograph", "Ideographic"},
    171141: {"Unified_Ideograph", "Ideographic"},
    171142: {"Unified_Ideograph", "Ideographic"},
    171143: {"Unified_Ideograph", "Ideographic"},
    171144: {"Unified_Ideograph", "Ideographic"},
    171145: {"Unified_Ideograph", "Ideographic"},
    171146: {"Unified_Ideograph", "Ideographic"},
    171147: {"Unified_Ideograph", "Ideographic"},
    171148: {"Unified_Ideograph", "Ideographic"},
    171149: {"Unified_Ideograph", "Ideographic"},
    171150: {"Unified_Ideograph", "Ideographic"},
    171151: {"Unified_Ideograph", "Ideographic"},
    171152: {"Unified_Ideograph", "Ideographic"},
    171153: {"Unified_Ideograph", "Ideographic"},
    171154: {"Unified_Ideograph", "Ideographic"},
    171155: {"Unified_Ideograph", "Ideographic"},
    171156: {"Unified_Ideograph", "Ideographic"},
    171157: {"Unified_Ideograph", "Ideographic"},
    171158: {"Unified_Ideograph", "Ideographic"},
    171159: {"Unified_Ideograph", "Ideographic"},
    171160: {"Unified_Ideograph", "Ideographic"},
    171161: {"Unified_Ideograph", "Ideographic"},
    171162: {"Unified_Ideograph", "Ideographic"},
    171163: {"Unified_Ideograph", "Ideographic"},
    171164: {"Unified_Ideograph", "Ideographic"},
    171165: {"Unified_Ideograph", "Ideographic"},
    171166: {"Unified_Ideograph", "Ideographic"},
    171167: {"Unified_Ideograph", "Ideographic"},
    171168: {"Unified_Ideograph", "Ideographic"},
    171169: {"Unified_Ideograph", "Ideographic"},
    171170: {"Unified_Ideograph", "Ideographic"},
    171171: {"Unified_Ideograph", "Ideographic"},
    171172: {"Unified_Ideograph", "Ideographic"},
    171173: {"Unified_Ideograph", "Ideographic"},
    171174: {"Unified_Ideograph", "Ideographic"},
    171175: {"Unified_Ideograph", "Ideographic"},
    171176: {"Unified_Ideograph", "Ideographic"},
    171177: {"Unified_Ideograph", "Ideographic"},
    171178: {"Unified_Ideograph", "Ideographic"},
    171179: {"Unified_Ideograph", "Ideographic"},
    171180: {"Unified_Ideograph", "Ideographic"},
    171181: {"Unified_Ideograph", "Ideographic"},
    171182: {"Unified_Ideograph", "Ideographic"},
    171183: {"Unified_Ideograph", "Ideographic"},
    171184: {"Unified_Ideograph", "Ideographic"},
    171185: {"Unified_Ideograph", "Ideographic"},
    171186: {"Unified_Ideograph", "Ideographic"},
    171187: {"Unified_Ideograph", "Ideographic"},
    171188: {"Unified_Ideograph", "Ideographic"},
    171189: {"Unified_Ideograph", "Ideographic"},
    171190: {"Unified_Ideograph", "Ideographic"},
    171191: {"Unified_Ideograph", "Ideographic"},
    171192: {"Unified_Ideograph", "Ideographic"},
    171193: {"Unified_Ideograph", "Ideographic"},
    171194: {"Unified_Ideograph", "Ideographic"},
    171195: {"Unified_Ideograph", "Ideographic"},
    171196: {"Unified_Ideograph", "Ideographic"},
    171197: {"Unified_Ideograph", "Ideographic"},
    171198: {"Unified_Ideograph", "Ideographic"},
    171199: {"Unified_Ideograph", "Ideographic"},
    171200: {"Unified_Ideograph", "Ideographic"},
    171201: {"Unified_Ideograph", "Ideographic"},
    171202: {"Unified_Ideograph", "Ideographic"},
    171203: {"Unified_Ideograph", "Ideographic"},
    171204: {"Unified_Ideograph", "Ideographic"},
    171205: {"Unified_Ideograph", "Ideographic"},
    171206: {"Unified_Ideograph", "Ideographic"},
    171207: {"Unified_Ideograph", "Ideographic"},
    171208: {"Unified_Ideograph", "Ideographic"},
    171209: {"Unified_Ideograph", "Ideographic"},
    171210: {"Unified_Ideograph", "Ideographic"},
    171211: {"Unified_Ideograph", "Ideographic"},
    171212: {"Unified_Ideograph", "Ideographic"},
    171213: {"Unified_Ideograph", "Ideographic"},
    171214: {"Unified_Ideograph", "Ideographic"},
    171215: {"Unified_Ideograph", "Ideographic"},
    171216: {"Unified_Ideograph", "Ideographic"},
    171217: {"Unified_Ideograph", "Ideographic"},
    171218: {"Unified_Ideograph", "Ideographic"},
    171219: {"Unified_Ideograph", "Ideographic"},
    171220: {"Unified_Ideograph", "Ideographic"},
    171221: {"Unified_Ideograph", "Ideographic"},
    171222: {"Unified_Ideograph", "Ideographic"},
    171223: {"Unified_Ideograph", "Ideographic"},
    171224: {"Unified_Ideograph", "Ideographic"},
    171225: {"Unified_Ideograph", "Ideographic"},
    171226: {"Unified_Ideograph", "Ideographic"},
    171227: {"Unified_Ideograph", "Ideographic"},
    171228: {"Unified_Ideograph", "Ideographic"},
    171229: {"Unified_Ideograph", "Ideographic"},
    171230: {"Unified_Ideograph", "Ideographic"},
    171231: {"Unified_Ideograph", "Ideographic"},
    171232: {"Unified_Ideograph", "Ideographic"},
    171233: {"Unified_Ideograph", "Ideographic"},
    171234: {"Unified_Ideograph", "Ideographic"},
    171235: {"Unified_Ideograph", "Ideographic"},
    171236: {"Unified_Ideograph", "Ideographic"},
    171237: {"Unified_Ideograph", "Ideographic"},
    171238: {"Unified_Ideograph", "Ideographic"},
    171239: {"Unified_Ideograph", "Ideographic"},
    171240: {"Unified_Ideograph", "Ideographic"},
    171241: {"Unified_Ideograph", "Ideographic"},
    171242: {"Unified_Ideograph", "Ideographic"},
    171243: {"Unified_Ideograph", "Ideographic"},
    171244: {"Unified_Ideograph", "Ideographic"},
    171245: {"Unified_Ideograph", "Ideographic"},
    171246: {"Unified_Ideograph", "Ideographic"},
    171247: {"Unified_Ideograph", "Ideographic"},
    171248: {"Unified_Ideograph", "Ideographic"},
    171249: {"Unified_Ideograph", "Ideographic"},
    171250: {"Unified_Ideograph", "Ideographic"},
    171251: {"Unified_Ideograph", "Ideographic"},
    171252: {"Unified_Ideograph", "Ideographic"},
    171253: {"Unified_Ideograph", "Ideographic"},
    171254: {"Unified_Ideograph", "Ideographic"},
    171255: {"Unified_Ideograph", "Ideographic"},
    171256: {"Unified_Ideograph", "Ideographic"},
    171257: {"Unified_Ideograph", "Ideographic"},
    171258: {"Unified_Ideograph", "Ideographic"},
    171259: {"Unified_Ideograph", "Ideographic"},
    171260: {"Unified_Ideograph", "Ideographic"},
    171261: {"Unified_Ideograph", "Ideographic"},
    171262: {"Unified_Ideograph", "Ideographic"},
    171263: {"Unified_Ideograph", "Ideographic"},
    171264: {"Unified_Ideograph", "Ideographic"},
    171265: {"Unified_Ideograph", "Ideographic"},
    171266: {"Unified_Ideograph", "Ideographic"},
    171267: {"Unified_Ideograph", "Ideographic"},
    171268: {"Unified_Ideograph", "Ideographic"},
    171269: {"Unified_Ideograph", "Ideographic"},
    171270: {"Unified_Ideograph", "Ideographic"},
    171271: {"Unified_Ideograph", "Ideographic"},
    171272: {"Unified_Ideograph", "Ideographic"},
    171273: {"Unified_Ideograph", "Ideographic"},
    171274: {"Unified_Ideograph", "Ideographic"},
    171275: {"Unified_Ideograph", "Ideographic"},
    171276: {"Unified_Ideograph", "Ideographic"},
    171277: {"Unified_Ideograph", "Ideographic"},
    171278: {"Unified_Ideograph", "Ideographic"},
    171279: {"Unified_Ideograph", "Ideographic"},
    171280: {"Unified_Ideograph", "Ideographic"},
    171281: {"Unified_Ideograph", "Ideographic"},
    171282: {"Unified_Ideograph", "Ideographic"},
    171283: {"Unified_Ideograph", "Ideographic"},
    171284: {"Unified_Ideograph", "Ideographic"},
    171285: {"Unified_Ideograph", "Ideographic"},
    171286: {"Unified_Ideograph", "Ideographic"},
    171287: {"Unified_Ideograph", "Ideographic"},
    171288: {"Unified_Ideograph", "Ideographic"},
    171289: {"Unified_Ideograph", "Ideographic"},
    171290: {"Unified_Ideograph", "Ideographic"},
    171291: {"Unified_Ideograph", "Ideographic"},
    171292: {"Unified_Ideograph", "Ideographic"},
    171293: {"Unified_Ideograph", "Ideographic"},
    171294: {"Unified_Ideograph", "Ideographic"},
    171295: {"Unified_Ideograph", "Ideographic"},
    171296: {"Unified_Ideograph", "Ideographic"},
    171297: {"Unified_Ideograph", "Ideographic"},
    171298: {"Unified_Ideograph", "Ideographic"},
    171299: {"Unified_Ideograph", "Ideographic"},
    171300: {"Unified_Ideograph", "Ideographic"},
    171301: {"Unified_Ideograph", "Ideographic"},
    171302: {"Unified_Ideograph", "Ideographic"},
    171303: {"Unified_Ideograph", "Ideographic"},
    171304: {"Unified_Ideograph", "Ideographic"},
    171305: {"Unified_Ideograph", "Ideographic"},
    171306: {"Unified_Ideograph", "Ideographic"},
    171307: {"Unified_Ideograph", "Ideographic"},
    171308: {"Unified_Ideograph", "Ideographic"},
    171309: {"Unified_Ideograph", "Ideographic"},
    171310: {"Unified_Ideograph", "Ideographic"},
    171311: {"Unified_Ideograph", "Ideographic"},
    171312: {"Unified_Ideograph", "Ideographic"},
    171313: {"Unified_Ideograph", "Ideographic"},
    171314: {"Unified_Ideograph", "Ideographic"},
    171315: {"Unified_Ideograph", "Ideographic"},
    171316: {"Unified_Ideograph", "Ideographic"},
    171317: {"Unified_Ideograph", "Ideographic"},
    171318: {"Unified_Ideograph", "Ideographic"},
    171319: {"Unified_Ideograph", "Ideographic"},
    171320: {"Unified_Ideograph", "Ideographic"},
    171321: {"Unified_Ideograph", "Ideographic"},
    171322: {"Unified_Ideograph", "Ideographic"},
    171323: {"Unified_Ideograph", "Ideographic"},
    171324: {"Unified_Ideograph", "Ideographic"},
    171325: {"Unified_Ideograph", "Ideographic"},
    171326: {"Unified_Ideograph", "Ideographic"},
    171327: {"Unified_Ideograph", "Ideographic"},
    171328: {"Unified_Ideograph", "Ideographic"},
    171329: {"Unified_Ideograph", "Ideographic"},
    171330: {"Unified_Ideograph", "Ideographic"},
    171331: {"Unified_Ideograph", "Ideographic"},
    171332: {"Unified_Ideograph", "Ideographic"},
    171333: {"Unified_Ideograph", "Ideographic"},
    171334: {"Unified_Ideograph", "Ideographic"},
    171335: {"Unified_Ideograph", "Ideographic"},
    171336: {"Unified_Ideograph", "Ideographic"},
    171337: {"Unified_Ideograph", "Ideographic"},
    171338: {"Unified_Ideograph", "Ideographic"},
    171339: {"Unified_Ideograph", "Ideographic"},
    171340: {"Unified_Ideograph", "Ideographic"},
    171341: {"Unified_Ideograph", "Ideographic"},
    171342: {"Unified_Ideograph", "Ideographic"},
    171343: {"Unified_Ideograph", "Ideographic"},
    171344: {"Unified_Ideograph", "Ideographic"},
    171345: {"Unified_Ideograph", "Ideographic"},
    171346: {"Unified_Ideograph", "Ideographic"},
    171347: {"Unified_Ideograph", "Ideographic"},
    171348: {"Unified_Ideograph", "Ideographic"},
    171349: {"Unified_Ideograph", "Ideographic"},
    171350: {"Unified_Ideograph", "Ideographic"},
    171351: {"Unified_Ideograph", "Ideographic"},
    171352: {"Unified_Ideograph", "Ideographic"},
    171353: {"Unified_Ideograph", "Ideographic"},
    171354: {"Unified_Ideograph", "Ideographic"},
    171355: {"Unified_Ideograph", "Ideographic"},
    171356: {"Unified_Ideograph", "Ideographic"},
    171357: {"Unified_Ideograph", "Ideographic"},
    171358: {"Unified_Ideograph", "Ideographic"},
    171359: {"Unified_Ideograph", "Ideographic"},
    171360: {"Unified_Ideograph", "Ideographic"},
    171361: {"Unified_Ideograph", "Ideographic"},
    171362: {"Unified_Ideograph", "Ideographic"},
    171363: {"Unified_Ideograph", "Ideographic"},
    171364: {"Unified_Ideograph", "Ideographic"},
    171365: {"Unified_Ideograph", "Ideographic"},
    171366: {"Unified_Ideograph", "Ideographic"},
    171367: {"Unified_Ideograph", "Ideographic"},
    171368: {"Unified_Ideograph", "Ideographic"},
    171369: {"Unified_Ideograph", "Ideographic"},
    171370: {"Unified_Ideograph", "Ideographic"},
    171371: {"Unified_Ideograph", "Ideographic"},
    171372: {"Unified_Ideograph", "Ideographic"},
    171373: {"Unified_Ideograph", "Ideographic"},
    171374: {"Unified_Ideograph", "Ideographic"},
    171375: {"Unified_Ideograph", "Ideographic"},
    171376: {"Unified_Ideograph", "Ideographic"},
    171377: {"Unified_Ideograph", "Ideographic"},
    171378: {"Unified_Ideograph", "Ideographic"},
    171379: {"Unified_Ideograph", "Ideographic"},
    171380: {"Unified_Ideograph", "Ideographic"},
    171381: {"Unified_Ideograph", "Ideographic"},
    171382: {"Unified_Ideograph", "Ideographic"},
    171383: {"Unified_Ideograph", "Ideographic"},
    171384: {"Unified_Ideograph", "Ideographic"},
    171385: {"Unified_Ideograph", "Ideographic"},
    171386: {"Unified_Ideograph", "Ideographic"},
    171387: {"Unified_Ideograph", "Ideographic"},
    171388: {"Unified_Ideograph", "Ideographic"},
    171389: {"Unified_Ideograph", "Ideographic"},
    171390: {"Unified_Ideograph", "Ideographic"},
    171391: {"Unified_Ideograph", "Ideographic"},
    171392: {"Unified_Ideograph", "Ideographic"},
    171393: {"Unified_Ideograph", "Ideographic"},
    171394: {"Unified_Ideograph", "Ideographic"},
    171395: {"Unified_Ideograph", "Ideographic"},
    171396: {"Unified_Ideograph", "Ideographic"},
    171397: {"Unified_Ideograph", "Ideographic"},
    171398: {"Unified_Ideograph", "Ideographic"},
    171399: {"Unified_Ideograph", "Ideographic"},
    171400: {"Unified_Ideograph", "Ideographic"},
    171401: {"Unified_Ideograph", "Ideographic"},
    171402: {"Unified_Ideograph", "Ideographic"},
    171403: {"Unified_Ideograph", "Ideographic"},
    171404: {"Unified_Ideograph", "Ideographic"},
    171405: {"Unified_Ideograph", "Ideographic"},
    171406: {"Unified_Ideograph", "Ideographic"},
    171407: {"Unified_Ideograph", "Ideographic"},
    171408: {"Unified_Ideograph", "Ideographic"},
    171409: {"Unified_Ideograph", "Ideographic"},
    171410: {"Unified_Ideograph", "Ideographic"},
    171411: {"Unified_Ideograph", "Ideographic"},
    171412: {"Unified_Ideograph", "Ideographic"},
    171413: {"Unified_Ideograph", "Ideographic"},
    171414: {"Unified_Ideograph", "Ideographic"},
    171415: {"Unified_Ideograph", "Ideographic"},
    171416: {"Unified_Ideograph", "Ideographic"},
    171417: {"Unified_Ideograph", "Ideographic"},
    171418: {"Unified_Ideograph", "Ideographic"},
    171419: {"Unified_Ideograph", "Ideographic"},
    171420: {"Unified_Ideograph", "Ideographic"},
    171421: {"Unified_Ideograph", "Ideographic"},
    171422: {"Unified_Ideograph", "Ideographic"},
    171423: {"Unified_Ideograph", "Ideographic"},
    171424: {"Unified_Ideograph", "Ideographic"},
    171425: {"Unified_Ideograph", "Ideographic"},
    171426: {"Unified_Ideograph", "Ideographic"},
    171427: {"Unified_Ideograph", "Ideographic"},
    171428: {"Unified_Ideograph", "Ideographic"},
    171429: {"Unified_Ideograph", "Ideographic"},
    171430: {"Unified_Ideograph", "Ideographic"},
    171431: {"Unified_Ideograph", "Ideographic"},
    171432: {"Unified_Ideograph", "Ideographic"},
    171433: {"Unified_Ideograph", "Ideographic"},
    171434: {"Unified_Ideograph", "Ideographic"},
    171435: {"Unified_Ideograph", "Ideographic"},
    171436: {"Unified_Ideograph", "Ideographic"},
    171437: {"Unified_Ideograph", "Ideographic"},
    171438: {"Unified_Ideograph", "Ideographic"},
    171439: {"Unified_Ideograph", "Ideographic"},
    171440: {"Unified_Ideograph", "Ideographic"},
    171441: {"Unified_Ideograph", "Ideographic"},
    171442: {"Unified_Ideograph", "Ideographic"},
    171443: {"Unified_Ideograph", "Ideographic"},
    171444: {"Unified_Ideograph", "Ideographic"},
    171445: {"Unified_Ideograph", "Ideographic"},
    171446: {"Unified_Ideograph", "Ideographic"},
    171447: {"Unified_Ideograph", "Ideographic"},
    171448: {"Unified_Ideograph", "Ideographic"},
    171449: {"Unified_Ideograph", "Ideographic"},
    171450: {"Unified_Ideograph", "Ideographic"},
    171451: {"Unified_Ideograph", "Ideographic"},
    171452: {"Unified_Ideograph", "Ideographic"},
    171453: {"Unified_Ideograph", "Ideographic"},
    171454: {"Unified_Ideograph", "Ideographic"},
    171455: {"Unified_Ideograph", "Ideographic"},
    171456: {"Unified_Ideograph", "Ideographic"},
    171457: {"Unified_Ideograph", "Ideographic"},
    171458: {"Unified_Ideograph", "Ideographic"},
    171459: {"Unified_Ideograph", "Ideographic"},
    171460: {"Unified_Ideograph", "Ideographic"},
    171461: {"Unified_Ideograph", "Ideographic"},
    171462: {"Unified_Ideograph", "Ideographic"},
    171463: {"Unified_Ideograph", "Ideographic"},
    171464: {"Unified_Ideograph", "Ideographic"},
    171465: {"Unified_Ideograph", "Ideographic"},
    171466: {"Unified_Ideograph", "Ideographic"},
    171467: {"Unified_Ideograph", "Ideographic"},
    171468: {"Unified_Ideograph", "Ideographic"},
    171469: {"Unified_Ideograph", "Ideographic"},
    171470: {"Unified_Ideograph", "Ideographic"},
    171471: {"Unified_Ideograph", "Ideographic"},
    171472: {"Unified_Ideograph", "Ideographic"},
    171473: {"Unified_Ideograph", "Ideographic"},
    171474: {"Unified_Ideograph", "Ideographic"},
    171475: {"Unified_Ideograph", "Ideographic"},
    171476: {"Unified_Ideograph", "Ideographic"},
    171477: {"Unified_Ideograph", "Ideographic"},
    171478: {"Unified_Ideograph", "Ideographic"},
    171479: {"Unified_Ideograph", "Ideographic"},
    171480: {"Unified_Ideograph", "Ideographic"},
    171481: {"Unified_Ideograph", "Ideographic"},
    171482: {"Unified_Ideograph", "Ideographic"},
    171483: {"Unified_Ideograph", "Ideographic"},
    171484: {"Unified_Ideograph", "Ideographic"},
    171485: {"Unified_Ideograph", "Ideographic"},
    171486: {"Unified_Ideograph", "Ideographic"},
    171487: {"Unified_Ideograph", "Ideographic"},
    171488: {"Unified_Ideograph", "Ideographic"},
    171489: {"Unified_Ideograph", "Ideographic"},
    171490: {"Unified_Ideograph", "Ideographic"},
    171491: {"Unified_Ideograph", "Ideographic"},
    171492: {"Unified_Ideograph", "Ideographic"},
    171493: {"Unified_Ideograph", "Ideographic"},
    171494: {"Unified_Ideograph", "Ideographic"},
    171495: {"Unified_Ideograph", "Ideographic"},
    171496: {"Unified_Ideograph", "Ideographic"},
    171497: {"Unified_Ideograph", "Ideographic"},
    171498: {"Unified_Ideograph", "Ideographic"},
    171499: {"Unified_Ideograph", "Ideographic"},
    171500: {"Unified_Ideograph", "Ideographic"},
    171501: {"Unified_Ideograph", "Ideographic"},
    171502: {"Unified_Ideograph", "Ideographic"},
    171503: {"Unified_Ideograph", "Ideographic"},
    171504: {"Unified_Ideograph", "Ideographic"},
    171505: {"Unified_Ideograph", "Ideographic"},
    171506: {"Unified_Ideograph", "Ideographic"},
    171507: {"Unified_Ideograph", "Ideographic"},
    171508: {"Unified_Ideograph", "Ideographic"},
    171509: {"Unified_Ideograph", "Ideographic"},
    171510: {"Unified_Ideograph", "Ideographic"},
    171511: {"Unified_Ideograph", "Ideographic"},
    171512: {"Unified_Ideograph", "Ideographic"},
    171513: {"Unified_Ideograph", "Ideographic"},
    171514: {"Unified_Ideograph", "Ideographic"},
    171515: {"Unified_Ideograph", "Ideographic"},
    171516: {"Unified_Ideograph", "Ideographic"},
    171517: {"Unified_Ideograph", "Ideographic"},
    171518: {"Unified_Ideograph", "Ideographic"},
    171519: {"Unified_Ideograph", "Ideographic"},
    171520: {"Unified_Ideograph", "Ideographic"},
    171521: {"Unified_Ideograph", "Ideographic"},
    171522: {"Unified_Ideograph", "Ideographic"},
    171523: {"Unified_Ideograph", "Ideographic"},
    171524: {"Unified_Ideograph", "Ideographic"},
    171525: {"Unified_Ideograph", "Ideographic"},
    171526: {"Unified_Ideograph", "Ideographic"},
    171527: {"Unified_Ideograph", "Ideographic"},
    171528: {"Unified_Ideograph", "Ideographic"},
    171529: {"Unified_Ideograph", "Ideographic"},
    171530: {"Unified_Ideograph", "Ideographic"},
    171531: {"Unified_Ideograph", "Ideographic"},
    171532: {"Unified_Ideograph", "Ideographic"},
    171533: {"Unified_Ideograph", "Ideographic"},
    171534: {"Unified_Ideograph", "Ideographic"},
    171535: {"Unified_Ideograph", "Ideographic"},
    171536: {"Unified_Ideograph", "Ideographic"},
    171537: {"Unified_Ideograph", "Ideographic"},
    171538: {"Unified_Ideograph", "Ideographic"},
    171539: {"Unified_Ideograph", "Ideographic"},
    171540: {"Unified_Ideograph", "Ideographic"},
    171541: {"Unified_Ideograph", "Ideographic"},
    171542: {"Unified_Ideograph", "Ideographic"},
    171543: {"Unified_Ideograph", "Ideographic"},
    171544: {"Unified_Ideograph", "Ideographic"},
    171545: {"Unified_Ideograph", "Ideographic"},
    171546: {"Unified_Ideograph", "Ideographic"},
    171547: {"Unified_Ideograph", "Ideographic"},
    171548: {"Unified_Ideograph", "Ideographic"},
    171549: {"Unified_Ideograph", "Ideographic"},
    171550: {"Unified_Ideograph", "Ideographic"},
    171551: {"Unified_Ideograph", "Ideographic"},
    171552: {"Unified_Ideograph", "Ideographic"},
    171553: {"Unified_Ideograph", "Ideographic"},
    171554: {"Unified_Ideograph", "Ideographic"},
    171555: {"Unified_Ideograph", "Ideographic"},
    171556: {"Unified_Ideograph", "Ideographic"},
    171557: {"Unified_Ideograph", "Ideographic"},
    171558: {"Unified_Ideograph", "Ideographic"},
    171559: {"Unified_Ideograph", "Ideographic"},
    171560: {"Unified_Ideograph", "Ideographic"},
    171561: {"Unified_Ideograph", "Ideographic"},
    171562: {"Unified_Ideograph", "Ideographic"},
    171563: {"Unified_Ideograph", "Ideographic"},
    171564: {"Unified_Ideograph", "Ideographic"},
    171565: {"Unified_Ideograph", "Ideographic"},
    171566: {"Unified_Ideograph", "Ideographic"},
    171567: {"Unified_Ideograph", "Ideographic"},
    171568: {"Unified_Ideograph", "Ideographic"},
    171569: {"Unified_Ideograph", "Ideographic"},
    171570: {"Unified_Ideograph", "Ideographic"},
    171571: {"Unified_Ideograph", "Ideographic"},
    171572: {"Unified_Ideograph", "Ideographic"},
    171573: {"Unified_Ideograph", "Ideographic"},
    171574: {"Unified_Ideograph", "Ideographic"},
    171575: {"Unified_Ideograph", "Ideographic"},
    171576: {"Unified_Ideograph", "Ideographic"},
    171577: {"Unified_Ideograph", "Ideographic"},
    171578: {"Unified_Ideograph", "Ideographic"},
    171579: {"Unified_Ideograph", "Ideographic"},
    171580: {"Unified_Ideograph", "Ideographic"},
    171581: {"Unified_Ideograph", "Ideographic"},
    171582: {"Unified_Ideograph", "Ideographic"},
    171583: {"Unified_Ideograph", "Ideographic"},
    171584: {"Unified_Ideograph", "Ideographic"},
    171585: {"Unified_Ideograph", "Ideographic"},
    171586: {"Unified_Ideograph", "Ideographic"},
    171587: {"Unified_Ideograph", "Ideographic"},
    171588: {"Unified_Ideograph", "Ideographic"},
    171589: {"Unified_Ideograph", "Ideographic"},
    171590: {"Unified_Ideograph", "Ideographic"},
    171591: {"Unified_Ideograph", "Ideographic"},
    171592: {"Unified_Ideograph", "Ideographic"},
    171593: {"Unified_Ideograph", "Ideographic"},
    171594: {"Unified_Ideograph", "Ideographic"},
    171595: {"Unified_Ideograph", "Ideographic"},
    171596: {"Unified_Ideograph", "Ideographic"},
    171597: {"Unified_Ideograph", "Ideographic"},
    171598: {"Unified_Ideograph", "Ideographic"},
    171599: {"Unified_Ideograph", "Ideographic"},
    171600: {"Unified_Ideograph", "Ideographic"},
    171601: {"Unified_Ideograph", "Ideographic"},
    171602: {"Unified_Ideograph", "Ideographic"},
    171603: {"Unified_Ideograph", "Ideographic"},
    171604: {"Unified_Ideograph", "Ideographic"},
    171605: {"Unified_Ideograph", "Ideographic"},
    171606: {"Unified_Ideograph", "Ideographic"},
    171607: {"Unified_Ideograph", "Ideographic"},
    171608: {"Unified_Ideograph", "Ideographic"},
    171609: {"Unified_Ideograph", "Ideographic"},
    171610: {"Unified_Ideograph", "Ideographic"},
    171611: {"Unified_Ideograph", "Ideographic"},
    171612: {"Unified_Ideograph", "Ideographic"},
    171613: {"Unified_Ideograph", "Ideographic"},
    171614: {"Unified_Ideograph", "Ideographic"},
    171615: {"Unified_Ideograph", "Ideographic"},
    171616: {"Unified_Ideograph", "Ideographic"},
    171617: {"Unified_Ideograph", "Ideographic"},
    171618: {"Unified_Ideograph", "Ideographic"},
    171619: {"Unified_Ideograph", "Ideographic"},
    171620: {"Unified_Ideograph", "Ideographic"},
    171621: {"Unified_Ideograph", "Ideographic"},
    171622: {"Unified_Ideograph", "Ideographic"},
    171623: {"Unified_Ideograph", "Ideographic"},
    171624: {"Unified_Ideograph", "Ideographic"},
    171625: {"Unified_Ideograph", "Ideographic"},
    171626: {"Unified_Ideograph", "Ideographic"},
    171627: {"Unified_Ideograph", "Ideographic"},
    171628: {"Unified_Ideograph", "Ideographic"},
    171629: {"Unified_Ideograph", "Ideographic"},
    171630: {"Unified_Ideograph", "Ideographic"},
    171631: {"Unified_Ideograph", "Ideographic"},
    171632: {"Unified_Ideograph", "Ideographic"},
    171633: {"Unified_Ideograph", "Ideographic"},
    171634: {"Unified_Ideograph", "Ideographic"},
    171635: {"Unified_Ideograph", "Ideographic"},
    171636: {"Unified_Ideograph", "Ideographic"},
    171637: {"Unified_Ideograph", "Ideographic"},
    171638: {"Unified_Ideograph", "Ideographic"},
    171639: {"Unified_Ideograph", "Ideographic"},
    171640: {"Unified_Ideograph", "Ideographic"},
    171641: {"Unified_Ideograph", "Ideographic"},
    171642: {"Unified_Ideograph", "Ideographic"},
    171643: {"Unified_Ideograph", "Ideographic"},
    171644: {"Unified_Ideograph", "Ideographic"},
    171645: {"Unified_Ideograph", "Ideographic"},
    171646: {"Unified_Ideograph", "Ideographic"},
    171647: {"Unified_Ideograph", "Ideographic"},
    171648: {"Unified_Ideograph", "Ideographic"},
    171649: {"Unified_Ideograph", "Ideographic"},
    171650: {"Unified_Ideograph", "Ideographic"},
    171651: {"Unified_Ideograph", "Ideographic"},
    171652: {"Unified_Ideograph", "Ideographic"},
    171653: {"Unified_Ideograph", "Ideographic"},
    171654: {"Unified_Ideograph", "Ideographic"},
    171655: {"Unified_Ideograph", "Ideographic"},
    171656: {"Unified_Ideograph", "Ideographic"},
    171657: {"Unified_Ideograph", "Ideographic"},
    171658: {"Unified_Ideograph", "Ideographic"},
    171659: {"Unified_Ideograph", "Ideographic"},
    171660: {"Unified_Ideograph", "Ideographic"},
    171661: {"Unified_Ideograph", "Ideographic"},
    171662: {"Unified_Ideograph", "Ideographic"},
    171663: {"Unified_Ideograph", "Ideographic"},
    171664: {"Unified_Ideograph", "Ideographic"},
    171665: {"Unified_Ideograph", "Ideographic"},
    171666: {"Unified_Ideograph", "Ideographic"},
    171667: {"Unified_Ideograph", "Ideographic"},
    171668: {"Unified_Ideograph", "Ideographic"},
    171669: {"Unified_Ideograph", "Ideographic"},
    171670: {"Unified_Ideograph", "Ideographic"},
    171671: {"Unified_Ideograph", "Ideographic"},
    171672: {"Unified_Ideograph", "Ideographic"},
    171673: {"Unified_Ideograph", "Ideographic"},
    171674: {"Unified_Ideograph", "Ideographic"},
    171675: {"Unified_Ideograph", "Ideographic"},
    171676: {"Unified_Ideograph", "Ideographic"},
    171677: {"Unified_Ideograph", "Ideographic"},
    171678: {"Unified_Ideograph", "Ideographic"},
    171679: {"Unified_Ideograph", "Ideographic"},
    171680: {"Unified_Ideograph", "Ideographic"},
    171681: {"Unified_Ideograph", "Ideographic"},
    171682: {"Unified_Ideograph", "Ideographic"},
    171683: {"Unified_Ideograph", "Ideographic"},
    171684: {"Unified_Ideograph", "Ideographic"},
    171685: {"Unified_Ideograph", "Ideographic"},
    171686: {"Unified_Ideograph", "Ideographic"},
    171687: {"Unified_Ideograph", "Ideographic"},
    171688: {"Unified_Ideograph", "Ideographic"},
    171689: {"Unified_Ideograph", "Ideographic"},
    171690: {"Unified_Ideograph", "Ideographic"},
    171691: {"Unified_Ideograph", "Ideographic"},
    171692: {"Unified_Ideograph", "Ideographic"},
    171693: {"Unified_Ideograph", "Ideographic"},
    171694: {"Unified_Ideograph", "Ideographic"},
    171695: {"Unified_Ideograph", "Ideographic"},
    171696: {"Unified_Ideograph", "Ideographic"},
    171697: {"Unified_Ideograph", "Ideographic"},
    171698: {"Unified_Ideograph", "Ideographic"},
    171699: {"Unified_Ideograph", "Ideographic"},
    171700: {"Unified_Ideograph", "Ideographic"},
    171701: {"Unified_Ideograph", "Ideographic"},
    171702: {"Unified_Ideograph", "Ideographic"},
    171703: {"Unified_Ideograph", "Ideographic"},
    171704: {"Unified_Ideograph", "Ideographic"},
    171705: {"Unified_Ideograph", "Ideographic"},
    171706: {"Unified_Ideograph", "Ideographic"},
    171707: {"Unified_Ideograph", "Ideographic"},
    171708: {"Unified_Ideograph", "Ideographic"},
    171709: {"Unified_Ideograph", "Ideographic"},
    171710: {"Unified_Ideograph", "Ideographic"},
    171711: {"Unified_Ideograph", "Ideographic"},
    171712: {"Unified_Ideograph", "Ideographic"},
    171713: {"Unified_Ideograph", "Ideographic"},
    171714: {"Unified_Ideograph", "Ideographic"},
    171715: {"Unified_Ideograph", "Ideographic"},
    171716: {"Unified_Ideograph", "Ideographic"},
    171717: {"Unified_Ideograph", "Ideographic"},
    171718: {"Unified_Ideograph", "Ideographic"},
    171719: {"Unified_Ideograph", "Ideographic"},
    171720: {"Unified_Ideograph", "Ideographic"},
    171721: {"Unified_Ideograph", "Ideographic"},
    171722: {"Unified_Ideograph", "Ideographic"},
    171723: {"Unified_Ideograph", "Ideographic"},
    171724: {"Unified_Ideograph", "Ideographic"},
    171725: {"Unified_Ideograph", "Ideographic"},
    171726: {"Unified_Ideograph", "Ideographic"},
    171727: {"Unified_Ideograph", "Ideographic"},
    171728: {"Unified_Ideograph", "Ideographic"},
    171729: {"Unified_Ideograph", "Ideographic"},
    171730: {"Unified_Ideograph", "Ideographic"},
    171731: {"Unified_Ideograph", "Ideographic"},
    171732: {"Unified_Ideograph", "Ideographic"},
    171733: {"Unified_Ideograph", "Ideographic"},
    171734: {"Unified_Ideograph", "Ideographic"},
    171735: {"Unified_Ideograph", "Ideographic"},
    171736: {"Unified_Ideograph", "Ideographic"},
    171737: {"Unified_Ideograph", "Ideographic"},
    171738: {"Unified_Ideograph", "Ideographic"},
    171739: {"Unified_Ideograph", "Ideographic"},
    171740: {"Unified_Ideograph", "Ideographic"},
    171741: {"Unified_Ideograph", "Ideographic"},
    171742: {"Unified_Ideograph", "Ideographic"},
    171743: {"Unified_Ideograph", "Ideographic"},
    171744: {"Unified_Ideograph", "Ideographic"},
    171745: {"Unified_Ideograph", "Ideographic"},
    171746: {"Unified_Ideograph", "Ideographic"},
    171747: {"Unified_Ideograph", "Ideographic"},
    171748: {"Unified_Ideograph", "Ideographic"},
    171749: {"Unified_Ideograph", "Ideographic"},
    171750: {"Unified_Ideograph", "Ideographic"},
    171751: {"Unified_Ideograph", "Ideographic"},
    171752: {"Unified_Ideograph", "Ideographic"},
    171753: {"Unified_Ideograph", "Ideographic"},
    171754: {"Unified_Ideograph", "Ideographic"},
    171755: {"Unified_Ideograph", "Ideographic"},
    171756: {"Unified_Ideograph", "Ideographic"},
    171757: {"Unified_Ideograph", "Ideographic"},
    171758: {"Unified_Ideograph", "Ideographic"},
    171759: {"Unified_Ideograph", "Ideographic"},
    171760: {"Unified_Ideograph", "Ideographic"},
    171761: {"Unified_Ideograph", "Ideographic"},
    171762: {"Unified_Ideograph", "Ideographic"},
    171763: {"Unified_Ideograph", "Ideographic"},
    171764: {"Unified_Ideograph", "Ideographic"},
    171765: {"Unified_Ideograph", "Ideographic"},
    171766: {"Unified_Ideograph", "Ideographic"},
    171767: {"Unified_Ideograph", "Ideographic"},
    171768: {"Unified_Ideograph", "Ideographic"},
    171769: {"Unified_Ideograph", "Ideographic"},
    171770: {"Unified_Ideograph", "Ideographic"},
    171771: {"Unified_Ideograph", "Ideographic"},
    171772: {"Unified_Ideograph", "Ideographic"},
    171773: {"Unified_Ideograph", "Ideographic"},
    171774: {"Unified_Ideograph", "Ideographic"},
    171775: {"Unified_Ideograph", "Ideographic"},
    171776: {"Unified_Ideograph", "Ideographic"},
    171777: {"Unified_Ideograph", "Ideographic"},
    171778: {"Unified_Ideograph", "Ideographic"},
    171779: {"Unified_Ideograph", "Ideographic"},
    171780: {"Unified_Ideograph", "Ideographic"},
    171781: {"Unified_Ideograph", "Ideographic"},
    171782: {"Unified_Ideograph", "Ideographic"},
    171783: {"Unified_Ideograph", "Ideographic"},
    171784: {"Unified_Ideograph", "Ideographic"},
    171785: {"Unified_Ideograph", "Ideographic"},
    171786: {"Unified_Ideograph", "Ideographic"},
    171787: {"Unified_Ideograph", "Ideographic"},
    171788: {"Unified_Ideograph", "Ideographic"},
    171789: {"Unified_Ideograph", "Ideographic"},
    171790: {"Unified_Ideograph", "Ideographic"},
    171791: {"Unified_Ideograph", "Ideographic"},
    171792: {"Unified_Ideograph", "Ideographic"},
    171793: {"Unified_Ideograph", "Ideographic"},
    171794: {"Unified_Ideograph", "Ideographic"},
    171795: {"Unified_Ideograph", "Ideographic"},
    171796: {"Unified_Ideograph", "Ideographic"},
    171797: {"Unified_Ideograph", "Ideographic"},
    171798: {"Unified_Ideograph", "Ideographic"},
    171799: {"Unified_Ideograph", "Ideographic"},
    171800: {"Unified_Ideograph", "Ideographic"},
    171801: {"Unified_Ideograph", "Ideographic"},
    171802: {"Unified_Ideograph", "Ideographic"},
    171803: {"Unified_Ideograph", "Ideographic"},
    171804: {"Unified_Ideograph", "Ideographic"},
    171805: {"Unified_Ideograph", "Ideographic"},
    171806: {"Unified_Ideograph", "Ideographic"},
    171807: {"Unified_Ideograph", "Ideographic"},
    171808: {"Unified_Ideograph", "Ideographic"},
    171809: {"Unified_Ideograph", "Ideographic"},
    171810: {"Unified_Ideograph", "Ideographic"},
    171811: {"Unified_Ideograph", "Ideographic"},
    171812: {"Unified_Ideograph", "Ideographic"},
    171813: {"Unified_Ideograph", "Ideographic"},
    171814: {"Unified_Ideograph", "Ideographic"},
    171815: {"Unified_Ideograph", "Ideographic"},
    171816: {"Unified_Ideograph", "Ideographic"},
    171817: {"Unified_Ideograph", "Ideographic"},
    171818: {"Unified_Ideograph", "Ideographic"},
    171819: {"Unified_Ideograph", "Ideographic"},
    171820: {"Unified_Ideograph", "Ideographic"},
    171821: {"Unified_Ideograph", "Ideographic"},
    171822: {"Unified_Ideograph", "Ideographic"},
    171823: {"Unified_Ideograph", "Ideographic"},
    171824: {"Unified_Ideograph", "Ideographic"},
    171825: {"Unified_Ideograph", "Ideographic"},
    171826: {"Unified_Ideograph", "Ideographic"},
    171827: {"Unified_Ideograph", "Ideographic"},
    171828: {"Unified_Ideograph", "Ideographic"},
    171829: {"Unified_Ideograph", "Ideographic"},
    171830: {"Unified_Ideograph", "Ideographic"},
    171831: {"Unified_Ideograph", "Ideographic"},
    171832: {"Unified_Ideograph", "Ideographic"},
    171833: {"Unified_Ideograph", "Ideographic"},
    171834: {"Unified_Ideograph", "Ideographic"},
    171835: {"Unified_Ideograph", "Ideographic"},
    171836: {"Unified_Ideograph", "Ideographic"},
    171837: {"Unified_Ideograph", "Ideographic"},
    171838: {"Unified_Ideograph", "Ideographic"},
    171839: {"Unified_Ideograph", "Ideographic"},
    171840: {"Unified_Ideograph", "Ideographic"},
    171841: {"Unified_Ideograph", "Ideographic"},
    171842: {"Unified_Ideograph", "Ideographic"},
    171843: {"Unified_Ideograph", "Ideographic"},
    171844: {"Unified_Ideograph", "Ideographic"},
    171845: {"Unified_Ideograph", "Ideographic"},
    171846: {"Unified_Ideograph", "Ideographic"},
    171847: {"Unified_Ideograph", "Ideographic"},
    171848: {"Unified_Ideograph", "Ideographic"},
    171849: {"Unified_Ideograph", "Ideographic"},
    171850: {"Unified_Ideograph", "Ideographic"},
    171851: {"Unified_Ideograph", "Ideographic"},
    171852: {"Unified_Ideograph", "Ideographic"},
    171853: {"Unified_Ideograph", "Ideographic"},
    171854: {"Unified_Ideograph", "Ideographic"},
    171855: {"Unified_Ideograph", "Ideographic"},
    171856: {"Unified_Ideograph", "Ideographic"},
    171857: {"Unified_Ideograph", "Ideographic"},
    171858: {"Unified_Ideograph", "Ideographic"},
    171859: {"Unified_Ideograph", "Ideographic"},
    171860: {"Unified_Ideograph", "Ideographic"},
    171861: {"Unified_Ideograph", "Ideographic"},
    171862: {"Unified_Ideograph", "Ideographic"},
    171863: {"Unified_Ideograph", "Ideographic"},
    171864: {"Unified_Ideograph", "Ideographic"},
    171865: {"Unified_Ideograph", "Ideographic"},
    171866: {"Unified_Ideograph", "Ideographic"},
    171867: {"Unified_Ideograph", "Ideographic"},
    171868: {"Unified_Ideograph", "Ideographic"},
    171869: {"Unified_Ideograph", "Ideographic"},
    171870: {"Unified_Ideograph", "Ideographic"},
    171871: {"Unified_Ideograph", "Ideographic"},
    171872: {"Unified_Ideograph", "Ideographic"},
    171873: {"Unified_Ideograph", "Ideographic"},
    171874: {"Unified_Ideograph", "Ideographic"},
    171875: {"Unified_Ideograph", "Ideographic"},
    171876: {"Unified_Ideograph", "Ideographic"},
    171877: {"Unified_Ideograph", "Ideographic"},
    171878: {"Unified_Ideograph", "Ideographic"},
    171879: {"Unified_Ideograph", "Ideographic"},
    171880: {"Unified_Ideograph", "Ideographic"},
    171881: {"Unified_Ideograph", "Ideographic"},
    171882: {"Unified_Ideograph", "Ideographic"},
    171883: {"Unified_Ideograph", "Ideographic"},
    171884: {"Unified_Ideograph", "Ideographic"},
    171885: {"Unified_Ideograph", "Ideographic"},
    171886: {"Unified_Ideograph", "Ideographic"},
    171887: {"Unified_Ideograph", "Ideographic"},
    171888: {"Unified_Ideograph", "Ideographic"},
    171889: {"Unified_Ideograph", "Ideographic"},
    171890: {"Unified_Ideograph", "Ideographic"},
    171891: {"Unified_Ideograph", "Ideographic"},
    171892: {"Unified_Ideograph", "Ideographic"},
    171893: {"Unified_Ideograph", "Ideographic"},
    171894: {"Unified_Ideograph", "Ideographic"},
    171895: {"Unified_Ideograph", "Ideographic"},
    171896: {"Unified_Ideograph", "Ideographic"},
    171897: {"Unified_Ideograph", "Ideographic"},
    171898: {"Unified_Ideograph", "Ideographic"},
    171899: {"Unified_Ideograph", "Ideographic"},
    171900: {"Unified_Ideograph", "Ideographic"},
    171901: {"Unified_Ideograph", "Ideographic"},
    171902: {"Unified_Ideograph", "Ideographic"},
    171903: {"Unified_Ideograph", "Ideographic"},
    171904: {"Unified_Ideograph", "Ideographic"},
    171905: {"Unified_Ideograph", "Ideographic"},
    171906: {"Unified_Ideograph", "Ideographic"},
    171907: {"Unified_Ideograph", "Ideographic"},
    171908: {"Unified_Ideograph", "Ideographic"},
    171909: {"Unified_Ideograph", "Ideographic"},
    171910: {"Unified_Ideograph", "Ideographic"},
    171911: {"Unified_Ideograph", "Ideographic"},
    171912: {"Unified_Ideograph", "Ideographic"},
    171913: {"Unified_Ideograph", "Ideographic"},
    171914: {"Unified_Ideograph", "Ideographic"},
    171915: {"Unified_Ideograph", "Ideographic"},
    171916: {"Unified_Ideograph", "Ideographic"},
    171917: {"Unified_Ideograph", "Ideographic"},
    171918: {"Unified_Ideograph", "Ideographic"},
    171919: {"Unified_Ideograph", "Ideographic"},
    171920: {"Unified_Ideograph", "Ideographic"},
    171921: {"Unified_Ideograph", "Ideographic"},
    171922: {"Unified_Ideograph", "Ideographic"},
    171923: {"Unified_Ideograph", "Ideographic"},
    171924: {"Unified_Ideograph", "Ideographic"},
    171925: {"Unified_Ideograph", "Ideographic"},
    171926: {"Unified_Ideograph", "Ideographic"},
    171927: {"Unified_Ideograph", "Ideographic"},
    171928: {"Unified_Ideograph", "Ideographic"},
    171929: {"Unified_Ideograph", "Ideographic"},
    171930: {"Unified_Ideograph", "Ideographic"},
    171931: {"Unified_Ideograph", "Ideographic"},
    171932: {"Unified_Ideograph", "Ideographic"},
    171933: {"Unified_Ideograph", "Ideographic"},
    171934: {"Unified_Ideograph", "Ideographic"},
    171935: {"Unified_Ideograph", "Ideographic"},
    171936: {"Unified_Ideograph", "Ideographic"},
    171937: {"Unified_Ideograph", "Ideographic"},
    171938: {"Unified_Ideograph", "Ideographic"},
    171939: {"Unified_Ideograph", "Ideographic"},
    171940: {"Unified_Ideograph", "Ideographic"},
    171941: {"Unified_Ideograph", "Ideographic"},
    171942: {"Unified_Ideograph", "Ideographic"},
    171943: {"Unified_Ideograph", "Ideographic"},
    171944: {"Unified_Ideograph", "Ideographic"},
    171945: {"Unified_Ideograph", "Ideographic"},
    171946: {"Unified_Ideograph", "Ideographic"},
    171947: {"Unified_Ideograph", "Ideographic"},
    171948: {"Unified_Ideograph", "Ideographic"},
    171949: {"Unified_Ideograph", "Ideographic"},
    171950: {"Unified_Ideograph", "Ideographic"},
    171951: {"Unified_Ideograph", "Ideographic"},
    171952: {"Unified_Ideograph", "Ideographic"},
    171953: {"Unified_Ideograph", "Ideographic"},
    171954: {"Unified_Ideograph", "Ideographic"},
    171955: {"Unified_Ideograph", "Ideographic"},
    171956: {"Unified_Ideograph", "Ideographic"},
    171957: {"Unified_Ideograph", "Ideographic"},
    171958: {"Unified_Ideograph", "Ideographic"},
    171959: {"Unified_Ideograph", "Ideographic"},
    171960: {"Unified_Ideograph", "Ideographic"},
    171961: {"Unified_Ideograph", "Ideographic"},
    171962: {"Unified_Ideograph", "Ideographic"},
    171963: {"Unified_Ideograph", "Ideographic"},
    171964: {"Unified_Ideograph", "Ideographic"},
    171965: {"Unified_Ideograph", "Ideographic"},
    171966: {"Unified_Ideograph", "Ideographic"},
    171967: {"Unified_Ideograph", "Ideographic"},
    171968: {"Unified_Ideograph", "Ideographic"},
    171969: {"Unified_Ideograph", "Ideographic"},
    171970: {"Unified_Ideograph", "Ideographic"},
    171971: {"Unified_Ideograph", "Ideographic"},
    171972: {"Unified_Ideograph", "Ideographic"},
    171973: {"Unified_Ideograph", "Ideographic"},
    171974: {"Unified_Ideograph", "Ideographic"},
    171975: {"Unified_Ideograph", "Ideographic"},
    171976: {"Unified_Ideograph", "Ideographic"},
    171977: {"Unified_Ideograph", "Ideographic"},
    171978: {"Unified_Ideograph", "Ideographic"},
    171979: {"Unified_Ideograph", "Ideographic"},
    171980: {"Unified_Ideograph", "Ideographic"},
    171981: {"Unified_Ideograph", "Ideographic"},
    171982: {"Unified_Ideograph", "Ideographic"},
    171983: {"Unified_Ideograph", "Ideographic"},
    171984: {"Unified_Ideograph", "Ideographic"},
    171985: {"Unified_Ideograph", "Ideographic"},
    171986: {"Unified_Ideograph", "Ideographic"},
    171987: {"Unified_Ideograph", "Ideographic"},
    171988: {"Unified_Ideograph", "Ideographic"},
    171989: {"Unified_Ideograph", "Ideographic"},
    171990: {"Unified_Ideograph", "Ideographic"},
    171991: {"Unified_Ideograph", "Ideographic"},
    171992: {"Unified_Ideograph", "Ideographic"},
    171993: {"Unified_Ideograph", "Ideographic"},
    171994: {"Unified_Ideograph", "Ideographic"},
    171995: {"Unified_Ideograph", "Ideographic"},
    171996: {"Unified_Ideograph", "Ideographic"},
    171997: {"Unified_Ideograph", "Ideographic"},
    171998: {"Unified_Ideograph", "Ideographic"},
    171999: {"Unified_Ideograph", "Ideographic"},
    172000: {"Unified_Ideograph", "Ideographic"},
    172001: {"Unified_Ideograph", "Ideographic"},
    172002: {"Unified_Ideograph", "Ideographic"},
    172003: {"Unified_Ideograph", "Ideographic"},
    172004: {"Unified_Ideograph", "Ideographic"},
    172005: {"Unified_Ideograph", "Ideographic"},
    172006: {"Unified_Ideograph", "Ideographic"},
    172007: {"Unified_Ideograph", "Ideographic"},
    172008: {"Unified_Ideograph", "Ideographic"},
    172009: {"Unified_Ideograph", "Ideographic"},
    172010: {"Unified_Ideograph", "Ideographic"},
    172011: {"Unified_Ideograph", "Ideographic"},
    172012: {"Unified_Ideograph", "Ideographic"},
    172013: {"Unified_Ideograph", "Ideographic"},
    172014: {"Unified_Ideograph", "Ideographic"},
    172015: {"Unified_Ideograph", "Ideographic"},
    172016: {"Unified_Ideograph", "Ideographic"},
    172017: {"Unified_Ideograph", "Ideographic"},
    172018: {"Unified_Ideograph", "Ideographic"},
    172019: {"Unified_Ideograph", "Ideographic"},
    172020: {"Unified_Ideograph", "Ideographic"},
    172021: {"Unified_Ideograph", "Ideographic"},
    172022: {"Unified_Ideograph", "Ideographic"},
    172023: {"Unified_Ideograph", "Ideographic"},
    172024: {"Unified_Ideograph", "Ideographic"},
    172025: {"Unified_Ideograph", "Ideographic"},
    172026: {"Unified_Ideograph", "Ideographic"},
    172027: {"Unified_Ideograph", "Ideographic"},
    172028: {"Unified_Ideograph", "Ideographic"},
    172029: {"Unified_Ideograph", "Ideographic"},
    172030: {"Unified_Ideograph", "Ideographic"},
    172031: {"Unified_Ideograph", "Ideographic"},
    172032: {"Unified_Ideograph", "Ideographic"},
    172033: {"Unified_Ideograph", "Ideographic"},
    172034: {"Unified_Ideograph", "Ideographic"},
    172035: {"Unified_Ideograph", "Ideographic"},
    172036: {"Unified_Ideograph", "Ideographic"},
    172037: {"Unified_Ideograph", "Ideographic"},
    172038: {"Unified_Ideograph", "Ideographic"},
    172039: {"Unified_Ideograph", "Ideographic"},
    172040: {"Unified_Ideograph", "Ideographic"},
    172041: {"Unified_Ideograph", "Ideographic"},
    172042: {"Unified_Ideograph", "Ideographic"},
    172043: {"Unified_Ideograph", "Ideographic"},
    172044: {"Unified_Ideograph", "Ideographic"},
    172045: {"Unified_Ideograph", "Ideographic"},
    172046: {"Unified_Ideograph", "Ideographic"},
    172047: {"Unified_Ideograph", "Ideographic"},
    172048: {"Unified_Ideograph", "Ideographic"},
    172049: {"Unified_Ideograph", "Ideographic"},
    172050: {"Unified_Ideograph", "Ideographic"},
    172051: {"Unified_Ideograph", "Ideographic"},
    172052: {"Unified_Ideograph", "Ideographic"},
    172053: {"Unified_Ideograph", "Ideographic"},
    172054: {"Unified_Ideograph", "Ideographic"},
    172055: {"Unified_Ideograph", "Ideographic"},
    172056: {"Unified_Ideograph", "Ideographic"},
    172057: {"Unified_Ideograph", "Ideographic"},
    172058: {"Unified_Ideograph", "Ideographic"},
    172059: {"Unified_Ideograph", "Ideographic"},
    172060: {"Unified_Ideograph", "Ideographic"},
    172061: {"Unified_Ideograph", "Ideographic"},
    172062: {"Unified_Ideograph", "Ideographic"},
    172063: {"Unified_Ideograph", "Ideographic"},
    172064: {"Unified_Ideograph", "Ideographic"},
    172065: {"Unified_Ideograph", "Ideographic"},
    172066: {"Unified_Ideograph", "Ideographic"},
    172067: {"Unified_Ideograph", "Ideographic"},
    172068: {"Unified_Ideograph", "Ideographic"},
    172069: {"Unified_Ideograph", "Ideographic"},
    172070: {"Unified_Ideograph", "Ideographic"},
    172071: {"Unified_Ideograph", "Ideographic"},
    172072: {"Unified_Ideograph", "Ideographic"},
    172073: {"Unified_Ideograph", "Ideographic"},
    172074: {"Unified_Ideograph", "Ideographic"},
    172075: {"Unified_Ideograph", "Ideographic"},
    172076: {"Unified_Ideograph", "Ideographic"},
    172077: {"Unified_Ideograph", "Ideographic"},
    172078: {"Unified_Ideograph", "Ideographic"},
    172079: {"Unified_Ideograph", "Ideographic"},
    172080: {"Unified_Ideograph", "Ideographic"},
    172081: {"Unified_Ideograph", "Ideographic"},
    172082: {"Unified_Ideograph", "Ideographic"},
    172083: {"Unified_Ideograph", "Ideographic"},
    172084: {"Unified_Ideograph", "Ideographic"},
    172085: {"Unified_Ideograph", "Ideographic"},
    172086: {"Unified_Ideograph", "Ideographic"},
    172087: {"Unified_Ideograph", "Ideographic"},
    172088: {"Unified_Ideograph", "Ideographic"},
    172089: {"Unified_Ideograph", "Ideographic"},
    172090: {"Unified_Ideograph", "Ideographic"},
    172091: {"Unified_Ideograph", "Ideographic"},
    172092: {"Unified_Ideograph", "Ideographic"},
    172093: {"Unified_Ideograph", "Ideographic"},
    172094: {"Unified_Ideograph", "Ideographic"},
    172095: {"Unified_Ideograph", "Ideographic"},
    172096: {"Unified_Ideograph", "Ideographic"},
    172097: {"Unified_Ideograph", "Ideographic"},
    172098: {"Unified_Ideograph", "Ideographic"},
    172099: {"Unified_Ideograph", "Ideographic"},
    172100: {"Unified_Ideograph", "Ideographic"},
    172101: {"Unified_Ideograph", "Ideographic"},
    172102: {"Unified_Ideograph", "Ideographic"},
    172103: {"Unified_Ideograph", "Ideographic"},
    172104: {"Unified_Ideograph", "Ideographic"},
    172105: {"Unified_Ideograph", "Ideographic"},
    172106: {"Unified_Ideograph", "Ideographic"},
    172107: {"Unified_Ideograph", "Ideographic"},
    172108: {"Unified_Ideograph", "Ideographic"},
    172109: {"Unified_Ideograph", "Ideographic"},
    172110: {"Unified_Ideograph", "Ideographic"},
    172111: {"Unified_Ideograph", "Ideographic"},
    172112: {"Unified_Ideograph", "Ideographic"},
    172113: {"Unified_Ideograph", "Ideographic"},
    172114: {"Unified_Ideograph", "Ideographic"},
    172115: {"Unified_Ideograph", "Ideographic"},
    172116: {"Unified_Ideograph", "Ideographic"},
    172117: {"Unified_Ideograph", "Ideographic"},
    172118: {"Unified_Ideograph", "Ideographic"},
    172119: {"Unified_Ideograph", "Ideographic"},
    172120: {"Unified_Ideograph", "Ideographic"},
    172121: {"Unified_Ideograph", "Ideographic"},
    172122: {"Unified_Ideograph", "Ideographic"},
    172123: {"Unified_Ideograph", "Ideographic"},
    172124: {"Unified_Ideograph", "Ideographic"},
    172125: {"Unified_Ideograph", "Ideographic"},
    172126: {"Unified_Ideograph", "Ideographic"},
    172127: {"Unified_Ideograph", "Ideographic"},
    172128: {"Unified_Ideograph", "Ideographic"},
    172129: {"Unified_Ideograph", "Ideographic"},
    172130: {"Unified_Ideograph", "Ideographic"},
    172131: {"Unified_Ideograph", "Ideographic"},
    172132: {"Unified_Ideograph", "Ideographic"},
    172133: {"Unified_Ideograph", "Ideographic"},
    172134: {"Unified_Ideograph", "Ideographic"},
    172135: {"Unified_Ideograph", "Ideographic"},
    172136: {"Unified_Ideograph", "Ideographic"},
    172137: {"Unified_Ideograph", "Ideographic"},
    172138: {"Unified_Ideograph", "Ideographic"},
    172139: {"Unified_Ideograph", "Ideographic"},
    172140: {"Unified_Ideograph", "Ideographic"},
    172141: {"Unified_Ideograph", "Ideographic"},
    172142: {"Unified_Ideograph", "Ideographic"},
    172143: {"Unified_Ideograph", "Ideographic"},
    172144: {"Unified_Ideograph", "Ideographic"},
    172145: {"Unified_Ideograph", "Ideographic"},
    172146: {"Unified_Ideograph", "Ideographic"},
    172147: {"Unified_Ideograph", "Ideographic"},
    172148: {"Unified_Ideograph", "Ideographic"},
    172149: {"Unified_Ideograph", "Ideographic"},
    172150: {"Unified_Ideograph", "Ideographic"},
    172151: {"Unified_Ideograph", "Ideographic"},
    172152: {"Unified_Ideograph", "Ideographic"},
    172153: {"Unified_Ideograph", "Ideographic"},
    172154: {"Unified_Ideograph", "Ideographic"},
    172155: {"Unified_Ideograph", "Ideographic"},
    172156: {"Unified_Ideograph", "Ideographic"},
    172157: {"Unified_Ideograph", "Ideographic"},
    172158: {"Unified_Ideograph", "Ideographic"},
    172159: {"Unified_Ideograph", "Ideographic"},
    172160: {"Unified_Ideograph", "Ideographic"},
    172161: {"Unified_Ideograph", "Ideographic"},
    172162: {"Unified_Ideograph", "Ideographic"},
    172163: {"Unified_Ideograph", "Ideographic"},
    172164: {"Unified_Ideograph", "Ideographic"},
    172165: {"Unified_Ideograph", "Ideographic"},
    172166: {"Unified_Ideograph", "Ideographic"},
    172167: {"Unified_Ideograph", "Ideographic"},
    172168: {"Unified_Ideograph", "Ideographic"},
    172169: {"Unified_Ideograph", "Ideographic"},
    172170: {"Unified_Ideograph", "Ideographic"},
    172171: {"Unified_Ideograph", "Ideographic"},
    172172: {"Unified_Ideograph", "Ideographic"},
    172173: {"Unified_Ideograph", "Ideographic"},
    172174: {"Unified_Ideograph", "Ideographic"},
    172175: {"Unified_Ideograph", "Ideographic"},
    172176: {"Unified_Ideograph", "Ideographic"},
    172177: {"Unified_Ideograph", "Ideographic"},
    172178: {"Unified_Ideograph", "Ideographic"},
    172179: {"Unified_Ideograph", "Ideographic"},
    172180: {"Unified_Ideograph", "Ideographic"},
    172181: {"Unified_Ideograph", "Ideographic"},
    172182: {"Unified_Ideograph", "Ideographic"},
    172183: {"Unified_Ideograph", "Ideographic"},
    172184: {"Unified_Ideograph", "Ideographic"},
    172185: {"Unified_Ideograph", "Ideographic"},
    172186: {"Unified_Ideograph", "Ideographic"},
    172187: {"Unified_Ideograph", "Ideographic"},
    172188: {"Unified_Ideograph", "Ideographic"},
    172189: {"Unified_Ideograph", "Ideographic"},
    172190: {"Unified_Ideograph", "Ideographic"},
    172191: {"Unified_Ideograph", "Ideographic"},
    172192: {"Unified_Ideograph", "Ideographic"},
    172193: {"Unified_Ideograph", "Ideographic"},
    172194: {"Unified_Ideograph", "Ideographic"},
    172195: {"Unified_Ideograph", "Ideographic"},
    172196: {"Unified_Ideograph", "Ideographic"},
    172197: {"Unified_Ideograph", "Ideographic"},
    172198: {"Unified_Ideograph", "Ideographic"},
    172199: {"Unified_Ideograph", "Ideographic"},
    172200: {"Unified_Ideograph", "Ideographic"},
    172201: {"Unified_Ideograph", "Ideographic"},
    172202: {"Unified_Ideograph", "Ideographic"},
    172203: {"Unified_Ideograph", "Ideographic"},
    172204: {"Unified_Ideograph", "Ideographic"},
    172205: {"Unified_Ideograph", "Ideographic"},
    172206: {"Unified_Ideograph", "Ideographic"},
    172207: {"Unified_Ideograph", "Ideographic"},
    172208: {"Unified_Ideograph", "Ideographic"},
    172209: {"Unified_Ideograph", "Ideographic"},
    172210: {"Unified_Ideograph", "Ideographic"},
    172211: {"Unified_Ideograph", "Ideographic"},
    172212: {"Unified_Ideograph", "Ideographic"},
    172213: {"Unified_Ideograph", "Ideographic"},
    172214: {"Unified_Ideograph", "Ideographic"},
    172215: {"Unified_Ideograph", "Ideographic"},
    172216: {"Unified_Ideograph", "Ideographic"},
    172217: {"Unified_Ideograph", "Ideographic"},
    172218: {"Unified_Ideograph", "Ideographic"},
    172219: {"Unified_Ideograph", "Ideographic"},
    172220: {"Unified_Ideograph", "Ideographic"},
    172221: {"Unified_Ideograph", "Ideographic"},
    172222: {"Unified_Ideograph", "Ideographic"},
    172223: {"Unified_Ideograph", "Ideographic"},
    172224: {"Unified_Ideograph", "Ideographic"},
    172225: {"Unified_Ideograph", "Ideographic"},
    172226: {"Unified_Ideograph", "Ideographic"},
    172227: {"Unified_Ideograph", "Ideographic"},
    172228: {"Unified_Ideograph", "Ideographic"},
    172229: {"Unified_Ideograph", "Ideographic"},
    172230: {"Unified_Ideograph", "Ideographic"},
    172231: {"Unified_Ideograph", "Ideographic"},
    172232: {"Unified_Ideograph", "Ideographic"},
    172233: {"Unified_Ideograph", "Ideographic"},
    172234: {"Unified_Ideograph", "Ideographic"},
    172235: {"Unified_Ideograph", "Ideographic"},
    172236: {"Unified_Ideograph", "Ideographic"},
    172237: {"Unified_Ideograph", "Ideographic"},
    172238: {"Unified_Ideograph", "Ideographic"},
    172239: {"Unified_Ideograph", "Ideographic"},
    172240: {"Unified_Ideograph", "Ideographic"},
    172241: {"Unified_Ideograph", "Ideographic"},
    172242: {"Unified_Ideograph", "Ideographic"},
    172243: {"Unified_Ideograph", "Ideographic"},
    172244: {"Unified_Ideograph", "Ideographic"},
    172245: {"Unified_Ideograph", "Ideographic"},
    172246: {"Unified_Ideograph", "Ideographic"},
    172247: {"Unified_Ideograph", "Ideographic"},
    172248: {"Unified_Ideograph", "Ideographic"},
    172249: {"Unified_Ideograph", "Ideographic"},
    172250: {"Unified_Ideograph", "Ideographic"},
    172251: {"Unified_Ideograph", "Ideographic"},
    172252: {"Unified_Ideograph", "Ideographic"},
    172253: {"Unified_Ideograph", "Ideographic"},
    172254: {"Unified_Ideograph", "Ideographic"},
    172255: {"Unified_Ideograph", "Ideographic"},
    172256: {"Unified_Ideograph", "Ideographic"},
    172257: {"Unified_Ideograph", "Ideographic"},
    172258: {"Unified_Ideograph", "Ideographic"},
    172259: {"Unified_Ideograph", "Ideographic"},
    172260: {"Unified_Ideograph", "Ideographic"},
    172261: {"Unified_Ideograph", "Ideographic"},
    172262: {"Unified_Ideograph", "Ideographic"},
    172263: {"Unified_Ideograph", "Ideographic"},
    172264: {"Unified_Ideograph", "Ideographic"},
    172265: {"Unified_Ideograph", "Ideographic"},
    172266: {"Unified_Ideograph", "Ideographic"},
    172267: {"Unified_Ideograph", "Ideographic"},
    172268: {"Unified_Ideograph", "Ideographic"},
    172269: {"Unified_Ideograph", "Ideographic"},
    172270: {"Unified_Ideograph", "Ideographic"},
    172271: {"Unified_Ideograph", "Ideographic"},
    172272: {"Unified_Ideograph", "Ideographic"},
    172273: {"Unified_Ideograph", "Ideographic"},
    172274: {"Unified_Ideograph", "Ideographic"},
    172275: {"Unified_Ideograph", "Ideographic"},
    172276: {"Unified_Ideograph", "Ideographic"},
    172277: {"Unified_Ideograph", "Ideographic"},
    172278: {"Unified_Ideograph", "Ideographic"},
    172279: {"Unified_Ideograph", "Ideographic"},
    172280: {"Unified_Ideograph", "Ideographic"},
    172281: {"Unified_Ideograph", "Ideographic"},
    172282: {"Unified_Ideograph", "Ideographic"},
    172283: {"Unified_Ideograph", "Ideographic"},
    172284: {"Unified_Ideograph", "Ideographic"},
    172285: {"Unified_Ideograph", "Ideographic"},
    172286: {"Unified_Ideograph", "Ideographic"},
    172287: {"Unified_Ideograph", "Ideographic"},
    172288: {"Unified_Ideograph", "Ideographic"},
    172289: {"Unified_Ideograph", "Ideographic"},
    172290: {"Unified_Ideograph", "Ideographic"},
    172291: {"Unified_Ideograph", "Ideographic"},
    172292: {"Unified_Ideograph", "Ideographic"},
    172293: {"Unified_Ideograph", "Ideographic"},
    172294: {"Unified_Ideograph", "Ideographic"},
    172295: {"Unified_Ideograph", "Ideographic"},
    172296: {"Unified_Ideograph", "Ideographic"},
    172297: {"Unified_Ideograph", "Ideographic"},
    172298: {"Unified_Ideograph", "Ideographic"},
    172299: {"Unified_Ideograph", "Ideographic"},
    172300: {"Unified_Ideograph", "Ideographic"},
    172301: {"Unified_Ideograph", "Ideographic"},
    172302: {"Unified_Ideograph", "Ideographic"},
    172303: {"Unified_Ideograph", "Ideographic"},
    172304: {"Unified_Ideograph", "Ideographic"},
    172305: {"Unified_Ideograph", "Ideographic"},
    172306: {"Unified_Ideograph", "Ideographic"},
    172307: {"Unified_Ideograph", "Ideographic"},
    172308: {"Unified_Ideograph", "Ideographic"},
    172309: {"Unified_Ideograph", "Ideographic"},
    172310: {"Unified_Ideograph", "Ideographic"},
    172311: {"Unified_Ideograph", "Ideographic"},
    172312: {"Unified_Ideograph", "Ideographic"},
    172313: {"Unified_Ideograph", "Ideographic"},
    172314: {"Unified_Ideograph", "Ideographic"},
    172315: {"Unified_Ideograph", "Ideographic"},
    172316: {"Unified_Ideograph", "Ideographic"},
    172317: {"Unified_Ideograph", "Ideographic"},
    172318: {"Unified_Ideograph", "Ideographic"},
    172319: {"Unified_Ideograph", "Ideographic"},
    172320: {"Unified_Ideograph", "Ideographic"},
    172321: {"Unified_Ideograph", "Ideographic"},
    172322: {"Unified_Ideograph", "Ideographic"},
    172323: {"Unified_Ideograph", "Ideographic"},
    172324: {"Unified_Ideograph", "Ideographic"},
    172325: {"Unified_Ideograph", "Ideographic"},
    172326: {"Unified_Ideograph", "Ideographic"},
    172327: {"Unified_Ideograph", "Ideographic"},
    172328: {"Unified_Ideograph", "Ideographic"},
    172329: {"Unified_Ideograph", "Ideographic"},
    172330: {"Unified_Ideograph", "Ideographic"},
    172331: {"Unified_Ideograph", "Ideographic"},
    172332: {"Unified_Ideograph", "Ideographic"},
    172333: {"Unified_Ideograph", "Ideographic"},
    172334: {"Unified_Ideograph", "Ideographic"},
    172335: {"Unified_Ideograph", "Ideographic"},
    172336: {"Unified_Ideograph", "Ideographic"},
    172337: {"Unified_Ideograph", "Ideographic"},
    172338: {"Unified_Ideograph", "Ideographic"},
    172339: {"Unified_Ideograph", "Ideographic"},
    172340: {"Unified_Ideograph", "Ideographic"},
    172341: {"Unified_Ideograph", "Ideographic"},
    172342: {"Unified_Ideograph", "Ideographic"},
    172343: {"Unified_Ideograph", "Ideographic"},
    172344: {"Unified_Ideograph", "Ideographic"},
    172345: {"Unified_Ideograph", "Ideographic"},
    172346: {"Unified_Ideograph", "Ideographic"},
    172347: {"Unified_Ideograph", "Ideographic"},
    172348: {"Unified_Ideograph", "Ideographic"},
    172349: {"Unified_Ideograph", "Ideographic"},
    172350: {"Unified_Ideograph", "Ideographic"},
    172351: {"Unified_Ideograph", "Ideographic"},
    172352: {"Unified_Ideograph", "Ideographic"},
    172353: {"Unified_Ideograph", "Ideographic"},
    172354: {"Unified_Ideograph", "Ideographic"},
    172355: {"Unified_Ideograph", "Ideographic"},
    172356: {"Unified_Ideograph", "Ideographic"},
    172357: {"Unified_Ideograph", "Ideographic"},
    172358: {"Unified_Ideograph", "Ideographic"},
    172359: {"Unified_Ideograph", "Ideographic"},
    172360: {"Unified_Ideograph", "Ideographic"},
    172361: {"Unified_Ideograph", "Ideographic"},
    172362: {"Unified_Ideograph", "Ideographic"},
    172363: {"Unified_Ideograph", "Ideographic"},
    172364: {"Unified_Ideograph", "Ideographic"},
    172365: {"Unified_Ideograph", "Ideographic"},
    172366: {"Unified_Ideograph", "Ideographic"},
    172367: {"Unified_Ideograph", "Ideographic"},
    172368: {"Unified_Ideograph", "Ideographic"},
    172369: {"Unified_Ideograph", "Ideographic"},
    172370: {"Unified_Ideograph", "Ideographic"},
    172371: {"Unified_Ideograph", "Ideographic"},
    172372: {"Unified_Ideograph", "Ideographic"},
    172373: {"Unified_Ideograph", "Ideographic"},
    172374: {"Unified_Ideograph", "Ideographic"},
    172375: {"Unified_Ideograph", "Ideographic"},
    172376: {"Unified_Ideograph", "Ideographic"},
    172377: {"Unified_Ideograph", "Ideographic"},
    172378: {"Unified_Ideograph", "Ideographic"},
    172379: {"Unified_Ideograph", "Ideographic"},
    172380: {"Unified_Ideograph", "Ideographic"},
    172381: {"Unified_Ideograph", "Ideographic"},
    172382: {"Unified_Ideograph", "Ideographic"},
    172383: {"Unified_Ideograph", "Ideographic"},
    172384: {"Unified_Ideograph", "Ideographic"},
    172385: {"Unified_Ideograph", "Ideographic"},
    172386: {"Unified_Ideograph", "Ideographic"},
    172387: {"Unified_Ideograph", "Ideographic"},
    172388: {"Unified_Ideograph", "Ideographic"},
    172389: {"Unified_Ideograph", "Ideographic"},
    172390: {"Unified_Ideograph", "Ideographic"},
    172391: {"Unified_Ideograph", "Ideographic"},
    172392: {"Unified_Ideograph", "Ideographic"},
    172393: {"Unified_Ideograph", "Ideographic"},
    172394: {"Unified_Ideograph", "Ideographic"},
    172395: {"Unified_Ideograph", "Ideographic"},
    172396: {"Unified_Ideograph", "Ideographic"},
    172397: {"Unified_Ideograph", "Ideographic"},
    172398: {"Unified_Ideograph", "Ideographic"},
    172399: {"Unified_Ideograph", "Ideographic"},
    172400: {"Unified_Ideograph", "Ideographic"},
    172401: {"Unified_Ideograph", "Ideographic"},
    172402: {"Unified_Ideograph", "Ideographic"},
    172403: {"Unified_Ideograph", "Ideographic"},
    172404: {"Unified_Ideograph", "Ideographic"},
    172405: {"Unified_Ideograph", "Ideographic"},
    172406: {"Unified_Ideograph", "Ideographic"},
    172407: {"Unified_Ideograph", "Ideographic"},
    172408: {"Unified_Ideograph", "Ideographic"},
    172409: {"Unified_Ideograph", "Ideographic"},
    172410: {"Unified_Ideograph", "Ideographic"},
    172411: {"Unified_Ideograph", "Ideographic"},
    172412: {"Unified_Ideograph", "Ideographic"},
    172413: {"Unified_Ideograph", "Ideographic"},
    172414: {"Unified_Ideograph", "Ideographic"},
    172415: {"Unified_Ideograph", "Ideographic"},
    172416: {"Unified_Ideograph", "Ideographic"},
    172417: {"Unified_Ideograph", "Ideographic"},
    172418: {"Unified_Ideograph", "Ideographic"},
    172419: {"Unified_Ideograph", "Ideographic"},
    172420: {"Unified_Ideograph", "Ideographic"},
    172421: {"Unified_Ideograph", "Ideographic"},
    172422: {"Unified_Ideograph", "Ideographic"},
    172423: {"Unified_Ideograph", "Ideographic"},
    172424: {"Unified_Ideograph", "Ideographic"},
    172425: {"Unified_Ideograph", "Ideographic"},
    172426: {"Unified_Ideograph", "Ideographic"},
    172427: {"Unified_Ideograph", "Ideographic"},
    172428: {"Unified_Ideograph", "Ideographic"},
    172429: {"Unified_Ideograph", "Ideographic"},
    172430: {"Unified_Ideograph", "Ideographic"},
    172431: {"Unified_Ideograph", "Ideographic"},
    172432: {"Unified_Ideograph", "Ideographic"},
    172433: {"Unified_Ideograph", "Ideographic"},
    172434: {"Unified_Ideograph", "Ideographic"},
    172435: {"Unified_Ideograph", "Ideographic"},
    172436: {"Unified_Ideograph", "Ideographic"},
    172437: {"Unified_Ideograph", "Ideographic"},
    172438: {"Unified_Ideograph", "Ideographic"},
    172439: {"Unified_Ideograph", "Ideographic"},
    172440: {"Unified_Ideograph", "Ideographic"},
    172441: {"Unified_Ideograph", "Ideographic"},
    172442: {"Unified_Ideograph", "Ideographic"},
    172443: {"Unified_Ideograph", "Ideographic"},
    172444: {"Unified_Ideograph", "Ideographic"},
    172445: {"Unified_Ideograph", "Ideographic"},
    172446: {"Unified_Ideograph", "Ideographic"},
    172447: {"Unified_Ideograph", "Ideographic"},
    172448: {"Unified_Ideograph", "Ideographic"},
    172449: {"Unified_Ideograph", "Ideographic"},
    172450: {"Unified_Ideograph", "Ideographic"},
    172451: {"Unified_Ideograph", "Ideographic"},
    172452: {"Unified_Ideograph", "Ideographic"},
    172453: {"Unified_Ideograph", "Ideographic"},
    172454: {"Unified_Ideograph", "Ideographic"},
    172455: {"Unified_Ideograph", "Ideographic"},
    172456: {"Unified_Ideograph", "Ideographic"},
    172457: {"Unified_Ideograph", "Ideographic"},
    172458: {"Unified_Ideograph", "Ideographic"},
    172459: {"Unified_Ideograph", "Ideographic"},
    172460: {"Unified_Ideograph", "Ideographic"},
    172461: {"Unified_Ideograph", "Ideographic"},
    172462: {"Unified_Ideograph", "Ideographic"},
    172463: {"Unified_Ideograph", "Ideographic"},
    172464: {"Unified_Ideograph", "Ideographic"},
    172465: {"Unified_Ideograph", "Ideographic"},
    172466: {"Unified_Ideograph", "Ideographic"},
    172467: {"Unified_Ideograph", "Ideographic"},
    172468: {"Unified_Ideograph", "Ideographic"},
    172469: {"Unified_Ideograph", "Ideographic"},
    172470: {"Unified_Ideograph", "Ideographic"},
    172471: {"Unified_Ideograph", "Ideographic"},
    172472: {"Unified_Ideograph", "Ideographic"},
    172473: {"Unified_Ideograph", "Ideographic"},
    172474: {"Unified_Ideograph", "Ideographic"},
    172475: {"Unified_Ideograph", "Ideographic"},
    172476: {"Unified_Ideograph", "Ideographic"},
    172477: {"Unified_Ideograph", "Ideographic"},
    172478: {"Unified_Ideograph", "Ideographic"},
    172479: {"Unified_Ideograph", "Ideographic"},
    172480: {"Unified_Ideograph", "Ideographic"},
    172481: {"Unified_Ideograph", "Ideographic"},
    172482: {"Unified_Ideograph", "Ideographic"},
    172483: {"Unified_Ideograph", "Ideographic"},
    172484: {"Unified_Ideograph", "Ideographic"},
    172485: {"Unified_Ideograph", "Ideographic"},
    172486: {"Unified_Ideograph", "Ideographic"},
    172487: {"Unified_Ideograph", "Ideographic"},
    172488: {"Unified_Ideograph", "Ideographic"},
    172489: {"Unified_Ideograph", "Ideographic"},
    172490: {"Unified_Ideograph", "Ideographic"},
    172491: {"Unified_Ideograph", "Ideographic"},
    172492: {"Unified_Ideograph", "Ideographic"},
    172493: {"Unified_Ideograph", "Ideographic"},
    172494: {"Unified_Ideograph", "Ideographic"},
    172495: {"Unified_Ideograph", "Ideographic"},
    172496: {"Unified_Ideograph", "Ideographic"},
    172497: {"Unified_Ideograph", "Ideographic"},
    172498: {"Unified_Ideograph", "Ideographic"},
    172499: {"Unified_Ideograph", "Ideographic"},
    172500: {"Unified_Ideograph", "Ideographic"},
    172501: {"Unified_Ideograph", "Ideographic"},
    172502: {"Unified_Ideograph", "Ideographic"},
    172503: {"Unified_Ideograph", "Ideographic"},
    172504: {"Unified_Ideograph", "Ideographic"},
    172505: {"Unified_Ideograph", "Ideographic"},
    172506: {"Unified_Ideograph", "Ideographic"},
    172507: {"Unified_Ideograph", "Ideographic"},
    172508: {"Unified_Ideograph", "Ideographic"},
    172509: {"Unified_Ideograph", "Ideographic"},
    172510: {"Unified_Ideograph", "Ideographic"},
    172511: {"Unified_Ideograph", "Ideographic"},
    172512: {"Unified_Ideograph", "Ideographic"},
    172513: {"Unified_Ideograph", "Ideographic"},
    172514: {"Unified_Ideograph", "Ideographic"},
    172515: {"Unified_Ideograph", "Ideographic"},
    172516: {"Unified_Ideograph", "Ideographic"},
    172517: {"Unified_Ideograph", "Ideographic"},
    172518: {"Unified_Ideograph", "Ideographic"},
    172519: {"Unified_Ideograph", "Ideographic"},
    172520: {"Unified_Ideograph", "Ideographic"},
    172521: {"Unified_Ideograph", "Ideographic"},
    172522: {"Unified_Ideograph", "Ideographic"},
    172523: {"Unified_Ideograph", "Ideographic"},
    172524: {"Unified_Ideograph", "Ideographic"},
    172525: {"Unified_Ideograph", "Ideographic"},
    172526: {"Unified_Ideograph", "Ideographic"},
    172527: {"Unified_Ideograph", "Ideographic"},
    172528: {"Unified_Ideograph", "Ideographic"},
    172529: {"Unified_Ideograph", "Ideographic"},
    172530: {"Unified_Ideograph", "Ideographic"},
    172531: {"Unified_Ideograph", "Ideographic"},
    172532: {"Unified_Ideograph", "Ideographic"},
    172533: {"Unified_Ideograph", "Ideographic"},
    172534: {"Unified_Ideograph", "Ideographic"},
    172535: {"Unified_Ideograph", "Ideographic"},
    172536: {"Unified_Ideograph", "Ideographic"},
    172537: {"Unified_Ideograph", "Ideographic"},
    172538: {"Unified_Ideograph", "Ideographic"},
    172539: {"Unified_Ideograph", "Ideographic"},
    172540: {"Unified_Ideograph", "Ideographic"},
    172541: {"Unified_Ideograph", "Ideographic"},
    172542: {"Unified_Ideograph", "Ideographic"},
    172543: {"Unified_Ideograph", "Ideographic"},
    172544: {"Unified_Ideograph", "Ideographic"},
    172545: {"Unified_Ideograph", "Ideographic"},
    172546: {"Unified_Ideograph", "Ideographic"},
    172547: {"Unified_Ideograph", "Ideographic"},
    172548: {"Unified_Ideograph", "Ideographic"},
    172549: {"Unified_Ideograph", "Ideographic"},
    172550: {"Unified_Ideograph", "Ideographic"},
    172551: {"Unified_Ideograph", "Ideographic"},
    172552: {"Unified_Ideograph", "Ideographic"},
    172553: {"Unified_Ideograph", "Ideographic"},
    172554: {"Unified_Ideograph", "Ideographic"},
    172555: {"Unified_Ideograph", "Ideographic"},
    172556: {"Unified_Ideograph", "Ideographic"},
    172557: {"Unified_Ideograph", "Ideographic"},
    172558: {"Unified_Ideograph", "Ideographic"},
    172559: {"Unified_Ideograph", "Ideographic"},
    172560: {"Unified_Ideograph", "Ideographic"},
    172561: {"Unified_Ideograph", "Ideographic"},
    172562: {"Unified_Ideograph", "Ideographic"},
    172563: {"Unified_Ideograph", "Ideographic"},
    172564: {"Unified_Ideograph", "Ideographic"},
    172565: {"Unified_Ideograph", "Ideographic"},
    172566: {"Unified_Ideograph", "Ideographic"},
    172567: {"Unified_Ideograph", "Ideographic"},
    172568: {"Unified_Ideograph", "Ideographic"},
    172569: {"Unified_Ideograph", "Ideographic"},
    172570: {"Unified_Ideograph", "Ideographic"},
    172571: {"Unified_Ideograph", "Ideographic"},
    172572: {"Unified_Ideograph", "Ideographic"},
    172573: {"Unified_Ideograph", "Ideographic"},
    172574: {"Unified_Ideograph", "Ideographic"},
    172575: {"Unified_Ideograph", "Ideographic"},
    172576: {"Unified_Ideograph", "Ideographic"},
    172577: {"Unified_Ideograph", "Ideographic"},
    172578: {"Unified_Ideograph", "Ideographic"},
    172579: {"Unified_Ideograph", "Ideographic"},
    172580: {"Unified_Ideograph", "Ideographic"},
    172581: {"Unified_Ideograph", "Ideographic"},
    172582: {"Unified_Ideograph", "Ideographic"},
    172583: {"Unified_Ideograph", "Ideographic"},
    172584: {"Unified_Ideograph", "Ideographic"},
    172585: {"Unified_Ideograph", "Ideographic"},
    172586: {"Unified_Ideograph", "Ideographic"},
    172587: {"Unified_Ideograph", "Ideographic"},
    172588: {"Unified_Ideograph", "Ideographic"},
    172589: {"Unified_Ideograph", "Ideographic"},
    172590: {"Unified_Ideograph", "Ideographic"},
    172591: {"Unified_Ideograph", "Ideographic"},
    172592: {"Unified_Ideograph", "Ideographic"},
    172593: {"Unified_Ideograph", "Ideographic"},
    172594: {"Unified_Ideograph", "Ideographic"},
    172595: {"Unified_Ideograph", "Ideographic"},
    172596: {"Unified_Ideograph", "Ideographic"},
    172597: {"Unified_Ideograph", "Ideographic"},
    172598: {"Unified_Ideograph", "Ideographic"},
    172599: {"Unified_Ideograph", "Ideographic"},
    172600: {"Unified_Ideograph", "Ideographic"},
    172601: {"Unified_Ideograph", "Ideographic"},
    172602: {"Unified_Ideograph", "Ideographic"},
    172603: {"Unified_Ideograph", "Ideographic"},
    172604: {"Unified_Ideograph", "Ideographic"},
    172605: {"Unified_Ideograph", "Ideographic"},
    172606: {"Unified_Ideograph", "Ideographic"},
    172607: {"Unified_Ideograph", "Ideographic"},
    172608: {"Unified_Ideograph", "Ideographic"},
    172609: {"Unified_Ideograph", "Ideographic"},
    172610: {"Unified_Ideograph", "Ideographic"},
    172611: {"Unified_Ideograph", "Ideographic"},
    172612: {"Unified_Ideograph", "Ideographic"},
    172613: {"Unified_Ideograph", "Ideographic"},
    172614: {"Unified_Ideograph", "Ideographic"},
    172615: {"Unified_Ideograph", "Ideographic"},
    172616: {"Unified_Ideograph", "Ideographic"},
    172617: {"Unified_Ideograph", "Ideographic"},
    172618: {"Unified_Ideograph", "Ideographic"},
    172619: {"Unified_Ideograph", "Ideographic"},
    172620: {"Unified_Ideograph", "Ideographic"},
    172621: {"Unified_Ideograph", "Ideographic"},
    172622: {"Unified_Ideograph", "Ideographic"},
    172623: {"Unified_Ideograph", "Ideographic"},
    172624: {"Unified_Ideograph", "Ideographic"},
    172625: {"Unified_Ideograph", "Ideographic"},
    172626: {"Unified_Ideograph", "Ideographic"},
    172627: {"Unified_Ideograph", "Ideographic"},
    172628: {"Unified_Ideograph", "Ideographic"},
    172629: {"Unified_Ideograph", "Ideographic"},
    172630: {"Unified_Ideograph", "Ideographic"},
    172631: {"Unified_Ideograph", "Ideographic"},
    172632: {"Unified_Ideograph", "Ideographic"},
    172633: {"Unified_Ideograph", "Ideographic"},
    172634: {"Unified_Ideograph", "Ideographic"},
    172635: {"Unified_Ideograph", "Ideographic"},
    172636: {"Unified_Ideograph", "Ideographic"},
    172637: {"Unified_Ideograph", "Ideographic"},
    172638: {"Unified_Ideograph", "Ideographic"},
    172639: {"Unified_Ideograph", "Ideographic"},
    172640: {"Unified_Ideograph", "Ideographic"},
    172641: {"Unified_Ideograph", "Ideographic"},
    172642: {"Unified_Ideograph", "Ideographic"},
    172643: {"Unified_Ideograph", "Ideographic"},
    172644: {"Unified_Ideograph", "Ideographic"},
    172645: {"Unified_Ideograph", "Ideographic"},
    172646: {"Unified_Ideograph", "Ideographic"},
    172647: {"Unified_Ideograph", "Ideographic"},
    172648: {"Unified_Ideograph", "Ideographic"},
    172649: {"Unified_Ideograph", "Ideographic"},
    172650: {"Unified_Ideograph", "Ideographic"},
    172651: {"Unified_Ideograph", "Ideographic"},
    172652: {"Unified_Ideograph", "Ideographic"},
    172653: {"Unified_Ideograph", "Ideographic"},
    172654: {"Unified_Ideograph", "Ideographic"},
    172655: {"Unified_Ideograph", "Ideographic"},
    172656: {"Unified_Ideograph", "Ideographic"},
    172657: {"Unified_Ideograph", "Ideographic"},
    172658: {"Unified_Ideograph", "Ideographic"},
    172659: {"Unified_Ideograph", "Ideographic"},
    172660: {"Unified_Ideograph", "Ideographic"},
    172661: {"Unified_Ideograph", "Ideographic"},
    172662: {"Unified_Ideograph", "Ideographic"},
    172663: {"Unified_Ideograph", "Ideographic"},
    172664: {"Unified_Ideograph", "Ideographic"},
    172665: {"Unified_Ideograph", "Ideographic"},
    172666: {"Unified_Ideograph", "Ideographic"},
    172667: {"Unified_Ideograph", "Ideographic"},
    172668: {"Unified_Ideograph", "Ideographic"},
    172669: {"Unified_Ideograph", "Ideographic"},
    172670: {"Unified_Ideograph", "Ideographic"},
    172671: {"Unified_Ideograph", "Ideographic"},
    172672: {"Unified_Ideograph", "Ideographic"},
    172673: {"Unified_Ideograph", "Ideographic"},
    172674: {"Unified_Ideograph", "Ideographic"},
    172675: {"Unified_Ideograph", "Ideographic"},
    172676: {"Unified_Ideograph", "Ideographic"},
    172677: {"Unified_Ideograph", "Ideographic"},
    172678: {"Unified_Ideograph", "Ideographic"},
    172679: {"Unified_Ideograph", "Ideographic"},
    172680: {"Unified_Ideograph", "Ideographic"},
    172681: {"Unified_Ideograph", "Ideographic"},
    172682: {"Unified_Ideograph", "Ideographic"},
    172683: {"Unified_Ideograph", "Ideographic"},
    172684: {"Unified_Ideograph", "Ideographic"},
    172685: {"Unified_Ideograph", "Ideographic"},
    172686: {"Unified_Ideograph", "Ideographic"},
    172687: {"Unified_Ideograph", "Ideographic"},
    172688: {"Unified_Ideograph", "Ideographic"},
    172689: {"Unified_Ideograph", "Ideographic"},
    172690: {"Unified_Ideograph", "Ideographic"},
    172691: {"Unified_Ideograph", "Ideographic"},
    172692: {"Unified_Ideograph", "Ideographic"},
    172693: {"Unified_Ideograph", "Ideographic"},
    172694: {"Unified_Ideograph", "Ideographic"},
    172695: {"Unified_Ideograph", "Ideographic"},
    172696: {"Unified_Ideograph", "Ideographic"},
    172697: {"Unified_Ideograph", "Ideographic"},
    172698: {"Unified_Ideograph", "Ideographic"},
    172699: {"Unified_Ideograph", "Ideographic"},
    172700: {"Unified_Ideograph", "Ideographic"},
    172701: {"Unified_Ideograph", "Ideographic"},
    172702: {"Unified_Ideograph", "Ideographic"},
    172703: {"Unified_Ideograph", "Ideographic"},
    172704: {"Unified_Ideograph", "Ideographic"},
    172705: {"Unified_Ideograph", "Ideographic"},
    172706: {"Unified_Ideograph", "Ideographic"},
    172707: {"Unified_Ideograph", "Ideographic"},
    172708: {"Unified_Ideograph", "Ideographic"},
    172709: {"Unified_Ideograph", "Ideographic"},
    172710: {"Unified_Ideograph", "Ideographic"},
    172711: {"Unified_Ideograph", "Ideographic"},
    172712: {"Unified_Ideograph", "Ideographic"},
    172713: {"Unified_Ideograph", "Ideographic"},
    172714: {"Unified_Ideograph", "Ideographic"},
    172715: {"Unified_Ideograph", "Ideographic"},
    172716: {"Unified_Ideograph", "Ideographic"},
    172717: {"Unified_Ideograph", "Ideographic"},
    172718: {"Unified_Ideograph", "Ideographic"},
    172719: {"Unified_Ideograph", "Ideographic"},
    172720: {"Unified_Ideograph", "Ideographic"},
    172721: {"Unified_Ideograph", "Ideographic"},
    172722: {"Unified_Ideograph", "Ideographic"},
    172723: {"Unified_Ideograph", "Ideographic"},
    172724: {"Unified_Ideograph", "Ideographic"},
    172725: {"Unified_Ideograph", "Ideographic"},
    172726: {"Unified_Ideograph", "Ideographic"},
    172727: {"Unified_Ideograph", "Ideographic"},
    172728: {"Unified_Ideograph", "Ideographic"},
    172729: {"Unified_Ideograph", "Ideographic"},
    172730: {"Unified_Ideograph", "Ideographic"},
    172731: {"Unified_Ideograph", "Ideographic"},
    172732: {"Unified_Ideograph", "Ideographic"},
    172733: {"Unified_Ideograph", "Ideographic"},
    172734: {"Unified_Ideograph", "Ideographic"},
    172735: {"Unified_Ideograph", "Ideographic"},
    172736: {"Unified_Ideograph", "Ideographic"},
    172737: {"Unified_Ideograph", "Ideographic"},
    172738: {"Unified_Ideograph", "Ideographic"},
    172739: {"Unified_Ideograph", "Ideographic"},
    172740: {"Unified_Ideograph", "Ideographic"},
    172741: {"Unified_Ideograph", "Ideographic"},
    172742: {"Unified_Ideograph", "Ideographic"},
    172743: {"Unified_Ideograph", "Ideographic"},
    172744: {"Unified_Ideograph", "Ideographic"},
    172745: {"Unified_Ideograph", "Ideographic"},
    172746: {"Unified_Ideograph", "Ideographic"},
    172747: {"Unified_Ideograph", "Ideographic"},
    172748: {"Unified_Ideograph", "Ideographic"},
    172749: {"Unified_Ideograph", "Ideographic"},
    172750: {"Unified_Ideograph", "Ideographic"},
    172751: {"Unified_Ideograph", "Ideographic"},
    172752: {"Unified_Ideograph", "Ideographic"},
    172753: {"Unified_Ideograph", "Ideographic"},
    172754: {"Unified_Ideograph", "Ideographic"},
    172755: {"Unified_Ideograph", "Ideographic"},
    172756: {"Unified_Ideograph", "Ideographic"},
    172757: {"Unified_Ideograph", "Ideographic"},
    172758: {"Unified_Ideograph", "Ideographic"},
    172759: {"Unified_Ideograph", "Ideographic"},
    172760: {"Unified_Ideograph", "Ideographic"},
    172761: {"Unified_Ideograph", "Ideographic"},
    172762: {"Unified_Ideograph", "Ideographic"},
    172763: {"Unified_Ideograph", "Ideographic"},
    172764: {"Unified_Ideograph", "Ideographic"},
    172765: {"Unified_Ideograph", "Ideographic"},
    172766: {"Unified_Ideograph", "Ideographic"},
    172767: {"Unified_Ideograph", "Ideographic"},
    172768: {"Unified_Ideograph", "Ideographic"},
    172769: {"Unified_Ideograph", "Ideographic"},
    172770: {"Unified_Ideograph", "Ideographic"},
    172771: {"Unified_Ideograph", "Ideographic"},
    172772: {"Unified_Ideograph", "Ideographic"},
    172773: {"Unified_Ideograph", "Ideographic"},
    172774: {"Unified_Ideograph", "Ideographic"},
    172775: {"Unified_Ideograph", "Ideographic"},
    172776: {"Unified_Ideograph", "Ideographic"},
    172777: {"Unified_Ideograph", "Ideographic"},
    172778: {"Unified_Ideograph", "Ideographic"},
    172779: {"Unified_Ideograph", "Ideographic"},
    172780: {"Unified_Ideograph", "Ideographic"},
    172781: {"Unified_Ideograph", "Ideographic"},
    172782: {"Unified_Ideograph", "Ideographic"},
    172783: {"Unified_Ideograph", "Ideographic"},
    172784: {"Unified_Ideograph", "Ideographic"},
    172785: {"Unified_Ideograph", "Ideographic"},
    172786: {"Unified_Ideograph", "Ideographic"},
    172787: {"Unified_Ideograph", "Ideographic"},
    172788: {"Unified_Ideograph", "Ideographic"},
    172789: {"Unified_Ideograph", "Ideographic"},
    172790: {"Unified_Ideograph", "Ideographic"},
    172791: {"Unified_Ideograph", "Ideographic"},
    172792: {"Unified_Ideograph", "Ideographic"},
    172793: {"Unified_Ideograph", "Ideographic"},
    172794: {"Unified_Ideograph", "Ideographic"},
    172795: {"Unified_Ideograph", "Ideographic"},
    172796: {"Unified_Ideograph", "Ideographic"},
    172797: {"Unified_Ideograph", "Ideographic"},
    172798: {"Unified_Ideograph", "Ideographic"},
    172799: {"Unified_Ideograph", "Ideographic"},
    172800: {"Unified_Ideograph", "Ideographic"},
    172801: {"Unified_Ideograph", "Ideographic"},
    172802: {"Unified_Ideograph", "Ideographic"},
    172803: {"Unified_Ideograph", "Ideographic"},
    172804: {"Unified_Ideograph", "Ideographic"},
    172805: {"Unified_Ideograph", "Ideographic"},
    172806: {"Unified_Ideograph", "Ideographic"},
    172807: {"Unified_Ideograph", "Ideographic"},
    172808: {"Unified_Ideograph", "Ideographic"},
    172809: {"Unified_Ideograph", "Ideographic"},
    172810: {"Unified_Ideograph", "Ideographic"},
    172811: {"Unified_Ideograph", "Ideographic"},
    172812: {"Unified_Ideograph", "Ideographic"},
    172813: {"Unified_Ideograph", "Ideographic"},
    172814: {"Unified_Ideograph", "Ideographic"},
    172815: {"Unified_Ideograph", "Ideographic"},
    172816: {"Unified_Ideograph", "Ideographic"},
    172817: {"Unified_Ideograph", "Ideographic"},
    172818: {"Unified_Ideograph", "Ideographic"},
    172819: {"Unified_Ideograph", "Ideographic"},
    172820: {"Unified_Ideograph", "Ideographic"},
    172821: {"Unified_Ideograph", "Ideographic"},
    172822: {"Unified_Ideograph", "Ideographic"},
    172823: {"Unified_Ideograph", "Ideographic"},
    172824: {"Unified_Ideograph", "Ideographic"},
    172825: {"Unified_Ideograph", "Ideographic"},
    172826: {"Unified_Ideograph", "Ideographic"},
    172827: {"Unified_Ideograph", "Ideographic"},
    172828: {"Unified_Ideograph", "Ideographic"},
    172829: {"Unified_Ideograph", "Ideographic"},
    172830: {"Unified_Ideograph", "Ideographic"},
    172831: {"Unified_Ideograph", "Ideographic"},
    172832: {"Unified_Ideograph", "Ideographic"},
    172833: {"Unified_Ideograph", "Ideographic"},
    172834: {"Unified_Ideograph", "Ideographic"},
    172835: {"Unified_Ideograph", "Ideographic"},
    172836: {"Unified_Ideograph", "Ideographic"},
    172837: {"Unified_Ideograph", "Ideographic"},
    172838: {"Unified_Ideograph", "Ideographic"},
    172839: {"Unified_Ideograph", "Ideographic"},
    172840: {"Unified_Ideograph", "Ideographic"},
    172841: {"Unified_Ideograph", "Ideographic"},
    172842: {"Unified_Ideograph", "Ideographic"},
    172843: {"Unified_Ideograph", "Ideographic"},
    172844: {"Unified_Ideograph", "Ideographic"},
    172845: {"Unified_Ideograph", "Ideographic"},
    172846: {"Unified_Ideograph", "Ideographic"},
    172847: {"Unified_Ideograph", "Ideographic"},
    172848: {"Unified_Ideograph", "Ideographic"},
    172849: {"Unified_Ideograph", "Ideographic"},
    172850: {"Unified_Ideograph", "Ideographic"},
    172851: {"Unified_Ideograph", "Ideographic"},
    172852: {"Unified_Ideograph", "Ideographic"},
    172853: {"Unified_Ideograph", "Ideographic"},
    172854: {"Unified_Ideograph", "Ideographic"},
    172855: {"Unified_Ideograph", "Ideographic"},
    172856: {"Unified_Ideograph", "Ideographic"},
    172857: {"Unified_Ideograph", "Ideographic"},
    172858: {"Unified_Ideograph", "Ideographic"},
    172859: {"Unified_Ideograph", "Ideographic"},
    172860: {"Unified_Ideograph", "Ideographic"},
    172861: {"Unified_Ideograph", "Ideographic"},
    172862: {"Unified_Ideograph", "Ideographic"},
    172863: {"Unified_Ideograph", "Ideographic"},
    172864: {"Unified_Ideograph", "Ideographic"},
    172865: {"Unified_Ideograph", "Ideographic"},
    172866: {"Unified_Ideograph", "Ideographic"},
    172867: {"Unified_Ideograph", "Ideographic"},
    172868: {"Unified_Ideograph", "Ideographic"},
    172869: {"Unified_Ideograph", "Ideographic"},
    172870: {"Unified_Ideograph", "Ideographic"},
    172871: {"Unified_Ideograph", "Ideographic"},
    172872: {"Unified_Ideograph", "Ideographic"},
    172873: {"Unified_Ideograph", "Ideographic"},
    172874: {"Unified_Ideograph", "Ideographic"},
    172875: {"Unified_Ideograph", "Ideographic"},
    172876: {"Unified_Ideograph", "Ideographic"},
    172877: {"Unified_Ideograph", "Ideographic"},
    172878: {"Unified_Ideograph", "Ideographic"},
    172879: {"Unified_Ideograph", "Ideographic"},
    172880: {"Unified_Ideograph", "Ideographic"},
    172881: {"Unified_Ideograph", "Ideographic"},
    172882: {"Unified_Ideograph", "Ideographic"},
    172883: {"Unified_Ideograph", "Ideographic"},
    172884: {"Unified_Ideograph", "Ideographic"},
    172885: {"Unified_Ideograph", "Ideographic"},
    172886: {"Unified_Ideograph", "Ideographic"},
    172887: {"Unified_Ideograph", "Ideographic"},
    172888: {"Unified_Ideograph", "Ideographic"},
    172889: {"Unified_Ideograph", "Ideographic"},
    172890: {"Unified_Ideograph", "Ideographic"},
    172891: {"Unified_Ideograph", "Ideographic"},
    172892: {"Unified_Ideograph", "Ideographic"},
    172893: {"Unified_Ideograph", "Ideographic"},
    172894: {"Unified_Ideograph", "Ideographic"},
    172895: {"Unified_Ideograph", "Ideographic"},
    172896: {"Unified_Ideograph", "Ideographic"},
    172897: {"Unified_Ideograph", "Ideographic"},
    172898: {"Unified_Ideograph", "Ideographic"},
    172899: {"Unified_Ideograph", "Ideographic"},
    172900: {"Unified_Ideograph", "Ideographic"},
    172901: {"Unified_Ideograph", "Ideographic"},
    172902: {"Unified_Ideograph", "Ideographic"},
    172903: {"Unified_Ideograph", "Ideographic"},
    172904: {"Unified_Ideograph", "Ideographic"},
    172905: {"Unified_Ideograph", "Ideographic"},
    172906: {"Unified_Ideograph", "Ideographic"},
    172907: {"Unified_Ideograph", "Ideographic"},
    172908: {"Unified_Ideograph", "Ideographic"},
    172909: {"Unified_Ideograph", "Ideographic"},
    172910: {"Unified_Ideograph", "Ideographic"},
    172911: {"Unified_Ideograph", "Ideographic"},
    172912: {"Unified_Ideograph", "Ideographic"},
    172913: {"Unified_Ideograph", "Ideographic"},
    172914: {"Unified_Ideograph", "Ideographic"},
    172915: {"Unified_Ideograph", "Ideographic"},
    172916: {"Unified_Ideograph", "Ideographic"},
    172917: {"Unified_Ideograph", "Ideographic"},
    172918: {"Unified_Ideograph", "Ideographic"},
    172919: {"Unified_Ideograph", "Ideographic"},
    172920: {"Unified_Ideograph", "Ideographic"},
    172921: {"Unified_Ideograph", "Ideographic"},
    172922: {"Unified_Ideograph", "Ideographic"},
    172923: {"Unified_Ideograph", "Ideographic"},
    172924: {"Unified_Ideograph", "Ideographic"},
    172925: {"Unified_Ideograph", "Ideographic"},
    172926: {"Unified_Ideograph", "Ideographic"},
    172927: {"Unified_Ideograph", "Ideographic"},
    172928: {"Unified_Ideograph", "Ideographic"},
    172929: {"Unified_Ideograph", "Ideographic"},
    172930: {"Unified_Ideograph", "Ideographic"},
    172931: {"Unified_Ideograph", "Ideographic"},
    172932: {"Unified_Ideograph", "Ideographic"},
    172933: {"Unified_Ideograph", "Ideographic"},
    172934: {"Unified_Ideograph", "Ideographic"},
    172935: {"Unified_Ideograph", "Ideographic"},
    172936: {"Unified_Ideograph", "Ideographic"},
    172937: {"Unified_Ideograph", "Ideographic"},
    172938: {"Unified_Ideograph", "Ideographic"},
    172939: {"Unified_Ideograph", "Ideographic"},
    172940: {"Unified_Ideograph", "Ideographic"},
    172941: {"Unified_Ideograph", "Ideographic"},
    172942: {"Unified_Ideograph", "Ideographic"},
    172943: {"Unified_Ideograph", "Ideographic"},
    172944: {"Unified_Ideograph", "Ideographic"},
    172945: {"Unified_Ideograph", "Ideographic"},
    172946: {"Unified_Ideograph", "Ideographic"},
    172947: {"Unified_Ideograph", "Ideographic"},
    172948: {"Unified_Ideograph", "Ideographic"},
    172949: {"Unified_Ideograph", "Ideographic"},
    172950: {"Unified_Ideograph", "Ideographic"},
    172951: {"Unified_Ideograph", "Ideographic"},
    172952: {"Unified_Ideograph", "Ideographic"},
    172953: {"Unified_Ideograph", "Ideographic"},
    172954: {"Unified_Ideograph", "Ideographic"},
    172955: {"Unified_Ideograph", "Ideographic"},
    172956: {"Unified_Ideograph", "Ideographic"},
    172957: {"Unified_Ideograph", "Ideographic"},
    172958: {"Unified_Ideograph", "Ideographic"},
    172959: {"Unified_Ideograph", "Ideographic"},
    172960: {"Unified_Ideograph", "Ideographic"},
    172961: {"Unified_Ideograph", "Ideographic"},
    172962: {"Unified_Ideograph", "Ideographic"},
    172963: {"Unified_Ideograph", "Ideographic"},
    172964: {"Unified_Ideograph", "Ideographic"},
    172965: {"Unified_Ideograph", "Ideographic"},
    172966: {"Unified_Ideograph", "Ideographic"},
    172967: {"Unified_Ideograph", "Ideographic"},
    172968: {"Unified_Ideograph", "Ideographic"},
    172969: {"Unified_Ideograph", "Ideographic"},
    172970: {"Unified_Ideograph", "Ideographic"},
    172971: {"Unified_Ideograph", "Ideographic"},
    172972: {"Unified_Ideograph", "Ideographic"},
    172973: {"Unified_Ideograph", "Ideographic"},
    172974: {"Unified_Ideograph", "Ideographic"},
    172975: {"Unified_Ideograph", "Ideographic"},
    172976: {"Unified_Ideograph", "Ideographic"},
    172977: {"Unified_Ideograph", "Ideographic"},
    172978: {"Unified_Ideograph", "Ideographic"},
    172979: {"Unified_Ideograph", "Ideographic"},
    172980: {"Unified_Ideograph", "Ideographic"},
    172981: {"Unified_Ideograph", "Ideographic"},
    172982: {"Unified_Ideograph", "Ideographic"},
    172983: {"Unified_Ideograph", "Ideographic"},
    172984: {"Unified_Ideograph", "Ideographic"},
    172985: {"Unified_Ideograph", "Ideographic"},
    172986: {"Unified_Ideograph", "Ideographic"},
    172987: {"Unified_Ideograph", "Ideographic"},
    172988: {"Unified_Ideograph", "Ideographic"},
    172989: {"Unified_Ideograph", "Ideographic"},
    172990: {"Unified_Ideograph", "Ideographic"},
    172991: {"Unified_Ideograph", "Ideographic"},
    172992: {"Unified_Ideograph", "Ideographic"},
    172993: {"Unified_Ideograph", "Ideographic"},
    172994: {"Unified_Ideograph", "Ideographic"},
    172995: {"Unified_Ideograph", "Ideographic"},
    172996: {"Unified_Ideograph", "Ideographic"},
    172997: {"Unified_Ideograph", "Ideographic"},
    172998: {"Unified_Ideograph", "Ideographic"},
    172999: {"Unified_Ideograph", "Ideographic"},
    173000: {"Unified_Ideograph", "Ideographic"},
    173001: {"Unified_Ideograph", "Ideographic"},
    173002: {"Unified_Ideograph", "Ideographic"},
    173003: {"Unified_Ideograph", "Ideographic"},
    173004: {"Unified_Ideograph", "Ideographic"},
    173005: {"Unified_Ideograph", "Ideographic"},
    173006: {"Unified_Ideograph", "Ideographic"},
    173007: {"Unified_Ideograph", "Ideographic"},
    173008: {"Unified_Ideograph", "Ideographic"},
    173009: {"Unified_Ideograph", "Ideographic"},
    173010: {"Unified_Ideograph", "Ideographic"},
    173011: {"Unified_Ideograph", "Ideographic"},
    173012: {"Unified_Ideograph", "Ideographic"},
    173013: {"Unified_Ideograph", "Ideographic"},
    173014: {"Unified_Ideograph", "Ideographic"},
    173015: {"Unified_Ideograph", "Ideographic"},
    173016: {"Unified_Ideograph", "Ideographic"},
    173017: {"Unified_Ideograph", "Ideographic"},
    173018: {"Unified_Ideograph", "Ideographic"},
    173019: {"Unified_Ideograph", "Ideographic"},
    173020: {"Unified_Ideograph", "Ideographic"},
    173021: {"Unified_Ideograph", "Ideographic"},
    173022: {"Unified_Ideograph", "Ideographic"},
    173023: {"Unified_Ideograph", "Ideographic"},
    173024: {"Unified_Ideograph", "Ideographic"},
    173025: {"Unified_Ideograph", "Ideographic"},
    173026: {"Unified_Ideograph", "Ideographic"},
    173027: {"Unified_Ideograph", "Ideographic"},
    173028: {"Unified_Ideograph", "Ideographic"},
    173029: {"Unified_Ideograph", "Ideographic"},
    173030: {"Unified_Ideograph", "Ideographic"},
    173031: {"Unified_Ideograph", "Ideographic"},
    173032: {"Unified_Ideograph", "Ideographic"},
    173033: {"Unified_Ideograph", "Ideographic"},
    173034: {"Unified_Ideograph", "Ideographic"},
    173035: {"Unified_Ideograph", "Ideographic"},
    173036: {"Unified_Ideograph", "Ideographic"},
    173037: {"Unified_Ideograph", "Ideographic"},
    173038: {"Unified_Ideograph", "Ideographic"},
    173039: {"Unified_Ideograph", "Ideographic"},
    173040: {"Unified_Ideograph", "Ideographic"},
    173041: {"Unified_Ideograph", "Ideographic"},
    173042: {"Unified_Ideograph", "Ideographic"},
    173043: {"Unified_Ideograph", "Ideographic"},
    173044: {"Unified_Ideograph", "Ideographic"},
    173045: {"Unified_Ideograph", "Ideographic"},
    173046: {"Unified_Ideograph", "Ideographic"},
    173047: {"Unified_Ideograph", "Ideographic"},
    173048: {"Unified_Ideograph", "Ideographic"},
    173049: {"Unified_Ideograph", "Ideographic"},
    173050: {"Unified_Ideograph", "Ideographic"},
    173051: {"Unified_Ideograph", "Ideographic"},
    173052: {"Unified_Ideograph", "Ideographic"},
    173053: {"Unified_Ideograph", "Ideographic"},
    173054: {"Unified_Ideograph", "Ideographic"},
    173055: {"Unified_Ideograph", "Ideographic"},
    173056: {"Unified_Ideograph", "Ideographic"},
    173057: {"Unified_Ideograph", "Ideographic"},
    173058: {"Unified_Ideograph", "Ideographic"},
    173059: {"Unified_Ideograph", "Ideographic"},
    173060: {"Unified_Ideograph", "Ideographic"},
    173061: {"Unified_Ideograph", "Ideographic"},
    173062: {"Unified_Ideograph", "Ideographic"},
    173063: {"Unified_Ideograph", "Ideographic"},
    173064: {"Unified_Ideograph", "Ideographic"},
    173065: {"Unified_Ideograph", "Ideographic"},
    173066: {"Unified_Ideograph", "Ideographic"},
    173067: {"Unified_Ideograph", "Ideographic"},
    173068: {"Unified_Ideograph", "Ideographic"},
    173069: {"Unified_Ideograph", "Ideographic"},
    173070: {"Unified_Ideograph", "Ideographic"},
    173071: {"Unified_Ideograph", "Ideographic"},
    173072: {"Unified_Ideograph", "Ideographic"},
    173073: {"Unified_Ideograph", "Ideographic"},
    173074: {"Unified_Ideograph", "Ideographic"},
    173075: {"Unified_Ideograph", "Ideographic"},
    173076: {"Unified_Ideograph", "Ideographic"},
    173077: {"Unified_Ideograph", "Ideographic"},
    173078: {"Unified_Ideograph", "Ideographic"},
    173079: {"Unified_Ideograph", "Ideographic"},
    173080: {"Unified_Ideograph", "Ideographic"},
    173081: {"Unified_Ideograph", "Ideographic"},
    173082: {"Unified_Ideograph", "Ideographic"},
    173083: {"Unified_Ideograph", "Ideographic"},
    173084: {"Unified_Ideograph", "Ideographic"},
    173085: {"Unified_Ideograph", "Ideographic"},
    173086: {"Unified_Ideograph", "Ideographic"},
    173087: {"Unified_Ideograph", "Ideographic"},
    173088: {"Unified_Ideograph", "Ideographic"},
    173089: {"Unified_Ideograph", "Ideographic"},
    173090: {"Unified_Ideograph", "Ideographic"},
    173091: {"Unified_Ideograph", "Ideographic"},
    173092: {"Unified_Ideograph", "Ideographic"},
    173093: {"Unified_Ideograph", "Ideographic"},
    173094: {"Unified_Ideograph", "Ideographic"},
    173095: {"Unified_Ideograph", "Ideographic"},
    173096: {"Unified_Ideograph", "Ideographic"},
    173097: {"Unified_Ideograph", "Ideographic"},
    173098: {"Unified_Ideograph", "Ideographic"},
    173099: {"Unified_Ideograph", "Ideographic"},
    173100: {"Unified_Ideograph", "Ideographic"},
    173101: {"Unified_Ideograph", "Ideographic"},
    173102: {"Unified_Ideograph", "Ideographic"},
    173103: {"Unified_Ideograph", "Ideographic"},
    173104: {"Unified_Ideograph", "Ideographic"},
    173105: {"Unified_Ideograph", "Ideographic"},
    173106: {"Unified_Ideograph", "Ideographic"},
    173107: {"Unified_Ideograph", "Ideographic"},
    173108: {"Unified_Ideograph", "Ideographic"},
    173109: {"Unified_Ideograph", "Ideographic"},
    173110: {"Unified_Ideograph", "Ideographic"},
    173111: {"Unified_Ideograph", "Ideographic"},
    173112: {"Unified_Ideograph", "Ideographic"},
    173113: {"Unified_Ideograph", "Ideographic"},
    173114: {"Unified_Ideograph", "Ideographic"},
    173115: {"Unified_Ideograph", "Ideographic"},
    173116: {"Unified_Ideograph", "Ideographic"},
    173117: {"Unified_Ideograph", "Ideographic"},
    173118: {"Unified_Ideograph", "Ideographic"},
    173119: {"Unified_Ideograph", "Ideographic"},
    173120: {"Unified_Ideograph", "Ideographic"},
    173121: {"Unified_Ideograph", "Ideographic"},
    173122: {"Unified_Ideograph", "Ideographic"},
    173123: {"Unified_Ideograph", "Ideographic"},
    173124: {"Unified_Ideograph", "Ideographic"},
    173125: {"Unified_Ideograph", "Ideographic"},
    173126: {"Unified_Ideograph", "Ideographic"},
    173127: {"Unified_Ideograph", "Ideographic"},
    173128: {"Unified_Ideograph", "Ideographic"},
    173129: {"Unified_Ideograph", "Ideographic"},
    173130: {"Unified_Ideograph", "Ideographic"},
    173131: {"Unified_Ideograph", "Ideographic"},
    173132: {"Unified_Ideograph", "Ideographic"},
    173133: {"Unified_Ideograph", "Ideographic"},
    173134: {"Unified_Ideograph", "Ideographic"},
    173135: {"Unified_Ideograph", "Ideographic"},
    173136: {"Unified_Ideograph", "Ideographic"},
    173137: {"Unified_Ideograph", "Ideographic"},
    173138: {"Unified_Ideograph", "Ideographic"},
    173139: {"Unified_Ideograph", "Ideographic"},
    173140: {"Unified_Ideograph", "Ideographic"},
    173141: {"Unified_Ideograph", "Ideographic"},
    173142: {"Unified_Ideograph", "Ideographic"},
    173143: {"Unified_Ideograph", "Ideographic"},
    173144: {"Unified_Ideograph", "Ideographic"},
    173145: {"Unified_Ideograph", "Ideographic"},
    173146: {"Unified_Ideograph", "Ideographic"},
    173147: {"Unified_Ideograph", "Ideographic"},
    173148: {"Unified_Ideograph", "Ideographic"},
    173149: {"Unified_Ideograph", "Ideographic"},
    173150: {"Unified_Ideograph", "Ideographic"},
    173151: {"Unified_Ideograph", "Ideographic"},
    173152: {"Unified_Ideograph", "Ideographic"},
    173153: {"Unified_Ideograph", "Ideographic"},
    173154: {"Unified_Ideograph", "Ideographic"},
    173155: {"Unified_Ideograph", "Ideographic"},
    173156: {"Unified_Ideograph", "Ideographic"},
    173157: {"Unified_Ideograph", "Ideographic"},
    173158: {"Unified_Ideograph", "Ideographic"},
    173159: {"Unified_Ideograph", "Ideographic"},
    173160: {"Unified_Ideograph", "Ideographic"},
    173161: {"Unified_Ideograph", "Ideographic"},
    173162: {"Unified_Ideograph", "Ideographic"},
    173163: {"Unified_Ideograph", "Ideographic"},
    173164: {"Unified_Ideograph", "Ideographic"},
    173165: {"Unified_Ideograph", "Ideographic"},
    173166: {"Unified_Ideograph", "Ideographic"},
    173167: {"Unified_Ideograph", "Ideographic"},
    173168: {"Unified_Ideograph", "Ideographic"},
    173169: {"Unified_Ideograph", "Ideographic"},
    173170: {"Unified_Ideograph", "Ideographic"},
    173171: {"Unified_Ideograph", "Ideographic"},
    173172: {"Unified_Ideograph", "Ideographic"},
    173173: {"Unified_Ideograph", "Ideographic"},
    173174: {"Unified_Ideograph", "Ideographic"},
    173175: {"Unified_Ideograph", "Ideographic"},
    173176: {"Unified_Ideograph", "Ideographic"},
    173177: {"Unified_Ideograph", "Ideographic"},
    173178: {"Unified_Ideograph", "Ideographic"},
    173179: {"Unified_Ideograph", "Ideographic"},
    173180: {"Unified_Ideograph", "Ideographic"},
    173181: {"Unified_Ideograph", "Ideographic"},
    173182: {"Unified_Ideograph", "Ideographic"},
    173183: {"Unified_Ideograph", "Ideographic"},
    173184: {"Unified_Ideograph", "Ideographic"},
    173185: {"Unified_Ideograph", "Ideographic"},
    173186: {"Unified_Ideograph", "Ideographic"},
    173187: {"Unified_Ideograph", "Ideographic"},
    173188: {"Unified_Ideograph", "Ideographic"},
    173189: {"Unified_Ideograph", "Ideographic"},
    173190: {"Unified_Ideograph", "Ideographic"},
    173191: {"Unified_Ideograph", "Ideographic"},
    173192: {"Unified_Ideograph", "Ideographic"},
    173193: {"Unified_Ideograph", "Ideographic"},
    173194: {"Unified_Ideograph", "Ideographic"},
    173195: {"Unified_Ideograph", "Ideographic"},
    173196: {"Unified_Ideograph", "Ideographic"},
    173197: {"Unified_Ideograph", "Ideographic"},
    173198: {"Unified_Ideograph", "Ideographic"},
    173199: {"Unified_Ideograph", "Ideographic"},
    173200: {"Unified_Ideograph", "Ideographic"},
    173201: {"Unified_Ideograph", "Ideographic"},
    173202: {"Unified_Ideograph", "Ideographic"},
    173203: {"Unified_Ideograph", "Ideographic"},
    173204: {"Unified_Ideograph", "Ideographic"},
    173205: {"Unified_Ideograph", "Ideographic"},
    173206: {"Unified_Ideograph", "Ideographic"},
    173207: {"Unified_Ideograph", "Ideographic"},
    173208: {"Unified_Ideograph", "Ideographic"},
    173209: {"Unified_Ideograph", "Ideographic"},
    173210: {"Unified_Ideograph", "Ideographic"},
    173211: {"Unified_Ideograph", "Ideographic"},
    173212: {"Unified_Ideograph", "Ideographic"},
    173213: {"Unified_Ideograph", "Ideographic"},
    173214: {"Unified_Ideograph", "Ideographic"},
    173215: {"Unified_Ideograph", "Ideographic"},
    173216: {"Unified_Ideograph", "Ideographic"},
    173217: {"Unified_Ideograph", "Ideographic"},
    173218: {"Unified_Ideograph", "Ideographic"},
    173219: {"Unified_Ideograph", "Ideographic"},
    173220: {"Unified_Ideograph", "Ideographic"},
    173221: {"Unified_Ideograph", "Ideographic"},
    173222: {"Unified_Ideograph", "Ideographic"},
    173223: {"Unified_Ideograph", "Ideographic"},
    173224: {"Unified_Ideograph", "Ideographic"},
    173225: {"Unified_Ideograph", "Ideographic"},
    173226: {"Unified_Ideograph", "Ideographic"},
    173227: {"Unified_Ideograph", "Ideographic"},
    173228: {"Unified_Ideograph", "Ideographic"},
    173229: {"Unified_Ideograph", "Ideographic"},
    173230: {"Unified_Ideograph", "Ideographic"},
    173231: {"Unified_Ideograph", "Ideographic"},
    173232: {"Unified_Ideograph", "Ideographic"},
    173233: {"Unified_Ideograph", "Ideographic"},
    173234: {"Unified_Ideograph", "Ideographic"},
    173235: {"Unified_Ideograph", "Ideographic"},
    173236: {"Unified_Ideograph", "Ideographic"},
    173237: {"Unified_Ideograph", "Ideographic"},
    173238: {"Unified_Ideograph", "Ideographic"},
    173239: {"Unified_Ideograph", "Ideographic"},
    173240: {"Unified_Ideograph", "Ideographic"},
    173241: {"Unified_Ideograph", "Ideographic"},
    173242: {"Unified_Ideograph", "Ideographic"},
    173243: {"Unified_Ideograph", "Ideographic"},
    173244: {"Unified_Ideograph", "Ideographic"},
    173245: {"Unified_Ideograph", "Ideographic"},
    173246: {"Unified_Ideograph", "Ideographic"},
    173247: {"Unified_Ideograph", "Ideographic"},
    173248: {"Unified_Ideograph", "Ideographic"},
    173249: {"Unified_Ideograph", "Ideographic"},
    173250: {"Unified_Ideograph", "Ideographic"},
    173251: {"Unified_Ideograph", "Ideographic"},
    173252: {"Unified_Ideograph", "Ideographic"},
    173253: {"Unified_Ideograph", "Ideographic"},
    173254: {"Unified_Ideograph", "Ideographic"},
    173255: {"Unified_Ideograph", "Ideographic"},
    173256: {"Unified_Ideograph", "Ideographic"},
    173257: {"Unified_Ideograph", "Ideographic"},
    173258: {"Unified_Ideograph", "Ideographic"},
    173259: {"Unified_Ideograph", "Ideographic"},
    173260: {"Unified_Ideograph", "Ideographic"},
    173261: {"Unified_Ideograph", "Ideographic"},
    173262: {"Unified_Ideograph", "Ideographic"},
    173263: {"Unified_Ideograph", "Ideographic"},
    173264: {"Unified_Ideograph", "Ideographic"},
    173265: {"Unified_Ideograph", "Ideographic"},
    173266: {"Unified_Ideograph", "Ideographic"},
    173267: {"Unified_Ideograph", "Ideographic"},
    173268: {"Unified_Ideograph", "Ideographic"},
    173269: {"Unified_Ideograph", "Ideographic"},
    173270: {"Unified_Ideograph", "Ideographic"},
    173271: {"Unified_Ideograph", "Ideographic"},
    173272: {"Unified_Ideograph", "Ideographic"},
    173273: {"Unified_Ideograph", "Ideographic"},
    173274: {"Unified_Ideograph", "Ideographic"},
    173275: {"Unified_Ideograph", "Ideographic"},
    173276: {"Unified_Ideograph", "Ideographic"},
    173277: {"Unified_Ideograph", "Ideographic"},
    173278: {"Unified_Ideograph", "Ideographic"},
    173279: {"Unified_Ideograph", "Ideographic"},
    173280: {"Unified_Ideograph", "Ideographic"},
    173281: {"Unified_Ideograph", "Ideographic"},
    173282: {"Unified_Ideograph", "Ideographic"},
    173283: {"Unified_Ideograph", "Ideographic"},
    173284: {"Unified_Ideograph", "Ideographic"},
    173285: {"Unified_Ideograph", "Ideographic"},
    173286: {"Unified_Ideograph", "Ideographic"},
    173287: {"Unified_Ideograph", "Ideographic"},
    173288: {"Unified_Ideograph", "Ideographic"},
    173289: {"Unified_Ideograph", "Ideographic"},
    173290: {"Unified_Ideograph", "Ideographic"},
    173291: {"Unified_Ideograph", "Ideographic"},
    173292: {"Unified_Ideograph", "Ideographic"},
    173293: {"Unified_Ideograph", "Ideographic"},
    173294: {"Unified_Ideograph", "Ideographic"},
    173295: {"Unified_Ideograph", "Ideographic"},
    173296: {"Unified_Ideograph", "Ideographic"},
    173297: {"Unified_Ideograph", "Ideographic"},
    173298: {"Unified_Ideograph", "Ideographic"},
    173299: {"Unified_Ideograph", "Ideographic"},
    173300: {"Unified_Ideograph", "Ideographic"},
    173301: {"Unified_Ideograph", "Ideographic"},
    173302: {"Unified_Ideograph", "Ideographic"},
    173303: {"Unified_Ideograph", "Ideographic"},
    173304: {"Unified_Ideograph", "Ideographic"},
    173305: {"Unified_Ideograph", "Ideographic"},
    173306: {"Unified_Ideograph", "Ideographic"},
    173307: {"Unified_Ideograph", "Ideographic"},
    173308: {"Unified_Ideograph", "Ideographic"},
    173309: {"Unified_Ideograph", "Ideographic"},
    173310: {"Unified_Ideograph", "Ideographic"},
    173311: {"Unified_Ideograph", "Ideographic"},
    173312: {"Unified_Ideograph", "Ideographic"},
    173313: {"Unified_Ideograph", "Ideographic"},
    173314: {"Unified_Ideograph", "Ideographic"},
    173315: {"Unified_Ideograph", "Ideographic"},
    173316: {"Unified_Ideograph", "Ideographic"},
    173317: {"Unified_Ideograph", "Ideographic"},
    173318: {"Unified_Ideograph", "Ideographic"},
    173319: {"Unified_Ideograph", "Ideographic"},
    173320: {"Unified_Ideograph", "Ideographic"},
    173321: {"Unified_Ideograph", "Ideographic"},
    173322: {"Unified_Ideograph", "Ideographic"},
    173323: {"Unified_Ideograph", "Ideographic"},
    173324: {"Unified_Ideograph", "Ideographic"},
    173325: {"Unified_Ideograph", "Ideographic"},
    173326: {"Unified_Ideograph", "Ideographic"},
    173327: {"Unified_Ideograph", "Ideographic"},
    173328: {"Unified_Ideograph", "Ideographic"},
    173329: {"Unified_Ideograph", "Ideographic"},
    173330: {"Unified_Ideograph", "Ideographic"},
    173331: {"Unified_Ideograph", "Ideographic"},
    173332: {"Unified_Ideograph", "Ideographic"},
    173333: {"Unified_Ideograph", "Ideographic"},
    173334: {"Unified_Ideograph", "Ideographic"},
    173335: {"Unified_Ideograph", "Ideographic"},
    173336: {"Unified_Ideograph", "Ideographic"},
    173337: {"Unified_Ideograph", "Ideographic"},
    173338: {"Unified_Ideograph", "Ideographic"},
    173339: {"Unified_Ideograph", "Ideographic"},
    173340: {"Unified_Ideograph", "Ideographic"},
    173341: {"Unified_Ideograph", "Ideographic"},
    173342: {"Unified_Ideograph", "Ideographic"},
    173343: {"Unified_Ideograph", "Ideographic"},
    173344: {"Unified_Ideograph", "Ideographic"},
    173345: {"Unified_Ideograph", "Ideographic"},
    173346: {"Unified_Ideograph", "Ideographic"},
    173347: {"Unified_Ideograph", "Ideographic"},
    173348: {"Unified_Ideograph", "Ideographic"},
    173349: {"Unified_Ideograph", "Ideographic"},
    173350: {"Unified_Ideograph", "Ideographic"},
    173351: {"Unified_Ideograph", "Ideographic"},
    173352: {"Unified_Ideograph", "Ideographic"},
    173353: {"Unified_Ideograph", "Ideographic"},
    173354: {"Unified_Ideograph", "Ideographic"},
    173355: {"Unified_Ideograph", "Ideographic"},
    173356: {"Unified_Ideograph", "Ideographic"},
    173357: {"Unified_Ideograph", "Ideographic"},
    173358: {"Unified_Ideograph", "Ideographic"},
    173359: {"Unified_Ideograph", "Ideographic"},
    173360: {"Unified_Ideograph", "Ideographic"},
    173361: {"Unified_Ideograph", "Ideographic"},
    173362: {"Unified_Ideograph", "Ideographic"},
    173363: {"Unified_Ideograph", "Ideographic"},
    173364: {"Unified_Ideograph", "Ideographic"},
    173365: {"Unified_Ideograph", "Ideographic"},
    173366: {"Unified_Ideograph", "Ideographic"},
    173367: {"Unified_Ideograph", "Ideographic"},
    173368: {"Unified_Ideograph", "Ideographic"},
    173369: {"Unified_Ideograph", "Ideographic"},
    173370: {"Unified_Ideograph", "Ideographic"},
    173371: {"Unified_Ideograph", "Ideographic"},
    173372: {"Unified_Ideograph", "Ideographic"},
    173373: {"Unified_Ideograph", "Ideographic"},
    173374: {"Unified_Ideograph", "Ideographic"},
    173375: {"Unified_Ideograph", "Ideographic"},
    173376: {"Unified_Ideograph", "Ideographic"},
    173377: {"Unified_Ideograph", "Ideographic"},
    173378: {"Unified_Ideograph", "Ideographic"},
    173379: {"Unified_Ideograph", "Ideographic"},
    173380: {"Unified_Ideograph", "Ideographic"},
    173381: {"Unified_Ideograph", "Ideographic"},
    173382: {"Unified_Ideograph", "Ideographic"},
    173383: {"Unified_Ideograph", "Ideographic"},
    173384: {"Unified_Ideograph", "Ideographic"},
    173385: {"Unified_Ideograph", "Ideographic"},
    173386: {"Unified_Ideograph", "Ideographic"},
    173387: {"Unified_Ideograph", "Ideographic"},
    173388: {"Unified_Ideograph", "Ideographic"},
    173389: {"Unified_Ideograph", "Ideographic"},
    173390: {"Unified_Ideograph", "Ideographic"},
    173391: {"Unified_Ideograph", "Ideographic"},
    173392: {"Unified_Ideograph", "Ideographic"},
    173393: {"Unified_Ideograph", "Ideographic"},
    173394: {"Unified_Ideograph", "Ideographic"},
    173395: {"Unified_Ideograph", "Ideographic"},
    173396: {"Unified_Ideograph", "Ideographic"},
    173397: {"Unified_Ideograph", "Ideographic"},
    173398: {"Unified_Ideograph", "Ideographic"},
    173399: {"Unified_Ideograph", "Ideographic"},
    173400: {"Unified_Ideograph", "Ideographic"},
    173401: {"Unified_Ideograph", "Ideographic"},
    173402: {"Unified_Ideograph", "Ideographic"},
    173403: {"Unified_Ideograph", "Ideographic"},
    173404: {"Unified_Ideograph", "Ideographic"},
    173405: {"Unified_Ideograph", "Ideographic"},
    173406: {"Unified_Ideograph", "Ideographic"},
    173407: {"Unified_Ideograph", "Ideographic"},
    173408: {"Unified_Ideograph", "Ideographic"},
    173409: {"Unified_Ideograph", "Ideographic"},
    173410: {"Unified_Ideograph", "Ideographic"},
    173411: {"Unified_Ideograph", "Ideographic"},
    173412: {"Unified_Ideograph", "Ideographic"},
    173413: {"Unified_Ideograph", "Ideographic"},
    173414: {"Unified_Ideograph", "Ideographic"},
    173415: {"Unified_Ideograph", "Ideographic"},
    173416: {"Unified_Ideograph", "Ideographic"},
    173417: {"Unified_Ideograph", "Ideographic"},
    173418: {"Unified_Ideograph", "Ideographic"},
    173419: {"Unified_Ideograph", "Ideographic"},
    173420: {"Unified_Ideograph", "Ideographic"},
    173421: {"Unified_Ideograph", "Ideographic"},
    173422: {"Unified_Ideograph", "Ideographic"},
    173423: {"Unified_Ideograph", "Ideographic"},
    173424: {"Unified_Ideograph", "Ideographic"},
    173425: {"Unified_Ideograph", "Ideographic"},
    173426: {"Unified_Ideograph", "Ideographic"},
    173427: {"Unified_Ideograph", "Ideographic"},
    173428: {"Unified_Ideograph", "Ideographic"},
    173429: {"Unified_Ideograph", "Ideographic"},
    173430: {"Unified_Ideograph", "Ideographic"},
    173431: {"Unified_Ideograph", "Ideographic"},
    173432: {"Unified_Ideograph", "Ideographic"},
    173433: {"Unified_Ideograph", "Ideographic"},
    173434: {"Unified_Ideograph", "Ideographic"},
    173435: {"Unified_Ideograph", "Ideographic"},
    173436: {"Unified_Ideograph", "Ideographic"},
    173437: {"Unified_Ideograph", "Ideographic"},
    173438: {"Unified_Ideograph", "Ideographic"},
    173439: {"Unified_Ideograph", "Ideographic"},
    173440: {"Unified_Ideograph", "Ideographic"},
    173441: {"Unified_Ideograph", "Ideographic"},
    173442: {"Unified_Ideograph", "Ideographic"},
    173443: {"Unified_Ideograph", "Ideographic"},
    173444: {"Unified_Ideograph", "Ideographic"},
    173445: {"Unified_Ideograph", "Ideographic"},
    173446: {"Unified_Ideograph", "Ideographic"},
    173447: {"Unified_Ideograph", "Ideographic"},
    173448: {"Unified_Ideograph", "Ideographic"},
    173449: {"Unified_Ideograph", "Ideographic"},
    173450: {"Unified_Ideograph", "Ideographic"},
    173451: {"Unified_Ideograph", "Ideographic"},
    173452: {"Unified_Ideograph", "Ideographic"},
    173453: {"Unified_Ideograph", "Ideographic"},
    173454: {"Unified_Ideograph", "Ideographic"},
    173455: {"Unified_Ideograph", "Ideographic"},
    173456: {"Unified_Ideograph", "Ideographic"},
    173457: {"Unified_Ideograph", "Ideographic"},
    173458: {"Unified_Ideograph", "Ideographic"},
    173459: {"Unified_Ideograph", "Ideographic"},
    173460: {"Unified_Ideograph", "Ideographic"},
    173461: {"Unified_Ideograph", "Ideographic"},
    173462: {"Unified_Ideograph", "Ideographic"},
    173463: {"Unified_Ideograph", "Ideographic"},
    173464: {"Unified_Ideograph", "Ideographic"},
    173465: {"Unified_Ideograph", "Ideographic"},
    173466: {"Unified_Ideograph", "Ideographic"},
    173467: {"Unified_Ideograph", "Ideographic"},
    173468: {"Unified_Ideograph", "Ideographic"},
    173469: {"Unified_Ideograph", "Ideographic"},
    173470: {"Unified_Ideograph", "Ideographic"},
    173471: {"Unified_Ideograph", "Ideographic"},
    173472: {"Unified_Ideograph", "Ideographic"},
    173473: {"Unified_Ideograph", "Ideographic"},
    173474: {"Unified_Ideograph", "Ideographic"},
    173475: {"Unified_Ideograph", "Ideographic"},
    173476: {"Unified_Ideograph", "Ideographic"},
    173477: {"Unified_Ideograph", "Ideographic"},
    173478: {"Unified_Ideograph", "Ideographic"},
    173479: {"Unified_Ideograph", "Ideographic"},
    173480: {"Unified_Ideograph", "Ideographic"},
    173481: {"Unified_Ideograph", "Ideographic"},
    173482: {"Unified_Ideograph", "Ideographic"},
    173483: {"Unified_Ideograph", "Ideographic"},
    173484: {"Unified_Ideograph", "Ideographic"},
    173485: {"Unified_Ideograph", "Ideographic"},
    173486: {"Unified_Ideograph", "Ideographic"},
    173487: {"Unified_Ideograph", "Ideographic"},
    173488: {"Unified_Ideograph", "Ideographic"},
    173489: {"Unified_Ideograph", "Ideographic"},
    173490: {"Unified_Ideograph", "Ideographic"},
    173491: {"Unified_Ideograph", "Ideographic"},
    173492: {"Unified_Ideograph", "Ideographic"},
    173493: {"Unified_Ideograph", "Ideographic"},
    173494: {"Unified_Ideograph", "Ideographic"},
    173495: {"Unified_Ideograph", "Ideographic"},
    173496: {"Unified_Ideograph", "Ideographic"},
    173497: {"Unified_Ideograph", "Ideographic"},
    173498: {"Unified_Ideograph", "Ideographic"},
    173499: {"Unified_Ideograph", "Ideographic"},
    173500: {"Unified_Ideograph", "Ideographic"},
    173501: {"Unified_Ideograph", "Ideographic"},
    173502: {"Unified_Ideograph", "Ideographic"},
    173503: {"Unified_Ideograph", "Ideographic"},
    173504: {"Unified_Ideograph", "Ideographic"},
    173505: {"Unified_Ideograph", "Ideographic"},
    173506: {"Unified_Ideograph", "Ideographic"},
    173507: {"Unified_Ideograph", "Ideographic"},
    173508: {"Unified_Ideograph", "Ideographic"},
    173509: {"Unified_Ideograph", "Ideographic"},
    173510: {"Unified_Ideograph", "Ideographic"},
    173511: {"Unified_Ideograph", "Ideographic"},
    173512: {"Unified_Ideograph", "Ideographic"},
    173513: {"Unified_Ideograph", "Ideographic"},
    173514: {"Unified_Ideograph", "Ideographic"},
    173515: {"Unified_Ideograph", "Ideographic"},
    173516: {"Unified_Ideograph", "Ideographic"},
    173517: {"Unified_Ideograph", "Ideographic"},
    173518: {"Unified_Ideograph", "Ideographic"},
    173519: {"Unified_Ideograph", "Ideographic"},
    173520: {"Unified_Ideograph", "Ideographic"},
    173521: {"Unified_Ideograph", "Ideographic"},
    173522: {"Unified_Ideograph", "Ideographic"},
    173523: {"Unified_Ideograph", "Ideographic"},
    173524: {"Unified_Ideograph", "Ideographic"},
    173525: {"Unified_Ideograph", "Ideographic"},
    173526: {"Unified_Ideograph", "Ideographic"},
    173527: {"Unified_Ideograph", "Ideographic"},
    173528: {"Unified_Ideograph", "Ideographic"},
    173529: {"Unified_Ideograph", "Ideographic"},
    173530: {"Unified_Ideograph", "Ideographic"},
    173531: {"Unified_Ideograph", "Ideographic"},
    173532: {"Unified_Ideograph", "Ideographic"},
    173533: {"Unified_Ideograph", "Ideographic"},
    173534: {"Unified_Ideograph", "Ideographic"},
    173535: {"Unified_Ideograph", "Ideographic"},
    173536: {"Unified_Ideograph", "Ideographic"},
    173537: {"Unified_Ideograph", "Ideographic"},
    173538: {"Unified_Ideograph", "Ideographic"},
    173539: {"Unified_Ideograph", "Ideographic"},
    173540: {"Unified_Ideograph", "Ideographic"},
    173541: {"Unified_Ideograph", "Ideographic"},
    173542: {"Unified_Ideograph", "Ideographic"},
    173543: {"Unified_Ideograph", "Ideographic"},
    173544: {"Unified_Ideograph", "Ideographic"},
    173545: {"Unified_Ideograph", "Ideographic"},
    173546: {"Unified_Ideograph", "Ideographic"},
    173547: {"Unified_Ideograph", "Ideographic"},
    173548: {"Unified_Ideograph", "Ideographic"},
    173549: {"Unified_Ideograph", "Ideographic"},
    173550: {"Unified_Ideograph", "Ideographic"},
    173551: {"Unified_Ideograph", "Ideographic"},
    173552: {"Unified_Ideograph", "Ideographic"},
    173553: {"Unified_Ideograph", "Ideographic"},
    173554: {"Unified_Ideograph", "Ideographic"},
    173555: {"Unified_Ideograph", "Ideographic"},
    173556: {"Unified_Ideograph", "Ideographic"},
    173557: {"Unified_Ideograph", "Ideographic"},
    173558: {"Unified_Ideograph", "Ideographic"},
    173559: {"Unified_Ideograph", "Ideographic"},
    173560: {"Unified_Ideograph", "Ideographic"},
    173561: {"Unified_Ideograph", "Ideographic"},
    173562: {"Unified_Ideograph", "Ideographic"},
    173563: {"Unified_Ideograph", "Ideographic"},
    173564: {"Unified_Ideograph", "Ideographic"},
    173565: {"Unified_Ideograph", "Ideographic"},
    173566: {"Unified_Ideograph", "Ideographic"},
    173567: {"Unified_Ideograph", "Ideographic"},
    173568: {"Unified_Ideograph", "Ideographic"},
    173569: {"Unified_Ideograph", "Ideographic"},
    173570: {"Unified_Ideograph", "Ideographic"},
    173571: {"Unified_Ideograph", "Ideographic"},
    173572: {"Unified_Ideograph", "Ideographic"},
    173573: {"Unified_Ideograph", "Ideographic"},
    173574: {"Unified_Ideograph", "Ideographic"},
    173575: {"Unified_Ideograph", "Ideographic"},
    173576: {"Unified_Ideograph", "Ideographic"},
    173577: {"Unified_Ideograph", "Ideographic"},
    173578: {"Unified_Ideograph", "Ideographic"},
    173579: {"Unified_Ideograph", "Ideographic"},
    173580: {"Unified_Ideograph", "Ideographic"},
    173581: {"Unified_Ideograph", "Ideographic"},
    173582: {"Unified_Ideograph", "Ideographic"},
    173583: {"Unified_Ideograph", "Ideographic"},
    173584: {"Unified_Ideograph", "Ideographic"},
    173585: {"Unified_Ideograph", "Ideographic"},
    173586: {"Unified_Ideograph", "Ideographic"},
    173587: {"Unified_Ideograph", "Ideographic"},
    173588: {"Unified_Ideograph", "Ideographic"},
    173589: {"Unified_Ideograph", "Ideographic"},
    173590: {"Unified_Ideograph", "Ideographic"},
    173591: {"Unified_Ideograph", "Ideographic"},
    173592: {"Unified_Ideograph", "Ideographic"},
    173593: {"Unified_Ideograph", "Ideographic"},
    173594: {"Unified_Ideograph", "Ideographic"},
    173595: {"Unified_Ideograph", "Ideographic"},
    173596: {"Unified_Ideograph", "Ideographic"},
    173597: {"Unified_Ideograph", "Ideographic"},
    173598: {"Unified_Ideograph", "Ideographic"},
    173599: {"Unified_Ideograph", "Ideographic"},
    173600: {"Unified_Ideograph", "Ideographic"},
    173601: {"Unified_Ideograph", "Ideographic"},
    173602: {"Unified_Ideograph", "Ideographic"},
    173603: {"Unified_Ideograph", "Ideographic"},
    173604: {"Unified_Ideograph", "Ideographic"},
    173605: {"Unified_Ideograph", "Ideographic"},
    173606: {"Unified_Ideograph", "Ideographic"},
    173607: {"Unified_Ideograph", "Ideographic"},
    173608: {"Unified_Ideograph", "Ideographic"},
    173609: {"Unified_Ideograph", "Ideographic"},
    173610: {"Unified_Ideograph", "Ideographic"},
    173611: {"Unified_Ideograph", "Ideographic"},
    173612: {"Unified_Ideograph", "Ideographic"},
    173613: {"Unified_Ideograph", "Ideographic"},
    173614: {"Unified_Ideograph", "Ideographic"},
    173615: {"Unified_Ideograph", "Ideographic"},
    173616: {"Unified_Ideograph", "Ideographic"},
    173617: {"Unified_Ideograph", "Ideographic"},
    173618: {"Unified_Ideograph", "Ideographic"},
    173619: {"Unified_Ideograph", "Ideographic"},
    173620: {"Unified_Ideograph", "Ideographic"},
    173621: {"Unified_Ideograph", "Ideographic"},
    173622: {"Unified_Ideograph", "Ideographic"},
    173623: {"Unified_Ideograph", "Ideographic"},
    173624: {"Unified_Ideograph", "Ideographic"},
    173625: {"Unified_Ideograph", "Ideographic"},
    173626: {"Unified_Ideograph", "Ideographic"},
    173627: {"Unified_Ideograph", "Ideographic"},
    173628: {"Unified_Ideograph", "Ideographic"},
    173629: {"Unified_Ideograph", "Ideographic"},
    173630: {"Unified_Ideograph", "Ideographic"},
    173631: {"Unified_Ideograph", "Ideographic"},
    173632: {"Unified_Ideograph", "Ideographic"},
    173633: {"Unified_Ideograph", "Ideographic"},
    173634: {"Unified_Ideograph", "Ideographic"},
    173635: {"Unified_Ideograph", "Ideographic"},
    173636: {"Unified_Ideograph", "Ideographic"},
    173637: {"Unified_Ideograph", "Ideographic"},
    173638: {"Unified_Ideograph", "Ideographic"},
    173639: {"Unified_Ideograph", "Ideographic"},
    173640: {"Unified_Ideograph", "Ideographic"},
    173641: {"Unified_Ideograph", "Ideographic"},
    173642: {"Unified_Ideograph", "Ideographic"},
    173643: {"Unified_Ideograph", "Ideographic"},
    173644: {"Unified_Ideograph", "Ideographic"},
    173645: {"Unified_Ideograph", "Ideographic"},
    173646: {"Unified_Ideograph", "Ideographic"},
    173647: {"Unified_Ideograph", "Ideographic"},
    173648: {"Unified_Ideograph", "Ideographic"},
    173649: {"Unified_Ideograph", "Ideographic"},
    173650: {"Unified_Ideograph", "Ideographic"},
    173651: {"Unified_Ideograph", "Ideographic"},
    173652: {"Unified_Ideograph", "Ideographic"},
    173653: {"Unified_Ideograph", "Ideographic"},
    173654: {"Unified_Ideograph", "Ideographic"},
    173655: {"Unified_Ideograph", "Ideographic"},
    173656: {"Unified_Ideograph", "Ideographic"},
    173657: {"Unified_Ideograph", "Ideographic"},
    173658: {"Unified_Ideograph", "Ideographic"},
    173659: {"Unified_Ideograph", "Ideographic"},
    173660: {"Unified_Ideograph", "Ideographic"},
    173661: {"Unified_Ideograph", "Ideographic"},
    173662: {"Unified_Ideograph", "Ideographic"},
    173663: {"Unified_Ideograph", "Ideographic"},
    173664: {"Unified_Ideograph", "Ideographic"},
    173665: {"Unified_Ideograph", "Ideographic"},
    173666: {"Unified_Ideograph", "Ideographic"},
    173667: {"Unified_Ideograph", "Ideographic"},
    173668: {"Unified_Ideograph", "Ideographic"},
    173669: {"Unified_Ideograph", "Ideographic"},
    173670: {"Unified_Ideograph", "Ideographic"},
    173671: {"Unified_Ideograph", "Ideographic"},
    173672: {"Unified_Ideograph", "Ideographic"},
    173673: {"Unified_Ideograph", "Ideographic"},
    173674: {"Unified_Ideograph", "Ideographic"},
    173675: {"Unified_Ideograph", "Ideographic"},
    173676: {"Unified_Ideograph", "Ideographic"},
    173677: {"Unified_Ideograph", "Ideographic"},
    173678: {"Unified_Ideograph", "Ideographic"},
    173679: {"Unified_Ideograph", "Ideographic"},
    173680: {"Unified_Ideograph", "Ideographic"},
    173681: {"Unified_Ideograph", "Ideographic"},
    173682: {"Unified_Ideograph", "Ideographic"},
    173683: {"Unified_Ideograph", "Ideographic"},
    173684: {"Unified_Ideograph", "Ideographic"},
    173685: {"Unified_Ideograph", "Ideographic"},
    173686: {"Unified_Ideograph", "Ideographic"},
    173687: {"Unified_Ideograph", "Ideographic"},
    173688: {"Unified_Ideograph", "Ideographic"},
    173689: {"Unified_Ideograph", "Ideographic"},
    173690: {"Unified_Ideograph", "Ideographic"},
    173691: {"Unified_Ideograph", "Ideographic"},
    173692: {"Unified_Ideograph", "Ideographic"},
    173693: {"Unified_Ideograph", "Ideographic"},
    173694: {"Unified_Ideograph", "Ideographic"},
    173695: {"Unified_Ideograph", "Ideographic"},
    173696: {"Unified_Ideograph", "Ideographic"},
    173697: {"Unified_Ideograph", "Ideographic"},
    173698: {"Unified_Ideograph", "Ideographic"},
    173699: {"Unified_Ideograph", "Ideographic"},
    173700: {"Unified_Ideograph", "Ideographic"},
    173701: {"Unified_Ideograph", "Ideographic"},
    173702: {"Unified_Ideograph", "Ideographic"},
    173703: {"Unified_Ideograph", "Ideographic"},
    173704: {"Unified_Ideograph", "Ideographic"},
    173705: {"Unified_Ideograph", "Ideographic"},
    173706: {"Unified_Ideograph", "Ideographic"},
    173707: {"Unified_Ideograph", "Ideographic"},
    173708: {"Unified_Ideograph", "Ideographic"},
    173709: {"Unified_Ideograph", "Ideographic"},
    173710: {"Unified_Ideograph", "Ideographic"},
    173711: {"Unified_Ideograph", "Ideographic"},
    173712: {"Unified_Ideograph", "Ideographic"},
    173713: {"Unified_Ideograph", "Ideographic"},
    173714: {"Unified_Ideograph", "Ideographic"},
    173715: {"Unified_Ideograph", "Ideographic"},
    173716: {"Unified_Ideograph", "Ideographic"},
    173717: {"Unified_Ideograph", "Ideographic"},
    173718: {"Unified_Ideograph", "Ideographic"},
    173719: {"Unified_Ideograph", "Ideographic"},
    173720: {"Unified_Ideograph", "Ideographic"},
    173721: {"Unified_Ideograph", "Ideographic"},
    173722: {"Unified_Ideograph", "Ideographic"},
    173723: {"Unified_Ideograph", "Ideographic"},
    173724: {"Unified_Ideograph", "Ideographic"},
    173725: {"Unified_Ideograph", "Ideographic"},
    173726: {"Unified_Ideograph", "Ideographic"},
    173727: {"Unified_Ideograph", "Ideographic"},
    173728: {"Unified_Ideograph", "Ideographic"},
    173729: {"Unified_Ideograph", "Ideographic"},
    173730: {"Unified_Ideograph", "Ideographic"},
    173731: {"Unified_Ideograph", "Ideographic"},
    173732: {"Unified_Ideograph", "Ideographic"},
    173733: {"Unified_Ideograph", "Ideographic"},
    173734: {"Unified_Ideograph", "Ideographic"},
    173735: {"Unified_Ideograph", "Ideographic"},
    173736: {"Unified_Ideograph", "Ideographic"},
    173737: {"Unified_Ideograph", "Ideographic"},
    173738: {"Unified_Ideograph", "Ideographic"},
    173739: {"Unified_Ideograph", "Ideographic"},
    173740: {"Unified_Ideograph", "Ideographic"},
    173741: {"Unified_Ideograph", "Ideographic"},
    173742: {"Unified_Ideograph", "Ideographic"},
    173743: {"Unified_Ideograph", "Ideographic"},
    173744: {"Unified_Ideograph", "Ideographic"},
    173745: {"Unified_Ideograph", "Ideographic"},
    173746: {"Unified_Ideograph", "Ideographic"},
    173747: {"Unified_Ideograph", "Ideographic"},
    173748: {"Unified_Ideograph", "Ideographic"},
    173749: {"Unified_Ideograph", "Ideographic"},
    173750: {"Unified_Ideograph", "Ideographic"},
    173751: {"Unified_Ideograph", "Ideographic"},
    173752: {"Unified_Ideograph", "Ideographic"},
    173753: {"Unified_Ideograph", "Ideographic"},
    173754: {"Unified_Ideograph", "Ideographic"},
    173755: {"Unified_Ideograph", "Ideographic"},
    173756: {"Unified_Ideograph", "Ideographic"},
    173757: {"Unified_Ideograph", "Ideographic"},
    173758: {"Unified_Ideograph", "Ideographic"},
    173759: {"Unified_Ideograph", "Ideographic"},
    173760: {"Unified_Ideograph", "Ideographic"},
    173761: {"Unified_Ideograph", "Ideographic"},
    173762: {"Unified_Ideograph", "Ideographic"},
    173763: {"Unified_Ideograph", "Ideographic"},
    173764: {"Unified_Ideograph", "Ideographic"},
    173765: {"Unified_Ideograph", "Ideographic"},
    173766: {"Unified_Ideograph", "Ideographic"},
    173767: {"Unified_Ideograph", "Ideographic"},
    173768: {"Unified_Ideograph", "Ideographic"},
    173769: {"Unified_Ideograph", "Ideographic"},
    173770: {"Unified_Ideograph", "Ideographic"},
    173771: {"Unified_Ideograph", "Ideographic"},
    173772: {"Unified_Ideograph", "Ideographic"},
    173773: {"Unified_Ideograph", "Ideographic"},
    173774: {"Unified_Ideograph", "Ideographic"},
    173775: {"Unified_Ideograph", "Ideographic"},
    173776: {"Unified_Ideograph", "Ideographic"},
    173777: {"Unified_Ideograph", "Ideographic"},
    173778: {"Unified_Ideograph", "Ideographic"},
    173779: {"Unified_Ideograph", "Ideographic"},
    173780: {"Unified_Ideograph", "Ideographic"},
    173781: {"Unified_Ideograph", "Ideographic"},
    173782: {"Unified_Ideograph", "Ideographic"},
    173783: {"Unified_Ideograph", "Ideographic"},
    173784: {"Unified_Ideograph", "Ideographic"},
    173785: {"Unified_Ideograph", "Ideographic"},
    173786: {"Unified_Ideograph", "Ideographic"},
    173787: {"Unified_Ideograph", "Ideographic"},
    173788: {"Unified_Ideograph", "Ideographic"},
    173789: {"Unified_Ideograph", "Ideographic"},
    173824: {"Unified_Ideograph", "Ideographic"},
    173825: {"Unified_Ideograph", "Ideographic"},
    173826: {"Unified_Ideograph", "Ideographic"},
    173827: {"Unified_Ideograph", "Ideographic"},
    173828: {"Unified_Ideograph", "Ideographic"},
    173829: {"Unified_Ideograph", "Ideographic"},
    173830: {"Unified_Ideograph", "Ideographic"},
    173831: {"Unified_Ideograph", "Ideographic"},
    173832: {"Unified_Ideograph", "Ideographic"},
    173833: {"Unified_Ideograph", "Ideographic"},
    173834: {"Unified_Ideograph", "Ideographic"},
    173835: {"Unified_Ideograph", "Ideographic"},
    173836: {"Unified_Ideograph", "Ideographic"},
    173837: {"Unified_Ideograph", "Ideographic"},
    173838: {"Unified_Ideograph", "Ideographic"},
    173839: {"Unified_Ideograph", "Ideographic"},
    173840: {"Unified_Ideograph", "Ideographic"},
    173841: {"Unified_Ideograph", "Ideographic"},
    173842: {"Unified_Ideograph", "Ideographic"},
    173843: {"Unified_Ideograph", "Ideographic"},
    173844: {"Unified_Ideograph", "Ideographic"},
    173845: {"Unified_Ideograph", "Ideographic"},
    173846: {"Unified_Ideograph", "Ideographic"},
    173847: {"Unified_Ideograph", "Ideographic"},
    173848: {"Unified_Ideograph", "Ideographic"},
    173849: {"Unified_Ideograph", "Ideographic"},
    173850: {"Unified_Ideograph", "Ideographic"},
    173851: {"Unified_Ideograph", "Ideographic"},
    173852: {"Unified_Ideograph", "Ideographic"},
    173853: {"Unified_Ideograph", "Ideographic"},
    173854: {"Unified_Ideograph", "Ideographic"},
    173855: {"Unified_Ideograph", "Ideographic"},
    173856: {"Unified_Ideograph", "Ideographic"},
    173857: {"Unified_Ideograph", "Ideographic"},
    173858: {"Unified_Ideograph", "Ideographic"},
    173859: {"Unified_Ideograph", "Ideographic"},
    173860: {"Unified_Ideograph", "Ideographic"},
    173861: {"Unified_Ideograph", "Ideographic"},
    173862: {"Unified_Ideograph", "Ideographic"},
    173863: {"Unified_Ideograph", "Ideographic"},
    173864: {"Unified_Ideograph", "Ideographic"},
    173865: {"Unified_Ideograph", "Ideographic"},
    173866: {"Unified_Ideograph", "Ideographic"},
    173867: {"Unified_Ideograph", "Ideographic"},
    173868: {"Unified_Ideograph", "Ideographic"},
    173869: {"Unified_Ideograph", "Ideographic"},
    173870: {"Unified_Ideograph", "Ideographic"},
    173871: {"Unified_Ideograph", "Ideographic"},
    173872: {"Unified_Ideograph", "Ideographic"},
    173873: {"Unified_Ideograph", "Ideographic"},
    173874: {"Unified_Ideograph", "Ideographic"},
    173875: {"Unified_Ideograph", "Ideographic"},
    173876: {"Unified_Ideograph", "Ideographic"},
    173877: {"Unified_Ideograph", "Ideographic"},
    173878: {"Unified_Ideograph", "Ideographic"},
    173879: {"Unified_Ideograph", "Ideographic"},
    173880: {"Unified_Ideograph", "Ideographic"},
    173881: {"Unified_Ideograph", "Ideographic"},
    173882: {"Unified_Ideograph", "Ideographic"},
    173883: {"Unified_Ideograph", "Ideographic"},
    173884: {"Unified_Ideograph", "Ideographic"},
    173885: {"Unified_Ideograph", "Ideographic"},
    173886: {"Unified_Ideograph", "Ideographic"},
    173887: {"Unified_Ideograph", "Ideographic"},
    173888: {"Unified_Ideograph", "Ideographic"},
    173889: {"Unified_Ideograph", "Ideographic"},
    173890: {"Unified_Ideograph", "Ideographic"},
    173891: {"Unified_Ideograph", "Ideographic"},
    173892: {"Unified_Ideograph", "Ideographic"},
    173893: {"Unified_Ideograph", "Ideographic"},
    173894: {"Unified_Ideograph", "Ideographic"},
    173895: {"Unified_Ideograph", "Ideographic"},
    173896: {"Unified_Ideograph", "Ideographic"},
    173897: {"Unified_Ideograph", "Ideographic"},
    173898: {"Unified_Ideograph", "Ideographic"},
    173899: {"Unified_Ideograph", "Ideographic"},
    173900: {"Unified_Ideograph", "Ideographic"},
    173901: {"Unified_Ideograph", "Ideographic"},
    173902: {"Unified_Ideograph", "Ideographic"},
    173903: {"Unified_Ideograph", "Ideographic"},
    173904: {"Unified_Ideograph", "Ideographic"},
    173905: {"Unified_Ideograph", "Ideographic"},
    173906: {"Unified_Ideograph", "Ideographic"},
    173907: {"Unified_Ideograph", "Ideographic"},
    173908: {"Unified_Ideograph", "Ideographic"},
    173909: {"Unified_Ideograph", "Ideographic"},
    173910: {"Unified_Ideograph", "Ideographic"},
    173911: {"Unified_Ideograph", "Ideographic"},
    173912: {"Unified_Ideograph", "Ideographic"},
    173913: {"Unified_Ideograph", "Ideographic"},
    173914: {"Unified_Ideograph", "Ideographic"},
    173915: {"Unified_Ideograph", "Ideographic"},
    173916: {"Unified_Ideograph", "Ideographic"},
    173917: {"Unified_Ideograph", "Ideographic"},
    173918: {"Unified_Ideograph", "Ideographic"},
    173919: {"Unified_Ideograph", "Ideographic"},
    173920: {"Unified_Ideograph", "Ideographic"},
    173921: {"Unified_Ideograph", "Ideographic"},
    173922: {"Unified_Ideograph", "Ideographic"},
    173923: {"Unified_Ideograph", "Ideographic"},
    173924: {"Unified_Ideograph", "Ideographic"},
    173925: {"Unified_Ideograph", "Ideographic"},
    173926: {"Unified_Ideograph", "Ideographic"},
    173927: {"Unified_Ideograph", "Ideographic"},
    173928: {"Unified_Ideograph", "Ideographic"},
    173929: {"Unified_Ideograph", "Ideographic"},
    173930: {"Unified_Ideograph", "Ideographic"},
    173931: {"Unified_Ideograph", "Ideographic"},
    173932: {"Unified_Ideograph", "Ideographic"},
    173933: {"Unified_Ideograph", "Ideographic"},
    173934: {"Unified_Ideograph", "Ideographic"},
    173935: {"Unified_Ideograph", "Ideographic"},
    173936: {"Unified_Ideograph", "Ideographic"},
    173937: {"Unified_Ideograph", "Ideographic"},
    173938: {"Unified_Ideograph", "Ideographic"},
    173939: {"Unified_Ideograph", "Ideographic"},
    173940: {"Unified_Ideograph", "Ideographic"},
    173941: {"Unified_Ideograph", "Ideographic"},
    173942: {"Unified_Ideograph", "Ideographic"},
    173943: {"Unified_Ideograph", "Ideographic"},
    173944: {"Unified_Ideograph", "Ideographic"},
    173945: {"Unified_Ideograph", "Ideographic"},
    173946: {"Unified_Ideograph", "Ideographic"},
    173947: {"Unified_Ideograph", "Ideographic"},
    173948: {"Unified_Ideograph", "Ideographic"},
    173949: {"Unified_Ideograph", "Ideographic"},
    173950: {"Unified_Ideograph", "Ideographic"},
    173951: {"Unified_Ideograph", "Ideographic"},
    173952: {"Unified_Ideograph", "Ideographic"},
    173953: {"Unified_Ideograph", "Ideographic"},
    173954: {"Unified_Ideograph", "Ideographic"},
    173955: {"Unified_Ideograph", "Ideographic"},
    173956: {"Unified_Ideograph", "Ideographic"},
    173957: {"Unified_Ideograph", "Ideographic"},
    173958: {"Unified_Ideograph", "Ideographic"},
    173959: {"Unified_Ideograph", "Ideographic"},
    173960: {"Unified_Ideograph", "Ideographic"},
    173961: {"Unified_Ideograph", "Ideographic"},
    173962: {"Unified_Ideograph", "Ideographic"},
    173963: {"Unified_Ideograph", "Ideographic"},
    173964: {"Unified_Ideograph", "Ideographic"},
    173965: {"Unified_Ideograph", "Ideographic"},
    173966: {"Unified_Ideograph", "Ideographic"},
    173967: {"Unified_Ideograph", "Ideographic"},
    173968: {"Unified_Ideograph", "Ideographic"},
    173969: {"Unified_Ideograph", "Ideographic"},
    173970: {"Unified_Ideograph", "Ideographic"},
    173971: {"Unified_Ideograph", "Ideographic"},
    173972: {"Unified_Ideograph", "Ideographic"},
    173973: {"Unified_Ideograph", "Ideographic"},
    173974: {"Unified_Ideograph", "Ideographic"},
    173975: {"Unified_Ideograph", "Ideographic"},
    173976: {"Unified_Ideograph", "Ideographic"},
    173977: {"Unified_Ideograph", "Ideographic"},
    173978: {"Unified_Ideograph", "Ideographic"},
    173979: {"Unified_Ideograph", "Ideographic"},
    173980: {"Unified_Ideograph", "Ideographic"},
    173981: {"Unified_Ideograph", "Ideographic"},
    173982: {"Unified_Ideograph", "Ideographic"},
    173983: {"Unified_Ideograph", "Ideographic"},
    173984: {"Unified_Ideograph", "Ideographic"},
    173985: {"Unified_Ideograph", "Ideographic"},
    173986: {"Unified_Ideograph", "Ideographic"},
    173987: {"Unified_Ideograph", "Ideographic"},
    173988: {"Unified_Ideograph", "Ideographic"},
    173989: {"Unified_Ideograph", "Ideographic"},
    173990: {"Unified_Ideograph", "Ideographic"},
    173991: {"Unified_Ideograph", "Ideographic"},
    173992: {"Unified_Ideograph", "Ideographic"},
    173993: {"Unified_Ideograph", "Ideographic"},
    173994: {"Unified_Ideograph", "Ideographic"},
    173995: {"Unified_Ideograph", "Ideographic"},
    173996: {"Unified_Ideograph", "Ideographic"},
    173997: {"Unified_Ideograph", "Ideographic"},
    173998: {"Unified_Ideograph", "Ideographic"},
    173999: {"Unified_Ideograph", "Ideographic"},
    174000: {"Unified_Ideograph", "Ideographic"},
    174001: {"Unified_Ideograph", "Ideographic"},
    174002: {"Unified_Ideograph", "Ideographic"},
    174003: {"Unified_Ideograph", "Ideographic"},
    174004: {"Unified_Ideograph", "Ideographic"},
    174005: {"Unified_Ideograph", "Ideographic"},
    174006: {"Unified_Ideograph", "Ideographic"},
    174007: {"Unified_Ideograph", "Ideographic"},
    174008: {"Unified_Ideograph", "Ideographic"},
    174009: {"Unified_Ideograph", "Ideographic"},
    174010: {"Unified_Ideograph", "Ideographic"},
    174011: {"Unified_Ideograph", "Ideographic"},
    174012: {"Unified_Ideograph", "Ideographic"},
    174013: {"Unified_Ideograph", "Ideographic"},
    174014: {"Unified_Ideograph", "Ideographic"},
    174015: {"Unified_Ideograph", "Ideographic"},
    174016: {"Unified_Ideograph", "Ideographic"},
    174017: {"Unified_Ideograph", "Ideographic"},
    174018: {"Unified_Ideograph", "Ideographic"},
    174019: {"Unified_Ideograph", "Ideographic"},
    174020: {"Unified_Ideograph", "Ideographic"},
    174021: {"Unified_Ideograph", "Ideographic"},
    174022: {"Unified_Ideograph", "Ideographic"},
    174023: {"Unified_Ideograph", "Ideographic"},
    174024: {"Unified_Ideograph", "Ideographic"},
    174025: {"Unified_Ideograph", "Ideographic"},
    174026: {"Unified_Ideograph", "Ideographic"},
    174027: {"Unified_Ideograph", "Ideographic"},
    174028: {"Unified_Ideograph", "Ideographic"},
    174029: {"Unified_Ideograph", "Ideographic"},
    174030: {"Unified_Ideograph", "Ideographic"},
    174031: {"Unified_Ideograph", "Ideographic"},
    174032: {"Unified_Ideograph", "Ideographic"},
    174033: {"Unified_Ideograph", "Ideographic"},
    174034: {"Unified_Ideograph", "Ideographic"},
    174035: {"Unified_Ideograph", "Ideographic"},
    174036: {"Unified_Ideograph", "Ideographic"},
    174037: {"Unified_Ideograph", "Ideographic"},
    174038: {"Unified_Ideograph", "Ideographic"},
    174039: {"Unified_Ideograph", "Ideographic"},
    174040: {"Unified_Ideograph", "Ideographic"},
    174041: {"Unified_Ideograph", "Ideographic"},
    174042: {"Unified_Ideograph", "Ideographic"},
    174043: {"Unified_Ideograph", "Ideographic"},
    174044: {"Unified_Ideograph", "Ideographic"},
    174045: {"Unified_Ideograph", "Ideographic"},
    174046: {"Unified_Ideograph", "Ideographic"},
    174047: {"Unified_Ideograph", "Ideographic"},
    174048: {"Unified_Ideograph", "Ideographic"},
    174049: {"Unified_Ideograph", "Ideographic"},
    174050: {"Unified_Ideograph", "Ideographic"},
    174051: {"Unified_Ideograph", "Ideographic"},
    174052: {"Unified_Ideograph", "Ideographic"},
    174053: {"Unified_Ideograph", "Ideographic"},
    174054: {"Unified_Ideograph", "Ideographic"},
    174055: {"Unified_Ideograph", "Ideographic"},
    174056: {"Unified_Ideograph", "Ideographic"},
    174057: {"Unified_Ideograph", "Ideographic"},
    174058: {"Unified_Ideograph", "Ideographic"},
    174059: {"Unified_Ideograph", "Ideographic"},
    174060: {"Unified_Ideograph", "Ideographic"},
    174061: {"Unified_Ideograph", "Ideographic"},
    174062: {"Unified_Ideograph", "Ideographic"},
    174063: {"Unified_Ideograph", "Ideographic"},
    174064: {"Unified_Ideograph", "Ideographic"},
    174065: {"Unified_Ideograph", "Ideographic"},
    174066: {"Unified_Ideograph", "Ideographic"},
    174067: {"Unified_Ideograph", "Ideographic"},
    174068: {"Unified_Ideograph", "Ideographic"},
    174069: {"Unified_Ideograph", "Ideographic"},
    174070: {"Unified_Ideograph", "Ideographic"},
    174071: {"Unified_Ideograph", "Ideographic"},
    174072: {"Unified_Ideograph", "Ideographic"},
    174073: {"Unified_Ideograph", "Ideographic"},
    174074: {"Unified_Ideograph", "Ideographic"},
    174075: {"Unified_Ideograph", "Ideographic"},
    174076: {"Unified_Ideograph", "Ideographic"},
    174077: {"Unified_Ideograph", "Ideographic"},
    174078: {"Unified_Ideograph", "Ideographic"},
    174079: {"Unified_Ideograph", "Ideographic"},
    174080: {"Unified_Ideograph", "Ideographic"},
    174081: {"Unified_Ideograph", "Ideographic"},
    174082: {"Unified_Ideograph", "Ideographic"},
    174083: {"Unified_Ideograph", "Ideographic"},
    174084: {"Unified_Ideograph", "Ideographic"},
    174085: {"Unified_Ideograph", "Ideographic"},
    174086: {"Unified_Ideograph", "Ideographic"},
    174087: {"Unified_Ideograph", "Ideographic"},
    174088: {"Unified_Ideograph", "Ideographic"},
    174089: {"Unified_Ideograph", "Ideographic"},
    174090: {"Unified_Ideograph", "Ideographic"},
    174091: {"Unified_Ideograph", "Ideographic"},
    174092: {"Unified_Ideograph", "Ideographic"},
    174093: {"Unified_Ideograph", "Ideographic"},
    174094: {"Unified_Ideograph", "Ideographic"},
    174095: {"Unified_Ideograph", "Ideographic"},
    174096: {"Unified_Ideograph", "Ideographic"},
    174097: {"Unified_Ideograph", "Ideographic"},
    174098: {"Unified_Ideograph", "Ideographic"},
    174099: {"Unified_Ideograph", "Ideographic"},
    174100: {"Unified_Ideograph", "Ideographic"},
    174101: {"Unified_Ideograph", "Ideographic"},
    174102: {"Unified_Ideograph", "Ideographic"},
    174103: {"Unified_Ideograph", "Ideographic"},
    174104: {"Unified_Ideograph", "Ideographic"},
    174105: {"Unified_Ideograph", "Ideographic"},
    174106: {"Unified_Ideograph", "Ideographic"},
    174107: {"Unified_Ideograph", "Ideographic"},
    174108: {"Unified_Ideograph", "Ideographic"},
    174109: {"Unified_Ideograph", "Ideographic"},
    174110: {"Unified_Ideograph", "Ideographic"},
    174111: {"Unified_Ideograph", "Ideographic"},
    174112: {"Unified_Ideograph", "Ideographic"},
    174113: {"Unified_Ideograph", "Ideographic"},
    174114: {"Unified_Ideograph", "Ideographic"},
    174115: {"Unified_Ideograph", "Ideographic"},
    174116: {"Unified_Ideograph", "Ideographic"},
    174117: {"Unified_Ideograph", "Ideographic"},
    174118: {"Unified_Ideograph", "Ideographic"},
    174119: {"Unified_Ideograph", "Ideographic"},
    174120: {"Unified_Ideograph", "Ideographic"},
    174121: {"Unified_Ideograph", "Ideographic"},
    174122: {"Unified_Ideograph", "Ideographic"},
    174123: {"Unified_Ideograph", "Ideographic"},
    174124: {"Unified_Ideograph", "Ideographic"},
    174125: {"Unified_Ideograph", "Ideographic"},
    174126: {"Unified_Ideograph", "Ideographic"},
    174127: {"Unified_Ideograph", "Ideographic"},
    174128: {"Unified_Ideograph", "Ideographic"},
    174129: {"Unified_Ideograph", "Ideographic"},
    174130: {"Unified_Ideograph", "Ideographic"},
    174131: {"Unified_Ideograph", "Ideographic"},
    174132: {"Unified_Ideograph", "Ideographic"},
    174133: {"Unified_Ideograph", "Ideographic"},
    174134: {"Unified_Ideograph", "Ideographic"},
    174135: {"Unified_Ideograph", "Ideographic"},
    174136: {"Unified_Ideograph", "Ideographic"},
    174137: {"Unified_Ideograph", "Ideographic"},
    174138: {"Unified_Ideograph", "Ideographic"},
    174139: {"Unified_Ideograph", "Ideographic"},
    174140: {"Unified_Ideograph", "Ideographic"},
    174141: {"Unified_Ideograph", "Ideographic"},
    174142: {"Unified_Ideograph", "Ideographic"},
    174143: {"Unified_Ideograph", "Ideographic"},
    174144: {"Unified_Ideograph", "Ideographic"},
    174145: {"Unified_Ideograph", "Ideographic"},
    174146: {"Unified_Ideograph", "Ideographic"},
    174147: {"Unified_Ideograph", "Ideographic"},
    174148: {"Unified_Ideograph", "Ideographic"},
    174149: {"Unified_Ideograph", "Ideographic"},
    174150: {"Unified_Ideograph", "Ideographic"},
    174151: {"Unified_Ideograph", "Ideographic"},
    174152: {"Unified_Ideograph", "Ideographic"},
    174153: {"Unified_Ideograph", "Ideographic"},
    174154: {"Unified_Ideograph", "Ideographic"},
    174155: {"Unified_Ideograph", "Ideographic"},
    174156: {"Unified_Ideograph", "Ideographic"},
    174157: {"Unified_Ideograph", "Ideographic"},
    174158: {"Unified_Ideograph", "Ideographic"},
    174159: {"Unified_Ideograph", "Ideographic"},
    174160: {"Unified_Ideograph", "Ideographic"},
    174161: {"Unified_Ideograph", "Ideographic"},
    174162: {"Unified_Ideograph", "Ideographic"},
    174163: {"Unified_Ideograph", "Ideographic"},
    174164: {"Unified_Ideograph", "Ideographic"},
    174165: {"Unified_Ideograph", "Ideographic"},
    174166: {"Unified_Ideograph", "Ideographic"},
    174167: {"Unified_Ideograph", "Ideographic"},
    174168: {"Unified_Ideograph", "Ideographic"},
    174169: {"Unified_Ideograph", "Ideographic"},
    174170: {"Unified_Ideograph", "Ideographic"},
    174171: {"Unified_Ideograph", "Ideographic"},
    174172: {"Unified_Ideograph", "Ideographic"},
    174173: {"Unified_Ideograph", "Ideographic"},
    174174: {"Unified_Ideograph", "Ideographic"},
    174175: {"Unified_Ideograph", "Ideographic"},
    174176: {"Unified_Ideograph", "Ideographic"},
    174177: {"Unified_Ideograph", "Ideographic"},
    174178: {"Unified_Ideograph", "Ideographic"},
    174179: {"Unified_Ideograph", "Ideographic"},
    174180: {"Unified_Ideograph", "Ideographic"},
    174181: {"Unified_Ideograph", "Ideographic"},
    174182: {"Unified_Ideograph", "Ideographic"},
    174183: {"Unified_Ideograph", "Ideographic"},
    174184: {"Unified_Ideograph", "Ideographic"},
    174185: {"Unified_Ideograph", "Ideographic"},
    174186: {"Unified_Ideograph", "Ideographic"},
    174187: {"Unified_Ideograph", "Ideographic"},
    174188: {"Unified_Ideograph", "Ideographic"},
    174189: {"Unified_Ideograph", "Ideographic"},
    174190: {"Unified_Ideograph", "Ideographic"},
    174191: {"Unified_Ideograph", "Ideographic"},
    174192: {"Unified_Ideograph", "Ideographic"},
    174193: {"Unified_Ideograph", "Ideographic"},
    174194: {"Unified_Ideograph", "Ideographic"},
    174195: {"Unified_Ideograph", "Ideographic"},
    174196: {"Unified_Ideograph", "Ideographic"},
    174197: {"Unified_Ideograph", "Ideographic"},
    174198: {"Unified_Ideograph", "Ideographic"},
    174199: {"Unified_Ideograph", "Ideographic"},
    174200: {"Unified_Ideograph", "Ideographic"},
    174201: {"Unified_Ideograph", "Ideographic"},
    174202: {"Unified_Ideograph", "Ideographic"},
    174203: {"Unified_Ideograph", "Ideographic"},
    174204: {"Unified_Ideograph", "Ideographic"},
    174205: {"Unified_Ideograph", "Ideographic"},
    174206: {"Unified_Ideograph", "Ideographic"},
    174207: {"Unified_Ideograph", "Ideographic"},
    174208: {"Unified_Ideograph", "Ideographic"},
    174209: {"Unified_Ideograph", "Ideographic"},
    174210: {"Unified_Ideograph", "Ideographic"},
    174211: {"Unified_Ideograph", "Ideographic"},
    174212: {"Unified_Ideograph", "Ideographic"},
    174213: {"Unified_Ideograph", "Ideographic"},
    174214: {"Unified_Ideograph", "Ideographic"},
    174215: {"Unified_Ideograph", "Ideographic"},
    174216: {"Unified_Ideograph", "Ideographic"},
    174217: {"Unified_Ideograph", "Ideographic"},
    174218: {"Unified_Ideograph", "Ideographic"},
    174219: {"Unified_Ideograph", "Ideographic"},
    174220: {"Unified_Ideograph", "Ideographic"},
    174221: {"Unified_Ideograph", "Ideographic"},
    174222: {"Unified_Ideograph", "Ideographic"},
    174223: {"Unified_Ideograph", "Ideographic"},
    174224: {"Unified_Ideograph", "Ideographic"},
    174225: {"Unified_Ideograph", "Ideographic"},
    174226: {"Unified_Ideograph", "Ideographic"},
    174227: {"Unified_Ideograph", "Ideographic"},
    174228: {"Unified_Ideograph", "Ideographic"},
    174229: {"Unified_Ideograph", "Ideographic"},
    174230: {"Unified_Ideograph", "Ideographic"},
    174231: {"Unified_Ideograph", "Ideographic"},
    174232: {"Unified_Ideograph", "Ideographic"},
    174233: {"Unified_Ideograph", "Ideographic"},
    174234: {"Unified_Ideograph", "Ideographic"},
    174235: {"Unified_Ideograph", "Ideographic"},
    174236: {"Unified_Ideograph", "Ideographic"},
    174237: {"Unified_Ideograph", "Ideographic"},
    174238: {"Unified_Ideograph", "Ideographic"},
    174239: {"Unified_Ideograph", "Ideographic"},
    174240: {"Unified_Ideograph", "Ideographic"},
    174241: {"Unified_Ideograph", "Ideographic"},
    174242: {"Unified_Ideograph", "Ideographic"},
    174243: {"Unified_Ideograph", "Ideographic"},
    174244: {"Unified_Ideograph", "Ideographic"},
    174245: {"Unified_Ideograph", "Ideographic"},
    174246: {"Unified_Ideograph", "Ideographic"},
    174247: {"Unified_Ideograph", "Ideographic"},
    174248: {"Unified_Ideograph", "Ideographic"},
    174249: {"Unified_Ideograph", "Ideographic"},
    174250: {"Unified_Ideograph", "Ideographic"},
    174251: {"Unified_Ideograph", "Ideographic"},
    174252: {"Unified_Ideograph", "Ideographic"},
    174253: {"Unified_Ideograph", "Ideographic"},
    174254: {"Unified_Ideograph", "Ideographic"},
    174255: {"Unified_Ideograph", "Ideographic"},
    174256: {"Unified_Ideograph", "Ideographic"},
    174257: {"Unified_Ideograph", "Ideographic"},
    174258: {"Unified_Ideograph", "Ideographic"},
    174259: {"Unified_Ideograph", "Ideographic"},
    174260: {"Unified_Ideograph", "Ideographic"},
    174261: {"Unified_Ideograph", "Ideographic"},
    174262: {"Unified_Ideograph", "Ideographic"},
    174263: {"Unified_Ideograph", "Ideographic"},
    174264: {"Unified_Ideograph", "Ideographic"},
    174265: {"Unified_Ideograph", "Ideographic"},
    174266: {"Unified_Ideograph", "Ideographic"},
    174267: {"Unified_Ideograph", "Ideographic"},
    174268: {"Unified_Ideograph", "Ideographic"},
    174269: {"Unified_Ideograph", "Ideographic"},
    174270: {"Unified_Ideograph", "Ideographic"},
    174271: {"Unified_Ideograph", "Ideographic"},
    174272: {"Unified_Ideograph", "Ideographic"},
    174273: {"Unified_Ideograph", "Ideographic"},
    174274: {"Unified_Ideograph", "Ideographic"},
    174275: {"Unified_Ideograph", "Ideographic"},
    174276: {"Unified_Ideograph", "Ideographic"},
    174277: {"Unified_Ideograph", "Ideographic"},
    174278: {"Unified_Ideograph", "Ideographic"},
    174279: {"Unified_Ideograph", "Ideographic"},
    174280: {"Unified_Ideograph", "Ideographic"},
    174281: {"Unified_Ideograph", "Ideographic"},
    174282: {"Unified_Ideograph", "Ideographic"},
    174283: {"Unified_Ideograph", "Ideographic"},
    174284: {"Unified_Ideograph", "Ideographic"},
    174285: {"Unified_Ideograph", "Ideographic"},
    174286: {"Unified_Ideograph", "Ideographic"},
    174287: {"Unified_Ideograph", "Ideographic"},
    174288: {"Unified_Ideograph", "Ideographic"},
    174289: {"Unified_Ideograph", "Ideographic"},
    174290: {"Unified_Ideograph", "Ideographic"},
    174291: {"Unified_Ideograph", "Ideographic"},
    174292: {"Unified_Ideograph", "Ideographic"},
    174293: {"Unified_Ideograph", "Ideographic"},
    174294: {"Unified_Ideograph", "Ideographic"},
    174295: {"Unified_Ideograph", "Ideographic"},
    174296: {"Unified_Ideograph", "Ideographic"},
    174297: {"Unified_Ideograph", "Ideographic"},
    174298: {"Unified_Ideograph", "Ideographic"},
    174299: {"Unified_Ideograph", "Ideographic"},
    174300: {"Unified_Ideograph", "Ideographic"},
    174301: {"Unified_Ideograph", "Ideographic"},
    174302: {"Unified_Ideograph", "Ideographic"},
    174303: {"Unified_Ideograph", "Ideographic"},
    174304: {"Unified_Ideograph", "Ideographic"},
    174305: {"Unified_Ideograph", "Ideographic"},
    174306: {"Unified_Ideograph", "Ideographic"},
    174307: {"Unified_Ideograph", "Ideographic"},
    174308: {"Unified_Ideograph", "Ideographic"},
    174309: {"Unified_Ideograph", "Ideographic"},
    174310: {"Unified_Ideograph", "Ideographic"},
    174311: {"Unified_Ideograph", "Ideographic"},
    174312: {"Unified_Ideograph", "Ideographic"},
    174313: {"Unified_Ideograph", "Ideographic"},
    174314: {"Unified_Ideograph", "Ideographic"},
    174315: {"Unified_Ideograph", "Ideographic"},
    174316: {"Unified_Ideograph", "Ideographic"},
    174317: {"Unified_Ideograph", "Ideographic"},
    174318: {"Unified_Ideograph", "Ideographic"},
    174319: {"Unified_Ideograph", "Ideographic"},
    174320: {"Unified_Ideograph", "Ideographic"},
    174321: {"Unified_Ideograph", "Ideographic"},
    174322: {"Unified_Ideograph", "Ideographic"},
    174323: {"Unified_Ideograph", "Ideographic"},
    174324: {"Unified_Ideograph", "Ideographic"},
    174325: {"Unified_Ideograph", "Ideographic"},
    174326: {"Unified_Ideograph", "Ideographic"},
    174327: {"Unified_Ideograph", "Ideographic"},
    174328: {"Unified_Ideograph", "Ideographic"},
    174329: {"Unified_Ideograph", "Ideographic"},
    174330: {"Unified_Ideograph", "Ideographic"},
    174331: {"Unified_Ideograph", "Ideographic"},
    174332: {"Unified_Ideograph", "Ideographic"},
    174333: {"Unified_Ideograph", "Ideographic"},
    174334: {"Unified_Ideograph", "Ideographic"},
    174335: {"Unified_Ideograph", "Ideographic"},
    174336: {"Unified_Ideograph", "Ideographic"},
    174337: {"Unified_Ideograph", "Ideographic"},
    174338: {"Unified_Ideograph", "Ideographic"},
    174339: {"Unified_Ideograph", "Ideographic"},
    174340: {"Unified_Ideograph", "Ideographic"},
    174341: {"Unified_Ideograph", "Ideographic"},
    174342: {"Unified_Ideograph", "Ideographic"},
    174343: {"Unified_Ideograph", "Ideographic"},
    174344: {"Unified_Ideograph", "Ideographic"},
    174345: {"Unified_Ideograph", "Ideographic"},
    174346: {"Unified_Ideograph", "Ideographic"},
    174347: {"Unified_Ideograph", "Ideographic"},
    174348: {"Unified_Ideograph", "Ideographic"},
    174349: {"Unified_Ideograph", "Ideographic"},
    174350: {"Unified_Ideograph", "Ideographic"},
    174351: {"Unified_Ideograph", "Ideographic"},
    174352: {"Unified_Ideograph", "Ideographic"},
    174353: {"Unified_Ideograph", "Ideographic"},
    174354: {"Unified_Ideograph", "Ideographic"},
    174355: {"Unified_Ideograph", "Ideographic"},
    174356: {"Unified_Ideograph", "Ideographic"},
    174357: {"Unified_Ideograph", "Ideographic"},
    174358: {"Unified_Ideograph", "Ideographic"},
    174359: {"Unified_Ideograph", "Ideographic"},
    174360: {"Unified_Ideograph", "Ideographic"},
    174361: {"Unified_Ideograph", "Ideographic"},
    174362: {"Unified_Ideograph", "Ideographic"},
    174363: {"Unified_Ideograph", "Ideographic"},
    174364: {"Unified_Ideograph", "Ideographic"},
    174365: {"Unified_Ideograph", "Ideographic"},
    174366: {"Unified_Ideograph", "Ideographic"},
    174367: {"Unified_Ideograph", "Ideographic"},
    174368: {"Unified_Ideograph", "Ideographic"},
    174369: {"Unified_Ideograph", "Ideographic"},
    174370: {"Unified_Ideograph", "Ideographic"},
    174371: {"Unified_Ideograph", "Ideographic"},
    174372: {"Unified_Ideograph", "Ideographic"},
    174373: {"Unified_Ideograph", "Ideographic"},
    174374: {"Unified_Ideograph", "Ideographic"},
    174375: {"Unified_Ideograph", "Ideographic"},
    174376: {"Unified_Ideograph", "Ideographic"},
    174377: {"Unified_Ideograph", "Ideographic"},
    174378: {"Unified_Ideograph", "Ideographic"},
    174379: {"Unified_Ideograph", "Ideographic"},
    174380: {"Unified_Ideograph", "Ideographic"},
    174381: {"Unified_Ideograph", "Ideographic"},
    174382: {"Unified_Ideograph", "Ideographic"},
    174383: {"Unified_Ideograph", "Ideographic"},
    174384: {"Unified_Ideograph", "Ideographic"},
    174385: {"Unified_Ideograph", "Ideographic"},
    174386: {"Unified_Ideograph", "Ideographic"},
    174387: {"Unified_Ideograph", "Ideographic"},
    174388: {"Unified_Ideograph", "Ideographic"},
    174389: {"Unified_Ideograph", "Ideographic"},
    174390: {"Unified_Ideograph", "Ideographic"},
    174391: {"Unified_Ideograph", "Ideographic"},
    174392: {"Unified_Ideograph", "Ideographic"},
    174393: {"Unified_Ideograph", "Ideographic"},
    174394: {"Unified_Ideograph", "Ideographic"},
    174395: {"Unified_Ideograph", "Ideographic"},
    174396: {"Unified_Ideograph", "Ideographic"},
    174397: {"Unified_Ideograph", "Ideographic"},
    174398: {"Unified_Ideograph", "Ideographic"},
    174399: {"Unified_Ideograph", "Ideographic"},
    174400: {"Unified_Ideograph", "Ideographic"},
    174401: {"Unified_Ideograph", "Ideographic"},
    174402: {"Unified_Ideograph", "Ideographic"},
    174403: {"Unified_Ideograph", "Ideographic"},
    174404: {"Unified_Ideograph", "Ideographic"},
    174405: {"Unified_Ideograph", "Ideographic"},
    174406: {"Unified_Ideograph", "Ideographic"},
    174407: {"Unified_Ideograph", "Ideographic"},
    174408: {"Unified_Ideograph", "Ideographic"},
    174409: {"Unified_Ideograph", "Ideographic"},
    174410: {"Unified_Ideograph", "Ideographic"},
    174411: {"Unified_Ideograph", "Ideographic"},
    174412: {"Unified_Ideograph", "Ideographic"},
    174413: {"Unified_Ideograph", "Ideographic"},
    174414: {"Unified_Ideograph", "Ideographic"},
    174415: {"Unified_Ideograph", "Ideographic"},
    174416: {"Unified_Ideograph", "Ideographic"},
    174417: {"Unified_Ideograph", "Ideographic"},
    174418: {"Unified_Ideograph", "Ideographic"},
    174419: {"Unified_Ideograph", "Ideographic"},
    174420: {"Unified_Ideograph", "Ideographic"},
    174421: {"Unified_Ideograph", "Ideographic"},
    174422: {"Unified_Ideograph", "Ideographic"},
    174423: {"Unified_Ideograph", "Ideographic"},
    174424: {"Unified_Ideograph", "Ideographic"},
    174425: {"Unified_Ideograph", "Ideographic"},
    174426: {"Unified_Ideograph", "Ideographic"},
    174427: {"Unified_Ideograph", "Ideographic"},
    174428: {"Unified_Ideograph", "Ideographic"},
    174429: {"Unified_Ideograph", "Ideographic"},
    174430: {"Unified_Ideograph", "Ideographic"},
    174431: {"Unified_Ideograph", "Ideographic"},
    174432: {"Unified_Ideograph", "Ideographic"},
    174433: {"Unified_Ideograph", "Ideographic"},
    174434: {"Unified_Ideograph", "Ideographic"},
    174435: {"Unified_Ideograph", "Ideographic"},
    174436: {"Unified_Ideograph", "Ideographic"},
    174437: {"Unified_Ideograph", "Ideographic"},
    174438: {"Unified_Ideograph", "Ideographic"},
    174439: {"Unified_Ideograph", "Ideographic"},
    174440: {"Unified_Ideograph", "Ideographic"},
    174441: {"Unified_Ideograph", "Ideographic"},
    174442: {"Unified_Ideograph", "Ideographic"},
    174443: {"Unified_Ideograph", "Ideographic"},
    174444: {"Unified_Ideograph", "Ideographic"},
    174445: {"Unified_Ideograph", "Ideographic"},
    174446: {"Unified_Ideograph", "Ideographic"},
    174447: {"Unified_Ideograph", "Ideographic"},
    174448: {"Unified_Ideograph", "Ideographic"},
    174449: {"Unified_Ideograph", "Ideographic"},
    174450: {"Unified_Ideograph", "Ideographic"},
    174451: {"Unified_Ideograph", "Ideographic"},
    174452: {"Unified_Ideograph", "Ideographic"},
    174453: {"Unified_Ideograph", "Ideographic"},
    174454: {"Unified_Ideograph", "Ideographic"},
    174455: {"Unified_Ideograph", "Ideographic"},
    174456: {"Unified_Ideograph", "Ideographic"},
    174457: {"Unified_Ideograph", "Ideographic"},
    174458: {"Unified_Ideograph", "Ideographic"},
    174459: {"Unified_Ideograph", "Ideographic"},
    174460: {"Unified_Ideograph", "Ideographic"},
    174461: {"Unified_Ideograph", "Ideographic"},
    174462: {"Unified_Ideograph", "Ideographic"},
    174463: {"Unified_Ideograph", "Ideographic"},
    174464: {"Unified_Ideograph", "Ideographic"},
    174465: {"Unified_Ideograph", "Ideographic"},
    174466: {"Unified_Ideograph", "Ideographic"},
    174467: {"Unified_Ideograph", "Ideographic"},
    174468: {"Unified_Ideograph", "Ideographic"},
    174469: {"Unified_Ideograph", "Ideographic"},
    174470: {"Unified_Ideograph", "Ideographic"},
    174471: {"Unified_Ideograph", "Ideographic"},
    174472: {"Unified_Ideograph", "Ideographic"},
    174473: {"Unified_Ideograph", "Ideographic"},
    174474: {"Unified_Ideograph", "Ideographic"},
    174475: {"Unified_Ideograph", "Ideographic"},
    174476: {"Unified_Ideograph", "Ideographic"},
    174477: {"Unified_Ideograph", "Ideographic"},
    174478: {"Unified_Ideograph", "Ideographic"},
    174479: {"Unified_Ideograph", "Ideographic"},
    174480: {"Unified_Ideograph", "Ideographic"},
    174481: {"Unified_Ideograph", "Ideographic"},
    174482: {"Unified_Ideograph", "Ideographic"},
    174483: {"Unified_Ideograph", "Ideographic"},
    174484: {"Unified_Ideograph", "Ideographic"},
    174485: {"Unified_Ideograph", "Ideographic"},
    174486: {"Unified_Ideograph", "Ideographic"},
    174487: {"Unified_Ideograph", "Ideographic"},
    174488: {"Unified_Ideograph", "Ideographic"},
    174489: {"Unified_Ideograph", "Ideographic"},
    174490: {"Unified_Ideograph", "Ideographic"},
    174491: {"Unified_Ideograph", "Ideographic"},
    174492: {"Unified_Ideograph", "Ideographic"},
    174493: {"Unified_Ideograph", "Ideographic"},
    174494: {"Unified_Ideograph", "Ideographic"},
    174495: {"Unified_Ideograph", "Ideographic"},
    174496: {"Unified_Ideograph", "Ideographic"},
    174497: {"Unified_Ideograph", "Ideographic"},
    174498: {"Unified_Ideograph", "Ideographic"},
    174499: {"Unified_Ideograph", "Ideographic"},
    174500: {"Unified_Ideograph", "Ideographic"},
    174501: {"Unified_Ideograph", "Ideographic"},
    174502: {"Unified_Ideograph", "Ideographic"},
    174503: {"Unified_Ideograph", "Ideographic"},
    174504: {"Unified_Ideograph", "Ideographic"},
    174505: {"Unified_Ideograph", "Ideographic"},
    174506: {"Unified_Ideograph", "Ideographic"},
    174507: {"Unified_Ideograph", "Ideographic"},
    174508: {"Unified_Ideograph", "Ideographic"},
    174509: {"Unified_Ideograph", "Ideographic"},
    174510: {"Unified_Ideograph", "Ideographic"},
    174511: {"Unified_Ideograph", "Ideographic"},
    174512: {"Unified_Ideograph", "Ideographic"},
    174513: {"Unified_Ideograph", "Ideographic"},
    174514: {"Unified_Ideograph", "Ideographic"},
    174515: {"Unified_Ideograph", "Ideographic"},
    174516: {"Unified_Ideograph", "Ideographic"},
    174517: {"Unified_Ideograph", "Ideographic"},
    174518: {"Unified_Ideograph", "Ideographic"},
    174519: {"Unified_Ideograph", "Ideographic"},
    174520: {"Unified_Ideograph", "Ideographic"},
    174521: {"Unified_Ideograph", "Ideographic"},
    174522: {"Unified_Ideograph", "Ideographic"},
    174523: {"Unified_Ideograph", "Ideographic"},
    174524: {"Unified_Ideograph", "Ideographic"},
    174525: {"Unified_Ideograph", "Ideographic"},
    174526: {"Unified_Ideograph", "Ideographic"},
    174527: {"Unified_Ideograph", "Ideographic"},
    174528: {"Unified_Ideograph", "Ideographic"},
    174529: {"Unified_Ideograph", "Ideographic"},
    174530: {"Unified_Ideograph", "Ideographic"},
    174531: {"Unified_Ideograph", "Ideographic"},
    174532: {"Unified_Ideograph", "Ideographic"},
    174533: {"Unified_Ideograph", "Ideographic"},
    174534: {"Unified_Ideograph", "Ideographic"},
    174535: {"Unified_Ideograph", "Ideographic"},
    174536: {"Unified_Ideograph", "Ideographic"},
    174537: {"Unified_Ideograph", "Ideographic"},
    174538: {"Unified_Ideograph", "Ideographic"},
    174539: {"Unified_Ideograph", "Ideographic"},
    174540: {"Unified_Ideograph", "Ideographic"},
    174541: {"Unified_Ideograph", "Ideographic"},
    174542: {"Unified_Ideograph", "Ideographic"},
    174543: {"Unified_Ideograph", "Ideographic"},
    174544: {"Unified_Ideograph", "Ideographic"},
    174545: {"Unified_Ideograph", "Ideographic"},
    174546: {"Unified_Ideograph", "Ideographic"},
    174547: {"Unified_Ideograph", "Ideographic"},
    174548: {"Unified_Ideograph", "Ideographic"},
    174549: {"Unified_Ideograph", "Ideographic"},
    174550: {"Unified_Ideograph", "Ideographic"},
    174551: {"Unified_Ideograph", "Ideographic"},
    174552: {"Unified_Ideograph", "Ideographic"},
    174553: {"Unified_Ideograph", "Ideographic"},
    174554: {"Unified_Ideograph", "Ideographic"},
    174555: {"Unified_Ideograph", "Ideographic"},
    174556: {"Unified_Ideograph", "Ideographic"},
    174557: {"Unified_Ideograph", "Ideographic"},
    174558: {"Unified_Ideograph", "Ideographic"},
    174559: {"Unified_Ideograph", "Ideographic"},
    174560: {"Unified_Ideograph", "Ideographic"},
    174561: {"Unified_Ideograph", "Ideographic"},
    174562: {"Unified_Ideograph", "Ideographic"},
    174563: {"Unified_Ideograph", "Ideographic"},
    174564: {"Unified_Ideograph", "Ideographic"},
    174565: {"Unified_Ideograph", "Ideographic"},
    174566: {"Unified_Ideograph", "Ideographic"},
    174567: {"Unified_Ideograph", "Ideographic"},
    174568: {"Unified_Ideograph", "Ideographic"},
    174569: {"Unified_Ideograph", "Ideographic"},
    174570: {"Unified_Ideograph", "Ideographic"},
    174571: {"Unified_Ideograph", "Ideographic"},
    174572: {"Unified_Ideograph", "Ideographic"},
    174573: {"Unified_Ideograph", "Ideographic"},
    174574: {"Unified_Ideograph", "Ideographic"},
    174575: {"Unified_Ideograph", "Ideographic"},
    174576: {"Unified_Ideograph", "Ideographic"},
    174577: {"Unified_Ideograph", "Ideographic"},
    174578: {"Unified_Ideograph", "Ideographic"},
    174579: {"Unified_Ideograph", "Ideographic"},
    174580: {"Unified_Ideograph", "Ideographic"},
    174581: {"Unified_Ideograph", "Ideographic"},
    174582: {"Unified_Ideograph", "Ideographic"},
    174583: {"Unified_Ideograph", "Ideographic"},
    174584: {"Unified_Ideograph", "Ideographic"},
    174585: {"Unified_Ideograph", "Ideographic"},
    174586: {"Unified_Ideograph", "Ideographic"},
    174587: {"Unified_Ideograph", "Ideographic"},
    174588: {"Unified_Ideograph", "Ideographic"},
    174589: {"Unified_Ideograph", "Ideographic"},
    174590: {"Unified_Ideograph", "Ideographic"},
    174591: {"Unified_Ideograph", "Ideographic"},
    174592: {"Unified_Ideograph", "Ideographic"},
    174593: {"Unified_Ideograph", "Ideographic"},
    174594: {"Unified_Ideograph", "Ideographic"},
    174595: {"Unified_Ideograph", "Ideographic"},
    174596: {"Unified_Ideograph", "Ideographic"},
    174597: {"Unified_Ideograph", "Ideographic"},
    174598: {"Unified_Ideograph", "Ideographic"},
    174599: {"Unified_Ideograph", "Ideographic"},
    174600: {"Unified_Ideograph", "Ideographic"},
    174601: {"Unified_Ideograph", "Ideographic"},
    174602: {"Unified_Ideograph", "Ideographic"},
    174603: {"Unified_Ideograph", "Ideographic"},
    174604: {"Unified_Ideograph", "Ideographic"},
    174605: {"Unified_Ideograph", "Ideographic"},
    174606: {"Unified_Ideograph", "Ideographic"},
    174607: {"Unified_Ideograph", "Ideographic"},
    174608: {"Unified_Ideograph", "Ideographic"},
    174609: {"Unified_Ideograph", "Ideographic"},
    174610: {"Unified_Ideograph", "Ideographic"},
    174611: {"Unified_Ideograph", "Ideographic"},
    174612: {"Unified_Ideograph", "Ideographic"},
    174613: {"Unified_Ideograph", "Ideographic"},
    174614: {"Unified_Ideograph", "Ideographic"},
    174615: {"Unified_Ideograph", "Ideographic"},
    174616: {"Unified_Ideograph", "Ideographic"},
    174617: {"Unified_Ideograph", "Ideographic"},
    174618: {"Unified_Ideograph", "Ideographic"},
    174619: {"Unified_Ideograph", "Ideographic"},
    174620: {"Unified_Ideograph", "Ideographic"},
    174621: {"Unified_Ideograph", "Ideographic"},
    174622: {"Unified_Ideograph", "Ideographic"},
    174623: {"Unified_Ideograph", "Ideographic"},
    174624: {"Unified_Ideograph", "Ideographic"},
    174625: {"Unified_Ideograph", "Ideographic"},
    174626: {"Unified_Ideograph", "Ideographic"},
    174627: {"Unified_Ideograph", "Ideographic"},
    174628: {"Unified_Ideograph", "Ideographic"},
    174629: {"Unified_Ideograph", "Ideographic"},
    174630: {"Unified_Ideograph", "Ideographic"},
    174631: {"Unified_Ideograph", "Ideographic"},
    174632: {"Unified_Ideograph", "Ideographic"},
    174633: {"Unified_Ideograph", "Ideographic"},
    174634: {"Unified_Ideograph", "Ideographic"},
    174635: {"Unified_Ideograph", "Ideographic"},
    174636: {"Unified_Ideograph", "Ideographic"},
    174637: {"Unified_Ideograph", "Ideographic"},
    174638: {"Unified_Ideograph", "Ideographic"},
    174639: {"Unified_Ideograph", "Ideographic"},
    174640: {"Unified_Ideograph", "Ideographic"},
    174641: {"Unified_Ideograph", "Ideographic"},
    174642: {"Unified_Ideograph", "Ideographic"},
    174643: {"Unified_Ideograph", "Ideographic"},
    174644: {"Unified_Ideograph", "Ideographic"},
    174645: {"Unified_Ideograph", "Ideographic"},
    174646: {"Unified_Ideograph", "Ideographic"},
    174647: {"Unified_Ideograph", "Ideographic"},
    174648: {"Unified_Ideograph", "Ideographic"},
    174649: {"Unified_Ideograph", "Ideographic"},
    174650: {"Unified_Ideograph", "Ideographic"},
    174651: {"Unified_Ideograph", "Ideographic"},
    174652: {"Unified_Ideograph", "Ideographic"},
    174653: {"Unified_Ideograph", "Ideographic"},
    174654: {"Unified_Ideograph", "Ideographic"},
    174655: {"Unified_Ideograph", "Ideographic"},
    174656: {"Unified_Ideograph", "Ideographic"},
    174657: {"Unified_Ideograph", "Ideographic"},
    174658: {"Unified_Ideograph", "Ideographic"},
    174659: {"Unified_Ideograph", "Ideographic"},
    174660: {"Unified_Ideograph", "Ideographic"},
    174661: {"Unified_Ideograph", "Ideographic"},
    174662: {"Unified_Ideograph", "Ideographic"},
    174663: {"Unified_Ideograph", "Ideographic"},
    174664: {"Unified_Ideograph", "Ideographic"},
    174665: {"Unified_Ideograph", "Ideographic"},
    174666: {"Unified_Ideograph", "Ideographic"},
    174667: {"Unified_Ideograph", "Ideographic"},
    174668: {"Unified_Ideograph", "Ideographic"},
    174669: {"Unified_Ideograph", "Ideographic"},
    174670: {"Unified_Ideograph", "Ideographic"},
    174671: {"Unified_Ideograph", "Ideographic"},
    174672: {"Unified_Ideograph", "Ideographic"},
    174673: {"Unified_Ideograph", "Ideographic"},
    174674: {"Unified_Ideograph", "Ideographic"},
    174675: {"Unified_Ideograph", "Ideographic"},
    174676: {"Unified_Ideograph", "Ideographic"},
    174677: {"Unified_Ideograph", "Ideographic"},
    174678: {"Unified_Ideograph", "Ideographic"},
    174679: {"Unified_Ideograph", "Ideographic"},
    174680: {"Unified_Ideograph", "Ideographic"},
    174681: {"Unified_Ideograph", "Ideographic"},
    174682: {"Unified_Ideograph", "Ideographic"},
    174683: {"Unified_Ideograph", "Ideographic"},
    174684: {"Unified_Ideograph", "Ideographic"},
    174685: {"Unified_Ideograph", "Ideographic"},
    174686: {"Unified_Ideograph", "Ideographic"},
    174687: {"Unified_Ideograph", "Ideographic"},
    174688: {"Unified_Ideograph", "Ideographic"},
    174689: {"Unified_Ideograph", "Ideographic"},
    174690: {"Unified_Ideograph", "Ideographic"},
    174691: {"Unified_Ideograph", "Ideographic"},
    174692: {"Unified_Ideograph", "Ideographic"},
    174693: {"Unified_Ideograph", "Ideographic"},
    174694: {"Unified_Ideograph", "Ideographic"},
    174695: {"Unified_Ideograph", "Ideographic"},
    174696: {"Unified_Ideograph", "Ideographic"},
    174697: {"Unified_Ideograph", "Ideographic"},
    174698: {"Unified_Ideograph", "Ideographic"},
    174699: {"Unified_Ideograph", "Ideographic"},
    174700: {"Unified_Ideograph", "Ideographic"},
    174701: {"Unified_Ideograph", "Ideographic"},
    174702: {"Unified_Ideograph", "Ideographic"},
    174703: {"Unified_Ideograph", "Ideographic"},
    174704: {"Unified_Ideograph", "Ideographic"},
    174705: {"Unified_Ideograph", "Ideographic"},
    174706: {"Unified_Ideograph", "Ideographic"},
    174707: {"Unified_Ideograph", "Ideographic"},
    174708: {"Unified_Ideograph", "Ideographic"},
    174709: {"Unified_Ideograph", "Ideographic"},
    174710: {"Unified_Ideograph", "Ideographic"},
    174711: {"Unified_Ideograph", "Ideographic"},
    174712: {"Unified_Ideograph", "Ideographic"},
    174713: {"Unified_Ideograph", "Ideographic"},
    174714: {"Unified_Ideograph", "Ideographic"},
    174715: {"Unified_Ideograph", "Ideographic"},
    174716: {"Unified_Ideograph", "Ideographic"},
    174717: {"Unified_Ideograph", "Ideographic"},
    174718: {"Unified_Ideograph", "Ideographic"},
    174719: {"Unified_Ideograph", "Ideographic"},
    174720: {"Unified_Ideograph", "Ideographic"},
    174721: {"Unified_Ideograph", "Ideographic"},
    174722: {"Unified_Ideograph", "Ideographic"},
    174723: {"Unified_Ideograph", "Ideographic"},
    174724: {"Unified_Ideograph", "Ideographic"},
    174725: {"Unified_Ideograph", "Ideographic"},
    174726: {"Unified_Ideograph", "Ideographic"},
    174727: {"Unified_Ideograph", "Ideographic"},
    174728: {"Unified_Ideograph", "Ideographic"},
    174729: {"Unified_Ideograph", "Ideographic"},
    174730: {"Unified_Ideograph", "Ideographic"},
    174731: {"Unified_Ideograph", "Ideographic"},
    174732: {"Unified_Ideograph", "Ideographic"},
    174733: {"Unified_Ideograph", "Ideographic"},
    174734: {"Unified_Ideograph", "Ideographic"},
    174735: {"Unified_Ideograph", "Ideographic"},
    174736: {"Unified_Ideograph", "Ideographic"},
    174737: {"Unified_Ideograph", "Ideographic"},
    174738: {"Unified_Ideograph", "Ideographic"},
    174739: {"Unified_Ideograph", "Ideographic"},
    174740: {"Unified_Ideograph", "Ideographic"},
    174741: {"Unified_Ideograph", "Ideographic"},
    174742: {"Unified_Ideograph", "Ideographic"},
    174743: {"Unified_Ideograph", "Ideographic"},
    174744: {"Unified_Ideograph", "Ideographic"},
    174745: {"Unified_Ideograph", "Ideographic"},
    174746: {"Unified_Ideograph", "Ideographic"},
    174747: {"Unified_Ideograph", "Ideographic"},
    174748: {"Unified_Ideograph", "Ideographic"},
    174749: {"Unified_Ideograph", "Ideographic"},
    174750: {"Unified_Ideograph", "Ideographic"},
    174751: {"Unified_Ideograph", "Ideographic"},
    174752: {"Unified_Ideograph", "Ideographic"},
    174753: {"Unified_Ideograph", "Ideographic"},
    174754: {"Unified_Ideograph", "Ideographic"},
    174755: {"Unified_Ideograph", "Ideographic"},
    174756: {"Unified_Ideograph", "Ideographic"},
    174757: {"Unified_Ideograph", "Ideographic"},
    174758: {"Unified_Ideograph", "Ideographic"},
    174759: {"Unified_Ideograph", "Ideographic"},
    174760: {"Unified_Ideograph", "Ideographic"},
    174761: {"Unified_Ideograph", "Ideographic"},
    174762: {"Unified_Ideograph", "Ideographic"},
    174763: {"Unified_Ideograph", "Ideographic"},
    174764: {"Unified_Ideograph", "Ideographic"},
    174765: {"Unified_Ideograph", "Ideographic"},
    174766: {"Unified_Ideograph", "Ideographic"},
    174767: {"Unified_Ideograph", "Ideographic"},
    174768: {"Unified_Ideograph", "Ideographic"},
    174769: {"Unified_Ideograph", "Ideographic"},
    174770: {"Unified_Ideograph", "Ideographic"},
    174771: {"Unified_Ideograph", "Ideographic"},
    174772: {"Unified_Ideograph", "Ideographic"},
    174773: {"Unified_Ideograph", "Ideographic"},
    174774: {"Unified_Ideograph", "Ideographic"},
    174775: {"Unified_Ideograph", "Ideographic"},
    174776: {"Unified_Ideograph", "Ideographic"},
    174777: {"Unified_Ideograph", "Ideographic"},
    174778: {"Unified_Ideograph", "Ideographic"},
    174779: {"Unified_Ideograph", "Ideographic"},
    174780: {"Unified_Ideograph", "Ideographic"},
    174781: {"Unified_Ideograph", "Ideographic"},
    174782: {"Unified_Ideograph", "Ideographic"},
    174783: {"Unified_Ideograph", "Ideographic"},
    174784: {"Unified_Ideograph", "Ideographic"},
    174785: {"Unified_Ideograph", "Ideographic"},
    174786: {"Unified_Ideograph", "Ideographic"},
    174787: {"Unified_Ideograph", "Ideographic"},
    174788: {"Unified_Ideograph", "Ideographic"},
    174789: {"Unified_Ideograph", "Ideographic"},
    174790: {"Unified_Ideograph", "Ideographic"},
    174791: {"Unified_Ideograph", "Ideographic"},
    174792: {"Unified_Ideograph", "Ideographic"},
    174793: {"Unified_Ideograph", "Ideographic"},
    174794: {"Unified_Ideograph", "Ideographic"},
    174795: {"Unified_Ideograph", "Ideographic"},
    174796: {"Unified_Ideograph", "Ideographic"},
    174797: {"Unified_Ideograph", "Ideographic"},
    174798: {"Unified_Ideograph", "Ideographic"},
    174799: {"Unified_Ideograph", "Ideographic"},
    174800: {"Unified_Ideograph", "Ideographic"},
    174801: {"Unified_Ideograph", "Ideographic"},
    174802: {"Unified_Ideograph", "Ideographic"},
    174803: {"Unified_Ideograph", "Ideographic"},
    174804: {"Unified_Ideograph", "Ideographic"},
    174805: {"Unified_Ideograph", "Ideographic"},
    174806: {"Unified_Ideograph", "Ideographic"},
    174807: {"Unified_Ideograph", "Ideographic"},
    174808: {"Unified_Ideograph", "Ideographic"},
    174809: {"Unified_Ideograph", "Ideographic"},
    174810: {"Unified_Ideograph", "Ideographic"},
    174811: {"Unified_Ideograph", "Ideographic"},
    174812: {"Unified_Ideograph", "Ideographic"},
    174813: {"Unified_Ideograph", "Ideographic"},
    174814: {"Unified_Ideograph", "Ideographic"},
    174815: {"Unified_Ideograph", "Ideographic"},
    174816: {"Unified_Ideograph", "Ideographic"},
    174817: {"Unified_Ideograph", "Ideographic"},
    174818: {"Unified_Ideograph", "Ideographic"},
    174819: {"Unified_Ideograph", "Ideographic"},
    174820: {"Unified_Ideograph", "Ideographic"},
    174821: {"Unified_Ideograph", "Ideographic"},
    174822: {"Unified_Ideograph", "Ideographic"},
    174823: {"Unified_Ideograph", "Ideographic"},
    174824: {"Unified_Ideograph", "Ideographic"},
    174825: {"Unified_Ideograph", "Ideographic"},
    174826: {"Unified_Ideograph", "Ideographic"},
    174827: {"Unified_Ideograph", "Ideographic"},
    174828: {"Unified_Ideograph", "Ideographic"},
    174829: {"Unified_Ideograph", "Ideographic"},
    174830: {"Unified_Ideograph", "Ideographic"},
    174831: {"Unified_Ideograph", "Ideographic"},
    174832: {"Unified_Ideograph", "Ideographic"},
    174833: {"Unified_Ideograph", "Ideographic"},
    174834: {"Unified_Ideograph", "Ideographic"},
    174835: {"Unified_Ideograph", "Ideographic"},
    174836: {"Unified_Ideograph", "Ideographic"},
    174837: {"Unified_Ideograph", "Ideographic"},
    174838: {"Unified_Ideograph", "Ideographic"},
    174839: {"Unified_Ideograph", "Ideographic"},
    174840: {"Unified_Ideograph", "Ideographic"},
    174841: {"Unified_Ideograph", "Ideographic"},
    174842: {"Unified_Ideograph", "Ideographic"},
    174843: {"Unified_Ideograph", "Ideographic"},
    174844: {"Unified_Ideograph", "Ideographic"},
    174845: {"Unified_Ideograph", "Ideographic"},
    174846: {"Unified_Ideograph", "Ideographic"},
    174847: {"Unified_Ideograph", "Ideographic"},
    174848: {"Unified_Ideograph", "Ideographic"},
    174849: {"Unified_Ideograph", "Ideographic"},
    174850: {"Unified_Ideograph", "Ideographic"},
    174851: {"Unified_Ideograph", "Ideographic"},
    174852: {"Unified_Ideograph", "Ideographic"},
    174853: {"Unified_Ideograph", "Ideographic"},
    174854: {"Unified_Ideograph", "Ideographic"},
    174855: {"Unified_Ideograph", "Ideographic"},
    174856: {"Unified_Ideograph", "Ideographic"},
    174857: {"Unified_Ideograph", "Ideographic"},
    174858: {"Unified_Ideograph", "Ideographic"},
    174859: {"Unified_Ideograph", "Ideographic"},
    174860: {"Unified_Ideograph", "Ideographic"},
    174861: {"Unified_Ideograph", "Ideographic"},
    174862: {"Unified_Ideograph", "Ideographic"},
    174863: {"Unified_Ideograph", "Ideographic"},
    174864: {"Unified_Ideograph", "Ideographic"},
    174865: {"Unified_Ideograph", "Ideographic"},
    174866: {"Unified_Ideograph", "Ideographic"},
    174867: {"Unified_Ideograph", "Ideographic"},
    174868: {"Unified_Ideograph", "Ideographic"},
    174869: {"Unified_Ideograph", "Ideographic"},
    174870: {"Unified_Ideograph", "Ideographic"},
    174871: {"Unified_Ideograph", "Ideographic"},
    174872: {"Unified_Ideograph", "Ideographic"},
    174873: {"Unified_Ideograph", "Ideographic"},
    174874: {"Unified_Ideograph", "Ideographic"},
    174875: {"Unified_Ideograph", "Ideographic"},
    174876: {"Unified_Ideograph", "Ideographic"},
    174877: {"Unified_Ideograph", "Ideographic"},
    174878: {"Unified_Ideograph", "Ideographic"},
    174879: {"Unified_Ideograph", "Ideographic"},
    174880: {"Unified_Ideograph", "Ideographic"},
    174881: {"Unified_Ideograph", "Ideographic"},
    174882: {"Unified_Ideograph", "Ideographic"},
    174883: {"Unified_Ideograph", "Ideographic"},
    174884: {"Unified_Ideograph", "Ideographic"},
    174885: {"Unified_Ideograph", "Ideographic"},
    174886: {"Unified_Ideograph", "Ideographic"},
    174887: {"Unified_Ideograph", "Ideographic"},
    174888: {"Unified_Ideograph", "Ideographic"},
    174889: {"Unified_Ideograph", "Ideographic"},
    174890: {"Unified_Ideograph", "Ideographic"},
    174891: {"Unified_Ideograph", "Ideographic"},
    174892: {"Unified_Ideograph", "Ideographic"},
    174893: {"Unified_Ideograph", "Ideographic"},
    174894: {"Unified_Ideograph", "Ideographic"},
    174895: {"Unified_Ideograph", "Ideographic"},
    174896: {"Unified_Ideograph", "Ideographic"},
    174897: {"Unified_Ideograph", "Ideographic"},
    174898: {"Unified_Ideograph", "Ideographic"},
    174899: {"Unified_Ideograph", "Ideographic"},
    174900: {"Unified_Ideograph", "Ideographic"},
    174901: {"Unified_Ideograph", "Ideographic"},
    174902: {"Unified_Ideograph", "Ideographic"},
    174903: {"Unified_Ideograph", "Ideographic"},
    174904: {"Unified_Ideograph", "Ideographic"},
    174905: {"Unified_Ideograph", "Ideographic"},
    174906: {"Unified_Ideograph", "Ideographic"},
    174907: {"Unified_Ideograph", "Ideographic"},
    174908: {"Unified_Ideograph", "Ideographic"},
    174909: {"Unified_Ideograph", "Ideographic"},
    174910: {"Unified_Ideograph", "Ideographic"},
    174911: {"Unified_Ideograph", "Ideographic"},
    174912: {"Unified_Ideograph", "Ideographic"},
    174913: {"Unified_Ideograph", "Ideographic"},
    174914: {"Unified_Ideograph", "Ideographic"},
    174915: {"Unified_Ideograph", "Ideographic"},
    174916: {"Unified_Ideograph", "Ideographic"},
    174917: {"Unified_Ideograph", "Ideographic"},
    174918: {"Unified_Ideograph", "Ideographic"},
    174919: {"Unified_Ideograph", "Ideographic"},
    174920: {"Unified_Ideograph", "Ideographic"},
    174921: {"Unified_Ideograph", "Ideographic"},
    174922: {"Unified_Ideograph", "Ideographic"},
    174923: {"Unified_Ideograph", "Ideographic"},
    174924: {"Unified_Ideograph", "Ideographic"},
    174925: {"Unified_Ideograph", "Ideographic"},
    174926: {"Unified_Ideograph", "Ideographic"},
    174927: {"Unified_Ideograph", "Ideographic"},
    174928: {"Unified_Ideograph", "Ideographic"},
    174929: {"Unified_Ideograph", "Ideographic"},
    174930: {"Unified_Ideograph", "Ideographic"},
    174931: {"Unified_Ideograph", "Ideographic"},
    174932: {"Unified_Ideograph", "Ideographic"},
    174933: {"Unified_Ideograph", "Ideographic"},
    174934: {"Unified_Ideograph", "Ideographic"},
    174935: {"Unified_Ideograph", "Ideographic"},
    174936: {"Unified_Ideograph", "Ideographic"},
    174937: {"Unified_Ideograph", "Ideographic"},
    174938: {"Unified_Ideograph", "Ideographic"},
    174939: {"Unified_Ideograph", "Ideographic"},
    174940: {"Unified_Ideograph", "Ideographic"},
    174941: {"Unified_Ideograph", "Ideographic"},
    174942: {"Unified_Ideograph", "Ideographic"},
    174943: {"Unified_Ideograph", "Ideographic"},
    174944: {"Unified_Ideograph", "Ideographic"},
    174945: {"Unified_Ideograph", "Ideographic"},
    174946: {"Unified_Ideograph", "Ideographic"},
    174947: {"Unified_Ideograph", "Ideographic"},
    174948: {"Unified_Ideograph", "Ideographic"},
    174949: {"Unified_Ideograph", "Ideographic"},
    174950: {"Unified_Ideograph", "Ideographic"},
    174951: {"Unified_Ideograph", "Ideographic"},
    174952: {"Unified_Ideograph", "Ideographic"},
    174953: {"Unified_Ideograph", "Ideographic"},
    174954: {"Unified_Ideograph", "Ideographic"},
    174955: {"Unified_Ideograph", "Ideographic"},
    174956: {"Unified_Ideograph", "Ideographic"},
    174957: {"Unified_Ideograph", "Ideographic"},
    174958: {"Unified_Ideograph", "Ideographic"},
    174959: {"Unified_Ideograph", "Ideographic"},
    174960: {"Unified_Ideograph", "Ideographic"},
    174961: {"Unified_Ideograph", "Ideographic"},
    174962: {"Unified_Ideograph", "Ideographic"},
    174963: {"Unified_Ideograph", "Ideographic"},
    174964: {"Unified_Ideograph", "Ideographic"},
    174965: {"Unified_Ideograph", "Ideographic"},
    174966: {"Unified_Ideograph", "Ideographic"},
    174967: {"Unified_Ideograph", "Ideographic"},
    174968: {"Unified_Ideograph", "Ideographic"},
    174969: {"Unified_Ideograph", "Ideographic"},
    174970: {"Unified_Ideograph", "Ideographic"},
    174971: {"Unified_Ideograph", "Ideographic"},
    174972: {"Unified_Ideograph", "Ideographic"},
    174973: {"Unified_Ideograph", "Ideographic"},
    174974: {"Unified_Ideograph", "Ideographic"},
    174975: {"Unified_Ideograph", "Ideographic"},
    174976: {"Unified_Ideograph", "Ideographic"},
    174977: {"Unified_Ideograph", "Ideographic"},
    174978: {"Unified_Ideograph", "Ideographic"},
    174979: {"Unified_Ideograph", "Ideographic"},
    174980: {"Unified_Ideograph", "Ideographic"},
    174981: {"Unified_Ideograph", "Ideographic"},
    174982: {"Unified_Ideograph", "Ideographic"},
    174983: {"Unified_Ideograph", "Ideographic"},
    174984: {"Unified_Ideograph", "Ideographic"},
    174985: {"Unified_Ideograph", "Ideographic"},
    174986: {"Unified_Ideograph", "Ideographic"},
    174987: {"Unified_Ideograph", "Ideographic"},
    174988: {"Unified_Ideograph", "Ideographic"},
    174989: {"Unified_Ideograph", "Ideographic"},
    174990: {"Unified_Ideograph", "Ideographic"},
    174991: {"Unified_Ideograph", "Ideographic"},
    174992: {"Unified_Ideograph", "Ideographic"},
    174993: {"Unified_Ideograph", "Ideographic"},
    174994: {"Unified_Ideograph", "Ideographic"},
    174995: {"Unified_Ideograph", "Ideographic"},
    174996: {"Unified_Ideograph", "Ideographic"},
    174997: {"Unified_Ideograph", "Ideographic"},
    174998: {"Unified_Ideograph", "Ideographic"},
    174999: {"Unified_Ideograph", "Ideographic"},
    175000: {"Unified_Ideograph", "Ideographic"},
    175001: {"Unified_Ideograph", "Ideographic"},
    175002: {"Unified_Ideograph", "Ideographic"},
    175003: {"Unified_Ideograph", "Ideographic"},
    175004: {"Unified_Ideograph", "Ideographic"},
    175005: {"Unified_Ideograph", "Ideographic"},
    175006: {"Unified_Ideograph", "Ideographic"},
    175007: {"Unified_Ideograph", "Ideographic"},
    175008: {"Unified_Ideograph", "Ideographic"},
    175009: {"Unified_Ideograph", "Ideographic"},
    175010: {"Unified_Ideograph", "Ideographic"},
    175011: {"Unified_Ideograph", "Ideographic"},
    175012: {"Unified_Ideograph", "Ideographic"},
    175013: {"Unified_Ideograph", "Ideographic"},
    175014: {"Unified_Ideograph", "Ideographic"},
    175015: {"Unified_Ideograph", "Ideographic"},
    175016: {"Unified_Ideograph", "Ideographic"},
    175017: {"Unified_Ideograph", "Ideographic"},
    175018: {"Unified_Ideograph", "Ideographic"},
    175019: {"Unified_Ideograph", "Ideographic"},
    175020: {"Unified_Ideograph", "Ideographic"},
    175021: {"Unified_Ideograph", "Ideographic"},
    175022: {"Unified_Ideograph", "Ideographic"},
    175023: {"Unified_Ideograph", "Ideographic"},
    175024: {"Unified_Ideograph", "Ideographic"},
    175025: {"Unified_Ideograph", "Ideographic"},
    175026: {"Unified_Ideograph", "Ideographic"},
    175027: {"Unified_Ideograph", "Ideographic"},
    175028: {"Unified_Ideograph", "Ideographic"},
    175029: {"Unified_Ideograph", "Ideographic"},
    175030: {"Unified_Ideograph", "Ideographic"},
    175031: {"Unified_Ideograph", "Ideographic"},
    175032: {"Unified_Ideograph", "Ideographic"},
    175033: {"Unified_Ideograph", "Ideographic"},
    175034: {"Unified_Ideograph", "Ideographic"},
    175035: {"Unified_Ideograph", "Ideographic"},
    175036: {"Unified_Ideograph", "Ideographic"},
    175037: {"Unified_Ideograph", "Ideographic"},
    175038: {"Unified_Ideograph", "Ideographic"},
    175039: {"Unified_Ideograph", "Ideographic"},
    175040: {"Unified_Ideograph", "Ideographic"},
    175041: {"Unified_Ideograph", "Ideographic"},
    175042: {"Unified_Ideograph", "Ideographic"},
    175043: {"Unified_Ideograph", "Ideographic"},
    175044: {"Unified_Ideograph", "Ideographic"},
    175045: {"Unified_Ideograph", "Ideographic"},
    175046: {"Unified_Ideograph", "Ideographic"},
    175047: {"Unified_Ideograph", "Ideographic"},
    175048: {"Unified_Ideograph", "Ideographic"},
    175049: {"Unified_Ideograph", "Ideographic"},
    175050: {"Unified_Ideograph", "Ideographic"},
    175051: {"Unified_Ideograph", "Ideographic"},
    175052: {"Unified_Ideograph", "Ideographic"},
    175053: {"Unified_Ideograph", "Ideographic"},
    175054: {"Unified_Ideograph", "Ideographic"},
    175055: {"Unified_Ideograph", "Ideographic"},
    175056: {"Unified_Ideograph", "Ideographic"},
    175057: {"Unified_Ideograph", "Ideographic"},
    175058: {"Unified_Ideograph", "Ideographic"},
    175059: {"Unified_Ideograph", "Ideographic"},
    175060: {"Unified_Ideograph", "Ideographic"},
    175061: {"Unified_Ideograph", "Ideographic"},
    175062: {"Unified_Ideograph", "Ideographic"},
    175063: {"Unified_Ideograph", "Ideographic"},
    175064: {"Unified_Ideograph", "Ideographic"},
    175065: {"Unified_Ideograph", "Ideographic"},
    175066: {"Unified_Ideograph", "Ideographic"},
    175067: {"Unified_Ideograph", "Ideographic"},
    175068: {"Unified_Ideograph", "Ideographic"},
    175069: {"Unified_Ideograph", "Ideographic"},
    175070: {"Unified_Ideograph", "Ideographic"},
    175071: {"Unified_Ideograph", "Ideographic"},
    175072: {"Unified_Ideograph", "Ideographic"},
    175073: {"Unified_Ideograph", "Ideographic"},
    175074: {"Unified_Ideograph", "Ideographic"},
    175075: {"Unified_Ideograph", "Ideographic"},
    175076: {"Unified_Ideograph", "Ideographic"},
    175077: {"Unified_Ideograph", "Ideographic"},
    175078: {"Unified_Ideograph", "Ideographic"},
    175079: {"Unified_Ideograph", "Ideographic"},
    175080: {"Unified_Ideograph", "Ideographic"},
    175081: {"Unified_Ideograph", "Ideographic"},
    175082: {"Unified_Ideograph", "Ideographic"},
    175083: {"Unified_Ideograph", "Ideographic"},
    175084: {"Unified_Ideograph", "Ideographic"},
    175085: {"Unified_Ideograph", "Ideographic"},
    175086: {"Unified_Ideograph", "Ideographic"},
    175087: {"Unified_Ideograph", "Ideographic"},
    175088: {"Unified_Ideograph", "Ideographic"},
    175089: {"Unified_Ideograph", "Ideographic"},
    175090: {"Unified_Ideograph", "Ideographic"},
    175091: {"Unified_Ideograph", "Ideographic"},
    175092: {"Unified_Ideograph", "Ideographic"},
    175093: {"Unified_Ideograph", "Ideographic"},
    175094: {"Unified_Ideograph", "Ideographic"},
    175095: {"Unified_Ideograph", "Ideographic"},
    175096: {"Unified_Ideograph", "Ideographic"},
    175097: {"Unified_Ideograph", "Ideographic"},
    175098: {"Unified_Ideograph", "Ideographic"},
    175099: {"Unified_Ideograph", "Ideographic"},
    175100: {"Unified_Ideograph", "Ideographic"},
    175101: {"Unified_Ideograph", "Ideographic"},
    175102: {"Unified_Ideograph", "Ideographic"},
    175103: {"Unified_Ideograph", "Ideographic"},
    175104: {"Unified_Ideograph", "Ideographic"},
    175105: {"Unified_Ideograph", "Ideographic"},
    175106: {"Unified_Ideograph", "Ideographic"},
    175107: {"Unified_Ideograph", "Ideographic"},
    175108: {"Unified_Ideograph", "Ideographic"},
    175109: {"Unified_Ideograph", "Ideographic"},
    175110: {"Unified_Ideograph", "Ideographic"},
    175111: {"Unified_Ideograph", "Ideographic"},
    175112: {"Unified_Ideograph", "Ideographic"},
    175113: {"Unified_Ideograph", "Ideographic"},
    175114: {"Unified_Ideograph", "Ideographic"},
    175115: {"Unified_Ideograph", "Ideographic"},
    175116: {"Unified_Ideograph", "Ideographic"},
    175117: {"Unified_Ideograph", "Ideographic"},
    175118: {"Unified_Ideograph", "Ideographic"},
    175119: {"Unified_Ideograph", "Ideographic"},
    175120: {"Unified_Ideograph", "Ideographic"},
    175121: {"Unified_Ideograph", "Ideographic"},
    175122: {"Unified_Ideograph", "Ideographic"},
    175123: {"Unified_Ideograph", "Ideographic"},
    175124: {"Unified_Ideograph", "Ideographic"},
    175125: {"Unified_Ideograph", "Ideographic"},
    175126: {"Unified_Ideograph", "Ideographic"},
    175127: {"Unified_Ideograph", "Ideographic"},
    175128: {"Unified_Ideograph", "Ideographic"},
    175129: {"Unified_Ideograph", "Ideographic"},
    175130: {"Unified_Ideograph", "Ideographic"},
    175131: {"Unified_Ideograph", "Ideographic"},
    175132: {"Unified_Ideograph", "Ideographic"},
    175133: {"Unified_Ideograph", "Ideographic"},
    175134: {"Unified_Ideograph", "Ideographic"},
    175135: {"Unified_Ideograph", "Ideographic"},
    175136: {"Unified_Ideograph", "Ideographic"},
    175137: {"Unified_Ideograph", "Ideographic"},
    175138: {"Unified_Ideograph", "Ideographic"},
    175139: {"Unified_Ideograph", "Ideographic"},
    175140: {"Unified_Ideograph", "Ideographic"},
    175141: {"Unified_Ideograph", "Ideographic"},
    175142: {"Unified_Ideograph", "Ideographic"},
    175143: {"Unified_Ideograph", "Ideographic"},
    175144: {"Unified_Ideograph", "Ideographic"},
    175145: {"Unified_Ideograph", "Ideographic"},
    175146: {"Unified_Ideograph", "Ideographic"},
    175147: {"Unified_Ideograph", "Ideographic"},
    175148: {"Unified_Ideograph", "Ideographic"},
    175149: {"Unified_Ideograph", "Ideographic"},
    175150: {"Unified_Ideograph", "Ideographic"},
    175151: {"Unified_Ideograph", "Ideographic"},
    175152: {"Unified_Ideograph", "Ideographic"},
    175153: {"Unified_Ideograph", "Ideographic"},
    175154: {"Unified_Ideograph", "Ideographic"},
    175155: {"Unified_Ideograph", "Ideographic"},
    175156: {"Unified_Ideograph", "Ideographic"},
    175157: {"Unified_Ideograph", "Ideographic"},
    175158: {"Unified_Ideograph", "Ideographic"},
    175159: {"Unified_Ideograph", "Ideographic"},
    175160: {"Unified_Ideograph", "Ideographic"},
    175161: {"Unified_Ideograph", "Ideographic"},
    175162: {"Unified_Ideograph", "Ideographic"},
    175163: {"Unified_Ideograph", "Ideographic"},
    175164: {"Unified_Ideograph", "Ideographic"},
    175165: {"Unified_Ideograph", "Ideographic"},
    175166: {"Unified_Ideograph", "Ideographic"},
    175167: {"Unified_Ideograph", "Ideographic"},
    175168: {"Unified_Ideograph", "Ideographic"},
    175169: {"Unified_Ideograph", "Ideographic"},
    175170: {"Unified_Ideograph", "Ideographic"},
    175171: {"Unified_Ideograph", "Ideographic"},
    175172: {"Unified_Ideograph", "Ideographic"},
    175173: {"Unified_Ideograph", "Ideographic"},
    175174: {"Unified_Ideograph", "Ideographic"},
    175175: {"Unified_Ideograph", "Ideographic"},
    175176: {"Unified_Ideograph", "Ideographic"},
    175177: {"Unified_Ideograph", "Ideographic"},
    175178: {"Unified_Ideograph", "Ideographic"},
    175179: {"Unified_Ideograph", "Ideographic"},
    175180: {"Unified_Ideograph", "Ideographic"},
    175181: {"Unified_Ideograph", "Ideographic"},
    175182: {"Unified_Ideograph", "Ideographic"},
    175183: {"Unified_Ideograph", "Ideographic"},
    175184: {"Unified_Ideograph", "Ideographic"},
    175185: {"Unified_Ideograph", "Ideographic"},
    175186: {"Unified_Ideograph", "Ideographic"},
    175187: {"Unified_Ideograph", "Ideographic"},
    175188: {"Unified_Ideograph", "Ideographic"},
    175189: {"Unified_Ideograph", "Ideographic"},
    175190: {"Unified_Ideograph", "Ideographic"},
    175191: {"Unified_Ideograph", "Ideographic"},
    175192: {"Unified_Ideograph", "Ideographic"},
    175193: {"Unified_Ideograph", "Ideographic"},
    175194: {"Unified_Ideograph", "Ideographic"},
    175195: {"Unified_Ideograph", "Ideographic"},
    175196: {"Unified_Ideograph", "Ideographic"},
    175197: {"Unified_Ideograph", "Ideographic"},
    175198: {"Unified_Ideograph", "Ideographic"},
    175199: {"Unified_Ideograph", "Ideographic"},
    175200: {"Unified_Ideograph", "Ideographic"},
    175201: {"Unified_Ideograph", "Ideographic"},
    175202: {"Unified_Ideograph", "Ideographic"},
    175203: {"Unified_Ideograph", "Ideographic"},
    175204: {"Unified_Ideograph", "Ideographic"},
    175205: {"Unified_Ideograph", "Ideographic"},
    175206: {"Unified_Ideograph", "Ideographic"},
    175207: {"Unified_Ideograph", "Ideographic"},
    175208: {"Unified_Ideograph", "Ideographic"},
    175209: {"Unified_Ideograph", "Ideographic"},
    175210: {"Unified_Ideograph", "Ideographic"},
    175211: {"Unified_Ideograph", "Ideographic"},
    175212: {"Unified_Ideograph", "Ideographic"},
    175213: {"Unified_Ideograph", "Ideographic"},
    175214: {"Unified_Ideograph", "Ideographic"},
    175215: {"Unified_Ideograph", "Ideographic"},
    175216: {"Unified_Ideograph", "Ideographic"},
    175217: {"Unified_Ideograph", "Ideographic"},
    175218: {"Unified_Ideograph", "Ideographic"},
    175219: {"Unified_Ideograph", "Ideographic"},
    175220: {"Unified_Ideograph", "Ideographic"},
    175221: {"Unified_Ideograph", "Ideographic"},
    175222: {"Unified_Ideograph", "Ideographic"},
    175223: {"Unified_Ideograph", "Ideographic"},
    175224: {"Unified_Ideograph", "Ideographic"},
    175225: {"Unified_Ideograph", "Ideographic"},
    175226: {"Unified_Ideograph", "Ideographic"},
    175227: {"Unified_Ideograph", "Ideographic"},
    175228: {"Unified_Ideograph", "Ideographic"},
    175229: {"Unified_Ideograph", "Ideographic"},
    175230: {"Unified_Ideograph", "Ideographic"},
    175231: {"Unified_Ideograph", "Ideographic"},
    175232: {"Unified_Ideograph", "Ideographic"},
    175233: {"Unified_Ideograph", "Ideographic"},
    175234: {"Unified_Ideograph", "Ideographic"},
    175235: {"Unified_Ideograph", "Ideographic"},
    175236: {"Unified_Ideograph", "Ideographic"},
    175237: {"Unified_Ideograph", "Ideographic"},
    175238: {"Unified_Ideograph", "Ideographic"},
    175239: {"Unified_Ideograph", "Ideographic"},
    175240: {"Unified_Ideograph", "Ideographic"},
    175241: {"Unified_Ideograph", "Ideographic"},
    175242: {"Unified_Ideograph", "Ideographic"},
    175243: {"Unified_Ideograph", "Ideographic"},
    175244: {"Unified_Ideograph", "Ideographic"},
    175245: {"Unified_Ideograph", "Ideographic"},
    175246: {"Unified_Ideograph", "Ideographic"},
    175247: {"Unified_Ideograph", "Ideographic"},
    175248: {"Unified_Ideograph", "Ideographic"},
    175249: {"Unified_Ideograph", "Ideographic"},
    175250: {"Unified_Ideograph", "Ideographic"},
    175251: {"Unified_Ideograph", "Ideographic"},
    175252: {"Unified_Ideograph", "Ideographic"},
    175253: {"Unified_Ideograph", "Ideographic"},
    175254: {"Unified_Ideograph", "Ideographic"},
    175255: {"Unified_Ideograph", "Ideographic"},
    175256: {"Unified_Ideograph", "Ideographic"},
    175257: {"Unified_Ideograph", "Ideographic"},
    175258: {"Unified_Ideograph", "Ideographic"},
    175259: {"Unified_Ideograph", "Ideographic"},
    175260: {"Unified_Ideograph", "Ideographic"},
    175261: {"Unified_Ideograph", "Ideographic"},
    175262: {"Unified_Ideograph", "Ideographic"},
    175263: {"Unified_Ideograph", "Ideographic"},
    175264: {"Unified_Ideograph", "Ideographic"},
    175265: {"Unified_Ideograph", "Ideographic"},
    175266: {"Unified_Ideograph", "Ideographic"},
    175267: {"Unified_Ideograph", "Ideographic"},
    175268: {"Unified_Ideograph", "Ideographic"},
    175269: {"Unified_Ideograph", "Ideographic"},
    175270: {"Unified_Ideograph", "Ideographic"},
    175271: {"Unified_Ideograph", "Ideographic"},
    175272: {"Unified_Ideograph", "Ideographic"},
    175273: {"Unified_Ideograph", "Ideographic"},
    175274: {"Unified_Ideograph", "Ideographic"},
    175275: {"Unified_Ideograph", "Ideographic"},
    175276: {"Unified_Ideograph", "Ideographic"},
    175277: {"Unified_Ideograph", "Ideographic"},
    175278: {"Unified_Ideograph", "Ideographic"},
    175279: {"Unified_Ideograph", "Ideographic"},
    175280: {"Unified_Ideograph", "Ideographic"},
    175281: {"Unified_Ideograph", "Ideographic"},
    175282: {"Unified_Ideograph", "Ideographic"},
    175283: {"Unified_Ideograph", "Ideographic"},
    175284: {"Unified_Ideograph", "Ideographic"},
    175285: {"Unified_Ideograph", "Ideographic"},
    175286: {"Unified_Ideograph", "Ideographic"},
    175287: {"Unified_Ideograph", "Ideographic"},
    175288: {"Unified_Ideograph", "Ideographic"},
    175289: {"Unified_Ideograph", "Ideographic"},
    175290: {"Unified_Ideograph", "Ideographic"},
    175291: {"Unified_Ideograph", "Ideographic"},
    175292: {"Unified_Ideograph", "Ideographic"},
    175293: {"Unified_Ideograph", "Ideographic"},
    175294: {"Unified_Ideograph", "Ideographic"},
    175295: {"Unified_Ideograph", "Ideographic"},
    175296: {"Unified_Ideograph", "Ideographic"},
    175297: {"Unified_Ideograph", "Ideographic"},
    175298: {"Unified_Ideograph", "Ideographic"},
    175299: {"Unified_Ideograph", "Ideographic"},
    175300: {"Unified_Ideograph", "Ideographic"},
    175301: {"Unified_Ideograph", "Ideographic"},
    175302: {"Unified_Ideograph", "Ideographic"},
    175303: {"Unified_Ideograph", "Ideographic"},
    175304: {"Unified_Ideograph", "Ideographic"},
    175305: {"Unified_Ideograph", "Ideographic"},
    175306: {"Unified_Ideograph", "Ideographic"},
    175307: {"Unified_Ideograph", "Ideographic"},
    175308: {"Unified_Ideograph", "Ideographic"},
    175309: {"Unified_Ideograph", "Ideographic"},
    175310: {"Unified_Ideograph", "Ideographic"},
    175311: {"Unified_Ideograph", "Ideographic"},
    175312: {"Unified_Ideograph", "Ideographic"},
    175313: {"Unified_Ideograph", "Ideographic"},
    175314: {"Unified_Ideograph", "Ideographic"},
    175315: {"Unified_Ideograph", "Ideographic"},
    175316: {"Unified_Ideograph", "Ideographic"},
    175317: {"Unified_Ideograph", "Ideographic"},
    175318: {"Unified_Ideograph", "Ideographic"},
    175319: {"Unified_Ideograph", "Ideographic"},
    175320: {"Unified_Ideograph", "Ideographic"},
    175321: {"Unified_Ideograph", "Ideographic"},
    175322: {"Unified_Ideograph", "Ideographic"},
    175323: {"Unified_Ideograph", "Ideographic"},
    175324: {"Unified_Ideograph", "Ideographic"},
    175325: {"Unified_Ideograph", "Ideographic"},
    175326: {"Unified_Ideograph", "Ideographic"},
    175327: {"Unified_Ideograph", "Ideographic"},
    175328: {"Unified_Ideograph", "Ideographic"},
    175329: {"Unified_Ideograph", "Ideographic"},
    175330: {"Unified_Ideograph", "Ideographic"},
    175331: {"Unified_Ideograph", "Ideographic"},
    175332: {"Unified_Ideograph", "Ideographic"},
    175333: {"Unified_Ideograph", "Ideographic"},
    175334: {"Unified_Ideograph", "Ideographic"},
    175335: {"Unified_Ideograph", "Ideographic"},
    175336: {"Unified_Ideograph", "Ideographic"},
    175337: {"Unified_Ideograph", "Ideographic"},
    175338: {"Unified_Ideograph", "Ideographic"},
    175339: {"Unified_Ideograph", "Ideographic"},
    175340: {"Unified_Ideograph", "Ideographic"},
    175341: {"Unified_Ideograph", "Ideographic"},
    175342: {"Unified_Ideograph", "Ideographic"},
    175343: {"Unified_Ideograph", "Ideographic"},
    175344: {"Unified_Ideograph", "Ideographic"},
    175345: {"Unified_Ideograph", "Ideographic"},
    175346: {"Unified_Ideograph", "Ideographic"},
    175347: {"Unified_Ideograph", "Ideographic"},
    175348: {"Unified_Ideograph", "Ideographic"},
    175349: {"Unified_Ideograph", "Ideographic"},
    175350: {"Unified_Ideograph", "Ideographic"},
    175351: {"Unified_Ideograph", "Ideographic"},
    175352: {"Unified_Ideograph", "Ideographic"},
    175353: {"Unified_Ideograph", "Ideographic"},
    175354: {"Unified_Ideograph", "Ideographic"},
    175355: {"Unified_Ideograph", "Ideographic"},
    175356: {"Unified_Ideograph", "Ideographic"},
    175357: {"Unified_Ideograph", "Ideographic"},
    175358: {"Unified_Ideograph", "Ideographic"},
    175359: {"Unified_Ideograph", "Ideographic"},
    175360: {"Unified_Ideograph", "Ideographic"},
    175361: {"Unified_Ideograph", "Ideographic"},
    175362: {"Unified_Ideograph", "Ideographic"},
    175363: {"Unified_Ideograph", "Ideographic"},
    175364: {"Unified_Ideograph", "Ideographic"},
    175365: {"Unified_Ideograph", "Ideographic"},
    175366: {"Unified_Ideograph", "Ideographic"},
    175367: {"Unified_Ideograph", "Ideographic"},
    175368: {"Unified_Ideograph", "Ideographic"},
    175369: {"Unified_Ideograph", "Ideographic"},
    175370: {"Unified_Ideograph", "Ideographic"},
    175371: {"Unified_Ideograph", "Ideographic"},
    175372: {"Unified_Ideograph", "Ideographic"},
    175373: {"Unified_Ideograph", "Ideographic"},
    175374: {"Unified_Ideograph", "Ideographic"},
    175375: {"Unified_Ideograph", "Ideographic"},
    175376: {"Unified_Ideograph", "Ideographic"},
    175377: {"Unified_Ideograph", "Ideographic"},
    175378: {"Unified_Ideograph", "Ideographic"},
    175379: {"Unified_Ideograph", "Ideographic"},
    175380: {"Unified_Ideograph", "Ideographic"},
    175381: {"Unified_Ideograph", "Ideographic"},
    175382: {"Unified_Ideograph", "Ideographic"},
    175383: {"Unified_Ideograph", "Ideographic"},
    175384: {"Unified_Ideograph", "Ideographic"},
    175385: {"Unified_Ideograph", "Ideographic"},
    175386: {"Unified_Ideograph", "Ideographic"},
    175387: {"Unified_Ideograph", "Ideographic"},
    175388: {"Unified_Ideograph", "Ideographic"},
    175389: {"Unified_Ideograph", "Ideographic"},
    175390: {"Unified_Ideograph", "Ideographic"},
    175391: {"Unified_Ideograph", "Ideographic"},
    175392: {"Unified_Ideograph", "Ideographic"},
    175393: {"Unified_Ideograph", "Ideographic"},
    175394: {"Unified_Ideograph", "Ideographic"},
    175395: {"Unified_Ideograph", "Ideographic"},
    175396: {"Unified_Ideograph", "Ideographic"},
    175397: {"Unified_Ideograph", "Ideographic"},
    175398: {"Unified_Ideograph", "Ideographic"},
    175399: {"Unified_Ideograph", "Ideographic"},
    175400: {"Unified_Ideograph", "Ideographic"},
    175401: {"Unified_Ideograph", "Ideographic"},
    175402: {"Unified_Ideograph", "Ideographic"},
    175403: {"Unified_Ideograph", "Ideographic"},
    175404: {"Unified_Ideograph", "Ideographic"},
    175405: {"Unified_Ideograph", "Ideographic"},
    175406: {"Unified_Ideograph", "Ideographic"},
    175407: {"Unified_Ideograph", "Ideographic"},
    175408: {"Unified_Ideograph", "Ideographic"},
    175409: {"Unified_Ideograph", "Ideographic"},
    175410: {"Unified_Ideograph", "Ideographic"},
    175411: {"Unified_Ideograph", "Ideographic"},
    175412: {"Unified_Ideograph", "Ideographic"},
    175413: {"Unified_Ideograph", "Ideographic"},
    175414: {"Unified_Ideograph", "Ideographic"},
    175415: {"Unified_Ideograph", "Ideographic"},
    175416: {"Unified_Ideograph", "Ideographic"},
    175417: {"Unified_Ideograph", "Ideographic"},
    175418: {"Unified_Ideograph", "Ideographic"},
    175419: {"Unified_Ideograph", "Ideographic"},
    175420: {"Unified_Ideograph", "Ideographic"},
    175421: {"Unified_Ideograph", "Ideographic"},
    175422: {"Unified_Ideograph", "Ideographic"},
    175423: {"Unified_Ideograph", "Ideographic"},
    175424: {"Unified_Ideograph", "Ideographic"},
    175425: {"Unified_Ideograph", "Ideographic"},
    175426: {"Unified_Ideograph", "Ideographic"},
    175427: {"Unified_Ideograph", "Ideographic"},
    175428: {"Unified_Ideograph", "Ideographic"},
    175429: {"Unified_Ideograph", "Ideographic"},
    175430: {"Unified_Ideograph", "Ideographic"},
    175431: {"Unified_Ideograph", "Ideographic"},
    175432: {"Unified_Ideograph", "Ideographic"},
    175433: {"Unified_Ideograph", "Ideographic"},
    175434: {"Unified_Ideograph", "Ideographic"},
    175435: {"Unified_Ideograph", "Ideographic"},
    175436: {"Unified_Ideograph", "Ideographic"},
    175437: {"Unified_Ideograph", "Ideographic"},
    175438: {"Unified_Ideograph", "Ideographic"},
    175439: {"Unified_Ideograph", "Ideographic"},
    175440: {"Unified_Ideograph", "Ideographic"},
    175441: {"Unified_Ideograph", "Ideographic"},
    175442: {"Unified_Ideograph", "Ideographic"},
    175443: {"Unified_Ideograph", "Ideographic"},
    175444: {"Unified_Ideograph", "Ideographic"},
    175445: {"Unified_Ideograph", "Ideographic"},
    175446: {"Unified_Ideograph", "Ideographic"},
    175447: {"Unified_Ideograph", "Ideographic"},
    175448: {"Unified_Ideograph", "Ideographic"},
    175449: {"Unified_Ideograph", "Ideographic"},
    175450: {"Unified_Ideograph", "Ideographic"},
    175451: {"Unified_Ideograph", "Ideographic"},
    175452: {"Unified_Ideograph", "Ideographic"},
    175453: {"Unified_Ideograph", "Ideographic"},
    175454: {"Unified_Ideograph", "Ideographic"},
    175455: {"Unified_Ideograph", "Ideographic"},
    175456: {"Unified_Ideograph", "Ideographic"},
    175457: {"Unified_Ideograph", "Ideographic"},
    175458: {"Unified_Ideograph", "Ideographic"},
    175459: {"Unified_Ideograph", "Ideographic"},
    175460: {"Unified_Ideograph", "Ideographic"},
    175461: {"Unified_Ideograph", "Ideographic"},
    175462: {"Unified_Ideograph", "Ideographic"},
    175463: {"Unified_Ideograph", "Ideographic"},
    175464: {"Unified_Ideograph", "Ideographic"},
    175465: {"Unified_Ideograph", "Ideographic"},
    175466: {"Unified_Ideograph", "Ideographic"},
    175467: {"Unified_Ideograph", "Ideographic"},
    175468: {"Unified_Ideograph", "Ideographic"},
    175469: {"Unified_Ideograph", "Ideographic"},
    175470: {"Unified_Ideograph", "Ideographic"},
    175471: {"Unified_Ideograph", "Ideographic"},
    175472: {"Unified_Ideograph", "Ideographic"},
    175473: {"Unified_Ideograph", "Ideographic"},
    175474: {"Unified_Ideograph", "Ideographic"},
    175475: {"Unified_Ideograph", "Ideographic"},
    175476: {"Unified_Ideograph", "Ideographic"},
    175477: {"Unified_Ideograph", "Ideographic"},
    175478: {"Unified_Ideograph", "Ideographic"},
    175479: {"Unified_Ideograph", "Ideographic"},
    175480: {"Unified_Ideograph", "Ideographic"},
    175481: {"Unified_Ideograph", "Ideographic"},
    175482: {"Unified_Ideograph", "Ideographic"},
    175483: {"Unified_Ideograph", "Ideographic"},
    175484: {"Unified_Ideograph", "Ideographic"},
    175485: {"Unified_Ideograph", "Ideographic"},
    175486: {"Unified_Ideograph", "Ideographic"},
    175487: {"Unified_Ideograph", "Ideographic"},
    175488: {"Unified_Ideograph", "Ideographic"},
    175489: {"Unified_Ideograph", "Ideographic"},
    175490: {"Unified_Ideograph", "Ideographic"},
    175491: {"Unified_Ideograph", "Ideographic"},
    175492: {"Unified_Ideograph", "Ideographic"},
    175493: {"Unified_Ideograph", "Ideographic"},
    175494: {"Unified_Ideograph", "Ideographic"},
    175495: {"Unified_Ideograph", "Ideographic"},
    175496: {"Unified_Ideograph", "Ideographic"},
    175497: {"Unified_Ideograph", "Ideographic"},
    175498: {"Unified_Ideograph", "Ideographic"},
    175499: {"Unified_Ideograph", "Ideographic"},
    175500: {"Unified_Ideograph", "Ideographic"},
    175501: {"Unified_Ideograph", "Ideographic"},
    175502: {"Unified_Ideograph", "Ideographic"},
    175503: {"Unified_Ideograph", "Ideographic"},
    175504: {"Unified_Ideograph", "Ideographic"},
    175505: {"Unified_Ideograph", "Ideographic"},
    175506: {"Unified_Ideograph", "Ideographic"},
    175507: {"Unified_Ideograph", "Ideographic"},
    175508: {"Unified_Ideograph", "Ideographic"},
    175509: {"Unified_Ideograph", "Ideographic"},
    175510: {"Unified_Ideograph", "Ideographic"},
    175511: {"Unified_Ideograph", "Ideographic"},
    175512: {"Unified_Ideograph", "Ideographic"},
    175513: {"Unified_Ideograph", "Ideographic"},
    175514: {"Unified_Ideograph", "Ideographic"},
    175515: {"Unified_Ideograph", "Ideographic"},
    175516: {"Unified_Ideograph", "Ideographic"},
    175517: {"Unified_Ideograph", "Ideographic"},
    175518: {"Unified_Ideograph", "Ideographic"},
    175519: {"Unified_Ideograph", "Ideographic"},
    175520: {"Unified_Ideograph", "Ideographic"},
    175521: {"Unified_Ideograph", "Ideographic"},
    175522: {"Unified_Ideograph", "Ideographic"},
    175523: {"Unified_Ideograph", "Ideographic"},
    175524: {"Unified_Ideograph", "Ideographic"},
    175525: {"Unified_Ideograph", "Ideographic"},
    175526: {"Unified_Ideograph", "Ideographic"},
    175527: {"Unified_Ideograph", "Ideographic"},
    175528: {"Unified_Ideograph", "Ideographic"},
    175529: {"Unified_Ideograph", "Ideographic"},
    175530: {"Unified_Ideograph", "Ideographic"},
    175531: {"Unified_Ideograph", "Ideographic"},
    175532: {"Unified_Ideograph", "Ideographic"},
    175533: {"Unified_Ideograph", "Ideographic"},
    175534: {"Unified_Ideograph", "Ideographic"},
    175535: {"Unified_Ideograph", "Ideographic"},
    175536: {"Unified_Ideograph", "Ideographic"},
    175537: {"Unified_Ideograph", "Ideographic"},
    175538: {"Unified_Ideograph", "Ideographic"},
    175539: {"Unified_Ideograph", "Ideographic"},
    175540: {"Unified_Ideograph", "Ideographic"},
    175541: {"Unified_Ideograph", "Ideographic"},
    175542: {"Unified_Ideograph", "Ideographic"},
    175543: {"Unified_Ideograph", "Ideographic"},
    175544: {"Unified_Ideograph", "Ideographic"},
    175545: {"Unified_Ideograph", "Ideographic"},
    175546: {"Unified_Ideograph", "Ideographic"},
    175547: {"Unified_Ideograph", "Ideographic"},
    175548: {"Unified_Ideograph", "Ideographic"},
    175549: {"Unified_Ideograph", "Ideographic"},
    175550: {"Unified_Ideograph", "Ideographic"},
    175551: {"Unified_Ideograph", "Ideographic"},
    175552: {"Unified_Ideograph", "Ideographic"},
    175553: {"Unified_Ideograph", "Ideographic"},
    175554: {"Unified_Ideograph", "Ideographic"},
    175555: {"Unified_Ideograph", "Ideographic"},
    175556: {"Unified_Ideograph", "Ideographic"},
    175557: {"Unified_Ideograph", "Ideographic"},
    175558: {"Unified_Ideograph", "Ideographic"},
    175559: {"Unified_Ideograph", "Ideographic"},
    175560: {"Unified_Ideograph", "Ideographic"},
    175561: {"Unified_Ideograph", "Ideographic"},
    175562: {"Unified_Ideograph", "Ideographic"},
    175563: {"Unified_Ideograph", "Ideographic"},
    175564: {"Unified_Ideograph", "Ideographic"},
    175565: {"Unified_Ideograph", "Ideographic"},
    175566: {"Unified_Ideograph", "Ideographic"},
    175567: {"Unified_Ideograph", "Ideographic"},
    175568: {"Unified_Ideograph", "Ideographic"},
    175569: {"Unified_Ideograph", "Ideographic"},
    175570: {"Unified_Ideograph", "Ideographic"},
    175571: {"Unified_Ideograph", "Ideographic"},
    175572: {"Unified_Ideograph", "Ideographic"},
    175573: {"Unified_Ideograph", "Ideographic"},
    175574: {"Unified_Ideograph", "Ideographic"},
    175575: {"Unified_Ideograph", "Ideographic"},
    175576: {"Unified_Ideograph", "Ideographic"},
    175577: {"Unified_Ideograph", "Ideographic"},
    175578: {"Unified_Ideograph", "Ideographic"},
    175579: {"Unified_Ideograph", "Ideographic"},
    175580: {"Unified_Ideograph", "Ideographic"},
    175581: {"Unified_Ideograph", "Ideographic"},
    175582: {"Unified_Ideograph", "Ideographic"},
    175583: {"Unified_Ideograph", "Ideographic"},
    175584: {"Unified_Ideograph", "Ideographic"},
    175585: {"Unified_Ideograph", "Ideographic"},
    175586: {"Unified_Ideograph", "Ideographic"},
    175587: {"Unified_Ideograph", "Ideographic"},
    175588: {"Unified_Ideograph", "Ideographic"},
    175589: {"Unified_Ideograph", "Ideographic"},
    175590: {"Unified_Ideograph", "Ideographic"},
    175591: {"Unified_Ideograph", "Ideographic"},
    175592: {"Unified_Ideograph", "Ideographic"},
    175593: {"Unified_Ideograph", "Ideographic"},
    175594: {"Unified_Ideograph", "Ideographic"},
    175595: {"Unified_Ideograph", "Ideographic"},
    175596: {"Unified_Ideograph", "Ideographic"},
    175597: {"Unified_Ideograph", "Ideographic"},
    175598: {"Unified_Ideograph", "Ideographic"},
    175599: {"Unified_Ideograph", "Ideographic"},
    175600: {"Unified_Ideograph", "Ideographic"},
    175601: {"Unified_Ideograph", "Ideographic"},
    175602: {"Unified_Ideograph", "Ideographic"},
    175603: {"Unified_Ideograph", "Ideographic"},
    175604: {"Unified_Ideograph", "Ideographic"},
    175605: {"Unified_Ideograph", "Ideographic"},
    175606: {"Unified_Ideograph", "Ideographic"},
    175607: {"Unified_Ideograph", "Ideographic"},
    175608: {"Unified_Ideograph", "Ideographic"},
    175609: {"Unified_Ideograph", "Ideographic"},
    175610: {"Unified_Ideograph", "Ideographic"},
    175611: {"Unified_Ideograph", "Ideographic"},
    175612: {"Unified_Ideograph", "Ideographic"},
    175613: {"Unified_Ideograph", "Ideographic"},
    175614: {"Unified_Ideograph", "Ideographic"},
    175615: {"Unified_Ideograph", "Ideographic"},
    175616: {"Unified_Ideograph", "Ideographic"},
    175617: {"Unified_Ideograph", "Ideographic"},
    175618: {"Unified_Ideograph", "Ideographic"},
    175619: {"Unified_Ideograph", "Ideographic"},
    175620: {"Unified_Ideograph", "Ideographic"},
    175621: {"Unified_Ideograph", "Ideographic"},
    175622: {"Unified_Ideograph", "Ideographic"},
    175623: {"Unified_Ideograph", "Ideographic"},
    175624: {"Unified_Ideograph", "Ideographic"},
    175625: {"Unified_Ideograph", "Ideographic"},
    175626: {"Unified_Ideograph", "Ideographic"},
    175627: {"Unified_Ideograph", "Ideographic"},
    175628: {"Unified_Ideograph", "Ideographic"},
    175629: {"Unified_Ideograph", "Ideographic"},
    175630: {"Unified_Ideograph", "Ideographic"},
    175631: {"Unified_Ideograph", "Ideographic"},
    175632: {"Unified_Ideograph", "Ideographic"},
    175633: {"Unified_Ideograph", "Ideographic"},
    175634: {"Unified_Ideograph", "Ideographic"},
    175635: {"Unified_Ideograph", "Ideographic"},
    175636: {"Unified_Ideograph", "Ideographic"},
    175637: {"Unified_Ideograph", "Ideographic"},
    175638: {"Unified_Ideograph", "Ideographic"},
    175639: {"Unified_Ideograph", "Ideographic"},
    175640: {"Unified_Ideograph", "Ideographic"},
    175641: {"Unified_Ideograph", "Ideographic"},
    175642: {"Unified_Ideograph", "Ideographic"},
    175643: {"Unified_Ideograph", "Ideographic"},
    175644: {"Unified_Ideograph", "Ideographic"},
    175645: {"Unified_Ideograph", "Ideographic"},
    175646: {"Unified_Ideograph", "Ideographic"},
    175647: {"Unified_Ideograph", "Ideographic"},
    175648: {"Unified_Ideograph", "Ideographic"},
    175649: {"Unified_Ideograph", "Ideographic"},
    175650: {"Unified_Ideograph", "Ideographic"},
    175651: {"Unified_Ideograph", "Ideographic"},
    175652: {"Unified_Ideograph", "Ideographic"},
    175653: {"Unified_Ideograph", "Ideographic"},
    175654: {"Unified_Ideograph", "Ideographic"},
    175655: {"Unified_Ideograph", "Ideographic"},
    175656: {"Unified_Ideograph", "Ideographic"},
    175657: {"Unified_Ideograph", "Ideographic"},
    175658: {"Unified_Ideograph", "Ideographic"},
    175659: {"Unified_Ideograph", "Ideographic"},
    175660: {"Unified_Ideograph", "Ideographic"},
    175661: {"Unified_Ideograph", "Ideographic"},
    175662: {"Unified_Ideograph", "Ideographic"},
    175663: {"Unified_Ideograph", "Ideographic"},
    175664: {"Unified_Ideograph", "Ideographic"},
    175665: {"Unified_Ideograph", "Ideographic"},
    175666: {"Unified_Ideograph", "Ideographic"},
    175667: {"Unified_Ideograph", "Ideographic"},
    175668: {"Unified_Ideograph", "Ideographic"},
    175669: {"Unified_Ideograph", "Ideographic"},
    175670: {"Unified_Ideograph", "Ideographic"},
    175671: {"Unified_Ideograph", "Ideographic"},
    175672: {"Unified_Ideograph", "Ideographic"},
    175673: {"Unified_Ideograph", "Ideographic"},
    175674: {"Unified_Ideograph", "Ideographic"},
    175675: {"Unified_Ideograph", "Ideographic"},
    175676: {"Unified_Ideograph", "Ideographic"},
    175677: {"Unified_Ideograph", "Ideographic"},
    175678: {"Unified_Ideograph", "Ideographic"},
    175679: {"Unified_Ideograph", "Ideographic"},
    175680: {"Unified_Ideograph", "Ideographic"},
    175681: {"Unified_Ideograph", "Ideographic"},
    175682: {"Unified_Ideograph", "Ideographic"},
    175683: {"Unified_Ideograph", "Ideographic"},
    175684: {"Unified_Ideograph", "Ideographic"},
    175685: {"Unified_Ideograph", "Ideographic"},
    175686: {"Unified_Ideograph", "Ideographic"},
    175687: {"Unified_Ideograph", "Ideographic"},
    175688: {"Unified_Ideograph", "Ideographic"},
    175689: {"Unified_Ideograph", "Ideographic"},
    175690: {"Unified_Ideograph", "Ideographic"},
    175691: {"Unified_Ideograph", "Ideographic"},
    175692: {"Unified_Ideograph", "Ideographic"},
    175693: {"Unified_Ideograph", "Ideographic"},
    175694: {"Unified_Ideograph", "Ideographic"},
    175695: {"Unified_Ideograph", "Ideographic"},
    175696: {"Unified_Ideograph", "Ideographic"},
    175697: {"Unified_Ideograph", "Ideographic"},
    175698: {"Unified_Ideograph", "Ideographic"},
    175699: {"Unified_Ideograph", "Ideographic"},
    175700: {"Unified_Ideograph", "Ideographic"},
    175701: {"Unified_Ideograph", "Ideographic"},
    175702: {"Unified_Ideograph", "Ideographic"},
    175703: {"Unified_Ideograph", "Ideographic"},
    175704: {"Unified_Ideograph", "Ideographic"},
    175705: {"Unified_Ideograph", "Ideographic"},
    175706: {"Unified_Ideograph", "Ideographic"},
    175707: {"Unified_Ideograph", "Ideographic"},
    175708: {"Unified_Ideograph", "Ideographic"},
    175709: {"Unified_Ideograph", "Ideographic"},
    175710: {"Unified_Ideograph", "Ideographic"},
    175711: {"Unified_Ideograph", "Ideographic"},
    175712: {"Unified_Ideograph", "Ideographic"},
    175713: {"Unified_Ideograph", "Ideographic"},
    175714: {"Unified_Ideograph", "Ideographic"},
    175715: {"Unified_Ideograph", "Ideographic"},
    175716: {"Unified_Ideograph", "Ideographic"},
    175717: {"Unified_Ideograph", "Ideographic"},
    175718: {"Unified_Ideograph", "Ideographic"},
    175719: {"Unified_Ideograph", "Ideographic"},
    175720: {"Unified_Ideograph", "Ideographic"},
    175721: {"Unified_Ideograph", "Ideographic"},
    175722: {"Unified_Ideograph", "Ideographic"},
    175723: {"Unified_Ideograph", "Ideographic"},
    175724: {"Unified_Ideograph", "Ideographic"},
    175725: {"Unified_Ideograph", "Ideographic"},
    175726: {"Unified_Ideograph", "Ideographic"},
    175727: {"Unified_Ideograph", "Ideographic"},
    175728: {"Unified_Ideograph", "Ideographic"},
    175729: {"Unified_Ideograph", "Ideographic"},
    175730: {"Unified_Ideograph", "Ideographic"},
    175731: {"Unified_Ideograph", "Ideographic"},
    175732: {"Unified_Ideograph", "Ideographic"},
    175733: {"Unified_Ideograph", "Ideographic"},
    175734: {"Unified_Ideograph", "Ideographic"},
    175735: {"Unified_Ideograph", "Ideographic"},
    175736: {"Unified_Ideograph", "Ideographic"},
    175737: {"Unified_Ideograph", "Ideographic"},
    175738: {"Unified_Ideograph", "Ideographic"},
    175739: {"Unified_Ideograph", "Ideographic"},
    175740: {"Unified_Ideograph", "Ideographic"},
    175741: {"Unified_Ideograph", "Ideographic"},
    175742: {"Unified_Ideograph", "Ideographic"},
    175743: {"Unified_Ideograph", "Ideographic"},
    175744: {"Unified_Ideograph", "Ideographic"},
    175745: {"Unified_Ideograph", "Ideographic"},
    175746: {"Unified_Ideograph", "Ideographic"},
    175747: {"Unified_Ideograph", "Ideographic"},
    175748: {"Unified_Ideograph", "Ideographic"},
    175749: {"Unified_Ideograph", "Ideographic"},
    175750: {"Unified_Ideograph", "Ideographic"},
    175751: {"Unified_Ideograph", "Ideographic"},
    175752: {"Unified_Ideograph", "Ideographic"},
    175753: {"Unified_Ideograph", "Ideographic"},
    175754: {"Unified_Ideograph", "Ideographic"},
    175755: {"Unified_Ideograph", "Ideographic"},
    175756: {"Unified_Ideograph", "Ideographic"},
    175757: {"Unified_Ideograph", "Ideographic"},
    175758: {"Unified_Ideograph", "Ideographic"},
    175759: {"Unified_Ideograph", "Ideographic"},
    175760: {"Unified_Ideograph", "Ideographic"},
    175761: {"Unified_Ideograph", "Ideographic"},
    175762: {"Unified_Ideograph", "Ideographic"},
    175763: {"Unified_Ideograph", "Ideographic"},
    175764: {"Unified_Ideograph", "Ideographic"},
    175765: {"Unified_Ideograph", "Ideographic"},
    175766: {"Unified_Ideograph", "Ideographic"},
    175767: {"Unified_Ideograph", "Ideographic"},
    175768: {"Unified_Ideograph", "Ideographic"},
    175769: {"Unified_Ideograph", "Ideographic"},
    175770: {"Unified_Ideograph", "Ideographic"},
    175771: {"Unified_Ideograph", "Ideographic"},
    175772: {"Unified_Ideograph", "Ideographic"},
    175773: {"Unified_Ideograph", "Ideographic"},
    175774: {"Unified_Ideograph", "Ideographic"},
    175775: {"Unified_Ideograph", "Ideographic"},
    175776: {"Unified_Ideograph", "Ideographic"},
    175777: {"Unified_Ideograph", "Ideographic"},
    175778: {"Unified_Ideograph", "Ideographic"},
    175779: {"Unified_Ideograph", "Ideographic"},
    175780: {"Unified_Ideograph", "Ideographic"},
    175781: {"Unified_Ideograph", "Ideographic"},
    175782: {"Unified_Ideograph", "Ideographic"},
    175783: {"Unified_Ideograph", "Ideographic"},
    175784: {"Unified_Ideograph", "Ideographic"},
    175785: {"Unified_Ideograph", "Ideographic"},
    175786: {"Unified_Ideograph", "Ideographic"},
    175787: {"Unified_Ideograph", "Ideographic"},
    175788: {"Unified_Ideograph", "Ideographic"},
    175789: {"Unified_Ideograph", "Ideographic"},
    175790: {"Unified_Ideograph", "Ideographic"},
    175791: {"Unified_Ideograph", "Ideographic"},
    175792: {"Unified_Ideograph", "Ideographic"},
    175793: {"Unified_Ideograph", "Ideographic"},
    175794: {"Unified_Ideograph", "Ideographic"},
    175795: {"Unified_Ideograph", "Ideographic"},
    175796: {"Unified_Ideograph", "Ideographic"},
    175797: {"Unified_Ideograph", "Ideographic"},
    175798: {"Unified_Ideograph", "Ideographic"},
    175799: {"Unified_Ideograph", "Ideographic"},
    175800: {"Unified_Ideograph", "Ideographic"},
    175801: {"Unified_Ideograph", "Ideographic"},
    175802: {"Unified_Ideograph", "Ideographic"},
    175803: {"Unified_Ideograph", "Ideographic"},
    175804: {"Unified_Ideograph", "Ideographic"},
    175805: {"Unified_Ideograph", "Ideographic"},
    175806: {"Unified_Ideograph", "Ideographic"},
    175807: {"Unified_Ideograph", "Ideographic"},
    175808: {"Unified_Ideograph", "Ideographic"},
    175809: {"Unified_Ideograph", "Ideographic"},
    175810: {"Unified_Ideograph", "Ideographic"},
    175811: {"Unified_Ideograph", "Ideographic"},
    175812: {"Unified_Ideograph", "Ideographic"},
    175813: {"Unified_Ideograph", "Ideographic"},
    175814: {"Unified_Ideograph", "Ideographic"},
    175815: {"Unified_Ideograph", "Ideographic"},
    175816: {"Unified_Ideograph", "Ideographic"},
    175817: {"Unified_Ideograph", "Ideographic"},
    175818: {"Unified_Ideograph", "Ideographic"},
    175819: {"Unified_Ideograph", "Ideographic"},
    175820: {"Unified_Ideograph", "Ideographic"},
    175821: {"Unified_Ideograph", "Ideographic"},
    175822: {"Unified_Ideograph", "Ideographic"},
    175823: {"Unified_Ideograph", "Ideographic"},
    175824: {"Unified_Ideograph", "Ideographic"},
    175825: {"Unified_Ideograph", "Ideographic"},
    175826: {"Unified_Ideograph", "Ideographic"},
    175827: {"Unified_Ideograph", "Ideographic"},
    175828: {"Unified_Ideograph", "Ideographic"},
    175829: {"Unified_Ideograph", "Ideographic"},
    175830: {"Unified_Ideograph", "Ideographic"},
    175831: {"Unified_Ideograph", "Ideographic"},
    175832: {"Unified_Ideograph", "Ideographic"},
    175833: {"Unified_Ideograph", "Ideographic"},
    175834: {"Unified_Ideograph", "Ideographic"},
    175835: {"Unified_Ideograph", "Ideographic"},
    175836: {"Unified_Ideograph", "Ideographic"},
    175837: {"Unified_Ideograph", "Ideographic"},
    175838: {"Unified_Ideograph", "Ideographic"},
    175839: {"Unified_Ideograph", "Ideographic"},
    175840: {"Unified_Ideograph", "Ideographic"},
    175841: {"Unified_Ideograph", "Ideographic"},
    175842: {"Unified_Ideograph", "Ideographic"},
    175843: {"Unified_Ideograph", "Ideographic"},
    175844: {"Unified_Ideograph", "Ideographic"},
    175845: {"Unified_Ideograph", "Ideographic"},
    175846: {"Unified_Ideograph", "Ideographic"},
    175847: {"Unified_Ideograph", "Ideographic"},
    175848: {"Unified_Ideograph", "Ideographic"},
    175849: {"Unified_Ideograph", "Ideographic"},
    175850: {"Unified_Ideograph", "Ideographic"},
    175851: {"Unified_Ideograph", "Ideographic"},
    175852: {"Unified_Ideograph", "Ideographic"},
    175853: {"Unified_Ideograph", "Ideographic"},
    175854: {"Unified_Ideograph", "Ideographic"},
    175855: {"Unified_Ideograph", "Ideographic"},
    175856: {"Unified_Ideograph", "Ideographic"},
    175857: {"Unified_Ideograph", "Ideographic"},
    175858: {"Unified_Ideograph", "Ideographic"},
    175859: {"Unified_Ideograph", "Ideographic"},
    175860: {"Unified_Ideograph", "Ideographic"},
    175861: {"Unified_Ideograph", "Ideographic"},
    175862: {"Unified_Ideograph", "Ideographic"},
    175863: {"Unified_Ideograph", "Ideographic"},
    175864: {"Unified_Ideograph", "Ideographic"},
    175865: {"Unified_Ideograph", "Ideographic"},
    175866: {"Unified_Ideograph", "Ideographic"},
    175867: {"Unified_Ideograph", "Ideographic"},
    175868: {"Unified_Ideograph", "Ideographic"},
    175869: {"Unified_Ideograph", "Ideographic"},
    175870: {"Unified_Ideograph", "Ideographic"},
    175871: {"Unified_Ideograph", "Ideographic"},
    175872: {"Unified_Ideograph", "Ideographic"},
    175873: {"Unified_Ideograph", "Ideographic"},
    175874: {"Unified_Ideograph", "Ideographic"},
    175875: {"Unified_Ideograph", "Ideographic"},
    175876: {"Unified_Ideograph", "Ideographic"},
    175877: {"Unified_Ideograph", "Ideographic"},
    175878: {"Unified_Ideograph", "Ideographic"},
    175879: {"Unified_Ideograph", "Ideographic"},
    175880: {"Unified_Ideograph", "Ideographic"},
    175881: {"Unified_Ideograph", "Ideographic"},
    175882: {"Unified_Ideograph", "Ideographic"},
    175883: {"Unified_Ideograph", "Ideographic"},
    175884: {"Unified_Ideograph", "Ideographic"},
    175885: {"Unified_Ideograph", "Ideographic"},
    175886: {"Unified_Ideograph", "Ideographic"},
    175887: {"Unified_Ideograph", "Ideographic"},
    175888: {"Unified_Ideograph", "Ideographic"},
    175889: {"Unified_Ideograph", "Ideographic"},
    175890: {"Unified_Ideograph", "Ideographic"},
    175891: {"Unified_Ideograph", "Ideographic"},
    175892: {"Unified_Ideograph", "Ideographic"},
    175893: {"Unified_Ideograph", "Ideographic"},
    175894: {"Unified_Ideograph", "Ideographic"},
    175895: {"Unified_Ideograph", "Ideographic"},
    175896: {"Unified_Ideograph", "Ideographic"},
    175897: {"Unified_Ideograph", "Ideographic"},
    175898: {"Unified_Ideograph", "Ideographic"},
    175899: {"Unified_Ideograph", "Ideographic"},
    175900: {"Unified_Ideograph", "Ideographic"},
    175901: {"Unified_Ideograph", "Ideographic"},
    175902: {"Unified_Ideograph", "Ideographic"},
    175903: {"Unified_Ideograph", "Ideographic"},
    175904: {"Unified_Ideograph", "Ideographic"},
    175905: {"Unified_Ideograph", "Ideographic"},
    175906: {"Unified_Ideograph", "Ideographic"},
    175907: {"Unified_Ideograph", "Ideographic"},
    175908: {"Unified_Ideograph", "Ideographic"},
    175909: {"Unified_Ideograph", "Ideographic"},
    175910: {"Unified_Ideograph", "Ideographic"},
    175911: {"Unified_Ideograph", "Ideographic"},
    175912: {"Unified_Ideograph", "Ideographic"},
    175913: {"Unified_Ideograph", "Ideographic"},
    175914: {"Unified_Ideograph", "Ideographic"},
    175915: {"Unified_Ideograph", "Ideographic"},
    175916: {"Unified_Ideograph", "Ideographic"},
    175917: {"Unified_Ideograph", "Ideographic"},
    175918: {"Unified_Ideograph", "Ideographic"},
    175919: {"Unified_Ideograph", "Ideographic"},
    175920: {"Unified_Ideograph", "Ideographic"},
    175921: {"Unified_Ideograph", "Ideographic"},
    175922: {"Unified_Ideograph", "Ideographic"},
    175923: {"Unified_Ideograph", "Ideographic"},
    175924: {"Unified_Ideograph", "Ideographic"},
    175925: {"Unified_Ideograph", "Ideographic"},
    175926: {"Unified_Ideograph", "Ideographic"},
    175927: {"Unified_Ideograph", "Ideographic"},
    175928: {"Unified_Ideograph", "Ideographic"},
    175929: {"Unified_Ideograph", "Ideographic"},
    175930: {"Unified_Ideograph", "Ideographic"},
    175931: {"Unified_Ideograph", "Ideographic"},
    175932: {"Unified_Ideograph", "Ideographic"},
    175933: {"Unified_Ideograph", "Ideographic"},
    175934: {"Unified_Ideograph", "Ideographic"},
    175935: {"Unified_Ideograph", "Ideographic"},
    175936: {"Unified_Ideograph", "Ideographic"},
    175937: {"Unified_Ideograph", "Ideographic"},
    175938: {"Unified_Ideograph", "Ideographic"},
    175939: {"Unified_Ideograph", "Ideographic"},
    175940: {"Unified_Ideograph", "Ideographic"},
    175941: {"Unified_Ideograph", "Ideographic"},
    175942: {"Unified_Ideograph", "Ideographic"},
    175943: {"Unified_Ideograph", "Ideographic"},
    175944: {"Unified_Ideograph", "Ideographic"},
    175945: {"Unified_Ideograph", "Ideographic"},
    175946: {"Unified_Ideograph", "Ideographic"},
    175947: {"Unified_Ideograph", "Ideographic"},
    175948: {"Unified_Ideograph", "Ideographic"},
    175949: {"Unified_Ideograph", "Ideographic"},
    175950: {"Unified_Ideograph", "Ideographic"},
    175951: {"Unified_Ideograph", "Ideographic"},
    175952: {"Unified_Ideograph", "Ideographic"},
    175953: {"Unified_Ideograph", "Ideographic"},
    175954: {"Unified_Ideograph", "Ideographic"},
    175955: {"Unified_Ideograph", "Ideographic"},
    175956: {"Unified_Ideograph", "Ideographic"},
    175957: {"Unified_Ideograph", "Ideographic"},
    175958: {"Unified_Ideograph", "Ideographic"},
    175959: {"Unified_Ideograph", "Ideographic"},
    175960: {"Unified_Ideograph", "Ideographic"},
    175961: {"Unified_Ideograph", "Ideographic"},
    175962: {"Unified_Ideograph", "Ideographic"},
    175963: {"Unified_Ideograph", "Ideographic"},
    175964: {"Unified_Ideograph", "Ideographic"},
    175965: {"Unified_Ideograph", "Ideographic"},
    175966: {"Unified_Ideograph", "Ideographic"},
    175967: {"Unified_Ideograph", "Ideographic"},
    175968: {"Unified_Ideograph", "Ideographic"},
    175969: {"Unified_Ideograph", "Ideographic"},
    175970: {"Unified_Ideograph", "Ideographic"},
    175971: {"Unified_Ideograph", "Ideographic"},
    175972: {"Unified_Ideograph", "Ideographic"},
    175973: {"Unified_Ideograph", "Ideographic"},
    175974: {"Unified_Ideograph", "Ideographic"},
    175975: {"Unified_Ideograph", "Ideographic"},
    175976: {"Unified_Ideograph", "Ideographic"},
    175977: {"Unified_Ideograph", "Ideographic"},
    175978: {"Unified_Ideograph", "Ideographic"},
    175979: {"Unified_Ideograph", "Ideographic"},
    175980: {"Unified_Ideograph", "Ideographic"},
    175981: {"Unified_Ideograph", "Ideographic"},
    175982: {"Unified_Ideograph", "Ideographic"},
    175983: {"Unified_Ideograph", "Ideographic"},
    175984: {"Unified_Ideograph", "Ideographic"},
    175985: {"Unified_Ideograph", "Ideographic"},
    175986: {"Unified_Ideograph", "Ideographic"},
    175987: {"Unified_Ideograph", "Ideographic"},
    175988: {"Unified_Ideograph", "Ideographic"},
    175989: {"Unified_Ideograph", "Ideographic"},
    175990: {"Unified_Ideograph", "Ideographic"},
    175991: {"Unified_Ideograph", "Ideographic"},
    175992: {"Unified_Ideograph", "Ideographic"},
    175993: {"Unified_Ideograph", "Ideographic"},
    175994: {"Unified_Ideograph", "Ideographic"},
    175995: {"Unified_Ideograph", "Ideographic"},
    175996: {"Unified_Ideograph", "Ideographic"},
    175997: {"Unified_Ideograph", "Ideographic"},
    175998: {"Unified_Ideograph", "Ideographic"},
    175999: {"Unified_Ideograph", "Ideographic"},
    176000: {"Unified_Ideograph", "Ideographic"},
    176001: {"Unified_Ideograph", "Ideographic"},
    176002: {"Unified_Ideograph", "Ideographic"},
    176003: {"Unified_Ideograph", "Ideographic"},
    176004: {"Unified_Ideograph", "Ideographic"},
    176005: {"Unified_Ideograph", "Ideographic"},
    176006: {"Unified_Ideograph", "Ideographic"},
    176007: {"Unified_Ideograph", "Ideographic"},
    176008: {"Unified_Ideograph", "Ideographic"},
    176009: {"Unified_Ideograph", "Ideographic"},
    176010: {"Unified_Ideograph", "Ideographic"},
    176011: {"Unified_Ideograph", "Ideographic"},
    176012: {"Unified_Ideograph", "Ideographic"},
    176013: {"Unified_Ideograph", "Ideographic"},
    176014: {"Unified_Ideograph", "Ideographic"},
    176015: {"Unified_Ideograph", "Ideographic"},
    176016: {"Unified_Ideograph", "Ideographic"},
    176017: {"Unified_Ideograph", "Ideographic"},
    176018: {"Unified_Ideograph", "Ideographic"},
    176019: {"Unified_Ideograph", "Ideographic"},
    176020: {"Unified_Ideograph", "Ideographic"},
    176021: {"Unified_Ideograph", "Ideographic"},
    176022: {"Unified_Ideograph", "Ideographic"},
    176023: {"Unified_Ideograph", "Ideographic"},
    176024: {"Unified_Ideograph", "Ideographic"},
    176025: {"Unified_Ideograph", "Ideographic"},
    176026: {"Unified_Ideograph", "Ideographic"},
    176027: {"Unified_Ideograph", "Ideographic"},
    176028: {"Unified_Ideograph", "Ideographic"},
    176029: {"Unified_Ideograph", "Ideographic"},
    176030: {"Unified_Ideograph", "Ideographic"},
    176031: {"Unified_Ideograph", "Ideographic"},
    176032: {"Unified_Ideograph", "Ideographic"},
    176033: {"Unified_Ideograph", "Ideographic"},
    176034: {"Unified_Ideograph", "Ideographic"},
    176035: {"Unified_Ideograph", "Ideographic"},
    176036: {"Unified_Ideograph", "Ideographic"},
    176037: {"Unified_Ideograph", "Ideographic"},
    176038: {"Unified_Ideograph", "Ideographic"},
    176039: {"Unified_Ideograph", "Ideographic"},
    176040: {"Unified_Ideograph", "Ideographic"},
    176041: {"Unified_Ideograph", "Ideographic"},
    176042: {"Unified_Ideograph", "Ideographic"},
    176043: {"Unified_Ideograph", "Ideographic"},
    176044: {"Unified_Ideograph", "Ideographic"},
    176045: {"Unified_Ideograph", "Ideographic"},
    176046: {"Unified_Ideograph", "Ideographic"},
    176047: {"Unified_Ideograph", "Ideographic"},
    176048: {"Unified_Ideograph", "Ideographic"},
    176049: {"Unified_Ideograph", "Ideographic"},
    176050: {"Unified_Ideograph", "Ideographic"},
    176051: {"Unified_Ideograph", "Ideographic"},
    176052: {"Unified_Ideograph", "Ideographic"},
    176053: {"Unified_Ideograph", "Ideographic"},
    176054: {"Unified_Ideograph", "Ideographic"},
    176055: {"Unified_Ideograph", "Ideographic"},
    176056: {"Unified_Ideograph", "Ideographic"},
    176057: {"Unified_Ideograph", "Ideographic"},
    176058: {"Unified_Ideograph", "Ideographic"},
    176059: {"Unified_Ideograph", "Ideographic"},
    176060: {"Unified_Ideograph", "Ideographic"},
    176061: {"Unified_Ideograph", "Ideographic"},
    176062: {"Unified_Ideograph", "Ideographic"},
    176063: {"Unified_Ideograph", "Ideographic"},
    176064: {"Unified_Ideograph", "Ideographic"},
    176065: {"Unified_Ideograph", "Ideographic"},
    176066: {"Unified_Ideograph", "Ideographic"},
    176067: {"Unified_Ideograph", "Ideographic"},
    176068: {"Unified_Ideograph", "Ideographic"},
    176069: {"Unified_Ideograph", "Ideographic"},
    176070: {"Unified_Ideograph", "Ideographic"},
    176071: {"Unified_Ideograph", "Ideographic"},
    176072: {"Unified_Ideograph", "Ideographic"},
    176073: {"Unified_Ideograph", "Ideographic"},
    176074: {"Unified_Ideograph", "Ideographic"},
    176075: {"Unified_Ideograph", "Ideographic"},
    176076: {"Unified_Ideograph", "Ideographic"},
    176077: {"Unified_Ideograph", "Ideographic"},
    176078: {"Unified_Ideograph", "Ideographic"},
    176079: {"Unified_Ideograph", "Ideographic"},
    176080: {"Unified_Ideograph", "Ideographic"},
    176081: {"Unified_Ideograph", "Ideographic"},
    176082: {"Unified_Ideograph", "Ideographic"},
    176083: {"Unified_Ideograph", "Ideographic"},
    176084: {"Unified_Ideograph", "Ideographic"},
    176085: {"Unified_Ideograph", "Ideographic"},
    176086: {"Unified_Ideograph", "Ideographic"},
    176087: {"Unified_Ideograph", "Ideographic"},
    176088: {"Unified_Ideograph", "Ideographic"},
    176089: {"Unified_Ideograph", "Ideographic"},
    176090: {"Unified_Ideograph", "Ideographic"},
    176091: {"Unified_Ideograph", "Ideographic"},
    176092: {"Unified_Ideograph", "Ideographic"},
    176093: {"Unified_Ideograph", "Ideographic"},
    176094: {"Unified_Ideograph", "Ideographic"},
    176095: {"Unified_Ideograph", "Ideographic"},
    176096: {"Unified_Ideograph", "Ideographic"},
    176097: {"Unified_Ideograph", "Ideographic"},
    176098: {"Unified_Ideograph", "Ideographic"},
    176099: {"Unified_Ideograph", "Ideographic"},
    176100: {"Unified_Ideograph", "Ideographic"},
    176101: {"Unified_Ideograph", "Ideographic"},
    176102: {"Unified_Ideograph", "Ideographic"},
    176103: {"Unified_Ideograph", "Ideographic"},
    176104: {"Unified_Ideograph", "Ideographic"},
    176105: {"Unified_Ideograph", "Ideographic"},
    176106: {"Unified_Ideograph", "Ideographic"},
    176107: {"Unified_Ideograph", "Ideographic"},
    176108: {"Unified_Ideograph", "Ideographic"},
    176109: {"Unified_Ideograph", "Ideographic"},
    176110: {"Unified_Ideograph", "Ideographic"},
    176111: {"Unified_Ideograph", "Ideographic"},
    176112: {"Unified_Ideograph", "Ideographic"},
    176113: {"Unified_Ideograph", "Ideographic"},
    176114: {"Unified_Ideograph", "Ideographic"},
    176115: {"Unified_Ideograph", "Ideographic"},
    176116: {"Unified_Ideograph", "Ideographic"},
    176117: {"Unified_Ideograph", "Ideographic"},
    176118: {"Unified_Ideograph", "Ideographic"},
    176119: {"Unified_Ideograph", "Ideographic"},
    176120: {"Unified_Ideograph", "Ideographic"},
    176121: {"Unified_Ideograph", "Ideographic"},
    176122: {"Unified_Ideograph", "Ideographic"},
    176123: {"Unified_Ideograph", "Ideographic"},
    176124: {"Unified_Ideograph", "Ideographic"},
    176125: {"Unified_Ideograph", "Ideographic"},
    176126: {"Unified_Ideograph", "Ideographic"},
    176127: {"Unified_Ideograph", "Ideographic"},
    176128: {"Unified_Ideograph", "Ideographic"},
    176129: {"Unified_Ideograph", "Ideographic"},
    176130: {"Unified_Ideograph", "Ideographic"},
    176131: {"Unified_Ideograph", "Ideographic"},
    176132: {"Unified_Ideograph", "Ideographic"},
    176133: {"Unified_Ideograph", "Ideographic"},
    176134: {"Unified_Ideograph", "Ideographic"},
    176135: {"Unified_Ideograph", "Ideographic"},
    176136: {"Unified_Ideograph", "Ideographic"},
    176137: {"Unified_Ideograph", "Ideographic"},
    176138: {"Unified_Ideograph", "Ideographic"},
    176139: {"Unified_Ideograph", "Ideographic"},
    176140: {"Unified_Ideograph", "Ideographic"},
    176141: {"Unified_Ideograph", "Ideographic"},
    176142: {"Unified_Ideograph", "Ideographic"},
    176143: {"Unified_Ideograph", "Ideographic"},
    176144: {"Unified_Ideograph", "Ideographic"},
    176145: {"Unified_Ideograph", "Ideographic"},
    176146: {"Unified_Ideograph", "Ideographic"},
    176147: {"Unified_Ideograph", "Ideographic"},
    176148: {"Unified_Ideograph", "Ideographic"},
    176149: {"Unified_Ideograph", "Ideographic"},
    176150: {"Unified_Ideograph", "Ideographic"},
    176151: {"Unified_Ideograph", "Ideographic"},
    176152: {"Unified_Ideograph", "Ideographic"},
    176153: {"Unified_Ideograph", "Ideographic"},
    176154: {"Unified_Ideograph", "Ideographic"},
    176155: {"Unified_Ideograph", "Ideographic"},
    176156: {"Unified_Ideograph", "Ideographic"},
    176157: {"Unified_Ideograph", "Ideographic"},
    176158: {"Unified_Ideograph", "Ideographic"},
    176159: {"Unified_Ideograph", "Ideographic"},
    176160: {"Unified_Ideograph", "Ideographic"},
    176161: {"Unified_Ideograph", "Ideographic"},
    176162: {"Unified_Ideograph", "Ideographic"},
    176163: {"Unified_Ideograph", "Ideographic"},
    176164: {"Unified_Ideograph", "Ideographic"},
    176165: {"Unified_Ideograph", "Ideographic"},
    176166: {"Unified_Ideograph", "Ideographic"},
    176167: {"Unified_Ideograph", "Ideographic"},
    176168: {"Unified_Ideograph", "Ideographic"},
    176169: {"Unified_Ideograph", "Ideographic"},
    176170: {"Unified_Ideograph", "Ideographic"},
    176171: {"Unified_Ideograph", "Ideographic"},
    176172: {"Unified_Ideograph", "Ideographic"},
    176173: {"Unified_Ideograph", "Ideographic"},
    176174: {"Unified_Ideograph", "Ideographic"},
    176175: {"Unified_Ideograph", "Ideographic"},
    176176: {"Unified_Ideograph", "Ideographic"},
    176177: {"Unified_Ideograph", "Ideographic"},
    176178: {"Unified_Ideograph", "Ideographic"},
    176179: {"Unified_Ideograph", "Ideographic"},
    176180: {"Unified_Ideograph", "Ideographic"},
    176181: {"Unified_Ideograph", "Ideographic"},
    176182: {"Unified_Ideograph", "Ideographic"},
    176183: {"Unified_Ideograph", "Ideographic"},
    176184: {"Unified_Ideograph", "Ideographic"},
    176185: {"Unified_Ideograph", "Ideographic"},
    176186: {"Unified_Ideograph", "Ideographic"},
    176187: {"Unified_Ideograph", "Ideographic"},
    176188: {"Unified_Ideograph", "Ideographic"},
    176189: {"Unified_Ideograph", "Ideographic"},
    176190: {"Unified_Ideograph", "Ideographic"},
    176191: {"Unified_Ideograph", "Ideographic"},
    176192: {"Unified_Ideograph", "Ideographic"},
    176193: {"Unified_Ideograph", "Ideographic"},
    176194: {"Unified_Ideograph", "Ideographic"},
    176195: {"Unified_Ideograph", "Ideographic"},
    176196: {"Unified_Ideograph", "Ideographic"},
    176197: {"Unified_Ideograph", "Ideographic"},
    176198: {"Unified_Ideograph", "Ideographic"},
    176199: {"Unified_Ideograph", "Ideographic"},
    176200: {"Unified_Ideograph", "Ideographic"},
    176201: {"Unified_Ideograph", "Ideographic"},
    176202: {"Unified_Ideograph", "Ideographic"},
    176203: {"Unified_Ideograph", "Ideographic"},
    176204: {"Unified_Ideograph", "Ideographic"},
    176205: {"Unified_Ideograph", "Ideographic"},
    176206: {"Unified_Ideograph", "Ideographic"},
    176207: {"Unified_Ideograph", "Ideographic"},
    176208: {"Unified_Ideograph", "Ideographic"},
    176209: {"Unified_Ideograph", "Ideographic"},
    176210: {"Unified_Ideograph", "Ideographic"},
    176211: {"Unified_Ideograph", "Ideographic"},
    176212: {"Unified_Ideograph", "Ideographic"},
    176213: {"Unified_Ideograph", "Ideographic"},
    176214: {"Unified_Ideograph", "Ideographic"},
    176215: {"Unified_Ideograph", "Ideographic"},
    176216: {"Unified_Ideograph", "Ideographic"},
    176217: {"Unified_Ideograph", "Ideographic"},
    176218: {"Unified_Ideograph", "Ideographic"},
    176219: {"Unified_Ideograph", "Ideographic"},
    176220: {"Unified_Ideograph", "Ideographic"},
    176221: {"Unified_Ideograph", "Ideographic"},
    176222: {"Unified_Ideograph", "Ideographic"},
    176223: {"Unified_Ideograph", "Ideographic"},
    176224: {"Unified_Ideograph", "Ideographic"},
    176225: {"Unified_Ideograph", "Ideographic"},
    176226: {"Unified_Ideograph", "Ideographic"},
    176227: {"Unified_Ideograph", "Ideographic"},
    176228: {"Unified_Ideograph", "Ideographic"},
    176229: {"Unified_Ideograph", "Ideographic"},
    176230: {"Unified_Ideograph", "Ideographic"},
    176231: {"Unified_Ideograph", "Ideographic"},
    176232: {"Unified_Ideograph", "Ideographic"},
    176233: {"Unified_Ideograph", "Ideographic"},
    176234: {"Unified_Ideograph", "Ideographic"},
    176235: {"Unified_Ideograph", "Ideographic"},
    176236: {"Unified_Ideograph", "Ideographic"},
    176237: {"Unified_Ideograph", "Ideographic"},
    176238: {"Unified_Ideograph", "Ideographic"},
    176239: {"Unified_Ideograph", "Ideographic"},
    176240: {"Unified_Ideograph", "Ideographic"},
    176241: {"Unified_Ideograph", "Ideographic"},
    176242: {"Unified_Ideograph", "Ideographic"},
    176243: {"Unified_Ideograph", "Ideographic"},
    176244: {"Unified_Ideograph", "Ideographic"},
    176245: {"Unified_Ideograph", "Ideographic"},
    176246: {"Unified_Ideograph", "Ideographic"},
    176247: {"Unified_Ideograph", "Ideographic"},
    176248: {"Unified_Ideograph", "Ideographic"},
    176249: {"Unified_Ideograph", "Ideographic"},
    176250: {"Unified_Ideograph", "Ideographic"},
    176251: {"Unified_Ideograph", "Ideographic"},
    176252: {"Unified_Ideograph", "Ideographic"},
    176253: {"Unified_Ideograph", "Ideographic"},
    176254: {"Unified_Ideograph", "Ideographic"},
    176255: {"Unified_Ideograph", "Ideographic"},
    176256: {"Unified_Ideograph", "Ideographic"},
    176257: {"Unified_Ideograph", "Ideographic"},
    176258: {"Unified_Ideograph", "Ideographic"},
    176259: {"Unified_Ideograph", "Ideographic"},
    176260: {"Unified_Ideograph", "Ideographic"},
    176261: {"Unified_Ideograph", "Ideographic"},
    176262: {"Unified_Ideograph", "Ideographic"},
    176263: {"Unified_Ideograph", "Ideographic"},
    176264: {"Unified_Ideograph", "Ideographic"},
    176265: {"Unified_Ideograph", "Ideographic"},
    176266: {"Unified_Ideograph", "Ideographic"},
    176267: {"Unified_Ideograph", "Ideographic"},
    176268: {"Unified_Ideograph", "Ideographic"},
    176269: {"Unified_Ideograph", "Ideographic"},
    176270: {"Unified_Ideograph", "Ideographic"},
    176271: {"Unified_Ideograph", "Ideographic"},
    176272: {"Unified_Ideograph", "Ideographic"},
    176273: {"Unified_Ideograph", "Ideographic"},
    176274: {"Unified_Ideograph", "Ideographic"},
    176275: {"Unified_Ideograph", "Ideographic"},
    176276: {"Unified_Ideograph", "Ideographic"},
    176277: {"Unified_Ideograph", "Ideographic"},
    176278: {"Unified_Ideograph", "Ideographic"},
    176279: {"Unified_Ideograph", "Ideographic"},
    176280: {"Unified_Ideograph", "Ideographic"},
    176281: {"Unified_Ideograph", "Ideographic"},
    176282: {"Unified_Ideograph", "Ideographic"},
    176283: {"Unified_Ideograph", "Ideographic"},
    176284: {"Unified_Ideograph", "Ideographic"},
    176285: {"Unified_Ideograph", "Ideographic"},
    176286: {"Unified_Ideograph", "Ideographic"},
    176287: {"Unified_Ideograph", "Ideographic"},
    176288: {"Unified_Ideograph", "Ideographic"},
    176289: {"Unified_Ideograph", "Ideographic"},
    176290: {"Unified_Ideograph", "Ideographic"},
    176291: {"Unified_Ideograph", "Ideographic"},
    176292: {"Unified_Ideograph", "Ideographic"},
    176293: {"Unified_Ideograph", "Ideographic"},
    176294: {"Unified_Ideograph", "Ideographic"},
    176295: {"Unified_Ideograph", "Ideographic"},
    176296: {"Unified_Ideograph", "Ideographic"},
    176297: {"Unified_Ideograph", "Ideographic"},
    176298: {"Unified_Ideograph", "Ideographic"},
    176299: {"Unified_Ideograph", "Ideographic"},
    176300: {"Unified_Ideograph", "Ideographic"},
    176301: {"Unified_Ideograph", "Ideographic"},
    176302: {"Unified_Ideograph", "Ideographic"},
    176303: {"Unified_Ideograph", "Ideographic"},
    176304: {"Unified_Ideograph", "Ideographic"},
    176305: {"Unified_Ideograph", "Ideographic"},
    176306: {"Unified_Ideograph", "Ideographic"},
    176307: {"Unified_Ideograph", "Ideographic"},
    176308: {"Unified_Ideograph", "Ideographic"},
    176309: {"Unified_Ideograph", "Ideographic"},
    176310: {"Unified_Ideograph", "Ideographic"},
    176311: {"Unified_Ideograph", "Ideographic"},
    176312: {"Unified_Ideograph", "Ideographic"},
    176313: {"Unified_Ideograph", "Ideographic"},
    176314: {"Unified_Ideograph", "Ideographic"},
    176315: {"Unified_Ideograph", "Ideographic"},
    176316: {"Unified_Ideograph", "Ideographic"},
    176317: {"Unified_Ideograph", "Ideographic"},
    176318: {"Unified_Ideograph", "Ideographic"},
    176319: {"Unified_Ideograph", "Ideographic"},
    176320: {"Unified_Ideograph", "Ideographic"},
    176321: {"Unified_Ideograph", "Ideographic"},
    176322: {"Unified_Ideograph", "Ideographic"},
    176323: {"Unified_Ideograph", "Ideographic"},
    176324: {"Unified_Ideograph", "Ideographic"},
    176325: {"Unified_Ideograph", "Ideographic"},
    176326: {"Unified_Ideograph", "Ideographic"},
    176327: {"Unified_Ideograph", "Ideographic"},
    176328: {"Unified_Ideograph", "Ideographic"},
    176329: {"Unified_Ideograph", "Ideographic"},
    176330: {"Unified_Ideograph", "Ideographic"},
    176331: {"Unified_Ideograph", "Ideographic"},
    176332: {"Unified_Ideograph", "Ideographic"},
    176333: {"Unified_Ideograph", "Ideographic"},
    176334: {"Unified_Ideograph", "Ideographic"},
    176335: {"Unified_Ideograph", "Ideographic"},
    176336: {"Unified_Ideograph", "Ideographic"},
    176337: {"Unified_Ideograph", "Ideographic"},
    176338: {"Unified_Ideograph", "Ideographic"},
    176339: {"Unified_Ideograph", "Ideographic"},
    176340: {"Unified_Ideograph", "Ideographic"},
    176341: {"Unified_Ideograph", "Ideographic"},
    176342: {"Unified_Ideograph", "Ideographic"},
    176343: {"Unified_Ideograph", "Ideographic"},
    176344: {"Unified_Ideograph", "Ideographic"},
    176345: {"Unified_Ideograph", "Ideographic"},
    176346: {"Unified_Ideograph", "Ideographic"},
    176347: {"Unified_Ideograph", "Ideographic"},
    176348: {"Unified_Ideograph", "Ideographic"},
    176349: {"Unified_Ideograph", "Ideographic"},
    176350: {"Unified_Ideograph", "Ideographic"},
    176351: {"Unified_Ideograph", "Ideographic"},
    176352: {"Unified_Ideograph", "Ideographic"},
    176353: {"Unified_Ideograph", "Ideographic"},
    176354: {"Unified_Ideograph", "Ideographic"},
    176355: {"Unified_Ideograph", "Ideographic"},
    176356: {"Unified_Ideograph", "Ideographic"},
    176357: {"Unified_Ideograph", "Ideographic"},
    176358: {"Unified_Ideograph", "Ideographic"},
    176359: {"Unified_Ideograph", "Ideographic"},
    176360: {"Unified_Ideograph", "Ideographic"},
    176361: {"Unified_Ideograph", "Ideographic"},
    176362: {"Unified_Ideograph", "Ideographic"},
    176363: {"Unified_Ideograph", "Ideographic"},
    176364: {"Unified_Ideograph", "Ideographic"},
    176365: {"Unified_Ideograph", "Ideographic"},
    176366: {"Unified_Ideograph", "Ideographic"},
    176367: {"Unified_Ideograph", "Ideographic"},
    176368: {"Unified_Ideograph", "Ideographic"},
    176369: {"Unified_Ideograph", "Ideographic"},
    176370: {"Unified_Ideograph", "Ideographic"},
    176371: {"Unified_Ideograph", "Ideographic"},
    176372: {"Unified_Ideograph", "Ideographic"},
    176373: {"Unified_Ideograph", "Ideographic"},
    176374: {"Unified_Ideograph", "Ideographic"},
    176375: {"Unified_Ideograph", "Ideographic"},
    176376: {"Unified_Ideograph", "Ideographic"},
    176377: {"Unified_Ideograph", "Ideographic"},
    176378: {"Unified_Ideograph", "Ideographic"},
    176379: {"Unified_Ideograph", "Ideographic"},
    176380: {"Unified_Ideograph", "Ideographic"},
    176381: {"Unified_Ideograph", "Ideographic"},
    176382: {"Unified_Ideograph", "Ideographic"},
    176383: {"Unified_Ideograph", "Ideographic"},
    176384: {"Unified_Ideograph", "Ideographic"},
    176385: {"Unified_Ideograph", "Ideographic"},
    176386: {"Unified_Ideograph", "Ideographic"},
    176387: {"Unified_Ideograph", "Ideographic"},
    176388: {"Unified_Ideograph", "Ideographic"},
    176389: {"Unified_Ideograph", "Ideographic"},
    176390: {"Unified_Ideograph", "Ideographic"},
    176391: {"Unified_Ideograph", "Ideographic"},
    176392: {"Unified_Ideograph", "Ideographic"},
    176393: {"Unified_Ideograph", "Ideographic"},
    176394: {"Unified_Ideograph", "Ideographic"},
    176395: {"Unified_Ideograph", "Ideographic"},
    176396: {"Unified_Ideograph", "Ideographic"},
    176397: {"Unified_Ideograph", "Ideographic"},
    176398: {"Unified_Ideograph", "Ideographic"},
    176399: {"Unified_Ideograph", "Ideographic"},
    176400: {"Unified_Ideograph", "Ideographic"},
    176401: {"Unified_Ideograph", "Ideographic"},
    176402: {"Unified_Ideograph", "Ideographic"},
    176403: {"Unified_Ideograph", "Ideographic"},
    176404: {"Unified_Ideograph", "Ideographic"},
    176405: {"Unified_Ideograph", "Ideographic"},
    176406: {"Unified_Ideograph", "Ideographic"},
    176407: {"Unified_Ideograph", "Ideographic"},
    176408: {"Unified_Ideograph", "Ideographic"},
    176409: {"Unified_Ideograph", "Ideographic"},
    176410: {"Unified_Ideograph", "Ideographic"},
    176411: {"Unified_Ideograph", "Ideographic"},
    176412: {"Unified_Ideograph", "Ideographic"},
    176413: {"Unified_Ideograph", "Ideographic"},
    176414: {"Unified_Ideograph", "Ideographic"},
    176415: {"Unified_Ideograph", "Ideographic"},
    176416: {"Unified_Ideograph", "Ideographic"},
    176417: {"Unified_Ideograph", "Ideographic"},
    176418: {"Unified_Ideograph", "Ideographic"},
    176419: {"Unified_Ideograph", "Ideographic"},
    176420: {"Unified_Ideograph", "Ideographic"},
    176421: {"Unified_Ideograph", "Ideographic"},
    176422: {"Unified_Ideograph", "Ideographic"},
    176423: {"Unified_Ideograph", "Ideographic"},
    176424: {"Unified_Ideograph", "Ideographic"},
    176425: {"Unified_Ideograph", "Ideographic"},
    176426: {"Unified_Ideograph", "Ideographic"},
    176427: {"Unified_Ideograph", "Ideographic"},
    176428: {"Unified_Ideograph", "Ideographic"},
    176429: {"Unified_Ideograph", "Ideographic"},
    176430: {"Unified_Ideograph", "Ideographic"},
    176431: {"Unified_Ideograph", "Ideographic"},
    176432: {"Unified_Ideograph", "Ideographic"},
    176433: {"Unified_Ideograph", "Ideographic"},
    176434: {"Unified_Ideograph", "Ideographic"},
    176435: {"Unified_Ideograph", "Ideographic"},
    176436: {"Unified_Ideograph", "Ideographic"},
    176437: {"Unified_Ideograph", "Ideographic"},
    176438: {"Unified_Ideograph", "Ideographic"},
    176439: {"Unified_Ideograph", "Ideographic"},
    176440: {"Unified_Ideograph", "Ideographic"},
    176441: {"Unified_Ideograph", "Ideographic"},
    176442: {"Unified_Ideograph", "Ideographic"},
    176443: {"Unified_Ideograph", "Ideographic"},
    176444: {"Unified_Ideograph", "Ideographic"},
    176445: {"Unified_Ideograph", "Ideographic"},
    176446: {"Unified_Ideograph", "Ideographic"},
    176447: {"Unified_Ideograph", "Ideographic"},
    176448: {"Unified_Ideograph", "Ideographic"},
    176449: {"Unified_Ideograph", "Ideographic"},
    176450: {"Unified_Ideograph", "Ideographic"},
    176451: {"Unified_Ideograph", "Ideographic"},
    176452: {"Unified_Ideograph", "Ideographic"},
    176453: {"Unified_Ideograph", "Ideographic"},
    176454: {"Unified_Ideograph", "Ideographic"},
    176455: {"Unified_Ideograph", "Ideographic"},
    176456: {"Unified_Ideograph", "Ideographic"},
    176457: {"Unified_Ideograph", "Ideographic"},
    176458: {"Unified_Ideograph", "Ideographic"},
    176459: {"Unified_Ideograph", "Ideographic"},
    176460: {"Unified_Ideograph", "Ideographic"},
    176461: {"Unified_Ideograph", "Ideographic"},
    176462: {"Unified_Ideograph", "Ideographic"},
    176463: {"Unified_Ideograph", "Ideographic"},
    176464: {"Unified_Ideograph", "Ideographic"},
    176465: {"Unified_Ideograph", "Ideographic"},
    176466: {"Unified_Ideograph", "Ideographic"},
    176467: {"Unified_Ideograph", "Ideographic"},
    176468: {"Unified_Ideograph", "Ideographic"},
    176469: {"Unified_Ideograph", "Ideographic"},
    176470: {"Unified_Ideograph", "Ideographic"},
    176471: {"Unified_Ideograph", "Ideographic"},
    176472: {"Unified_Ideograph", "Ideographic"},
    176473: {"Unified_Ideograph", "Ideographic"},
    176474: {"Unified_Ideograph", "Ideographic"},
    176475: {"Unified_Ideograph", "Ideographic"},
    176476: {"Unified_Ideograph", "Ideographic"},
    176477: {"Unified_Ideograph", "Ideographic"},
    176478: {"Unified_Ideograph", "Ideographic"},
    176479: {"Unified_Ideograph", "Ideographic"},
    176480: {"Unified_Ideograph", "Ideographic"},
    176481: {"Unified_Ideograph", "Ideographic"},
    176482: {"Unified_Ideograph", "Ideographic"},
    176483: {"Unified_Ideograph", "Ideographic"},
    176484: {"Unified_Ideograph", "Ideographic"},
    176485: {"Unified_Ideograph", "Ideographic"},
    176486: {"Unified_Ideograph", "Ideographic"},
    176487: {"Unified_Ideograph", "Ideographic"},
    176488: {"Unified_Ideograph", "Ideographic"},
    176489: {"Unified_Ideograph", "Ideographic"},
    176490: {"Unified_Ideograph", "Ideographic"},
    176491: {"Unified_Ideograph", "Ideographic"},
    176492: {"Unified_Ideograph", "Ideographic"},
    176493: {"Unified_Ideograph", "Ideographic"},
    176494: {"Unified_Ideograph", "Ideographic"},
    176495: {"Unified_Ideograph", "Ideographic"},
    176496: {"Unified_Ideograph", "Ideographic"},
    176497: {"Unified_Ideograph", "Ideographic"},
    176498: {"Unified_Ideograph", "Ideographic"},
    176499: {"Unified_Ideograph", "Ideographic"},
    176500: {"Unified_Ideograph", "Ideographic"},
    176501: {"Unified_Ideograph", "Ideographic"},
    176502: {"Unified_Ideograph", "Ideographic"},
    176503: {"Unified_Ideograph", "Ideographic"},
    176504: {"Unified_Ideograph", "Ideographic"},
    176505: {"Unified_Ideograph", "Ideographic"},
    176506: {"Unified_Ideograph", "Ideographic"},
    176507: {"Unified_Ideograph", "Ideographic"},
    176508: {"Unified_Ideograph", "Ideographic"},
    176509: {"Unified_Ideograph", "Ideographic"},
    176510: {"Unified_Ideograph", "Ideographic"},
    176511: {"Unified_Ideograph", "Ideographic"},
    176512: {"Unified_Ideograph", "Ideographic"},
    176513: {"Unified_Ideograph", "Ideographic"},
    176514: {"Unified_Ideograph", "Ideographic"},
    176515: {"Unified_Ideograph", "Ideographic"},
    176516: {"Unified_Ideograph", "Ideographic"},
    176517: {"Unified_Ideograph", "Ideographic"},
    176518: {"Unified_Ideograph", "Ideographic"},
    176519: {"Unified_Ideograph", "Ideographic"},
    176520: {"Unified_Ideograph", "Ideographic"},
    176521: {"Unified_Ideograph", "Ideographic"},
    176522: {"Unified_Ideograph", "Ideographic"},
    176523: {"Unified_Ideograph", "Ideographic"},
    176524: {"Unified_Ideograph", "Ideographic"},
    176525: {"Unified_Ideograph", "Ideographic"},
    176526: {"Unified_Ideograph", "Ideographic"},
    176527: {"Unified_Ideograph", "Ideographic"},
    176528: {"Unified_Ideograph", "Ideographic"},
    176529: {"Unified_Ideograph", "Ideographic"},
    176530: {"Unified_Ideograph", "Ideographic"},
    176531: {"Unified_Ideograph", "Ideographic"},
    176532: {"Unified_Ideograph", "Ideographic"},
    176533: {"Unified_Ideograph", "Ideographic"},
    176534: {"Unified_Ideograph", "Ideographic"},
    176535: {"Unified_Ideograph", "Ideographic"},
    176536: {"Unified_Ideograph", "Ideographic"},
    176537: {"Unified_Ideograph", "Ideographic"},
    176538: {"Unified_Ideograph", "Ideographic"},
    176539: {"Unified_Ideograph", "Ideographic"},
    176540: {"Unified_Ideograph", "Ideographic"},
    176541: {"Unified_Ideograph", "Ideographic"},
    176542: {"Unified_Ideograph", "Ideographic"},
    176543: {"Unified_Ideograph", "Ideographic"},
    176544: {"Unified_Ideograph", "Ideographic"},
    176545: {"Unified_Ideograph", "Ideographic"},
    176546: {"Unified_Ideograph", "Ideographic"},
    176547: {"Unified_Ideograph", "Ideographic"},
    176548: {"Unified_Ideograph", "Ideographic"},
    176549: {"Unified_Ideograph", "Ideographic"},
    176550: {"Unified_Ideograph", "Ideographic"},
    176551: {"Unified_Ideograph", "Ideographic"},
    176552: {"Unified_Ideograph", "Ideographic"},
    176553: {"Unified_Ideograph", "Ideographic"},
    176554: {"Unified_Ideograph", "Ideographic"},
    176555: {"Unified_Ideograph", "Ideographic"},
    176556: {"Unified_Ideograph", "Ideographic"},
    176557: {"Unified_Ideograph", "Ideographic"},
    176558: {"Unified_Ideograph", "Ideographic"},
    176559: {"Unified_Ideograph", "Ideographic"},
    176560: {"Unified_Ideograph", "Ideographic"},
    176561: {"Unified_Ideograph", "Ideographic"},
    176562: {"Unified_Ideograph", "Ideographic"},
    176563: {"Unified_Ideograph", "Ideographic"},
    176564: {"Unified_Ideograph", "Ideographic"},
    176565: {"Unified_Ideograph", "Ideographic"},
    176566: {"Unified_Ideograph", "Ideographic"},
    176567: {"Unified_Ideograph", "Ideographic"},
    176568: {"Unified_Ideograph", "Ideographic"},
    176569: {"Unified_Ideograph", "Ideographic"},
    176570: {"Unified_Ideograph", "Ideographic"},
    176571: {"Unified_Ideograph", "Ideographic"},
    176572: {"Unified_Ideograph", "Ideographic"},
    176573: {"Unified_Ideograph", "Ideographic"},
    176574: {"Unified_Ideograph", "Ideographic"},
    176575: {"Unified_Ideograph", "Ideographic"},
    176576: {"Unified_Ideograph", "Ideographic"},
    176577: {"Unified_Ideograph", "Ideographic"},
    176578: {"Unified_Ideograph", "Ideographic"},
    176579: {"Unified_Ideograph", "Ideographic"},
    176580: {"Unified_Ideograph", "Ideographic"},
    176581: {"Unified_Ideograph", "Ideographic"},
    176582: {"Unified_Ideograph", "Ideographic"},
    176583: {"Unified_Ideograph", "Ideographic"},
    176584: {"Unified_Ideograph", "Ideographic"},
    176585: {"Unified_Ideograph", "Ideographic"},
    176586: {"Unified_Ideograph", "Ideographic"},
    176587: {"Unified_Ideograph", "Ideographic"},
    176588: {"Unified_Ideograph", "Ideographic"},
    176589: {"Unified_Ideograph", "Ideographic"},
    176590: {"Unified_Ideograph", "Ideographic"},
    176591: {"Unified_Ideograph", "Ideographic"},
    176592: {"Unified_Ideograph", "Ideographic"},
    176593: {"Unified_Ideograph", "Ideographic"},
    176594: {"Unified_Ideograph", "Ideographic"},
    176595: {"Unified_Ideograph", "Ideographic"},
    176596: {"Unified_Ideograph", "Ideographic"},
    176597: {"Unified_Ideograph", "Ideographic"},
    176598: {"Unified_Ideograph", "Ideographic"},
    176599: {"Unified_Ideograph", "Ideographic"},
    176600: {"Unified_Ideograph", "Ideographic"},
    176601: {"Unified_Ideograph", "Ideographic"},
    176602: {"Unified_Ideograph", "Ideographic"},
    176603: {"Unified_Ideograph", "Ideographic"},
    176604: {"Unified_Ideograph", "Ideographic"},
    176605: {"Unified_Ideograph", "Ideographic"},
    176606: {"Unified_Ideograph", "Ideographic"},
    176607: {"Unified_Ideograph", "Ideographic"},
    176608: {"Unified_Ideograph", "Ideographic"},
    176609: {"Unified_Ideograph", "Ideographic"},
    176610: {"Unified_Ideograph", "Ideographic"},
    176611: {"Unified_Ideograph", "Ideographic"},
    176612: {"Unified_Ideograph", "Ideographic"},
    176613: {"Unified_Ideograph", "Ideographic"},
    176614: {"Unified_Ideograph", "Ideographic"},
    176615: {"Unified_Ideograph", "Ideographic"},
    176616: {"Unified_Ideograph", "Ideographic"},
    176617: {"Unified_Ideograph", "Ideographic"},
    176618: {"Unified_Ideograph", "Ideographic"},
    176619: {"Unified_Ideograph", "Ideographic"},
    176620: {"Unified_Ideograph", "Ideographic"},
    176621: {"Unified_Ideograph", "Ideographic"},
    176622: {"Unified_Ideograph", "Ideographic"},
    176623: {"Unified_Ideograph", "Ideographic"},
    176624: {"Unified_Ideograph", "Ideographic"},
    176625: {"Unified_Ideograph", "Ideographic"},
    176626: {"Unified_Ideograph", "Ideographic"},
    176627: {"Unified_Ideograph", "Ideographic"},
    176628: {"Unified_Ideograph", "Ideographic"},
    176629: {"Unified_Ideograph", "Ideographic"},
    176630: {"Unified_Ideograph", "Ideographic"},
    176631: {"Unified_Ideograph", "Ideographic"},
    176632: {"Unified_Ideograph", "Ideographic"},
    176633: {"Unified_Ideograph", "Ideographic"},
    176634: {"Unified_Ideograph", "Ideographic"},
    176635: {"Unified_Ideograph", "Ideographic"},
    176636: {"Unified_Ideograph", "Ideographic"},
    176637: {"Unified_Ideograph", "Ideographic"},
    176638: {"Unified_Ideograph", "Ideographic"},
    176639: {"Unified_Ideograph", "Ideographic"},
    176640: {"Unified_Ideograph", "Ideographic"},
    176641: {"Unified_Ideograph", "Ideographic"},
    176642: {"Unified_Ideograph", "Ideographic"},
    176643: {"Unified_Ideograph", "Ideographic"},
    176644: {"Unified_Ideograph", "Ideographic"},
    176645: {"Unified_Ideograph", "Ideographic"},
    176646: {"Unified_Ideograph", "Ideographic"},
    176647: {"Unified_Ideograph", "Ideographic"},
    176648: {"Unified_Ideograph", "Ideographic"},
    176649: {"Unified_Ideograph", "Ideographic"},
    176650: {"Unified_Ideograph", "Ideographic"},
    176651: {"Unified_Ideograph", "Ideographic"},
    176652: {"Unified_Ideograph", "Ideographic"},
    176653: {"Unified_Ideograph", "Ideographic"},
    176654: {"Unified_Ideograph", "Ideographic"},
    176655: {"Unified_Ideograph", "Ideographic"},
    176656: {"Unified_Ideograph", "Ideographic"},
    176657: {"Unified_Ideograph", "Ideographic"},
    176658: {"Unified_Ideograph", "Ideographic"},
    176659: {"Unified_Ideograph", "Ideographic"},
    176660: {"Unified_Ideograph", "Ideographic"},
    176661: {"Unified_Ideograph", "Ideographic"},
    176662: {"Unified_Ideograph", "Ideographic"},
    176663: {"Unified_Ideograph", "Ideographic"},
    176664: {"Unified_Ideograph", "Ideographic"},
    176665: {"Unified_Ideograph", "Ideographic"},
    176666: {"Unified_Ideograph", "Ideographic"},
    176667: {"Unified_Ideograph", "Ideographic"},
    176668: {"Unified_Ideograph", "Ideographic"},
    176669: {"Unified_Ideograph", "Ideographic"},
    176670: {"Unified_Ideograph", "Ideographic"},
    176671: {"Unified_Ideograph", "Ideographic"},
    176672: {"Unified_Ideograph", "Ideographic"},
    176673: {"Unified_Ideograph", "Ideographic"},
    176674: {"Unified_Ideograph", "Ideographic"},
    176675: {"Unified_Ideograph", "Ideographic"},
    176676: {"Unified_Ideograph", "Ideographic"},
    176677: {"Unified_Ideograph", "Ideographic"},
    176678: {"Unified_Ideograph", "Ideographic"},
    176679: {"Unified_Ideograph", "Ideographic"},
    176680: {"Unified_Ideograph", "Ideographic"},
    176681: {"Unified_Ideograph", "Ideographic"},
    176682: {"Unified_Ideograph", "Ideographic"},
    176683: {"Unified_Ideograph", "Ideographic"},
    176684: {"Unified_Ideograph", "Ideographic"},
    176685: {"Unified_Ideograph", "Ideographic"},
    176686: {"Unified_Ideograph", "Ideographic"},
    176687: {"Unified_Ideograph", "Ideographic"},
    176688: {"Unified_Ideograph", "Ideographic"},
    176689: {"Unified_Ideograph", "Ideographic"},
    176690: {"Unified_Ideograph", "Ideographic"},
    176691: {"Unified_Ideograph", "Ideographic"},
    176692: {"Unified_Ideograph", "Ideographic"},
    176693: {"Unified_Ideograph", "Ideographic"},
    176694: {"Unified_Ideograph", "Ideographic"},
    176695: {"Unified_Ideograph", "Ideographic"},
    176696: {"Unified_Ideograph", "Ideographic"},
    176697: {"Unified_Ideograph", "Ideographic"},
    176698: {"Unified_Ideograph", "Ideographic"},
    176699: {"Unified_Ideograph", "Ideographic"},
    176700: {"Unified_Ideograph", "Ideographic"},
    176701: {"Unified_Ideograph", "Ideographic"},
    176702: {"Unified_Ideograph", "Ideographic"},
    176703: {"Unified_Ideograph", "Ideographic"},
    176704: {"Unified_Ideograph", "Ideographic"},
    176705: {"Unified_Ideograph", "Ideographic"},
    176706: {"Unified_Ideograph", "Ideographic"},
    176707: {"Unified_Ideograph", "Ideographic"},
    176708: {"Unified_Ideograph", "Ideographic"},
    176709: {"Unified_Ideograph", "Ideographic"},
    176710: {"Unified_Ideograph", "Ideographic"},
    176711: {"Unified_Ideograph", "Ideographic"},
    176712: {"Unified_Ideograph", "Ideographic"},
    176713: {"Unified_Ideograph", "Ideographic"},
    176714: {"Unified_Ideograph", "Ideographic"},
    176715: {"Unified_Ideograph", "Ideographic"},
    176716: {"Unified_Ideograph", "Ideographic"},
    176717: {"Unified_Ideograph", "Ideographic"},
    176718: {"Unified_Ideograph", "Ideographic"},
    176719: {"Unified_Ideograph", "Ideographic"},
    176720: {"Unified_Ideograph", "Ideographic"},
    176721: {"Unified_Ideograph", "Ideographic"},
    176722: {"Unified_Ideograph", "Ideographic"},
    176723: {"Unified_Ideograph", "Ideographic"},
    176724: {"Unified_Ideograph", "Ideographic"},
    176725: {"Unified_Ideograph", "Ideographic"},
    176726: {"Unified_Ideograph", "Ideographic"},
    176727: {"Unified_Ideograph", "Ideographic"},
    176728: {"Unified_Ideograph", "Ideographic"},
    176729: {"Unified_Ideograph", "Ideographic"},
    176730: {"Unified_Ideograph", "Ideographic"},
    176731: {"Unified_Ideograph", "Ideographic"},
    176732: {"Unified_Ideograph", "Ideographic"},
    176733: {"Unified_Ideograph", "Ideographic"},
    176734: {"Unified_Ideograph", "Ideographic"},
    176735: {"Unified_Ideograph", "Ideographic"},
    176736: {"Unified_Ideograph", "Ideographic"},
    176737: {"Unified_Ideograph", "Ideographic"},
    176738: {"Unified_Ideograph", "Ideographic"},
    176739: {"Unified_Ideograph", "Ideographic"},
    176740: {"Unified_Ideograph", "Ideographic"},
    176741: {"Unified_Ideograph", "Ideographic"},
    176742: {"Unified_Ideograph", "Ideographic"},
    176743: {"Unified_Ideograph", "Ideographic"},
    176744: {"Unified_Ideograph", "Ideographic"},
    176745: {"Unified_Ideograph", "Ideographic"},
    176746: {"Unified_Ideograph", "Ideographic"},
    176747: {"Unified_Ideograph", "Ideographic"},
    176748: {"Unified_Ideograph", "Ideographic"},
    176749: {"Unified_Ideograph", "Ideographic"},
    176750: {"Unified_Ideograph", "Ideographic"},
    176751: {"Unified_Ideograph", "Ideographic"},
    176752: {"Unified_Ideograph", "Ideographic"},
    176753: {"Unified_Ideograph", "Ideographic"},
    176754: {"Unified_Ideograph", "Ideographic"},
    176755: {"Unified_Ideograph", "Ideographic"},
    176756: {"Unified_Ideograph", "Ideographic"},
    176757: {"Unified_Ideograph", "Ideographic"},
    176758: {"Unified_Ideograph", "Ideographic"},
    176759: {"Unified_Ideograph", "Ideographic"},
    176760: {"Unified_Ideograph", "Ideographic"},
    176761: {"Unified_Ideograph", "Ideographic"},
    176762: {"Unified_Ideograph", "Ideographic"},
    176763: {"Unified_Ideograph", "Ideographic"},
    176764: {"Unified_Ideograph", "Ideographic"},
    176765: {"Unified_Ideograph", "Ideographic"},
    176766: {"Unified_Ideograph", "Ideographic"},
    176767: {"Unified_Ideograph", "Ideographic"},
    176768: {"Unified_Ideograph", "Ideographic"},
    176769: {"Unified_Ideograph", "Ideographic"},
    176770: {"Unified_Ideograph", "Ideographic"},
    176771: {"Unified_Ideograph", "Ideographic"},
    176772: {"Unified_Ideograph", "Ideographic"},
    176773: {"Unified_Ideograph", "Ideographic"},
    176774: {"Unified_Ideograph", "Ideographic"},
    176775: {"Unified_Ideograph", "Ideographic"},
    176776: {"Unified_Ideograph", "Ideographic"},
    176777: {"Unified_Ideograph", "Ideographic"},
    176778: {"Unified_Ideograph", "Ideographic"},
    176779: {"Unified_Ideograph", "Ideographic"},
    176780: {"Unified_Ideograph", "Ideographic"},
    176781: {"Unified_Ideograph", "Ideographic"},
    176782: {"Unified_Ideograph", "Ideographic"},
    176783: {"Unified_Ideograph", "Ideographic"},
    176784: {"Unified_Ideograph", "Ideographic"},
    176785: {"Unified_Ideograph", "Ideographic"},
    176786: {"Unified_Ideograph", "Ideographic"},
    176787: {"Unified_Ideograph", "Ideographic"},
    176788: {"Unified_Ideograph", "Ideographic"},
    176789: {"Unified_Ideograph", "Ideographic"},
    176790: {"Unified_Ideograph", "Ideographic"},
    176791: {"Unified_Ideograph", "Ideographic"},
    176792: {"Unified_Ideograph", "Ideographic"},
    176793: {"Unified_Ideograph", "Ideographic"},
    176794: {"Unified_Ideograph", "Ideographic"},
    176795: {"Unified_Ideograph", "Ideographic"},
    176796: {"Unified_Ideograph", "Ideographic"},
    176797: {"Unified_Ideograph", "Ideographic"},
    176798: {"Unified_Ideograph", "Ideographic"},
    176799: {"Unified_Ideograph", "Ideographic"},
    176800: {"Unified_Ideograph", "Ideographic"},
    176801: {"Unified_Ideograph", "Ideographic"},
    176802: {"Unified_Ideograph", "Ideographic"},
    176803: {"Unified_Ideograph", "Ideographic"},
    176804: {"Unified_Ideograph", "Ideographic"},
    176805: {"Unified_Ideograph", "Ideographic"},
    176806: {"Unified_Ideograph", "Ideographic"},
    176807: {"Unified_Ideograph", "Ideographic"},
    176808: {"Unified_Ideograph", "Ideographic"},
    176809: {"Unified_Ideograph", "Ideographic"},
    176810: {"Unified_Ideograph", "Ideographic"},
    176811: {"Unified_Ideograph", "Ideographic"},
    176812: {"Unified_Ideograph", "Ideographic"},
    176813: {"Unified_Ideograph", "Ideographic"},
    176814: {"Unified_Ideograph", "Ideographic"},
    176815: {"Unified_Ideograph", "Ideographic"},
    176816: {"Unified_Ideograph", "Ideographic"},
    176817: {"Unified_Ideograph", "Ideographic"},
    176818: {"Unified_Ideograph", "Ideographic"},
    176819: {"Unified_Ideograph", "Ideographic"},
    176820: {"Unified_Ideograph", "Ideographic"},
    176821: {"Unified_Ideograph", "Ideographic"},
    176822: {"Unified_Ideograph", "Ideographic"},
    176823: {"Unified_Ideograph", "Ideographic"},
    176824: {"Unified_Ideograph", "Ideographic"},
    176825: {"Unified_Ideograph", "Ideographic"},
    176826: {"Unified_Ideograph", "Ideographic"},
    176827: {"Unified_Ideograph", "Ideographic"},
    176828: {"Unified_Ideograph", "Ideographic"},
    176829: {"Unified_Ideograph", "Ideographic"},
    176830: {"Unified_Ideograph", "Ideographic"},
    176831: {"Unified_Ideograph", "Ideographic"},
    176832: {"Unified_Ideograph", "Ideographic"},
    176833: {"Unified_Ideograph", "Ideographic"},
    176834: {"Unified_Ideograph", "Ideographic"},
    176835: {"Unified_Ideograph", "Ideographic"},
    176836: {"Unified_Ideograph", "Ideographic"},
    176837: {"Unified_Ideograph", "Ideographic"},
    176838: {"Unified_Ideograph", "Ideographic"},
    176839: {"Unified_Ideograph", "Ideographic"},
    176840: {"Unified_Ideograph", "Ideographic"},
    176841: {"Unified_Ideograph", "Ideographic"},
    176842: {"Unified_Ideograph", "Ideographic"},
    176843: {"Unified_Ideograph", "Ideographic"},
    176844: {"Unified_Ideograph", "Ideographic"},
    176845: {"Unified_Ideograph", "Ideographic"},
    176846: {"Unified_Ideograph", "Ideographic"},
    176847: {"Unified_Ideograph", "Ideographic"},
    176848: {"Unified_Ideograph", "Ideographic"},
    176849: {"Unified_Ideograph", "Ideographic"},
    176850: {"Unified_Ideograph", "Ideographic"},
    176851: {"Unified_Ideograph", "Ideographic"},
    176852: {"Unified_Ideograph", "Ideographic"},
    176853: {"Unified_Ideograph", "Ideographic"},
    176854: {"Unified_Ideograph", "Ideographic"},
    176855: {"Unified_Ideograph", "Ideographic"},
    176856: {"Unified_Ideograph", "Ideographic"},
    176857: {"Unified_Ideograph", "Ideographic"},
    176858: {"Unified_Ideograph", "Ideographic"},
    176859: {"Unified_Ideograph", "Ideographic"},
    176860: {"Unified_Ideograph", "Ideographic"},
    176861: {"Unified_Ideograph", "Ideographic"},
    176862: {"Unified_Ideograph", "Ideographic"},
    176863: {"Unified_Ideograph", "Ideographic"},
    176864: {"Unified_Ideograph", "Ideographic"},
    176865: {"Unified_Ideograph", "Ideographic"},
    176866: {"Unified_Ideograph", "Ideographic"},
    176867: {"Unified_Ideograph", "Ideographic"},
    176868: {"Unified_Ideograph", "Ideographic"},
    176869: {"Unified_Ideograph", "Ideographic"},
    176870: {"Unified_Ideograph", "Ideographic"},
    176871: {"Unified_Ideograph", "Ideographic"},
    176872: {"Unified_Ideograph", "Ideographic"},
    176873: {"Unified_Ideograph", "Ideographic"},
    176874: {"Unified_Ideograph", "Ideographic"},
    176875: {"Unified_Ideograph", "Ideographic"},
    176876: {"Unified_Ideograph", "Ideographic"},
    176877: {"Unified_Ideograph", "Ideographic"},
    176878: {"Unified_Ideograph", "Ideographic"},
    176879: {"Unified_Ideograph", "Ideographic"},
    176880: {"Unified_Ideograph", "Ideographic"},
    176881: {"Unified_Ideograph", "Ideographic"},
    176882: {"Unified_Ideograph", "Ideographic"},
    176883: {"Unified_Ideograph", "Ideographic"},
    176884: {"Unified_Ideograph", "Ideographic"},
    176885: {"Unified_Ideograph", "Ideographic"},
    176886: {"Unified_Ideograph", "Ideographic"},
    176887: {"Unified_Ideograph", "Ideographic"},
    176888: {"Unified_Ideograph", "Ideographic"},
    176889: {"Unified_Ideograph", "Ideographic"},
    176890: {"Unified_Ideograph", "Ideographic"},
    176891: {"Unified_Ideograph", "Ideographic"},
    176892: {"Unified_Ideograph", "Ideographic"},
    176893: {"Unified_Ideograph", "Ideographic"},
    176894: {"Unified_Ideograph", "Ideographic"},
    176895: {"Unified_Ideograph", "Ideographic"},
    176896: {"Unified_Ideograph", "Ideographic"},
    176897: {"Unified_Ideograph", "Ideographic"},
    176898: {"Unified_Ideograph", "Ideographic"},
    176899: {"Unified_Ideograph", "Ideographic"},
    176900: {"Unified_Ideograph", "Ideographic"},
    176901: {"Unified_Ideograph", "Ideographic"},
    176902: {"Unified_Ideograph", "Ideographic"},
    176903: {"Unified_Ideograph", "Ideographic"},
    176904: {"Unified_Ideograph", "Ideographic"},
    176905: {"Unified_Ideograph", "Ideographic"},
    176906: {"Unified_Ideograph", "Ideographic"},
    176907: {"Unified_Ideograph", "Ideographic"},
    176908: {"Unified_Ideograph", "Ideographic"},
    176909: {"Unified_Ideograph", "Ideographic"},
    176910: {"Unified_Ideograph", "Ideographic"},
    176911: {"Unified_Ideograph", "Ideographic"},
    176912: {"Unified_Ideograph", "Ideographic"},
    176913: {"Unified_Ideograph", "Ideographic"},
    176914: {"Unified_Ideograph", "Ideographic"},
    176915: {"Unified_Ideograph", "Ideographic"},
    176916: {"Unified_Ideograph", "Ideographic"},
    176917: {"Unified_Ideograph", "Ideographic"},
    176918: {"Unified_Ideograph", "Ideographic"},
    176919: {"Unified_Ideograph", "Ideographic"},
    176920: {"Unified_Ideograph", "Ideographic"},
    176921: {"Unified_Ideograph", "Ideographic"},
    176922: {"Unified_Ideograph", "Ideographic"},
    176923: {"Unified_Ideograph", "Ideographic"},
    176924: {"Unified_Ideograph", "Ideographic"},
    176925: {"Unified_Ideograph", "Ideographic"},
    176926: {"Unified_Ideograph", "Ideographic"},
    176927: {"Unified_Ideograph", "Ideographic"},
    176928: {"Unified_Ideograph", "Ideographic"},
    176929: {"Unified_Ideograph", "Ideographic"},
    176930: {"Unified_Ideograph", "Ideographic"},
    176931: {"Unified_Ideograph", "Ideographic"},
    176932: {"Unified_Ideograph", "Ideographic"},
    176933: {"Unified_Ideograph", "Ideographic"},
    176934: {"Unified_Ideograph", "Ideographic"},
    176935: {"Unified_Ideograph", "Ideographic"},
    176936: {"Unified_Ideograph", "Ideographic"},
    176937: {"Unified_Ideograph", "Ideographic"},
    176938: {"Unified_Ideograph", "Ideographic"},
    176939: {"Unified_Ideograph", "Ideographic"},
    176940: {"Unified_Ideograph", "Ideographic"},
    176941: {"Unified_Ideograph", "Ideographic"},
    176942: {"Unified_Ideograph", "Ideographic"},
    176943: {"Unified_Ideograph", "Ideographic"},
    176944: {"Unified_Ideograph", "Ideographic"},
    176945: {"Unified_Ideograph", "Ideographic"},
    176946: {"Unified_Ideograph", "Ideographic"},
    176947: {"Unified_Ideograph", "Ideographic"},
    176948: {"Unified_Ideograph", "Ideographic"},
    176949: {"Unified_Ideograph", "Ideographic"},
    176950: {"Unified_Ideograph", "Ideographic"},
    176951: {"Unified_Ideograph", "Ideographic"},
    176952: {"Unified_Ideograph", "Ideographic"},
    176953: {"Unified_Ideograph", "Ideographic"},
    176954: {"Unified_Ideograph", "Ideographic"},
    176955: {"Unified_Ideograph", "Ideographic"},
    176956: {"Unified_Ideograph", "Ideographic"},
    176957: {"Unified_Ideograph", "Ideographic"},
    176958: {"Unified_Ideograph", "Ideographic"},
    176959: {"Unified_Ideograph", "Ideographic"},
    176960: {"Unified_Ideograph", "Ideographic"},
    176961: {"Unified_Ideograph", "Ideographic"},
    176962: {"Unified_Ideograph", "Ideographic"},
    176963: {"Unified_Ideograph", "Ideographic"},
    176964: {"Unified_Ideograph", "Ideographic"},
    176965: {"Unified_Ideograph", "Ideographic"},
    176966: {"Unified_Ideograph", "Ideographic"},
    176967: {"Unified_Ideograph", "Ideographic"},
    176968: {"Unified_Ideograph", "Ideographic"},
    176969: {"Unified_Ideograph", "Ideographic"},
    176970: {"Unified_Ideograph", "Ideographic"},
    176971: {"Unified_Ideograph", "Ideographic"},
    176972: {"Unified_Ideograph", "Ideographic"},
    176973: {"Unified_Ideograph", "Ideographic"},
    176974: {"Unified_Ideograph", "Ideographic"},
    176975: {"Unified_Ideograph", "Ideographic"},
    176976: {"Unified_Ideograph", "Ideographic"},
    176977: {"Unified_Ideograph", "Ideographic"},
    176978: {"Unified_Ideograph", "Ideographic"},
    176979: {"Unified_Ideograph", "Ideographic"},
    176980: {"Unified_Ideograph", "Ideographic"},
    176981: {"Unified_Ideograph", "Ideographic"},
    176982: {"Unified_Ideograph", "Ideographic"},
    176983: {"Unified_Ideograph", "Ideographic"},
    176984: {"Unified_Ideograph", "Ideographic"},
    176985: {"Unified_Ideograph", "Ideographic"},
    176986: {"Unified_Ideograph", "Ideographic"},
    176987: {"Unified_Ideograph", "Ideographic"},
    176988: {"Unified_Ideograph", "Ideographic"},
    176989: {"Unified_Ideograph", "Ideographic"},
    176990: {"Unified_Ideograph", "Ideographic"},
    176991: {"Unified_Ideograph", "Ideographic"},
    176992: {"Unified_Ideograph", "Ideographic"},
    176993: {"Unified_Ideograph", "Ideographic"},
    176994: {"Unified_Ideograph", "Ideographic"},
    176995: {"Unified_Ideograph", "Ideographic"},
    176996: {"Unified_Ideograph", "Ideographic"},
    176997: {"Unified_Ideograph", "Ideographic"},
    176998: {"Unified_Ideograph", "Ideographic"},
    176999: {"Unified_Ideograph", "Ideographic"},
    177000: {"Unified_Ideograph", "Ideographic"},
    177001: {"Unified_Ideograph", "Ideographic"},
    177002: {"Unified_Ideograph", "Ideographic"},
    177003: {"Unified_Ideograph", "Ideographic"},
    177004: {"Unified_Ideograph", "Ideographic"},
    177005: {"Unified_Ideograph", "Ideographic"},
    177006: {"Unified_Ideograph", "Ideographic"},
    177007: {"Unified_Ideograph", "Ideographic"},
    177008: {"Unified_Ideograph", "Ideographic"},
    177009: {"Unified_Ideograph", "Ideographic"},
    177010: {"Unified_Ideograph", "Ideographic"},
    177011: {"Unified_Ideograph", "Ideographic"},
    177012: {"Unified_Ideograph", "Ideographic"},
    177013: {"Unified_Ideograph", "Ideographic"},
    177014: {"Unified_Ideograph", "Ideographic"},
    177015: {"Unified_Ideograph", "Ideographic"},
    177016: {"Unified_Ideograph", "Ideographic"},
    177017: {"Unified_Ideograph", "Ideographic"},
    177018: {"Unified_Ideograph", "Ideographic"},
    177019: {"Unified_Ideograph", "Ideographic"},
    177020: {"Unified_Ideograph", "Ideographic"},
    177021: {"Unified_Ideograph", "Ideographic"},
    177022: {"Unified_Ideograph", "Ideographic"},
    177023: {"Unified_Ideograph", "Ideographic"},
    177024: {"Unified_Ideograph", "Ideographic"},
    177025: {"Unified_Ideograph", "Ideographic"},
    177026: {"Unified_Ideograph", "Ideographic"},
    177027: {"Unified_Ideograph", "Ideographic"},
    177028: {"Unified_Ideograph", "Ideographic"},
    177029: {"Unified_Ideograph", "Ideographic"},
    177030: {"Unified_Ideograph", "Ideographic"},
    177031: {"Unified_Ideograph", "Ideographic"},
    177032: {"Unified_Ideograph", "Ideographic"},
    177033: {"Unified_Ideograph", "Ideographic"},
    177034: {"Unified_Ideograph", "Ideographic"},
    177035: {"Unified_Ideograph", "Ideographic"},
    177036: {"Unified_Ideograph", "Ideographic"},
    177037: {"Unified_Ideograph", "Ideographic"},
    177038: {"Unified_Ideograph", "Ideographic"},
    177039: {"Unified_Ideograph", "Ideographic"},
    177040: {"Unified_Ideograph", "Ideographic"},
    177041: {"Unified_Ideograph", "Ideographic"},
    177042: {"Unified_Ideograph", "Ideographic"},
    177043: {"Unified_Ideograph", "Ideographic"},
    177044: {"Unified_Ideograph", "Ideographic"},
    177045: {"Unified_Ideograph", "Ideographic"},
    177046: {"Unified_Ideograph", "Ideographic"},
    177047: {"Unified_Ideograph", "Ideographic"},
    177048: {"Unified_Ideograph", "Ideographic"},
    177049: {"Unified_Ideograph", "Ideographic"},
    177050: {"Unified_Ideograph", "Ideographic"},
    177051: {"Unified_Ideograph", "Ideographic"},
    177052: {"Unified_Ideograph", "Ideographic"},
    177053: {"Unified_Ideograph", "Ideographic"},
    177054: {"Unified_Ideograph", "Ideographic"},
    177055: {"Unified_Ideograph", "Ideographic"},
    177056: {"Unified_Ideograph", "Ideographic"},
    177057: {"Unified_Ideograph", "Ideographic"},
    177058: {"Unified_Ideograph", "Ideographic"},
    177059: {"Unified_Ideograph", "Ideographic"},
    177060: {"Unified_Ideograph", "Ideographic"},
    177061: {"Unified_Ideograph", "Ideographic"},
    177062: {"Unified_Ideograph", "Ideographic"},
    177063: {"Unified_Ideograph", "Ideographic"},
    177064: {"Unified_Ideograph", "Ideographic"},
    177065: {"Unified_Ideograph", "Ideographic"},
    177066: {"Unified_Ideograph", "Ideographic"},
    177067: {"Unified_Ideograph", "Ideographic"},
    177068: {"Unified_Ideograph", "Ideographic"},
    177069: {"Unified_Ideograph", "Ideographic"},
    177070: {"Unified_Ideograph", "Ideographic"},
    177071: {"Unified_Ideograph", "Ideographic"},
    177072: {"Unified_Ideograph", "Ideographic"},
    177073: {"Unified_Ideograph", "Ideographic"},
    177074: {"Unified_Ideograph", "Ideographic"},
    177075: {"Unified_Ideograph", "Ideographic"},
    177076: {"Unified_Ideograph", "Ideographic"},
    177077: {"Unified_Ideograph", "Ideographic"},
    177078: {"Unified_Ideograph", "Ideographic"},
    177079: {"Unified_Ideograph", "Ideographic"},
    177080: {"Unified_Ideograph", "Ideographic"},
    177081: {"Unified_Ideograph", "Ideographic"},
    177082: {"Unified_Ideograph", "Ideographic"},
    177083: {"Unified_Ideograph", "Ideographic"},
    177084: {"Unified_Ideograph", "Ideographic"},
    177085: {"Unified_Ideograph", "Ideographic"},
    177086: {"Unified_Ideograph", "Ideographic"},
    177087: {"Unified_Ideograph", "Ideographic"},
    177088: {"Unified_Ideograph", "Ideographic"},
    177089: {"Unified_Ideograph", "Ideographic"},
    177090: {"Unified_Ideograph", "Ideographic"},
    177091: {"Unified_Ideograph", "Ideographic"},
    177092: {"Unified_Ideograph", "Ideographic"},
    177093: {"Unified_Ideograph", "Ideographic"},
    177094: {"Unified_Ideograph", "Ideographic"},
    177095: {"Unified_Ideograph", "Ideographic"},
    177096: {"Unified_Ideograph", "Ideographic"},
    177097: {"Unified_Ideograph", "Ideographic"},
    177098: {"Unified_Ideograph", "Ideographic"},
    177099: {"Unified_Ideograph", "Ideographic"},
    177100: {"Unified_Ideograph", "Ideographic"},
    177101: {"Unified_Ideograph", "Ideographic"},
    177102: {"Unified_Ideograph", "Ideographic"},
    177103: {"Unified_Ideograph", "Ideographic"},
    177104: {"Unified_Ideograph", "Ideographic"},
    177105: {"Unified_Ideograph", "Ideographic"},
    177106: {"Unified_Ideograph", "Ideographic"},
    177107: {"Unified_Ideograph", "Ideographic"},
    177108: {"Unified_Ideograph", "Ideographic"},
    177109: {"Unified_Ideograph", "Ideographic"},
    177110: {"Unified_Ideograph", "Ideographic"},
    177111: {"Unified_Ideograph", "Ideographic"},
    177112: {"Unified_Ideograph", "Ideographic"},
    177113: {"Unified_Ideograph", "Ideographic"},
    177114: {"Unified_Ideograph", "Ideographic"},
    177115: {"Unified_Ideograph", "Ideographic"},
    177116: {"Unified_Ideograph", "Ideographic"},
    177117: {"Unified_Ideograph", "Ideographic"},
    177118: {"Unified_Ideograph", "Ideographic"},
    177119: {"Unified_Ideograph", "Ideographic"},
    177120: {"Unified_Ideograph", "Ideographic"},
    177121: {"Unified_Ideograph", "Ideographic"},
    177122: {"Unified_Ideograph", "Ideographic"},
    177123: {"Unified_Ideograph", "Ideographic"},
    177124: {"Unified_Ideograph", "Ideographic"},
    177125: {"Unified_Ideograph", "Ideographic"},
    177126: {"Unified_Ideograph", "Ideographic"},
    177127: {"Unified_Ideograph", "Ideographic"},
    177128: {"Unified_Ideograph", "Ideographic"},
    177129: {"Unified_Ideograph", "Ideographic"},
    177130: {"Unified_Ideograph", "Ideographic"},
    177131: {"Unified_Ideograph", "Ideographic"},
    177132: {"Unified_Ideograph", "Ideographic"},
    177133: {"Unified_Ideograph", "Ideographic"},
    177134: {"Unified_Ideograph", "Ideographic"},
    177135: {"Unified_Ideograph", "Ideographic"},
    177136: {"Unified_Ideograph", "Ideographic"},
    177137: {"Unified_Ideograph", "Ideographic"},
    177138: {"Unified_Ideograph", "Ideographic"},
    177139: {"Unified_Ideograph", "Ideographic"},
    177140: {"Unified_Ideograph", "Ideographic"},
    177141: {"Unified_Ideograph", "Ideographic"},
    177142: {"Unified_Ideograph", "Ideographic"},
    177143: {"Unified_Ideograph", "Ideographic"},
    177144: {"Unified_Ideograph", "Ideographic"},
    177145: {"Unified_Ideograph", "Ideographic"},
    177146: {"Unified_Ideograph", "Ideographic"},
    177147: {"Unified_Ideograph", "Ideographic"},
    177148: {"Unified_Ideograph", "Ideographic"},
    177149: {"Unified_Ideograph", "Ideographic"},
    177150: {"Unified_Ideograph", "Ideographic"},
    177151: {"Unified_Ideograph", "Ideographic"},
    177152: {"Unified_Ideograph", "Ideographic"},
    177153: {"Unified_Ideograph", "Ideographic"},
    177154: {"Unified_Ideograph", "Ideographic"},
    177155: {"Unified_Ideograph", "Ideographic"},
    177156: {"Unified_Ideograph", "Ideographic"},
    177157: {"Unified_Ideograph", "Ideographic"},
    177158: {"Unified_Ideograph", "Ideographic"},
    177159: {"Unified_Ideograph", "Ideographic"},
    177160: {"Unified_Ideograph", "Ideographic"},
    177161: {"Unified_Ideograph", "Ideographic"},
    177162: {"Unified_Ideograph", "Ideographic"},
    177163: {"Unified_Ideograph", "Ideographic"},
    177164: {"Unified_Ideograph", "Ideographic"},
    177165: {"Unified_Ideograph", "Ideographic"},
    177166: {"Unified_Ideograph", "Ideographic"},
    177167: {"Unified_Ideograph", "Ideographic"},
    177168: {"Unified_Ideograph", "Ideographic"},
    177169: {"Unified_Ideograph", "Ideographic"},
    177170: {"Unified_Ideograph", "Ideographic"},
    177171: {"Unified_Ideograph", "Ideographic"},
    177172: {"Unified_Ideograph", "Ideographic"},
    177173: {"Unified_Ideograph", "Ideographic"},
    177174: {"Unified_Ideograph", "Ideographic"},
    177175: {"Unified_Ideograph", "Ideographic"},
    177176: {"Unified_Ideograph", "Ideographic"},
    177177: {"Unified_Ideograph", "Ideographic"},
    177178: {"Unified_Ideograph", "Ideographic"},
    177179: {"Unified_Ideograph", "Ideographic"},
    177180: {"Unified_Ideograph", "Ideographic"},
    177181: {"Unified_Ideograph", "Ideographic"},
    177182: {"Unified_Ideograph", "Ideographic"},
    177183: {"Unified_Ideograph", "Ideographic"},
    177184: {"Unified_Ideograph", "Ideographic"},
    177185: {"Unified_Ideograph", "Ideographic"},
    177186: {"Unified_Ideograph", "Ideographic"},
    177187: {"Unified_Ideograph", "Ideographic"},
    177188: {"Unified_Ideograph", "Ideographic"},
    177189: {"Unified_Ideograph", "Ideographic"},
    177190: {"Unified_Ideograph", "Ideographic"},
    177191: {"Unified_Ideograph", "Ideographic"},
    177192: {"Unified_Ideograph", "Ideographic"},
    177193: {"Unified_Ideograph", "Ideographic"},
    177194: {"Unified_Ideograph", "Ideographic"},
    177195: {"Unified_Ideograph", "Ideographic"},
    177196: {"Unified_Ideograph", "Ideographic"},
    177197: {"Unified_Ideograph", "Ideographic"},
    177198: {"Unified_Ideograph", "Ideographic"},
    177199: {"Unified_Ideograph", "Ideographic"},
    177200: {"Unified_Ideograph", "Ideographic"},
    177201: {"Unified_Ideograph", "Ideographic"},
    177202: {"Unified_Ideograph", "Ideographic"},
    177203: {"Unified_Ideograph", "Ideographic"},
    177204: {"Unified_Ideograph", "Ideographic"},
    177205: {"Unified_Ideograph", "Ideographic"},
    177206: {"Unified_Ideograph", "Ideographic"},
    177207: {"Unified_Ideograph", "Ideographic"},
    177208: {"Unified_Ideograph", "Ideographic"},
    177209: {"Unified_Ideograph", "Ideographic"},
    177210: {"Unified_Ideograph", "Ideographic"},
    177211: {"Unified_Ideograph", "Ideographic"},
    177212: {"Unified_Ideograph", "Ideographic"},
    177213: {"Unified_Ideograph", "Ideographic"},
    177214: {"Unified_Ideograph", "Ideographic"},
    177215: {"Unified_Ideograph", "Ideographic"},
    177216: {"Unified_Ideograph", "Ideographic"},
    177217: {"Unified_Ideograph", "Ideographic"},
    177218: {"Unified_Ideograph", "Ideographic"},
    177219: {"Unified_Ideograph", "Ideographic"},
    177220: {"Unified_Ideograph", "Ideographic"},
    177221: {"Unified_Ideograph", "Ideographic"},
    177222: {"Unified_Ideograph", "Ideographic"},
    177223: {"Unified_Ideograph", "Ideographic"},
    177224: {"Unified_Ideograph", "Ideographic"},
    177225: {"Unified_Ideograph", "Ideographic"},
    177226: {"Unified_Ideograph", "Ideographic"},
    177227: {"Unified_Ideograph", "Ideographic"},
    177228: {"Unified_Ideograph", "Ideographic"},
    177229: {"Unified_Ideograph", "Ideographic"},
    177230: {"Unified_Ideograph", "Ideographic"},
    177231: {"Unified_Ideograph", "Ideographic"},
    177232: {"Unified_Ideograph", "Ideographic"},
    177233: {"Unified_Ideograph", "Ideographic"},
    177234: {"Unified_Ideograph", "Ideographic"},
    177235: {"Unified_Ideograph", "Ideographic"},
    177236: {"Unified_Ideograph", "Ideographic"},
    177237: {"Unified_Ideograph", "Ideographic"},
    177238: {"Unified_Ideograph", "Ideographic"},
    177239: {"Unified_Ideograph", "Ideographic"},
    177240: {"Unified_Ideograph", "Ideographic"},
    177241: {"Unified_Ideograph", "Ideographic"},
    177242: {"Unified_Ideograph", "Ideographic"},
    177243: {"Unified_Ideograph", "Ideographic"},
    177244: {"Unified_Ideograph", "Ideographic"},
    177245: {"Unified_Ideograph", "Ideographic"},
    177246: {"Unified_Ideograph", "Ideographic"},
    177247: {"Unified_Ideograph", "Ideographic"},
    177248: {"Unified_Ideograph", "Ideographic"},
    177249: {"Unified_Ideograph", "Ideographic"},
    177250: {"Unified_Ideograph", "Ideographic"},
    177251: {"Unified_Ideograph", "Ideographic"},
    177252: {"Unified_Ideograph", "Ideographic"},
    177253: {"Unified_Ideograph", "Ideographic"},
    177254: {"Unified_Ideograph", "Ideographic"},
    177255: {"Unified_Ideograph", "Ideographic"},
    177256: {"Unified_Ideograph", "Ideographic"},
    177257: {"Unified_Ideograph", "Ideographic"},
    177258: {"Unified_Ideograph", "Ideographic"},
    177259: {"Unified_Ideograph", "Ideographic"},
    177260: {"Unified_Ideograph", "Ideographic"},
    177261: {"Unified_Ideograph", "Ideographic"},
    177262: {"Unified_Ideograph", "Ideographic"},
    177263: {"Unified_Ideograph", "Ideographic"},
    177264: {"Unified_Ideograph", "Ideographic"},
    177265: {"Unified_Ideograph", "Ideographic"},
    177266: {"Unified_Ideograph", "Ideographic"},
    177267: {"Unified_Ideograph", "Ideographic"},
    177268: {"Unified_Ideograph", "Ideographic"},
    177269: {"Unified_Ideograph", "Ideographic"},
    177270: {"Unified_Ideograph", "Ideographic"},
    177271: {"Unified_Ideograph", "Ideographic"},
    177272: {"Unified_Ideograph", "Ideographic"},
    177273: {"Unified_Ideograph", "Ideographic"},
    177274: {"Unified_Ideograph", "Ideographic"},
    177275: {"Unified_Ideograph", "Ideographic"},
    177276: {"Unified_Ideograph", "Ideographic"},
    177277: {"Unified_Ideograph", "Ideographic"},
    177278: {"Unified_Ideograph", "Ideographic"},
    177279: {"Unified_Ideograph", "Ideographic"},
    177280: {"Unified_Ideograph", "Ideographic"},
    177281: {"Unified_Ideograph", "Ideographic"},
    177282: {"Unified_Ideograph", "Ideographic"},
    177283: {"Unified_Ideograph", "Ideographic"},
    177284: {"Unified_Ideograph", "Ideographic"},
    177285: {"Unified_Ideograph", "Ideographic"},
    177286: {"Unified_Ideograph", "Ideographic"},
    177287: {"Unified_Ideograph", "Ideographic"},
    177288: {"Unified_Ideograph", "Ideographic"},
    177289: {"Unified_Ideograph", "Ideographic"},
    177290: {"Unified_Ideograph", "Ideographic"},
    177291: {"Unified_Ideograph", "Ideographic"},
    177292: {"Unified_Ideograph", "Ideographic"},
    177293: {"Unified_Ideograph", "Ideographic"},
    177294: {"Unified_Ideograph", "Ideographic"},
    177295: {"Unified_Ideograph", "Ideographic"},
    177296: {"Unified_Ideograph", "Ideographic"},
    177297: {"Unified_Ideograph", "Ideographic"},
    177298: {"Unified_Ideograph", "Ideographic"},
    177299: {"Unified_Ideograph", "Ideographic"},
    177300: {"Unified_Ideograph", "Ideographic"},
    177301: {"Unified_Ideograph", "Ideographic"},
    177302: {"Unified_Ideograph", "Ideographic"},
    177303: {"Unified_Ideograph", "Ideographic"},
    177304: {"Unified_Ideograph", "Ideographic"},
    177305: {"Unified_Ideograph", "Ideographic"},
    177306: {"Unified_Ideograph", "Ideographic"},
    177307: {"Unified_Ideograph", "Ideographic"},
    177308: {"Unified_Ideograph", "Ideographic"},
    177309: {"Unified_Ideograph", "Ideographic"},
    177310: {"Unified_Ideograph", "Ideographic"},
    177311: {"Unified_Ideograph", "Ideographic"},
    177312: {"Unified_Ideograph", "Ideographic"},
    177313: {"Unified_Ideograph", "Ideographic"},
    177314: {"Unified_Ideograph", "Ideographic"},
    177315: {"Unified_Ideograph", "Ideographic"},
    177316: {"Unified_Ideograph", "Ideographic"},
    177317: {"Unified_Ideograph", "Ideographic"},
    177318: {"Unified_Ideograph", "Ideographic"},
    177319: {"Unified_Ideograph", "Ideographic"},
    177320: {"Unified_Ideograph", "Ideographic"},
    177321: {"Unified_Ideograph", "Ideographic"},
    177322: {"Unified_Ideograph", "Ideographic"},
    177323: {"Unified_Ideograph", "Ideographic"},
    177324: {"Unified_Ideograph", "Ideographic"},
    177325: {"Unified_Ideograph", "Ideographic"},
    177326: {"Unified_Ideograph", "Ideographic"},
    177327: {"Unified_Ideograph", "Ideographic"},
    177328: {"Unified_Ideograph", "Ideographic"},
    177329: {"Unified_Ideograph", "Ideographic"},
    177330: {"Unified_Ideograph", "Ideographic"},
    177331: {"Unified_Ideograph", "Ideographic"},
    177332: {"Unified_Ideograph", "Ideographic"},
    177333: {"Unified_Ideograph", "Ideographic"},
    177334: {"Unified_Ideograph", "Ideographic"},
    177335: {"Unified_Ideograph", "Ideographic"},
    177336: {"Unified_Ideograph", "Ideographic"},
    177337: {"Unified_Ideograph", "Ideographic"},
    177338: {"Unified_Ideograph", "Ideographic"},
    177339: {"Unified_Ideograph", "Ideographic"},
    177340: {"Unified_Ideograph", "Ideographic"},
    177341: {"Unified_Ideograph", "Ideographic"},
    177342: {"Unified_Ideograph", "Ideographic"},
    177343: {"Unified_Ideograph", "Ideographic"},
    177344: {"Unified_Ideograph", "Ideographic"},
    177345: {"Unified_Ideograph", "Ideographic"},
    177346: {"Unified_Ideograph", "Ideographic"},
    177347: {"Unified_Ideograph", "Ideographic"},
    177348: {"Unified_Ideograph", "Ideographic"},
    177349: {"Unified_Ideograph", "Ideographic"},
    177350: {"Unified_Ideograph", "Ideographic"},
    177351: {"Unified_Ideograph", "Ideographic"},
    177352: {"Unified_Ideograph", "Ideographic"},
    177353: {"Unified_Ideograph", "Ideographic"},
    177354: {"Unified_Ideograph", "Ideographic"},
    177355: {"Unified_Ideograph", "Ideographic"},
    177356: {"Unified_Ideograph", "Ideographic"},
    177357: {"Unified_Ideograph", "Ideographic"},
    177358: {"Unified_Ideograph", "Ideographic"},
    177359: {"Unified_Ideograph", "Ideographic"},
    177360: {"Unified_Ideograph", "Ideographic"},
    177361: {"Unified_Ideograph", "Ideographic"},
    177362: {"Unified_Ideograph", "Ideographic"},
    177363: {"Unified_Ideograph", "Ideographic"},
    177364: {"Unified_Ideograph", "Ideographic"},
    177365: {"Unified_Ideograph", "Ideographic"},
    177366: {"Unified_Ideograph", "Ideographic"},
    177367: {"Unified_Ideograph", "Ideographic"},
    177368: {"Unified_Ideograph", "Ideographic"},
    177369: {"Unified_Ideograph", "Ideographic"},
    177370: {"Unified_Ideograph", "Ideographic"},
    177371: {"Unified_Ideograph", "Ideographic"},
    177372: {"Unified_Ideograph", "Ideographic"},
    177373: {"Unified_Ideograph", "Ideographic"},
    177374: {"Unified_Ideograph", "Ideographic"},
    177375: {"Unified_Ideograph", "Ideographic"},
    177376: {"Unified_Ideograph", "Ideographic"},
    177377: {"Unified_Ideograph", "Ideographic"},
    177378: {"Unified_Ideograph", "Ideographic"},
    177379: {"Unified_Ideograph", "Ideographic"},
    177380: {"Unified_Ideograph", "Ideographic"},
    177381: {"Unified_Ideograph", "Ideographic"},
    177382: {"Unified_Ideograph", "Ideographic"},
    177383: {"Unified_Ideograph", "Ideographic"},
    177384: {"Unified_Ideograph", "Ideographic"},
    177385: {"Unified_Ideograph", "Ideographic"},
    177386: {"Unified_Ideograph", "Ideographic"},
    177387: {"Unified_Ideograph", "Ideographic"},
    177388: {"Unified_Ideograph", "Ideographic"},
    177389: {"Unified_Ideograph", "Ideographic"},
    177390: {"Unified_Ideograph", "Ideographic"},
    177391: {"Unified_Ideograph", "Ideographic"},
    177392: {"Unified_Ideograph", "Ideographic"},
    177393: {"Unified_Ideograph", "Ideographic"},
    177394: {"Unified_Ideograph", "Ideographic"},
    177395: {"Unified_Ideograph", "Ideographic"},
    177396: {"Unified_Ideograph", "Ideographic"},
    177397: {"Unified_Ideograph", "Ideographic"},
    177398: {"Unified_Ideograph", "Ideographic"},
    177399: {"Unified_Ideograph", "Ideographic"},
    177400: {"Unified_Ideograph", "Ideographic"},
    177401: {"Unified_Ideograph", "Ideographic"},
    177402: {"Unified_Ideograph", "Ideographic"},
    177403: {"Unified_Ideograph", "Ideographic"},
    177404: {"Unified_Ideograph", "Ideographic"},
    177405: {"Unified_Ideograph", "Ideographic"},
    177406: {"Unified_Ideograph", "Ideographic"},
    177407: {"Unified_Ideograph", "Ideographic"},
    177408: {"Unified_Ideograph", "Ideographic"},
    177409: {"Unified_Ideograph", "Ideographic"},
    177410: {"Unified_Ideograph", "Ideographic"},
    177411: {"Unified_Ideograph", "Ideographic"},
    177412: {"Unified_Ideograph", "Ideographic"},
    177413: {"Unified_Ideograph", "Ideographic"},
    177414: {"Unified_Ideograph", "Ideographic"},
    177415: {"Unified_Ideograph", "Ideographic"},
    177416: {"Unified_Ideograph", "Ideographic"},
    177417: {"Unified_Ideograph", "Ideographic"},
    177418: {"Unified_Ideograph", "Ideographic"},
    177419: {"Unified_Ideograph", "Ideographic"},
    177420: {"Unified_Ideograph", "Ideographic"},
    177421: {"Unified_Ideograph", "Ideographic"},
    177422: {"Unified_Ideograph", "Ideographic"},
    177423: {"Unified_Ideograph", "Ideographic"},
    177424: {"Unified_Ideograph", "Ideographic"},
    177425: {"Unified_Ideograph", "Ideographic"},
    177426: {"Unified_Ideograph", "Ideographic"},
    177427: {"Unified_Ideograph", "Ideographic"},
    177428: {"Unified_Ideograph", "Ideographic"},
    177429: {"Unified_Ideograph", "Ideographic"},
    177430: {"Unified_Ideograph", "Ideographic"},
    177431: {"Unified_Ideograph", "Ideographic"},
    177432: {"Unified_Ideograph", "Ideographic"},
    177433: {"Unified_Ideograph", "Ideographic"},
    177434: {"Unified_Ideograph", "Ideographic"},
    177435: {"Unified_Ideograph", "Ideographic"},
    177436: {"Unified_Ideograph", "Ideographic"},
    177437: {"Unified_Ideograph", "Ideographic"},
    177438: {"Unified_Ideograph", "Ideographic"},
    177439: {"Unified_Ideograph", "Ideographic"},
    177440: {"Unified_Ideograph", "Ideographic"},
    177441: {"Unified_Ideograph", "Ideographic"},
    177442: {"Unified_Ideograph", "Ideographic"},
    177443: {"Unified_Ideograph", "Ideographic"},
    177444: {"Unified_Ideograph", "Ideographic"},
    177445: {"Unified_Ideograph", "Ideographic"},
    177446: {"Unified_Ideograph", "Ideographic"},
    177447: {"Unified_Ideograph", "Ideographic"},
    177448: {"Unified_Ideograph", "Ideographic"},
    177449: {"Unified_Ideograph", "Ideographic"},
    177450: {"Unified_Ideograph", "Ideographic"},
    177451: {"Unified_Ideograph", "Ideographic"},
    177452: {"Unified_Ideograph", "Ideographic"},
    177453: {"Unified_Ideograph", "Ideographic"},
    177454: {"Unified_Ideograph", "Ideographic"},
    177455: {"Unified_Ideograph", "Ideographic"},
    177456: {"Unified_Ideograph", "Ideographic"},
    177457: {"Unified_Ideograph", "Ideographic"},
    177458: {"Unified_Ideograph", "Ideographic"},
    177459: {"Unified_Ideograph", "Ideographic"},
    177460: {"Unified_Ideograph", "Ideographic"},
    177461: {"Unified_Ideograph", "Ideographic"},
    177462: {"Unified_Ideograph", "Ideographic"},
    177463: {"Unified_Ideograph", "Ideographic"},
    177464: {"Unified_Ideograph", "Ideographic"},
    177465: {"Unified_Ideograph", "Ideographic"},
    177466: {"Unified_Ideograph", "Ideographic"},
    177467: {"Unified_Ideograph", "Ideographic"},
    177468: {"Unified_Ideograph", "Ideographic"},
    177469: {"Unified_Ideograph", "Ideographic"},
    177470: {"Unified_Ideograph", "Ideographic"},
    177471: {"Unified_Ideograph", "Ideographic"},
    177472: {"Unified_Ideograph", "Ideographic"},
    177473: {"Unified_Ideograph", "Ideographic"},
    177474: {"Unified_Ideograph", "Ideographic"},
    177475: {"Unified_Ideograph", "Ideographic"},
    177476: {"Unified_Ideograph", "Ideographic"},
    177477: {"Unified_Ideograph", "Ideographic"},
    177478: {"Unified_Ideograph", "Ideographic"},
    177479: {"Unified_Ideograph", "Ideographic"},
    177480: {"Unified_Ideograph", "Ideographic"},
    177481: {"Unified_Ideograph", "Ideographic"},
    177482: {"Unified_Ideograph", "Ideographic"},
    177483: {"Unified_Ideograph", "Ideographic"},
    177484: {"Unified_Ideograph", "Ideographic"},
    177485: {"Unified_Ideograph", "Ideographic"},
    177486: {"Unified_Ideograph", "Ideographic"},
    177487: {"Unified_Ideograph", "Ideographic"},
    177488: {"Unified_Ideograph", "Ideographic"},
    177489: {"Unified_Ideograph", "Ideographic"},
    177490: {"Unified_Ideograph", "Ideographic"},
    177491: {"Unified_Ideograph", "Ideographic"},
    177492: {"Unified_Ideograph", "Ideographic"},
    177493: {"Unified_Ideograph", "Ideographic"},
    177494: {"Unified_Ideograph", "Ideographic"},
    177495: {"Unified_Ideograph", "Ideographic"},
    177496: {"Unified_Ideograph", "Ideographic"},
    177497: {"Unified_Ideograph", "Ideographic"},
    177498: {"Unified_Ideograph", "Ideographic"},
    177499: {"Unified_Ideograph", "Ideographic"},
    177500: {"Unified_Ideograph", "Ideographic"},
    177501: {"Unified_Ideograph", "Ideographic"},
    177502: {"Unified_Ideograph", "Ideographic"},
    177503: {"Unified_Ideograph", "Ideographic"},
    177504: {"Unified_Ideograph", "Ideographic"},
    177505: {"Unified_Ideograph", "Ideographic"},
    177506: {"Unified_Ideograph", "Ideographic"},
    177507: {"Unified_Ideograph", "Ideographic"},
    177508: {"Unified_Ideograph", "Ideographic"},
    177509: {"Unified_Ideograph", "Ideographic"},
    177510: {"Unified_Ideograph", "Ideographic"},
    177511: {"Unified_Ideograph", "Ideographic"},
    177512: {"Unified_Ideograph", "Ideographic"},
    177513: {"Unified_Ideograph", "Ideographic"},
    177514: {"Unified_Ideograph", "Ideographic"},
    177515: {"Unified_Ideograph", "Ideographic"},
    177516: {"Unified_Ideograph", "Ideographic"},
    177517: {"Unified_Ideograph", "Ideographic"},
    177518: {"Unified_Ideograph", "Ideographic"},
    177519: {"Unified_Ideograph", "Ideographic"},
    177520: {"Unified_Ideograph", "Ideographic"},
    177521: {"Unified_Ideograph", "Ideographic"},
    177522: {"Unified_Ideograph", "Ideographic"},
    177523: {"Unified_Ideograph", "Ideographic"},
    177524: {"Unified_Ideograph", "Ideographic"},
    177525: {"Unified_Ideograph", "Ideographic"},
    177526: {"Unified_Ideograph", "Ideographic"},
    177527: {"Unified_Ideograph", "Ideographic"},
    177528: {"Unified_Ideograph", "Ideographic"},
    177529: {"Unified_Ideograph", "Ideographic"},
    177530: {"Unified_Ideograph", "Ideographic"},
    177531: {"Unified_Ideograph", "Ideographic"},
    177532: {"Unified_Ideograph", "Ideographic"},
    177533: {"Unified_Ideograph", "Ideographic"},
    177534: {"Unified_Ideograph", "Ideographic"},
    177535: {"Unified_Ideograph", "Ideographic"},
    177536: {"Unified_Ideograph", "Ideographic"},
    177537: {"Unified_Ideograph", "Ideographic"},
    177538: {"Unified_Ideograph", "Ideographic"},
    177539: {"Unified_Ideograph", "Ideographic"},
    177540: {"Unified_Ideograph", "Ideographic"},
    177541: {"Unified_Ideograph", "Ideographic"},
    177542: {"Unified_Ideograph", "Ideographic"},
    177543: {"Unified_Ideograph", "Ideographic"},
    177544: {"Unified_Ideograph", "Ideographic"},
    177545: {"Unified_Ideograph", "Ideographic"},
    177546: {"Unified_Ideograph", "Ideographic"},
    177547: {"Unified_Ideograph", "Ideographic"},
    177548: {"Unified_Ideograph", "Ideographic"},
    177549: {"Unified_Ideograph", "Ideographic"},
    177550: {"Unified_Ideograph", "Ideographic"},
    177551: {"Unified_Ideograph", "Ideographic"},
    177552: {"Unified_Ideograph", "Ideographic"},
    177553: {"Unified_Ideograph", "Ideographic"},
    177554: {"Unified_Ideograph", "Ideographic"},
    177555: {"Unified_Ideograph", "Ideographic"},
    177556: {"Unified_Ideograph", "Ideographic"},
    177557: {"Unified_Ideograph", "Ideographic"},
    177558: {"Unified_Ideograph", "Ideographic"},
    177559: {"Unified_Ideograph", "Ideographic"},
    177560: {"Unified_Ideograph", "Ideographic"},
    177561: {"Unified_Ideograph", "Ideographic"},
    177562: {"Unified_Ideograph", "Ideographic"},
    177563: {"Unified_Ideograph", "Ideographic"},
    177564: {"Unified_Ideograph", "Ideographic"},
    177565: {"Unified_Ideograph", "Ideographic"},
    177566: {"Unified_Ideograph", "Ideographic"},
    177567: {"Unified_Ideograph", "Ideographic"},
    177568: {"Unified_Ideograph", "Ideographic"},
    177569: {"Unified_Ideograph", "Ideographic"},
    177570: {"Unified_Ideograph", "Ideographic"},
    177571: {"Unified_Ideograph", "Ideographic"},
    177572: {"Unified_Ideograph", "Ideographic"},
    177573: {"Unified_Ideograph", "Ideographic"},
    177574: {"Unified_Ideograph", "Ideographic"},
    177575: {"Unified_Ideograph", "Ideographic"},
    177576: {"Unified_Ideograph", "Ideographic"},
    177577: {"Unified_Ideograph", "Ideographic"},
    177578: {"Unified_Ideograph", "Ideographic"},
    177579: {"Unified_Ideograph", "Ideographic"},
    177580: {"Unified_Ideograph", "Ideographic"},
    177581: {"Unified_Ideograph", "Ideographic"},
    177582: {"Unified_Ideograph", "Ideographic"},
    177583: {"Unified_Ideograph", "Ideographic"},
    177584: {"Unified_Ideograph", "Ideographic"},
    177585: {"Unified_Ideograph", "Ideographic"},
    177586: {"Unified_Ideograph", "Ideographic"},
    177587: {"Unified_Ideograph", "Ideographic"},
    177588: {"Unified_Ideograph", "Ideographic"},
    177589: {"Unified_Ideograph", "Ideographic"},
    177590: {"Unified_Ideograph", "Ideographic"},
    177591: {"Unified_Ideograph", "Ideographic"},
    177592: {"Unified_Ideograph", "Ideographic"},
    177593: {"Unified_Ideograph", "Ideographic"},
    177594: {"Unified_Ideograph", "Ideographic"},
    177595: {"Unified_Ideograph", "Ideographic"},
    177596: {"Unified_Ideograph", "Ideographic"},
    177597: {"Unified_Ideograph", "Ideographic"},
    177598: {"Unified_Ideograph", "Ideographic"},
    177599: {"Unified_Ideograph", "Ideographic"},
    177600: {"Unified_Ideograph", "Ideographic"},
    177601: {"Unified_Ideograph", "Ideographic"},
    177602: {"Unified_Ideograph", "Ideographic"},
    177603: {"Unified_Ideograph", "Ideographic"},
    177604: {"Unified_Ideograph", "Ideographic"},
    177605: {"Unified_Ideograph", "Ideographic"},
    177606: {"Unified_Ideograph", "Ideographic"},
    177607: {"Unified_Ideograph", "Ideographic"},
    177608: {"Unified_Ideograph", "Ideographic"},
    177609: {"Unified_Ideograph", "Ideographic"},
    177610: {"Unified_Ideograph", "Ideographic"},
    177611: {"Unified_Ideograph", "Ideographic"},
    177612: {"Unified_Ideograph", "Ideographic"},
    177613: {"Unified_Ideograph", "Ideographic"},
    177614: {"Unified_Ideograph", "Ideographic"},
    177615: {"Unified_Ideograph", "Ideographic"},
    177616: {"Unified_Ideograph", "Ideographic"},
    177617: {"Unified_Ideograph", "Ideographic"},
    177618: {"Unified_Ideograph", "Ideographic"},
    177619: {"Unified_Ideograph", "Ideographic"},
    177620: {"Unified_Ideograph", "Ideographic"},
    177621: {"Unified_Ideograph", "Ideographic"},
    177622: {"Unified_Ideograph", "Ideographic"},
    177623: {"Unified_Ideograph", "Ideographic"},
    177624: {"Unified_Ideograph", "Ideographic"},
    177625: {"Unified_Ideograph", "Ideographic"},
    177626: {"Unified_Ideograph", "Ideographic"},
    177627: {"Unified_Ideograph", "Ideographic"},
    177628: {"Unified_Ideograph", "Ideographic"},
    177629: {"Unified_Ideograph", "Ideographic"},
    177630: {"Unified_Ideograph", "Ideographic"},
    177631: {"Unified_Ideograph", "Ideographic"},
    177632: {"Unified_Ideograph", "Ideographic"},
    177633: {"Unified_Ideograph", "Ideographic"},
    177634: {"Unified_Ideograph", "Ideographic"},
    177635: {"Unified_Ideograph", "Ideographic"},
    177636: {"Unified_Ideograph", "Ideographic"},
    177637: {"Unified_Ideograph", "Ideographic"},
    177638: {"Unified_Ideograph", "Ideographic"},
    177639: {"Unified_Ideograph", "Ideographic"},
    177640: {"Unified_Ideograph", "Ideographic"},
    177641: {"Unified_Ideograph", "Ideographic"},
    177642: {"Unified_Ideograph", "Ideographic"},
    177643: {"Unified_Ideograph", "Ideographic"},
    177644: {"Unified_Ideograph", "Ideographic"},
    177645: {"Unified_Ideograph", "Ideographic"},
    177646: {"Unified_Ideograph", "Ideographic"},
    177647: {"Unified_Ideograph", "Ideographic"},
    177648: {"Unified_Ideograph", "Ideographic"},
    177649: {"Unified_Ideograph", "Ideographic"},
    177650: {"Unified_Ideograph", "Ideographic"},
    177651: {"Unified_Ideograph", "Ideographic"},
    177652: {"Unified_Ideograph", "Ideographic"},
    177653: {"Unified_Ideograph", "Ideographic"},
    177654: {"Unified_Ideograph", "Ideographic"},
    177655: {"Unified_Ideograph", "Ideographic"},
    177656: {"Unified_Ideograph", "Ideographic"},
    177657: {"Unified_Ideograph", "Ideographic"},
    177658: {"Unified_Ideograph", "Ideographic"},
    177659: {"Unified_Ideograph", "Ideographic"},
    177660: {"Unified_Ideograph", "Ideographic"},
    177661: {"Unified_Ideograph", "Ideographic"},
    177662: {"Unified_Ideograph", "Ideographic"},
    177663: {"Unified_Ideograph", "Ideographic"},
    177664: {"Unified_Ideograph", "Ideographic"},
    177665: {"Unified_Ideograph", "Ideographic"},
    177666: {"Unified_Ideograph", "Ideographic"},
    177667: {"Unified_Ideograph", "Ideographic"},
    177668: {"Unified_Ideograph", "Ideographic"},
    177669: {"Unified_Ideograph", "Ideographic"},
    177670: {"Unified_Ideograph", "Ideographic"},
    177671: {"Unified_Ideograph", "Ideographic"},
    177672: {"Unified_Ideograph", "Ideographic"},
    177673: {"Unified_Ideograph", "Ideographic"},
    177674: {"Unified_Ideograph", "Ideographic"},
    177675: {"Unified_Ideograph", "Ideographic"},
    177676: {"Unified_Ideograph", "Ideographic"},
    177677: {"Unified_Ideograph", "Ideographic"},
    177678: {"Unified_Ideograph", "Ideographic"},
    177679: {"Unified_Ideograph", "Ideographic"},
    177680: {"Unified_Ideograph", "Ideographic"},
    177681: {"Unified_Ideograph", "Ideographic"},
    177682: {"Unified_Ideograph", "Ideographic"},
    177683: {"Unified_Ideograph", "Ideographic"},
    177684: {"Unified_Ideograph", "Ideographic"},
    177685: {"Unified_Ideograph", "Ideographic"},
    177686: {"Unified_Ideograph", "Ideographic"},
    177687: {"Unified_Ideograph", "Ideographic"},
    177688: {"Unified_Ideograph", "Ideographic"},
    177689: {"Unified_Ideograph", "Ideographic"},
    177690: {"Unified_Ideograph", "Ideographic"},
    177691: {"Unified_Ideograph", "Ideographic"},
    177692: {"Unified_Ideograph", "Ideographic"},
    177693: {"Unified_Ideograph", "Ideographic"},
    177694: {"Unified_Ideograph", "Ideographic"},
    177695: {"Unified_Ideograph", "Ideographic"},
    177696: {"Unified_Ideograph", "Ideographic"},
    177697: {"Unified_Ideograph", "Ideographic"},
    177698: {"Unified_Ideograph", "Ideographic"},
    177699: {"Unified_Ideograph", "Ideographic"},
    177700: {"Unified_Ideograph", "Ideographic"},
    177701: {"Unified_Ideograph", "Ideographic"},
    177702: {"Unified_Ideograph", "Ideographic"},
    177703: {"Unified_Ideograph", "Ideographic"},
    177704: {"Unified_Ideograph", "Ideographic"},
    177705: {"Unified_Ideograph", "Ideographic"},
    177706: {"Unified_Ideograph", "Ideographic"},
    177707: {"Unified_Ideograph", "Ideographic"},
    177708: {"Unified_Ideograph", "Ideographic"},
    177709: {"Unified_Ideograph", "Ideographic"},
    177710: {"Unified_Ideograph", "Ideographic"},
    177711: {"Unified_Ideograph", "Ideographic"},
    177712: {"Unified_Ideograph", "Ideographic"},
    177713: {"Unified_Ideograph", "Ideographic"},
    177714: {"Unified_Ideograph", "Ideographic"},
    177715: {"Unified_Ideograph", "Ideographic"},
    177716: {"Unified_Ideograph", "Ideographic"},
    177717: {"Unified_Ideograph", "Ideographic"},
    177718: {"Unified_Ideograph", "Ideographic"},
    177719: {"Unified_Ideograph", "Ideographic"},
    177720: {"Unified_Ideograph", "Ideographic"},
    177721: {"Unified_Ideograph", "Ideographic"},
    177722: {"Unified_Ideograph", "Ideographic"},
    177723: {"Unified_Ideograph", "Ideographic"},
    177724: {"Unified_Ideograph", "Ideographic"},
    177725: {"Unified_Ideograph", "Ideographic"},
    177726: {"Unified_Ideograph", "Ideographic"},
    177727: {"Unified_Ideograph", "Ideographic"},
    177728: {"Unified_Ideograph", "Ideographic"},
    177729: {"Unified_Ideograph", "Ideographic"},
    177730: {"Unified_Ideograph", "Ideographic"},
    177731: {"Unified_Ideograph", "Ideographic"},
    177732: {"Unified_Ideograph", "Ideographic"},
    177733: {"Unified_Ideograph", "Ideographic"},
    177734: {"Unified_Ideograph", "Ideographic"},
    177735: {"Unified_Ideograph", "Ideographic"},
    177736: {"Unified_Ideograph", "Ideographic"},
    177737: {"Unified_Ideograph", "Ideographic"},
    177738: {"Unified_Ideograph", "Ideographic"},
    177739: {"Unified_Ideograph", "Ideographic"},
    177740: {"Unified_Ideograph", "Ideographic"},
    177741: {"Unified_Ideograph", "Ideographic"},
    177742: {"Unified_Ideograph", "Ideographic"},
    177743: {"Unified_Ideograph", "Ideographic"},
    177744: {"Unified_Ideograph", "Ideographic"},
    177745: {"Unified_Ideograph", "Ideographic"},
    177746: {"Unified_Ideograph", "Ideographic"},
    177747: {"Unified_Ideograph", "Ideographic"},
    177748: {"Unified_Ideograph", "Ideographic"},
    177749: {"Unified_Ideograph", "Ideographic"},
    177750: {"Unified_Ideograph", "Ideographic"},
    177751: {"Unified_Ideograph", "Ideographic"},
    177752: {"Unified_Ideograph", "Ideographic"},
    177753: {"Unified_Ideograph", "Ideographic"},
    177754: {"Unified_Ideograph", "Ideographic"},
    177755: {"Unified_Ideograph", "Ideographic"},
    177756: {"Unified_Ideograph", "Ideographic"},
    177757: {"Unified_Ideograph", "Ideographic"},
    177758: {"Unified_Ideograph", "Ideographic"},
    177759: {"Unified_Ideograph", "Ideographic"},
    177760: {"Unified_Ideograph", "Ideographic"},
    177761: {"Unified_Ideograph", "Ideographic"},
    177762: {"Unified_Ideograph", "Ideographic"},
    177763: {"Unified_Ideograph", "Ideographic"},
    177764: {"Unified_Ideograph", "Ideographic"},
    177765: {"Unified_Ideograph", "Ideographic"},
    177766: {"Unified_Ideograph", "Ideographic"},
    177767: {"Unified_Ideograph", "Ideographic"},
    177768: {"Unified_Ideograph", "Ideographic"},
    177769: {"Unified_Ideograph", "Ideographic"},
    177770: {"Unified_Ideograph", "Ideographic"},
    177771: {"Unified_Ideograph", "Ideographic"},
    177772: {"Unified_Ideograph", "Ideographic"},
    177773: {"Unified_Ideograph", "Ideographic"},
    177774: {"Unified_Ideograph", "Ideographic"},
    177775: {"Unified_Ideograph", "Ideographic"},
    177776: {"Unified_Ideograph", "Ideographic"},
    177777: {"Unified_Ideograph", "Ideographic"},
    177778: {"Unified_Ideograph", "Ideographic"},
    177779: {"Unified_Ideograph", "Ideographic"},
    177780: {"Unified_Ideograph", "Ideographic"},
    177781: {"Unified_Ideograph", "Ideographic"},
    177782: {"Unified_Ideograph", "Ideographic"},
    177783: {"Unified_Ideograph", "Ideographic"},
    177784: {"Unified_Ideograph", "Ideographic"},
    177785: {"Unified_Ideograph", "Ideographic"},
    177786: {"Unified_Ideograph", "Ideographic"},
    177787: {"Unified_Ideograph", "Ideographic"},
    177788: {"Unified_Ideograph", "Ideographic"},
    177789: {"Unified_Ideograph", "Ideographic"},
    177790: {"Unified_Ideograph", "Ideographic"},
    177791: {"Unified_Ideograph", "Ideographic"},
    177792: {"Unified_Ideograph", "Ideographic"},
    177793: {"Unified_Ideograph", "Ideographic"},
    177794: {"Unified_Ideograph", "Ideographic"},
    177795: {"Unified_Ideograph", "Ideographic"},
    177796: {"Unified_Ideograph", "Ideographic"},
    177797: {"Unified_Ideograph", "Ideographic"},
    177798: {"Unified_Ideograph", "Ideographic"},
    177799: {"Unified_Ideograph", "Ideographic"},
    177800: {"Unified_Ideograph", "Ideographic"},
    177801: {"Unified_Ideograph", "Ideographic"},
    177802: {"Unified_Ideograph", "Ideographic"},
    177803: {"Unified_Ideograph", "Ideographic"},
    177804: {"Unified_Ideograph", "Ideographic"},
    177805: {"Unified_Ideograph", "Ideographic"},
    177806: {"Unified_Ideograph", "Ideographic"},
    177807: {"Unified_Ideograph", "Ideographic"},
    177808: {"Unified_Ideograph", "Ideographic"},
    177809: {"Unified_Ideograph", "Ideographic"},
    177810: {"Unified_Ideograph", "Ideographic"},
    177811: {"Unified_Ideograph", "Ideographic"},
    177812: {"Unified_Ideograph", "Ideographic"},
    177813: {"Unified_Ideograph", "Ideographic"},
    177814: {"Unified_Ideograph", "Ideographic"},
    177815: {"Unified_Ideograph", "Ideographic"},
    177816: {"Unified_Ideograph", "Ideographic"},
    177817: {"Unified_Ideograph", "Ideographic"},
    177818: {"Unified_Ideograph", "Ideographic"},
    177819: {"Unified_Ideograph", "Ideographic"},
    177820: {"Unified_Ideograph", "Ideographic"},
    177821: {"Unified_Ideograph", "Ideographic"},
    177822: {"Unified_Ideograph", "Ideographic"},
    177823: {"Unified_Ideograph", "Ideographic"},
    177824: {"Unified_Ideograph", "Ideographic"},
    177825: {"Unified_Ideograph", "Ideographic"},
    177826: {"Unified_Ideograph", "Ideographic"},
    177827: {"Unified_Ideograph", "Ideographic"},
    177828: {"Unified_Ideograph", "Ideographic"},
    177829: {"Unified_Ideograph", "Ideographic"},
    177830: {"Unified_Ideograph", "Ideographic"},
    177831: {"Unified_Ideograph", "Ideographic"},
    177832: {"Unified_Ideograph", "Ideographic"},
    177833: {"Unified_Ideograph", "Ideographic"},
    177834: {"Unified_Ideograph", "Ideographic"},
    177835: {"Unified_Ideograph", "Ideographic"},
    177836: {"Unified_Ideograph", "Ideographic"},
    177837: {"Unified_Ideograph", "Ideographic"},
    177838: {"Unified_Ideograph", "Ideographic"},
    177839: {"Unified_Ideograph", "Ideographic"},
    177840: {"Unified_Ideograph", "Ideographic"},
    177841: {"Unified_Ideograph", "Ideographic"},
    177842: {"Unified_Ideograph", "Ideographic"},
    177843: {"Unified_Ideograph", "Ideographic"},
    177844: {"Unified_Ideograph", "Ideographic"},
    177845: {"Unified_Ideograph", "Ideographic"},
    177846: {"Unified_Ideograph", "Ideographic"},
    177847: {"Unified_Ideograph", "Ideographic"},
    177848: {"Unified_Ideograph", "Ideographic"},
    177849: {"Unified_Ideograph", "Ideographic"},
    177850: {"Unified_Ideograph", "Ideographic"},
    177851: {"Unified_Ideograph", "Ideographic"},
    177852: {"Unified_Ideograph", "Ideographic"},
    177853: {"Unified_Ideograph", "Ideographic"},
    177854: {"Unified_Ideograph", "Ideographic"},
    177855: {"Unified_Ideograph", "Ideographic"},
    177856: {"Unified_Ideograph", "Ideographic"},
    177857: {"Unified_Ideograph", "Ideographic"},
    177858: {"Unified_Ideograph", "Ideographic"},
    177859: {"Unified_Ideograph", "Ideographic"},
    177860: {"Unified_Ideograph", "Ideographic"},
    177861: {"Unified_Ideograph", "Ideographic"},
    177862: {"Unified_Ideograph", "Ideographic"},
    177863: {"Unified_Ideograph", "Ideographic"},
    177864: {"Unified_Ideograph", "Ideographic"},
    177865: {"Unified_Ideograph", "Ideographic"},
    177866: {"Unified_Ideograph", "Ideographic"},
    177867: {"Unified_Ideograph", "Ideographic"},
    177868: {"Unified_Ideograph", "Ideographic"},
    177869: {"Unified_Ideograph", "Ideographic"},
    177870: {"Unified_Ideograph", "Ideographic"},
    177871: {"Unified_Ideograph", "Ideographic"},
    177872: {"Unified_Ideograph", "Ideographic"},
    177873: {"Unified_Ideograph", "Ideographic"},
    177874: {"Unified_Ideograph", "Ideographic"},
    177875: {"Unified_Ideograph", "Ideographic"},
    177876: {"Unified_Ideograph", "Ideographic"},
    177877: {"Unified_Ideograph", "Ideographic"},
    177878: {"Unified_Ideograph", "Ideographic"},
    177879: {"Unified_Ideograph", "Ideographic"},
    177880: {"Unified_Ideograph", "Ideographic"},
    177881: {"Unified_Ideograph", "Ideographic"},
    177882: {"Unified_Ideograph", "Ideographic"},
    177883: {"Unified_Ideograph", "Ideographic"},
    177884: {"Unified_Ideograph", "Ideographic"},
    177885: {"Unified_Ideograph", "Ideographic"},
    177886: {"Unified_Ideograph", "Ideographic"},
    177887: {"Unified_Ideograph", "Ideographic"},
    177888: {"Unified_Ideograph", "Ideographic"},
    177889: {"Unified_Ideograph", "Ideographic"},
    177890: {"Unified_Ideograph", "Ideographic"},
    177891: {"Unified_Ideograph", "Ideographic"},
    177892: {"Unified_Ideograph", "Ideographic"},
    177893: {"Unified_Ideograph", "Ideographic"},
    177894: {"Unified_Ideograph", "Ideographic"},
    177895: {"Unified_Ideograph", "Ideographic"},
    177896: {"Unified_Ideograph", "Ideographic"},
    177897: {"Unified_Ideograph", "Ideographic"},
    177898: {"Unified_Ideograph", "Ideographic"},
    177899: {"Unified_Ideograph", "Ideographic"},
    177900: {"Unified_Ideograph", "Ideographic"},
    177901: {"Unified_Ideograph", "Ideographic"},
    177902: {"Unified_Ideograph", "Ideographic"},
    177903: {"Unified_Ideograph", "Ideographic"},
    177904: {"Unified_Ideograph", "Ideographic"},
    177905: {"Unified_Ideograph", "Ideographic"},
    177906: {"Unified_Ideograph", "Ideographic"},
    177907: {"Unified_Ideograph", "Ideographic"},
    177908: {"Unified_Ideograph", "Ideographic"},
    177909: {"Unified_Ideograph", "Ideographic"},
    177910: {"Unified_Ideograph", "Ideographic"},
    177911: {"Unified_Ideograph", "Ideographic"},
    177912: {"Unified_Ideograph", "Ideographic"},
    177913: {"Unified_Ideograph", "Ideographic"},
    177914: {"Unified_Ideograph", "Ideographic"},
    177915: {"Unified_Ideograph", "Ideographic"},
    177916: {"Unified_Ideograph", "Ideographic"},
    177917: {"Unified_Ideograph", "Ideographic"},
    177918: {"Unified_Ideograph", "Ideographic"},
    177919: {"Unified_Ideograph", "Ideographic"},
    177920: {"Unified_Ideograph", "Ideographic"},
    177921: {"Unified_Ideograph", "Ideographic"},
    177922: {"Unified_Ideograph", "Ideographic"},
    177923: {"Unified_Ideograph", "Ideographic"},
    177924: {"Unified_Ideograph", "Ideographic"},
    177925: {"Unified_Ideograph", "Ideographic"},
    177926: {"Unified_Ideograph", "Ideographic"},
    177927: {"Unified_Ideograph", "Ideographic"},
    177928: {"Unified_Ideograph", "Ideographic"},
    177929: {"Unified_Ideograph", "Ideographic"},
    177930: {"Unified_Ideograph", "Ideographic"},
    177931: {"Unified_Ideograph", "Ideographic"},
    177932: {"Unified_Ideograph", "Ideographic"},
    177933: {"Unified_Ideograph", "Ideographic"},
    177934: {"Unified_Ideograph", "Ideographic"},
    177935: {"Unified_Ideograph", "Ideographic"},
    177936: {"Unified_Ideograph", "Ideographic"},
    177937: {"Unified_Ideograph", "Ideographic"},
    177938: {"Unified_Ideograph", "Ideographic"},
    177939: {"Unified_Ideograph", "Ideographic"},
    177940: {"Unified_Ideograph", "Ideographic"},
    177941: {"Unified_Ideograph", "Ideographic"},
    177942: {"Unified_Ideograph", "Ideographic"},
    177943: {"Unified_Ideograph", "Ideographic"},
    177944: {"Unified_Ideograph", "Ideographic"},
    177945: {"Unified_Ideograph", "Ideographic"},
    177946: {"Unified_Ideograph", "Ideographic"},
    177947: {"Unified_Ideograph", "Ideographic"},
    177948: {"Unified_Ideograph", "Ideographic"},
    177949: {"Unified_Ideograph", "Ideographic"},
    177950: {"Unified_Ideograph", "Ideographic"},
    177951: {"Unified_Ideograph", "Ideographic"},
    177952: {"Unified_Ideograph", "Ideographic"},
    177953: {"Unified_Ideograph", "Ideographic"},
    177954: {"Unified_Ideograph", "Ideographic"},
    177955: {"Unified_Ideograph", "Ideographic"},
    177956: {"Unified_Ideograph", "Ideographic"},
    177957: {"Unified_Ideograph", "Ideographic"},
    177958: {"Unified_Ideograph", "Ideographic"},
    177959: {"Unified_Ideograph", "Ideographic"},
    177960: {"Unified_Ideograph", "Ideographic"},
    177961: {"Unified_Ideograph", "Ideographic"},
    177962: {"Unified_Ideograph", "Ideographic"},
    177963: {"Unified_Ideograph", "Ideographic"},
    177964: {"Unified_Ideograph", "Ideographic"},
    177965: {"Unified_Ideograph", "Ideographic"},
    177966: {"Unified_Ideograph", "Ideographic"},
    177967: {"Unified_Ideograph", "Ideographic"},
    177968: {"Unified_Ideograph", "Ideographic"},
    177969: {"Unified_Ideograph", "Ideographic"},
    177970: {"Unified_Ideograph", "Ideographic"},
    177971: {"Unified_Ideograph", "Ideographic"},
    177972: {"Unified_Ideograph", "Ideographic"},
    177984: {"Unified_Ideograph", "Ideographic"},
    177985: {"Unified_Ideograph", "Ideographic"},
    177986: {"Unified_Ideograph", "Ideographic"},
    177987: {"Unified_Ideograph", "Ideographic"},
    177988: {"Unified_Ideograph", "Ideographic"},
    177989: {"Unified_Ideograph", "Ideographic"},
    177990: {"Unified_Ideograph", "Ideographic"},
    177991: {"Unified_Ideograph", "Ideographic"},
    177992: {"Unified_Ideograph", "Ideographic"},
    177993: {"Unified_Ideograph", "Ideographic"},
    177994: {"Unified_Ideograph", "Ideographic"},
    177995: {"Unified_Ideograph", "Ideographic"},
    177996: {"Unified_Ideograph", "Ideographic"},
    177997: {"Unified_Ideograph", "Ideographic"},
    177998: {"Unified_Ideograph", "Ideographic"},
    177999: {"Unified_Ideograph", "Ideographic"},
    178000: {"Unified_Ideograph", "Ideographic"},
    178001: {"Unified_Ideograph", "Ideographic"},
    178002: {"Unified_Ideograph", "Ideographic"},
    178003: {"Unified_Ideograph", "Ideographic"},
    178004: {"Unified_Ideograph", "Ideographic"},
    178005: {"Unified_Ideograph", "Ideographic"},
    178006: {"Unified_Ideograph", "Ideographic"},
    178007: {"Unified_Ideograph", "Ideographic"},
    178008: {"Unified_Ideograph", "Ideographic"},
    178009: {"Unified_Ideograph", "Ideographic"},
    178010: {"Unified_Ideograph", "Ideographic"},
    178011: {"Unified_Ideograph", "Ideographic"},
    178012: {"Unified_Ideograph", "Ideographic"},
    178013: {"Unified_Ideograph", "Ideographic"},
    178014: {"Unified_Ideograph", "Ideographic"},
    178015: {"Unified_Ideograph", "Ideographic"},
    178016: {"Unified_Ideograph", "Ideographic"},
    178017: {"Unified_Ideograph", "Ideographic"},
    178018: {"Unified_Ideograph", "Ideographic"},
    178019: {"Unified_Ideograph", "Ideographic"},
    178020: {"Unified_Ideograph", "Ideographic"},
    178021: {"Unified_Ideograph", "Ideographic"},
    178022: {"Unified_Ideograph", "Ideographic"},
    178023: {"Unified_Ideograph", "Ideographic"},
    178024: {"Unified_Ideograph", "Ideographic"},
    178025: {"Unified_Ideograph", "Ideographic"},
    178026: {"Unified_Ideograph", "Ideographic"},
    178027: {"Unified_Ideograph", "Ideographic"},
    178028: {"Unified_Ideograph", "Ideographic"},
    178029: {"Unified_Ideograph", "Ideographic"},
    178030: {"Unified_Ideograph", "Ideographic"},
    178031: {"Unified_Ideograph", "Ideographic"},
    178032: {"Unified_Ideograph", "Ideographic"},
    178033: {"Unified_Ideograph", "Ideographic"},
    178034: {"Unified_Ideograph", "Ideographic"},
    178035: {"Unified_Ideograph", "Ideographic"},
    178036: {"Unified_Ideograph", "Ideographic"},
    178037: {"Unified_Ideograph", "Ideographic"},
    178038: {"Unified_Ideograph", "Ideographic"},
    178039: {"Unified_Ideograph", "Ideographic"},
    178040: {"Unified_Ideograph", "Ideographic"},
    178041: {"Unified_Ideograph", "Ideographic"},
    178042: {"Unified_Ideograph", "Ideographic"},
    178043: {"Unified_Ideograph", "Ideographic"},
    178044: {"Unified_Ideograph", "Ideographic"},
    178045: {"Unified_Ideograph", "Ideographic"},
    178046: {"Unified_Ideograph", "Ideographic"},
    178047: {"Unified_Ideograph", "Ideographic"},
    178048: {"Unified_Ideograph", "Ideographic"},
    178049: {"Unified_Ideograph", "Ideographic"},
    178050: {"Unified_Ideograph", "Ideographic"},
    178051: {"Unified_Ideograph", "Ideographic"},
    178052: {"Unified_Ideograph", "Ideographic"},
    178053: {"Unified_Ideograph", "Ideographic"},
    178054: {"Unified_Ideograph", "Ideographic"},
    178055: {"Unified_Ideograph", "Ideographic"},
    178056: {"Unified_Ideograph", "Ideographic"},
    178057: {"Unified_Ideograph", "Ideographic"},
    178058: {"Unified_Ideograph", "Ideographic"},
    178059: {"Unified_Ideograph", "Ideographic"},
    178060: {"Unified_Ideograph", "Ideographic"},
    178061: {"Unified_Ideograph", "Ideographic"},
    178062: {"Unified_Ideograph", "Ideographic"},
    178063: {"Unified_Ideograph", "Ideographic"},
    178064: {"Unified_Ideograph", "Ideographic"},
    178065: {"Unified_Ideograph", "Ideographic"},
    178066: {"Unified_Ideograph", "Ideographic"},
    178067: {"Unified_Ideograph", "Ideographic"},
    178068: {"Unified_Ideograph", "Ideographic"},
    178069: {"Unified_Ideograph", "Ideographic"},
    178070: {"Unified_Ideograph", "Ideographic"},
    178071: {"Unified_Ideograph", "Ideographic"},
    178072: {"Unified_Ideograph", "Ideographic"},
    178073: {"Unified_Ideograph", "Ideographic"},
    178074: {"Unified_Ideograph", "Ideographic"},
    178075: {"Unified_Ideograph", "Ideographic"},
    178076: {"Unified_Ideograph", "Ideographic"},
    178077: {"Unified_Ideograph", "Ideographic"},
    178078: {"Unified_Ideograph", "Ideographic"},
    178079: {"Unified_Ideograph", "Ideographic"},
    178080: {"Unified_Ideograph", "Ideographic"},
    178081: {"Unified_Ideograph", "Ideographic"},
    178082: {"Unified_Ideograph", "Ideographic"},
    178083: {"Unified_Ideograph", "Ideographic"},
    178084: {"Unified_Ideograph", "Ideographic"},
    178085: {"Unified_Ideograph", "Ideographic"},
    178086: {"Unified_Ideograph", "Ideographic"},
    178087: {"Unified_Ideograph", "Ideographic"},
    178088: {"Unified_Ideograph", "Ideographic"},
    178089: {"Unified_Ideograph", "Ideographic"},
    178090: {"Unified_Ideograph", "Ideographic"},
    178091: {"Unified_Ideograph", "Ideographic"},
    178092: {"Unified_Ideograph", "Ideographic"},
    178093: {"Unified_Ideograph", "Ideographic"},
    178094: {"Unified_Ideograph", "Ideographic"},
    178095: {"Unified_Ideograph", "Ideographic"},
    178096: {"Unified_Ideograph", "Ideographic"},
    178097: {"Unified_Ideograph", "Ideographic"},
    178098: {"Unified_Ideograph", "Ideographic"},
    178099: {"Unified_Ideograph", "Ideographic"},
    178100: {"Unified_Ideograph", "Ideographic"},
    178101: {"Unified_Ideograph", "Ideographic"},
    178102: {"Unified_Ideograph", "Ideographic"},
    178103: {"Unified_Ideograph", "Ideographic"},
    178104: {"Unified_Ideograph", "Ideographic"},
    178105: {"Unified_Ideograph", "Ideographic"},
    178106: {"Unified_Ideograph", "Ideographic"},
    178107: {"Unified_Ideograph", "Ideographic"},
    178108: {"Unified_Ideograph", "Ideographic"},
    178109: {"Unified_Ideograph", "Ideographic"},
    178110: {"Unified_Ideograph", "Ideographic"},
    178111: {"Unified_Ideograph", "Ideographic"},
    178112: {"Unified_Ideograph", "Ideographic"},
    178113: {"Unified_Ideograph", "Ideographic"},
    178114: {"Unified_Ideograph", "Ideographic"},
    178115: {"Unified_Ideograph", "Ideographic"},
    178116: {"Unified_Ideograph", "Ideographic"},
    178117: {"Unified_Ideograph", "Ideographic"},
    178118: {"Unified_Ideograph", "Ideographic"},
    178119: {"Unified_Ideograph", "Ideographic"},
    178120: {"Unified_Ideograph", "Ideographic"},
    178121: {"Unified_Ideograph", "Ideographic"},
    178122: {"Unified_Ideograph", "Ideographic"},
    178123: {"Unified_Ideograph", "Ideographic"},
    178124: {"Unified_Ideograph", "Ideographic"},
    178125: {"Unified_Ideograph", "Ideographic"},
    178126: {"Unified_Ideograph", "Ideographic"},
    178127: {"Unified_Ideograph", "Ideographic"},
    178128: {"Unified_Ideograph", "Ideographic"},
    178129: {"Unified_Ideograph", "Ideographic"},
    178130: {"Unified_Ideograph", "Ideographic"},
    178131: {"Unified_Ideograph", "Ideographic"},
    178132: {"Unified_Ideograph", "Ideographic"},
    178133: {"Unified_Ideograph", "Ideographic"},
    178134: {"Unified_Ideograph", "Ideographic"},
    178135: {"Unified_Ideograph", "Ideographic"},
    178136: {"Unified_Ideograph", "Ideographic"},
    178137: {"Unified_Ideograph", "Ideographic"},
    178138: {"Unified_Ideograph", "Ideographic"},
    178139: {"Unified_Ideograph", "Ideographic"},
    178140: {"Unified_Ideograph", "Ideographic"},
    178141: {"Unified_Ideograph", "Ideographic"},
    178142: {"Unified_Ideograph", "Ideographic"},
    178143: {"Unified_Ideograph", "Ideographic"},
    178144: {"Unified_Ideograph", "Ideographic"},
    178145: {"Unified_Ideograph", "Ideographic"},
    178146: {"Unified_Ideograph", "Ideographic"},
    178147: {"Unified_Ideograph", "Ideographic"},
    178148: {"Unified_Ideograph", "Ideographic"},
    178149: {"Unified_Ideograph", "Ideographic"},
    178150: {"Unified_Ideograph", "Ideographic"},
    178151: {"Unified_Ideograph", "Ideographic"},
    178152: {"Unified_Ideograph", "Ideographic"},
    178153: {"Unified_Ideograph", "Ideographic"},
    178154: {"Unified_Ideograph", "Ideographic"},
    178155: {"Unified_Ideograph", "Ideographic"},
    178156: {"Unified_Ideograph", "Ideographic"},
    178157: {"Unified_Ideograph", "Ideographic"},
    178158: {"Unified_Ideograph", "Ideographic"},
    178159: {"Unified_Ideograph", "Ideographic"},
    178160: {"Unified_Ideograph", "Ideographic"},
    178161: {"Unified_Ideograph", "Ideographic"},
    178162: {"Unified_Ideograph", "Ideographic"},
    178163: {"Unified_Ideograph", "Ideographic"},
    178164: {"Unified_Ideograph", "Ideographic"},
    178165: {"Unified_Ideograph", "Ideographic"},
    178166: {"Unified_Ideograph", "Ideographic"},
    178167: {"Unified_Ideograph", "Ideographic"},
    178168: {"Unified_Ideograph", "Ideographic"},
    178169: {"Unified_Ideograph", "Ideographic"},
    178170: {"Unified_Ideograph", "Ideographic"},
    178171: {"Unified_Ideograph", "Ideographic"},
    178172: {"Unified_Ideograph", "Ideographic"},
    178173: {"Unified_Ideograph", "Ideographic"},
    178174: {"Unified_Ideograph", "Ideographic"},
    178175: {"Unified_Ideograph", "Ideographic"},
    178176: {"Unified_Ideograph", "Ideographic"},
    178177: {"Unified_Ideograph", "Ideographic"},
    178178: {"Unified_Ideograph", "Ideographic"},
    178179: {"Unified_Ideograph", "Ideographic"},
    178180: {"Unified_Ideograph", "Ideographic"},
    178181: {"Unified_Ideograph", "Ideographic"},
    178182: {"Unified_Ideograph", "Ideographic"},
    178183: {"Unified_Ideograph", "Ideographic"},
    178184: {"Unified_Ideograph", "Ideographic"},
    178185: {"Unified_Ideograph", "Ideographic"},
    178186: {"Unified_Ideograph", "Ideographic"},
    178187: {"Unified_Ideograph", "Ideographic"},
    178188: {"Unified_Ideograph", "Ideographic"},
    178189: {"Unified_Ideograph", "Ideographic"},
    178190: {"Unified_Ideograph", "Ideographic"},
    178191: {"Unified_Ideograph", "Ideographic"},
    178192: {"Unified_Ideograph", "Ideographic"},
    178193: {"Unified_Ideograph", "Ideographic"},
    178194: {"Unified_Ideograph", "Ideographic"},
    178195: {"Unified_Ideograph", "Ideographic"},
    178196: {"Unified_Ideograph", "Ideographic"},
    178197: {"Unified_Ideograph", "Ideographic"},
    178198: {"Unified_Ideograph", "Ideographic"},
    178199: {"Unified_Ideograph", "Ideographic"},
    178200: {"Unified_Ideograph", "Ideographic"},
    178201: {"Unified_Ideograph", "Ideographic"},
    178202: {"Unified_Ideograph", "Ideographic"},
    178203: {"Unified_Ideograph", "Ideographic"},
    178204: {"Unified_Ideograph", "Ideographic"},
    178205: {"Unified_Ideograph", "Ideographic"},
    178208: {"Unified_Ideograph", "Ideographic"},
    178209: {"Unified_Ideograph", "Ideographic"},
    178210: {"Unified_Ideograph", "Ideographic"},
    178211: {"Unified_Ideograph", "Ideographic"},
    178212: {"Unified_Ideograph", "Ideographic"},
    178213: {"Unified_Ideograph", "Ideographic"},
    178214: {"Unified_Ideograph", "Ideographic"},
    178215: {"Unified_Ideograph", "Ideographic"},
    178216: {"Unified_Ideograph", "Ideographic"},
    178217: {"Unified_Ideograph", "Ideographic"},
    178218: {"Unified_Ideograph", "Ideographic"},
    178219: {"Unified_Ideograph", "Ideographic"},
    178220: {"Unified_Ideograph", "Ideographic"},
    178221: {"Unified_Ideograph", "Ideographic"},
    178222: {"Unified_Ideograph", "Ideographic"},
    178223: {"Unified_Ideograph", "Ideographic"},
    178224: {"Unified_Ideograph", "Ideographic"},
    178225: {"Unified_Ideograph", "Ideographic"},
    178226: {"Unified_Ideograph", "Ideographic"},
    178227: {"Unified_Ideograph", "Ideographic"},
    178228: {"Unified_Ideograph", "Ideographic"},
    178229: {"Unified_Ideograph", "Ideographic"},
    178230: {"Unified_Ideograph", "Ideographic"},
    178231: {"Unified_Ideograph", "Ideographic"},
    178232: {"Unified_Ideograph", "Ideographic"},
    178233: {"Unified_Ideograph", "Ideographic"},
    178234: {"Unified_Ideograph", "Ideographic"},
    178235: {"Unified_Ideograph", "Ideographic"},
    178236: {"Unified_Ideograph", "Ideographic"},
    178237: {"Unified_Ideograph", "Ideographic"},
    178238: {"Unified_Ideograph", "Ideographic"},
    178239: {"Unified_Ideograph", "Ideographic"},
    178240: {"Unified_Ideograph", "Ideographic"},
    178241: {"Unified_Ideograph", "Ideographic"},
    178242: {"Unified_Ideograph", "Ideographic"},
    178243: {"Unified_Ideograph", "Ideographic"},
    178244: {"Unified_Ideograph", "Ideographic"},
    178245: {"Unified_Ideograph", "Ideographic"},
    178246: {"Unified_Ideograph", "Ideographic"},
    178247: {"Unified_Ideograph", "Ideographic"},
    178248: {"Unified_Ideograph", "Ideographic"},
    178249: {"Unified_Ideograph", "Ideographic"},
    178250: {"Unified_Ideograph", "Ideographic"},
    178251: {"Unified_Ideograph", "Ideographic"},
    178252: {"Unified_Ideograph", "Ideographic"},
    178253: {"Unified_Ideograph", "Ideographic"},
    178254: {"Unified_Ideograph", "Ideographic"},
    178255: {"Unified_Ideograph", "Ideographic"},
    178256: {"Unified_Ideograph", "Ideographic"},
    178257: {"Unified_Ideograph", "Ideographic"},
    178258: {"Unified_Ideograph", "Ideographic"},
    178259: {"Unified_Ideograph", "Ideographic"},
    178260: {"Unified_Ideograph", "Ideographic"},
    178261: {"Unified_Ideograph", "Ideographic"},
    178262: {"Unified_Ideograph", "Ideographic"},
    178263: {"Unified_Ideograph", "Ideographic"},
    178264: {"Unified_Ideograph", "Ideographic"},
    178265: {"Unified_Ideograph", "Ideographic"},
    178266: {"Unified_Ideograph", "Ideographic"},
    178267: {"Unified_Ideograph", "Ideographic"},
    178268: {"Unified_Ideograph", "Ideographic"},
    178269: {"Unified_Ideograph", "Ideographic"},
    178270: {"Unified_Ideograph", "Ideographic"},
    178271: {"Unified_Ideograph", "Ideographic"},
    178272: {"Unified_Ideograph", "Ideographic"},
    178273: {"Unified_Ideograph", "Ideographic"},
    178274: {"Unified_Ideograph", "Ideographic"},
    178275: {"Unified_Ideograph", "Ideographic"},
    178276: {"Unified_Ideograph", "Ideographic"},
    178277: {"Unified_Ideograph", "Ideographic"},
    178278: {"Unified_Ideograph", "Ideographic"},
    178279: {"Unified_Ideograph", "Ideographic"},
    178280: {"Unified_Ideograph", "Ideographic"},
    178281: {"Unified_Ideograph", "Ideographic"},
    178282: {"Unified_Ideograph", "Ideographic"},
    178283: {"Unified_Ideograph", "Ideographic"},
    178284: {"Unified_Ideograph", "Ideographic"},
    178285: {"Unified_Ideograph", "Ideographic"},
    178286: {"Unified_Ideograph", "Ideographic"},
    178287: {"Unified_Ideograph", "Ideographic"},
    178288: {"Unified_Ideograph", "Ideographic"},
    178289: {"Unified_Ideograph", "Ideographic"},
    178290: {"Unified_Ideograph", "Ideographic"},
    178291: {"Unified_Ideograph", "Ideographic"},
    178292: {"Unified_Ideograph", "Ideographic"},
    178293: {"Unified_Ideograph", "Ideographic"},
    178294: {"Unified_Ideograph", "Ideographic"},
    178295: {"Unified_Ideograph", "Ideographic"},
    178296: {"Unified_Ideograph", "Ideographic"},
    178297: {"Unified_Ideograph", "Ideographic"},
    178298: {"Unified_Ideograph", "Ideographic"},
    178299: {"Unified_Ideograph", "Ideographic"},
    178300: {"Unified_Ideograph", "Ideographic"},
    178301: {"Unified_Ideograph", "Ideographic"},
    178302: {"Unified_Ideograph", "Ideographic"},
    178303: {"Unified_Ideograph", "Ideographic"},
    178304: {"Unified_Ideograph", "Ideographic"},
    178305: {"Unified_Ideograph", "Ideographic"},
    178306: {"Unified_Ideograph", "Ideographic"},
    178307: {"Unified_Ideograph", "Ideographic"},
    178308: {"Unified_Ideograph", "Ideographic"},
    178309: {"Unified_Ideograph", "Ideographic"},
    178310: {"Unified_Ideograph", "Ideographic"},
    178311: {"Unified_Ideograph", "Ideographic"},
    178312: {"Unified_Ideograph", "Ideographic"},
    178313: {"Unified_Ideograph", "Ideographic"},
    178314: {"Unified_Ideograph", "Ideographic"},
    178315: {"Unified_Ideograph", "Ideographic"},
    178316: {"Unified_Ideograph", "Ideographic"},
    178317: {"Unified_Ideograph", "Ideographic"},
    178318: {"Unified_Ideograph", "Ideographic"},
    178319: {"Unified_Ideograph", "Ideographic"},
    178320: {"Unified_Ideograph", "Ideographic"},
    178321: {"Unified_Ideograph", "Ideographic"},
    178322: {"Unified_Ideograph", "Ideographic"},
    178323: {"Unified_Ideograph", "Ideographic"},
    178324: {"Unified_Ideograph", "Ideographic"},
    178325: {"Unified_Ideograph", "Ideographic"},
    178326: {"Unified_Ideograph", "Ideographic"},
    178327: {"Unified_Ideograph", "Ideographic"},
    178328: {"Unified_Ideograph", "Ideographic"},
    178329: {"Unified_Ideograph", "Ideographic"},
    178330: {"Unified_Ideograph", "Ideographic"},
    178331: {"Unified_Ideograph", "Ideographic"},
    178332: {"Unified_Ideograph", "Ideographic"},
    178333: {"Unified_Ideograph", "Ideographic"},
    178334: {"Unified_Ideograph", "Ideographic"},
    178335: {"Unified_Ideograph", "Ideographic"},
    178336: {"Unified_Ideograph", "Ideographic"},
    178337: {"Unified_Ideograph", "Ideographic"},
    178338: {"Unified_Ideograph", "Ideographic"},
    178339: {"Unified_Ideograph", "Ideographic"},
    178340: {"Unified_Ideograph", "Ideographic"},
    178341: {"Unified_Ideograph", "Ideographic"},
    178342: {"Unified_Ideograph", "Ideographic"},
    178343: {"Unified_Ideograph", "Ideographic"},
    178344: {"Unified_Ideograph", "Ideographic"},
    178345: {"Unified_Ideograph", "Ideographic"},
    178346: {"Unified_Ideograph", "Ideographic"},
    178347: {"Unified_Ideograph", "Ideographic"},
    178348: {"Unified_Ideograph", "Ideographic"},
    178349: {"Unified_Ideograph", "Ideographic"},
    178350: {"Unified_Ideograph", "Ideographic"},
    178351: {"Unified_Ideograph", "Ideographic"},
    178352: {"Unified_Ideograph", "Ideographic"},
    178353: {"Unified_Ideograph", "Ideographic"},
    178354: {"Unified_Ideograph", "Ideographic"},
    178355: {"Unified_Ideograph", "Ideographic"},
    178356: {"Unified_Ideograph", "Ideographic"},
    178357: {"Unified_Ideograph", "Ideographic"},
    178358: {"Unified_Ideograph", "Ideographic"},
    178359: {"Unified_Ideograph", "Ideographic"},
    178360: {"Unified_Ideograph", "Ideographic"},
    178361: {"Unified_Ideograph", "Ideographic"},
    178362: {"Unified_Ideograph", "Ideographic"},
    178363: {"Unified_Ideograph", "Ideographic"},
    178364: {"Unified_Ideograph", "Ideographic"},
    178365: {"Unified_Ideograph", "Ideographic"},
    178366: {"Unified_Ideograph", "Ideographic"},
    178367: {"Unified_Ideograph", "Ideographic"},
    178368: {"Unified_Ideograph", "Ideographic"},
    178369: {"Unified_Ideograph", "Ideographic"},
    178370: {"Unified_Ideograph", "Ideographic"},
    178371: {"Unified_Ideograph", "Ideographic"},
    178372: {"Unified_Ideograph", "Ideographic"},
    178373: {"Unified_Ideograph", "Ideographic"},
    178374: {"Unified_Ideograph", "Ideographic"},
    178375: {"Unified_Ideograph", "Ideographic"},
    178376: {"Unified_Ideograph", "Ideographic"},
    178377: {"Unified_Ideograph", "Ideographic"},
    178378: {"Unified_Ideograph", "Ideographic"},
    178379: {"Unified_Ideograph", "Ideographic"},
    178380: {"Unified_Ideograph", "Ideographic"},
    178381: {"Unified_Ideograph", "Ideographic"},
    178382: {"Unified_Ideograph", "Ideographic"},
    178383: {"Unified_Ideograph", "Ideographic"},
    178384: {"Unified_Ideograph", "Ideographic"},
    178385: {"Unified_Ideograph", "Ideographic"},
    178386: {"Unified_Ideograph", "Ideographic"},
    178387: {"Unified_Ideograph", "Ideographic"},
    178388: {"Unified_Ideograph", "Ideographic"},
    178389: {"Unified_Ideograph", "Ideographic"},
    178390: {"Unified_Ideograph", "Ideographic"},
    178391: {"Unified_Ideograph", "Ideographic"},
    178392: {"Unified_Ideograph", "Ideographic"},
    178393: {"Unified_Ideograph", "Ideographic"},
    178394: {"Unified_Ideograph", "Ideographic"},
    178395: {"Unified_Ideograph", "Ideographic"},
    178396: {"Unified_Ideograph", "Ideographic"},
    178397: {"Unified_Ideograph", "Ideographic"},
    178398: {"Unified_Ideograph", "Ideographic"},
    178399: {"Unified_Ideograph", "Ideographic"},
    178400: {"Unified_Ideograph", "Ideographic"},
    178401: {"Unified_Ideograph", "Ideographic"},
    178402: {"Unified_Ideograph", "Ideographic"},
    178403: {"Unified_Ideograph", "Ideographic"},
    178404: {"Unified_Ideograph", "Ideographic"},
    178405: {"Unified_Ideograph", "Ideographic"},
    178406: {"Unified_Ideograph", "Ideographic"},
    178407: {"Unified_Ideograph", "Ideographic"},
    178408: {"Unified_Ideograph", "Ideographic"},
    178409: {"Unified_Ideograph", "Ideographic"},
    178410: {"Unified_Ideograph", "Ideographic"},
    178411: {"Unified_Ideograph", "Ideographic"},
    178412: {"Unified_Ideograph", "Ideographic"},
    178413: {"Unified_Ideograph", "Ideographic"},
    178414: {"Unified_Ideograph", "Ideographic"},
    178415: {"Unified_Ideograph", "Ideographic"},
    178416: {"Unified_Ideograph", "Ideographic"},
    178417: {"Unified_Ideograph", "Ideographic"},
    178418: {"Unified_Ideograph", "Ideographic"},
    178419: {"Unified_Ideograph", "Ideographic"},
    178420: {"Unified_Ideograph", "Ideographic"},
    178421: {"Unified_Ideograph", "Ideographic"},
    178422: {"Unified_Ideograph", "Ideographic"},
    178423: {"Unified_Ideograph", "Ideographic"},
    178424: {"Unified_Ideograph", "Ideographic"},
    178425: {"Unified_Ideograph", "Ideographic"},
    178426: {"Unified_Ideograph", "Ideographic"},
    178427: {"Unified_Ideograph", "Ideographic"},
    178428: {"Unified_Ideograph", "Ideographic"},
    178429: {"Unified_Ideograph", "Ideographic"},
    178430: {"Unified_Ideograph", "Ideographic"},
    178431: {"Unified_Ideograph", "Ideographic"},
    178432: {"Unified_Ideograph", "Ideographic"},
    178433: {"Unified_Ideograph", "Ideographic"},
    178434: {"Unified_Ideograph", "Ideographic"},
    178435: {"Unified_Ideograph", "Ideographic"},
    178436: {"Unified_Ideograph", "Ideographic"},
    178437: {"Unified_Ideograph", "Ideographic"},
    178438: {"Unified_Ideograph", "Ideographic"},
    178439: {"Unified_Ideograph", "Ideographic"},
    178440: {"Unified_Ideograph", "Ideographic"},
    178441: {"Unified_Ideograph", "Ideographic"},
    178442: {"Unified_Ideograph", "Ideographic"},
    178443: {"Unified_Ideograph", "Ideographic"},
    178444: {"Unified_Ideograph", "Ideographic"},
    178445: {"Unified_Ideograph", "Ideographic"},
    178446: {"Unified_Ideograph", "Ideographic"},
    178447: {"Unified_Ideograph", "Ideographic"},
    178448: {"Unified_Ideograph", "Ideographic"},
    178449: {"Unified_Ideograph", "Ideographic"},
    178450: {"Unified_Ideograph", "Ideographic"},
    178451: {"Unified_Ideograph", "Ideographic"},
    178452: {"Unified_Ideograph", "Ideographic"},
    178453: {"Unified_Ideograph", "Ideographic"},
    178454: {"Unified_Ideograph", "Ideographic"},
    178455: {"Unified_Ideograph", "Ideographic"},
    178456: {"Unified_Ideograph", "Ideographic"},
    178457: {"Unified_Ideograph", "Ideographic"},
    178458: {"Unified_Ideograph", "Ideographic"},
    178459: {"Unified_Ideograph", "Ideographic"},
    178460: {"Unified_Ideograph", "Ideographic"},
    178461: {"Unified_Ideograph", "Ideographic"},
    178462: {"Unified_Ideograph", "Ideographic"},
    178463: {"Unified_Ideograph", "Ideographic"},
    178464: {"Unified_Ideograph", "Ideographic"},
    178465: {"Unified_Ideograph", "Ideographic"},
    178466: {"Unified_Ideograph", "Ideographic"},
    178467: {"Unified_Ideograph", "Ideographic"},
    178468: {"Unified_Ideograph", "Ideographic"},
    178469: {"Unified_Ideograph", "Ideographic"},
    178470: {"Unified_Ideograph", "Ideographic"},
    178471: {"Unified_Ideograph", "Ideographic"},
    178472: {"Unified_Ideograph", "Ideographic"},
    178473: {"Unified_Ideograph", "Ideographic"},
    178474: {"Unified_Ideograph", "Ideographic"},
    178475: {"Unified_Ideograph", "Ideographic"},
    178476: {"Unified_Ideograph", "Ideographic"},
    178477: {"Unified_Ideograph", "Ideographic"},
    178478: {"Unified_Ideograph", "Ideographic"},
    178479: {"Unified_Ideograph", "Ideographic"},
    178480: {"Unified_Ideograph", "Ideographic"},
    178481: {"Unified_Ideograph", "Ideographic"},
    178482: {"Unified_Ideograph", "Ideographic"},
    178483: {"Unified_Ideograph", "Ideographic"},
    178484: {"Unified_Ideograph", "Ideographic"},
    178485: {"Unified_Ideograph", "Ideographic"},
    178486: {"Unified_Ideograph", "Ideographic"},
    178487: {"Unified_Ideograph", "Ideographic"},
    178488: {"Unified_Ideograph", "Ideographic"},
    178489: {"Unified_Ideograph", "Ideographic"},
    178490: {"Unified_Ideograph", "Ideographic"},
    178491: {"Unified_Ideograph", "Ideographic"},
    178492: {"Unified_Ideograph", "Ideographic"},
    178493: {"Unified_Ideograph", "Ideographic"},
    178494: {"Unified_Ideograph", "Ideographic"},
    178495: {"Unified_Ideograph", "Ideographic"},
    178496: {"Unified_Ideograph", "Ideographic"},
    178497: {"Unified_Ideograph", "Ideographic"},
    178498: {"Unified_Ideograph", "Ideographic"},
    178499: {"Unified_Ideograph", "Ideographic"},
    178500: {"Unified_Ideograph", "Ideographic"},
    178501: {"Unified_Ideograph", "Ideographic"},
    178502: {"Unified_Ideograph", "Ideographic"},
    178503: {"Unified_Ideograph", "Ideographic"},
    178504: {"Unified_Ideograph", "Ideographic"},
    178505: {"Unified_Ideograph", "Ideographic"},
    178506: {"Unified_Ideograph", "Ideographic"},
    178507: {"Unified_Ideograph", "Ideographic"},
    178508: {"Unified_Ideograph", "Ideographic"},
    178509: {"Unified_Ideograph", "Ideographic"},
    178510: {"Unified_Ideograph", "Ideographic"},
    178511: {"Unified_Ideograph", "Ideographic"},
    178512: {"Unified_Ideograph", "Ideographic"},
    178513: {"Unified_Ideograph", "Ideographic"},
    178514: {"Unified_Ideograph", "Ideographic"},
    178515: {"Unified_Ideograph", "Ideographic"},
    178516: {"Unified_Ideograph", "Ideographic"},
    178517: {"Unified_Ideograph", "Ideographic"},
    178518: {"Unified_Ideograph", "Ideographic"},
    178519: {"Unified_Ideograph", "Ideographic"},
    178520: {"Unified_Ideograph", "Ideographic"},
    178521: {"Unified_Ideograph", "Ideographic"},
    178522: {"Unified_Ideograph", "Ideographic"},
    178523: {"Unified_Ideograph", "Ideographic"},
    178524: {"Unified_Ideograph", "Ideographic"},
    178525: {"Unified_Ideograph", "Ideographic"},
    178526: {"Unified_Ideograph", "Ideographic"},
    178527: {"Unified_Ideograph", "Ideographic"},
    178528: {"Unified_Ideograph", "Ideographic"},
    178529: {"Unified_Ideograph", "Ideographic"},
    178530: {"Unified_Ideograph", "Ideographic"},
    178531: {"Unified_Ideograph", "Ideographic"},
    178532: {"Unified_Ideograph", "Ideographic"},
    178533: {"Unified_Ideograph", "Ideographic"},
    178534: {"Unified_Ideograph", "Ideographic"},
    178535: {"Unified_Ideograph", "Ideographic"},
    178536: {"Unified_Ideograph", "Ideographic"},
    178537: {"Unified_Ideograph", "Ideographic"},
    178538: {"Unified_Ideograph", "Ideographic"},
    178539: {"Unified_Ideograph", "Ideographic"},
    178540: {"Unified_Ideograph", "Ideographic"},
    178541: {"Unified_Ideograph", "Ideographic"},
    178542: {"Unified_Ideograph", "Ideographic"},
    178543: {"Unified_Ideograph", "Ideographic"},
    178544: {"Unified_Ideograph", "Ideographic"},
    178545: {"Unified_Ideograph", "Ideographic"},
    178546: {"Unified_Ideograph", "Ideographic"},
    178547: {"Unified_Ideograph", "Ideographic"},
    178548: {"Unified_Ideograph", "Ideographic"},
    178549: {"Unified_Ideograph", "Ideographic"},
    178550: {"Unified_Ideograph", "Ideographic"},
    178551: {"Unified_Ideograph", "Ideographic"},
    178552: {"Unified_Ideograph", "Ideographic"},
    178553: {"Unified_Ideograph", "Ideographic"},
    178554: {"Unified_Ideograph", "Ideographic"},
    178555: {"Unified_Ideograph", "Ideographic"},
    178556: {"Unified_Ideograph", "Ideographic"},
    178557: {"Unified_Ideograph", "Ideographic"},
    178558: {"Unified_Ideograph", "Ideographic"},
    178559: {"Unified_Ideograph", "Ideographic"},
    178560: {"Unified_Ideograph", "Ideographic"},
    178561: {"Unified_Ideograph", "Ideographic"},
    178562: {"Unified_Ideograph", "Ideographic"},
    178563: {"Unified_Ideograph", "Ideographic"},
    178564: {"Unified_Ideograph", "Ideographic"},
    178565: {"Unified_Ideograph", "Ideographic"},
    178566: {"Unified_Ideograph", "Ideographic"},
    178567: {"Unified_Ideograph", "Ideographic"},
    178568: {"Unified_Ideograph", "Ideographic"},
    178569: {"Unified_Ideograph", "Ideographic"},
    178570: {"Unified_Ideograph", "Ideographic"},
    178571: {"Unified_Ideograph", "Ideographic"},
    178572: {"Unified_Ideograph", "Ideographic"},
    178573: {"Unified_Ideograph", "Ideographic"},
    178574: {"Unified_Ideograph", "Ideographic"},
    178575: {"Unified_Ideograph", "Ideographic"},
    178576: {"Unified_Ideograph", "Ideographic"},
    178577: {"Unified_Ideograph", "Ideographic"},
    178578: {"Unified_Ideograph", "Ideographic"},
    178579: {"Unified_Ideograph", "Ideographic"},
    178580: {"Unified_Ideograph", "Ideographic"},
    178581: {"Unified_Ideograph", "Ideographic"},
    178582: {"Unified_Ideograph", "Ideographic"},
    178583: {"Unified_Ideograph", "Ideographic"},
    178584: {"Unified_Ideograph", "Ideographic"},
    178585: {"Unified_Ideograph", "Ideographic"},
    178586: {"Unified_Ideograph", "Ideographic"},
    178587: {"Unified_Ideograph", "Ideographic"},
    178588: {"Unified_Ideograph", "Ideographic"},
    178589: {"Unified_Ideograph", "Ideographic"},
    178590: {"Unified_Ideograph", "Ideographic"},
    178591: {"Unified_Ideograph", "Ideographic"},
    178592: {"Unified_Ideograph", "Ideographic"},
    178593: {"Unified_Ideograph", "Ideographic"},
    178594: {"Unified_Ideograph", "Ideographic"},
    178595: {"Unified_Ideograph", "Ideographic"},
    178596: {"Unified_Ideograph", "Ideographic"},
    178597: {"Unified_Ideograph", "Ideographic"},
    178598: {"Unified_Ideograph", "Ideographic"},
    178599: {"Unified_Ideograph", "Ideographic"},
    178600: {"Unified_Ideograph", "Ideographic"},
    178601: {"Unified_Ideograph", "Ideographic"},
    178602: {"Unified_Ideograph", "Ideographic"},
    178603: {"Unified_Ideograph", "Ideographic"},
    178604: {"Unified_Ideograph", "Ideographic"},
    178605: {"Unified_Ideograph", "Ideographic"},
    178606: {"Unified_Ideograph", "Ideographic"},
    178607: {"Unified_Ideograph", "Ideographic"},
    178608: {"Unified_Ideograph", "Ideographic"},
    178609: {"Unified_Ideograph", "Ideographic"},
    178610: {"Unified_Ideograph", "Ideographic"},
    178611: {"Unified_Ideograph", "Ideographic"},
    178612: {"Unified_Ideograph", "Ideographic"},
    178613: {"Unified_Ideograph", "Ideographic"},
    178614: {"Unified_Ideograph", "Ideographic"},
    178615: {"Unified_Ideograph", "Ideographic"},
    178616: {"Unified_Ideograph", "Ideographic"},
    178617: {"Unified_Ideograph", "Ideographic"},
    178618: {"Unified_Ideograph", "Ideographic"},
    178619: {"Unified_Ideograph", "Ideographic"},
    178620: {"Unified_Ideograph", "Ideographic"},
    178621: {"Unified_Ideograph", "Ideographic"},
    178622: {"Unified_Ideograph", "Ideographic"},
    178623: {"Unified_Ideograph", "Ideographic"},
    178624: {"Unified_Ideograph", "Ideographic"},
    178625: {"Unified_Ideograph", "Ideographic"},
    178626: {"Unified_Ideograph", "Ideographic"},
    178627: {"Unified_Ideograph", "Ideographic"},
    178628: {"Unified_Ideograph", "Ideographic"},
    178629: {"Unified_Ideograph", "Ideographic"},
    178630: {"Unified_Ideograph", "Ideographic"},
    178631: {"Unified_Ideograph", "Ideographic"},
    178632: {"Unified_Ideograph", "Ideographic"},
    178633: {"Unified_Ideograph", "Ideographic"},
    178634: {"Unified_Ideograph", "Ideographic"},
    178635: {"Unified_Ideograph", "Ideographic"},
    178636: {"Unified_Ideograph", "Ideographic"},
    178637: {"Unified_Ideograph", "Ideographic"},
    178638: {"Unified_Ideograph", "Ideographic"},
    178639: {"Unified_Ideograph", "Ideographic"},
    178640: {"Unified_Ideograph", "Ideographic"},
    178641: {"Unified_Ideograph", "Ideographic"},
    178642: {"Unified_Ideograph", "Ideographic"},
    178643: {"Unified_Ideograph", "Ideographic"},
    178644: {"Unified_Ideograph", "Ideographic"},
    178645: {"Unified_Ideograph", "Ideographic"},
    178646: {"Unified_Ideograph", "Ideographic"},
    178647: {"Unified_Ideograph", "Ideographic"},
    178648: {"Unified_Ideograph", "Ideographic"},
    178649: {"Unified_Ideograph", "Ideographic"},
    178650: {"Unified_Ideograph", "Ideographic"},
    178651: {"Unified_Ideograph", "Ideographic"},
    178652: {"Unified_Ideograph", "Ideographic"},
    178653: {"Unified_Ideograph", "Ideographic"},
    178654: {"Unified_Ideograph", "Ideographic"},
    178655: {"Unified_Ideograph", "Ideographic"},
    178656: {"Unified_Ideograph", "Ideographic"},
    178657: {"Unified_Ideograph", "Ideographic"},
    178658: {"Unified_Ideograph", "Ideographic"},
    178659: {"Unified_Ideograph", "Ideographic"},
    178660: {"Unified_Ideograph", "Ideographic"},
    178661: {"Unified_Ideograph", "Ideographic"},
    178662: {"Unified_Ideograph", "Ideographic"},
    178663: {"Unified_Ideograph", "Ideographic"},
    178664: {"Unified_Ideograph", "Ideographic"},
    178665: {"Unified_Ideograph", "Ideographic"},
    178666: {"Unified_Ideograph", "Ideographic"},
    178667: {"Unified_Ideograph", "Ideographic"},
    178668: {"Unified_Ideograph", "Ideographic"},
    178669: {"Unified_Ideograph", "Ideographic"},
    178670: {"Unified_Ideograph", "Ideographic"},
    178671: {"Unified_Ideograph", "Ideographic"},
    178672: {"Unified_Ideograph", "Ideographic"},
    178673: {"Unified_Ideograph", "Ideographic"},
    178674: {"Unified_Ideograph", "Ideographic"},
    178675: {"Unified_Ideograph", "Ideographic"},
    178676: {"Unified_Ideograph", "Ideographic"},
    178677: {"Unified_Ideograph", "Ideographic"},
    178678: {"Unified_Ideograph", "Ideographic"},
    178679: {"Unified_Ideograph", "Ideographic"},
    178680: {"Unified_Ideograph", "Ideographic"},
    178681: {"Unified_Ideograph", "Ideographic"},
    178682: {"Unified_Ideograph", "Ideographic"},
    178683: {"Unified_Ideograph", "Ideographic"},
    178684: {"Unified_Ideograph", "Ideographic"},
    178685: {"Unified_Ideograph", "Ideographic"},
    178686: {"Unified_Ideograph", "Ideographic"},
    178687: {"Unified_Ideograph", "Ideographic"},
    178688: {"Unified_Ideograph", "Ideographic"},
    178689: {"Unified_Ideograph", "Ideographic"},
    178690: {"Unified_Ideograph", "Ideographic"},
    178691: {"Unified_Ideograph", "Ideographic"},
    178692: {"Unified_Ideograph", "Ideographic"},
    178693: {"Unified_Ideograph", "Ideographic"},
    178694: {"Unified_Ideograph", "Ideographic"},
    178695: {"Unified_Ideograph", "Ideographic"},
    178696: {"Unified_Ideograph", "Ideographic"},
    178697: {"Unified_Ideograph", "Ideographic"},
    178698: {"Unified_Ideograph", "Ideographic"},
    178699: {"Unified_Ideograph", "Ideographic"},
    178700: {"Unified_Ideograph", "Ideographic"},
    178701: {"Unified_Ideograph", "Ideographic"},
    178702: {"Unified_Ideograph", "Ideographic"},
    178703: {"Unified_Ideograph", "Ideographic"},
    178704: {"Unified_Ideograph", "Ideographic"},
    178705: {"Unified_Ideograph", "Ideographic"},
    178706: {"Unified_Ideograph", "Ideographic"},
    178707: {"Unified_Ideograph", "Ideographic"},
    178708: {"Unified_Ideograph", "Ideographic"},
    178709: {"Unified_Ideograph", "Ideographic"},
    178710: {"Unified_Ideograph", "Ideographic"},
    178711: {"Unified_Ideograph", "Ideographic"},
    178712: {"Unified_Ideograph", "Ideographic"},
    178713: {"Unified_Ideograph", "Ideographic"},
    178714: {"Unified_Ideograph", "Ideographic"},
    178715: {"Unified_Ideograph", "Ideographic"},
    178716: {"Unified_Ideograph", "Ideographic"},
    178717: {"Unified_Ideograph", "Ideographic"},
    178718: {"Unified_Ideograph", "Ideographic"},
    178719: {"Unified_Ideograph", "Ideographic"},
    178720: {"Unified_Ideograph", "Ideographic"},
    178721: {"Unified_Ideograph", "Ideographic"},
    178722: {"Unified_Ideograph", "Ideographic"},
    178723: {"Unified_Ideograph", "Ideographic"},
    178724: {"Unified_Ideograph", "Ideographic"},
    178725: {"Unified_Ideograph", "Ideographic"},
    178726: {"Unified_Ideograph", "Ideographic"},
    178727: {"Unified_Ideograph", "Ideographic"},
    178728: {"Unified_Ideograph", "Ideographic"},
    178729: {"Unified_Ideograph", "Ideographic"},
    178730: {"Unified_Ideograph", "Ideographic"},
    178731: {"Unified_Ideograph", "Ideographic"},
    178732: {"Unified_Ideograph", "Ideographic"},
    178733: {"Unified_Ideograph", "Ideographic"},
    178734: {"Unified_Ideograph", "Ideographic"},
    178735: {"Unified_Ideograph", "Ideographic"},
    178736: {"Unified_Ideograph", "Ideographic"},
    178737: {"Unified_Ideograph", "Ideographic"},
    178738: {"Unified_Ideograph", "Ideographic"},
    178739: {"Unified_Ideograph", "Ideographic"},
    178740: {"Unified_Ideograph", "Ideographic"},
    178741: {"Unified_Ideograph", "Ideographic"},
    178742: {"Unified_Ideograph", "Ideographic"},
    178743: {"Unified_Ideograph", "Ideographic"},
    178744: {"Unified_Ideograph", "Ideographic"},
    178745: {"Unified_Ideograph", "Ideographic"},
    178746: {"Unified_Ideograph", "Ideographic"},
    178747: {"Unified_Ideograph", "Ideographic"},
    178748: {"Unified_Ideograph", "Ideographic"},
    178749: {"Unified_Ideograph", "Ideographic"},
    178750: {"Unified_Ideograph", "Ideographic"},
    178751: {"Unified_Ideograph", "Ideographic"},
    178752: {"Unified_Ideograph", "Ideographic"},
    178753: {"Unified_Ideograph", "Ideographic"},
    178754: {"Unified_Ideograph", "Ideographic"},
    178755: {"Unified_Ideograph", "Ideographic"},
    178756: {"Unified_Ideograph", "Ideographic"},
    178757: {"Unified_Ideograph", "Ideographic"},
    178758: {"Unified_Ideograph", "Ideographic"},
    178759: {"Unified_Ideograph", "Ideographic"},
    178760: {"Unified_Ideograph", "Ideographic"},
    178761: {"Unified_Ideograph", "Ideographic"},
    178762: {"Unified_Ideograph", "Ideographic"},
    178763: {"Unified_Ideograph", "Ideographic"},
    178764: {"Unified_Ideograph", "Ideographic"},
    178765: {"Unified_Ideograph", "Ideographic"},
    178766: {"Unified_Ideograph", "Ideographic"},
    178767: {"Unified_Ideograph", "Ideographic"},
    178768: {"Unified_Ideograph", "Ideographic"},
    178769: {"Unified_Ideograph", "Ideographic"},
    178770: {"Unified_Ideograph", "Ideographic"},
    178771: {"Unified_Ideograph", "Ideographic"},
    178772: {"Unified_Ideograph", "Ideographic"},
    178773: {"Unified_Ideograph", "Ideographic"},
    178774: {"Unified_Ideograph", "Ideographic"},
    178775: {"Unified_Ideograph", "Ideographic"},
    178776: {"Unified_Ideograph", "Ideographic"},
    178777: {"Unified_Ideograph", "Ideographic"},
    178778: {"Unified_Ideograph", "Ideographic"},
    178779: {"Unified_Ideograph", "Ideographic"},
    178780: {"Unified_Ideograph", "Ideographic"},
    178781: {"Unified_Ideograph", "Ideographic"},
    178782: {"Unified_Ideograph", "Ideographic"},
    178783: {"Unified_Ideograph", "Ideographic"},
    178784: {"Unified_Ideograph", "Ideographic"},
    178785: {"Unified_Ideograph", "Ideographic"},
    178786: {"Unified_Ideograph", "Ideographic"},
    178787: {"Unified_Ideograph", "Ideographic"},
    178788: {"Unified_Ideograph", "Ideographic"},
    178789: {"Unified_Ideograph", "Ideographic"},
    178790: {"Unified_Ideograph", "Ideographic"},
    178791: {"Unified_Ideograph", "Ideographic"},
    178792: {"Unified_Ideograph", "Ideographic"},
    178793: {"Unified_Ideograph", "Ideographic"},
    178794: {"Unified_Ideograph", "Ideographic"},
    178795: {"Unified_Ideograph", "Ideographic"},
    178796: {"Unified_Ideograph", "Ideographic"},
    178797: {"Unified_Ideograph", "Ideographic"},
    178798: {"Unified_Ideograph", "Ideographic"},
    178799: {"Unified_Ideograph", "Ideographic"},
    178800: {"Unified_Ideograph", "Ideographic"},
    178801: {"Unified_Ideograph", "Ideographic"},
    178802: {"Unified_Ideograph", "Ideographic"},
    178803: {"Unified_Ideograph", "Ideographic"},
    178804: {"Unified_Ideograph", "Ideographic"},
    178805: {"Unified_Ideograph", "Ideographic"},
    178806: {"Unified_Ideograph", "Ideographic"},
    178807: {"Unified_Ideograph", "Ideographic"},
    178808: {"Unified_Ideograph", "Ideographic"},
    178809: {"Unified_Ideograph", "Ideographic"},
    178810: {"Unified_Ideograph", "Ideographic"},
    178811: {"Unified_Ideograph", "Ideographic"},
    178812: {"Unified_Ideograph", "Ideographic"},
    178813: {"Unified_Ideograph", "Ideographic"},
    178814: {"Unified_Ideograph", "Ideographic"},
    178815: {"Unified_Ideograph", "Ideographic"},
    178816: {"Unified_Ideograph", "Ideographic"},
    178817: {"Unified_Ideograph", "Ideographic"},
    178818: {"Unified_Ideograph", "Ideographic"},
    178819: {"Unified_Ideograph", "Ideographic"},
    178820: {"Unified_Ideograph", "Ideographic"},
    178821: {"Unified_Ideograph", "Ideographic"},
    178822: {"Unified_Ideograph", "Ideographic"},
    178823: {"Unified_Ideograph", "Ideographic"},
    178824: {"Unified_Ideograph", "Ideographic"},
    178825: {"Unified_Ideograph", "Ideographic"},
    178826: {"Unified_Ideograph", "Ideographic"},
    178827: {"Unified_Ideograph", "Ideographic"},
    178828: {"Unified_Ideograph", "Ideographic"},
    178829: {"Unified_Ideograph", "Ideographic"},
    178830: {"Unified_Ideograph", "Ideographic"},
    178831: {"Unified_Ideograph", "Ideographic"},
    178832: {"Unified_Ideograph", "Ideographic"},
    178833: {"Unified_Ideograph", "Ideographic"},
    178834: {"Unified_Ideograph", "Ideographic"},
    178835: {"Unified_Ideograph", "Ideographic"},
    178836: {"Unified_Ideograph", "Ideographic"},
    178837: {"Unified_Ideograph", "Ideographic"},
    178838: {"Unified_Ideograph", "Ideographic"},
    178839: {"Unified_Ideograph", "Ideographic"},
    178840: {"Unified_Ideograph", "Ideographic"},
    178841: {"Unified_Ideograph", "Ideographic"},
    178842: {"Unified_Ideograph", "Ideographic"},
    178843: {"Unified_Ideograph", "Ideographic"},
    178844: {"Unified_Ideograph", "Ideographic"},
    178845: {"Unified_Ideograph", "Ideographic"},
    178846: {"Unified_Ideograph", "Ideographic"},
    178847: {"Unified_Ideograph", "Ideographic"},
    178848: {"Unified_Ideograph", "Ideographic"},
    178849: {"Unified_Ideograph", "Ideographic"},
    178850: {"Unified_Ideograph", "Ideographic"},
    178851: {"Unified_Ideograph", "Ideographic"},
    178852: {"Unified_Ideograph", "Ideographic"},
    178853: {"Unified_Ideograph", "Ideographic"},
    178854: {"Unified_Ideograph", "Ideographic"},
    178855: {"Unified_Ideograph", "Ideographic"},
    178856: {"Unified_Ideograph", "Ideographic"},
    178857: {"Unified_Ideograph", "Ideographic"},
    178858: {"Unified_Ideograph", "Ideographic"},
    178859: {"Unified_Ideograph", "Ideographic"},
    178860: {"Unified_Ideograph", "Ideographic"},
    178861: {"Unified_Ideograph", "Ideographic"},
    178862: {"Unified_Ideograph", "Ideographic"},
    178863: {"Unified_Ideograph", "Ideographic"},
    178864: {"Unified_Ideograph", "Ideographic"},
    178865: {"Unified_Ideograph", "Ideographic"},
    178866: {"Unified_Ideograph", "Ideographic"},
    178867: {"Unified_Ideograph", "Ideographic"},
    178868: {"Unified_Ideograph", "Ideographic"},
    178869: {"Unified_Ideograph", "Ideographic"},
    178870: {"Unified_Ideograph", "Ideographic"},
    178871: {"Unified_Ideograph", "Ideographic"},
    178872: {"Unified_Ideograph", "Ideographic"},
    178873: {"Unified_Ideograph", "Ideographic"},
    178874: {"Unified_Ideograph", "Ideographic"},
    178875: {"Unified_Ideograph", "Ideographic"},
    178876: {"Unified_Ideograph", "Ideographic"},
    178877: {"Unified_Ideograph", "Ideographic"},
    178878: {"Unified_Ideograph", "Ideographic"},
    178879: {"Unified_Ideograph", "Ideographic"},
    178880: {"Unified_Ideograph", "Ideographic"},
    178881: {"Unified_Ideograph", "Ideographic"},
    178882: {"Unified_Ideograph", "Ideographic"},
    178883: {"Unified_Ideograph", "Ideographic"},
    178884: {"Unified_Ideograph", "Ideographic"},
    178885: {"Unified_Ideograph", "Ideographic"},
    178886: {"Unified_Ideograph", "Ideographic"},
    178887: {"Unified_Ideograph", "Ideographic"},
    178888: {"Unified_Ideograph", "Ideographic"},
    178889: {"Unified_Ideograph", "Ideographic"},
    178890: {"Unified_Ideograph", "Ideographic"},
    178891: {"Unified_Ideograph", "Ideographic"},
    178892: {"Unified_Ideograph", "Ideographic"},
    178893: {"Unified_Ideograph", "Ideographic"},
    178894: {"Unified_Ideograph", "Ideographic"},
    178895: {"Unified_Ideograph", "Ideographic"},
    178896: {"Unified_Ideograph", "Ideographic"},
    178897: {"Unified_Ideograph", "Ideographic"},
    178898: {"Unified_Ideograph", "Ideographic"},
    178899: {"Unified_Ideograph", "Ideographic"},
    178900: {"Unified_Ideograph", "Ideographic"},
    178901: {"Unified_Ideograph", "Ideographic"},
    178902: {"Unified_Ideograph", "Ideographic"},
    178903: {"Unified_Ideograph", "Ideographic"},
    178904: {"Unified_Ideograph", "Ideographic"},
    178905: {"Unified_Ideograph", "Ideographic"},
    178906: {"Unified_Ideograph", "Ideographic"},
    178907: {"Unified_Ideograph", "Ideographic"},
    178908: {"Unified_Ideograph", "Ideographic"},
    178909: {"Unified_Ideograph", "Ideographic"},
    178910: {"Unified_Ideograph", "Ideographic"},
    178911: {"Unified_Ideograph", "Ideographic"},
    178912: {"Unified_Ideograph", "Ideographic"},
    178913: {"Unified_Ideograph", "Ideographic"},
    178914: {"Unified_Ideograph", "Ideographic"},
    178915: {"Unified_Ideograph", "Ideographic"},
    178916: {"Unified_Ideograph", "Ideographic"},
    178917: {"Unified_Ideograph", "Ideographic"},
    178918: {"Unified_Ideograph", "Ideographic"},
    178919: {"Unified_Ideograph", "Ideographic"},
    178920: {"Unified_Ideograph", "Ideographic"},
    178921: {"Unified_Ideograph", "Ideographic"},
    178922: {"Unified_Ideograph", "Ideographic"},
    178923: {"Unified_Ideograph", "Ideographic"},
    178924: {"Unified_Ideograph", "Ideographic"},
    178925: {"Unified_Ideograph", "Ideographic"},
    178926: {"Unified_Ideograph", "Ideographic"},
    178927: {"Unified_Ideograph", "Ideographic"},
    178928: {"Unified_Ideograph", "Ideographic"},
    178929: {"Unified_Ideograph", "Ideographic"},
    178930: {"Unified_Ideograph", "Ideographic"},
    178931: {"Unified_Ideograph", "Ideographic"},
    178932: {"Unified_Ideograph", "Ideographic"},
    178933: {"Unified_Ideograph", "Ideographic"},
    178934: {"Unified_Ideograph", "Ideographic"},
    178935: {"Unified_Ideograph", "Ideographic"},
    178936: {"Unified_Ideograph", "Ideographic"},
    178937: {"Unified_Ideograph", "Ideographic"},
    178938: {"Unified_Ideograph", "Ideographic"},
    178939: {"Unified_Ideograph", "Ideographic"},
    178940: {"Unified_Ideograph", "Ideographic"},
    178941: {"Unified_Ideograph", "Ideographic"},
    178942: {"Unified_Ideograph", "Ideographic"},
    178943: {"Unified_Ideograph", "Ideographic"},
    178944: {"Unified_Ideograph", "Ideographic"},
    178945: {"Unified_Ideograph", "Ideographic"},
    178946: {"Unified_Ideograph", "Ideographic"},
    178947: {"Unified_Ideograph", "Ideographic"},
    178948: {"Unified_Ideograph", "Ideographic"},
    178949: {"Unified_Ideograph", "Ideographic"},
    178950: {"Unified_Ideograph", "Ideographic"},
    178951: {"Unified_Ideograph", "Ideographic"},
    178952: {"Unified_Ideograph", "Ideographic"},
    178953: {"Unified_Ideograph", "Ideographic"},
    178954: {"Unified_Ideograph", "Ideographic"},
    178955: {"Unified_Ideograph", "Ideographic"},
    178956: {"Unified_Ideograph", "Ideographic"},
    178957: {"Unified_Ideograph", "Ideographic"},
    178958: {"Unified_Ideograph", "Ideographic"},
    178959: {"Unified_Ideograph", "Ideographic"},
    178960: {"Unified_Ideograph", "Ideographic"},
    178961: {"Unified_Ideograph", "Ideographic"},
    178962: {"Unified_Ideograph", "Ideographic"},
    178963: {"Unified_Ideograph", "Ideographic"},
    178964: {"Unified_Ideograph", "Ideographic"},
    178965: {"Unified_Ideograph", "Ideographic"},
    178966: {"Unified_Ideograph", "Ideographic"},
    178967: {"Unified_Ideograph", "Ideographic"},
    178968: {"Unified_Ideograph", "Ideographic"},
    178969: {"Unified_Ideograph", "Ideographic"},
    178970: {"Unified_Ideograph", "Ideographic"},
    178971: {"Unified_Ideograph", "Ideographic"},
    178972: {"Unified_Ideograph", "Ideographic"},
    178973: {"Unified_Ideograph", "Ideographic"},
    178974: {"Unified_Ideograph", "Ideographic"},
    178975: {"Unified_Ideograph", "Ideographic"},
    178976: {"Unified_Ideograph", "Ideographic"},
    178977: {"Unified_Ideograph", "Ideographic"},
    178978: {"Unified_Ideograph", "Ideographic"},
    178979: {"Unified_Ideograph", "Ideographic"},
    178980: {"Unified_Ideograph", "Ideographic"},
    178981: {"Unified_Ideograph", "Ideographic"},
    178982: {"Unified_Ideograph", "Ideographic"},
    178983: {"Unified_Ideograph", "Ideographic"},
    178984: {"Unified_Ideograph", "Ideographic"},
    178985: {"Unified_Ideograph", "Ideographic"},
    178986: {"Unified_Ideograph", "Ideographic"},
    178987: {"Unified_Ideograph", "Ideographic"},
    178988: {"Unified_Ideograph", "Ideographic"},
    178989: {"Unified_Ideograph", "Ideographic"},
    178990: {"Unified_Ideograph", "Ideographic"},
    178991: {"Unified_Ideograph", "Ideographic"},
    178992: {"Unified_Ideograph", "Ideographic"},
    178993: {"Unified_Ideograph", "Ideographic"},
    178994: {"Unified_Ideograph", "Ideographic"},
    178995: {"Unified_Ideograph", "Ideographic"},
    178996: {"Unified_Ideograph", "Ideographic"},
    178997: {"Unified_Ideograph", "Ideographic"},
    178998: {"Unified_Ideograph", "Ideographic"},
    178999: {"Unified_Ideograph", "Ideographic"},
    179000: {"Unified_Ideograph", "Ideographic"},
    179001: {"Unified_Ideograph", "Ideographic"},
    179002: {"Unified_Ideograph", "Ideographic"},
    179003: {"Unified_Ideograph", "Ideographic"},
    179004: {"Unified_Ideograph", "Ideographic"},
    179005: {"Unified_Ideograph", "Ideographic"},
    179006: {"Unified_Ideograph", "Ideographic"},
    179007: {"Unified_Ideograph", "Ideographic"},
    179008: {"Unified_Ideograph", "Ideographic"},
    179009: {"Unified_Ideograph", "Ideographic"},
    179010: {"Unified_Ideograph", "Ideographic"},
    179011: {"Unified_Ideograph", "Ideographic"},
    179012: {"Unified_Ideograph", "Ideographic"},
    179013: {"Unified_Ideograph", "Ideographic"},
    179014: {"Unified_Ideograph", "Ideographic"},
    179015: {"Unified_Ideograph", "Ideographic"},
    179016: {"Unified_Ideograph", "Ideographic"},
    179017: {"Unified_Ideograph", "Ideographic"},
    179018: {"Unified_Ideograph", "Ideographic"},
    179019: {"Unified_Ideograph", "Ideographic"},
    179020: {"Unified_Ideograph", "Ideographic"},
    179021: {"Unified_Ideograph", "Ideographic"},
    179022: {"Unified_Ideograph", "Ideographic"},
    179023: {"Unified_Ideograph", "Ideographic"},
    179024: {"Unified_Ideograph", "Ideographic"},
    179025: {"Unified_Ideograph", "Ideographic"},
    179026: {"Unified_Ideograph", "Ideographic"},
    179027: {"Unified_Ideograph", "Ideographic"},
    179028: {"Unified_Ideograph", "Ideographic"},
    179029: {"Unified_Ideograph", "Ideographic"},
    179030: {"Unified_Ideograph", "Ideographic"},
    179031: {"Unified_Ideograph", "Ideographic"},
    179032: {"Unified_Ideograph", "Ideographic"},
    179033: {"Unified_Ideograph", "Ideographic"},
    179034: {"Unified_Ideograph", "Ideographic"},
    179035: {"Unified_Ideograph", "Ideographic"},
    179036: {"Unified_Ideograph", "Ideographic"},
    179037: {"Unified_Ideograph", "Ideographic"},
    179038: {"Unified_Ideograph", "Ideographic"},
    179039: {"Unified_Ideograph", "Ideographic"},
    179040: {"Unified_Ideograph", "Ideographic"},
    179041: {"Unified_Ideograph", "Ideographic"},
    179042: {"Unified_Ideograph", "Ideographic"},
    179043: {"Unified_Ideograph", "Ideographic"},
    179044: {"Unified_Ideograph", "Ideographic"},
    179045: {"Unified_Ideograph", "Ideographic"},
    179046: {"Unified_Ideograph", "Ideographic"},
    179047: {"Unified_Ideograph", "Ideographic"},
    179048: {"Unified_Ideograph", "Ideographic"},
    179049: {"Unified_Ideograph", "Ideographic"},
    179050: {"Unified_Ideograph", "Ideographic"},
    179051: {"Unified_Ideograph", "Ideographic"},
    179052: {"Unified_Ideograph", "Ideographic"},
    179053: {"Unified_Ideograph", "Ideographic"},
    179054: {"Unified_Ideograph", "Ideographic"},
    179055: {"Unified_Ideograph", "Ideographic"},
    179056: {"Unified_Ideograph", "Ideographic"},
    179057: {"Unified_Ideograph", "Ideographic"},
    179058: {"Unified_Ideograph", "Ideographic"},
    179059: {"Unified_Ideograph", "Ideographic"},
    179060: {"Unified_Ideograph", "Ideographic"},
    179061: {"Unified_Ideograph", "Ideographic"},
    179062: {"Unified_Ideograph", "Ideographic"},
    179063: {"Unified_Ideograph", "Ideographic"},
    179064: {"Unified_Ideograph", "Ideographic"},
    179065: {"Unified_Ideograph", "Ideographic"},
    179066: {"Unified_Ideograph", "Ideographic"},
    179067: {"Unified_Ideograph", "Ideographic"},
    179068: {"Unified_Ideograph", "Ideographic"},
    179069: {"Unified_Ideograph", "Ideographic"},
    179070: {"Unified_Ideograph", "Ideographic"},
    179071: {"Unified_Ideograph", "Ideographic"},
    179072: {"Unified_Ideograph", "Ideographic"},
    179073: {"Unified_Ideograph", "Ideographic"},
    179074: {"Unified_Ideograph", "Ideographic"},
    179075: {"Unified_Ideograph", "Ideographic"},
    179076: {"Unified_Ideograph", "Ideographic"},
    179077: {"Unified_Ideograph", "Ideographic"},
    179078: {"Unified_Ideograph", "Ideographic"},
    179079: {"Unified_Ideograph", "Ideographic"},
    179080: {"Unified_Ideograph", "Ideographic"},
    179081: {"Unified_Ideograph", "Ideographic"},
    179082: {"Unified_Ideograph", "Ideographic"},
    179083: {"Unified_Ideograph", "Ideographic"},
    179084: {"Unified_Ideograph", "Ideographic"},
    179085: {"Unified_Ideograph", "Ideographic"},
    179086: {"Unified_Ideograph", "Ideographic"},
    179087: {"Unified_Ideograph", "Ideographic"},
    179088: {"Unified_Ideograph", "Ideographic"},
    179089: {"Unified_Ideograph", "Ideographic"},
    179090: {"Unified_Ideograph", "Ideographic"},
    179091: {"Unified_Ideograph", "Ideographic"},
    179092: {"Unified_Ideograph", "Ideographic"},
    179093: {"Unified_Ideograph", "Ideographic"},
    179094: {"Unified_Ideograph", "Ideographic"},
    179095: {"Unified_Ideograph", "Ideographic"},
    179096: {"Unified_Ideograph", "Ideographic"},
    179097: {"Unified_Ideograph", "Ideographic"},
    179098: {"Unified_Ideograph", "Ideographic"},
    179099: {"Unified_Ideograph", "Ideographic"},
    179100: {"Unified_Ideograph", "Ideographic"},
    179101: {"Unified_Ideograph", "Ideographic"},
    179102: {"Unified_Ideograph", "Ideographic"},
    179103: {"Unified_Ideograph", "Ideographic"},
    179104: {"Unified_Ideograph", "Ideographic"},
    179105: {"Unified_Ideograph", "Ideographic"},
    179106: {"Unified_Ideograph", "Ideographic"},
    179107: {"Unified_Ideograph", "Ideographic"},
    179108: {"Unified_Ideograph", "Ideographic"},
    179109: {"Unified_Ideograph", "Ideographic"},
    179110: {"Unified_Ideograph", "Ideographic"},
    179111: {"Unified_Ideograph", "Ideographic"},
    179112: {"Unified_Ideograph", "Ideographic"},
    179113: {"Unified_Ideograph", "Ideographic"},
    179114: {"Unified_Ideograph", "Ideographic"},
    179115: {"Unified_Ideograph", "Ideographic"},
    179116: {"Unified_Ideograph", "Ideographic"},
    179117: {"Unified_Ideograph", "Ideographic"},
    179118: {"Unified_Ideograph", "Ideographic"},
    179119: {"Unified_Ideograph", "Ideographic"},
    179120: {"Unified_Ideograph", "Ideographic"},
    179121: {"Unified_Ideograph", "Ideographic"},
    179122: {"Unified_Ideograph", "Ideographic"},
    179123: {"Unified_Ideograph", "Ideographic"},
    179124: {"Unified_Ideograph", "Ideographic"},
    179125: {"Unified_Ideograph", "Ideographic"},
    179126: {"Unified_Ideograph", "Ideographic"},
    179127: {"Unified_Ideograph", "Ideographic"},
    179128: {"Unified_Ideograph", "Ideographic"},
    179129: {"Unified_Ideograph", "Ideographic"},
    179130: {"Unified_Ideograph", "Ideographic"},
    179131: {"Unified_Ideograph", "Ideographic"},
    179132: {"Unified_Ideograph", "Ideographic"},
    179133: {"Unified_Ideograph", "Ideographic"},
    179134: {"Unified_Ideograph", "Ideographic"},
    179135: {"Unified_Ideograph", "Ideographic"},
    179136: {"Unified_Ideograph", "Ideographic"},
    179137: {"Unified_Ideograph", "Ideographic"},
    179138: {"Unified_Ideograph", "Ideographic"},
    179139: {"Unified_Ideograph", "Ideographic"},
    179140: {"Unified_Ideograph", "Ideographic"},
    179141: {"Unified_Ideograph", "Ideographic"},
    179142: {"Unified_Ideograph", "Ideographic"},
    179143: {"Unified_Ideograph", "Ideographic"},
    179144: {"Unified_Ideograph", "Ideographic"},
    179145: {"Unified_Ideograph", "Ideographic"},
    179146: {"Unified_Ideograph", "Ideographic"},
    179147: {"Unified_Ideograph", "Ideographic"},
    179148: {"Unified_Ideograph", "Ideographic"},
    179149: {"Unified_Ideograph", "Ideographic"},
    179150: {"Unified_Ideograph", "Ideographic"},
    179151: {"Unified_Ideograph", "Ideographic"},
    179152: {"Unified_Ideograph", "Ideographic"},
    179153: {"Unified_Ideograph", "Ideographic"},
    179154: {"Unified_Ideograph", "Ideographic"},
    179155: {"Unified_Ideograph", "Ideographic"},
    179156: {"Unified_Ideograph", "Ideographic"},
    179157: {"Unified_Ideograph", "Ideographic"},
    179158: {"Unified_Ideograph", "Ideographic"},
    179159: {"Unified_Ideograph", "Ideographic"},
    179160: {"Unified_Ideograph", "Ideographic"},
    179161: {"Unified_Ideograph", "Ideographic"},
    179162: {"Unified_Ideograph", "Ideographic"},
    179163: {"Unified_Ideograph", "Ideographic"},
    179164: {"Unified_Ideograph", "Ideographic"},
    179165: {"Unified_Ideograph", "Ideographic"},
    179166: {"Unified_Ideograph", "Ideographic"},
    179167: {"Unified_Ideograph", "Ideographic"},
    179168: {"Unified_Ideograph", "Ideographic"},
    179169: {"Unified_Ideograph", "Ideographic"},
    179170: {"Unified_Ideograph", "Ideographic"},
    179171: {"Unified_Ideograph", "Ideographic"},
    179172: {"Unified_Ideograph", "Ideographic"},
    179173: {"Unified_Ideograph", "Ideographic"},
    179174: {"Unified_Ideograph", "Ideographic"},
    179175: {"Unified_Ideograph", "Ideographic"},
    179176: {"Unified_Ideograph", "Ideographic"},
    179177: {"Unified_Ideograph", "Ideographic"},
    179178: {"Unified_Ideograph", "Ideographic"},
    179179: {"Unified_Ideograph", "Ideographic"},
    179180: {"Unified_Ideograph", "Ideographic"},
    179181: {"Unified_Ideograph", "Ideographic"},
    179182: {"Unified_Ideograph", "Ideographic"},
    179183: {"Unified_Ideograph", "Ideographic"},
    179184: {"Unified_Ideograph", "Ideographic"},
    179185: {"Unified_Ideograph", "Ideographic"},
    179186: {"Unified_Ideograph", "Ideographic"},
    179187: {"Unified_Ideograph", "Ideographic"},
    179188: {"Unified_Ideograph", "Ideographic"},
    179189: {"Unified_Ideograph", "Ideographic"},
    179190: {"Unified_Ideograph", "Ideographic"},
    179191: {"Unified_Ideograph", "Ideographic"},
    179192: {"Unified_Ideograph", "Ideographic"},
    179193: {"Unified_Ideograph", "Ideographic"},
    179194: {"Unified_Ideograph", "Ideographic"},
    179195: {"Unified_Ideograph", "Ideographic"},
    179196: {"Unified_Ideograph", "Ideographic"},
    179197: {"Unified_Ideograph", "Ideographic"},
    179198: {"Unified_Ideograph", "Ideographic"},
    179199: {"Unified_Ideograph", "Ideographic"},
    179200: {"Unified_Ideograph", "Ideographic"},
    179201: {"Unified_Ideograph", "Ideographic"},
    179202: {"Unified_Ideograph", "Ideographic"},
    179203: {"Unified_Ideograph", "Ideographic"},
    179204: {"Unified_Ideograph", "Ideographic"},
    179205: {"Unified_Ideograph", "Ideographic"},
    179206: {"Unified_Ideograph", "Ideographic"},
    179207: {"Unified_Ideograph", "Ideographic"},
    179208: {"Unified_Ideograph", "Ideographic"},
    179209: {"Unified_Ideograph", "Ideographic"},
    179210: {"Unified_Ideograph", "Ideographic"},
    179211: {"Unified_Ideograph", "Ideographic"},
    179212: {"Unified_Ideograph", "Ideographic"},
    179213: {"Unified_Ideograph", "Ideographic"},
    179214: {"Unified_Ideograph", "Ideographic"},
    179215: {"Unified_Ideograph", "Ideographic"},
    179216: {"Unified_Ideograph", "Ideographic"},
    179217: {"Unified_Ideograph", "Ideographic"},
    179218: {"Unified_Ideograph", "Ideographic"},
    179219: {"Unified_Ideograph", "Ideographic"},
    179220: {"Unified_Ideograph", "Ideographic"},
    179221: {"Unified_Ideograph", "Ideographic"},
    179222: {"Unified_Ideograph", "Ideographic"},
    179223: {"Unified_Ideograph", "Ideographic"},
    179224: {"Unified_Ideograph", "Ideographic"},
    179225: {"Unified_Ideograph", "Ideographic"},
    179226: {"Unified_Ideograph", "Ideographic"},
    179227: {"Unified_Ideograph", "Ideographic"},
    179228: {"Unified_Ideograph", "Ideographic"},
    179229: {"Unified_Ideograph", "Ideographic"},
    179230: {"Unified_Ideograph", "Ideographic"},
    179231: {"Unified_Ideograph", "Ideographic"},
    179232: {"Unified_Ideograph", "Ideographic"},
    179233: {"Unified_Ideograph", "Ideographic"},
    179234: {"Unified_Ideograph", "Ideographic"},
    179235: {"Unified_Ideograph", "Ideographic"},
    179236: {"Unified_Ideograph", "Ideographic"},
    179237: {"Unified_Ideograph", "Ideographic"},
    179238: {"Unified_Ideograph", "Ideographic"},
    179239: {"Unified_Ideograph", "Ideographic"},
    179240: {"Unified_Ideograph", "Ideographic"},
    179241: {"Unified_Ideograph", "Ideographic"},
    179242: {"Unified_Ideograph", "Ideographic"},
    179243: {"Unified_Ideograph", "Ideographic"},
    179244: {"Unified_Ideograph", "Ideographic"},
    179245: {"Unified_Ideograph", "Ideographic"},
    179246: {"Unified_Ideograph", "Ideographic"},
    179247: {"Unified_Ideograph", "Ideographic"},
    179248: {"Unified_Ideograph", "Ideographic"},
    179249: {"Unified_Ideograph", "Ideographic"},
    179250: {"Unified_Ideograph", "Ideographic"},
    179251: {"Unified_Ideograph", "Ideographic"},
    179252: {"Unified_Ideograph", "Ideographic"},
    179253: {"Unified_Ideograph", "Ideographic"},
    179254: {"Unified_Ideograph", "Ideographic"},
    179255: {"Unified_Ideograph", "Ideographic"},
    179256: {"Unified_Ideograph", "Ideographic"},
    179257: {"Unified_Ideograph", "Ideographic"},
    179258: {"Unified_Ideograph", "Ideographic"},
    179259: {"Unified_Ideograph", "Ideographic"},
    179260: {"Unified_Ideograph", "Ideographic"},
    179261: {"Unified_Ideograph", "Ideographic"},
    179262: {"Unified_Ideograph", "Ideographic"},
    179263: {"Unified_Ideograph", "Ideographic"},
    179264: {"Unified_Ideograph", "Ideographic"},
    179265: {"Unified_Ideograph", "Ideographic"},
    179266: {"Unified_Ideograph", "Ideographic"},
    179267: {"Unified_Ideograph", "Ideographic"},
    179268: {"Unified_Ideograph", "Ideographic"},
    179269: {"Unified_Ideograph", "Ideographic"},
    179270: {"Unified_Ideograph", "Ideographic"},
    179271: {"Unified_Ideograph", "Ideographic"},
    179272: {"Unified_Ideograph", "Ideographic"},
    179273: {"Unified_Ideograph", "Ideographic"},
    179274: {"Unified_Ideograph", "Ideographic"},
    179275: {"Unified_Ideograph", "Ideographic"},
    179276: {"Unified_Ideograph", "Ideographic"},
    179277: {"Unified_Ideograph", "Ideographic"},
    179278: {"Unified_Ideograph", "Ideographic"},
    179279: {"Unified_Ideograph", "Ideographic"},
    179280: {"Unified_Ideograph", "Ideographic"},
    179281: {"Unified_Ideograph", "Ideographic"},
    179282: {"Unified_Ideograph", "Ideographic"},
    179283: {"Unified_Ideograph", "Ideographic"},
    179284: {"Unified_Ideograph", "Ideographic"},
    179285: {"Unified_Ideograph", "Ideographic"},
    179286: {"Unified_Ideograph", "Ideographic"},
    179287: {"Unified_Ideograph", "Ideographic"},
    179288: {"Unified_Ideograph", "Ideographic"},
    179289: {"Unified_Ideograph", "Ideographic"},
    179290: {"Unified_Ideograph", "Ideographic"},
    179291: {"Unified_Ideograph", "Ideographic"},
    179292: {"Unified_Ideograph", "Ideographic"},
    179293: {"Unified_Ideograph", "Ideographic"},
    179294: {"Unified_Ideograph", "Ideographic"},
    179295: {"Unified_Ideograph", "Ideographic"},
    179296: {"Unified_Ideograph", "Ideographic"},
    179297: {"Unified_Ideograph", "Ideographic"},
    179298: {"Unified_Ideograph", "Ideographic"},
    179299: {"Unified_Ideograph", "Ideographic"},
    179300: {"Unified_Ideograph", "Ideographic"},
    179301: {"Unified_Ideograph", "Ideographic"},
    179302: {"Unified_Ideograph", "Ideographic"},
    179303: {"Unified_Ideograph", "Ideographic"},
    179304: {"Unified_Ideograph", "Ideographic"},
    179305: {"Unified_Ideograph", "Ideographic"},
    179306: {"Unified_Ideograph", "Ideographic"},
    179307: {"Unified_Ideograph", "Ideographic"},
    179308: {"Unified_Ideograph", "Ideographic"},
    179309: {"Unified_Ideograph", "Ideographic"},
    179310: {"Unified_Ideograph", "Ideographic"},
    179311: {"Unified_Ideograph", "Ideographic"},
    179312: {"Unified_Ideograph", "Ideographic"},
    179313: {"Unified_Ideograph", "Ideographic"},
    179314: {"Unified_Ideograph", "Ideographic"},
    179315: {"Unified_Ideograph", "Ideographic"},
    179316: {"Unified_Ideograph", "Ideographic"},
    179317: {"Unified_Ideograph", "Ideographic"},
    179318: {"Unified_Ideograph", "Ideographic"},
    179319: {"Unified_Ideograph", "Ideographic"},
    179320: {"Unified_Ideograph", "Ideographic"},
    179321: {"Unified_Ideograph", "Ideographic"},
    179322: {"Unified_Ideograph", "Ideographic"},
    179323: {"Unified_Ideograph", "Ideographic"},
    179324: {"Unified_Ideograph", "Ideographic"},
    179325: {"Unified_Ideograph", "Ideographic"},
    179326: {"Unified_Ideograph", "Ideographic"},
    179327: {"Unified_Ideograph", "Ideographic"},
    179328: {"Unified_Ideograph", "Ideographic"},
    179329: {"Unified_Ideograph", "Ideographic"},
    179330: {"Unified_Ideograph", "Ideographic"},
    179331: {"Unified_Ideograph", "Ideographic"},
    179332: {"Unified_Ideograph", "Ideographic"},
    179333: {"Unified_Ideograph", "Ideographic"},
    179334: {"Unified_Ideograph", "Ideographic"},
    179335: {"Unified_Ideograph", "Ideographic"},
    179336: {"Unified_Ideograph", "Ideographic"},
    179337: {"Unified_Ideograph", "Ideographic"},
    179338: {"Unified_Ideograph", "Ideographic"},
    179339: {"Unified_Ideograph", "Ideographic"},
    179340: {"Unified_Ideograph", "Ideographic"},
    179341: {"Unified_Ideograph", "Ideographic"},
    179342: {"Unified_Ideograph", "Ideographic"},
    179343: {"Unified_Ideograph", "Ideographic"},
    179344: {"Unified_Ideograph", "Ideographic"},
    179345: {"Unified_Ideograph", "Ideographic"},
    179346: {"Unified_Ideograph", "Ideographic"},
    179347: {"Unified_Ideograph", "Ideographic"},
    179348: {"Unified_Ideograph", "Ideographic"},
    179349: {"Unified_Ideograph", "Ideographic"},
    179350: {"Unified_Ideograph", "Ideographic"},
    179351: {"Unified_Ideograph", "Ideographic"},
    179352: {"Unified_Ideograph", "Ideographic"},
    179353: {"Unified_Ideograph", "Ideographic"},
    179354: {"Unified_Ideograph", "Ideographic"},
    179355: {"Unified_Ideograph", "Ideographic"},
    179356: {"Unified_Ideograph", "Ideographic"},
    179357: {"Unified_Ideograph", "Ideographic"},
    179358: {"Unified_Ideograph", "Ideographic"},
    179359: {"Unified_Ideograph", "Ideographic"},
    179360: {"Unified_Ideograph", "Ideographic"},
    179361: {"Unified_Ideograph", "Ideographic"},
    179362: {"Unified_Ideograph", "Ideographic"},
    179363: {"Unified_Ideograph", "Ideographic"},
    179364: {"Unified_Ideograph", "Ideographic"},
    179365: {"Unified_Ideograph", "Ideographic"},
    179366: {"Unified_Ideograph", "Ideographic"},
    179367: {"Unified_Ideograph", "Ideographic"},
    179368: {"Unified_Ideograph", "Ideographic"},
    179369: {"Unified_Ideograph", "Ideographic"},
    179370: {"Unified_Ideograph", "Ideographic"},
    179371: {"Unified_Ideograph", "Ideographic"},
    179372: {"Unified_Ideograph", "Ideographic"},
    179373: {"Unified_Ideograph", "Ideographic"},
    179374: {"Unified_Ideograph", "Ideographic"},
    179375: {"Unified_Ideograph", "Ideographic"},
    179376: {"Unified_Ideograph", "Ideographic"},
    179377: {"Unified_Ideograph", "Ideographic"},
    179378: {"Unified_Ideograph", "Ideographic"},
    179379: {"Unified_Ideograph", "Ideographic"},
    179380: {"Unified_Ideograph", "Ideographic"},
    179381: {"Unified_Ideograph", "Ideographic"},
    179382: {"Unified_Ideograph", "Ideographic"},
    179383: {"Unified_Ideograph", "Ideographic"},
    179384: {"Unified_Ideograph", "Ideographic"},
    179385: {"Unified_Ideograph", "Ideographic"},
    179386: {"Unified_Ideograph", "Ideographic"},
    179387: {"Unified_Ideograph", "Ideographic"},
    179388: {"Unified_Ideograph", "Ideographic"},
    179389: {"Unified_Ideograph", "Ideographic"},
    179390: {"Unified_Ideograph", "Ideographic"},
    179391: {"Unified_Ideograph", "Ideographic"},
    179392: {"Unified_Ideograph", "Ideographic"},
    179393: {"Unified_Ideograph", "Ideographic"},
    179394: {"Unified_Ideograph", "Ideographic"},
    179395: {"Unified_Ideograph", "Ideographic"},
    179396: {"Unified_Ideograph", "Ideographic"},
    179397: {"Unified_Ideograph", "Ideographic"},
    179398: {"Unified_Ideograph", "Ideographic"},
    179399: {"Unified_Ideograph", "Ideographic"},
    179400: {"Unified_Ideograph", "Ideographic"},
    179401: {"Unified_Ideograph", "Ideographic"},
    179402: {"Unified_Ideograph", "Ideographic"},
    179403: {"Unified_Ideograph", "Ideographic"},
    179404: {"Unified_Ideograph", "Ideographic"},
    179405: {"Unified_Ideograph", "Ideographic"},
    179406: {"Unified_Ideograph", "Ideographic"},
    179407: {"Unified_Ideograph", "Ideographic"},
    179408: {"Unified_Ideograph", "Ideographic"},
    179409: {"Unified_Ideograph", "Ideographic"},
    179410: {"Unified_Ideograph", "Ideographic"},
    179411: {"Unified_Ideograph", "Ideographic"},
    179412: {"Unified_Ideograph", "Ideographic"},
    179413: {"Unified_Ideograph", "Ideographic"},
    179414: {"Unified_Ideograph", "Ideographic"},
    179415: {"Unified_Ideograph", "Ideographic"},
    179416: {"Unified_Ideograph", "Ideographic"},
    179417: {"Unified_Ideograph", "Ideographic"},
    179418: {"Unified_Ideograph", "Ideographic"},
    179419: {"Unified_Ideograph", "Ideographic"},
    179420: {"Unified_Ideograph", "Ideographic"},
    179421: {"Unified_Ideograph", "Ideographic"},
    179422: {"Unified_Ideograph", "Ideographic"},
    179423: {"Unified_Ideograph", "Ideographic"},
    179424: {"Unified_Ideograph", "Ideographic"},
    179425: {"Unified_Ideograph", "Ideographic"},
    179426: {"Unified_Ideograph", "Ideographic"},
    179427: {"Unified_Ideograph", "Ideographic"},
    179428: {"Unified_Ideograph", "Ideographic"},
    179429: {"Unified_Ideograph", "Ideographic"},
    179430: {"Unified_Ideograph", "Ideographic"},
    179431: {"Unified_Ideograph", "Ideographic"},
    179432: {"Unified_Ideograph", "Ideographic"},
    179433: {"Unified_Ideograph", "Ideographic"},
    179434: {"Unified_Ideograph", "Ideographic"},
    179435: {"Unified_Ideograph", "Ideographic"},
    179436: {"Unified_Ideograph", "Ideographic"},
    179437: {"Unified_Ideograph", "Ideographic"},
    179438: {"Unified_Ideograph", "Ideographic"},
    179439: {"Unified_Ideograph", "Ideographic"},
    179440: {"Unified_Ideograph", "Ideographic"},
    179441: {"Unified_Ideograph", "Ideographic"},
    179442: {"Unified_Ideograph", "Ideographic"},
    179443: {"Unified_Ideograph", "Ideographic"},
    179444: {"Unified_Ideograph", "Ideographic"},
    179445: {"Unified_Ideograph", "Ideographic"},
    179446: {"Unified_Ideograph", "Ideographic"},
    179447: {"Unified_Ideograph", "Ideographic"},
    179448: {"Unified_Ideograph", "Ideographic"},
    179449: {"Unified_Ideograph", "Ideographic"},
    179450: {"Unified_Ideograph", "Ideographic"},
    179451: {"Unified_Ideograph", "Ideographic"},
    179452: {"Unified_Ideograph", "Ideographic"},
    179453: {"Unified_Ideograph", "Ideographic"},
    179454: {"Unified_Ideograph", "Ideographic"},
    179455: {"Unified_Ideograph", "Ideographic"},
    179456: {"Unified_Ideograph", "Ideographic"},
    179457: {"Unified_Ideograph", "Ideographic"},
    179458: {"Unified_Ideograph", "Ideographic"},
    179459: {"Unified_Ideograph", "Ideographic"},
    179460: {"Unified_Ideograph", "Ideographic"},
    179461: {"Unified_Ideograph", "Ideographic"},
    179462: {"Unified_Ideograph", "Ideographic"},
    179463: {"Unified_Ideograph", "Ideographic"},
    179464: {"Unified_Ideograph", "Ideographic"},
    179465: {"Unified_Ideograph", "Ideographic"},
    179466: {"Unified_Ideograph", "Ideographic"},
    179467: {"Unified_Ideograph", "Ideographic"},
    179468: {"Unified_Ideograph", "Ideographic"},
    179469: {"Unified_Ideograph", "Ideographic"},
    179470: {"Unified_Ideograph", "Ideographic"},
    179471: {"Unified_Ideograph", "Ideographic"},
    179472: {"Unified_Ideograph", "Ideographic"},
    179473: {"Unified_Ideograph", "Ideographic"},
    179474: {"Unified_Ideograph", "Ideographic"},
    179475: {"Unified_Ideograph", "Ideographic"},
    179476: {"Unified_Ideograph", "Ideographic"},
    179477: {"Unified_Ideograph", "Ideographic"},
    179478: {"Unified_Ideograph", "Ideographic"},
    179479: {"Unified_Ideograph", "Ideographic"},
    179480: {"Unified_Ideograph", "Ideographic"},
    179481: {"Unified_Ideograph", "Ideographic"},
    179482: {"Unified_Ideograph", "Ideographic"},
    179483: {"Unified_Ideograph", "Ideographic"},
    179484: {"Unified_Ideograph", "Ideographic"},
    179485: {"Unified_Ideograph", "Ideographic"},
    179486: {"Unified_Ideograph", "Ideographic"},
    179487: {"Unified_Ideograph", "Ideographic"},
    179488: {"Unified_Ideograph", "Ideographic"},
    179489: {"Unified_Ideograph", "Ideographic"},
    179490: {"Unified_Ideograph", "Ideographic"},
    179491: {"Unified_Ideograph", "Ideographic"},
    179492: {"Unified_Ideograph", "Ideographic"},
    179493: {"Unified_Ideograph", "Ideographic"},
    179494: {"Unified_Ideograph", "Ideographic"},
    179495: {"Unified_Ideograph", "Ideographic"},
    179496: {"Unified_Ideograph", "Ideographic"},
    179497: {"Unified_Ideograph", "Ideographic"},
    179498: {"Unified_Ideograph", "Ideographic"},
    179499: {"Unified_Ideograph", "Ideographic"},
    179500: {"Unified_Ideograph", "Ideographic"},
    179501: {"Unified_Ideograph", "Ideographic"},
    179502: {"Unified_Ideograph", "Ideographic"},
    179503: {"Unified_Ideograph", "Ideographic"},
    179504: {"Unified_Ideograph", "Ideographic"},
    179505: {"Unified_Ideograph", "Ideographic"},
    179506: {"Unified_Ideograph", "Ideographic"},
    179507: {"Unified_Ideograph", "Ideographic"},
    179508: {"Unified_Ideograph", "Ideographic"},
    179509: {"Unified_Ideograph", "Ideographic"},
    179510: {"Unified_Ideograph", "Ideographic"},
    179511: {"Unified_Ideograph", "Ideographic"},
    179512: {"Unified_Ideograph", "Ideographic"},
    179513: {"Unified_Ideograph", "Ideographic"},
    179514: {"Unified_Ideograph", "Ideographic"},
    179515: {"Unified_Ideograph", "Ideographic"},
    179516: {"Unified_Ideograph", "Ideographic"},
    179517: {"Unified_Ideograph", "Ideographic"},
    179518: {"Unified_Ideograph", "Ideographic"},
    179519: {"Unified_Ideograph", "Ideographic"},
    179520: {"Unified_Ideograph", "Ideographic"},
    179521: {"Unified_Ideograph", "Ideographic"},
    179522: {"Unified_Ideograph", "Ideographic"},
    179523: {"Unified_Ideograph", "Ideographic"},
    179524: {"Unified_Ideograph", "Ideographic"},
    179525: {"Unified_Ideograph", "Ideographic"},
    179526: {"Unified_Ideograph", "Ideographic"},
    179527: {"Unified_Ideograph", "Ideographic"},
    179528: {"Unified_Ideograph", "Ideographic"},
    179529: {"Unified_Ideograph", "Ideographic"},
    179530: {"Unified_Ideograph", "Ideographic"},
    179531: {"Unified_Ideograph", "Ideographic"},
    179532: {"Unified_Ideograph", "Ideographic"},
    179533: {"Unified_Ideograph", "Ideographic"},
    179534: {"Unified_Ideograph", "Ideographic"},
    179535: {"Unified_Ideograph", "Ideographic"},
    179536: {"Unified_Ideograph", "Ideographic"},
    179537: {"Unified_Ideograph", "Ideographic"},
    179538: {"Unified_Ideograph", "Ideographic"},
    179539: {"Unified_Ideograph", "Ideographic"},
    179540: {"Unified_Ideograph", "Ideographic"},
    179541: {"Unified_Ideograph", "Ideographic"},
    179542: {"Unified_Ideograph", "Ideographic"},
    179543: {"Unified_Ideograph", "Ideographic"},
    179544: {"Unified_Ideograph", "Ideographic"},
    179545: {"Unified_Ideograph", "Ideographic"},
    179546: {"Unified_Ideograph", "Ideographic"},
    179547: {"Unified_Ideograph", "Ideographic"},
    179548: {"Unified_Ideograph", "Ideographic"},
    179549: {"Unified_Ideograph", "Ideographic"},
    179550: {"Unified_Ideograph", "Ideographic"},
    179551: {"Unified_Ideograph", "Ideographic"},
    179552: {"Unified_Ideograph", "Ideographic"},
    179553: {"Unified_Ideograph", "Ideographic"},
    179554: {"Unified_Ideograph", "Ideographic"},
    179555: {"Unified_Ideograph", "Ideographic"},
    179556: {"Unified_Ideograph", "Ideographic"},
    179557: {"Unified_Ideograph", "Ideographic"},
    179558: {"Unified_Ideograph", "Ideographic"},
    179559: {"Unified_Ideograph", "Ideographic"},
    179560: {"Unified_Ideograph", "Ideographic"},
    179561: {"Unified_Ideograph", "Ideographic"},
    179562: {"Unified_Ideograph", "Ideographic"},
    179563: {"Unified_Ideograph", "Ideographic"},
    179564: {"Unified_Ideograph", "Ideographic"},
    179565: {"Unified_Ideograph", "Ideographic"},
    179566: {"Unified_Ideograph", "Ideographic"},
    179567: {"Unified_Ideograph", "Ideographic"},
    179568: {"Unified_Ideograph", "Ideographic"},
    179569: {"Unified_Ideograph", "Ideographic"},
    179570: {"Unified_Ideograph", "Ideographic"},
    179571: {"Unified_Ideograph", "Ideographic"},
    179572: {"Unified_Ideograph", "Ideographic"},
    179573: {"Unified_Ideograph", "Ideographic"},
    179574: {"Unified_Ideograph", "Ideographic"},
    179575: {"Unified_Ideograph", "Ideographic"},
    179576: {"Unified_Ideograph", "Ideographic"},
    179577: {"Unified_Ideograph", "Ideographic"},
    179578: {"Unified_Ideograph", "Ideographic"},
    179579: {"Unified_Ideograph", "Ideographic"},
    179580: {"Unified_Ideograph", "Ideographic"},
    179581: {"Unified_Ideograph", "Ideographic"},
    179582: {"Unified_Ideograph", "Ideographic"},
    179583: {"Unified_Ideograph", "Ideographic"},
    179584: {"Unified_Ideograph", "Ideographic"},
    179585: {"Unified_Ideograph", "Ideographic"},
    179586: {"Unified_Ideograph", "Ideographic"},
    179587: {"Unified_Ideograph", "Ideographic"},
    179588: {"Unified_Ideograph", "Ideographic"},
    179589: {"Unified_Ideograph", "Ideographic"},
    179590: {"Unified_Ideograph", "Ideographic"},
    179591: {"Unified_Ideograph", "Ideographic"},
    179592: {"Unified_Ideograph", "Ideographic"},
    179593: {"Unified_Ideograph", "Ideographic"},
    179594: {"Unified_Ideograph", "Ideographic"},
    179595: {"Unified_Ideograph", "Ideographic"},
    179596: {"Unified_Ideograph", "Ideographic"},
    179597: {"Unified_Ideograph", "Ideographic"},
    179598: {"Unified_Ideograph", "Ideographic"},
    179599: {"Unified_Ideograph", "Ideographic"},
    179600: {"Unified_Ideograph", "Ideographic"},
    179601: {"Unified_Ideograph", "Ideographic"},
    179602: {"Unified_Ideograph", "Ideographic"},
    179603: {"Unified_Ideograph", "Ideographic"},
    179604: {"Unified_Ideograph", "Ideographic"},
    179605: {"Unified_Ideograph", "Ideographic"},
    179606: {"Unified_Ideograph", "Ideographic"},
    179607: {"Unified_Ideograph", "Ideographic"},
    179608: {"Unified_Ideograph", "Ideographic"},
    179609: {"Unified_Ideograph", "Ideographic"},
    179610: {"Unified_Ideograph", "Ideographic"},
    179611: {"Unified_Ideograph", "Ideographic"},
    179612: {"Unified_Ideograph", "Ideographic"},
    179613: {"Unified_Ideograph", "Ideographic"},
    179614: {"Unified_Ideograph", "Ideographic"},
    179615: {"Unified_Ideograph", "Ideographic"},
    179616: {"Unified_Ideograph", "Ideographic"},
    179617: {"Unified_Ideograph", "Ideographic"},
    179618: {"Unified_Ideograph", "Ideographic"},
    179619: {"Unified_Ideograph", "Ideographic"},
    179620: {"Unified_Ideograph", "Ideographic"},
    179621: {"Unified_Ideograph", "Ideographic"},
    179622: {"Unified_Ideograph", "Ideographic"},
    179623: {"Unified_Ideograph", "Ideographic"},
    179624: {"Unified_Ideograph", "Ideographic"},
    179625: {"Unified_Ideograph", "Ideographic"},
    179626: {"Unified_Ideograph", "Ideographic"},
    179627: {"Unified_Ideograph", "Ideographic"},
    179628: {"Unified_Ideograph", "Ideographic"},
    179629: {"Unified_Ideograph", "Ideographic"},
    179630: {"Unified_Ideograph", "Ideographic"},
    179631: {"Unified_Ideograph", "Ideographic"},
    179632: {"Unified_Ideograph", "Ideographic"},
    179633: {"Unified_Ideograph", "Ideographic"},
    179634: {"Unified_Ideograph", "Ideographic"},
    179635: {"Unified_Ideograph", "Ideographic"},
    179636: {"Unified_Ideograph", "Ideographic"},
    179637: {"Unified_Ideograph", "Ideographic"},
    179638: {"Unified_Ideograph", "Ideographic"},
    179639: {"Unified_Ideograph", "Ideographic"},
    179640: {"Unified_Ideograph", "Ideographic"},
    179641: {"Unified_Ideograph", "Ideographic"},
    179642: {"Unified_Ideograph", "Ideographic"},
    179643: {"Unified_Ideograph", "Ideographic"},
    179644: {"Unified_Ideograph", "Ideographic"},
    179645: {"Unified_Ideograph", "Ideographic"},
    179646: {"Unified_Ideograph", "Ideographic"},
    179647: {"Unified_Ideograph", "Ideographic"},
    179648: {"Unified_Ideograph", "Ideographic"},
    179649: {"Unified_Ideograph", "Ideographic"},
    179650: {"Unified_Ideograph", "Ideographic"},
    179651: {"Unified_Ideograph", "Ideographic"},
    179652: {"Unified_Ideograph", "Ideographic"},
    179653: {"Unified_Ideograph", "Ideographic"},
    179654: {"Unified_Ideograph", "Ideographic"},
    179655: {"Unified_Ideograph", "Ideographic"},
    179656: {"Unified_Ideograph", "Ideographic"},
    179657: {"Unified_Ideograph", "Ideographic"},
    179658: {"Unified_Ideograph", "Ideographic"},
    179659: {"Unified_Ideograph", "Ideographic"},
    179660: {"Unified_Ideograph", "Ideographic"},
    179661: {"Unified_Ideograph", "Ideographic"},
    179662: {"Unified_Ideograph", "Ideographic"},
    179663: {"Unified_Ideograph", "Ideographic"},
    179664: {"Unified_Ideograph", "Ideographic"},
    179665: {"Unified_Ideograph", "Ideographic"},
    179666: {"Unified_Ideograph", "Ideographic"},
    179667: {"Unified_Ideograph", "Ideographic"},
    179668: {"Unified_Ideograph", "Ideographic"},
    179669: {"Unified_Ideograph", "Ideographic"},
    179670: {"Unified_Ideograph", "Ideographic"},
    179671: {"Unified_Ideograph", "Ideographic"},
    179672: {"Unified_Ideograph", "Ideographic"},
    179673: {"Unified_Ideograph", "Ideographic"},
    179674: {"Unified_Ideograph", "Ideographic"},
    179675: {"Unified_Ideograph", "Ideographic"},
    179676: {"Unified_Ideograph", "Ideographic"},
    179677: {"Unified_Ideograph", "Ideographic"},
    179678: {"Unified_Ideograph", "Ideographic"},
    179679: {"Unified_Ideograph", "Ideographic"},
    179680: {"Unified_Ideograph", "Ideographic"},
    179681: {"Unified_Ideograph", "Ideographic"},
    179682: {"Unified_Ideograph", "Ideographic"},
    179683: {"Unified_Ideograph", "Ideographic"},
    179684: {"Unified_Ideograph", "Ideographic"},
    179685: {"Unified_Ideograph", "Ideographic"},
    179686: {"Unified_Ideograph", "Ideographic"},
    179687: {"Unified_Ideograph", "Ideographic"},
    179688: {"Unified_Ideograph", "Ideographic"},
    179689: {"Unified_Ideograph", "Ideographic"},
    179690: {"Unified_Ideograph", "Ideographic"},
    179691: {"Unified_Ideograph", "Ideographic"},
    179692: {"Unified_Ideograph", "Ideographic"},
    179693: {"Unified_Ideograph", "Ideographic"},
    179694: {"Unified_Ideograph", "Ideographic"},
    179695: {"Unified_Ideograph", "Ideographic"},
    179696: {"Unified_Ideograph", "Ideographic"},
    179697: {"Unified_Ideograph", "Ideographic"},
    179698: {"Unified_Ideograph", "Ideographic"},
    179699: {"Unified_Ideograph", "Ideographic"},
    179700: {"Unified_Ideograph", "Ideographic"},
    179701: {"Unified_Ideograph", "Ideographic"},
    179702: {"Unified_Ideograph", "Ideographic"},
    179703: {"Unified_Ideograph", "Ideographic"},
    179704: {"Unified_Ideograph", "Ideographic"},
    179705: {"Unified_Ideograph", "Ideographic"},
    179706: {"Unified_Ideograph", "Ideographic"},
    179707: {"Unified_Ideograph", "Ideographic"},
    179708: {"Unified_Ideograph", "Ideographic"},
    179709: {"Unified_Ideograph", "Ideographic"},
    179710: {"Unified_Ideograph", "Ideographic"},
    179711: {"Unified_Ideograph", "Ideographic"},
    179712: {"Unified_Ideograph", "Ideographic"},
    179713: {"Unified_Ideograph", "Ideographic"},
    179714: {"Unified_Ideograph", "Ideographic"},
    179715: {"Unified_Ideograph", "Ideographic"},
    179716: {"Unified_Ideograph", "Ideographic"},
    179717: {"Unified_Ideograph", "Ideographic"},
    179718: {"Unified_Ideograph", "Ideographic"},
    179719: {"Unified_Ideograph", "Ideographic"},
    179720: {"Unified_Ideograph", "Ideographic"},
    179721: {"Unified_Ideograph", "Ideographic"},
    179722: {"Unified_Ideograph", "Ideographic"},
    179723: {"Unified_Ideograph", "Ideographic"},
    179724: {"Unified_Ideograph", "Ideographic"},
    179725: {"Unified_Ideograph", "Ideographic"},
    179726: {"Unified_Ideograph", "Ideographic"},
    179727: {"Unified_Ideograph", "Ideographic"},
    179728: {"Unified_Ideograph", "Ideographic"},
    179729: {"Unified_Ideograph", "Ideographic"},
    179730: {"Unified_Ideograph", "Ideographic"},
    179731: {"Unified_Ideograph", "Ideographic"},
    179732: {"Unified_Ideograph", "Ideographic"},
    179733: {"Unified_Ideograph", "Ideographic"},
    179734: {"Unified_Ideograph", "Ideographic"},
    179735: {"Unified_Ideograph", "Ideographic"},
    179736: {"Unified_Ideograph", "Ideographic"},
    179737: {"Unified_Ideograph", "Ideographic"},
    179738: {"Unified_Ideograph", "Ideographic"},
    179739: {"Unified_Ideograph", "Ideographic"},
    179740: {"Unified_Ideograph", "Ideographic"},
    179741: {"Unified_Ideograph", "Ideographic"},
    179742: {"Unified_Ideograph", "Ideographic"},
    179743: {"Unified_Ideograph", "Ideographic"},
    179744: {"Unified_Ideograph", "Ideographic"},
    179745: {"Unified_Ideograph", "Ideographic"},
    179746: {"Unified_Ideograph", "Ideographic"},
    179747: {"Unified_Ideograph", "Ideographic"},
    179748: {"Unified_Ideograph", "Ideographic"},
    179749: {"Unified_Ideograph", "Ideographic"},
    179750: {"Unified_Ideograph", "Ideographic"},
    179751: {"Unified_Ideograph", "Ideographic"},
    179752: {"Unified_Ideograph", "Ideographic"},
    179753: {"Unified_Ideograph", "Ideographic"},
    179754: {"Unified_Ideograph", "Ideographic"},
    179755: {"Unified_Ideograph", "Ideographic"},
    179756: {"Unified_Ideograph", "Ideographic"},
    179757: {"Unified_Ideograph", "Ideographic"},
    179758: {"Unified_Ideograph", "Ideographic"},
    179759: {"Unified_Ideograph", "Ideographic"},
    179760: {"Unified_Ideograph", "Ideographic"},
    179761: {"Unified_Ideograph", "Ideographic"},
    179762: {"Unified_Ideograph", "Ideographic"},
    179763: {"Unified_Ideograph", "Ideographic"},
    179764: {"Unified_Ideograph", "Ideographic"},
    179765: {"Unified_Ideograph", "Ideographic"},
    179766: {"Unified_Ideograph", "Ideographic"},
    179767: {"Unified_Ideograph", "Ideographic"},
    179768: {"Unified_Ideograph", "Ideographic"},
    179769: {"Unified_Ideograph", "Ideographic"},
    179770: {"Unified_Ideograph", "Ideographic"},
    179771: {"Unified_Ideograph", "Ideographic"},
    179772: {"Unified_Ideograph", "Ideographic"},
    179773: {"Unified_Ideograph", "Ideographic"},
    179774: {"Unified_Ideograph", "Ideographic"},
    179775: {"Unified_Ideograph", "Ideographic"},
    179776: {"Unified_Ideograph", "Ideographic"},
    179777: {"Unified_Ideograph", "Ideographic"},
    179778: {"Unified_Ideograph", "Ideographic"},
    179779: {"Unified_Ideograph", "Ideographic"},
    179780: {"Unified_Ideograph", "Ideographic"},
    179781: {"Unified_Ideograph", "Ideographic"},
    179782: {"Unified_Ideograph", "Ideographic"},
    179783: {"Unified_Ideograph", "Ideographic"},
    179784: {"Unified_Ideograph", "Ideographic"},
    179785: {"Unified_Ideograph", "Ideographic"},
    179786: {"Unified_Ideograph", "Ideographic"},
    179787: {"Unified_Ideograph", "Ideographic"},
    179788: {"Unified_Ideograph", "Ideographic"},
    179789: {"Unified_Ideograph", "Ideographic"},
    179790: {"Unified_Ideograph", "Ideographic"},
    179791: {"Unified_Ideograph", "Ideographic"},
    179792: {"Unified_Ideograph", "Ideographic"},
    179793: {"Unified_Ideograph", "Ideographic"},
    179794: {"Unified_Ideograph", "Ideographic"},
    179795: {"Unified_Ideograph", "Ideographic"},
    179796: {"Unified_Ideograph", "Ideographic"},
    179797: {"Unified_Ideograph", "Ideographic"},
    179798: {"Unified_Ideograph", "Ideographic"},
    179799: {"Unified_Ideograph", "Ideographic"},
    179800: {"Unified_Ideograph", "Ideographic"},
    179801: {"Unified_Ideograph", "Ideographic"},
    179802: {"Unified_Ideograph", "Ideographic"},
    179803: {"Unified_Ideograph", "Ideographic"},
    179804: {"Unified_Ideograph", "Ideographic"},
    179805: {"Unified_Ideograph", "Ideographic"},
    179806: {"Unified_Ideograph", "Ideographic"},
    179807: {"Unified_Ideograph", "Ideographic"},
    179808: {"Unified_Ideograph", "Ideographic"},
    179809: {"Unified_Ideograph", "Ideographic"},
    179810: {"Unified_Ideograph", "Ideographic"},
    179811: {"Unified_Ideograph", "Ideographic"},
    179812: {"Unified_Ideograph", "Ideographic"},
    179813: {"Unified_Ideograph", "Ideographic"},
    179814: {"Unified_Ideograph", "Ideographic"},
    179815: {"Unified_Ideograph", "Ideographic"},
    179816: {"Unified_Ideograph", "Ideographic"},
    179817: {"Unified_Ideograph", "Ideographic"},
    179818: {"Unified_Ideograph", "Ideographic"},
    179819: {"Unified_Ideograph", "Ideographic"},
    179820: {"Unified_Ideograph", "Ideographic"},
    179821: {"Unified_Ideograph", "Ideographic"},
    179822: {"Unified_Ideograph", "Ideographic"},
    179823: {"Unified_Ideograph", "Ideographic"},
    179824: {"Unified_Ideograph", "Ideographic"},
    179825: {"Unified_Ideograph", "Ideographic"},
    179826: {"Unified_Ideograph", "Ideographic"},
    179827: {"Unified_Ideograph", "Ideographic"},
    179828: {"Unified_Ideograph", "Ideographic"},
    179829: {"Unified_Ideograph", "Ideographic"},
    179830: {"Unified_Ideograph", "Ideographic"},
    179831: {"Unified_Ideograph", "Ideographic"},
    179832: {"Unified_Ideograph", "Ideographic"},
    179833: {"Unified_Ideograph", "Ideographic"},
    179834: {"Unified_Ideograph", "Ideographic"},
    179835: {"Unified_Ideograph", "Ideographic"},
    179836: {"Unified_Ideograph", "Ideographic"},
    179837: {"Unified_Ideograph", "Ideographic"},
    179838: {"Unified_Ideograph", "Ideographic"},
    179839: {"Unified_Ideograph", "Ideographic"},
    179840: {"Unified_Ideograph", "Ideographic"},
    179841: {"Unified_Ideograph", "Ideographic"},
    179842: {"Unified_Ideograph", "Ideographic"},
    179843: {"Unified_Ideograph", "Ideographic"},
    179844: {"Unified_Ideograph", "Ideographic"},
    179845: {"Unified_Ideograph", "Ideographic"},
    179846: {"Unified_Ideograph", "Ideographic"},
    179847: {"Unified_Ideograph", "Ideographic"},
    179848: {"Unified_Ideograph", "Ideographic"},
    179849: {"Unified_Ideograph", "Ideographic"},
    179850: {"Unified_Ideograph", "Ideographic"},
    179851: {"Unified_Ideograph", "Ideographic"},
    179852: {"Unified_Ideograph", "Ideographic"},
    179853: {"Unified_Ideograph", "Ideographic"},
    179854: {"Unified_Ideograph", "Ideographic"},
    179855: {"Unified_Ideograph", "Ideographic"},
    179856: {"Unified_Ideograph", "Ideographic"},
    179857: {"Unified_Ideograph", "Ideographic"},
    179858: {"Unified_Ideograph", "Ideographic"},
    179859: {"Unified_Ideograph", "Ideographic"},
    179860: {"Unified_Ideograph", "Ideographic"},
    179861: {"Unified_Ideograph", "Ideographic"},
    179862: {"Unified_Ideograph", "Ideographic"},
    179863: {"Unified_Ideograph", "Ideographic"},
    179864: {"Unified_Ideograph", "Ideographic"},
    179865: {"Unified_Ideograph", "Ideographic"},
    179866: {"Unified_Ideograph", "Ideographic"},
    179867: {"Unified_Ideograph", "Ideographic"},
    179868: {"Unified_Ideograph", "Ideographic"},
    179869: {"Unified_Ideograph", "Ideographic"},
    179870: {"Unified_Ideograph", "Ideographic"},
    179871: {"Unified_Ideograph", "Ideographic"},
    179872: {"Unified_Ideograph", "Ideographic"},
    179873: {"Unified_Ideograph", "Ideographic"},
    179874: {"Unified_Ideograph", "Ideographic"},
    179875: {"Unified_Ideograph", "Ideographic"},
    179876: {"Unified_Ideograph", "Ideographic"},
    179877: {"Unified_Ideograph", "Ideographic"},
    179878: {"Unified_Ideograph", "Ideographic"},
    179879: {"Unified_Ideograph", "Ideographic"},
    179880: {"Unified_Ideograph", "Ideographic"},
    179881: {"Unified_Ideograph", "Ideographic"},
    179882: {"Unified_Ideograph", "Ideographic"},
    179883: {"Unified_Ideograph", "Ideographic"},
    179884: {"Unified_Ideograph", "Ideographic"},
    179885: {"Unified_Ideograph", "Ideographic"},
    179886: {"Unified_Ideograph", "Ideographic"},
    179887: {"Unified_Ideograph", "Ideographic"},
    179888: {"Unified_Ideograph", "Ideographic"},
    179889: {"Unified_Ideograph", "Ideographic"},
    179890: {"Unified_Ideograph", "Ideographic"},
    179891: {"Unified_Ideograph", "Ideographic"},
    179892: {"Unified_Ideograph", "Ideographic"},
    179893: {"Unified_Ideograph", "Ideographic"},
    179894: {"Unified_Ideograph", "Ideographic"},
    179895: {"Unified_Ideograph", "Ideographic"},
    179896: {"Unified_Ideograph", "Ideographic"},
    179897: {"Unified_Ideograph", "Ideographic"},
    179898: {"Unified_Ideograph", "Ideographic"},
    179899: {"Unified_Ideograph", "Ideographic"},
    179900: {"Unified_Ideograph", "Ideographic"},
    179901: {"Unified_Ideograph", "Ideographic"},
    179902: {"Unified_Ideograph", "Ideographic"},
    179903: {"Unified_Ideograph", "Ideographic"},
    179904: {"Unified_Ideograph", "Ideographic"},
    179905: {"Unified_Ideograph", "Ideographic"},
    179906: {"Unified_Ideograph", "Ideographic"},
    179907: {"Unified_Ideograph", "Ideographic"},
    179908: {"Unified_Ideograph", "Ideographic"},
    179909: {"Unified_Ideograph", "Ideographic"},
    179910: {"Unified_Ideograph", "Ideographic"},
    179911: {"Unified_Ideograph", "Ideographic"},
    179912: {"Unified_Ideograph", "Ideographic"},
    179913: {"Unified_Ideograph", "Ideographic"},
    179914: {"Unified_Ideograph", "Ideographic"},
    179915: {"Unified_Ideograph", "Ideographic"},
    179916: {"Unified_Ideograph", "Ideographic"},
    179917: {"Unified_Ideograph", "Ideographic"},
    179918: {"Unified_Ideograph", "Ideographic"},
    179919: {"Unified_Ideograph", "Ideographic"},
    179920: {"Unified_Ideograph", "Ideographic"},
    179921: {"Unified_Ideograph", "Ideographic"},
    179922: {"Unified_Ideograph", "Ideographic"},
    179923: {"Unified_Ideograph", "Ideographic"},
    179924: {"Unified_Ideograph", "Ideographic"},
    179925: {"Unified_Ideograph", "Ideographic"},
    179926: {"Unified_Ideograph", "Ideographic"},
    179927: {"Unified_Ideograph", "Ideographic"},
    179928: {"Unified_Ideograph", "Ideographic"},
    179929: {"Unified_Ideograph", "Ideographic"},
    179930: {"Unified_Ideograph", "Ideographic"},
    179931: {"Unified_Ideograph", "Ideographic"},
    179932: {"Unified_Ideograph", "Ideographic"},
    179933: {"Unified_Ideograph", "Ideographic"},
    179934: {"Unified_Ideograph", "Ideographic"},
    179935: {"Unified_Ideograph", "Ideographic"},
    179936: {"Unified_Ideograph", "Ideographic"},
    179937: {"Unified_Ideograph", "Ideographic"},
    179938: {"Unified_Ideograph", "Ideographic"},
    179939: {"Unified_Ideograph", "Ideographic"},
    179940: {"Unified_Ideograph", "Ideographic"},
    179941: {"Unified_Ideograph", "Ideographic"},
    179942: {"Unified_Ideograph", "Ideographic"},
    179943: {"Unified_Ideograph", "Ideographic"},
    179944: {"Unified_Ideograph", "Ideographic"},
    179945: {"Unified_Ideograph", "Ideographic"},
    179946: {"Unified_Ideograph", "Ideographic"},
    179947: {"Unified_Ideograph", "Ideographic"},
    179948: {"Unified_Ideograph", "Ideographic"},
    179949: {"Unified_Ideograph", "Ideographic"},
    179950: {"Unified_Ideograph", "Ideographic"},
    179951: {"Unified_Ideograph", "Ideographic"},
    179952: {"Unified_Ideograph", "Ideographic"},
    179953: {"Unified_Ideograph", "Ideographic"},
    179954: {"Unified_Ideograph", "Ideographic"},
    179955: {"Unified_Ideograph", "Ideographic"},
    179956: {"Unified_Ideograph", "Ideographic"},
    179957: {"Unified_Ideograph", "Ideographic"},
    179958: {"Unified_Ideograph", "Ideographic"},
    179959: {"Unified_Ideograph", "Ideographic"},
    179960: {"Unified_Ideograph", "Ideographic"},
    179961: {"Unified_Ideograph", "Ideographic"},
    179962: {"Unified_Ideograph", "Ideographic"},
    179963: {"Unified_Ideograph", "Ideographic"},
    179964: {"Unified_Ideograph", "Ideographic"},
    179965: {"Unified_Ideograph", "Ideographic"},
    179966: {"Unified_Ideograph", "Ideographic"},
    179967: {"Unified_Ideograph", "Ideographic"},
    179968: {"Unified_Ideograph", "Ideographic"},
    179969: {"Unified_Ideograph", "Ideographic"},
    179970: {"Unified_Ideograph", "Ideographic"},
    179971: {"Unified_Ideograph", "Ideographic"},
    179972: {"Unified_Ideograph", "Ideographic"},
    179973: {"Unified_Ideograph", "Ideographic"},
    179974: {"Unified_Ideograph", "Ideographic"},
    179975: {"Unified_Ideograph", "Ideographic"},
    179976: {"Unified_Ideograph", "Ideographic"},
    179977: {"Unified_Ideograph", "Ideographic"},
    179978: {"Unified_Ideograph", "Ideographic"},
    179979: {"Unified_Ideograph", "Ideographic"},
    179980: {"Unified_Ideograph", "Ideographic"},
    179981: {"Unified_Ideograph", "Ideographic"},
    179982: {"Unified_Ideograph", "Ideographic"},
    179983: {"Unified_Ideograph", "Ideographic"},
    179984: {"Unified_Ideograph", "Ideographic"},
    179985: {"Unified_Ideograph", "Ideographic"},
    179986: {"Unified_Ideograph", "Ideographic"},
    179987: {"Unified_Ideograph", "Ideographic"},
    179988: {"Unified_Ideograph", "Ideographic"},
    179989: {"Unified_Ideograph", "Ideographic"},
    179990: {"Unified_Ideograph", "Ideographic"},
    179991: {"Unified_Ideograph", "Ideographic"},
    179992: {"Unified_Ideograph", "Ideographic"},
    179993: {"Unified_Ideograph", "Ideographic"},
    179994: {"Unified_Ideograph", "Ideographic"},
    179995: {"Unified_Ideograph", "Ideographic"},
    179996: {"Unified_Ideograph", "Ideographic"},
    179997: {"Unified_Ideograph", "Ideographic"},
    179998: {"Unified_Ideograph", "Ideographic"},
    179999: {"Unified_Ideograph", "Ideographic"},
    180000: {"Unified_Ideograph", "Ideographic"},
    180001: {"Unified_Ideograph", "Ideographic"},
    180002: {"Unified_Ideograph", "Ideographic"},
    180003: {"Unified_Ideograph", "Ideographic"},
    180004: {"Unified_Ideograph", "Ideographic"},
    180005: {"Unified_Ideograph", "Ideographic"},
    180006: {"Unified_Ideograph", "Ideographic"},
    180007: {"Unified_Ideograph", "Ideographic"},
    180008: {"Unified_Ideograph", "Ideographic"},
    180009: {"Unified_Ideograph", "Ideographic"},
    180010: {"Unified_Ideograph", "Ideographic"},
    180011: {"Unified_Ideograph", "Ideographic"},
    180012: {"Unified_Ideograph", "Ideographic"},
    180013: {"Unified_Ideograph", "Ideographic"},
    180014: {"Unified_Ideograph", "Ideographic"},
    180015: {"Unified_Ideograph", "Ideographic"},
    180016: {"Unified_Ideograph", "Ideographic"},
    180017: {"Unified_Ideograph", "Ideographic"},
    180018: {"Unified_Ideograph", "Ideographic"},
    180019: {"Unified_Ideograph", "Ideographic"},
    180020: {"Unified_Ideograph", "Ideographic"},
    180021: {"Unified_Ideograph", "Ideographic"},
    180022: {"Unified_Ideograph", "Ideographic"},
    180023: {"Unified_Ideograph", "Ideographic"},
    180024: {"Unified_Ideograph", "Ideographic"},
    180025: {"Unified_Ideograph", "Ideographic"},
    180026: {"Unified_Ideograph", "Ideographic"},
    180027: {"Unified_Ideograph", "Ideographic"},
    180028: {"Unified_Ideograph", "Ideographic"},
    180029: {"Unified_Ideograph", "Ideographic"},
    180030: {"Unified_Ideograph", "Ideographic"},
    180031: {"Unified_Ideograph", "Ideographic"},
    180032: {"Unified_Ideograph", "Ideographic"},
    180033: {"Unified_Ideograph", "Ideographic"},
    180034: {"Unified_Ideograph", "Ideographic"},
    180035: {"Unified_Ideograph", "Ideographic"},
    180036: {"Unified_Ideograph", "Ideographic"},
    180037: {"Unified_Ideograph", "Ideographic"},
    180038: {"Unified_Ideograph", "Ideographic"},
    180039: {"Unified_Ideograph", "Ideographic"},
    180040: {"Unified_Ideograph", "Ideographic"},
    180041: {"Unified_Ideograph", "Ideographic"},
    180042: {"Unified_Ideograph", "Ideographic"},
    180043: {"Unified_Ideograph", "Ideographic"},
    180044: {"Unified_Ideograph", "Ideographic"},
    180045: {"Unified_Ideograph", "Ideographic"},
    180046: {"Unified_Ideograph", "Ideographic"},
    180047: {"Unified_Ideograph", "Ideographic"},
    180048: {"Unified_Ideograph", "Ideographic"},
    180049: {"Unified_Ideograph", "Ideographic"},
    180050: {"Unified_Ideograph", "Ideographic"},
    180051: {"Unified_Ideograph", "Ideographic"},
    180052: {"Unified_Ideograph", "Ideographic"},
    180053: {"Unified_Ideograph", "Ideographic"},
    180054: {"Unified_Ideograph", "Ideographic"},
    180055: {"Unified_Ideograph", "Ideographic"},
    180056: {"Unified_Ideograph", "Ideographic"},
    180057: {"Unified_Ideograph", "Ideographic"},
    180058: {"Unified_Ideograph", "Ideographic"},
    180059: {"Unified_Ideograph", "Ideographic"},
    180060: {"Unified_Ideograph", "Ideographic"},
    180061: {"Unified_Ideograph", "Ideographic"},
    180062: {"Unified_Ideograph", "Ideographic"},
    180063: {"Unified_Ideograph", "Ideographic"},
    180064: {"Unified_Ideograph", "Ideographic"},
    180065: {"Unified_Ideograph", "Ideographic"},
    180066: {"Unified_Ideograph", "Ideographic"},
    180067: {"Unified_Ideograph", "Ideographic"},
    180068: {"Unified_Ideograph", "Ideographic"},
    180069: {"Unified_Ideograph", "Ideographic"},
    180070: {"Unified_Ideograph", "Ideographic"},
    180071: {"Unified_Ideograph", "Ideographic"},
    180072: {"Unified_Ideograph", "Ideographic"},
    180073: {"Unified_Ideograph", "Ideographic"},
    180074: {"Unified_Ideograph", "Ideographic"},
    180075: {"Unified_Ideograph", "Ideographic"},
    180076: {"Unified_Ideograph", "Ideographic"},
    180077: {"Unified_Ideograph", "Ideographic"},
    180078: {"Unified_Ideograph", "Ideographic"},
    180079: {"Unified_Ideograph", "Ideographic"},
    180080: {"Unified_Ideograph", "Ideographic"},
    180081: {"Unified_Ideograph", "Ideographic"},
    180082: {"Unified_Ideograph", "Ideographic"},
    180083: {"Unified_Ideograph", "Ideographic"},
    180084: {"Unified_Ideograph", "Ideographic"},
    180085: {"Unified_Ideograph", "Ideographic"},
    180086: {"Unified_Ideograph", "Ideographic"},
    180087: {"Unified_Ideograph", "Ideographic"},
    180088: {"Unified_Ideograph", "Ideographic"},
    180089: {"Unified_Ideograph", "Ideographic"},
    180090: {"Unified_Ideograph", "Ideographic"},
    180091: {"Unified_Ideograph", "Ideographic"},
    180092: {"Unified_Ideograph", "Ideographic"},
    180093: {"Unified_Ideograph", "Ideographic"},
    180094: {"Unified_Ideograph", "Ideographic"},
    180095: {"Unified_Ideograph", "Ideographic"},
    180096: {"Unified_Ideograph", "Ideographic"},
    180097: {"Unified_Ideograph", "Ideographic"},
    180098: {"Unified_Ideograph", "Ideographic"},
    180099: {"Unified_Ideograph", "Ideographic"},
    180100: {"Unified_Ideograph", "Ideographic"},
    180101: {"Unified_Ideograph", "Ideographic"},
    180102: {"Unified_Ideograph", "Ideographic"},
    180103: {"Unified_Ideograph", "Ideographic"},
    180104: {"Unified_Ideograph", "Ideographic"},
    180105: {"Unified_Ideograph", "Ideographic"},
    180106: {"Unified_Ideograph", "Ideographic"},
    180107: {"Unified_Ideograph", "Ideographic"},
    180108: {"Unified_Ideograph", "Ideographic"},
    180109: {"Unified_Ideograph", "Ideographic"},
    180110: {"Unified_Ideograph", "Ideographic"},
    180111: {"Unified_Ideograph", "Ideographic"},
    180112: {"Unified_Ideograph", "Ideographic"},
    180113: {"Unified_Ideograph", "Ideographic"},
    180114: {"Unified_Ideograph", "Ideographic"},
    180115: {"Unified_Ideograph", "Ideographic"},
    180116: {"Unified_Ideograph", "Ideographic"},
    180117: {"Unified_Ideograph", "Ideographic"},
    180118: {"Unified_Ideograph", "Ideographic"},
    180119: {"Unified_Ideograph", "Ideographic"},
    180120: {"Unified_Ideograph", "Ideographic"},
    180121: {"Unified_Ideograph", "Ideographic"},
    180122: {"Unified_Ideograph", "Ideographic"},
    180123: {"Unified_Ideograph", "Ideographic"},
    180124: {"Unified_Ideograph", "Ideographic"},
    180125: {"Unified_Ideograph", "Ideographic"},
    180126: {"Unified_Ideograph", "Ideographic"},
    180127: {"Unified_Ideograph", "Ideographic"},
    180128: {"Unified_Ideograph", "Ideographic"},
    180129: {"Unified_Ideograph", "Ideographic"},
    180130: {"Unified_Ideograph", "Ideographic"},
    180131: {"Unified_Ideograph", "Ideographic"},
    180132: {"Unified_Ideograph", "Ideographic"},
    180133: {"Unified_Ideograph", "Ideographic"},
    180134: {"Unified_Ideograph", "Ideographic"},
    180135: {"Unified_Ideograph", "Ideographic"},
    180136: {"Unified_Ideograph", "Ideographic"},
    180137: {"Unified_Ideograph", "Ideographic"},
    180138: {"Unified_Ideograph", "Ideographic"},
    180139: {"Unified_Ideograph", "Ideographic"},
    180140: {"Unified_Ideograph", "Ideographic"},
    180141: {"Unified_Ideograph", "Ideographic"},
    180142: {"Unified_Ideograph", "Ideographic"},
    180143: {"Unified_Ideograph", "Ideographic"},
    180144: {"Unified_Ideograph", "Ideographic"},
    180145: {"Unified_Ideograph", "Ideographic"},
    180146: {"Unified_Ideograph", "Ideographic"},
    180147: {"Unified_Ideograph", "Ideographic"},
    180148: {"Unified_Ideograph", "Ideographic"},
    180149: {"Unified_Ideograph", "Ideographic"},
    180150: {"Unified_Ideograph", "Ideographic"},
    180151: {"Unified_Ideograph", "Ideographic"},
    180152: {"Unified_Ideograph", "Ideographic"},
    180153: {"Unified_Ideograph", "Ideographic"},
    180154: {"Unified_Ideograph", "Ideographic"},
    180155: {"Unified_Ideograph", "Ideographic"},
    180156: {"Unified_Ideograph", "Ideographic"},
    180157: {"Unified_Ideograph", "Ideographic"},
    180158: {"Unified_Ideograph", "Ideographic"},
    180159: {"Unified_Ideograph", "Ideographic"},
    180160: {"Unified_Ideograph", "Ideographic"},
    180161: {"Unified_Ideograph", "Ideographic"},
    180162: {"Unified_Ideograph", "Ideographic"},
    180163: {"Unified_Ideograph", "Ideographic"},
    180164: {"Unified_Ideograph", "Ideographic"},
    180165: {"Unified_Ideograph", "Ideographic"},
    180166: {"Unified_Ideograph", "Ideographic"},
    180167: {"Unified_Ideograph", "Ideographic"},
    180168: {"Unified_Ideograph", "Ideographic"},
    180169: {"Unified_Ideograph", "Ideographic"},
    180170: {"Unified_Ideograph", "Ideographic"},
    180171: {"Unified_Ideograph", "Ideographic"},
    180172: {"Unified_Ideograph", "Ideographic"},
    180173: {"Unified_Ideograph", "Ideographic"},
    180174: {"Unified_Ideograph", "Ideographic"},
    180175: {"Unified_Ideograph", "Ideographic"},
    180176: {"Unified_Ideograph", "Ideographic"},
    180177: {"Unified_Ideograph", "Ideographic"},
    180178: {"Unified_Ideograph", "Ideographic"},
    180179: {"Unified_Ideograph", "Ideographic"},
    180180: {"Unified_Ideograph", "Ideographic"},
    180181: {"Unified_Ideograph", "Ideographic"},
    180182: {"Unified_Ideograph", "Ideographic"},
    180183: {"Unified_Ideograph", "Ideographic"},
    180184: {"Unified_Ideograph", "Ideographic"},
    180185: {"Unified_Ideograph", "Ideographic"},
    180186: {"Unified_Ideograph", "Ideographic"},
    180187: {"Unified_Ideograph", "Ideographic"},
    180188: {"Unified_Ideograph", "Ideographic"},
    180189: {"Unified_Ideograph", "Ideographic"},
    180190: {"Unified_Ideograph", "Ideographic"},
    180191: {"Unified_Ideograph", "Ideographic"},
    180192: {"Unified_Ideograph", "Ideographic"},
    180193: {"Unified_Ideograph", "Ideographic"},
    180194: {"Unified_Ideograph", "Ideographic"},
    180195: {"Unified_Ideograph", "Ideographic"},
    180196: {"Unified_Ideograph", "Ideographic"},
    180197: {"Unified_Ideograph", "Ideographic"},
    180198: {"Unified_Ideograph", "Ideographic"},
    180199: {"Unified_Ideograph", "Ideographic"},
    180200: {"Unified_Ideograph", "Ideographic"},
    180201: {"Unified_Ideograph", "Ideographic"},
    180202: {"Unified_Ideograph", "Ideographic"},
    180203: {"Unified_Ideograph", "Ideographic"},
    180204: {"Unified_Ideograph", "Ideographic"},
    180205: {"Unified_Ideograph", "Ideographic"},
    180206: {"Unified_Ideograph", "Ideographic"},
    180207: {"Unified_Ideograph", "Ideographic"},
    180208: {"Unified_Ideograph", "Ideographic"},
    180209: {"Unified_Ideograph", "Ideographic"},
    180210: {"Unified_Ideograph", "Ideographic"},
    180211: {"Unified_Ideograph", "Ideographic"},
    180212: {"Unified_Ideograph", "Ideographic"},
    180213: {"Unified_Ideograph", "Ideographic"},
    180214: {"Unified_Ideograph", "Ideographic"},
    180215: {"Unified_Ideograph", "Ideographic"},
    180216: {"Unified_Ideograph", "Ideographic"},
    180217: {"Unified_Ideograph", "Ideographic"},
    180218: {"Unified_Ideograph", "Ideographic"},
    180219: {"Unified_Ideograph", "Ideographic"},
    180220: {"Unified_Ideograph", "Ideographic"},
    180221: {"Unified_Ideograph", "Ideographic"},
    180222: {"Unified_Ideograph", "Ideographic"},
    180223: {"Unified_Ideograph", "Ideographic"},
    180224: {"Unified_Ideograph", "Ideographic"},
    180225: {"Unified_Ideograph", "Ideographic"},
    180226: {"Unified_Ideograph", "Ideographic"},
    180227: {"Unified_Ideograph", "Ideographic"},
    180228: {"Unified_Ideograph", "Ideographic"},
    180229: {"Unified_Ideograph", "Ideographic"},
    180230: {"Unified_Ideograph", "Ideographic"},
    180231: {"Unified_Ideograph", "Ideographic"},
    180232: {"Unified_Ideograph", "Ideographic"},
    180233: {"Unified_Ideograph", "Ideographic"},
    180234: {"Unified_Ideograph", "Ideographic"},
    180235: {"Unified_Ideograph", "Ideographic"},
    180236: {"Unified_Ideograph", "Ideographic"},
    180237: {"Unified_Ideograph", "Ideographic"},
    180238: {"Unified_Ideograph", "Ideographic"},
    180239: {"Unified_Ideograph", "Ideographic"},
    180240: {"Unified_Ideograph", "Ideographic"},
    180241: {"Unified_Ideograph", "Ideographic"},
    180242: {"Unified_Ideograph", "Ideographic"},
    180243: {"Unified_Ideograph", "Ideographic"},
    180244: {"Unified_Ideograph", "Ideographic"},
    180245: {"Unified_Ideograph", "Ideographic"},
    180246: {"Unified_Ideograph", "Ideographic"},
    180247: {"Unified_Ideograph", "Ideographic"},
    180248: {"Unified_Ideograph", "Ideographic"},
    180249: {"Unified_Ideograph", "Ideographic"},
    180250: {"Unified_Ideograph", "Ideographic"},
    180251: {"Unified_Ideograph", "Ideographic"},
    180252: {"Unified_Ideograph", "Ideographic"},
    180253: {"Unified_Ideograph", "Ideographic"},
    180254: {"Unified_Ideograph", "Ideographic"},
    180255: {"Unified_Ideograph", "Ideographic"},
    180256: {"Unified_Ideograph", "Ideographic"},
    180257: {"Unified_Ideograph", "Ideographic"},
    180258: {"Unified_Ideograph", "Ideographic"},
    180259: {"Unified_Ideograph", "Ideographic"},
    180260: {"Unified_Ideograph", "Ideographic"},
    180261: {"Unified_Ideograph", "Ideographic"},
    180262: {"Unified_Ideograph", "Ideographic"},
    180263: {"Unified_Ideograph", "Ideographic"},
    180264: {"Unified_Ideograph", "Ideographic"},
    180265: {"Unified_Ideograph", "Ideographic"},
    180266: {"Unified_Ideograph", "Ideographic"},
    180267: {"Unified_Ideograph", "Ideographic"},
    180268: {"Unified_Ideograph", "Ideographic"},
    180269: {"Unified_Ideograph", "Ideographic"},
    180270: {"Unified_Ideograph", "Ideographic"},
    180271: {"Unified_Ideograph", "Ideographic"},
    180272: {"Unified_Ideograph", "Ideographic"},
    180273: {"Unified_Ideograph", "Ideographic"},
    180274: {"Unified_Ideograph", "Ideographic"},
    180275: {"Unified_Ideograph", "Ideographic"},
    180276: {"Unified_Ideograph", "Ideographic"},
    180277: {"Unified_Ideograph", "Ideographic"},
    180278: {"Unified_Ideograph", "Ideographic"},
    180279: {"Unified_Ideograph", "Ideographic"},
    180280: {"Unified_Ideograph", "Ideographic"},
    180281: {"Unified_Ideograph", "Ideographic"},
    180282: {"Unified_Ideograph", "Ideographic"},
    180283: {"Unified_Ideograph", "Ideographic"},
    180284: {"Unified_Ideograph", "Ideographic"},
    180285: {"Unified_Ideograph", "Ideographic"},
    180286: {"Unified_Ideograph", "Ideographic"},
    180287: {"Unified_Ideograph", "Ideographic"},
    180288: {"Unified_Ideograph", "Ideographic"},
    180289: {"Unified_Ideograph", "Ideographic"},
    180290: {"Unified_Ideograph", "Ideographic"},
    180291: {"Unified_Ideograph", "Ideographic"},
    180292: {"Unified_Ideograph", "Ideographic"},
    180293: {"Unified_Ideograph", "Ideographic"},
    180294: {"Unified_Ideograph", "Ideographic"},
    180295: {"Unified_Ideograph", "Ideographic"},
    180296: {"Unified_Ideograph", "Ideographic"},
    180297: {"Unified_Ideograph", "Ideographic"},
    180298: {"Unified_Ideograph", "Ideographic"},
    180299: {"Unified_Ideograph", "Ideographic"},
    180300: {"Unified_Ideograph", "Ideographic"},
    180301: {"Unified_Ideograph", "Ideographic"},
    180302: {"Unified_Ideograph", "Ideographic"},
    180303: {"Unified_Ideograph", "Ideographic"},
    180304: {"Unified_Ideograph", "Ideographic"},
    180305: {"Unified_Ideograph", "Ideographic"},
    180306: {"Unified_Ideograph", "Ideographic"},
    180307: {"Unified_Ideograph", "Ideographic"},
    180308: {"Unified_Ideograph", "Ideographic"},
    180309: {"Unified_Ideograph", "Ideographic"},
    180310: {"Unified_Ideograph", "Ideographic"},
    180311: {"Unified_Ideograph", "Ideographic"},
    180312: {"Unified_Ideograph", "Ideographic"},
    180313: {"Unified_Ideograph", "Ideographic"},
    180314: {"Unified_Ideograph", "Ideographic"},
    180315: {"Unified_Ideograph", "Ideographic"},
    180316: {"Unified_Ideograph", "Ideographic"},
    180317: {"Unified_Ideograph", "Ideographic"},
    180318: {"Unified_Ideograph", "Ideographic"},
    180319: {"Unified_Ideograph", "Ideographic"},
    180320: {"Unified_Ideograph", "Ideographic"},
    180321: {"Unified_Ideograph", "Ideographic"},
    180322: {"Unified_Ideograph", "Ideographic"},
    180323: {"Unified_Ideograph", "Ideographic"},
    180324: {"Unified_Ideograph", "Ideographic"},
    180325: {"Unified_Ideograph", "Ideographic"},
    180326: {"Unified_Ideograph", "Ideographic"},
    180327: {"Unified_Ideograph", "Ideographic"},
    180328: {"Unified_Ideograph", "Ideographic"},
    180329: {"Unified_Ideograph", "Ideographic"},
    180330: {"Unified_Ideograph", "Ideographic"},
    180331: {"Unified_Ideograph", "Ideographic"},
    180332: {"Unified_Ideograph", "Ideographic"},
    180333: {"Unified_Ideograph", "Ideographic"},
    180334: {"Unified_Ideograph", "Ideographic"},
    180335: {"Unified_Ideograph", "Ideographic"},
    180336: {"Unified_Ideograph", "Ideographic"},
    180337: {"Unified_Ideograph", "Ideographic"},
    180338: {"Unified_Ideograph", "Ideographic"},
    180339: {"Unified_Ideograph", "Ideographic"},
    180340: {"Unified_Ideograph", "Ideographic"},
    180341: {"Unified_Ideograph", "Ideographic"},
    180342: {"Unified_Ideograph", "Ideographic"},
    180343: {"Unified_Ideograph", "Ideographic"},
    180344: {"Unified_Ideograph", "Ideographic"},
    180345: {"Unified_Ideograph", "Ideographic"},
    180346: {"Unified_Ideograph", "Ideographic"},
    180347: {"Unified_Ideograph", "Ideographic"},
    180348: {"Unified_Ideograph", "Ideographic"},
    180349: {"Unified_Ideograph", "Ideographic"},
    180350: {"Unified_Ideograph", "Ideographic"},
    180351: {"Unified_Ideograph", "Ideographic"},
    180352: {"Unified_Ideograph", "Ideographic"},
    180353: {"Unified_Ideograph", "Ideographic"},
    180354: {"Unified_Ideograph", "Ideographic"},
    180355: {"Unified_Ideograph", "Ideographic"},
    180356: {"Unified_Ideograph", "Ideographic"},
    180357: {"Unified_Ideograph", "Ideographic"},
    180358: {"Unified_Ideograph", "Ideographic"},
    180359: {"Unified_Ideograph", "Ideographic"},
    180360: {"Unified_Ideograph", "Ideographic"},
    180361: {"Unified_Ideograph", "Ideographic"},
    180362: {"Unified_Ideograph", "Ideographic"},
    180363: {"Unified_Ideograph", "Ideographic"},
    180364: {"Unified_Ideograph", "Ideographic"},
    180365: {"Unified_Ideograph", "Ideographic"},
    180366: {"Unified_Ideograph", "Ideographic"},
    180367: {"Unified_Ideograph", "Ideographic"},
    180368: {"Unified_Ideograph", "Ideographic"},
    180369: {"Unified_Ideograph", "Ideographic"},
    180370: {"Unified_Ideograph", "Ideographic"},
    180371: {"Unified_Ideograph", "Ideographic"},
    180372: {"Unified_Ideograph", "Ideographic"},
    180373: {"Unified_Ideograph", "Ideographic"},
    180374: {"Unified_Ideograph", "Ideographic"},
    180375: {"Unified_Ideograph", "Ideographic"},
    180376: {"Unified_Ideograph", "Ideographic"},
    180377: {"Unified_Ideograph", "Ideographic"},
    180378: {"Unified_Ideograph", "Ideographic"},
    180379: {"Unified_Ideograph", "Ideographic"},
    180380: {"Unified_Ideograph", "Ideographic"},
    180381: {"Unified_Ideograph", "Ideographic"},
    180382: {"Unified_Ideograph", "Ideographic"},
    180383: {"Unified_Ideograph", "Ideographic"},
    180384: {"Unified_Ideograph", "Ideographic"},
    180385: {"Unified_Ideograph", "Ideographic"},
    180386: {"Unified_Ideograph", "Ideographic"},
    180387: {"Unified_Ideograph", "Ideographic"},
    180388: {"Unified_Ideograph", "Ideographic"},
    180389: {"Unified_Ideograph", "Ideographic"},
    180390: {"Unified_Ideograph", "Ideographic"},
    180391: {"Unified_Ideograph", "Ideographic"},
    180392: {"Unified_Ideograph", "Ideographic"},
    180393: {"Unified_Ideograph", "Ideographic"},
    180394: {"Unified_Ideograph", "Ideographic"},
    180395: {"Unified_Ideograph", "Ideographic"},
    180396: {"Unified_Ideograph", "Ideographic"},
    180397: {"Unified_Ideograph", "Ideographic"},
    180398: {"Unified_Ideograph", "Ideographic"},
    180399: {"Unified_Ideograph", "Ideographic"},
    180400: {"Unified_Ideograph", "Ideographic"},
    180401: {"Unified_Ideograph", "Ideographic"},
    180402: {"Unified_Ideograph", "Ideographic"},
    180403: {"Unified_Ideograph", "Ideographic"},
    180404: {"Unified_Ideograph", "Ideographic"},
    180405: {"Unified_Ideograph", "Ideographic"},
    180406: {"Unified_Ideograph", "Ideographic"},
    180407: {"Unified_Ideograph", "Ideographic"},
    180408: {"Unified_Ideograph", "Ideographic"},
    180409: {"Unified_Ideograph", "Ideographic"},
    180410: {"Unified_Ideograph", "Ideographic"},
    180411: {"Unified_Ideograph", "Ideographic"},
    180412: {"Unified_Ideograph", "Ideographic"},
    180413: {"Unified_Ideograph", "Ideographic"},
    180414: {"Unified_Ideograph", "Ideographic"},
    180415: {"Unified_Ideograph", "Ideographic"},
    180416: {"Unified_Ideograph", "Ideographic"},
    180417: {"Unified_Ideograph", "Ideographic"},
    180418: {"Unified_Ideograph", "Ideographic"},
    180419: {"Unified_Ideograph", "Ideographic"},
    180420: {"Unified_Ideograph", "Ideographic"},
    180421: {"Unified_Ideograph", "Ideographic"},
    180422: {"Unified_Ideograph", "Ideographic"},
    180423: {"Unified_Ideograph", "Ideographic"},
    180424: {"Unified_Ideograph", "Ideographic"},
    180425: {"Unified_Ideograph", "Ideographic"},
    180426: {"Unified_Ideograph", "Ideographic"},
    180427: {"Unified_Ideograph", "Ideographic"},
    180428: {"Unified_Ideograph", "Ideographic"},
    180429: {"Unified_Ideograph", "Ideographic"},
    180430: {"Unified_Ideograph", "Ideographic"},
    180431: {"Unified_Ideograph", "Ideographic"},
    180432: {"Unified_Ideograph", "Ideographic"},
    180433: {"Unified_Ideograph", "Ideographic"},
    180434: {"Unified_Ideograph", "Ideographic"},
    180435: {"Unified_Ideograph", "Ideographic"},
    180436: {"Unified_Ideograph", "Ideographic"},
    180437: {"Unified_Ideograph", "Ideographic"},
    180438: {"Unified_Ideograph", "Ideographic"},
    180439: {"Unified_Ideograph", "Ideographic"},
    180440: {"Unified_Ideograph", "Ideographic"},
    180441: {"Unified_Ideograph", "Ideographic"},
    180442: {"Unified_Ideograph", "Ideographic"},
    180443: {"Unified_Ideograph", "Ideographic"},
    180444: {"Unified_Ideograph", "Ideographic"},
    180445: {"Unified_Ideograph", "Ideographic"},
    180446: {"Unified_Ideograph", "Ideographic"},
    180447: {"Unified_Ideograph", "Ideographic"},
    180448: {"Unified_Ideograph", "Ideographic"},
    180449: {"Unified_Ideograph", "Ideographic"},
    180450: {"Unified_Ideograph", "Ideographic"},
    180451: {"Unified_Ideograph", "Ideographic"},
    180452: {"Unified_Ideograph", "Ideographic"},
    180453: {"Unified_Ideograph", "Ideographic"},
    180454: {"Unified_Ideograph", "Ideographic"},
    180455: {"Unified_Ideograph", "Ideographic"},
    180456: {"Unified_Ideograph", "Ideographic"},
    180457: {"Unified_Ideograph", "Ideographic"},
    180458: {"Unified_Ideograph", "Ideographic"},
    180459: {"Unified_Ideograph", "Ideographic"},
    180460: {"Unified_Ideograph", "Ideographic"},
    180461: {"Unified_Ideograph", "Ideographic"},
    180462: {"Unified_Ideograph", "Ideographic"},
    180463: {"Unified_Ideograph", "Ideographic"},
    180464: {"Unified_Ideograph", "Ideographic"},
    180465: {"Unified_Ideograph", "Ideographic"},
    180466: {"Unified_Ideograph", "Ideographic"},
    180467: {"Unified_Ideograph", "Ideographic"},
    180468: {"Unified_Ideograph", "Ideographic"},
    180469: {"Unified_Ideograph", "Ideographic"},
    180470: {"Unified_Ideograph", "Ideographic"},
    180471: {"Unified_Ideograph", "Ideographic"},
    180472: {"Unified_Ideograph", "Ideographic"},
    180473: {"Unified_Ideograph", "Ideographic"},
    180474: {"Unified_Ideograph", "Ideographic"},
    180475: {"Unified_Ideograph", "Ideographic"},
    180476: {"Unified_Ideograph", "Ideographic"},
    180477: {"Unified_Ideograph", "Ideographic"},
    180478: {"Unified_Ideograph", "Ideographic"},
    180479: {"Unified_Ideograph", "Ideographic"},
    180480: {"Unified_Ideograph", "Ideographic"},
    180481: {"Unified_Ideograph", "Ideographic"},
    180482: {"Unified_Ideograph", "Ideographic"},
    180483: {"Unified_Ideograph", "Ideographic"},
    180484: {"Unified_Ideograph", "Ideographic"},
    180485: {"Unified_Ideograph", "Ideographic"},
    180486: {"Unified_Ideograph", "Ideographic"},
    180487: {"Unified_Ideograph", "Ideographic"},
    180488: {"Unified_Ideograph", "Ideographic"},
    180489: {"Unified_Ideograph", "Ideographic"},
    180490: {"Unified_Ideograph", "Ideographic"},
    180491: {"Unified_Ideograph", "Ideographic"},
    180492: {"Unified_Ideograph", "Ideographic"},
    180493: {"Unified_Ideograph", "Ideographic"},
    180494: {"Unified_Ideograph", "Ideographic"},
    180495: {"Unified_Ideograph", "Ideographic"},
    180496: {"Unified_Ideograph", "Ideographic"},
    180497: {"Unified_Ideograph", "Ideographic"},
    180498: {"Unified_Ideograph", "Ideographic"},
    180499: {"Unified_Ideograph", "Ideographic"},
    180500: {"Unified_Ideograph", "Ideographic"},
    180501: {"Unified_Ideograph", "Ideographic"},
    180502: {"Unified_Ideograph", "Ideographic"},
    180503: {"Unified_Ideograph", "Ideographic"},
    180504: {"Unified_Ideograph", "Ideographic"},
    180505: {"Unified_Ideograph", "Ideographic"},
    180506: {"Unified_Ideograph", "Ideographic"},
    180507: {"Unified_Ideograph", "Ideographic"},
    180508: {"Unified_Ideograph", "Ideographic"},
    180509: {"Unified_Ideograph", "Ideographic"},
    180510: {"Unified_Ideograph", "Ideographic"},
    180511: {"Unified_Ideograph", "Ideographic"},
    180512: {"Unified_Ideograph", "Ideographic"},
    180513: {"Unified_Ideograph", "Ideographic"},
    180514: {"Unified_Ideograph", "Ideographic"},
    180515: {"Unified_Ideograph", "Ideographic"},
    180516: {"Unified_Ideograph", "Ideographic"},
    180517: {"Unified_Ideograph", "Ideographic"},
    180518: {"Unified_Ideograph", "Ideographic"},
    180519: {"Unified_Ideograph", "Ideographic"},
    180520: {"Unified_Ideograph", "Ideographic"},
    180521: {"Unified_Ideograph", "Ideographic"},
    180522: {"Unified_Ideograph", "Ideographic"},
    180523: {"Unified_Ideograph", "Ideographic"},
    180524: {"Unified_Ideograph", "Ideographic"},
    180525: {"Unified_Ideograph", "Ideographic"},
    180526: {"Unified_Ideograph", "Ideographic"},
    180527: {"Unified_Ideograph", "Ideographic"},
    180528: {"Unified_Ideograph", "Ideographic"},
    180529: {"Unified_Ideograph", "Ideographic"},
    180530: {"Unified_Ideograph", "Ideographic"},
    180531: {"Unified_Ideograph", "Ideographic"},
    180532: {"Unified_Ideograph", "Ideographic"},
    180533: {"Unified_Ideograph", "Ideographic"},
    180534: {"Unified_Ideograph", "Ideographic"},
    180535: {"Unified_Ideograph", "Ideographic"},
    180536: {"Unified_Ideograph", "Ideographic"},
    180537: {"Unified_Ideograph", "Ideographic"},
    180538: {"Unified_Ideograph", "Ideographic"},
    180539: {"Unified_Ideograph", "Ideographic"},
    180540: {"Unified_Ideograph", "Ideographic"},
    180541: {"Unified_Ideograph", "Ideographic"},
    180542: {"Unified_Ideograph", "Ideographic"},
    180543: {"Unified_Ideograph", "Ideographic"},
    180544: {"Unified_Ideograph", "Ideographic"},
    180545: {"Unified_Ideograph", "Ideographic"},
    180546: {"Unified_Ideograph", "Ideographic"},
    180547: {"Unified_Ideograph", "Ideographic"},
    180548: {"Unified_Ideograph", "Ideographic"},
    180549: {"Unified_Ideograph", "Ideographic"},
    180550: {"Unified_Ideograph", "Ideographic"},
    180551: {"Unified_Ideograph", "Ideographic"},
    180552: {"Unified_Ideograph", "Ideographic"},
    180553: {"Unified_Ideograph", "Ideographic"},
    180554: {"Unified_Ideograph", "Ideographic"},
    180555: {"Unified_Ideograph", "Ideographic"},
    180556: {"Unified_Ideograph", "Ideographic"},
    180557: {"Unified_Ideograph", "Ideographic"},
    180558: {"Unified_Ideograph", "Ideographic"},
    180559: {"Unified_Ideograph", "Ideographic"},
    180560: {"Unified_Ideograph", "Ideographic"},
    180561: {"Unified_Ideograph", "Ideographic"},
    180562: {"Unified_Ideograph", "Ideographic"},
    180563: {"Unified_Ideograph", "Ideographic"},
    180564: {"Unified_Ideograph", "Ideographic"},
    180565: {"Unified_Ideograph", "Ideographic"},
    180566: {"Unified_Ideograph", "Ideographic"},
    180567: {"Unified_Ideograph", "Ideographic"},
    180568: {"Unified_Ideograph", "Ideographic"},
    180569: {"Unified_Ideograph", "Ideographic"},
    180570: {"Unified_Ideograph", "Ideographic"},
    180571: {"Unified_Ideograph", "Ideographic"},
    180572: {"Unified_Ideograph", "Ideographic"},
    180573: {"Unified_Ideograph", "Ideographic"},
    180574: {"Unified_Ideograph", "Ideographic"},
    180575: {"Unified_Ideograph", "Ideographic"},
    180576: {"Unified_Ideograph", "Ideographic"},
    180577: {"Unified_Ideograph", "Ideographic"},
    180578: {"Unified_Ideograph", "Ideographic"},
    180579: {"Unified_Ideograph", "Ideographic"},
    180580: {"Unified_Ideograph", "Ideographic"},
    180581: {"Unified_Ideograph", "Ideographic"},
    180582: {"Unified_Ideograph", "Ideographic"},
    180583: {"Unified_Ideograph", "Ideographic"},
    180584: {"Unified_Ideograph", "Ideographic"},
    180585: {"Unified_Ideograph", "Ideographic"},
    180586: {"Unified_Ideograph", "Ideographic"},
    180587: {"Unified_Ideograph", "Ideographic"},
    180588: {"Unified_Ideograph", "Ideographic"},
    180589: {"Unified_Ideograph", "Ideographic"},
    180590: {"Unified_Ideograph", "Ideographic"},
    180591: {"Unified_Ideograph", "Ideographic"},
    180592: {"Unified_Ideograph", "Ideographic"},
    180593: {"Unified_Ideograph", "Ideographic"},
    180594: {"Unified_Ideograph", "Ideographic"},
    180595: {"Unified_Ideograph", "Ideographic"},
    180596: {"Unified_Ideograph", "Ideographic"},
    180597: {"Unified_Ideograph", "Ideographic"},
    180598: {"Unified_Ideograph", "Ideographic"},
    180599: {"Unified_Ideograph", "Ideographic"},
    180600: {"Unified_Ideograph", "Ideographic"},
    180601: {"Unified_Ideograph", "Ideographic"},
    180602: {"Unified_Ideograph", "Ideographic"},
    180603: {"Unified_Ideograph", "Ideographic"},
    180604: {"Unified_Ideograph", "Ideographic"},
    180605: {"Unified_Ideograph", "Ideographic"},
    180606: {"Unified_Ideograph", "Ideographic"},
    180607: {"Unified_Ideograph", "Ideographic"},
    180608: {"Unified_Ideograph", "Ideographic"},
    180609: {"Unified_Ideograph", "Ideographic"},
    180610: {"Unified_Ideograph", "Ideographic"},
    180611: {"Unified_Ideograph", "Ideographic"},
    180612: {"Unified_Ideograph", "Ideographic"},
    180613: {"Unified_Ideograph", "Ideographic"},
    180614: {"Unified_Ideograph", "Ideographic"},
    180615: {"Unified_Ideograph", "Ideographic"},
    180616: {"Unified_Ideograph", "Ideographic"},
    180617: {"Unified_Ideograph", "Ideographic"},
    180618: {"Unified_Ideograph", "Ideographic"},
    180619: {"Unified_Ideograph", "Ideographic"},
    180620: {"Unified_Ideograph", "Ideographic"},
    180621: {"Unified_Ideograph", "Ideographic"},
    180622: {"Unified_Ideograph", "Ideographic"},
    180623: {"Unified_Ideograph", "Ideographic"},
    180624: {"Unified_Ideograph", "Ideographic"},
    180625: {"Unified_Ideograph", "Ideographic"},
    180626: {"Unified_Ideograph", "Ideographic"},
    180627: {"Unified_Ideograph", "Ideographic"},
    180628: {"Unified_Ideograph", "Ideographic"},
    180629: {"Unified_Ideograph", "Ideographic"},
    180630: {"Unified_Ideograph", "Ideographic"},
    180631: {"Unified_Ideograph", "Ideographic"},
    180632: {"Unified_Ideograph", "Ideographic"},
    180633: {"Unified_Ideograph", "Ideographic"},
    180634: {"Unified_Ideograph", "Ideographic"},
    180635: {"Unified_Ideograph", "Ideographic"},
    180636: {"Unified_Ideograph", "Ideographic"},
    180637: {"Unified_Ideograph", "Ideographic"},
    180638: {"Unified_Ideograph", "Ideographic"},
    180639: {"Unified_Ideograph", "Ideographic"},
    180640: {"Unified_Ideograph", "Ideographic"},
    180641: {"Unified_Ideograph", "Ideographic"},
    180642: {"Unified_Ideograph", "Ideographic"},
    180643: {"Unified_Ideograph", "Ideographic"},
    180644: {"Unified_Ideograph", "Ideographic"},
    180645: {"Unified_Ideograph", "Ideographic"},
    180646: {"Unified_Ideograph", "Ideographic"},
    180647: {"Unified_Ideograph", "Ideographic"},
    180648: {"Unified_Ideograph", "Ideographic"},
    180649: {"Unified_Ideograph", "Ideographic"},
    180650: {"Unified_Ideograph", "Ideographic"},
    180651: {"Unified_Ideograph", "Ideographic"},
    180652: {"Unified_Ideograph", "Ideographic"},
    180653: {"Unified_Ideograph", "Ideographic"},
    180654: {"Unified_Ideograph", "Ideographic"},
    180655: {"Unified_Ideograph", "Ideographic"},
    180656: {"Unified_Ideograph", "Ideographic"},
    180657: {"Unified_Ideograph", "Ideographic"},
    180658: {"Unified_Ideograph", "Ideographic"},
    180659: {"Unified_Ideograph", "Ideographic"},
    180660: {"Unified_Ideograph", "Ideographic"},
    180661: {"Unified_Ideograph", "Ideographic"},
    180662: {"Unified_Ideograph", "Ideographic"},
    180663: {"Unified_Ideograph", "Ideographic"},
    180664: {"Unified_Ideograph", "Ideographic"},
    180665: {"Unified_Ideograph", "Ideographic"},
    180666: {"Unified_Ideograph", "Ideographic"},
    180667: {"Unified_Ideograph", "Ideographic"},
    180668: {"Unified_Ideograph", "Ideographic"},
    180669: {"Unified_Ideograph", "Ideographic"},
    180670: {"Unified_Ideograph", "Ideographic"},
    180671: {"Unified_Ideograph", "Ideographic"},
    180672: {"Unified_Ideograph", "Ideographic"},
    180673: {"Unified_Ideograph", "Ideographic"},
    180674: {"Unified_Ideograph", "Ideographic"},
    180675: {"Unified_Ideograph", "Ideographic"},
    180676: {"Unified_Ideograph", "Ideographic"},
    180677: {"Unified_Ideograph", "Ideographic"},
    180678: {"Unified_Ideograph", "Ideographic"},
    180679: {"Unified_Ideograph", "Ideographic"},
    180680: {"Unified_Ideograph", "Ideographic"},
    180681: {"Unified_Ideograph", "Ideographic"},
    180682: {"Unified_Ideograph", "Ideographic"},
    180683: {"Unified_Ideograph", "Ideographic"},
    180684: {"Unified_Ideograph", "Ideographic"},
    180685: {"Unified_Ideograph", "Ideographic"},
    180686: {"Unified_Ideograph", "Ideographic"},
    180687: {"Unified_Ideograph", "Ideographic"},
    180688: {"Unified_Ideograph", "Ideographic"},
    180689: {"Unified_Ideograph", "Ideographic"},
    180690: {"Unified_Ideograph", "Ideographic"},
    180691: {"Unified_Ideograph", "Ideographic"},
    180692: {"Unified_Ideograph", "Ideographic"},
    180693: {"Unified_Ideograph", "Ideographic"},
    180694: {"Unified_Ideograph", "Ideographic"},
    180695: {"Unified_Ideograph", "Ideographic"},
    180696: {"Unified_Ideograph", "Ideographic"},
    180697: {"Unified_Ideograph", "Ideographic"},
    180698: {"Unified_Ideograph", "Ideographic"},
    180699: {"Unified_Ideograph", "Ideographic"},
    180700: {"Unified_Ideograph", "Ideographic"},
    180701: {"Unified_Ideograph", "Ideographic"},
    180702: {"Unified_Ideograph", "Ideographic"},
    180703: {"Unified_Ideograph", "Ideographic"},
    180704: {"Unified_Ideograph", "Ideographic"},
    180705: {"Unified_Ideograph", "Ideographic"},
    180706: {"Unified_Ideograph", "Ideographic"},
    180707: {"Unified_Ideograph", "Ideographic"},
    180708: {"Unified_Ideograph", "Ideographic"},
    180709: {"Unified_Ideograph", "Ideographic"},
    180710: {"Unified_Ideograph", "Ideographic"},
    180711: {"Unified_Ideograph", "Ideographic"},
    180712: {"Unified_Ideograph", "Ideographic"},
    180713: {"Unified_Ideograph", "Ideographic"},
    180714: {"Unified_Ideograph", "Ideographic"},
    180715: {"Unified_Ideograph", "Ideographic"},
    180716: {"Unified_Ideograph", "Ideographic"},
    180717: {"Unified_Ideograph", "Ideographic"},
    180718: {"Unified_Ideograph", "Ideographic"},
    180719: {"Unified_Ideograph", "Ideographic"},
    180720: {"Unified_Ideograph", "Ideographic"},
    180721: {"Unified_Ideograph", "Ideographic"},
    180722: {"Unified_Ideograph", "Ideographic"},
    180723: {"Unified_Ideograph", "Ideographic"},
    180724: {"Unified_Ideograph", "Ideographic"},
    180725: {"Unified_Ideograph", "Ideographic"},
    180726: {"Unified_Ideograph", "Ideographic"},
    180727: {"Unified_Ideograph", "Ideographic"},
    180728: {"Unified_Ideograph", "Ideographic"},
    180729: {"Unified_Ideograph", "Ideographic"},
    180730: {"Unified_Ideograph", "Ideographic"},
    180731: {"Unified_Ideograph", "Ideographic"},
    180732: {"Unified_Ideograph", "Ideographic"},
    180733: {"Unified_Ideograph", "Ideographic"},
    180734: {"Unified_Ideograph", "Ideographic"},
    180735: {"Unified_Ideograph", "Ideographic"},
    180736: {"Unified_Ideograph", "Ideographic"},
    180737: {"Unified_Ideograph", "Ideographic"},
    180738: {"Unified_Ideograph", "Ideographic"},
    180739: {"Unified_Ideograph", "Ideographic"},
    180740: {"Unified_Ideograph", "Ideographic"},
    180741: {"Unified_Ideograph", "Ideographic"},
    180742: {"Unified_Ideograph", "Ideographic"},
    180743: {"Unified_Ideograph", "Ideographic"},
    180744: {"Unified_Ideograph", "Ideographic"},
    180745: {"Unified_Ideograph", "Ideographic"},
    180746: {"Unified_Ideograph", "Ideographic"},
    180747: {"Unified_Ideograph", "Ideographic"},
    180748: {"Unified_Ideograph", "Ideographic"},
    180749: {"Unified_Ideograph", "Ideographic"},
    180750: {"Unified_Ideograph", "Ideographic"},
    180751: {"Unified_Ideograph", "Ideographic"},
    180752: {"Unified_Ideograph", "Ideographic"},
    180753: {"Unified_Ideograph", "Ideographic"},
    180754: {"Unified_Ideograph", "Ideographic"},
    180755: {"Unified_Ideograph", "Ideographic"},
    180756: {"Unified_Ideograph", "Ideographic"},
    180757: {"Unified_Ideograph", "Ideographic"},
    180758: {"Unified_Ideograph", "Ideographic"},
    180759: {"Unified_Ideograph", "Ideographic"},
    180760: {"Unified_Ideograph", "Ideographic"},
    180761: {"Unified_Ideograph", "Ideographic"},
    180762: {"Unified_Ideograph", "Ideographic"},
    180763: {"Unified_Ideograph", "Ideographic"},
    180764: {"Unified_Ideograph", "Ideographic"},
    180765: {"Unified_Ideograph", "Ideographic"},
    180766: {"Unified_Ideograph", "Ideographic"},
    180767: {"Unified_Ideograph", "Ideographic"},
    180768: {"Unified_Ideograph", "Ideographic"},
    180769: {"Unified_Ideograph", "Ideographic"},
    180770: {"Unified_Ideograph", "Ideographic"},
    180771: {"Unified_Ideograph", "Ideographic"},
    180772: {"Unified_Ideograph", "Ideographic"},
    180773: {"Unified_Ideograph", "Ideographic"},
    180774: {"Unified_Ideograph", "Ideographic"},
    180775: {"Unified_Ideograph", "Ideographic"},
    180776: {"Unified_Ideograph", "Ideographic"},
    180777: {"Unified_Ideograph", "Ideographic"},
    180778: {"Unified_Ideograph", "Ideographic"},
    180779: {"Unified_Ideograph", "Ideographic"},
    180780: {"Unified_Ideograph", "Ideographic"},
    180781: {"Unified_Ideograph", "Ideographic"},
    180782: {"Unified_Ideograph", "Ideographic"},
    180783: {"Unified_Ideograph", "Ideographic"},
    180784: {"Unified_Ideograph", "Ideographic"},
    180785: {"Unified_Ideograph", "Ideographic"},
    180786: {"Unified_Ideograph", "Ideographic"},
    180787: {"Unified_Ideograph", "Ideographic"},
    180788: {"Unified_Ideograph", "Ideographic"},
    180789: {"Unified_Ideograph", "Ideographic"},
    180790: {"Unified_Ideograph", "Ideographic"},
    180791: {"Unified_Ideograph", "Ideographic"},
    180792: {"Unified_Ideograph", "Ideographic"},
    180793: {"Unified_Ideograph", "Ideographic"},
    180794: {"Unified_Ideograph", "Ideographic"},
    180795: {"Unified_Ideograph", "Ideographic"},
    180796: {"Unified_Ideograph", "Ideographic"},
    180797: {"Unified_Ideograph", "Ideographic"},
    180798: {"Unified_Ideograph", "Ideographic"},
    180799: {"Unified_Ideograph", "Ideographic"},
    180800: {"Unified_Ideograph", "Ideographic"},
    180801: {"Unified_Ideograph", "Ideographic"},
    180802: {"Unified_Ideograph", "Ideographic"},
    180803: {"Unified_Ideograph", "Ideographic"},
    180804: {"Unified_Ideograph", "Ideographic"},
    180805: {"Unified_Ideograph", "Ideographic"},
    180806: {"Unified_Ideograph", "Ideographic"},
    180807: {"Unified_Ideograph", "Ideographic"},
    180808: {"Unified_Ideograph", "Ideographic"},
    180809: {"Unified_Ideograph", "Ideographic"},
    180810: {"Unified_Ideograph", "Ideographic"},
    180811: {"Unified_Ideograph", "Ideographic"},
    180812: {"Unified_Ideograph", "Ideographic"},
    180813: {"Unified_Ideograph", "Ideographic"},
    180814: {"Unified_Ideograph", "Ideographic"},
    180815: {"Unified_Ideograph", "Ideographic"},
    180816: {"Unified_Ideograph", "Ideographic"},
    180817: {"Unified_Ideograph", "Ideographic"},
    180818: {"Unified_Ideograph", "Ideographic"},
    180819: {"Unified_Ideograph", "Ideographic"},
    180820: {"Unified_Ideograph", "Ideographic"},
    180821: {"Unified_Ideograph", "Ideographic"},
    180822: {"Unified_Ideograph", "Ideographic"},
    180823: {"Unified_Ideograph", "Ideographic"},
    180824: {"Unified_Ideograph", "Ideographic"},
    180825: {"Unified_Ideograph", "Ideographic"},
    180826: {"Unified_Ideograph", "Ideographic"},
    180827: {"Unified_Ideograph", "Ideographic"},
    180828: {"Unified_Ideograph", "Ideographic"},
    180829: {"Unified_Ideograph", "Ideographic"},
    180830: {"Unified_Ideograph", "Ideographic"},
    180831: {"Unified_Ideograph", "Ideographic"},
    180832: {"Unified_Ideograph", "Ideographic"},
    180833: {"Unified_Ideograph", "Ideographic"},
    180834: {"Unified_Ideograph", "Ideographic"},
    180835: {"Unified_Ideograph", "Ideographic"},
    180836: {"Unified_Ideograph", "Ideographic"},
    180837: {"Unified_Ideograph", "Ideographic"},
    180838: {"Unified_Ideograph", "Ideographic"},
    180839: {"Unified_Ideograph", "Ideographic"},
    180840: {"Unified_Ideograph", "Ideographic"},
    180841: {"Unified_Ideograph", "Ideographic"},
    180842: {"Unified_Ideograph", "Ideographic"},
    180843: {"Unified_Ideograph", "Ideographic"},
    180844: {"Unified_Ideograph", "Ideographic"},
    180845: {"Unified_Ideograph", "Ideographic"},
    180846: {"Unified_Ideograph", "Ideographic"},
    180847: {"Unified_Ideograph", "Ideographic"},
    180848: {"Unified_Ideograph", "Ideographic"},
    180849: {"Unified_Ideograph", "Ideographic"},
    180850: {"Unified_Ideograph", "Ideographic"},
    180851: {"Unified_Ideograph", "Ideographic"},
    180852: {"Unified_Ideograph", "Ideographic"},
    180853: {"Unified_Ideograph", "Ideographic"},
    180854: {"Unified_Ideograph", "Ideographic"},
    180855: {"Unified_Ideograph", "Ideographic"},
    180856: {"Unified_Ideograph", "Ideographic"},
    180857: {"Unified_Ideograph", "Ideographic"},
    180858: {"Unified_Ideograph", "Ideographic"},
    180859: {"Unified_Ideograph", "Ideographic"},
    180860: {"Unified_Ideograph", "Ideographic"},
    180861: {"Unified_Ideograph", "Ideographic"},
    180862: {"Unified_Ideograph", "Ideographic"},
    180863: {"Unified_Ideograph", "Ideographic"},
    180864: {"Unified_Ideograph", "Ideographic"},
    180865: {"Unified_Ideograph", "Ideographic"},
    180866: {"Unified_Ideograph", "Ideographic"},
    180867: {"Unified_Ideograph", "Ideographic"},
    180868: {"Unified_Ideograph", "Ideographic"},
    180869: {"Unified_Ideograph", "Ideographic"},
    180870: {"Unified_Ideograph", "Ideographic"},
    180871: {"Unified_Ideograph", "Ideographic"},
    180872: {"Unified_Ideograph", "Ideographic"},
    180873: {"Unified_Ideograph", "Ideographic"},
    180874: {"Unified_Ideograph", "Ideographic"},
    180875: {"Unified_Ideograph", "Ideographic"},
    180876: {"Unified_Ideograph", "Ideographic"},
    180877: {"Unified_Ideograph", "Ideographic"},
    180878: {"Unified_Ideograph", "Ideographic"},
    180879: {"Unified_Ideograph", "Ideographic"},
    180880: {"Unified_Ideograph", "Ideographic"},
    180881: {"Unified_Ideograph", "Ideographic"},
    180882: {"Unified_Ideograph", "Ideographic"},
    180883: {"Unified_Ideograph", "Ideographic"},
    180884: {"Unified_Ideograph", "Ideographic"},
    180885: {"Unified_Ideograph", "Ideographic"},
    180886: {"Unified_Ideograph", "Ideographic"},
    180887: {"Unified_Ideograph", "Ideographic"},
    180888: {"Unified_Ideograph", "Ideographic"},
    180889: {"Unified_Ideograph", "Ideographic"},
    180890: {"Unified_Ideograph", "Ideographic"},
    180891: {"Unified_Ideograph", "Ideographic"},
    180892: {"Unified_Ideograph", "Ideographic"},
    180893: {"Unified_Ideograph", "Ideographic"},
    180894: {"Unified_Ideograph", "Ideographic"},
    180895: {"Unified_Ideograph", "Ideographic"},
    180896: {"Unified_Ideograph", "Ideographic"},
    180897: {"Unified_Ideograph", "Ideographic"},
    180898: {"Unified_Ideograph", "Ideographic"},
    180899: {"Unified_Ideograph", "Ideographic"},
    180900: {"Unified_Ideograph", "Ideographic"},
    180901: {"Unified_Ideograph", "Ideographic"},
    180902: {"Unified_Ideograph", "Ideographic"},
    180903: {"Unified_Ideograph", "Ideographic"},
    180904: {"Unified_Ideograph", "Ideographic"},
    180905: {"Unified_Ideograph", "Ideographic"},
    180906: {"Unified_Ideograph", "Ideographic"},
    180907: {"Unified_Ideograph", "Ideographic"},
    180908: {"Unified_Ideograph", "Ideographic"},
    180909: {"Unified_Ideograph", "Ideographic"},
    180910: {"Unified_Ideograph", "Ideographic"},
    180911: {"Unified_Ideograph", "Ideographic"},
    180912: {"Unified_Ideograph", "Ideographic"},
    180913: {"Unified_Ideograph", "Ideographic"},
    180914: {"Unified_Ideograph", "Ideographic"},
    180915: {"Unified_Ideograph", "Ideographic"},
    180916: {"Unified_Ideograph", "Ideographic"},
    180917: {"Unified_Ideograph", "Ideographic"},
    180918: {"Unified_Ideograph", "Ideographic"},
    180919: {"Unified_Ideograph", "Ideographic"},
    180920: {"Unified_Ideograph", "Ideographic"},
    180921: {"Unified_Ideograph", "Ideographic"},
    180922: {"Unified_Ideograph", "Ideographic"},
    180923: {"Unified_Ideograph", "Ideographic"},
    180924: {"Unified_Ideograph", "Ideographic"},
    180925: {"Unified_Ideograph", "Ideographic"},
    180926: {"Unified_Ideograph", "Ideographic"},
    180927: {"Unified_Ideograph", "Ideographic"},
    180928: {"Unified_Ideograph", "Ideographic"},
    180929: {"Unified_Ideograph", "Ideographic"},
    180930: {"Unified_Ideograph", "Ideographic"},
    180931: {"Unified_Ideograph", "Ideographic"},
    180932: {"Unified_Ideograph", "Ideographic"},
    180933: {"Unified_Ideograph", "Ideographic"},
    180934: {"Unified_Ideograph", "Ideographic"},
    180935: {"Unified_Ideograph", "Ideographic"},
    180936: {"Unified_Ideograph", "Ideographic"},
    180937: {"Unified_Ideograph", "Ideographic"},
    180938: {"Unified_Ideograph", "Ideographic"},
    180939: {"Unified_Ideograph", "Ideographic"},
    180940: {"Unified_Ideograph", "Ideographic"},
    180941: {"Unified_Ideograph", "Ideographic"},
    180942: {"Unified_Ideograph", "Ideographic"},
    180943: {"Unified_Ideograph", "Ideographic"},
    180944: {"Unified_Ideograph", "Ideographic"},
    180945: {"Unified_Ideograph", "Ideographic"},
    180946: {"Unified_Ideograph", "Ideographic"},
    180947: {"Unified_Ideograph", "Ideographic"},
    180948: {"Unified_Ideograph", "Ideographic"},
    180949: {"Unified_Ideograph", "Ideographic"},
    180950: {"Unified_Ideograph", "Ideographic"},
    180951: {"Unified_Ideograph", "Ideographic"},
    180952: {"Unified_Ideograph", "Ideographic"},
    180953: {"Unified_Ideograph", "Ideographic"},
    180954: {"Unified_Ideograph", "Ideographic"},
    180955: {"Unified_Ideograph", "Ideographic"},
    180956: {"Unified_Ideograph", "Ideographic"},
    180957: {"Unified_Ideograph", "Ideographic"},
    180958: {"Unified_Ideograph", "Ideographic"},
    180959: {"Unified_Ideograph", "Ideographic"},
    180960: {"Unified_Ideograph", "Ideographic"},
    180961: {"Unified_Ideograph", "Ideographic"},
    180962: {"Unified_Ideograph", "Ideographic"},
    180963: {"Unified_Ideograph", "Ideographic"},
    180964: {"Unified_Ideograph", "Ideographic"},
    180965: {"Unified_Ideograph", "Ideographic"},
    180966: {"Unified_Ideograph", "Ideographic"},
    180967: {"Unified_Ideograph", "Ideographic"},
    180968: {"Unified_Ideograph", "Ideographic"},
    180969: {"Unified_Ideograph", "Ideographic"},
    180970: {"Unified_Ideograph", "Ideographic"},
    180971: {"Unified_Ideograph", "Ideographic"},
    180972: {"Unified_Ideograph", "Ideographic"},
    180973: {"Unified_Ideograph", "Ideographic"},
    180974: {"Unified_Ideograph", "Ideographic"},
    180975: {"Unified_Ideograph", "Ideographic"},
    180976: {"Unified_Ideograph", "Ideographic"},
    180977: {"Unified_Ideograph", "Ideographic"},
    180978: {"Unified_Ideograph", "Ideographic"},
    180979: {"Unified_Ideograph", "Ideographic"},
    180980: {"Unified_Ideograph", "Ideographic"},
    180981: {"Unified_Ideograph", "Ideographic"},
    180982: {"Unified_Ideograph", "Ideographic"},
    180983: {"Unified_Ideograph", "Ideographic"},
    180984: {"Unified_Ideograph", "Ideographic"},
    180985: {"Unified_Ideograph", "Ideographic"},
    180986: {"Unified_Ideograph", "Ideographic"},
    180987: {"Unified_Ideograph", "Ideographic"},
    180988: {"Unified_Ideograph", "Ideographic"},
    180989: {"Unified_Ideograph", "Ideographic"},
    180990: {"Unified_Ideograph", "Ideographic"},
    180991: {"Unified_Ideograph", "Ideographic"},
    180992: {"Unified_Ideograph", "Ideographic"},
    180993: {"Unified_Ideograph", "Ideographic"},
    180994: {"Unified_Ideograph", "Ideographic"},
    180995: {"Unified_Ideograph", "Ideographic"},
    180996: {"Unified_Ideograph", "Ideographic"},
    180997: {"Unified_Ideograph", "Ideographic"},
    180998: {"Unified_Ideograph", "Ideographic"},
    180999: {"Unified_Ideograph", "Ideographic"},
    181000: {"Unified_Ideograph", "Ideographic"},
    181001: {"Unified_Ideograph", "Ideographic"},
    181002: {"Unified_Ideograph", "Ideographic"},
    181003: {"Unified_Ideograph", "Ideographic"},
    181004: {"Unified_Ideograph", "Ideographic"},
    181005: {"Unified_Ideograph", "Ideographic"},
    181006: {"Unified_Ideograph", "Ideographic"},
    181007: {"Unified_Ideograph", "Ideographic"},
    181008: {"Unified_Ideograph", "Ideographic"},
    181009: {"Unified_Ideograph", "Ideographic"},
    181010: {"Unified_Ideograph", "Ideographic"},
    181011: {"Unified_Ideograph", "Ideographic"},
    181012: {"Unified_Ideograph", "Ideographic"},
    181013: {"Unified_Ideograph", "Ideographic"},
    181014: {"Unified_Ideograph", "Ideographic"},
    181015: {"Unified_Ideograph", "Ideographic"},
    181016: {"Unified_Ideograph", "Ideographic"},
    181017: {"Unified_Ideograph", "Ideographic"},
    181018: {"Unified_Ideograph", "Ideographic"},
    181019: {"Unified_Ideograph", "Ideographic"},
    181020: {"Unified_Ideograph", "Ideographic"},
    181021: {"Unified_Ideograph", "Ideographic"},
    181022: {"Unified_Ideograph", "Ideographic"},
    181023: {"Unified_Ideograph", "Ideographic"},
    181024: {"Unified_Ideograph", "Ideographic"},
    181025: {"Unified_Ideograph", "Ideographic"},
    181026: {"Unified_Ideograph", "Ideographic"},
    181027: {"Unified_Ideograph", "Ideographic"},
    181028: {"Unified_Ideograph", "Ideographic"},
    181029: {"Unified_Ideograph", "Ideographic"},
    181030: {"Unified_Ideograph", "Ideographic"},
    181031: {"Unified_Ideograph", "Ideographic"},
    181032: {"Unified_Ideograph", "Ideographic"},
    181033: {"Unified_Ideograph", "Ideographic"},
    181034: {"Unified_Ideograph", "Ideographic"},
    181035: {"Unified_Ideograph", "Ideographic"},
    181036: {"Unified_Ideograph", "Ideographic"},
    181037: {"Unified_Ideograph", "Ideographic"},
    181038: {"Unified_Ideograph", "Ideographic"},
    181039: {"Unified_Ideograph", "Ideographic"},
    181040: {"Unified_Ideograph", "Ideographic"},
    181041: {"Unified_Ideograph", "Ideographic"},
    181042: {"Unified_Ideograph", "Ideographic"},
    181043: {"Unified_Ideograph", "Ideographic"},
    181044: {"Unified_Ideograph", "Ideographic"},
    181045: {"Unified_Ideograph", "Ideographic"},
    181046: {"Unified_Ideograph", "Ideographic"},
    181047: {"Unified_Ideograph", "Ideographic"},
    181048: {"Unified_Ideograph", "Ideographic"},
    181049: {"Unified_Ideograph", "Ideographic"},
    181050: {"Unified_Ideograph", "Ideographic"},
    181051: {"Unified_Ideograph", "Ideographic"},
    181052: {"Unified_Ideograph", "Ideographic"},
    181053: {"Unified_Ideograph", "Ideographic"},
    181054: {"Unified_Ideograph", "Ideographic"},
    181055: {"Unified_Ideograph", "Ideographic"},
    181056: {"Unified_Ideograph", "Ideographic"},
    181057: {"Unified_Ideograph", "Ideographic"},
    181058: {"Unified_Ideograph", "Ideographic"},
    181059: {"Unified_Ideograph", "Ideographic"},
    181060: {"Unified_Ideograph", "Ideographic"},
    181061: {"Unified_Ideograph", "Ideographic"},
    181062: {"Unified_Ideograph", "Ideographic"},
    181063: {"Unified_Ideograph", "Ideographic"},
    181064: {"Unified_Ideograph", "Ideographic"},
    181065: {"Unified_Ideograph", "Ideographic"},
    181066: {"Unified_Ideograph", "Ideographic"},
    181067: {"Unified_Ideograph", "Ideographic"},
    181068: {"Unified_Ideograph", "Ideographic"},
    181069: {"Unified_Ideograph", "Ideographic"},
    181070: {"Unified_Ideograph", "Ideographic"},
    181071: {"Unified_Ideograph", "Ideographic"},
    181072: {"Unified_Ideograph", "Ideographic"},
    181073: {"Unified_Ideograph", "Ideographic"},
    181074: {"Unified_Ideograph", "Ideographic"},
    181075: {"Unified_Ideograph", "Ideographic"},
    181076: {"Unified_Ideograph", "Ideographic"},
    181077: {"Unified_Ideograph", "Ideographic"},
    181078: {"Unified_Ideograph", "Ideographic"},
    181079: {"Unified_Ideograph", "Ideographic"},
    181080: {"Unified_Ideograph", "Ideographic"},
    181081: {"Unified_Ideograph", "Ideographic"},
    181082: {"Unified_Ideograph", "Ideographic"},
    181083: {"Unified_Ideograph", "Ideographic"},
    181084: {"Unified_Ideograph", "Ideographic"},
    181085: {"Unified_Ideograph", "Ideographic"},
    181086: {"Unified_Ideograph", "Ideographic"},
    181087: {"Unified_Ideograph", "Ideographic"},
    181088: {"Unified_Ideograph", "Ideographic"},
    181089: {"Unified_Ideograph", "Ideographic"},
    181090: {"Unified_Ideograph", "Ideographic"},
    181091: {"Unified_Ideograph", "Ideographic"},
    181092: {"Unified_Ideograph", "Ideographic"},
    181093: {"Unified_Ideograph", "Ideographic"},
    181094: {"Unified_Ideograph", "Ideographic"},
    181095: {"Unified_Ideograph", "Ideographic"},
    181096: {"Unified_Ideograph", "Ideographic"},
    181097: {"Unified_Ideograph", "Ideographic"},
    181098: {"Unified_Ideograph", "Ideographic"},
    181099: {"Unified_Ideograph", "Ideographic"},
    181100: {"Unified_Ideograph", "Ideographic"},
    181101: {"Unified_Ideograph", "Ideographic"},
    181102: {"Unified_Ideograph", "Ideographic"},
    181103: {"Unified_Ideograph", "Ideographic"},
    181104: {"Unified_Ideograph", "Ideographic"},
    181105: {"Unified_Ideograph", "Ideographic"},
    181106: {"Unified_Ideograph", "Ideographic"},
    181107: {"Unified_Ideograph", "Ideographic"},
    181108: {"Unified_Ideograph", "Ideographic"},
    181109: {"Unified_Ideograph", "Ideographic"},
    181110: {"Unified_Ideograph", "Ideographic"},
    181111: {"Unified_Ideograph", "Ideographic"},
    181112: {"Unified_Ideograph", "Ideographic"},
    181113: {"Unified_Ideograph", "Ideographic"},
    181114: {"Unified_Ideograph", "Ideographic"},
    181115: {"Unified_Ideograph", "Ideographic"},
    181116: {"Unified_Ideograph", "Ideographic"},
    181117: {"Unified_Ideograph", "Ideographic"},
    181118: {"Unified_Ideograph", "Ideographic"},
    181119: {"Unified_Ideograph", "Ideographic"},
    181120: {"Unified_Ideograph", "Ideographic"},
    181121: {"Unified_Ideograph", "Ideographic"},
    181122: {"Unified_Ideograph", "Ideographic"},
    181123: {"Unified_Ideograph", "Ideographic"},
    181124: {"Unified_Ideograph", "Ideographic"},
    181125: {"Unified_Ideograph", "Ideographic"},
    181126: {"Unified_Ideograph", "Ideographic"},
    181127: {"Unified_Ideograph", "Ideographic"},
    181128: {"Unified_Ideograph", "Ideographic"},
    181129: {"Unified_Ideograph", "Ideographic"},
    181130: {"Unified_Ideograph", "Ideographic"},
    181131: {"Unified_Ideograph", "Ideographic"},
    181132: {"Unified_Ideograph", "Ideographic"},
    181133: {"Unified_Ideograph", "Ideographic"},
    181134: {"Unified_Ideograph", "Ideographic"},
    181135: {"Unified_Ideograph", "Ideographic"},
    181136: {"Unified_Ideograph", "Ideographic"},
    181137: {"Unified_Ideograph", "Ideographic"},
    181138: {"Unified_Ideograph", "Ideographic"},
    181139: {"Unified_Ideograph", "Ideographic"},
    181140: {"Unified_Ideograph", "Ideographic"},
    181141: {"Unified_Ideograph", "Ideographic"},
    181142: {"Unified_Ideograph", "Ideographic"},
    181143: {"Unified_Ideograph", "Ideographic"},
    181144: {"Unified_Ideograph", "Ideographic"},
    181145: {"Unified_Ideograph", "Ideographic"},
    181146: {"Unified_Ideograph", "Ideographic"},
    181147: {"Unified_Ideograph", "Ideographic"},
    181148: {"Unified_Ideograph", "Ideographic"},
    181149: {"Unified_Ideograph", "Ideographic"},
    181150: {"Unified_Ideograph", "Ideographic"},
    181151: {"Unified_Ideograph", "Ideographic"},
    181152: {"Unified_Ideograph", "Ideographic"},
    181153: {"Unified_Ideograph", "Ideographic"},
    181154: {"Unified_Ideograph", "Ideographic"},
    181155: {"Unified_Ideograph", "Ideographic"},
    181156: {"Unified_Ideograph", "Ideographic"},
    181157: {"Unified_Ideograph", "Ideographic"},
    181158: {"Unified_Ideograph", "Ideographic"},
    181159: {"Unified_Ideograph", "Ideographic"},
    181160: {"Unified_Ideograph", "Ideographic"},
    181161: {"Unified_Ideograph", "Ideographic"},
    181162: {"Unified_Ideograph", "Ideographic"},
    181163: {"Unified_Ideograph", "Ideographic"},
    181164: {"Unified_Ideograph", "Ideographic"},
    181165: {"Unified_Ideograph", "Ideographic"},
    181166: {"Unified_Ideograph", "Ideographic"},
    181167: {"Unified_Ideograph", "Ideographic"},
    181168: {"Unified_Ideograph", "Ideographic"},
    181169: {"Unified_Ideograph", "Ideographic"},
    181170: {"Unified_Ideograph", "Ideographic"},
    181171: {"Unified_Ideograph", "Ideographic"},
    181172: {"Unified_Ideograph", "Ideographic"},
    181173: {"Unified_Ideograph", "Ideographic"},
    181174: {"Unified_Ideograph", "Ideographic"},
    181175: {"Unified_Ideograph", "Ideographic"},
    181176: {"Unified_Ideograph", "Ideographic"},
    181177: {"Unified_Ideograph", "Ideographic"},
    181178: {"Unified_Ideograph", "Ideographic"},
    181179: {"Unified_Ideograph", "Ideographic"},
    181180: {"Unified_Ideograph", "Ideographic"},
    181181: {"Unified_Ideograph", "Ideographic"},
    181182: {"Unified_Ideograph", "Ideographic"},
    181183: {"Unified_Ideograph", "Ideographic"},
    181184: {"Unified_Ideograph", "Ideographic"},
    181185: {"Unified_Ideograph", "Ideographic"},
    181186: {"Unified_Ideograph", "Ideographic"},
    181187: {"Unified_Ideograph", "Ideographic"},
    181188: {"Unified_Ideograph", "Ideographic"},
    181189: {"Unified_Ideograph", "Ideographic"},
    181190: {"Unified_Ideograph", "Ideographic"},
    181191: {"Unified_Ideograph", "Ideographic"},
    181192: {"Unified_Ideograph", "Ideographic"},
    181193: {"Unified_Ideograph", "Ideographic"},
    181194: {"Unified_Ideograph", "Ideographic"},
    181195: {"Unified_Ideograph", "Ideographic"},
    181196: {"Unified_Ideograph", "Ideographic"},
    181197: {"Unified_Ideograph", "Ideographic"},
    181198: {"Unified_Ideograph", "Ideographic"},
    181199: {"Unified_Ideograph", "Ideographic"},
    181200: {"Unified_Ideograph", "Ideographic"},
    181201: {"Unified_Ideograph", "Ideographic"},
    181202: {"Unified_Ideograph", "Ideographic"},
    181203: {"Unified_Ideograph", "Ideographic"},
    181204: {"Unified_Ideograph", "Ideographic"},
    181205: {"Unified_Ideograph", "Ideographic"},
    181206: {"Unified_Ideograph", "Ideographic"},
    181207: {"Unified_Ideograph", "Ideographic"},
    181208: {"Unified_Ideograph", "Ideographic"},
    181209: {"Unified_Ideograph", "Ideographic"},
    181210: {"Unified_Ideograph", "Ideographic"},
    181211: {"Unified_Ideograph", "Ideographic"},
    181212: {"Unified_Ideograph", "Ideographic"},
    181213: {"Unified_Ideograph", "Ideographic"},
    181214: {"Unified_Ideograph", "Ideographic"},
    181215: {"Unified_Ideograph", "Ideographic"},
    181216: {"Unified_Ideograph", "Ideographic"},
    181217: {"Unified_Ideograph", "Ideographic"},
    181218: {"Unified_Ideograph", "Ideographic"},
    181219: {"Unified_Ideograph", "Ideographic"},
    181220: {"Unified_Ideograph", "Ideographic"},
    181221: {"Unified_Ideograph", "Ideographic"},
    181222: {"Unified_Ideograph", "Ideographic"},
    181223: {"Unified_Ideograph", "Ideographic"},
    181224: {"Unified_Ideograph", "Ideographic"},
    181225: {"Unified_Ideograph", "Ideographic"},
    181226: {"Unified_Ideograph", "Ideographic"},
    181227: {"Unified_Ideograph", "Ideographic"},
    181228: {"Unified_Ideograph", "Ideographic"},
    181229: {"Unified_Ideograph", "Ideographic"},
    181230: {"Unified_Ideograph", "Ideographic"},
    181231: {"Unified_Ideograph", "Ideographic"},
    181232: {"Unified_Ideograph", "Ideographic"},
    181233: {"Unified_Ideograph", "Ideographic"},
    181234: {"Unified_Ideograph", "Ideographic"},
    181235: {"Unified_Ideograph", "Ideographic"},
    181236: {"Unified_Ideograph", "Ideographic"},
    181237: {"Unified_Ideograph", "Ideographic"},
    181238: {"Unified_Ideograph", "Ideographic"},
    181239: {"Unified_Ideograph", "Ideographic"},
    181240: {"Unified_Ideograph", "Ideographic"},
    181241: {"Unified_Ideograph", "Ideographic"},
    181242: {"Unified_Ideograph", "Ideographic"},
    181243: {"Unified_Ideograph", "Ideographic"},
    181244: {"Unified_Ideograph", "Ideographic"},
    181245: {"Unified_Ideograph", "Ideographic"},
    181246: {"Unified_Ideograph", "Ideographic"},
    181247: {"Unified_Ideograph", "Ideographic"},
    181248: {"Unified_Ideograph", "Ideographic"},
    181249: {"Unified_Ideograph", "Ideographic"},
    181250: {"Unified_Ideograph", "Ideographic"},
    181251: {"Unified_Ideograph", "Ideographic"},
    181252: {"Unified_Ideograph", "Ideographic"},
    181253: {"Unified_Ideograph", "Ideographic"},
    181254: {"Unified_Ideograph", "Ideographic"},
    181255: {"Unified_Ideograph", "Ideographic"},
    181256: {"Unified_Ideograph", "Ideographic"},
    181257: {"Unified_Ideograph", "Ideographic"},
    181258: {"Unified_Ideograph", "Ideographic"},
    181259: {"Unified_Ideograph", "Ideographic"},
    181260: {"Unified_Ideograph", "Ideographic"},
    181261: {"Unified_Ideograph", "Ideographic"},
    181262: {"Unified_Ideograph", "Ideographic"},
    181263: {"Unified_Ideograph", "Ideographic"},
    181264: {"Unified_Ideograph", "Ideographic"},
    181265: {"Unified_Ideograph", "Ideographic"},
    181266: {"Unified_Ideograph", "Ideographic"},
    181267: {"Unified_Ideograph", "Ideographic"},
    181268: {"Unified_Ideograph", "Ideographic"},
    181269: {"Unified_Ideograph", "Ideographic"},
    181270: {"Unified_Ideograph", "Ideographic"},
    181271: {"Unified_Ideograph", "Ideographic"},
    181272: {"Unified_Ideograph", "Ideographic"},
    181273: {"Unified_Ideograph", "Ideographic"},
    181274: {"Unified_Ideograph", "Ideographic"},
    181275: {"Unified_Ideograph", "Ideographic"},
    181276: {"Unified_Ideograph", "Ideographic"},
    181277: {"Unified_Ideograph", "Ideographic"},
    181278: {"Unified_Ideograph", "Ideographic"},
    181279: {"Unified_Ideograph", "Ideographic"},
    181280: {"Unified_Ideograph", "Ideographic"},
    181281: {"Unified_Ideograph", "Ideographic"},
    181282: {"Unified_Ideograph", "Ideographic"},
    181283: {"Unified_Ideograph", "Ideographic"},
    181284: {"Unified_Ideograph", "Ideographic"},
    181285: {"Unified_Ideograph", "Ideographic"},
    181286: {"Unified_Ideograph", "Ideographic"},
    181287: {"Unified_Ideograph", "Ideographic"},
    181288: {"Unified_Ideograph", "Ideographic"},
    181289: {"Unified_Ideograph", "Ideographic"},
    181290: {"Unified_Ideograph", "Ideographic"},
    181291: {"Unified_Ideograph", "Ideographic"},
    181292: {"Unified_Ideograph", "Ideographic"},
    181293: {"Unified_Ideograph", "Ideographic"},
    181294: {"Unified_Ideograph", "Ideographic"},
    181295: {"Unified_Ideograph", "Ideographic"},
    181296: {"Unified_Ideograph", "Ideographic"},
    181297: {"Unified_Ideograph", "Ideographic"},
    181298: {"Unified_Ideograph", "Ideographic"},
    181299: {"Unified_Ideograph", "Ideographic"},
    181300: {"Unified_Ideograph", "Ideographic"},
    181301: {"Unified_Ideograph", "Ideographic"},
    181302: {"Unified_Ideograph", "Ideographic"},
    181303: {"Unified_Ideograph", "Ideographic"},
    181304: {"Unified_Ideograph", "Ideographic"},
    181305: {"Unified_Ideograph", "Ideographic"},
    181306: {"Unified_Ideograph", "Ideographic"},
    181307: {"Unified_Ideograph", "Ideographic"},
    181308: {"Unified_Ideograph", "Ideographic"},
    181309: {"Unified_Ideograph", "Ideographic"},
    181310: {"Unified_Ideograph", "Ideographic"},
    181311: {"Unified_Ideograph", "Ideographic"},
    181312: {"Unified_Ideograph", "Ideographic"},
    181313: {"Unified_Ideograph", "Ideographic"},
    181314: {"Unified_Ideograph", "Ideographic"},
    181315: {"Unified_Ideograph", "Ideographic"},
    181316: {"Unified_Ideograph", "Ideographic"},
    181317: {"Unified_Ideograph", "Ideographic"},
    181318: {"Unified_Ideograph", "Ideographic"},
    181319: {"Unified_Ideograph", "Ideographic"},
    181320: {"Unified_Ideograph", "Ideographic"},
    181321: {"Unified_Ideograph", "Ideographic"},
    181322: {"Unified_Ideograph", "Ideographic"},
    181323: {"Unified_Ideograph", "Ideographic"},
    181324: {"Unified_Ideograph", "Ideographic"},
    181325: {"Unified_Ideograph", "Ideographic"},
    181326: {"Unified_Ideograph", "Ideographic"},
    181327: {"Unified_Ideograph", "Ideographic"},
    181328: {"Unified_Ideograph", "Ideographic"},
    181329: {"Unified_Ideograph", "Ideographic"},
    181330: {"Unified_Ideograph", "Ideographic"},
    181331: {"Unified_Ideograph", "Ideographic"},
    181332: {"Unified_Ideograph", "Ideographic"},
    181333: {"Unified_Ideograph", "Ideographic"},
    181334: {"Unified_Ideograph", "Ideographic"},
    181335: {"Unified_Ideograph", "Ideographic"},
    181336: {"Unified_Ideograph", "Ideographic"},
    181337: {"Unified_Ideograph", "Ideographic"},
    181338: {"Unified_Ideograph", "Ideographic"},
    181339: {"Unified_Ideograph", "Ideographic"},
    181340: {"Unified_Ideograph", "Ideographic"},
    181341: {"Unified_Ideograph", "Ideographic"},
    181342: {"Unified_Ideograph", "Ideographic"},
    181343: {"Unified_Ideograph", "Ideographic"},
    181344: {"Unified_Ideograph", "Ideographic"},
    181345: {"Unified_Ideograph", "Ideographic"},
    181346: {"Unified_Ideograph", "Ideographic"},
    181347: {"Unified_Ideograph", "Ideographic"},
    181348: {"Unified_Ideograph", "Ideographic"},
    181349: {"Unified_Ideograph", "Ideographic"},
    181350: {"Unified_Ideograph", "Ideographic"},
    181351: {"Unified_Ideograph", "Ideographic"},
    181352: {"Unified_Ideograph", "Ideographic"},
    181353: {"Unified_Ideograph", "Ideographic"},
    181354: {"Unified_Ideograph", "Ideographic"},
    181355: {"Unified_Ideograph", "Ideographic"},
    181356: {"Unified_Ideograph", "Ideographic"},
    181357: {"Unified_Ideograph", "Ideographic"},
    181358: {"Unified_Ideograph", "Ideographic"},
    181359: {"Unified_Ideograph", "Ideographic"},
    181360: {"Unified_Ideograph", "Ideographic"},
    181361: {"Unified_Ideograph", "Ideographic"},
    181362: {"Unified_Ideograph", "Ideographic"},
    181363: {"Unified_Ideograph", "Ideographic"},
    181364: {"Unified_Ideograph", "Ideographic"},
    181365: {"Unified_Ideograph", "Ideographic"},
    181366: {"Unified_Ideograph", "Ideographic"},
    181367: {"Unified_Ideograph", "Ideographic"},
    181368: {"Unified_Ideograph", "Ideographic"},
    181369: {"Unified_Ideograph", "Ideographic"},
    181370: {"Unified_Ideograph", "Ideographic"},
    181371: {"Unified_Ideograph", "Ideographic"},
    181372: {"Unified_Ideograph", "Ideographic"},
    181373: {"Unified_Ideograph", "Ideographic"},
    181374: {"Unified_Ideograph", "Ideographic"},
    181375: {"Unified_Ideograph", "Ideographic"},
    181376: {"Unified_Ideograph", "Ideographic"},
    181377: {"Unified_Ideograph", "Ideographic"},
    181378: {"Unified_Ideograph", "Ideographic"},
    181379: {"Unified_Ideograph", "Ideographic"},
    181380: {"Unified_Ideograph", "Ideographic"},
    181381: {"Unified_Ideograph", "Ideographic"},
    181382: {"Unified_Ideograph", "Ideographic"},
    181383: {"Unified_Ideograph", "Ideographic"},
    181384: {"Unified_Ideograph", "Ideographic"},
    181385: {"Unified_Ideograph", "Ideographic"},
    181386: {"Unified_Ideograph", "Ideographic"},
    181387: {"Unified_Ideograph", "Ideographic"},
    181388: {"Unified_Ideograph", "Ideographic"},
    181389: {"Unified_Ideograph", "Ideographic"},
    181390: {"Unified_Ideograph", "Ideographic"},
    181391: {"Unified_Ideograph", "Ideographic"},
    181392: {"Unified_Ideograph", "Ideographic"},
    181393: {"Unified_Ideograph", "Ideographic"},
    181394: {"Unified_Ideograph", "Ideographic"},
    181395: {"Unified_Ideograph", "Ideographic"},
    181396: {"Unified_Ideograph", "Ideographic"},
    181397: {"Unified_Ideograph", "Ideographic"},
    181398: {"Unified_Ideograph", "Ideographic"},
    181399: {"Unified_Ideograph", "Ideographic"},
    181400: {"Unified_Ideograph", "Ideographic"},
    181401: {"Unified_Ideograph", "Ideographic"},
    181402: {"Unified_Ideograph", "Ideographic"},
    181403: {"Unified_Ideograph", "Ideographic"},
    181404: {"Unified_Ideograph", "Ideographic"},
    181405: {"Unified_Ideograph", "Ideographic"},
    181406: {"Unified_Ideograph", "Ideographic"},
    181407: {"Unified_Ideograph", "Ideographic"},
    181408: {"Unified_Ideograph", "Ideographic"},
    181409: {"Unified_Ideograph", "Ideographic"},
    181410: {"Unified_Ideograph", "Ideographic"},
    181411: {"Unified_Ideograph", "Ideographic"},
    181412: {"Unified_Ideograph", "Ideographic"},
    181413: {"Unified_Ideograph", "Ideographic"},
    181414: {"Unified_Ideograph", "Ideographic"},
    181415: {"Unified_Ideograph", "Ideographic"},
    181416: {"Unified_Ideograph", "Ideographic"},
    181417: {"Unified_Ideograph", "Ideographic"},
    181418: {"Unified_Ideograph", "Ideographic"},
    181419: {"Unified_Ideograph", "Ideographic"},
    181420: {"Unified_Ideograph", "Ideographic"},
    181421: {"Unified_Ideograph", "Ideographic"},
    181422: {"Unified_Ideograph", "Ideographic"},
    181423: {"Unified_Ideograph", "Ideographic"},
    181424: {"Unified_Ideograph", "Ideographic"},
    181425: {"Unified_Ideograph", "Ideographic"},
    181426: {"Unified_Ideograph", "Ideographic"},
    181427: {"Unified_Ideograph", "Ideographic"},
    181428: {"Unified_Ideograph", "Ideographic"},
    181429: {"Unified_Ideograph", "Ideographic"},
    181430: {"Unified_Ideograph", "Ideographic"},
    181431: {"Unified_Ideograph", "Ideographic"},
    181432: {"Unified_Ideograph", "Ideographic"},
    181433: {"Unified_Ideograph", "Ideographic"},
    181434: {"Unified_Ideograph", "Ideographic"},
    181435: {"Unified_Ideograph", "Ideographic"},
    181436: {"Unified_Ideograph", "Ideographic"},
    181437: {"Unified_Ideograph", "Ideographic"},
    181438: {"Unified_Ideograph", "Ideographic"},
    181439: {"Unified_Ideograph", "Ideographic"},
    181440: {"Unified_Ideograph", "Ideographic"},
    181441: {"Unified_Ideograph", "Ideographic"},
    181442: {"Unified_Ideograph", "Ideographic"},
    181443: {"Unified_Ideograph", "Ideographic"},
    181444: {"Unified_Ideograph", "Ideographic"},
    181445: {"Unified_Ideograph", "Ideographic"},
    181446: {"Unified_Ideograph", "Ideographic"},
    181447: {"Unified_Ideograph", "Ideographic"},
    181448: {"Unified_Ideograph", "Ideographic"},
    181449: {"Unified_Ideograph", "Ideographic"},
    181450: {"Unified_Ideograph", "Ideographic"},
    181451: {"Unified_Ideograph", "Ideographic"},
    181452: {"Unified_Ideograph", "Ideographic"},
    181453: {"Unified_Ideograph", "Ideographic"},
    181454: {"Unified_Ideograph", "Ideographic"},
    181455: {"Unified_Ideograph", "Ideographic"},
    181456: {"Unified_Ideograph", "Ideographic"},
    181457: {"Unified_Ideograph", "Ideographic"},
    181458: {"Unified_Ideograph", "Ideographic"},
    181459: {"Unified_Ideograph", "Ideographic"},
    181460: {"Unified_Ideograph", "Ideographic"},
    181461: {"Unified_Ideograph", "Ideographic"},
    181462: {"Unified_Ideograph", "Ideographic"},
    181463: {"Unified_Ideograph", "Ideographic"},
    181464: {"Unified_Ideograph", "Ideographic"},
    181465: {"Unified_Ideograph", "Ideographic"},
    181466: {"Unified_Ideograph", "Ideographic"},
    181467: {"Unified_Ideograph", "Ideographic"},
    181468: {"Unified_Ideograph", "Ideographic"},
    181469: {"Unified_Ideograph", "Ideographic"},
    181470: {"Unified_Ideograph", "Ideographic"},
    181471: {"Unified_Ideograph", "Ideographic"},
    181472: {"Unified_Ideograph", "Ideographic"},
    181473: {"Unified_Ideograph", "Ideographic"},
    181474: {"Unified_Ideograph", "Ideographic"},
    181475: {"Unified_Ideograph", "Ideographic"},
    181476: {"Unified_Ideograph", "Ideographic"},
    181477: {"Unified_Ideograph", "Ideographic"},
    181478: {"Unified_Ideograph", "Ideographic"},
    181479: {"Unified_Ideograph", "Ideographic"},
    181480: {"Unified_Ideograph", "Ideographic"},
    181481: {"Unified_Ideograph", "Ideographic"},
    181482: {"Unified_Ideograph", "Ideographic"},
    181483: {"Unified_Ideograph", "Ideographic"},
    181484: {"Unified_Ideograph", "Ideographic"},
    181485: {"Unified_Ideograph", "Ideographic"},
    181486: {"Unified_Ideograph", "Ideographic"},
    181487: {"Unified_Ideograph", "Ideographic"},
    181488: {"Unified_Ideograph", "Ideographic"},
    181489: {"Unified_Ideograph", "Ideographic"},
    181490: {"Unified_Ideograph", "Ideographic"},
    181491: {"Unified_Ideograph", "Ideographic"},
    181492: {"Unified_Ideograph", "Ideographic"},
    181493: {"Unified_Ideograph", "Ideographic"},
    181494: {"Unified_Ideograph", "Ideographic"},
    181495: {"Unified_Ideograph", "Ideographic"},
    181496: {"Unified_Ideograph", "Ideographic"},
    181497: {"Unified_Ideograph", "Ideographic"},
    181498: {"Unified_Ideograph", "Ideographic"},
    181499: {"Unified_Ideograph", "Ideographic"},
    181500: {"Unified_Ideograph", "Ideographic"},
    181501: {"Unified_Ideograph", "Ideographic"},
    181502: {"Unified_Ideograph", "Ideographic"},
    181503: {"Unified_Ideograph", "Ideographic"},
    181504: {"Unified_Ideograph", "Ideographic"},
    181505: {"Unified_Ideograph", "Ideographic"},
    181506: {"Unified_Ideograph", "Ideographic"},
    181507: {"Unified_Ideograph", "Ideographic"},
    181508: {"Unified_Ideograph", "Ideographic"},
    181509: {"Unified_Ideograph", "Ideographic"},
    181510: {"Unified_Ideograph", "Ideographic"},
    181511: {"Unified_Ideograph", "Ideographic"},
    181512: {"Unified_Ideograph", "Ideographic"},
    181513: {"Unified_Ideograph", "Ideographic"},
    181514: {"Unified_Ideograph", "Ideographic"},
    181515: {"Unified_Ideograph", "Ideographic"},
    181516: {"Unified_Ideograph", "Ideographic"},
    181517: {"Unified_Ideograph", "Ideographic"},
    181518: {"Unified_Ideograph", "Ideographic"},
    181519: {"Unified_Ideograph", "Ideographic"},
    181520: {"Unified_Ideograph", "Ideographic"},
    181521: {"Unified_Ideograph", "Ideographic"},
    181522: {"Unified_Ideograph", "Ideographic"},
    181523: {"Unified_Ideograph", "Ideographic"},
    181524: {"Unified_Ideograph", "Ideographic"},
    181525: {"Unified_Ideograph", "Ideographic"},
    181526: {"Unified_Ideograph", "Ideographic"},
    181527: {"Unified_Ideograph", "Ideographic"},
    181528: {"Unified_Ideograph", "Ideographic"},
    181529: {"Unified_Ideograph", "Ideographic"},
    181530: {"Unified_Ideograph", "Ideographic"},
    181531: {"Unified_Ideograph", "Ideographic"},
    181532: {"Unified_Ideograph", "Ideographic"},
    181533: {"Unified_Ideograph", "Ideographic"},
    181534: {"Unified_Ideograph", "Ideographic"},
    181535: {"Unified_Ideograph", "Ideographic"},
    181536: {"Unified_Ideograph", "Ideographic"},
    181537: {"Unified_Ideograph", "Ideographic"},
    181538: {"Unified_Ideograph", "Ideographic"},
    181539: {"Unified_Ideograph", "Ideographic"},
    181540: {"Unified_Ideograph", "Ideographic"},
    181541: {"Unified_Ideograph", "Ideographic"},
    181542: {"Unified_Ideograph", "Ideographic"},
    181543: {"Unified_Ideograph", "Ideographic"},
    181544: {"Unified_Ideograph", "Ideographic"},
    181545: {"Unified_Ideograph", "Ideographic"},
    181546: {"Unified_Ideograph", "Ideographic"},
    181547: {"Unified_Ideograph", "Ideographic"},
    181548: {"Unified_Ideograph", "Ideographic"},
    181549: {"Unified_Ideograph", "Ideographic"},
    181550: {"Unified_Ideograph", "Ideographic"},
    181551: {"Unified_Ideograph", "Ideographic"},
    181552: {"Unified_Ideograph", "Ideographic"},
    181553: {"Unified_Ideograph", "Ideographic"},
    181554: {"Unified_Ideograph", "Ideographic"},
    181555: {"Unified_Ideograph", "Ideographic"},
    181556: {"Unified_Ideograph", "Ideographic"},
    181557: {"Unified_Ideograph", "Ideographic"},
    181558: {"Unified_Ideograph", "Ideographic"},
    181559: {"Unified_Ideograph", "Ideographic"},
    181560: {"Unified_Ideograph", "Ideographic"},
    181561: {"Unified_Ideograph", "Ideographic"},
    181562: {"Unified_Ideograph", "Ideographic"},
    181563: {"Unified_Ideograph", "Ideographic"},
    181564: {"Unified_Ideograph", "Ideographic"},
    181565: {"Unified_Ideograph", "Ideographic"},
    181566: {"Unified_Ideograph", "Ideographic"},
    181567: {"Unified_Ideograph", "Ideographic"},
    181568: {"Unified_Ideograph", "Ideographic"},
    181569: {"Unified_Ideograph", "Ideographic"},
    181570: {"Unified_Ideograph", "Ideographic"},
    181571: {"Unified_Ideograph", "Ideographic"},
    181572: {"Unified_Ideograph", "Ideographic"},
    181573: {"Unified_Ideograph", "Ideographic"},
    181574: {"Unified_Ideograph", "Ideographic"},
    181575: {"Unified_Ideograph", "Ideographic"},
    181576: {"Unified_Ideograph", "Ideographic"},
    181577: {"Unified_Ideograph", "Ideographic"},
    181578: {"Unified_Ideograph", "Ideographic"},
    181579: {"Unified_Ideograph", "Ideographic"},
    181580: {"Unified_Ideograph", "Ideographic"},
    181581: {"Unified_Ideograph", "Ideographic"},
    181582: {"Unified_Ideograph", "Ideographic"},
    181583: {"Unified_Ideograph", "Ideographic"},
    181584: {"Unified_Ideograph", "Ideographic"},
    181585: {"Unified_Ideograph", "Ideographic"},
    181586: {"Unified_Ideograph", "Ideographic"},
    181587: {"Unified_Ideograph", "Ideographic"},
    181588: {"Unified_Ideograph", "Ideographic"},
    181589: {"Unified_Ideograph", "Ideographic"},
    181590: {"Unified_Ideograph", "Ideographic"},
    181591: {"Unified_Ideograph", "Ideographic"},
    181592: {"Unified_Ideograph", "Ideographic"},
    181593: {"Unified_Ideograph", "Ideographic"},
    181594: {"Unified_Ideograph", "Ideographic"},
    181595: {"Unified_Ideograph", "Ideographic"},
    181596: {"Unified_Ideograph", "Ideographic"},
    181597: {"Unified_Ideograph", "Ideographic"},
    181598: {"Unified_Ideograph", "Ideographic"},
    181599: {"Unified_Ideograph", "Ideographic"},
    181600: {"Unified_Ideograph", "Ideographic"},
    181601: {"Unified_Ideograph", "Ideographic"},
    181602: {"Unified_Ideograph", "Ideographic"},
    181603: {"Unified_Ideograph", "Ideographic"},
    181604: {"Unified_Ideograph", "Ideographic"},
    181605: {"Unified_Ideograph", "Ideographic"},
    181606: {"Unified_Ideograph", "Ideographic"},
    181607: {"Unified_Ideograph", "Ideographic"},
    181608: {"Unified_Ideograph", "Ideographic"},
    181609: {"Unified_Ideograph", "Ideographic"},
    181610: {"Unified_Ideograph", "Ideographic"},
    181611: {"Unified_Ideograph", "Ideographic"},
    181612: {"Unified_Ideograph", "Ideographic"},
    181613: {"Unified_Ideograph", "Ideographic"},
    181614: {"Unified_Ideograph", "Ideographic"},
    181615: {"Unified_Ideograph", "Ideographic"},
    181616: {"Unified_Ideograph", "Ideographic"},
    181617: {"Unified_Ideograph", "Ideographic"},
    181618: {"Unified_Ideograph", "Ideographic"},
    181619: {"Unified_Ideograph", "Ideographic"},
    181620: {"Unified_Ideograph", "Ideographic"},
    181621: {"Unified_Ideograph", "Ideographic"},
    181622: {"Unified_Ideograph", "Ideographic"},
    181623: {"Unified_Ideograph", "Ideographic"},
    181624: {"Unified_Ideograph", "Ideographic"},
    181625: {"Unified_Ideograph", "Ideographic"},
    181626: {"Unified_Ideograph", "Ideographic"},
    181627: {"Unified_Ideograph", "Ideographic"},
    181628: {"Unified_Ideograph", "Ideographic"},
    181629: {"Unified_Ideograph", "Ideographic"},
    181630: {"Unified_Ideograph", "Ideographic"},
    181631: {"Unified_Ideograph", "Ideographic"},
    181632: {"Unified_Ideograph", "Ideographic"},
    181633: {"Unified_Ideograph", "Ideographic"},
    181634: {"Unified_Ideograph", "Ideographic"},
    181635: {"Unified_Ideograph", "Ideographic"},
    181636: {"Unified_Ideograph", "Ideographic"},
    181637: {"Unified_Ideograph", "Ideographic"},
    181638: {"Unified_Ideograph", "Ideographic"},
    181639: {"Unified_Ideograph", "Ideographic"},
    181640: {"Unified_Ideograph", "Ideographic"},
    181641: {"Unified_Ideograph", "Ideographic"},
    181642: {"Unified_Ideograph", "Ideographic"},
    181643: {"Unified_Ideograph", "Ideographic"},
    181644: {"Unified_Ideograph", "Ideographic"},
    181645: {"Unified_Ideograph", "Ideographic"},
    181646: {"Unified_Ideograph", "Ideographic"},
    181647: {"Unified_Ideograph", "Ideographic"},
    181648: {"Unified_Ideograph", "Ideographic"},
    181649: {"Unified_Ideograph", "Ideographic"},
    181650: {"Unified_Ideograph", "Ideographic"},
    181651: {"Unified_Ideograph", "Ideographic"},
    181652: {"Unified_Ideograph", "Ideographic"},
    181653: {"Unified_Ideograph", "Ideographic"},
    181654: {"Unified_Ideograph", "Ideographic"},
    181655: {"Unified_Ideograph", "Ideographic"},
    181656: {"Unified_Ideograph", "Ideographic"},
    181657: {"Unified_Ideograph", "Ideographic"},
    181658: {"Unified_Ideograph", "Ideographic"},
    181659: {"Unified_Ideograph", "Ideographic"},
    181660: {"Unified_Ideograph", "Ideographic"},
    181661: {"Unified_Ideograph", "Ideographic"},
    181662: {"Unified_Ideograph", "Ideographic"},
    181663: {"Unified_Ideograph", "Ideographic"},
    181664: {"Unified_Ideograph", "Ideographic"},
    181665: {"Unified_Ideograph", "Ideographic"},
    181666: {"Unified_Ideograph", "Ideographic"},
    181667: {"Unified_Ideograph", "Ideographic"},
    181668: {"Unified_Ideograph", "Ideographic"},
    181669: {"Unified_Ideograph", "Ideographic"},
    181670: {"Unified_Ideograph", "Ideographic"},
    181671: {"Unified_Ideograph", "Ideographic"},
    181672: {"Unified_Ideograph", "Ideographic"},
    181673: {"Unified_Ideograph", "Ideographic"},
    181674: {"Unified_Ideograph", "Ideographic"},
    181675: {"Unified_Ideograph", "Ideographic"},
    181676: {"Unified_Ideograph", "Ideographic"},
    181677: {"Unified_Ideograph", "Ideographic"},
    181678: {"Unified_Ideograph", "Ideographic"},
    181679: {"Unified_Ideograph", "Ideographic"},
    181680: {"Unified_Ideograph", "Ideographic"},
    181681: {"Unified_Ideograph", "Ideographic"},
    181682: {"Unified_Ideograph", "Ideographic"},
    181683: {"Unified_Ideograph", "Ideographic"},
    181684: {"Unified_Ideograph", "Ideographic"},
    181685: {"Unified_Ideograph", "Ideographic"},
    181686: {"Unified_Ideograph", "Ideographic"},
    181687: {"Unified_Ideograph", "Ideographic"},
    181688: {"Unified_Ideograph", "Ideographic"},
    181689: {"Unified_Ideograph", "Ideographic"},
    181690: {"Unified_Ideograph", "Ideographic"},
    181691: {"Unified_Ideograph", "Ideographic"},
    181692: {"Unified_Ideograph", "Ideographic"},
    181693: {"Unified_Ideograph", "Ideographic"},
    181694: {"Unified_Ideograph", "Ideographic"},
    181695: {"Unified_Ideograph", "Ideographic"},
    181696: {"Unified_Ideograph", "Ideographic"},
    181697: {"Unified_Ideograph", "Ideographic"},
    181698: {"Unified_Ideograph", "Ideographic"},
    181699: {"Unified_Ideograph", "Ideographic"},
    181700: {"Unified_Ideograph", "Ideographic"},
    181701: {"Unified_Ideograph", "Ideographic"},
    181702: {"Unified_Ideograph", "Ideographic"},
    181703: {"Unified_Ideograph", "Ideographic"},
    181704: {"Unified_Ideograph", "Ideographic"},
    181705: {"Unified_Ideograph", "Ideographic"},
    181706: {"Unified_Ideograph", "Ideographic"},
    181707: {"Unified_Ideograph", "Ideographic"},
    181708: {"Unified_Ideograph", "Ideographic"},
    181709: {"Unified_Ideograph", "Ideographic"},
    181710: {"Unified_Ideograph", "Ideographic"},
    181711: {"Unified_Ideograph", "Ideographic"},
    181712: {"Unified_Ideograph", "Ideographic"},
    181713: {"Unified_Ideograph", "Ideographic"},
    181714: {"Unified_Ideograph", "Ideographic"},
    181715: {"Unified_Ideograph", "Ideographic"},
    181716: {"Unified_Ideograph", "Ideographic"},
    181717: {"Unified_Ideograph", "Ideographic"},
    181718: {"Unified_Ideograph", "Ideographic"},
    181719: {"Unified_Ideograph", "Ideographic"},
    181720: {"Unified_Ideograph", "Ideographic"},
    181721: {"Unified_Ideograph", "Ideographic"},
    181722: {"Unified_Ideograph", "Ideographic"},
    181723: {"Unified_Ideograph", "Ideographic"},
    181724: {"Unified_Ideograph", "Ideographic"},
    181725: {"Unified_Ideograph", "Ideographic"},
    181726: {"Unified_Ideograph", "Ideographic"},
    181727: {"Unified_Ideograph", "Ideographic"},
    181728: {"Unified_Ideograph", "Ideographic"},
    181729: {"Unified_Ideograph", "Ideographic"},
    181730: {"Unified_Ideograph", "Ideographic"},
    181731: {"Unified_Ideograph", "Ideographic"},
    181732: {"Unified_Ideograph", "Ideographic"},
    181733: {"Unified_Ideograph", "Ideographic"},
    181734: {"Unified_Ideograph", "Ideographic"},
    181735: {"Unified_Ideograph", "Ideographic"},
    181736: {"Unified_Ideograph", "Ideographic"},
    181737: {"Unified_Ideograph", "Ideographic"},
    181738: {"Unified_Ideograph", "Ideographic"},
    181739: {"Unified_Ideograph", "Ideographic"},
    181740: {"Unified_Ideograph", "Ideographic"},
    181741: {"Unified_Ideograph", "Ideographic"},
    181742: {"Unified_Ideograph", "Ideographic"},
    181743: {"Unified_Ideograph", "Ideographic"},
    181744: {"Unified_Ideograph", "Ideographic"},
    181745: {"Unified_Ideograph", "Ideographic"},
    181746: {"Unified_Ideograph", "Ideographic"},
    181747: {"Unified_Ideograph", "Ideographic"},
    181748: {"Unified_Ideograph", "Ideographic"},
    181749: {"Unified_Ideograph", "Ideographic"},
    181750: {"Unified_Ideograph", "Ideographic"},
    181751: {"Unified_Ideograph", "Ideographic"},
    181752: {"Unified_Ideograph", "Ideographic"},
    181753: {"Unified_Ideograph", "Ideographic"},
    181754: {"Unified_Ideograph", "Ideographic"},
    181755: {"Unified_Ideograph", "Ideographic"},
    181756: {"Unified_Ideograph", "Ideographic"},
    181757: {"Unified_Ideograph", "Ideographic"},
    181758: {"Unified_Ideograph", "Ideographic"},
    181759: {"Unified_Ideograph", "Ideographic"},
    181760: {"Unified_Ideograph", "Ideographic"},
    181761: {"Unified_Ideograph", "Ideographic"},
    181762: {"Unified_Ideograph", "Ideographic"},
    181763: {"Unified_Ideograph", "Ideographic"},
    181764: {"Unified_Ideograph", "Ideographic"},
    181765: {"Unified_Ideograph", "Ideographic"},
    181766: {"Unified_Ideograph", "Ideographic"},
    181767: {"Unified_Ideograph", "Ideographic"},
    181768: {"Unified_Ideograph", "Ideographic"},
    181769: {"Unified_Ideograph", "Ideographic"},
    181770: {"Unified_Ideograph", "Ideographic"},
    181771: {"Unified_Ideograph", "Ideographic"},
    181772: {"Unified_Ideograph", "Ideographic"},
    181773: {"Unified_Ideograph", "Ideographic"},
    181774: {"Unified_Ideograph", "Ideographic"},
    181775: {"Unified_Ideograph", "Ideographic"},
    181776: {"Unified_Ideograph", "Ideographic"},
    181777: {"Unified_Ideograph", "Ideographic"},
    181778: {"Unified_Ideograph", "Ideographic"},
    181779: {"Unified_Ideograph", "Ideographic"},
    181780: {"Unified_Ideograph", "Ideographic"},
    181781: {"Unified_Ideograph", "Ideographic"},
    181782: {"Unified_Ideograph", "Ideographic"},
    181783: {"Unified_Ideograph", "Ideographic"},
    181784: {"Unified_Ideograph", "Ideographic"},
    181785: {"Unified_Ideograph", "Ideographic"},
    181786: {"Unified_Ideograph", "Ideographic"},
    181787: {"Unified_Ideograph", "Ideographic"},
    181788: {"Unified_Ideograph", "Ideographic"},
    181789: {"Unified_Ideograph", "Ideographic"},
    181790: {"Unified_Ideograph", "Ideographic"},
    181791: {"Unified_Ideograph", "Ideographic"},
    181792: {"Unified_Ideograph", "Ideographic"},
    181793: {"Unified_Ideograph", "Ideographic"},
    181794: {"Unified_Ideograph", "Ideographic"},
    181795: {"Unified_Ideograph", "Ideographic"},
    181796: {"Unified_Ideograph", "Ideographic"},
    181797: {"Unified_Ideograph", "Ideographic"},
    181798: {"Unified_Ideograph", "Ideographic"},
    181799: {"Unified_Ideograph", "Ideographic"},
    181800: {"Unified_Ideograph", "Ideographic"},
    181801: {"Unified_Ideograph", "Ideographic"},
    181802: {"Unified_Ideograph", "Ideographic"},
    181803: {"Unified_Ideograph", "Ideographic"},
    181804: {"Unified_Ideograph", "Ideographic"},
    181805: {"Unified_Ideograph", "Ideographic"},
    181806: {"Unified_Ideograph", "Ideographic"},
    181807: {"Unified_Ideograph", "Ideographic"},
    181808: {"Unified_Ideograph", "Ideographic"},
    181809: {"Unified_Ideograph", "Ideographic"},
    181810: {"Unified_Ideograph", "Ideographic"},
    181811: {"Unified_Ideograph", "Ideographic"},
    181812: {"Unified_Ideograph", "Ideographic"},
    181813: {"Unified_Ideograph", "Ideographic"},
    181814: {"Unified_Ideograph", "Ideographic"},
    181815: {"Unified_Ideograph", "Ideographic"},
    181816: {"Unified_Ideograph", "Ideographic"},
    181817: {"Unified_Ideograph", "Ideographic"},
    181818: {"Unified_Ideograph", "Ideographic"},
    181819: {"Unified_Ideograph", "Ideographic"},
    181820: {"Unified_Ideograph", "Ideographic"},
    181821: {"Unified_Ideograph", "Ideographic"},
    181822: {"Unified_Ideograph", "Ideographic"},
    181823: {"Unified_Ideograph", "Ideographic"},
    181824: {"Unified_Ideograph", "Ideographic"},
    181825: {"Unified_Ideograph", "Ideographic"},
    181826: {"Unified_Ideograph", "Ideographic"},
    181827: {"Unified_Ideograph", "Ideographic"},
    181828: {"Unified_Ideograph", "Ideographic"},
    181829: {"Unified_Ideograph", "Ideographic"},
    181830: {"Unified_Ideograph", "Ideographic"},
    181831: {"Unified_Ideograph", "Ideographic"},
    181832: {"Unified_Ideograph", "Ideographic"},
    181833: {"Unified_Ideograph", "Ideographic"},
    181834: {"Unified_Ideograph", "Ideographic"},
    181835: {"Unified_Ideograph", "Ideographic"},
    181836: {"Unified_Ideograph", "Ideographic"},
    181837: {"Unified_Ideograph", "Ideographic"},
    181838: {"Unified_Ideograph", "Ideographic"},
    181839: {"Unified_Ideograph", "Ideographic"},
    181840: {"Unified_Ideograph", "Ideographic"},
    181841: {"Unified_Ideograph", "Ideographic"},
    181842: {"Unified_Ideograph", "Ideographic"},
    181843: {"Unified_Ideograph", "Ideographic"},
    181844: {"Unified_Ideograph", "Ideographic"},
    181845: {"Unified_Ideograph", "Ideographic"},
    181846: {"Unified_Ideograph", "Ideographic"},
    181847: {"Unified_Ideograph", "Ideographic"},
    181848: {"Unified_Ideograph", "Ideographic"},
    181849: {"Unified_Ideograph", "Ideographic"},
    181850: {"Unified_Ideograph", "Ideographic"},
    181851: {"Unified_Ideograph", "Ideographic"},
    181852: {"Unified_Ideograph", "Ideographic"},
    181853: {"Unified_Ideograph", "Ideographic"},
    181854: {"Unified_Ideograph", "Ideographic"},
    181855: {"Unified_Ideograph", "Ideographic"},
    181856: {"Unified_Ideograph", "Ideographic"},
    181857: {"Unified_Ideograph", "Ideographic"},
    181858: {"Unified_Ideograph", "Ideographic"},
    181859: {"Unified_Ideograph", "Ideographic"},
    181860: {"Unified_Ideograph", "Ideographic"},
    181861: {"Unified_Ideograph", "Ideographic"},
    181862: {"Unified_Ideograph", "Ideographic"},
    181863: {"Unified_Ideograph", "Ideographic"},
    181864: {"Unified_Ideograph", "Ideographic"},
    181865: {"Unified_Ideograph", "Ideographic"},
    181866: {"Unified_Ideograph", "Ideographic"},
    181867: {"Unified_Ideograph", "Ideographic"},
    181868: {"Unified_Ideograph", "Ideographic"},
    181869: {"Unified_Ideograph", "Ideographic"},
    181870: {"Unified_Ideograph", "Ideographic"},
    181871: {"Unified_Ideograph", "Ideographic"},
    181872: {"Unified_Ideograph", "Ideographic"},
    181873: {"Unified_Ideograph", "Ideographic"},
    181874: {"Unified_Ideograph", "Ideographic"},
    181875: {"Unified_Ideograph", "Ideographic"},
    181876: {"Unified_Ideograph", "Ideographic"},
    181877: {"Unified_Ideograph", "Ideographic"},
    181878: {"Unified_Ideograph", "Ideographic"},
    181879: {"Unified_Ideograph", "Ideographic"},
    181880: {"Unified_Ideograph", "Ideographic"},
    181881: {"Unified_Ideograph", "Ideographic"},
    181882: {"Unified_Ideograph", "Ideographic"},
    181883: {"Unified_Ideograph", "Ideographic"},
    181884: {"Unified_Ideograph", "Ideographic"},
    181885: {"Unified_Ideograph", "Ideographic"},
    181886: {"Unified_Ideograph", "Ideographic"},
    181887: {"Unified_Ideograph", "Ideographic"},
    181888: {"Unified_Ideograph", "Ideographic"},
    181889: {"Unified_Ideograph", "Ideographic"},
    181890: {"Unified_Ideograph", "Ideographic"},
    181891: {"Unified_Ideograph", "Ideographic"},
    181892: {"Unified_Ideograph", "Ideographic"},
    181893: {"Unified_Ideograph", "Ideographic"},
    181894: {"Unified_Ideograph", "Ideographic"},
    181895: {"Unified_Ideograph", "Ideographic"},
    181896: {"Unified_Ideograph", "Ideographic"},
    181897: {"Unified_Ideograph", "Ideographic"},
    181898: {"Unified_Ideograph", "Ideographic"},
    181899: {"Unified_Ideograph", "Ideographic"},
    181900: {"Unified_Ideograph", "Ideographic"},
    181901: {"Unified_Ideograph", "Ideographic"},
    181902: {"Unified_Ideograph", "Ideographic"},
    181903: {"Unified_Ideograph", "Ideographic"},
    181904: {"Unified_Ideograph", "Ideographic"},
    181905: {"Unified_Ideograph", "Ideographic"},
    181906: {"Unified_Ideograph", "Ideographic"},
    181907: {"Unified_Ideograph", "Ideographic"},
    181908: {"Unified_Ideograph", "Ideographic"},
    181909: {"Unified_Ideograph", "Ideographic"},
    181910: {"Unified_Ideograph", "Ideographic"},
    181911: {"Unified_Ideograph", "Ideographic"},
    181912: {"Unified_Ideograph", "Ideographic"},
    181913: {"Unified_Ideograph", "Ideographic"},
    181914: {"Unified_Ideograph", "Ideographic"},
    181915: {"Unified_Ideograph", "Ideographic"},
    181916: {"Unified_Ideograph", "Ideographic"},
    181917: {"Unified_Ideograph", "Ideographic"},
    181918: {"Unified_Ideograph", "Ideographic"},
    181919: {"Unified_Ideograph", "Ideographic"},
    181920: {"Unified_Ideograph", "Ideographic"},
    181921: {"Unified_Ideograph", "Ideographic"},
    181922: {"Unified_Ideograph", "Ideographic"},
    181923: {"Unified_Ideograph", "Ideographic"},
    181924: {"Unified_Ideograph", "Ideographic"},
    181925: {"Unified_Ideograph", "Ideographic"},
    181926: {"Unified_Ideograph", "Ideographic"},
    181927: {"Unified_Ideograph", "Ideographic"},
    181928: {"Unified_Ideograph", "Ideographic"},
    181929: {"Unified_Ideograph", "Ideographic"},
    181930: {"Unified_Ideograph", "Ideographic"},
    181931: {"Unified_Ideograph", "Ideographic"},
    181932: {"Unified_Ideograph", "Ideographic"},
    181933: {"Unified_Ideograph", "Ideographic"},
    181934: {"Unified_Ideograph", "Ideographic"},
    181935: {"Unified_Ideograph", "Ideographic"},
    181936: {"Unified_Ideograph", "Ideographic"},
    181937: {"Unified_Ideograph", "Ideographic"},
    181938: {"Unified_Ideograph", "Ideographic"},
    181939: {"Unified_Ideograph", "Ideographic"},
    181940: {"Unified_Ideograph", "Ideographic"},
    181941: {"Unified_Ideograph", "Ideographic"},
    181942: {"Unified_Ideograph", "Ideographic"},
    181943: {"Unified_Ideograph", "Ideographic"},
    181944: {"Unified_Ideograph", "Ideographic"},
    181945: {"Unified_Ideograph", "Ideographic"},
    181946: {"Unified_Ideograph", "Ideographic"},
    181947: {"Unified_Ideograph", "Ideographic"},
    181948: {"Unified_Ideograph", "Ideographic"},
    181949: {"Unified_Ideograph", "Ideographic"},
    181950: {"Unified_Ideograph", "Ideographic"},
    181951: {"Unified_Ideograph", "Ideographic"},
    181952: {"Unified_Ideograph", "Ideographic"},
    181953: {"Unified_Ideograph", "Ideographic"},
    181954: {"Unified_Ideograph", "Ideographic"},
    181955: {"Unified_Ideograph", "Ideographic"},
    181956: {"Unified_Ideograph", "Ideographic"},
    181957: {"Unified_Ideograph", "Ideographic"},
    181958: {"Unified_Ideograph", "Ideographic"},
    181959: {"Unified_Ideograph", "Ideographic"},
    181960: {"Unified_Ideograph", "Ideographic"},
    181961: {"Unified_Ideograph", "Ideographic"},
    181962: {"Unified_Ideograph", "Ideographic"},
    181963: {"Unified_Ideograph", "Ideographic"},
    181964: {"Unified_Ideograph", "Ideographic"},
    181965: {"Unified_Ideograph", "Ideographic"},
    181966: {"Unified_Ideograph", "Ideographic"},
    181967: {"Unified_Ideograph", "Ideographic"},
    181968: {"Unified_Ideograph", "Ideographic"},
    181969: {"Unified_Ideograph", "Ideographic"},
    181970: {"Unified_Ideograph", "Ideographic"},
    181971: {"Unified_Ideograph", "Ideographic"},
    181972: {"Unified_Ideograph", "Ideographic"},
    181973: {"Unified_Ideograph", "Ideographic"},
    181974: {"Unified_Ideograph", "Ideographic"},
    181975: {"Unified_Ideograph", "Ideographic"},
    181976: {"Unified_Ideograph", "Ideographic"},
    181977: {"Unified_Ideograph", "Ideographic"},
    181978: {"Unified_Ideograph", "Ideographic"},
    181979: {"Unified_Ideograph", "Ideographic"},
    181980: {"Unified_Ideograph", "Ideographic"},
    181981: {"Unified_Ideograph", "Ideographic"},
    181982: {"Unified_Ideograph", "Ideographic"},
    181983: {"Unified_Ideograph", "Ideographic"},
    181984: {"Unified_Ideograph", "Ideographic"},
    181985: {"Unified_Ideograph", "Ideographic"},
    181986: {"Unified_Ideograph", "Ideographic"},
    181987: {"Unified_Ideograph", "Ideographic"},
    181988: {"Unified_Ideograph", "Ideographic"},
    181989: {"Unified_Ideograph", "Ideographic"},
    181990: {"Unified_Ideograph", "Ideographic"},
    181991: {"Unified_Ideograph", "Ideographic"},
    181992: {"Unified_Ideograph", "Ideographic"},
    181993: {"Unified_Ideograph", "Ideographic"},
    181994: {"Unified_Ideograph", "Ideographic"},
    181995: {"Unified_Ideograph", "Ideographic"},
    181996: {"Unified_Ideograph", "Ideographic"},
    181997: {"Unified_Ideograph", "Ideographic"},
    181998: {"Unified_Ideograph", "Ideographic"},
    181999: {"Unified_Ideograph", "Ideographic"},
    182000: {"Unified_Ideograph", "Ideographic"},
    182001: {"Unified_Ideograph", "Ideographic"},
    182002: {"Unified_Ideograph", "Ideographic"},
    182003: {"Unified_Ideograph", "Ideographic"},
    182004: {"Unified_Ideograph", "Ideographic"},
    182005: {"Unified_Ideograph", "Ideographic"},
    182006: {"Unified_Ideograph", "Ideographic"},
    182007: {"Unified_Ideograph", "Ideographic"},
    182008: {"Unified_Ideograph", "Ideographic"},
    182009: {"Unified_Ideograph", "Ideographic"},
    182010: {"Unified_Ideograph", "Ideographic"},
    182011: {"Unified_Ideograph", "Ideographic"},
    182012: {"Unified_Ideograph", "Ideographic"},
    182013: {"Unified_Ideograph", "Ideographic"},
    182014: {"Unified_Ideograph", "Ideographic"},
    182015: {"Unified_Ideograph", "Ideographic"},
    182016: {"Unified_Ideograph", "Ideographic"},
    182017: {"Unified_Ideograph", "Ideographic"},
    182018: {"Unified_Ideograph", "Ideographic"},
    182019: {"Unified_Ideograph", "Ideographic"},
    182020: {"Unified_Ideograph", "Ideographic"},
    182021: {"Unified_Ideograph", "Ideographic"},
    182022: {"Unified_Ideograph", "Ideographic"},
    182023: {"Unified_Ideograph", "Ideographic"},
    182024: {"Unified_Ideograph", "Ideographic"},
    182025: {"Unified_Ideograph", "Ideographic"},
    182026: {"Unified_Ideograph", "Ideographic"},
    182027: {"Unified_Ideograph", "Ideographic"},
    182028: {"Unified_Ideograph", "Ideographic"},
    182029: {"Unified_Ideograph", "Ideographic"},
    182030: {"Unified_Ideograph", "Ideographic"},
    182031: {"Unified_Ideograph", "Ideographic"},
    182032: {"Unified_Ideograph", "Ideographic"},
    182033: {"Unified_Ideograph", "Ideographic"},
    182034: {"Unified_Ideograph", "Ideographic"},
    182035: {"Unified_Ideograph", "Ideographic"},
    182036: {"Unified_Ideograph", "Ideographic"},
    182037: {"Unified_Ideograph", "Ideographic"},
    182038: {"Unified_Ideograph", "Ideographic"},
    182039: {"Unified_Ideograph", "Ideographic"},
    182040: {"Unified_Ideograph", "Ideographic"},
    182041: {"Unified_Ideograph", "Ideographic"},
    182042: {"Unified_Ideograph", "Ideographic"},
    182043: {"Unified_Ideograph", "Ideographic"},
    182044: {"Unified_Ideograph", "Ideographic"},
    182045: {"Unified_Ideograph", "Ideographic"},
    182046: {"Unified_Ideograph", "Ideographic"},
    182047: {"Unified_Ideograph", "Ideographic"},
    182048: {"Unified_Ideograph", "Ideographic"},
    182049: {"Unified_Ideograph", "Ideographic"},
    182050: {"Unified_Ideograph", "Ideographic"},
    182051: {"Unified_Ideograph", "Ideographic"},
    182052: {"Unified_Ideograph", "Ideographic"},
    182053: {"Unified_Ideograph", "Ideographic"},
    182054: {"Unified_Ideograph", "Ideographic"},
    182055: {"Unified_Ideograph", "Ideographic"},
    182056: {"Unified_Ideograph", "Ideographic"},
    182057: {"Unified_Ideograph", "Ideographic"},
    182058: {"Unified_Ideograph", "Ideographic"},
    182059: {"Unified_Ideograph", "Ideographic"},
    182060: {"Unified_Ideograph", "Ideographic"},
    182061: {"Unified_Ideograph", "Ideographic"},
    182062: {"Unified_Ideograph", "Ideographic"},
    182063: {"Unified_Ideograph", "Ideographic"},
    182064: {"Unified_Ideograph", "Ideographic"},
    182065: {"Unified_Ideograph", "Ideographic"},
    182066: {"Unified_Ideograph", "Ideographic"},
    182067: {"Unified_Ideograph", "Ideographic"},
    182068: {"Unified_Ideograph", "Ideographic"},
    182069: {"Unified_Ideograph", "Ideographic"},
    182070: {"Unified_Ideograph", "Ideographic"},
    182071: {"Unified_Ideograph", "Ideographic"},
    182072: {"Unified_Ideograph", "Ideographic"},
    182073: {"Unified_Ideograph", "Ideographic"},
    182074: {"Unified_Ideograph", "Ideographic"},
    182075: {"Unified_Ideograph", "Ideographic"},
    182076: {"Unified_Ideograph", "Ideographic"},
    182077: {"Unified_Ideograph", "Ideographic"},
    182078: {"Unified_Ideograph", "Ideographic"},
    182079: {"Unified_Ideograph", "Ideographic"},
    182080: {"Unified_Ideograph", "Ideographic"},
    182081: {"Unified_Ideograph", "Ideographic"},
    182082: {"Unified_Ideograph", "Ideographic"},
    182083: {"Unified_Ideograph", "Ideographic"},
    182084: {"Unified_Ideograph", "Ideographic"},
    182085: {"Unified_Ideograph", "Ideographic"},
    182086: {"Unified_Ideograph", "Ideographic"},
    182087: {"Unified_Ideograph", "Ideographic"},
    182088: {"Unified_Ideograph", "Ideographic"},
    182089: {"Unified_Ideograph", "Ideographic"},
    182090: {"Unified_Ideograph", "Ideographic"},
    182091: {"Unified_Ideograph", "Ideographic"},
    182092: {"Unified_Ideograph", "Ideographic"},
    182093: {"Unified_Ideograph", "Ideographic"},
    182094: {"Unified_Ideograph", "Ideographic"},
    182095: {"Unified_Ideograph", "Ideographic"},
    182096: {"Unified_Ideograph", "Ideographic"},
    182097: {"Unified_Ideograph", "Ideographic"},
    182098: {"Unified_Ideograph", "Ideographic"},
    182099: {"Unified_Ideograph", "Ideographic"},
    182100: {"Unified_Ideograph", "Ideographic"},
    182101: {"Unified_Ideograph", "Ideographic"},
    182102: {"Unified_Ideograph", "Ideographic"},
    182103: {"Unified_Ideograph", "Ideographic"},
    182104: {"Unified_Ideograph", "Ideographic"},
    182105: {"Unified_Ideograph", "Ideographic"},
    182106: {"Unified_Ideograph", "Ideographic"},
    182107: {"Unified_Ideograph", "Ideographic"},
    182108: {"Unified_Ideograph", "Ideographic"},
    182109: {"Unified_Ideograph", "Ideographic"},
    182110: {"Unified_Ideograph", "Ideographic"},
    182111: {"Unified_Ideograph", "Ideographic"},
    182112: {"Unified_Ideograph", "Ideographic"},
    182113: {"Unified_Ideograph", "Ideographic"},
    182114: {"Unified_Ideograph", "Ideographic"},
    182115: {"Unified_Ideograph", "Ideographic"},
    182116: {"Unified_Ideograph", "Ideographic"},
    182117: {"Unified_Ideograph", "Ideographic"},
    182118: {"Unified_Ideograph", "Ideographic"},
    182119: {"Unified_Ideograph", "Ideographic"},
    182120: {"Unified_Ideograph", "Ideographic"},
    182121: {"Unified_Ideograph", "Ideographic"},
    182122: {"Unified_Ideograph", "Ideographic"},
    182123: {"Unified_Ideograph", "Ideographic"},
    182124: {"Unified_Ideograph", "Ideographic"},
    182125: {"Unified_Ideograph", "Ideographic"},
    182126: {"Unified_Ideograph", "Ideographic"},
    182127: {"Unified_Ideograph", "Ideographic"},
    182128: {"Unified_Ideograph", "Ideographic"},
    182129: {"Unified_Ideograph", "Ideographic"},
    182130: {"Unified_Ideograph", "Ideographic"},
    182131: {"Unified_Ideograph", "Ideographic"},
    182132: {"Unified_Ideograph", "Ideographic"},
    182133: {"Unified_Ideograph", "Ideographic"},
    182134: {"Unified_Ideograph", "Ideographic"},
    182135: {"Unified_Ideograph", "Ideographic"},
    182136: {"Unified_Ideograph", "Ideographic"},
    182137: {"Unified_Ideograph", "Ideographic"},
    182138: {"Unified_Ideograph", "Ideographic"},
    182139: {"Unified_Ideograph", "Ideographic"},
    182140: {"Unified_Ideograph", "Ideographic"},
    182141: {"Unified_Ideograph", "Ideographic"},
    182142: {"Unified_Ideograph", "Ideographic"},
    182143: {"Unified_Ideograph", "Ideographic"},
    182144: {"Unified_Ideograph", "Ideographic"},
    182145: {"Unified_Ideograph", "Ideographic"},
    182146: {"Unified_Ideograph", "Ideographic"},
    182147: {"Unified_Ideograph", "Ideographic"},
    182148: {"Unified_Ideograph", "Ideographic"},
    182149: {"Unified_Ideograph", "Ideographic"},
    182150: {"Unified_Ideograph", "Ideographic"},
    182151: {"Unified_Ideograph", "Ideographic"},
    182152: {"Unified_Ideograph", "Ideographic"},
    182153: {"Unified_Ideograph", "Ideographic"},
    182154: {"Unified_Ideograph", "Ideographic"},
    182155: {"Unified_Ideograph", "Ideographic"},
    182156: {"Unified_Ideograph", "Ideographic"},
    182157: {"Unified_Ideograph", "Ideographic"},
    182158: {"Unified_Ideograph", "Ideographic"},
    182159: {"Unified_Ideograph", "Ideographic"},
    182160: {"Unified_Ideograph", "Ideographic"},
    182161: {"Unified_Ideograph", "Ideographic"},
    182162: {"Unified_Ideograph", "Ideographic"},
    182163: {"Unified_Ideograph", "Ideographic"},
    182164: {"Unified_Ideograph", "Ideographic"},
    182165: {"Unified_Ideograph", "Ideographic"},
    182166: {"Unified_Ideograph", "Ideographic"},
    182167: {"Unified_Ideograph", "Ideographic"},
    182168: {"Unified_Ideograph", "Ideographic"},
    182169: {"Unified_Ideograph", "Ideographic"},
    182170: {"Unified_Ideograph", "Ideographic"},
    182171: {"Unified_Ideograph", "Ideographic"},
    182172: {"Unified_Ideograph", "Ideographic"},
    182173: {"Unified_Ideograph", "Ideographic"},
    182174: {"Unified_Ideograph", "Ideographic"},
    182175: {"Unified_Ideograph", "Ideographic"},
    182176: {"Unified_Ideograph", "Ideographic"},
    182177: {"Unified_Ideograph", "Ideographic"},
    182178: {"Unified_Ideograph", "Ideographic"},
    182179: {"Unified_Ideograph", "Ideographic"},
    182180: {"Unified_Ideograph", "Ideographic"},
    182181: {"Unified_Ideograph", "Ideographic"},
    182182: {"Unified_Ideograph", "Ideographic"},
    182183: {"Unified_Ideograph", "Ideographic"},
    182184: {"Unified_Ideograph", "Ideographic"},
    182185: {"Unified_Ideograph", "Ideographic"},
    182186: {"Unified_Ideograph", "Ideographic"},
    182187: {"Unified_Ideograph", "Ideographic"},
    182188: {"Unified_Ideograph", "Ideographic"},
    182189: {"Unified_Ideograph", "Ideographic"},
    182190: {"Unified_Ideograph", "Ideographic"},
    182191: {"Unified_Ideograph", "Ideographic"},
    182192: {"Unified_Ideograph", "Ideographic"},
    182193: {"Unified_Ideograph", "Ideographic"},
    182194: {"Unified_Ideograph", "Ideographic"},
    182195: {"Unified_Ideograph", "Ideographic"},
    182196: {"Unified_Ideograph", "Ideographic"},
    182197: {"Unified_Ideograph", "Ideographic"},
    182198: {"Unified_Ideograph", "Ideographic"},
    182199: {"Unified_Ideograph", "Ideographic"},
    182200: {"Unified_Ideograph", "Ideographic"},
    182201: {"Unified_Ideograph", "Ideographic"},
    182202: {"Unified_Ideograph", "Ideographic"},
    182203: {"Unified_Ideograph", "Ideographic"},
    182204: {"Unified_Ideograph", "Ideographic"},
    182205: {"Unified_Ideograph", "Ideographic"},
    182206: {"Unified_Ideograph", "Ideographic"},
    182207: {"Unified_Ideograph", "Ideographic"},
    182208: {"Unified_Ideograph", "Ideographic"},
    182209: {"Unified_Ideograph", "Ideographic"},
    182210: {"Unified_Ideograph", "Ideographic"},
    182211: {"Unified_Ideograph", "Ideographic"},
    182212: {"Unified_Ideograph", "Ideographic"},
    182213: {"Unified_Ideograph", "Ideographic"},
    182214: {"Unified_Ideograph", "Ideographic"},
    182215: {"Unified_Ideograph", "Ideographic"},
    182216: {"Unified_Ideograph", "Ideographic"},
    182217: {"Unified_Ideograph", "Ideographic"},
    182218: {"Unified_Ideograph", "Ideographic"},
    182219: {"Unified_Ideograph", "Ideographic"},
    182220: {"Unified_Ideograph", "Ideographic"},
    182221: {"Unified_Ideograph", "Ideographic"},
    182222: {"Unified_Ideograph", "Ideographic"},
    182223: {"Unified_Ideograph", "Ideographic"},
    182224: {"Unified_Ideograph", "Ideographic"},
    182225: {"Unified_Ideograph", "Ideographic"},
    182226: {"Unified_Ideograph", "Ideographic"},
    182227: {"Unified_Ideograph", "Ideographic"},
    182228: {"Unified_Ideograph", "Ideographic"},
    182229: {"Unified_Ideograph", "Ideographic"},
    182230: {"Unified_Ideograph", "Ideographic"},
    182231: {"Unified_Ideograph", "Ideographic"},
    182232: {"Unified_Ideograph", "Ideographic"},
    182233: {"Unified_Ideograph", "Ideographic"},
    182234: {"Unified_Ideograph", "Ideographic"},
    182235: {"Unified_Ideograph", "Ideographic"},
    182236: {"Unified_Ideograph", "Ideographic"},
    182237: {"Unified_Ideograph", "Ideographic"},
    182238: {"Unified_Ideograph", "Ideographic"},
    182239: {"Unified_Ideograph", "Ideographic"},
    182240: {"Unified_Ideograph", "Ideographic"},
    182241: {"Unified_Ideograph", "Ideographic"},
    182242: {"Unified_Ideograph", "Ideographic"},
    182243: {"Unified_Ideograph", "Ideographic"},
    182244: {"Unified_Ideograph", "Ideographic"},
    182245: {"Unified_Ideograph", "Ideographic"},
    182246: {"Unified_Ideograph", "Ideographic"},
    182247: {"Unified_Ideograph", "Ideographic"},
    182248: {"Unified_Ideograph", "Ideographic"},
    182249: {"Unified_Ideograph", "Ideographic"},
    182250: {"Unified_Ideograph", "Ideographic"},
    182251: {"Unified_Ideograph", "Ideographic"},
    182252: {"Unified_Ideograph", "Ideographic"},
    182253: {"Unified_Ideograph", "Ideographic"},
    182254: {"Unified_Ideograph", "Ideographic"},
    182255: {"Unified_Ideograph", "Ideographic"},
    182256: {"Unified_Ideograph", "Ideographic"},
    182257: {"Unified_Ideograph", "Ideographic"},
    182258: {"Unified_Ideograph", "Ideographic"},
    182259: {"Unified_Ideograph", "Ideographic"},
    182260: {"Unified_Ideograph", "Ideographic"},
    182261: {"Unified_Ideograph", "Ideographic"},
    182262: {"Unified_Ideograph", "Ideographic"},
    182263: {"Unified_Ideograph", "Ideographic"},
    182264: {"Unified_Ideograph", "Ideographic"},
    182265: {"Unified_Ideograph", "Ideographic"},
    182266: {"Unified_Ideograph", "Ideographic"},
    182267: {"Unified_Ideograph", "Ideographic"},
    182268: {"Unified_Ideograph", "Ideographic"},
    182269: {"Unified_Ideograph", "Ideographic"},
    182270: {"Unified_Ideograph", "Ideographic"},
    182271: {"Unified_Ideograph", "Ideographic"},
    182272: {"Unified_Ideograph", "Ideographic"},
    182273: {"Unified_Ideograph", "Ideographic"},
    182274: {"Unified_Ideograph", "Ideographic"},
    182275: {"Unified_Ideograph", "Ideographic"},
    182276: {"Unified_Ideograph", "Ideographic"},
    182277: {"Unified_Ideograph", "Ideographic"},
    182278: {"Unified_Ideograph", "Ideographic"},
    182279: {"Unified_Ideograph", "Ideographic"},
    182280: {"Unified_Ideograph", "Ideographic"},
    182281: {"Unified_Ideograph", "Ideographic"},
    182282: {"Unified_Ideograph", "Ideographic"},
    182283: {"Unified_Ideograph", "Ideographic"},
    182284: {"Unified_Ideograph", "Ideographic"},
    182285: {"Unified_Ideograph", "Ideographic"},
    182286: {"Unified_Ideograph", "Ideographic"},
    182287: {"Unified_Ideograph", "Ideographic"},
    182288: {"Unified_Ideograph", "Ideographic"},
    182289: {"Unified_Ideograph", "Ideographic"},
    182290: {"Unified_Ideograph", "Ideographic"},
    182291: {"Unified_Ideograph", "Ideographic"},
    182292: {"Unified_Ideograph", "Ideographic"},
    182293: {"Unified_Ideograph", "Ideographic"},
    182294: {"Unified_Ideograph", "Ideographic"},
    182295: {"Unified_Ideograph", "Ideographic"},
    182296: {"Unified_Ideograph", "Ideographic"},
    182297: {"Unified_Ideograph", "Ideographic"},
    182298: {"Unified_Ideograph", "Ideographic"},
    182299: {"Unified_Ideograph", "Ideographic"},
    182300: {"Unified_Ideograph", "Ideographic"},
    182301: {"Unified_Ideograph", "Ideographic"},
    182302: {"Unified_Ideograph", "Ideographic"},
    182303: {"Unified_Ideograph", "Ideographic"},
    182304: {"Unified_Ideograph", "Ideographic"},
    182305: {"Unified_Ideograph", "Ideographic"},
    182306: {"Unified_Ideograph", "Ideographic"},
    182307: {"Unified_Ideograph", "Ideographic"},
    182308: {"Unified_Ideograph", "Ideographic"},
    182309: {"Unified_Ideograph", "Ideographic"},
    182310: {"Unified_Ideograph", "Ideographic"},
    182311: {"Unified_Ideograph", "Ideographic"},
    182312: {"Unified_Ideograph", "Ideographic"},
    182313: {"Unified_Ideograph", "Ideographic"},
    182314: {"Unified_Ideograph", "Ideographic"},
    182315: {"Unified_Ideograph", "Ideographic"},
    182316: {"Unified_Ideograph", "Ideographic"},
    182317: {"Unified_Ideograph", "Ideographic"},
    182318: {"Unified_Ideograph", "Ideographic"},
    182319: {"Unified_Ideograph", "Ideographic"},
    182320: {"Unified_Ideograph", "Ideographic"},
    182321: {"Unified_Ideograph", "Ideographic"},
    182322: {"Unified_Ideograph", "Ideographic"},
    182323: {"Unified_Ideograph", "Ideographic"},
    182324: {"Unified_Ideograph", "Ideographic"},
    182325: {"Unified_Ideograph", "Ideographic"},
    182326: {"Unified_Ideograph", "Ideographic"},
    182327: {"Unified_Ideograph", "Ideographic"},
    182328: {"Unified_Ideograph", "Ideographic"},
    182329: {"Unified_Ideograph", "Ideographic"},
    182330: {"Unified_Ideograph", "Ideographic"},
    182331: {"Unified_Ideograph", "Ideographic"},
    182332: {"Unified_Ideograph", "Ideographic"},
    182333: {"Unified_Ideograph", "Ideographic"},
    182334: {"Unified_Ideograph", "Ideographic"},
    182335: {"Unified_Ideograph", "Ideographic"},
    182336: {"Unified_Ideograph", "Ideographic"},
    182337: {"Unified_Ideograph", "Ideographic"},
    182338: {"Unified_Ideograph", "Ideographic"},
    182339: {"Unified_Ideograph", "Ideographic"},
    182340: {"Unified_Ideograph", "Ideographic"},
    182341: {"Unified_Ideograph", "Ideographic"},
    182342: {"Unified_Ideograph", "Ideographic"},
    182343: {"Unified_Ideograph", "Ideographic"},
    182344: {"Unified_Ideograph", "Ideographic"},
    182345: {"Unified_Ideograph", "Ideographic"},
    182346: {"Unified_Ideograph", "Ideographic"},
    182347: {"Unified_Ideograph", "Ideographic"},
    182348: {"Unified_Ideograph", "Ideographic"},
    182349: {"Unified_Ideograph", "Ideographic"},
    182350: {"Unified_Ideograph", "Ideographic"},
    182351: {"Unified_Ideograph", "Ideographic"},
    182352: {"Unified_Ideograph", "Ideographic"},
    182353: {"Unified_Ideograph", "Ideographic"},
    182354: {"Unified_Ideograph", "Ideographic"},
    182355: {"Unified_Ideograph", "Ideographic"},
    182356: {"Unified_Ideograph", "Ideographic"},
    182357: {"Unified_Ideograph", "Ideographic"},
    182358: {"Unified_Ideograph", "Ideographic"},
    182359: {"Unified_Ideograph", "Ideographic"},
    182360: {"Unified_Ideograph", "Ideographic"},
    182361: {"Unified_Ideograph", "Ideographic"},
    182362: {"Unified_Ideograph", "Ideographic"},
    182363: {"Unified_Ideograph", "Ideographic"},
    182364: {"Unified_Ideograph", "Ideographic"},
    182365: {"Unified_Ideograph", "Ideographic"},
    182366: {"Unified_Ideograph", "Ideographic"},
    182367: {"Unified_Ideograph", "Ideographic"},
    182368: {"Unified_Ideograph", "Ideographic"},
    182369: {"Unified_Ideograph", "Ideographic"},
    182370: {"Unified_Ideograph", "Ideographic"},
    182371: {"Unified_Ideograph", "Ideographic"},
    182372: {"Unified_Ideograph", "Ideographic"},
    182373: {"Unified_Ideograph", "Ideographic"},
    182374: {"Unified_Ideograph", "Ideographic"},
    182375: {"Unified_Ideograph", "Ideographic"},
    182376: {"Unified_Ideograph", "Ideographic"},
    182377: {"Unified_Ideograph", "Ideographic"},
    182378: {"Unified_Ideograph", "Ideographic"},
    182379: {"Unified_Ideograph", "Ideographic"},
    182380: {"Unified_Ideograph", "Ideographic"},
    182381: {"Unified_Ideograph", "Ideographic"},
    182382: {"Unified_Ideograph", "Ideographic"},
    182383: {"Unified_Ideograph", "Ideographic"},
    182384: {"Unified_Ideograph", "Ideographic"},
    182385: {"Unified_Ideograph", "Ideographic"},
    182386: {"Unified_Ideograph", "Ideographic"},
    182387: {"Unified_Ideograph", "Ideographic"},
    182388: {"Unified_Ideograph", "Ideographic"},
    182389: {"Unified_Ideograph", "Ideographic"},
    182390: {"Unified_Ideograph", "Ideographic"},
    182391: {"Unified_Ideograph", "Ideographic"},
    182392: {"Unified_Ideograph", "Ideographic"},
    182393: {"Unified_Ideograph", "Ideographic"},
    182394: {"Unified_Ideograph", "Ideographic"},
    182395: {"Unified_Ideograph", "Ideographic"},
    182396: {"Unified_Ideograph", "Ideographic"},
    182397: {"Unified_Ideograph", "Ideographic"},
    182398: {"Unified_Ideograph", "Ideographic"},
    182399: {"Unified_Ideograph", "Ideographic"},
    182400: {"Unified_Ideograph", "Ideographic"},
    182401: {"Unified_Ideograph", "Ideographic"},
    182402: {"Unified_Ideograph", "Ideographic"},
    182403: {"Unified_Ideograph", "Ideographic"},
    182404: {"Unified_Ideograph", "Ideographic"},
    182405: {"Unified_Ideograph", "Ideographic"},
    182406: {"Unified_Ideograph", "Ideographic"},
    182407: {"Unified_Ideograph", "Ideographic"},
    182408: {"Unified_Ideograph", "Ideographic"},
    182409: {"Unified_Ideograph", "Ideographic"},
    182410: {"Unified_Ideograph", "Ideographic"},
    182411: {"Unified_Ideograph", "Ideographic"},
    182412: {"Unified_Ideograph", "Ideographic"},
    182413: {"Unified_Ideograph", "Ideographic"},
    182414: {"Unified_Ideograph", "Ideographic"},
    182415: {"Unified_Ideograph", "Ideographic"},
    182416: {"Unified_Ideograph", "Ideographic"},
    182417: {"Unified_Ideograph", "Ideographic"},
    182418: {"Unified_Ideograph", "Ideographic"},
    182419: {"Unified_Ideograph", "Ideographic"},
    182420: {"Unified_Ideograph", "Ideographic"},
    182421: {"Unified_Ideograph", "Ideographic"},
    182422: {"Unified_Ideograph", "Ideographic"},
    182423: {"Unified_Ideograph", "Ideographic"},
    182424: {"Unified_Ideograph", "Ideographic"},
    182425: {"Unified_Ideograph", "Ideographic"},
    182426: {"Unified_Ideograph", "Ideographic"},
    182427: {"Unified_Ideograph", "Ideographic"},
    182428: {"Unified_Ideograph", "Ideographic"},
    182429: {"Unified_Ideograph", "Ideographic"},
    182430: {"Unified_Ideograph", "Ideographic"},
    182431: {"Unified_Ideograph", "Ideographic"},
    182432: {"Unified_Ideograph", "Ideographic"},
    182433: {"Unified_Ideograph", "Ideographic"},
    182434: {"Unified_Ideograph", "Ideographic"},
    182435: {"Unified_Ideograph", "Ideographic"},
    182436: {"Unified_Ideograph", "Ideographic"},
    182437: {"Unified_Ideograph", "Ideographic"},
    182438: {"Unified_Ideograph", "Ideographic"},
    182439: {"Unified_Ideograph", "Ideographic"},
    182440: {"Unified_Ideograph", "Ideographic"},
    182441: {"Unified_Ideograph", "Ideographic"},
    182442: {"Unified_Ideograph", "Ideographic"},
    182443: {"Unified_Ideograph", "Ideographic"},
    182444: {"Unified_Ideograph", "Ideographic"},
    182445: {"Unified_Ideograph", "Ideographic"},
    182446: {"Unified_Ideograph", "Ideographic"},
    182447: {"Unified_Ideograph", "Ideographic"},
    182448: {"Unified_Ideograph", "Ideographic"},
    182449: {"Unified_Ideograph", "Ideographic"},
    182450: {"Unified_Ideograph", "Ideographic"},
    182451: {"Unified_Ideograph", "Ideographic"},
    182452: {"Unified_Ideograph", "Ideographic"},
    182453: {"Unified_Ideograph", "Ideographic"},
    182454: {"Unified_Ideograph", "Ideographic"},
    182455: {"Unified_Ideograph", "Ideographic"},
    182456: {"Unified_Ideograph", "Ideographic"},
    182457: {"Unified_Ideograph", "Ideographic"},
    182458: {"Unified_Ideograph", "Ideographic"},
    182459: {"Unified_Ideograph", "Ideographic"},
    182460: {"Unified_Ideograph", "Ideographic"},
    182461: {"Unified_Ideograph", "Ideographic"},
    182462: {"Unified_Ideograph", "Ideographic"},
    182463: {"Unified_Ideograph", "Ideographic"},
    182464: {"Unified_Ideograph", "Ideographic"},
    182465: {"Unified_Ideograph", "Ideographic"},
    182466: {"Unified_Ideograph", "Ideographic"},
    182467: {"Unified_Ideograph", "Ideographic"},
    182468: {"Unified_Ideograph", "Ideographic"},
    182469: {"Unified_Ideograph", "Ideographic"},
    182470: {"Unified_Ideograph", "Ideographic"},
    182471: {"Unified_Ideograph", "Ideographic"},
    182472: {"Unified_Ideograph", "Ideographic"},
    182473: {"Unified_Ideograph", "Ideographic"},
    182474: {"Unified_Ideograph", "Ideographic"},
    182475: {"Unified_Ideograph", "Ideographic"},
    182476: {"Unified_Ideograph", "Ideographic"},
    182477: {"Unified_Ideograph", "Ideographic"},
    182478: {"Unified_Ideograph", "Ideographic"},
    182479: {"Unified_Ideograph", "Ideographic"},
    182480: {"Unified_Ideograph", "Ideographic"},
    182481: {"Unified_Ideograph", "Ideographic"},
    182482: {"Unified_Ideograph", "Ideographic"},
    182483: {"Unified_Ideograph", "Ideographic"},
    182484: {"Unified_Ideograph", "Ideographic"},
    182485: {"Unified_Ideograph", "Ideographic"},
    182486: {"Unified_Ideograph", "Ideographic"},
    182487: {"Unified_Ideograph", "Ideographic"},
    182488: {"Unified_Ideograph", "Ideographic"},
    182489: {"Unified_Ideograph", "Ideographic"},
    182490: {"Unified_Ideograph", "Ideographic"},
    182491: {"Unified_Ideograph", "Ideographic"},
    182492: {"Unified_Ideograph", "Ideographic"},
    182493: {"Unified_Ideograph", "Ideographic"},
    182494: {"Unified_Ideograph", "Ideographic"},
    182495: {"Unified_Ideograph", "Ideographic"},
    182496: {"Unified_Ideograph", "Ideographic"},
    182497: {"Unified_Ideograph", "Ideographic"},
    182498: {"Unified_Ideograph", "Ideographic"},
    182499: {"Unified_Ideograph", "Ideographic"},
    182500: {"Unified_Ideograph", "Ideographic"},
    182501: {"Unified_Ideograph", "Ideographic"},
    182502: {"Unified_Ideograph", "Ideographic"},
    182503: {"Unified_Ideograph", "Ideographic"},
    182504: {"Unified_Ideograph", "Ideographic"},
    182505: {"Unified_Ideograph", "Ideographic"},
    182506: {"Unified_Ideograph", "Ideographic"},
    182507: {"Unified_Ideograph", "Ideographic"},
    182508: {"Unified_Ideograph", "Ideographic"},
    182509: {"Unified_Ideograph", "Ideographic"},
    182510: {"Unified_Ideograph", "Ideographic"},
    182511: {"Unified_Ideograph", "Ideographic"},
    182512: {"Unified_Ideograph", "Ideographic"},
    182513: {"Unified_Ideograph", "Ideographic"},
    182514: {"Unified_Ideograph", "Ideographic"},
    182515: {"Unified_Ideograph", "Ideographic"},
    182516: {"Unified_Ideograph", "Ideographic"},
    182517: {"Unified_Ideograph", "Ideographic"},
    182518: {"Unified_Ideograph", "Ideographic"},
    182519: {"Unified_Ideograph", "Ideographic"},
    182520: {"Unified_Ideograph", "Ideographic"},
    182521: {"Unified_Ideograph", "Ideographic"},
    182522: {"Unified_Ideograph", "Ideographic"},
    182523: {"Unified_Ideograph", "Ideographic"},
    182524: {"Unified_Ideograph", "Ideographic"},
    182525: {"Unified_Ideograph", "Ideographic"},
    182526: {"Unified_Ideograph", "Ideographic"},
    182527: {"Unified_Ideograph", "Ideographic"},
    182528: {"Unified_Ideograph", "Ideographic"},
    182529: {"Unified_Ideograph", "Ideographic"},
    182530: {"Unified_Ideograph", "Ideographic"},
    182531: {"Unified_Ideograph", "Ideographic"},
    182532: {"Unified_Ideograph", "Ideographic"},
    182533: {"Unified_Ideograph", "Ideographic"},
    182534: {"Unified_Ideograph", "Ideographic"},
    182535: {"Unified_Ideograph", "Ideographic"},
    182536: {"Unified_Ideograph", "Ideographic"},
    182537: {"Unified_Ideograph", "Ideographic"},
    182538: {"Unified_Ideograph", "Ideographic"},
    182539: {"Unified_Ideograph", "Ideographic"},
    182540: {"Unified_Ideograph", "Ideographic"},
    182541: {"Unified_Ideograph", "Ideographic"},
    182542: {"Unified_Ideograph", "Ideographic"},
    182543: {"Unified_Ideograph", "Ideographic"},
    182544: {"Unified_Ideograph", "Ideographic"},
    182545: {"Unified_Ideograph", "Ideographic"},
    182546: {"Unified_Ideograph", "Ideographic"},
    182547: {"Unified_Ideograph", "Ideographic"},
    182548: {"Unified_Ideograph", "Ideographic"},
    182549: {"Unified_Ideograph", "Ideographic"},
    182550: {"Unified_Ideograph", "Ideographic"},
    182551: {"Unified_Ideograph", "Ideographic"},
    182552: {"Unified_Ideograph", "Ideographic"},
    182553: {"Unified_Ideograph", "Ideographic"},
    182554: {"Unified_Ideograph", "Ideographic"},
    182555: {"Unified_Ideograph", "Ideographic"},
    182556: {"Unified_Ideograph", "Ideographic"},
    182557: {"Unified_Ideograph", "Ideographic"},
    182558: {"Unified_Ideograph", "Ideographic"},
    182559: {"Unified_Ideograph", "Ideographic"},
    182560: {"Unified_Ideograph", "Ideographic"},
    182561: {"Unified_Ideograph", "Ideographic"},
    182562: {"Unified_Ideograph", "Ideographic"},
    182563: {"Unified_Ideograph", "Ideographic"},
    182564: {"Unified_Ideograph", "Ideographic"},
    182565: {"Unified_Ideograph", "Ideographic"},
    182566: {"Unified_Ideograph", "Ideographic"},
    182567: {"Unified_Ideograph", "Ideographic"},
    182568: {"Unified_Ideograph", "Ideographic"},
    182569: {"Unified_Ideograph", "Ideographic"},
    182570: {"Unified_Ideograph", "Ideographic"},
    182571: {"Unified_Ideograph", "Ideographic"},
    182572: {"Unified_Ideograph", "Ideographic"},
    182573: {"Unified_Ideograph", "Ideographic"},
    182574: {"Unified_Ideograph", "Ideographic"},
    182575: {"Unified_Ideograph", "Ideographic"},
    182576: {"Unified_Ideograph", "Ideographic"},
    182577: {"Unified_Ideograph", "Ideographic"},
    182578: {"Unified_Ideograph", "Ideographic"},
    182579: {"Unified_Ideograph", "Ideographic"},
    182580: {"Unified_Ideograph", "Ideographic"},
    182581: {"Unified_Ideograph", "Ideographic"},
    182582: {"Unified_Ideograph", "Ideographic"},
    182583: {"Unified_Ideograph", "Ideographic"},
    182584: {"Unified_Ideograph", "Ideographic"},
    182585: {"Unified_Ideograph", "Ideographic"},
    182586: {"Unified_Ideograph", "Ideographic"},
    182587: {"Unified_Ideograph", "Ideographic"},
    182588: {"Unified_Ideograph", "Ideographic"},
    182589: {"Unified_Ideograph", "Ideographic"},
    182590: {"Unified_Ideograph", "Ideographic"},
    182591: {"Unified_Ideograph", "Ideographic"},
    182592: {"Unified_Ideograph", "Ideographic"},
    182593: {"Unified_Ideograph", "Ideographic"},
    182594: {"Unified_Ideograph", "Ideographic"},
    182595: {"Unified_Ideograph", "Ideographic"},
    182596: {"Unified_Ideograph", "Ideographic"},
    182597: {"Unified_Ideograph", "Ideographic"},
    182598: {"Unified_Ideograph", "Ideographic"},
    182599: {"Unified_Ideograph", "Ideographic"},
    182600: {"Unified_Ideograph", "Ideographic"},
    182601: {"Unified_Ideograph", "Ideographic"},
    182602: {"Unified_Ideograph", "Ideographic"},
    182603: {"Unified_Ideograph", "Ideographic"},
    182604: {"Unified_Ideograph", "Ideographic"},
    182605: {"Unified_Ideograph", "Ideographic"},
    182606: {"Unified_Ideograph", "Ideographic"},
    182607: {"Unified_Ideograph", "Ideographic"},
    182608: {"Unified_Ideograph", "Ideographic"},
    182609: {"Unified_Ideograph", "Ideographic"},
    182610: {"Unified_Ideograph", "Ideographic"},
    182611: {"Unified_Ideograph", "Ideographic"},
    182612: {"Unified_Ideograph", "Ideographic"},
    182613: {"Unified_Ideograph", "Ideographic"},
    182614: {"Unified_Ideograph", "Ideographic"},
    182615: {"Unified_Ideograph", "Ideographic"},
    182616: {"Unified_Ideograph", "Ideographic"},
    182617: {"Unified_Ideograph", "Ideographic"},
    182618: {"Unified_Ideograph", "Ideographic"},
    182619: {"Unified_Ideograph", "Ideographic"},
    182620: {"Unified_Ideograph", "Ideographic"},
    182621: {"Unified_Ideograph", "Ideographic"},
    182622: {"Unified_Ideograph", "Ideographic"},
    182623: {"Unified_Ideograph", "Ideographic"},
    182624: {"Unified_Ideograph", "Ideographic"},
    182625: {"Unified_Ideograph", "Ideographic"},
    182626: {"Unified_Ideograph", "Ideographic"},
    182627: {"Unified_Ideograph", "Ideographic"},
    182628: {"Unified_Ideograph", "Ideographic"},
    182629: {"Unified_Ideograph", "Ideographic"},
    182630: {"Unified_Ideograph", "Ideographic"},
    182631: {"Unified_Ideograph", "Ideographic"},
    182632: {"Unified_Ideograph", "Ideographic"},
    182633: {"Unified_Ideograph", "Ideographic"},
    182634: {"Unified_Ideograph", "Ideographic"},
    182635: {"Unified_Ideograph", "Ideographic"},
    182636: {"Unified_Ideograph", "Ideographic"},
    182637: {"Unified_Ideograph", "Ideographic"},
    182638: {"Unified_Ideograph", "Ideographic"},
    182639: {"Unified_Ideograph", "Ideographic"},
    182640: {"Unified_Ideograph", "Ideographic"},
    182641: {"Unified_Ideograph", "Ideographic"},
    182642: {"Unified_Ideograph", "Ideographic"},
    182643: {"Unified_Ideograph", "Ideographic"},
    182644: {"Unified_Ideograph", "Ideographic"},
    182645: {"Unified_Ideograph", "Ideographic"},
    182646: {"Unified_Ideograph", "Ideographic"},
    182647: {"Unified_Ideograph", "Ideographic"},
    182648: {"Unified_Ideograph", "Ideographic"},
    182649: {"Unified_Ideograph", "Ideographic"},
    182650: {"Unified_Ideograph", "Ideographic"},
    182651: {"Unified_Ideograph", "Ideographic"},
    182652: {"Unified_Ideograph", "Ideographic"},
    182653: {"Unified_Ideograph", "Ideographic"},
    182654: {"Unified_Ideograph", "Ideographic"},
    182655: {"Unified_Ideograph", "Ideographic"},
    182656: {"Unified_Ideograph", "Ideographic"},
    182657: {"Unified_Ideograph", "Ideographic"},
    182658: {"Unified_Ideograph", "Ideographic"},
    182659: {"Unified_Ideograph", "Ideographic"},
    182660: {"Unified_Ideograph", "Ideographic"},
    182661: {"Unified_Ideograph", "Ideographic"},
    182662: {"Unified_Ideograph", "Ideographic"},
    182663: {"Unified_Ideograph", "Ideographic"},
    182664: {"Unified_Ideograph", "Ideographic"},
    182665: {"Unified_Ideograph", "Ideographic"},
    182666: {"Unified_Ideograph", "Ideographic"},
    182667: {"Unified_Ideograph", "Ideographic"},
    182668: {"Unified_Ideograph", "Ideographic"},
    182669: {"Unified_Ideograph", "Ideographic"},
    182670: {"Unified_Ideograph", "Ideographic"},
    182671: {"Unified_Ideograph", "Ideographic"},
    182672: {"Unified_Ideograph", "Ideographic"},
    182673: {"Unified_Ideograph", "Ideographic"},
    182674: {"Unified_Ideograph", "Ideographic"},
    182675: {"Unified_Ideograph", "Ideographic"},
    182676: {"Unified_Ideograph", "Ideographic"},
    182677: {"Unified_Ideograph", "Ideographic"},
    182678: {"Unified_Ideograph", "Ideographic"},
    182679: {"Unified_Ideograph", "Ideographic"},
    182680: {"Unified_Ideograph", "Ideographic"},
    182681: {"Unified_Ideograph", "Ideographic"},
    182682: {"Unified_Ideograph", "Ideographic"},
    182683: {"Unified_Ideograph", "Ideographic"},
    182684: {"Unified_Ideograph", "Ideographic"},
    182685: {"Unified_Ideograph", "Ideographic"},
    182686: {"Unified_Ideograph", "Ideographic"},
    182687: {"Unified_Ideograph", "Ideographic"},
    182688: {"Unified_Ideograph", "Ideographic"},
    182689: {"Unified_Ideograph", "Ideographic"},
    182690: {"Unified_Ideograph", "Ideographic"},
    182691: {"Unified_Ideograph", "Ideographic"},
    182692: {"Unified_Ideograph", "Ideographic"},
    182693: {"Unified_Ideograph", "Ideographic"},
    182694: {"Unified_Ideograph", "Ideographic"},
    182695: {"Unified_Ideograph", "Ideographic"},
    182696: {"Unified_Ideograph", "Ideographic"},
    182697: {"Unified_Ideograph", "Ideographic"},
    182698: {"Unified_Ideograph", "Ideographic"},
    182699: {"Unified_Ideograph", "Ideographic"},
    182700: {"Unified_Ideograph", "Ideographic"},
    182701: {"Unified_Ideograph", "Ideographic"},
    182702: {"Unified_Ideograph", "Ideographic"},
    182703: {"Unified_Ideograph", "Ideographic"},
    182704: {"Unified_Ideograph", "Ideographic"},
    182705: {"Unified_Ideograph", "Ideographic"},
    182706: {"Unified_Ideograph", "Ideographic"},
    182707: {"Unified_Ideograph", "Ideographic"},
    182708: {"Unified_Ideograph", "Ideographic"},
    182709: {"Unified_Ideograph", "Ideographic"},
    182710: {"Unified_Ideograph", "Ideographic"},
    182711: {"Unified_Ideograph", "Ideographic"},
    182712: {"Unified_Ideograph", "Ideographic"},
    182713: {"Unified_Ideograph", "Ideographic"},
    182714: {"Unified_Ideograph", "Ideographic"},
    182715: {"Unified_Ideograph", "Ideographic"},
    182716: {"Unified_Ideograph", "Ideographic"},
    182717: {"Unified_Ideograph", "Ideographic"},
    182718: {"Unified_Ideograph", "Ideographic"},
    182719: {"Unified_Ideograph", "Ideographic"},
    182720: {"Unified_Ideograph", "Ideographic"},
    182721: {"Unified_Ideograph", "Ideographic"},
    182722: {"Unified_Ideograph", "Ideographic"},
    182723: {"Unified_Ideograph", "Ideographic"},
    182724: {"Unified_Ideograph", "Ideographic"},
    182725: {"Unified_Ideograph", "Ideographic"},
    182726: {"Unified_Ideograph", "Ideographic"},
    182727: {"Unified_Ideograph", "Ideographic"},
    182728: {"Unified_Ideograph", "Ideographic"},
    182729: {"Unified_Ideograph", "Ideographic"},
    182730: {"Unified_Ideograph", "Ideographic"},
    182731: {"Unified_Ideograph", "Ideographic"},
    182732: {"Unified_Ideograph", "Ideographic"},
    182733: {"Unified_Ideograph", "Ideographic"},
    182734: {"Unified_Ideograph", "Ideographic"},
    182735: {"Unified_Ideograph", "Ideographic"},
    182736: {"Unified_Ideograph", "Ideographic"},
    182737: {"Unified_Ideograph", "Ideographic"},
    182738: {"Unified_Ideograph", "Ideographic"},
    182739: {"Unified_Ideograph", "Ideographic"},
    182740: {"Unified_Ideograph", "Ideographic"},
    182741: {"Unified_Ideograph", "Ideographic"},
    182742: {"Unified_Ideograph", "Ideographic"},
    182743: {"Unified_Ideograph", "Ideographic"},
    182744: {"Unified_Ideograph", "Ideographic"},
    182745: {"Unified_Ideograph", "Ideographic"},
    182746: {"Unified_Ideograph", "Ideographic"},
    182747: {"Unified_Ideograph", "Ideographic"},
    182748: {"Unified_Ideograph", "Ideographic"},
    182749: {"Unified_Ideograph", "Ideographic"},
    182750: {"Unified_Ideograph", "Ideographic"},
    182751: {"Unified_Ideograph", "Ideographic"},
    182752: {"Unified_Ideograph", "Ideographic"},
    182753: {"Unified_Ideograph", "Ideographic"},
    182754: {"Unified_Ideograph", "Ideographic"},
    182755: {"Unified_Ideograph", "Ideographic"},
    182756: {"Unified_Ideograph", "Ideographic"},
    182757: {"Unified_Ideograph", "Ideographic"},
    182758: {"Unified_Ideograph", "Ideographic"},
    182759: {"Unified_Ideograph", "Ideographic"},
    182760: {"Unified_Ideograph", "Ideographic"},
    182761: {"Unified_Ideograph", "Ideographic"},
    182762: {"Unified_Ideograph", "Ideographic"},
    182763: {"Unified_Ideograph", "Ideographic"},
    182764: {"Unified_Ideograph", "Ideographic"},
    182765: {"Unified_Ideograph", "Ideographic"},
    182766: {"Unified_Ideograph", "Ideographic"},
    182767: {"Unified_Ideograph", "Ideographic"},
    182768: {"Unified_Ideograph", "Ideographic"},
    182769: {"Unified_Ideograph", "Ideographic"},
    182770: {"Unified_Ideograph", "Ideographic"},
    182771: {"Unified_Ideograph", "Ideographic"},
    182772: {"Unified_Ideograph", "Ideographic"},
    182773: {"Unified_Ideograph", "Ideographic"},
    182774: {"Unified_Ideograph", "Ideographic"},
    182775: {"Unified_Ideograph", "Ideographic"},
    182776: {"Unified_Ideograph", "Ideographic"},
    182777: {"Unified_Ideograph", "Ideographic"},
    182778: {"Unified_Ideograph", "Ideographic"},
    182779: {"Unified_Ideograph", "Ideographic"},
    182780: {"Unified_Ideograph", "Ideographic"},
    182781: {"Unified_Ideograph", "Ideographic"},
    182782: {"Unified_Ideograph", "Ideographic"},
    182783: {"Unified_Ideograph", "Ideographic"},
    182784: {"Unified_Ideograph", "Ideographic"},
    182785: {"Unified_Ideograph", "Ideographic"},
    182786: {"Unified_Ideograph", "Ideographic"},
    182787: {"Unified_Ideograph", "Ideographic"},
    182788: {"Unified_Ideograph", "Ideographic"},
    182789: {"Unified_Ideograph", "Ideographic"},
    182790: {"Unified_Ideograph", "Ideographic"},
    182791: {"Unified_Ideograph", "Ideographic"},
    182792: {"Unified_Ideograph", "Ideographic"},
    182793: {"Unified_Ideograph", "Ideographic"},
    182794: {"Unified_Ideograph", "Ideographic"},
    182795: {"Unified_Ideograph", "Ideographic"},
    182796: {"Unified_Ideograph", "Ideographic"},
    182797: {"Unified_Ideograph", "Ideographic"},
    182798: {"Unified_Ideograph", "Ideographic"},
    182799: {"Unified_Ideograph", "Ideographic"},
    182800: {"Unified_Ideograph", "Ideographic"},
    182801: {"Unified_Ideograph", "Ideographic"},
    182802: {"Unified_Ideograph", "Ideographic"},
    182803: {"Unified_Ideograph", "Ideographic"},
    182804: {"Unified_Ideograph", "Ideographic"},
    182805: {"Unified_Ideograph", "Ideographic"},
    182806: {"Unified_Ideograph", "Ideographic"},
    182807: {"Unified_Ideograph", "Ideographic"},
    182808: {"Unified_Ideograph", "Ideographic"},
    182809: {"Unified_Ideograph", "Ideographic"},
    182810: {"Unified_Ideograph", "Ideographic"},
    182811: {"Unified_Ideograph", "Ideographic"},
    182812: {"Unified_Ideograph", "Ideographic"},
    182813: {"Unified_Ideograph", "Ideographic"},
    182814: {"Unified_Ideograph", "Ideographic"},
    182815: {"Unified_Ideograph", "Ideographic"},
    182816: {"Unified_Ideograph", "Ideographic"},
    182817: {"Unified_Ideograph", "Ideographic"},
    182818: {"Unified_Ideograph", "Ideographic"},
    182819: {"Unified_Ideograph", "Ideographic"},
    182820: {"Unified_Ideograph", "Ideographic"},
    182821: {"Unified_Ideograph", "Ideographic"},
    182822: {"Unified_Ideograph", "Ideographic"},
    182823: {"Unified_Ideograph", "Ideographic"},
    182824: {"Unified_Ideograph", "Ideographic"},
    182825: {"Unified_Ideograph", "Ideographic"},
    182826: {"Unified_Ideograph", "Ideographic"},
    182827: {"Unified_Ideograph", "Ideographic"},
    182828: {"Unified_Ideograph", "Ideographic"},
    182829: {"Unified_Ideograph", "Ideographic"},
    182830: {"Unified_Ideograph", "Ideographic"},
    182831: {"Unified_Ideograph", "Ideographic"},
    182832: {"Unified_Ideograph", "Ideographic"},
    182833: {"Unified_Ideograph", "Ideographic"},
    182834: {"Unified_Ideograph", "Ideographic"},
    182835: {"Unified_Ideograph", "Ideographic"},
    182836: {"Unified_Ideograph", "Ideographic"},
    182837: {"Unified_Ideograph", "Ideographic"},
    182838: {"Unified_Ideograph", "Ideographic"},
    182839: {"Unified_Ideograph", "Ideographic"},
    182840: {"Unified_Ideograph", "Ideographic"},
    182841: {"Unified_Ideograph", "Ideographic"},
    182842: {"Unified_Ideograph", "Ideographic"},
    182843: {"Unified_Ideograph", "Ideographic"},
    182844: {"Unified_Ideograph", "Ideographic"},
    182845: {"Unified_Ideograph", "Ideographic"},
    182846: {"Unified_Ideograph", "Ideographic"},
    182847: {"Unified_Ideograph", "Ideographic"},
    182848: {"Unified_Ideograph", "Ideographic"},
    182849: {"Unified_Ideograph", "Ideographic"},
    182850: {"Unified_Ideograph", "Ideographic"},
    182851: {"Unified_Ideograph", "Ideographic"},
    182852: {"Unified_Ideograph", "Ideographic"},
    182853: {"Unified_Ideograph", "Ideographic"},
    182854: {"Unified_Ideograph", "Ideographic"},
    182855: {"Unified_Ideograph", "Ideographic"},
    182856: {"Unified_Ideograph", "Ideographic"},
    182857: {"Unified_Ideograph", "Ideographic"},
    182858: {"Unified_Ideograph", "Ideographic"},
    182859: {"Unified_Ideograph", "Ideographic"},
    182860: {"Unified_Ideograph", "Ideographic"},
    182861: {"Unified_Ideograph", "Ideographic"},
    182862: {"Unified_Ideograph", "Ideographic"},
    182863: {"Unified_Ideograph", "Ideographic"},
    182864: {"Unified_Ideograph", "Ideographic"},
    182865: {"Unified_Ideograph", "Ideographic"},
    182866: {"Unified_Ideograph", "Ideographic"},
    182867: {"Unified_Ideograph", "Ideographic"},
    182868: {"Unified_Ideograph", "Ideographic"},
    182869: {"Unified_Ideograph", "Ideographic"},
    182870: {"Unified_Ideograph", "Ideographic"},
    182871: {"Unified_Ideograph", "Ideographic"},
    182872: {"Unified_Ideograph", "Ideographic"},
    182873: {"Unified_Ideograph", "Ideographic"},
    182874: {"Unified_Ideograph", "Ideographic"},
    182875: {"Unified_Ideograph", "Ideographic"},
    182876: {"Unified_Ideograph", "Ideographic"},
    182877: {"Unified_Ideograph", "Ideographic"},
    182878: {"Unified_Ideograph", "Ideographic"},
    182879: {"Unified_Ideograph", "Ideographic"},
    182880: {"Unified_Ideograph", "Ideographic"},
    182881: {"Unified_Ideograph", "Ideographic"},
    182882: {"Unified_Ideograph", "Ideographic"},
    182883: {"Unified_Ideograph", "Ideographic"},
    182884: {"Unified_Ideograph", "Ideographic"},
    182885: {"Unified_Ideograph", "Ideographic"},
    182886: {"Unified_Ideograph", "Ideographic"},
    182887: {"Unified_Ideograph", "Ideographic"},
    182888: {"Unified_Ideograph", "Ideographic"},
    182889: {"Unified_Ideograph", "Ideographic"},
    182890: {"Unified_Ideograph", "Ideographic"},
    182891: {"Unified_Ideograph", "Ideographic"},
    182892: {"Unified_Ideograph", "Ideographic"},
    182893: {"Unified_Ideograph", "Ideographic"},
    182894: {"Unified_Ideograph", "Ideographic"},
    182895: {"Unified_Ideograph", "Ideographic"},
    182896: {"Unified_Ideograph", "Ideographic"},
    182897: {"Unified_Ideograph", "Ideographic"},
    182898: {"Unified_Ideograph", "Ideographic"},
    182899: {"Unified_Ideograph", "Ideographic"},
    182900: {"Unified_Ideograph", "Ideographic"},
    182901: {"Unified_Ideograph", "Ideographic"},
    182902: {"Unified_Ideograph", "Ideographic"},
    182903: {"Unified_Ideograph", "Ideographic"},
    182904: {"Unified_Ideograph", "Ideographic"},
    182905: {"Unified_Ideograph", "Ideographic"},
    182906: {"Unified_Ideograph", "Ideographic"},
    182907: {"Unified_Ideograph", "Ideographic"},
    182908: {"Unified_Ideograph", "Ideographic"},
    182909: {"Unified_Ideograph", "Ideographic"},
    182910: {"Unified_Ideograph", "Ideographic"},
    182911: {"Unified_Ideograph", "Ideographic"},
    182912: {"Unified_Ideograph", "Ideographic"},
    182913: {"Unified_Ideograph", "Ideographic"},
    182914: {"Unified_Ideograph", "Ideographic"},
    182915: {"Unified_Ideograph", "Ideographic"},
    182916: {"Unified_Ideograph", "Ideographic"},
    182917: {"Unified_Ideograph", "Ideographic"},
    182918: {"Unified_Ideograph", "Ideographic"},
    182919: {"Unified_Ideograph", "Ideographic"},
    182920: {"Unified_Ideograph", "Ideographic"},
    182921: {"Unified_Ideograph", "Ideographic"},
    182922: {"Unified_Ideograph", "Ideographic"},
    182923: {"Unified_Ideograph", "Ideographic"},
    182924: {"Unified_Ideograph", "Ideographic"},
    182925: {"Unified_Ideograph", "Ideographic"},
    182926: {"Unified_Ideograph", "Ideographic"},
    182927: {"Unified_Ideograph", "Ideographic"},
    182928: {"Unified_Ideograph", "Ideographic"},
    182929: {"Unified_Ideograph", "Ideographic"},
    182930: {"Unified_Ideograph", "Ideographic"},
    182931: {"Unified_Ideograph", "Ideographic"},
    182932: {"Unified_Ideograph", "Ideographic"},
    182933: {"Unified_Ideograph", "Ideographic"},
    182934: {"Unified_Ideograph", "Ideographic"},
    182935: {"Unified_Ideograph", "Ideographic"},
    182936: {"Unified_Ideograph", "Ideographic"},
    182937: {"Unified_Ideograph", "Ideographic"},
    182938: {"Unified_Ideograph", "Ideographic"},
    182939: {"Unified_Ideograph", "Ideographic"},
    182940: {"Unified_Ideograph", "Ideographic"},
    182941: {"Unified_Ideograph", "Ideographic"},
    182942: {"Unified_Ideograph", "Ideographic"},
    182943: {"Unified_Ideograph", "Ideographic"},
    182944: {"Unified_Ideograph", "Ideographic"},
    182945: {"Unified_Ideograph", "Ideographic"},
    182946: {"Unified_Ideograph", "Ideographic"},
    182947: {"Unified_Ideograph", "Ideographic"},
    182948: {"Unified_Ideograph", "Ideographic"},
    182949: {"Unified_Ideograph", "Ideographic"},
    182950: {"Unified_Ideograph", "Ideographic"},
    182951: {"Unified_Ideograph", "Ideographic"},
    182952: {"Unified_Ideograph", "Ideographic"},
    182953: {"Unified_Ideograph", "Ideographic"},
    182954: {"Unified_Ideograph", "Ideographic"},
    182955: {"Unified_Ideograph", "Ideographic"},
    182956: {"Unified_Ideograph", "Ideographic"},
    182957: {"Unified_Ideograph", "Ideographic"},
    182958: {"Unified_Ideograph", "Ideographic"},
    182959: {"Unified_Ideograph", "Ideographic"},
    182960: {"Unified_Ideograph", "Ideographic"},
    182961: {"Unified_Ideograph", "Ideographic"},
    182962: {"Unified_Ideograph", "Ideographic"},
    182963: {"Unified_Ideograph", "Ideographic"},
    182964: {"Unified_Ideograph", "Ideographic"},
    182965: {"Unified_Ideograph", "Ideographic"},
    182966: {"Unified_Ideograph", "Ideographic"},
    182967: {"Unified_Ideograph", "Ideographic"},
    182968: {"Unified_Ideograph", "Ideographic"},
    182969: {"Unified_Ideograph", "Ideographic"},
    182970: {"Unified_Ideograph", "Ideographic"},
    182971: {"Unified_Ideograph", "Ideographic"},
    182972: {"Unified_Ideograph", "Ideographic"},
    182973: {"Unified_Ideograph", "Ideographic"},
    182974: {"Unified_Ideograph", "Ideographic"},
    182975: {"Unified_Ideograph", "Ideographic"},
    182976: {"Unified_Ideograph", "Ideographic"},
    182977: {"Unified_Ideograph", "Ideographic"},
    182978: {"Unified_Ideograph", "Ideographic"},
    182979: {"Unified_Ideograph", "Ideographic"},
    182980: {"Unified_Ideograph", "Ideographic"},
    182981: {"Unified_Ideograph", "Ideographic"},
    182982: {"Unified_Ideograph", "Ideographic"},
    182983: {"Unified_Ideograph", "Ideographic"},
    182984: {"Unified_Ideograph", "Ideographic"},
    182985: {"Unified_Ideograph", "Ideographic"},
    182986: {"Unified_Ideograph", "Ideographic"},
    182987: {"Unified_Ideograph", "Ideographic"},
    182988: {"Unified_Ideograph", "Ideographic"},
    182989: {"Unified_Ideograph", "Ideographic"},
    182990: {"Unified_Ideograph", "Ideographic"},
    182991: {"Unified_Ideograph", "Ideographic"},
    182992: {"Unified_Ideograph", "Ideographic"},
    182993: {"Unified_Ideograph", "Ideographic"},
    182994: {"Unified_Ideograph", "Ideographic"},
    182995: {"Unified_Ideograph", "Ideographic"},
    182996: {"Unified_Ideograph", "Ideographic"},
    182997: {"Unified_Ideograph", "Ideographic"},
    182998: {"Unified_Ideograph", "Ideographic"},
    182999: {"Unified_Ideograph", "Ideographic"},
    183000: {"Unified_Ideograph", "Ideographic"},
    183001: {"Unified_Ideograph", "Ideographic"},
    183002: {"Unified_Ideograph", "Ideographic"},
    183003: {"Unified_Ideograph", "Ideographic"},
    183004: {"Unified_Ideograph", "Ideographic"},
    183005: {"Unified_Ideograph", "Ideographic"},
    183006: {"Unified_Ideograph", "Ideographic"},
    183007: {"Unified_Ideograph", "Ideographic"},
    183008: {"Unified_Ideograph", "Ideographic"},
    183009: {"Unified_Ideograph", "Ideographic"},
    183010: {"Unified_Ideograph", "Ideographic"},
    183011: {"Unified_Ideograph", "Ideographic"},
    183012: {"Unified_Ideograph", "Ideographic"},
    183013: {"Unified_Ideograph", "Ideographic"},
    183014: {"Unified_Ideograph", "Ideographic"},
    183015: {"Unified_Ideograph", "Ideographic"},
    183016: {"Unified_Ideograph", "Ideographic"},
    183017: {"Unified_Ideograph", "Ideographic"},
    183018: {"Unified_Ideograph", "Ideographic"},
    183019: {"Unified_Ideograph", "Ideographic"},
    183020: {"Unified_Ideograph", "Ideographic"},
    183021: {"Unified_Ideograph", "Ideographic"},
    183022: {"Unified_Ideograph", "Ideographic"},
    183023: {"Unified_Ideograph", "Ideographic"},
    183024: {"Unified_Ideograph", "Ideographic"},
    183025: {"Unified_Ideograph", "Ideographic"},
    183026: {"Unified_Ideograph", "Ideographic"},
    183027: {"Unified_Ideograph", "Ideographic"},
    183028: {"Unified_Ideograph", "Ideographic"},
    183029: {"Unified_Ideograph", "Ideographic"},
    183030: {"Unified_Ideograph", "Ideographic"},
    183031: {"Unified_Ideograph", "Ideographic"},
    183032: {"Unified_Ideograph", "Ideographic"},
    183033: {"Unified_Ideograph", "Ideographic"},
    183034: {"Unified_Ideograph", "Ideographic"},
    183035: {"Unified_Ideograph", "Ideographic"},
    183036: {"Unified_Ideograph", "Ideographic"},
    183037: {"Unified_Ideograph", "Ideographic"},
    183038: {"Unified_Ideograph", "Ideographic"},
    183039: {"Unified_Ideograph", "Ideographic"},
    183040: {"Unified_Ideograph", "Ideographic"},
    183041: {"Unified_Ideograph", "Ideographic"},
    183042: {"Unified_Ideograph", "Ideographic"},
    183043: {"Unified_Ideograph", "Ideographic"},
    183044: {"Unified_Ideograph", "Ideographic"},
    183045: {"Unified_Ideograph", "Ideographic"},
    183046: {"Unified_Ideograph", "Ideographic"},
    183047: {"Unified_Ideograph", "Ideographic"},
    183048: {"Unified_Ideograph", "Ideographic"},
    183049: {"Unified_Ideograph", "Ideographic"},
    183050: {"Unified_Ideograph", "Ideographic"},
    183051: {"Unified_Ideograph", "Ideographic"},
    183052: {"Unified_Ideograph", "Ideographic"},
    183053: {"Unified_Ideograph", "Ideographic"},
    183054: {"Unified_Ideograph", "Ideographic"},
    183055: {"Unified_Ideograph", "Ideographic"},
    183056: {"Unified_Ideograph", "Ideographic"},
    183057: {"Unified_Ideograph", "Ideographic"},
    183058: {"Unified_Ideograph", "Ideographic"},
    183059: {"Unified_Ideograph", "Ideographic"},
    183060: {"Unified_Ideograph", "Ideographic"},
    183061: {"Unified_Ideograph", "Ideographic"},
    183062: {"Unified_Ideograph", "Ideographic"},
    183063: {"Unified_Ideograph", "Ideographic"},
    183064: {"Unified_Ideograph", "Ideographic"},
    183065: {"Unified_Ideograph", "Ideographic"},
    183066: {"Unified_Ideograph", "Ideographic"},
    183067: {"Unified_Ideograph", "Ideographic"},
    183068: {"Unified_Ideograph", "Ideographic"},
    183069: {"Unified_Ideograph", "Ideographic"},
    183070: {"Unified_Ideograph", "Ideographic"},
    183071: {"Unified_Ideograph", "Ideographic"},
    183072: {"Unified_Ideograph", "Ideographic"},
    183073: {"Unified_Ideograph", "Ideographic"},
    183074: {"Unified_Ideograph", "Ideographic"},
    183075: {"Unified_Ideograph", "Ideographic"},
    183076: {"Unified_Ideograph", "Ideographic"},
    183077: {"Unified_Ideograph", "Ideographic"},
    183078: {"Unified_Ideograph", "Ideographic"},
    183079: {"Unified_Ideograph", "Ideographic"},
    183080: {"Unified_Ideograph", "Ideographic"},
    183081: {"Unified_Ideograph", "Ideographic"},
    183082: {"Unified_Ideograph", "Ideographic"},
    183083: {"Unified_Ideograph", "Ideographic"},
    183084: {"Unified_Ideograph", "Ideographic"},
    183085: {"Unified_Ideograph", "Ideographic"},
    183086: {"Unified_Ideograph", "Ideographic"},
    183087: {"Unified_Ideograph", "Ideographic"},
    183088: {"Unified_Ideograph", "Ideographic"},
    183089: {"Unified_Ideograph", "Ideographic"},
    183090: {"Unified_Ideograph", "Ideographic"},
    183091: {"Unified_Ideograph", "Ideographic"},
    183092: {"Unified_Ideograph", "Ideographic"},
    183093: {"Unified_Ideograph", "Ideographic"},
    183094: {"Unified_Ideograph", "Ideographic"},
    183095: {"Unified_Ideograph", "Ideographic"},
    183096: {"Unified_Ideograph", "Ideographic"},
    183097: {"Unified_Ideograph", "Ideographic"},
    183098: {"Unified_Ideograph", "Ideographic"},
    183099: {"Unified_Ideograph", "Ideographic"},
    183100: {"Unified_Ideograph", "Ideographic"},
    183101: {"Unified_Ideograph", "Ideographic"},
    183102: {"Unified_Ideograph", "Ideographic"},
    183103: {"Unified_Ideograph", "Ideographic"},
    183104: {"Unified_Ideograph", "Ideographic"},
    183105: {"Unified_Ideograph", "Ideographic"},
    183106: {"Unified_Ideograph", "Ideographic"},
    183107: {"Unified_Ideograph", "Ideographic"},
    183108: {"Unified_Ideograph", "Ideographic"},
    183109: {"Unified_Ideograph", "Ideographic"},
    183110: {"Unified_Ideograph", "Ideographic"},
    183111: {"Unified_Ideograph", "Ideographic"},
    183112: {"Unified_Ideograph", "Ideographic"},
    183113: {"Unified_Ideograph", "Ideographic"},
    183114: {"Unified_Ideograph", "Ideographic"},
    183115: {"Unified_Ideograph", "Ideographic"},
    183116: {"Unified_Ideograph", "Ideographic"},
    183117: {"Unified_Ideograph", "Ideographic"},
    183118: {"Unified_Ideograph", "Ideographic"},
    183119: {"Unified_Ideograph", "Ideographic"},
    183120: {"Unified_Ideograph", "Ideographic"},
    183121: {"Unified_Ideograph", "Ideographic"},
    183122: {"Unified_Ideograph", "Ideographic"},
    183123: {"Unified_Ideograph", "Ideographic"},
    183124: {"Unified_Ideograph", "Ideographic"},
    183125: {"Unified_Ideograph", "Ideographic"},
    183126: {"Unified_Ideograph", "Ideographic"},
    183127: {"Unified_Ideograph", "Ideographic"},
    183128: {"Unified_Ideograph", "Ideographic"},
    183129: {"Unified_Ideograph", "Ideographic"},
    183130: {"Unified_Ideograph", "Ideographic"},
    183131: {"Unified_Ideograph", "Ideographic"},
    183132: {"Unified_Ideograph", "Ideographic"},
    183133: {"Unified_Ideograph", "Ideographic"},
    183134: {"Unified_Ideograph", "Ideographic"},
    183135: {"Unified_Ideograph", "Ideographic"},
    183136: {"Unified_Ideograph", "Ideographic"},
    183137: {"Unified_Ideograph", "Ideographic"},
    183138: {"Unified_Ideograph", "Ideographic"},
    183139: {"Unified_Ideograph", "Ideographic"},
    183140: {"Unified_Ideograph", "Ideographic"},
    183141: {"Unified_Ideograph", "Ideographic"},
    183142: {"Unified_Ideograph", "Ideographic"},
    183143: {"Unified_Ideograph", "Ideographic"},
    183144: {"Unified_Ideograph", "Ideographic"},
    183145: {"Unified_Ideograph", "Ideographic"},
    183146: {"Unified_Ideograph", "Ideographic"},
    183147: {"Unified_Ideograph", "Ideographic"},
    183148: {"Unified_Ideograph", "Ideographic"},
    183149: {"Unified_Ideograph", "Ideographic"},
    183150: {"Unified_Ideograph", "Ideographic"},
    183151: {"Unified_Ideograph", "Ideographic"},
    183152: {"Unified_Ideograph", "Ideographic"},
    183153: {"Unified_Ideograph", "Ideographic"},
    183154: {"Unified_Ideograph", "Ideographic"},
    183155: {"Unified_Ideograph", "Ideographic"},
    183156: {"Unified_Ideograph", "Ideographic"},
    183157: {"Unified_Ideograph", "Ideographic"},
    183158: {"Unified_Ideograph", "Ideographic"},
    183159: {"Unified_Ideograph", "Ideographic"},
    183160: {"Unified_Ideograph", "Ideographic"},
    183161: {"Unified_Ideograph", "Ideographic"},
    183162: {"Unified_Ideograph", "Ideographic"},
    183163: {"Unified_Ideograph", "Ideographic"},
    183164: {"Unified_Ideograph", "Ideographic"},
    183165: {"Unified_Ideograph", "Ideographic"},
    183166: {"Unified_Ideograph", "Ideographic"},
    183167: {"Unified_Ideograph", "Ideographic"},
    183168: {"Unified_Ideograph", "Ideographic"},
    183169: {"Unified_Ideograph", "Ideographic"},
    183170: {"Unified_Ideograph", "Ideographic"},
    183171: {"Unified_Ideograph", "Ideographic"},
    183172: {"Unified_Ideograph", "Ideographic"},
    183173: {"Unified_Ideograph", "Ideographic"},
    183174: {"Unified_Ideograph", "Ideographic"},
    183175: {"Unified_Ideograph", "Ideographic"},
    183176: {"Unified_Ideograph", "Ideographic"},
    183177: {"Unified_Ideograph", "Ideographic"},
    183178: {"Unified_Ideograph", "Ideographic"},
    183179: {"Unified_Ideograph", "Ideographic"},
    183180: {"Unified_Ideograph", "Ideographic"},
    183181: {"Unified_Ideograph", "Ideographic"},
    183182: {"Unified_Ideograph", "Ideographic"},
    183183: {"Unified_Ideograph", "Ideographic"},
    183184: {"Unified_Ideograph", "Ideographic"},
    183185: {"Unified_Ideograph", "Ideographic"},
    183186: {"Unified_Ideograph", "Ideographic"},
    183187: {"Unified_Ideograph", "Ideographic"},
    183188: {"Unified_Ideograph", "Ideographic"},
    183189: {"Unified_Ideograph", "Ideographic"},
    183190: {"Unified_Ideograph", "Ideographic"},
    183191: {"Unified_Ideograph", "Ideographic"},
    183192: {"Unified_Ideograph", "Ideographic"},
    183193: {"Unified_Ideograph", "Ideographic"},
    183194: {"Unified_Ideograph", "Ideographic"},
    183195: {"Unified_Ideograph", "Ideographic"},
    183196: {"Unified_Ideograph", "Ideographic"},
    183197: {"Unified_Ideograph", "Ideographic"},
    183198: {"Unified_Ideograph", "Ideographic"},
    183199: {"Unified_Ideograph", "Ideographic"},
    183200: {"Unified_Ideograph", "Ideographic"},
    183201: {"Unified_Ideograph", "Ideographic"},
    183202: {"Unified_Ideograph", "Ideographic"},
    183203: {"Unified_Ideograph", "Ideographic"},
    183204: {"Unified_Ideograph", "Ideographic"},
    183205: {"Unified_Ideograph", "Ideographic"},
    183206: {"Unified_Ideograph", "Ideographic"},
    183207: {"Unified_Ideograph", "Ideographic"},
    183208: {"Unified_Ideograph", "Ideographic"},
    183209: {"Unified_Ideograph", "Ideographic"},
    183210: {"Unified_Ideograph", "Ideographic"},
    183211: {"Unified_Ideograph", "Ideographic"},
    183212: {"Unified_Ideograph", "Ideographic"},
    183213: {"Unified_Ideograph", "Ideographic"},
    183214: {"Unified_Ideograph", "Ideographic"},
    183215: {"Unified_Ideograph", "Ideographic"},
    183216: {"Unified_Ideograph", "Ideographic"},
    183217: {"Unified_Ideograph", "Ideographic"},
    183218: {"Unified_Ideograph", "Ideographic"},
    183219: {"Unified_Ideograph", "Ideographic"},
    183220: {"Unified_Ideograph", "Ideographic"},
    183221: {"Unified_Ideograph", "Ideographic"},
    183222: {"Unified_Ideograph", "Ideographic"},
    183223: {"Unified_Ideograph", "Ideographic"},
    183224: {"Unified_Ideograph", "Ideographic"},
    183225: {"Unified_Ideograph", "Ideographic"},
    183226: {"Unified_Ideograph", "Ideographic"},
    183227: {"Unified_Ideograph", "Ideographic"},
    183228: {"Unified_Ideograph", "Ideographic"},
    183229: {"Unified_Ideograph", "Ideographic"},
    183230: {"Unified_Ideograph", "Ideographic"},
    183231: {"Unified_Ideograph", "Ideographic"},
    183232: {"Unified_Ideograph", "Ideographic"},
    183233: {"Unified_Ideograph", "Ideographic"},
    183234: {"Unified_Ideograph", "Ideographic"},
    183235: {"Unified_Ideograph", "Ideographic"},
    183236: {"Unified_Ideograph", "Ideographic"},
    183237: {"Unified_Ideograph", "Ideographic"},
    183238: {"Unified_Ideograph", "Ideographic"},
    183239: {"Unified_Ideograph", "Ideographic"},
    183240: {"Unified_Ideograph", "Ideographic"},
    183241: {"Unified_Ideograph", "Ideographic"},
    183242: {"Unified_Ideograph", "Ideographic"},
    183243: {"Unified_Ideograph", "Ideographic"},
    183244: {"Unified_Ideograph", "Ideographic"},
    183245: {"Unified_Ideograph", "Ideographic"},
    183246: {"Unified_Ideograph", "Ideographic"},
    183247: {"Unified_Ideograph", "Ideographic"},
    183248: {"Unified_Ideograph", "Ideographic"},
    183249: {"Unified_Ideograph", "Ideographic"},
    183250: {"Unified_Ideograph", "Ideographic"},
    183251: {"Unified_Ideograph", "Ideographic"},
    183252: {"Unified_Ideograph", "Ideographic"},
    183253: {"Unified_Ideograph", "Ideographic"},
    183254: {"Unified_Ideograph", "Ideographic"},
    183255: {"Unified_Ideograph", "Ideographic"},
    183256: {"Unified_Ideograph", "Ideographic"},
    183257: {"Unified_Ideograph", "Ideographic"},
    183258: {"Unified_Ideograph", "Ideographic"},
    183259: {"Unified_Ideograph", "Ideographic"},
    183260: {"Unified_Ideograph", "Ideographic"},
    183261: {"Unified_Ideograph", "Ideographic"},
    183262: {"Unified_Ideograph", "Ideographic"},
    183263: {"Unified_Ideograph", "Ideographic"},
    183264: {"Unified_Ideograph", "Ideographic"},
    183265: {"Unified_Ideograph", "Ideographic"},
    183266: {"Unified_Ideograph", "Ideographic"},
    183267: {"Unified_Ideograph", "Ideographic"},
    183268: {"Unified_Ideograph", "Ideographic"},
    183269: {"Unified_Ideograph", "Ideographic"},
    183270: {"Unified_Ideograph", "Ideographic"},
    183271: {"Unified_Ideograph", "Ideographic"},
    183272: {"Unified_Ideograph", "Ideographic"},
    183273: {"Unified_Ideograph", "Ideographic"},
    183274: {"Unified_Ideograph", "Ideographic"},
    183275: {"Unified_Ideograph", "Ideographic"},
    183276: {"Unified_Ideograph", "Ideographic"},
    183277: {"Unified_Ideograph", "Ideographic"},
    183278: {"Unified_Ideograph", "Ideographic"},
    183279: {"Unified_Ideograph", "Ideographic"},
    183280: {"Unified_Ideograph", "Ideographic"},
    183281: {"Unified_Ideograph", "Ideographic"},
    183282: {"Unified_Ideograph", "Ideographic"},
    183283: {"Unified_Ideograph", "Ideographic"},
    183284: {"Unified_Ideograph", "Ideographic"},
    183285: {"Unified_Ideograph", "Ideographic"},
    183286: {"Unified_Ideograph", "Ideographic"},
    183287: {"Unified_Ideograph", "Ideographic"},
    183288: {"Unified_Ideograph", "Ideographic"},
    183289: {"Unified_Ideograph", "Ideographic"},
    183290: {"Unified_Ideograph", "Ideographic"},
    183291: {"Unified_Ideograph", "Ideographic"},
    183292: {"Unified_Ideograph", "Ideographic"},
    183293: {"Unified_Ideograph", "Ideographic"},
    183294: {"Unified_Ideograph", "Ideographic"},
    183295: {"Unified_Ideograph", "Ideographic"},
    183296: {"Unified_Ideograph", "Ideographic"},
    183297: {"Unified_Ideograph", "Ideographic"},
    183298: {"Unified_Ideograph", "Ideographic"},
    183299: {"Unified_Ideograph", "Ideographic"},
    183300: {"Unified_Ideograph", "Ideographic"},
    183301: {"Unified_Ideograph", "Ideographic"},
    183302: {"Unified_Ideograph", "Ideographic"},
    183303: {"Unified_Ideograph", "Ideographic"},
    183304: {"Unified_Ideograph", "Ideographic"},
    183305: {"Unified_Ideograph", "Ideographic"},
    183306: {"Unified_Ideograph", "Ideographic"},
    183307: {"Unified_Ideograph", "Ideographic"},
    183308: {"Unified_Ideograph", "Ideographic"},
    183309: {"Unified_Ideograph", "Ideographic"},
    183310: {"Unified_Ideograph", "Ideographic"},
    183311: {"Unified_Ideograph", "Ideographic"},
    183312: {"Unified_Ideograph", "Ideographic"},
    183313: {"Unified_Ideograph", "Ideographic"},
    183314: {"Unified_Ideograph", "Ideographic"},
    183315: {"Unified_Ideograph", "Ideographic"},
    183316: {"Unified_Ideograph", "Ideographic"},
    183317: {"Unified_Ideograph", "Ideographic"},
    183318: {"Unified_Ideograph", "Ideographic"},
    183319: {"Unified_Ideograph", "Ideographic"},
    183320: {"Unified_Ideograph", "Ideographic"},
    183321: {"Unified_Ideograph", "Ideographic"},
    183322: {"Unified_Ideograph", "Ideographic"},
    183323: {"Unified_Ideograph", "Ideographic"},
    183324: {"Unified_Ideograph", "Ideographic"},
    183325: {"Unified_Ideograph", "Ideographic"},
    183326: {"Unified_Ideograph", "Ideographic"},
    183327: {"Unified_Ideograph", "Ideographic"},
    183328: {"Unified_Ideograph", "Ideographic"},
    183329: {"Unified_Ideograph", "Ideographic"},
    183330: {"Unified_Ideograph", "Ideographic"},
    183331: {"Unified_Ideograph", "Ideographic"},
    183332: {"Unified_Ideograph", "Ideographic"},
    183333: {"Unified_Ideograph", "Ideographic"},
    183334: {"Unified_Ideograph", "Ideographic"},
    183335: {"Unified_Ideograph", "Ideographic"},
    183336: {"Unified_Ideograph", "Ideographic"},
    183337: {"Unified_Ideograph", "Ideographic"},
    183338: {"Unified_Ideograph", "Ideographic"},
    183339: {"Unified_Ideograph", "Ideographic"},
    183340: {"Unified_Ideograph", "Ideographic"},
    183341: {"Unified_Ideograph", "Ideographic"},
    183342: {"Unified_Ideograph", "Ideographic"},
    183343: {"Unified_Ideograph", "Ideographic"},
    183344: {"Unified_Ideograph", "Ideographic"},
    183345: {"Unified_Ideograph", "Ideographic"},
    183346: {"Unified_Ideograph", "Ideographic"},
    183347: {"Unified_Ideograph", "Ideographic"},
    183348: {"Unified_Ideograph", "Ideographic"},
    183349: {"Unified_Ideograph", "Ideographic"},
    183350: {"Unified_Ideograph", "Ideographic"},
    183351: {"Unified_Ideograph", "Ideographic"},
    183352: {"Unified_Ideograph", "Ideographic"},
    183353: {"Unified_Ideograph", "Ideographic"},
    183354: {"Unified_Ideograph", "Ideographic"},
    183355: {"Unified_Ideograph", "Ideographic"},
    183356: {"Unified_Ideograph", "Ideographic"},
    183357: {"Unified_Ideograph", "Ideographic"},
    183358: {"Unified_Ideograph", "Ideographic"},
    183359: {"Unified_Ideograph", "Ideographic"},
    183360: {"Unified_Ideograph", "Ideographic"},
    183361: {"Unified_Ideograph", "Ideographic"},
    183362: {"Unified_Ideograph", "Ideographic"},
    183363: {"Unified_Ideograph", "Ideographic"},
    183364: {"Unified_Ideograph", "Ideographic"},
    183365: {"Unified_Ideograph", "Ideographic"},
    183366: {"Unified_Ideograph", "Ideographic"},
    183367: {"Unified_Ideograph", "Ideographic"},
    183368: {"Unified_Ideograph", "Ideographic"},
    183369: {"Unified_Ideograph", "Ideographic"},
    183370: {"Unified_Ideograph", "Ideographic"},
    183371: {"Unified_Ideograph", "Ideographic"},
    183372: {"Unified_Ideograph", "Ideographic"},
    183373: {"Unified_Ideograph", "Ideographic"},
    183374: {"Unified_Ideograph", "Ideographic"},
    183375: {"Unified_Ideograph", "Ideographic"},
    183376: {"Unified_Ideograph", "Ideographic"},
    183377: {"Unified_Ideograph", "Ideographic"},
    183378: {"Unified_Ideograph", "Ideographic"},
    183379: {"Unified_Ideograph", "Ideographic"},
    183380: {"Unified_Ideograph", "Ideographic"},
    183381: {"Unified_Ideograph", "Ideographic"},
    183382: {"Unified_Ideograph", "Ideographic"},
    183383: {"Unified_Ideograph", "Ideographic"},
    183384: {"Unified_Ideograph", "Ideographic"},
    183385: {"Unified_Ideograph", "Ideographic"},
    183386: {"Unified_Ideograph", "Ideographic"},
    183387: {"Unified_Ideograph", "Ideographic"},
    183388: {"Unified_Ideograph", "Ideographic"},
    183389: {"Unified_Ideograph", "Ideographic"},
    183390: {"Unified_Ideograph", "Ideographic"},
    183391: {"Unified_Ideograph", "Ideographic"},
    183392: {"Unified_Ideograph", "Ideographic"},
    183393: {"Unified_Ideograph", "Ideographic"},
    183394: {"Unified_Ideograph", "Ideographic"},
    183395: {"Unified_Ideograph", "Ideographic"},
    183396: {"Unified_Ideograph", "Ideographic"},
    183397: {"Unified_Ideograph", "Ideographic"},
    183398: {"Unified_Ideograph", "Ideographic"},
    183399: {"Unified_Ideograph", "Ideographic"},
    183400: {"Unified_Ideograph", "Ideographic"},
    183401: {"Unified_Ideograph", "Ideographic"},
    183402: {"Unified_Ideograph", "Ideographic"},
    183403: {"Unified_Ideograph", "Ideographic"},
    183404: {"Unified_Ideograph", "Ideographic"},
    183405: {"Unified_Ideograph", "Ideographic"},
    183406: {"Unified_Ideograph", "Ideographic"},
    183407: {"Unified_Ideograph", "Ideographic"},
    183408: {"Unified_Ideograph", "Ideographic"},
    183409: {"Unified_Ideograph", "Ideographic"},
    183410: {"Unified_Ideograph", "Ideographic"},
    183411: {"Unified_Ideograph", "Ideographic"},
    183412: {"Unified_Ideograph", "Ideographic"},
    183413: {"Unified_Ideograph", "Ideographic"},
    183414: {"Unified_Ideograph", "Ideographic"},
    183415: {"Unified_Ideograph", "Ideographic"},
    183416: {"Unified_Ideograph", "Ideographic"},
    183417: {"Unified_Ideograph", "Ideographic"},
    183418: {"Unified_Ideograph", "Ideographic"},
    183419: {"Unified_Ideograph", "Ideographic"},
    183420: {"Unified_Ideograph", "Ideographic"},
    183421: {"Unified_Ideograph", "Ideographic"},
    183422: {"Unified_Ideograph", "Ideographic"},
    183423: {"Unified_Ideograph", "Ideographic"},
    183424: {"Unified_Ideograph", "Ideographic"},
    183425: {"Unified_Ideograph", "Ideographic"},
    183426: {"Unified_Ideograph", "Ideographic"},
    183427: {"Unified_Ideograph", "Ideographic"},
    183428: {"Unified_Ideograph", "Ideographic"},
    183429: {"Unified_Ideograph", "Ideographic"},
    183430: {"Unified_Ideograph", "Ideographic"},
    183431: {"Unified_Ideograph", "Ideographic"},
    183432: {"Unified_Ideograph", "Ideographic"},
    183433: {"Unified_Ideograph", "Ideographic"},
    183434: {"Unified_Ideograph", "Ideographic"},
    183435: {"Unified_Ideograph", "Ideographic"},
    183436: {"Unified_Ideograph", "Ideographic"},
    183437: {"Unified_Ideograph", "Ideographic"},
    183438: {"Unified_Ideograph", "Ideographic"},
    183439: {"Unified_Ideograph", "Ideographic"},
    183440: {"Unified_Ideograph", "Ideographic"},
    183441: {"Unified_Ideograph", "Ideographic"},
    183442: {"Unified_Ideograph", "Ideographic"},
    183443: {"Unified_Ideograph", "Ideographic"},
    183444: {"Unified_Ideograph", "Ideographic"},
    183445: {"Unified_Ideograph", "Ideographic"},
    183446: {"Unified_Ideograph", "Ideographic"},
    183447: {"Unified_Ideograph", "Ideographic"},
    183448: {"Unified_Ideograph", "Ideographic"},
    183449: {"Unified_Ideograph", "Ideographic"},
    183450: {"Unified_Ideograph", "Ideographic"},
    183451: {"Unified_Ideograph", "Ideographic"},
    183452: {"Unified_Ideograph", "Ideographic"},
    183453: {"Unified_Ideograph", "Ideographic"},
    183454: {"Unified_Ideograph", "Ideographic"},
    183455: {"Unified_Ideograph", "Ideographic"},
    183456: {"Unified_Ideograph", "Ideographic"},
    183457: {"Unified_Ideograph", "Ideographic"},
    183458: {"Unified_Ideograph", "Ideographic"},
    183459: {"Unified_Ideograph", "Ideographic"},
    183460: {"Unified_Ideograph", "Ideographic"},
    183461: {"Unified_Ideograph", "Ideographic"},
    183462: {"Unified_Ideograph", "Ideographic"},
    183463: {"Unified_Ideograph", "Ideographic"},
    183464: {"Unified_Ideograph", "Ideographic"},
    183465: {"Unified_Ideograph", "Ideographic"},
    183466: {"Unified_Ideograph", "Ideographic"},
    183467: {"Unified_Ideograph", "Ideographic"},
    183468: {"Unified_Ideograph", "Ideographic"},
    183469: {"Unified_Ideograph", "Ideographic"},
    183470: {"Unified_Ideograph", "Ideographic"},
    183471: {"Unified_Ideograph", "Ideographic"},
    183472: {"Unified_Ideograph", "Ideographic"},
    183473: {"Unified_Ideograph", "Ideographic"},
    183474: {"Unified_Ideograph", "Ideographic"},
    183475: {"Unified_Ideograph", "Ideographic"},
    183476: {"Unified_Ideograph", "Ideographic"},
    183477: {"Unified_Ideograph", "Ideographic"},
    183478: {"Unified_Ideograph", "Ideographic"},
    183479: {"Unified_Ideograph", "Ideographic"},
    183480: {"Unified_Ideograph", "Ideographic"},
    183481: {"Unified_Ideograph", "Ideographic"},
    183482: {"Unified_Ideograph", "Ideographic"},
    183483: {"Unified_Ideograph", "Ideographic"},
    183484: {"Unified_Ideograph", "Ideographic"},
    183485: {"Unified_Ideograph", "Ideographic"},
    183486: {"Unified_Ideograph", "Ideographic"},
    183487: {"Unified_Ideograph", "Ideographic"},
    183488: {"Unified_Ideograph", "Ideographic"},
    183489: {"Unified_Ideograph", "Ideographic"},
    183490: {"Unified_Ideograph", "Ideographic"},
    183491: {"Unified_Ideograph", "Ideographic"},
    183492: {"Unified_Ideograph", "Ideographic"},
    183493: {"Unified_Ideograph", "Ideographic"},
    183494: {"Unified_Ideograph", "Ideographic"},
    183495: {"Unified_Ideograph", "Ideographic"},
    183496: {"Unified_Ideograph", "Ideographic"},
    183497: {"Unified_Ideograph", "Ideographic"},
    183498: {"Unified_Ideograph", "Ideographic"},
    183499: {"Unified_Ideograph", "Ideographic"},
    183500: {"Unified_Ideograph", "Ideographic"},
    183501: {"Unified_Ideograph", "Ideographic"},
    183502: {"Unified_Ideograph", "Ideographic"},
    183503: {"Unified_Ideograph", "Ideographic"},
    183504: {"Unified_Ideograph", "Ideographic"},
    183505: {"Unified_Ideograph", "Ideographic"},
    183506: {"Unified_Ideograph", "Ideographic"},
    183507: {"Unified_Ideograph", "Ideographic"},
    183508: {"Unified_Ideograph", "Ideographic"},
    183509: {"Unified_Ideograph", "Ideographic"},
    183510: {"Unified_Ideograph", "Ideographic"},
    183511: {"Unified_Ideograph", "Ideographic"},
    183512: {"Unified_Ideograph", "Ideographic"},
    183513: {"Unified_Ideograph", "Ideographic"},
    183514: {"Unified_Ideograph", "Ideographic"},
    183515: {"Unified_Ideograph", "Ideographic"},
    183516: {"Unified_Ideograph", "Ideographic"},
    183517: {"Unified_Ideograph", "Ideographic"},
    183518: {"Unified_Ideograph", "Ideographic"},
    183519: {"Unified_Ideograph", "Ideographic"},
    183520: {"Unified_Ideograph", "Ideographic"},
    183521: {"Unified_Ideograph", "Ideographic"},
    183522: {"Unified_Ideograph", "Ideographic"},
    183523: {"Unified_Ideograph", "Ideographic"},
    183524: {"Unified_Ideograph", "Ideographic"},
    183525: {"Unified_Ideograph", "Ideographic"},
    183526: {"Unified_Ideograph", "Ideographic"},
    183527: {"Unified_Ideograph", "Ideographic"},
    183528: {"Unified_Ideograph", "Ideographic"},
    183529: {"Unified_Ideograph", "Ideographic"},
    183530: {"Unified_Ideograph", "Ideographic"},
    183531: {"Unified_Ideograph", "Ideographic"},
    183532: {"Unified_Ideograph", "Ideographic"},
    183533: {"Unified_Ideograph", "Ideographic"},
    183534: {"Unified_Ideograph", "Ideographic"},
    183535: {"Unified_Ideograph", "Ideographic"},
    183536: {"Unified_Ideograph", "Ideographic"},
    183537: {"Unified_Ideograph", "Ideographic"},
    183538: {"Unified_Ideograph", "Ideographic"},
    183539: {"Unified_Ideograph", "Ideographic"},
    183540: {"Unified_Ideograph", "Ideographic"},
    183541: {"Unified_Ideograph", "Ideographic"},
    183542: {"Unified_Ideograph", "Ideographic"},
    183543: {"Unified_Ideograph", "Ideographic"},
    183544: {"Unified_Ideograph", "Ideographic"},
    183545: {"Unified_Ideograph", "Ideographic"},
    183546: {"Unified_Ideograph", "Ideographic"},
    183547: {"Unified_Ideograph", "Ideographic"},
    183548: {"Unified_Ideograph", "Ideographic"},
    183549: {"Unified_Ideograph", "Ideographic"},
    183550: {"Unified_Ideograph", "Ideographic"},
    183551: {"Unified_Ideograph", "Ideographic"},
    183552: {"Unified_Ideograph", "Ideographic"},
    183553: {"Unified_Ideograph", "Ideographic"},
    183554: {"Unified_Ideograph", "Ideographic"},
    183555: {"Unified_Ideograph", "Ideographic"},
    183556: {"Unified_Ideograph", "Ideographic"},
    183557: {"Unified_Ideograph", "Ideographic"},
    183558: {"Unified_Ideograph", "Ideographic"},
    183559: {"Unified_Ideograph", "Ideographic"},
    183560: {"Unified_Ideograph", "Ideographic"},
    183561: {"Unified_Ideograph", "Ideographic"},
    183562: {"Unified_Ideograph", "Ideographic"},
    183563: {"Unified_Ideograph", "Ideographic"},
    183564: {"Unified_Ideograph", "Ideographic"},
    183565: {"Unified_Ideograph", "Ideographic"},
    183566: {"Unified_Ideograph", "Ideographic"},
    183567: {"Unified_Ideograph", "Ideographic"},
    183568: {"Unified_Ideograph", "Ideographic"},
    183569: {"Unified_Ideograph", "Ideographic"},
    183570: {"Unified_Ideograph", "Ideographic"},
    183571: {"Unified_Ideograph", "Ideographic"},
    183572: {"Unified_Ideograph", "Ideographic"},
    183573: {"Unified_Ideograph", "Ideographic"},
    183574: {"Unified_Ideograph", "Ideographic"},
    183575: {"Unified_Ideograph", "Ideographic"},
    183576: {"Unified_Ideograph", "Ideographic"},
    183577: {"Unified_Ideograph", "Ideographic"},
    183578: {"Unified_Ideograph", "Ideographic"},
    183579: {"Unified_Ideograph", "Ideographic"},
    183580: {"Unified_Ideograph", "Ideographic"},
    183581: {"Unified_Ideograph", "Ideographic"},
    183582: {"Unified_Ideograph", "Ideographic"},
    183583: {"Unified_Ideograph", "Ideographic"},
    183584: {"Unified_Ideograph", "Ideographic"},
    183585: {"Unified_Ideograph", "Ideographic"},
    183586: {"Unified_Ideograph", "Ideographic"},
    183587: {"Unified_Ideograph", "Ideographic"},
    183588: {"Unified_Ideograph", "Ideographic"},
    183589: {"Unified_Ideograph", "Ideographic"},
    183590: {"Unified_Ideograph", "Ideographic"},
    183591: {"Unified_Ideograph", "Ideographic"},
    183592: {"Unified_Ideograph", "Ideographic"},
    183593: {"Unified_Ideograph", "Ideographic"},
    183594: {"Unified_Ideograph", "Ideographic"},
    183595: {"Unified_Ideograph", "Ideographic"},
    183596: {"Unified_Ideograph", "Ideographic"},
    183597: {"Unified_Ideograph", "Ideographic"},
    183598: {"Unified_Ideograph", "Ideographic"},
    183599: {"Unified_Ideograph", "Ideographic"},
    183600: {"Unified_Ideograph", "Ideographic"},
    183601: {"Unified_Ideograph", "Ideographic"},
    183602: {"Unified_Ideograph", "Ideographic"},
    183603: {"Unified_Ideograph", "Ideographic"},
    183604: {"Unified_Ideograph", "Ideographic"},
    183605: {"Unified_Ideograph", "Ideographic"},
    183606: {"Unified_Ideograph", "Ideographic"},
    183607: {"Unified_Ideograph", "Ideographic"},
    183608: {"Unified_Ideograph", "Ideographic"},
    183609: {"Unified_Ideograph", "Ideographic"},
    183610: {"Unified_Ideograph", "Ideographic"},
    183611: {"Unified_Ideograph", "Ideographic"},
    183612: {"Unified_Ideograph", "Ideographic"},
    183613: {"Unified_Ideograph", "Ideographic"},
    183614: {"Unified_Ideograph", "Ideographic"},
    183615: {"Unified_Ideograph", "Ideographic"},
    183616: {"Unified_Ideograph", "Ideographic"},
    183617: {"Unified_Ideograph", "Ideographic"},
    183618: {"Unified_Ideograph", "Ideographic"},
    183619: {"Unified_Ideograph", "Ideographic"},
    183620: {"Unified_Ideograph", "Ideographic"},
    183621: {"Unified_Ideograph", "Ideographic"},
    183622: {"Unified_Ideograph", "Ideographic"},
    183623: {"Unified_Ideograph", "Ideographic"},
    183624: {"Unified_Ideograph", "Ideographic"},
    183625: {"Unified_Ideograph", "Ideographic"},
    183626: {"Unified_Ideograph", "Ideographic"},
    183627: {"Unified_Ideograph", "Ideographic"},
    183628: {"Unified_Ideograph", "Ideographic"},
    183629: {"Unified_Ideograph", "Ideographic"},
    183630: {"Unified_Ideograph", "Ideographic"},
    183631: {"Unified_Ideograph", "Ideographic"},
    183632: {"Unified_Ideograph", "Ideographic"},
    183633: {"Unified_Ideograph", "Ideographic"},
    183634: {"Unified_Ideograph", "Ideographic"},
    183635: {"Unified_Ideograph", "Ideographic"},
    183636: {"Unified_Ideograph", "Ideographic"},
    183637: {"Unified_Ideograph", "Ideographic"},
    183638: {"Unified_Ideograph", "Ideographic"},
    183639: {"Unified_Ideograph", "Ideographic"},
    183640: {"Unified_Ideograph", "Ideographic"},
    183641: {"Unified_Ideograph", "Ideographic"},
    183642: {"Unified_Ideograph", "Ideographic"},
    183643: {"Unified_Ideograph", "Ideographic"},
    183644: {"Unified_Ideograph", "Ideographic"},
    183645: {"Unified_Ideograph", "Ideographic"},
    183646: {"Unified_Ideograph", "Ideographic"},
    183647: {"Unified_Ideograph", "Ideographic"},
    183648: {"Unified_Ideograph", "Ideographic"},
    183649: {"Unified_Ideograph", "Ideographic"},
    183650: {"Unified_Ideograph", "Ideographic"},
    183651: {"Unified_Ideograph", "Ideographic"},
    183652: {"Unified_Ideograph", "Ideographic"},
    183653: {"Unified_Ideograph", "Ideographic"},
    183654: {"Unified_Ideograph", "Ideographic"},
    183655: {"Unified_Ideograph", "Ideographic"},
    183656: {"Unified_Ideograph", "Ideographic"},
    183657: {"Unified_Ideograph", "Ideographic"},
    183658: {"Unified_Ideograph", "Ideographic"},
    183659: {"Unified_Ideograph", "Ideographic"},
    183660: {"Unified_Ideograph", "Ideographic"},
    183661: {"Unified_Ideograph", "Ideographic"},
    183662: {"Unified_Ideograph", "Ideographic"},
    183663: {"Unified_Ideograph", "Ideographic"},
    183664: {"Unified_Ideograph", "Ideographic"},
    183665: {"Unified_Ideograph", "Ideographic"},
    183666: {"Unified_Ideograph", "Ideographic"},
    183667: {"Unified_Ideograph", "Ideographic"},
    183668: {"Unified_Ideograph", "Ideographic"},
    183669: {"Unified_Ideograph", "Ideographic"},
    183670: {"Unified_Ideograph", "Ideographic"},
    183671: {"Unified_Ideograph", "Ideographic"},
    183672: {"Unified_Ideograph", "Ideographic"},
    183673: {"Unified_Ideograph", "Ideographic"},
    183674: {"Unified_Ideograph", "Ideographic"},
    183675: {"Unified_Ideograph", "Ideographic"},
    183676: {"Unified_Ideograph", "Ideographic"},
    183677: {"Unified_Ideograph", "Ideographic"},
    183678: {"Unified_Ideograph", "Ideographic"},
    183679: {"Unified_Ideograph", "Ideographic"},
    183680: {"Unified_Ideograph", "Ideographic"},
    183681: {"Unified_Ideograph", "Ideographic"},
    183682: {"Unified_Ideograph", "Ideographic"},
    183683: {"Unified_Ideograph", "Ideographic"},
    183684: {"Unified_Ideograph", "Ideographic"},
    183685: {"Unified_Ideograph", "Ideographic"},
    183686: {"Unified_Ideograph", "Ideographic"},
    183687: {"Unified_Ideograph", "Ideographic"},
    183688: {"Unified_Ideograph", "Ideographic"},
    183689: {"Unified_Ideograph", "Ideographic"},
    183690: {"Unified_Ideograph", "Ideographic"},
    183691: {"Unified_Ideograph", "Ideographic"},
    183692: {"Unified_Ideograph", "Ideographic"},
    183693: {"Unified_Ideograph", "Ideographic"},
    183694: {"Unified_Ideograph", "Ideographic"},
    183695: {"Unified_Ideograph", "Ideographic"},
    183696: {"Unified_Ideograph", "Ideographic"},
    183697: {"Unified_Ideograph", "Ideographic"},
    183698: {"Unified_Ideograph", "Ideographic"},
    183699: {"Unified_Ideograph", "Ideographic"},
    183700: {"Unified_Ideograph", "Ideographic"},
    183701: {"Unified_Ideograph", "Ideographic"},
    183702: {"Unified_Ideograph", "Ideographic"},
    183703: {"Unified_Ideograph", "Ideographic"},
    183704: {"Unified_Ideograph", "Ideographic"},
    183705: {"Unified_Ideograph", "Ideographic"},
    183706: {"Unified_Ideograph", "Ideographic"},
    183707: {"Unified_Ideograph", "Ideographic"},
    183708: {"Unified_Ideograph", "Ideographic"},
    183709: {"Unified_Ideograph", "Ideographic"},
    183710: {"Unified_Ideograph", "Ideographic"},
    183711: {"Unified_Ideograph", "Ideographic"},
    183712: {"Unified_Ideograph", "Ideographic"},
    183713: {"Unified_Ideograph", "Ideographic"},
    183714: {"Unified_Ideograph", "Ideographic"},
    183715: {"Unified_Ideograph", "Ideographic"},
    183716: {"Unified_Ideograph", "Ideographic"},
    183717: {"Unified_Ideograph", "Ideographic"},
    183718: {"Unified_Ideograph", "Ideographic"},
    183719: {"Unified_Ideograph", "Ideographic"},
    183720: {"Unified_Ideograph", "Ideographic"},
    183721: {"Unified_Ideograph", "Ideographic"},
    183722: {"Unified_Ideograph", "Ideographic"},
    183723: {"Unified_Ideograph", "Ideographic"},
    183724: {"Unified_Ideograph", "Ideographic"},
    183725: {"Unified_Ideograph", "Ideographic"},
    183726: {"Unified_Ideograph", "Ideographic"},
    183727: {"Unified_Ideograph", "Ideographic"},
    183728: {"Unified_Ideograph", "Ideographic"},
    183729: {"Unified_Ideograph", "Ideographic"},
    183730: {"Unified_Ideograph", "Ideographic"},
    183731: {"Unified_Ideograph", "Ideographic"},
    183732: {"Unified_Ideograph", "Ideographic"},
    183733: {"Unified_Ideograph", "Ideographic"},
    183734: {"Unified_Ideograph", "Ideographic"},
    183735: {"Unified_Ideograph", "Ideographic"},
    183736: {"Unified_Ideograph", "Ideographic"},
    183737: {"Unified_Ideograph", "Ideographic"},
    183738: {"Unified_Ideograph", "Ideographic"},
    183739: {"Unified_Ideograph", "Ideographic"},
    183740: {"Unified_Ideograph", "Ideographic"},
    183741: {"Unified_Ideograph", "Ideographic"},
    183742: {"Unified_Ideograph", "Ideographic"},
    183743: {"Unified_Ideograph", "Ideographic"},
    183744: {"Unified_Ideograph", "Ideographic"},
    183745: {"Unified_Ideograph", "Ideographic"},
    183746: {"Unified_Ideograph", "Ideographic"},
    183747: {"Unified_Ideograph", "Ideographic"},
    183748: {"Unified_Ideograph", "Ideographic"},
    183749: {"Unified_Ideograph", "Ideographic"},
    183750: {"Unified_Ideograph", "Ideographic"},
    183751: {"Unified_Ideograph", "Ideographic"},
    183752: {"Unified_Ideograph", "Ideographic"},
    183753: {"Unified_Ideograph", "Ideographic"},
    183754: {"Unified_Ideograph", "Ideographic"},
    183755: {"Unified_Ideograph", "Ideographic"},
    183756: {"Unified_Ideograph", "Ideographic"},
    183757: {"Unified_Ideograph", "Ideographic"},
    183758: {"Unified_Ideograph", "Ideographic"},
    183759: {"Unified_Ideograph", "Ideographic"},
    183760: {"Unified_Ideograph", "Ideographic"},
    183761: {"Unified_Ideograph", "Ideographic"},
    183762: {"Unified_Ideograph", "Ideographic"},
    183763: {"Unified_Ideograph", "Ideographic"},
    183764: {"Unified_Ideograph", "Ideographic"},
    183765: {"Unified_Ideograph", "Ideographic"},
    183766: {"Unified_Ideograph", "Ideographic"},
    183767: {"Unified_Ideograph", "Ideographic"},
    183768: {"Unified_Ideograph", "Ideographic"},
    183769: {"Unified_Ideograph", "Ideographic"},
    183770: {"Unified_Ideograph", "Ideographic"},
    183771: {"Unified_Ideograph", "Ideographic"},
    183772: {"Unified_Ideograph", "Ideographic"},
    183773: {"Unified_Ideograph", "Ideographic"},
    183774: {"Unified_Ideograph", "Ideographic"},
    183775: {"Unified_Ideograph", "Ideographic"},
    183776: {"Unified_Ideograph", "Ideographic"},
    183777: {"Unified_Ideograph", "Ideographic"},
    183778: {"Unified_Ideograph", "Ideographic"},
    183779: {"Unified_Ideograph", "Ideographic"},
    183780: {"Unified_Ideograph", "Ideographic"},
    183781: {"Unified_Ideograph", "Ideographic"},
    183782: {"Unified_Ideograph", "Ideographic"},
    183783: {"Unified_Ideograph", "Ideographic"},
    183784: {"Unified_Ideograph", "Ideographic"},
    183785: {"Unified_Ideograph", "Ideographic"},
    183786: {"Unified_Ideograph", "Ideographic"},
    183787: {"Unified_Ideograph", "Ideographic"},
    183788: {"Unified_Ideograph", "Ideographic"},
    183789: {"Unified_Ideograph", "Ideographic"},
    183790: {"Unified_Ideograph", "Ideographic"},
    183791: {"Unified_Ideograph", "Ideographic"},
    183792: {"Unified_Ideograph", "Ideographic"},
    183793: {"Unified_Ideograph", "Ideographic"},
    183794: {"Unified_Ideograph", "Ideographic"},
    183795: {"Unified_Ideograph", "Ideographic"},
    183796: {"Unified_Ideograph", "Ideographic"},
    183797: {"Unified_Ideograph", "Ideographic"},
    183798: {"Unified_Ideograph", "Ideographic"},
    183799: {"Unified_Ideograph", "Ideographic"},
    183800: {"Unified_Ideograph", "Ideographic"},
    183801: {"Unified_Ideograph", "Ideographic"},
    183802: {"Unified_Ideograph", "Ideographic"},
    183803: {"Unified_Ideograph", "Ideographic"},
    183804: {"Unified_Ideograph", "Ideographic"},
    183805: {"Unified_Ideograph", "Ideographic"},
    183806: {"Unified_Ideograph", "Ideographic"},
    183807: {"Unified_Ideograph", "Ideographic"},
    183808: {"Unified_Ideograph", "Ideographic"},
    183809: {"Unified_Ideograph", "Ideographic"},
    183810: {"Unified_Ideograph", "Ideographic"},
    183811: {"Unified_Ideograph", "Ideographic"},
    183812: {"Unified_Ideograph", "Ideographic"},
    183813: {"Unified_Ideograph", "Ideographic"},
    183814: {"Unified_Ideograph", "Ideographic"},
    183815: {"Unified_Ideograph", "Ideographic"},
    183816: {"Unified_Ideograph", "Ideographic"},
    183817: {"Unified_Ideograph", "Ideographic"},
    183818: {"Unified_Ideograph", "Ideographic"},
    183819: {"Unified_Ideograph", "Ideographic"},
    183820: {"Unified_Ideograph", "Ideographic"},
    183821: {"Unified_Ideograph", "Ideographic"},
    183822: {"Unified_Ideograph", "Ideographic"},
    183823: {"Unified_Ideograph", "Ideographic"},
    183824: {"Unified_Ideograph", "Ideographic"},
    183825: {"Unified_Ideograph", "Ideographic"},
    183826: {"Unified_Ideograph", "Ideographic"},
    183827: {"Unified_Ideograph", "Ideographic"},
    183828: {"Unified_Ideograph", "Ideographic"},
    183829: {"Unified_Ideograph", "Ideographic"},
    183830: {"Unified_Ideograph", "Ideographic"},
    183831: {"Unified_Ideograph", "Ideographic"},
    183832: {"Unified_Ideograph", "Ideographic"},
    183833: {"Unified_Ideograph", "Ideographic"},
    183834: {"Unified_Ideograph", "Ideographic"},
    183835: {"Unified_Ideograph", "Ideographic"},
    183836: {"Unified_Ideograph", "Ideographic"},
    183837: {"Unified_Ideograph", "Ideographic"},
    183838: {"Unified_Ideograph", "Ideographic"},
    183839: {"Unified_Ideograph", "Ideographic"},
    183840: {"Unified_Ideograph", "Ideographic"},
    183841: {"Unified_Ideograph", "Ideographic"},
    183842: {"Unified_Ideograph", "Ideographic"},
    183843: {"Unified_Ideograph", "Ideographic"},
    183844: {"Unified_Ideograph", "Ideographic"},
    183845: {"Unified_Ideograph", "Ideographic"},
    183846: {"Unified_Ideograph", "Ideographic"},
    183847: {"Unified_Ideograph", "Ideographic"},
    183848: {"Unified_Ideograph", "Ideographic"},
    183849: {"Unified_Ideograph", "Ideographic"},
    183850: {"Unified_Ideograph", "Ideographic"},
    183851: {"Unified_Ideograph", "Ideographic"},
    183852: {"Unified_Ideograph", "Ideographic"},
    183853: {"Unified_Ideograph", "Ideographic"},
    183854: {"Unified_Ideograph", "Ideographic"},
    183855: {"Unified_Ideograph", "Ideographic"},
    183856: {"Unified_Ideograph", "Ideographic"},
    183857: {"Unified_Ideograph", "Ideographic"},
    183858: {"Unified_Ideograph", "Ideographic"},
    183859: {"Unified_Ideograph", "Ideographic"},
    183860: {"Unified_Ideograph", "Ideographic"},
    183861: {"Unified_Ideograph", "Ideographic"},
    183862: {"Unified_Ideograph", "Ideographic"},
    183863: {"Unified_Ideograph", "Ideographic"},
    183864: {"Unified_Ideograph", "Ideographic"},
    183865: {"Unified_Ideograph", "Ideographic"},
    183866: {"Unified_Ideograph", "Ideographic"},
    183867: {"Unified_Ideograph", "Ideographic"},
    183868: {"Unified_Ideograph", "Ideographic"},
    183869: {"Unified_Ideograph", "Ideographic"},
    183870: {"Unified_Ideograph", "Ideographic"},
    183871: {"Unified_Ideograph", "Ideographic"},
    183872: {"Unified_Ideograph", "Ideographic"},
    183873: {"Unified_Ideograph", "Ideographic"},
    183874: {"Unified_Ideograph", "Ideographic"},
    183875: {"Unified_Ideograph", "Ideographic"},
    183876: {"Unified_Ideograph", "Ideographic"},
    183877: {"Unified_Ideograph", "Ideographic"},
    183878: {"Unified_Ideograph", "Ideographic"},
    183879: {"Unified_Ideograph", "Ideographic"},
    183880: {"Unified_Ideograph", "Ideographic"},
    183881: {"Unified_Ideograph", "Ideographic"},
    183882: {"Unified_Ideograph", "Ideographic"},
    183883: {"Unified_Ideograph", "Ideographic"},
    183884: {"Unified_Ideograph", "Ideographic"},
    183885: {"Unified_Ideograph", "Ideographic"},
    183886: {"Unified_Ideograph", "Ideographic"},
    183887: {"Unified_Ideograph", "Ideographic"},
    183888: {"Unified_Ideograph", "Ideographic"},
    183889: {"Unified_Ideograph", "Ideographic"},
    183890: {"Unified_Ideograph", "Ideographic"},
    183891: {"Unified_Ideograph", "Ideographic"},
    183892: {"Unified_Ideograph", "Ideographic"},
    183893: {"Unified_Ideograph", "Ideographic"},
    183894: {"Unified_Ideograph", "Ideographic"},
    183895: {"Unified_Ideograph", "Ideographic"},
    183896: {"Unified_Ideograph", "Ideographic"},
    183897: {"Unified_Ideograph", "Ideographic"},
    183898: {"Unified_Ideograph", "Ideographic"},
    183899: {"Unified_Ideograph", "Ideographic"},
    183900: {"Unified_Ideograph", "Ideographic"},
    183901: {"Unified_Ideograph", "Ideographic"},
    183902: {"Unified_Ideograph", "Ideographic"},
    183903: {"Unified_Ideograph", "Ideographic"},
    183904: {"Unified_Ideograph", "Ideographic"},
    183905: {"Unified_Ideograph", "Ideographic"},
    183906: {"Unified_Ideograph", "Ideographic"},
    183907: {"Unified_Ideograph", "Ideographic"},
    183908: {"Unified_Ideograph", "Ideographic"},
    183909: {"Unified_Ideograph", "Ideographic"},
    183910: {"Unified_Ideograph", "Ideographic"},
    183911: {"Unified_Ideograph", "Ideographic"},
    183912: {"Unified_Ideograph", "Ideographic"},
    183913: {"Unified_Ideograph", "Ideographic"},
    183914: {"Unified_Ideograph", "Ideographic"},
    183915: {"Unified_Ideograph", "Ideographic"},
    183916: {"Unified_Ideograph", "Ideographic"},
    183917: {"Unified_Ideograph", "Ideographic"},
    183918: {"Unified_Ideograph", "Ideographic"},
    183919: {"Unified_Ideograph", "Ideographic"},
    183920: {"Unified_Ideograph", "Ideographic"},
    183921: {"Unified_Ideograph", "Ideographic"},
    183922: {"Unified_Ideograph", "Ideographic"},
    183923: {"Unified_Ideograph", "Ideographic"},
    183924: {"Unified_Ideograph", "Ideographic"},
    183925: {"Unified_Ideograph", "Ideographic"},
    183926: {"Unified_Ideograph", "Ideographic"},
    183927: {"Unified_Ideograph", "Ideographic"},
    183928: {"Unified_Ideograph", "Ideographic"},
    183929: {"Unified_Ideograph", "Ideographic"},
    183930: {"Unified_Ideograph", "Ideographic"},
    183931: {"Unified_Ideograph", "Ideographic"},
    183932: {"Unified_Ideograph", "Ideographic"},
    183933: {"Unified_Ideograph", "Ideographic"},
    183934: {"Unified_Ideograph", "Ideographic"},
    183935: {"Unified_Ideograph", "Ideographic"},
    183936: {"Unified_Ideograph", "Ideographic"},
    183937: {"Unified_Ideograph", "Ideographic"},
    183938: {"Unified_Ideograph", "Ideographic"},
    183939: {"Unified_Ideograph", "Ideographic"},
    183940: {"Unified_Ideograph", "Ideographic"},
    183941: {"Unified_Ideograph", "Ideographic"},
    183942: {"Unified_Ideograph", "Ideographic"},
    183943: {"Unified_Ideograph", "Ideographic"},
    183944: {"Unified_Ideograph", "Ideographic"},
    183945: {"Unified_Ideograph", "Ideographic"},
    183946: {"Unified_Ideograph", "Ideographic"},
    183947: {"Unified_Ideograph", "Ideographic"},
    183948: {"Unified_Ideograph", "Ideographic"},
    183949: {"Unified_Ideograph", "Ideographic"},
    183950: {"Unified_Ideograph", "Ideographic"},
    183951: {"Unified_Ideograph", "Ideographic"},
    183952: {"Unified_Ideograph", "Ideographic"},
    183953: {"Unified_Ideograph", "Ideographic"},
    183954: {"Unified_Ideograph", "Ideographic"},
    183955: {"Unified_Ideograph", "Ideographic"},
    183956: {"Unified_Ideograph", "Ideographic"},
    183957: {"Unified_Ideograph", "Ideographic"},
    183958: {"Unified_Ideograph", "Ideographic"},
    183959: {"Unified_Ideograph", "Ideographic"},
    183960: {"Unified_Ideograph", "Ideographic"},
    183961: {"Unified_Ideograph", "Ideographic"},
    183962: {"Unified_Ideograph", "Ideographic"},
    183963: {"Unified_Ideograph", "Ideographic"},
    183964: {"Unified_Ideograph", "Ideographic"},
    183965: {"Unified_Ideograph", "Ideographic"},
    183966: {"Unified_Ideograph", "Ideographic"},
    183967: {"Unified_Ideograph", "Ideographic"},
    183968: {"Unified_Ideograph", "Ideographic"},
    183969: {"Unified_Ideograph", "Ideographic"},
    183984: {"Unified_Ideograph", "Ideographic"},
    183985: {"Unified_Ideograph", "Ideographic"},
    183986: {"Unified_Ideograph", "Ideographic"},
    183987: {"Unified_Ideograph", "Ideographic"},
    183988: {"Unified_Ideograph", "Ideographic"},
    183989: {"Unified_Ideograph", "Ideographic"},
    183990: {"Unified_Ideograph", "Ideographic"},
    183991: {"Unified_Ideograph", "Ideographic"},
    183992: {"Unified_Ideograph", "Ideographic"},
    183993: {"Unified_Ideograph", "Ideographic"},
    183994: {"Unified_Ideograph", "Ideographic"},
    183995: {"Unified_Ideograph", "Ideographic"},
    183996: {"Unified_Ideograph", "Ideographic"},
    183997: {"Unified_Ideograph", "Ideographic"},
    183998: {"Unified_Ideograph", "Ideographic"},
    183999: {"Unified_Ideograph", "Ideographic"},
    184000: {"Unified_Ideograph", "Ideographic"},
    184001: {"Unified_Ideograph", "Ideographic"},
    184002: {"Unified_Ideograph", "Ideographic"},
    184003: {"Unified_Ideograph", "Ideographic"},
    184004: {"Unified_Ideograph", "Ideographic"},
    184005: {"Unified_Ideograph", "Ideographic"},
    184006: {"Unified_Ideograph", "Ideographic"},
    184007: {"Unified_Ideograph", "Ideographic"},
    184008: {"Unified_Ideograph", "Ideographic"},
    184009: {"Unified_Ideograph", "Ideographic"},
    184010: {"Unified_Ideograph", "Ideographic"},
    184011: {"Unified_Ideograph", "Ideographic"},
    184012: {"Unified_Ideograph", "Ideographic"},
    184013: {"Unified_Ideograph", "Ideographic"},
    184014: {"Unified_Ideograph", "Ideographic"},
    184015: {"Unified_Ideograph", "Ideographic"},
    184016: {"Unified_Ideograph", "Ideographic"},
    184017: {"Unified_Ideograph", "Ideographic"},
    184018: {"Unified_Ideograph", "Ideographic"},
    184019: {"Unified_Ideograph", "Ideographic"},
    184020: {"Unified_Ideograph", "Ideographic"},
    184021: {"Unified_Ideograph", "Ideographic"},
    184022: {"Unified_Ideograph", "Ideographic"},
    184023: {"Unified_Ideograph", "Ideographic"},
    184024: {"Unified_Ideograph", "Ideographic"},
    184025: {"Unified_Ideograph", "Ideographic"},
    184026: {"Unified_Ideograph", "Ideographic"},
    184027: {"Unified_Ideograph", "Ideographic"},
    184028: {"Unified_Ideograph", "Ideographic"},
    184029: {"Unified_Ideograph", "Ideographic"},
    184030: {"Unified_Ideograph", "Ideographic"},
    184031: {"Unified_Ideograph", "Ideographic"},
    184032: {"Unified_Ideograph", "Ideographic"},
    184033: {"Unified_Ideograph", "Ideographic"},
    184034: {"Unified_Ideograph", "Ideographic"},
    184035: {"Unified_Ideograph", "Ideographic"},
    184036: {"Unified_Ideograph", "Ideographic"},
    184037: {"Unified_Ideograph", "Ideographic"},
    184038: {"Unified_Ideograph", "Ideographic"},
    184039: {"Unified_Ideograph", "Ideographic"},
    184040: {"Unified_Ideograph", "Ideographic"},
    184041: {"Unified_Ideograph", "Ideographic"},
    184042: {"Unified_Ideograph", "Ideographic"},
    184043: {"Unified_Ideograph", "Ideographic"},
    184044: {"Unified_Ideograph", "Ideographic"},
    184045: {"Unified_Ideograph", "Ideographic"},
    184046: {"Unified_Ideograph", "Ideographic"},
    184047: {"Unified_Ideograph", "Ideographic"},
    184048: {"Unified_Ideograph", "Ideographic"},
    184049: {"Unified_Ideograph", "Ideographic"},
    184050: {"Unified_Ideograph", "Ideographic"},
    184051: {"Unified_Ideograph", "Ideographic"},
    184052: {"Unified_Ideograph", "Ideographic"},
    184053: {"Unified_Ideograph", "Ideographic"},
    184054: {"Unified_Ideograph", "Ideographic"},
    184055: {"Unified_Ideograph", "Ideographic"},
    184056: {"Unified_Ideograph", "Ideographic"},
    184057: {"Unified_Ideograph", "Ideographic"},
    184058: {"Unified_Ideograph", "Ideographic"},
    184059: {"Unified_Ideograph", "Ideographic"},
    184060: {"Unified_Ideograph", "Ideographic"},
    184061: {"Unified_Ideograph", "Ideographic"},
    184062: {"Unified_Ideograph", "Ideographic"},
    184063: {"Unified_Ideograph", "Ideographic"},
    184064: {"Unified_Ideograph", "Ideographic"},
    184065: {"Unified_Ideograph", "Ideographic"},
    184066: {"Unified_Ideograph", "Ideographic"},
    184067: {"Unified_Ideograph", "Ideographic"},
    184068: {"Unified_Ideograph", "Ideographic"},
    184069: {"Unified_Ideograph", "Ideographic"},
    184070: {"Unified_Ideograph", "Ideographic"},
    184071: {"Unified_Ideograph", "Ideographic"},
    184072: {"Unified_Ideograph", "Ideographic"},
    184073: {"Unified_Ideograph", "Ideographic"},
    184074: {"Unified_Ideograph", "Ideographic"},
    184075: {"Unified_Ideograph", "Ideographic"},
    184076: {"Unified_Ideograph", "Ideographic"},
    184077: {"Unified_Ideograph", "Ideographic"},
    184078: {"Unified_Ideograph", "Ideographic"},
    184079: {"Unified_Ideograph", "Ideographic"},
    184080: {"Unified_Ideograph", "Ideographic"},
    184081: {"Unified_Ideograph", "Ideographic"},
    184082: {"Unified_Ideograph", "Ideographic"},
    184083: {"Unified_Ideograph", "Ideographic"},
    184084: {"Unified_Ideograph", "Ideographic"},
    184085: {"Unified_Ideograph", "Ideographic"},
    184086: {"Unified_Ideograph", "Ideographic"},
    184087: {"Unified_Ideograph", "Ideographic"},
    184088: {"Unified_Ideograph", "Ideographic"},
    184089: {"Unified_Ideograph", "Ideographic"},
    184090: {"Unified_Ideograph", "Ideographic"},
    184091: {"Unified_Ideograph", "Ideographic"},
    184092: {"Unified_Ideograph", "Ideographic"},
    184093: {"Unified_Ideograph", "Ideographic"},
    184094: {"Unified_Ideograph", "Ideographic"},
    184095: {"Unified_Ideograph", "Ideographic"},
    184096: {"Unified_Ideograph", "Ideographic"},
    184097: {"Unified_Ideograph", "Ideographic"},
    184098: {"Unified_Ideograph", "Ideographic"},
    184099: {"Unified_Ideograph", "Ideographic"},
    184100: {"Unified_Ideograph", "Ideographic"},
    184101: {"Unified_Ideograph", "Ideographic"},
    184102: {"Unified_Ideograph", "Ideographic"},
    184103: {"Unified_Ideograph", "Ideographic"},
    184104: {"Unified_Ideograph", "Ideographic"},
    184105: {"Unified_Ideograph", "Ideographic"},
    184106: {"Unified_Ideograph", "Ideographic"},
    184107: {"Unified_Ideograph", "Ideographic"},
    184108: {"Unified_Ideograph", "Ideographic"},
    184109: {"Unified_Ideograph", "Ideographic"},
    184110: {"Unified_Ideograph", "Ideographic"},
    184111: {"Unified_Ideograph", "Ideographic"},
    184112: {"Unified_Ideograph", "Ideographic"},
    184113: {"Unified_Ideograph", "Ideographic"},
    184114: {"Unified_Ideograph", "Ideographic"},
    184115: {"Unified_Ideograph", "Ideographic"},
    184116: {"Unified_Ideograph", "Ideographic"},
    184117: {"Unified_Ideograph", "Ideographic"},
    184118: {"Unified_Ideograph", "Ideographic"},
    184119: {"Unified_Ideograph", "Ideographic"},
    184120: {"Unified_Ideograph", "Ideographic"},
    184121: {"Unified_Ideograph", "Ideographic"},
    184122: {"Unified_Ideograph", "Ideographic"},
    184123: {"Unified_Ideograph", "Ideographic"},
    184124: {"Unified_Ideograph", "Ideographic"},
    184125: {"Unified_Ideograph", "Ideographic"},
    184126: {"Unified_Ideograph", "Ideographic"},
    184127: {"Unified_Ideograph", "Ideographic"},
    184128: {"Unified_Ideograph", "Ideographic"},
    184129: {"Unified_Ideograph", "Ideographic"},
    184130: {"Unified_Ideograph", "Ideographic"},
    184131: {"Unified_Ideograph", "Ideographic"},
    184132: {"Unified_Ideograph", "Ideographic"},
    184133: {"Unified_Ideograph", "Ideographic"},
    184134: {"Unified_Ideograph", "Ideographic"},
    184135: {"Unified_Ideograph", "Ideographic"},
    184136: {"Unified_Ideograph", "Ideographic"},
    184137: {"Unified_Ideograph", "Ideographic"},
    184138: {"Unified_Ideograph", "Ideographic"},
    184139: {"Unified_Ideograph", "Ideographic"},
    184140: {"Unified_Ideograph", "Ideographic"},
    184141: {"Unified_Ideograph", "Ideographic"},
    184142: {"Unified_Ideograph", "Ideographic"},
    184143: {"Unified_Ideograph", "Ideographic"},
    184144: {"Unified_Ideograph", "Ideographic"},
    184145: {"Unified_Ideograph", "Ideographic"},
    184146: {"Unified_Ideograph", "Ideographic"},
    184147: {"Unified_Ideograph", "Ideographic"},
    184148: {"Unified_Ideograph", "Ideographic"},
    184149: {"Unified_Ideograph", "Ideographic"},
    184150: {"Unified_Ideograph", "Ideographic"},
    184151: {"Unified_Ideograph", "Ideographic"},
    184152: {"Unified_Ideograph", "Ideographic"},
    184153: {"Unified_Ideograph", "Ideographic"},
    184154: {"Unified_Ideograph", "Ideographic"},
    184155: {"Unified_Ideograph", "Ideographic"},
    184156: {"Unified_Ideograph", "Ideographic"},
    184157: {"Unified_Ideograph", "Ideographic"},
    184158: {"Unified_Ideograph", "Ideographic"},
    184159: {"Unified_Ideograph", "Ideographic"},
    184160: {"Unified_Ideograph", "Ideographic"},
    184161: {"Unified_Ideograph", "Ideographic"},
    184162: {"Unified_Ideograph", "Ideographic"},
    184163: {"Unified_Ideograph", "Ideographic"},
    184164: {"Unified_Ideograph", "Ideographic"},
    184165: {"Unified_Ideograph", "Ideographic"},
    184166: {"Unified_Ideograph", "Ideographic"},
    184167: {"Unified_Ideograph", "Ideographic"},
    184168: {"Unified_Ideograph", "Ideographic"},
    184169: {"Unified_Ideograph", "Ideographic"},
    184170: {"Unified_Ideograph", "Ideographic"},
    184171: {"Unified_Ideograph", "Ideographic"},
    184172: {"Unified_Ideograph", "Ideographic"},
    184173: {"Unified_Ideograph", "Ideographic"},
    184174: {"Unified_Ideograph", "Ideographic"},
    184175: {"Unified_Ideograph", "Ideographic"},
    184176: {"Unified_Ideograph", "Ideographic"},
    184177: {"Unified_Ideograph", "Ideographic"},
    184178: {"Unified_Ideograph", "Ideographic"},
    184179: {"Unified_Ideograph", "Ideographic"},
    184180: {"Unified_Ideograph", "Ideographic"},
    184181: {"Unified_Ideograph", "Ideographic"},
    184182: {"Unified_Ideograph", "Ideographic"},
    184183: {"Unified_Ideograph", "Ideographic"},
    184184: {"Unified_Ideograph", "Ideographic"},
    184185: {"Unified_Ideograph", "Ideographic"},
    184186: {"Unified_Ideograph", "Ideographic"},
    184187: {"Unified_Ideograph", "Ideographic"},
    184188: {"Unified_Ideograph", "Ideographic"},
    184189: {"Unified_Ideograph", "Ideographic"},
    184190: {"Unified_Ideograph", "Ideographic"},
    184191: {"Unified_Ideograph", "Ideographic"},
    184192: {"Unified_Ideograph", "Ideographic"},
    184193: {"Unified_Ideograph", "Ideographic"},
    184194: {"Unified_Ideograph", "Ideographic"},
    184195: {"Unified_Ideograph", "Ideographic"},
    184196: {"Unified_Ideograph", "Ideographic"},
    184197: {"Unified_Ideograph", "Ideographic"},
    184198: {"Unified_Ideograph", "Ideographic"},
    184199: {"Unified_Ideograph", "Ideographic"},
    184200: {"Unified_Ideograph", "Ideographic"},
    184201: {"Unified_Ideograph", "Ideographic"},
    184202: {"Unified_Ideograph", "Ideographic"},
    184203: {"Unified_Ideograph", "Ideographic"},
    184204: {"Unified_Ideograph", "Ideographic"},
    184205: {"Unified_Ideograph", "Ideographic"},
    184206: {"Unified_Ideograph", "Ideographic"},
    184207: {"Unified_Ideograph", "Ideographic"},
    184208: {"Unified_Ideograph", "Ideographic"},
    184209: {"Unified_Ideograph", "Ideographic"},
    184210: {"Unified_Ideograph", "Ideographic"},
    184211: {"Unified_Ideograph", "Ideographic"},
    184212: {"Unified_Ideograph", "Ideographic"},
    184213: {"Unified_Ideograph", "Ideographic"},
    184214: {"Unified_Ideograph", "Ideographic"},
    184215: {"Unified_Ideograph", "Ideographic"},
    184216: {"Unified_Ideograph", "Ideographic"},
    184217: {"Unified_Ideograph", "Ideographic"},
    184218: {"Unified_Ideograph", "Ideographic"},
    184219: {"Unified_Ideograph", "Ideographic"},
    184220: {"Unified_Ideograph", "Ideographic"},
    184221: {"Unified_Ideograph", "Ideographic"},
    184222: {"Unified_Ideograph", "Ideographic"},
    184223: {"Unified_Ideograph", "Ideographic"},
    184224: {"Unified_Ideograph", "Ideographic"},
    184225: {"Unified_Ideograph", "Ideographic"},
    184226: {"Unified_Ideograph", "Ideographic"},
    184227: {"Unified_Ideograph", "Ideographic"},
    184228: {"Unified_Ideograph", "Ideographic"},
    184229: {"Unified_Ideograph", "Ideographic"},
    184230: {"Unified_Ideograph", "Ideographic"},
    184231: {"Unified_Ideograph", "Ideographic"},
    184232: {"Unified_Ideograph", "Ideographic"},
    184233: {"Unified_Ideograph", "Ideographic"},
    184234: {"Unified_Ideograph", "Ideographic"},
    184235: {"Unified_Ideograph", "Ideographic"},
    184236: {"Unified_Ideograph", "Ideographic"},
    184237: {"Unified_Ideograph", "Ideographic"},
    184238: {"Unified_Ideograph", "Ideographic"},
    184239: {"Unified_Ideograph", "Ideographic"},
    184240: {"Unified_Ideograph", "Ideographic"},
    184241: {"Unified_Ideograph", "Ideographic"},
    184242: {"Unified_Ideograph", "Ideographic"},
    184243: {"Unified_Ideograph", "Ideographic"},
    184244: {"Unified_Ideograph", "Ideographic"},
    184245: {"Unified_Ideograph", "Ideographic"},
    184246: {"Unified_Ideograph", "Ideographic"},
    184247: {"Unified_Ideograph", "Ideographic"},
    184248: {"Unified_Ideograph", "Ideographic"},
    184249: {"Unified_Ideograph", "Ideographic"},
    184250: {"Unified_Ideograph", "Ideographic"},
    184251: {"Unified_Ideograph", "Ideographic"},
    184252: {"Unified_Ideograph", "Ideographic"},
    184253: {"Unified_Ideograph", "Ideographic"},
    184254: {"Unified_Ideograph", "Ideographic"},
    184255: {"Unified_Ideograph", "Ideographic"},
    184256: {"Unified_Ideograph", "Ideographic"},
    184257: {"Unified_Ideograph", "Ideographic"},
    184258: {"Unified_Ideograph", "Ideographic"},
    184259: {"Unified_Ideograph", "Ideographic"},
    184260: {"Unified_Ideograph", "Ideographic"},
    184261: {"Unified_Ideograph", "Ideographic"},
    184262: {"Unified_Ideograph", "Ideographic"},
    184263: {"Unified_Ideograph", "Ideographic"},
    184264: {"Unified_Ideograph", "Ideographic"},
    184265: {"Unified_Ideograph", "Ideographic"},
    184266: {"Unified_Ideograph", "Ideographic"},
    184267: {"Unified_Ideograph", "Ideographic"},
    184268: {"Unified_Ideograph", "Ideographic"},
    184269: {"Unified_Ideograph", "Ideographic"},
    184270: {"Unified_Ideograph", "Ideographic"},
    184271: {"Unified_Ideograph", "Ideographic"},
    184272: {"Unified_Ideograph", "Ideographic"},
    184273: {"Unified_Ideograph", "Ideographic"},
    184274: {"Unified_Ideograph", "Ideographic"},
    184275: {"Unified_Ideograph", "Ideographic"},
    184276: {"Unified_Ideograph", "Ideographic"},
    184277: {"Unified_Ideograph", "Ideographic"},
    184278: {"Unified_Ideograph", "Ideographic"},
    184279: {"Unified_Ideograph", "Ideographic"},
    184280: {"Unified_Ideograph", "Ideographic"},
    184281: {"Unified_Ideograph", "Ideographic"},
    184282: {"Unified_Ideograph", "Ideographic"},
    184283: {"Unified_Ideograph", "Ideographic"},
    184284: {"Unified_Ideograph", "Ideographic"},
    184285: {"Unified_Ideograph", "Ideographic"},
    184286: {"Unified_Ideograph", "Ideographic"},
    184287: {"Unified_Ideograph", "Ideographic"},
    184288: {"Unified_Ideograph", "Ideographic"},
    184289: {"Unified_Ideograph", "Ideographic"},
    184290: {"Unified_Ideograph", "Ideographic"},
    184291: {"Unified_Ideograph", "Ideographic"},
    184292: {"Unified_Ideograph", "Ideographic"},
    184293: {"Unified_Ideograph", "Ideographic"},
    184294: {"Unified_Ideograph", "Ideographic"},
    184295: {"Unified_Ideograph", "Ideographic"},
    184296: {"Unified_Ideograph", "Ideographic"},
    184297: {"Unified_Ideograph", "Ideographic"},
    184298: {"Unified_Ideograph", "Ideographic"},
    184299: {"Unified_Ideograph", "Ideographic"},
    184300: {"Unified_Ideograph", "Ideographic"},
    184301: {"Unified_Ideograph", "Ideographic"},
    184302: {"Unified_Ideograph", "Ideographic"},
    184303: {"Unified_Ideograph", "Ideographic"},
    184304: {"Unified_Ideograph", "Ideographic"},
    184305: {"Unified_Ideograph", "Ideographic"},
    184306: {"Unified_Ideograph", "Ideographic"},
    184307: {"Unified_Ideograph", "Ideographic"},
    184308: {"Unified_Ideograph", "Ideographic"},
    184309: {"Unified_Ideograph", "Ideographic"},
    184310: {"Unified_Ideograph", "Ideographic"},
    184311: {"Unified_Ideograph", "Ideographic"},
    184312: {"Unified_Ideograph", "Ideographic"},
    184313: {"Unified_Ideograph", "Ideographic"},
    184314: {"Unified_Ideograph", "Ideographic"},
    184315: {"Unified_Ideograph", "Ideographic"},
    184316: {"Unified_Ideograph", "Ideographic"},
    184317: {"Unified_Ideograph", "Ideographic"},
    184318: {"Unified_Ideograph", "Ideographic"},
    184319: {"Unified_Ideograph", "Ideographic"},
    184320: {"Unified_Ideograph", "Ideographic"},
    184321: {"Unified_Ideograph", "Ideographic"},
    184322: {"Unified_Ideograph", "Ideographic"},
    184323: {"Unified_Ideograph", "Ideographic"},
    184324: {"Unified_Ideograph", "Ideographic"},
    184325: {"Unified_Ideograph", "Ideographic"},
    184326: {"Unified_Ideograph", "Ideographic"},
    184327: {"Unified_Ideograph", "Ideographic"},
    184328: {"Unified_Ideograph", "Ideographic"},
    184329: {"Unified_Ideograph", "Ideographic"},
    184330: {"Unified_Ideograph", "Ideographic"},
    184331: {"Unified_Ideograph", "Ideographic"},
    184332: {"Unified_Ideograph", "Ideographic"},
    184333: {"Unified_Ideograph", "Ideographic"},
    184334: {"Unified_Ideograph", "Ideographic"},
    184335: {"Unified_Ideograph", "Ideographic"},
    184336: {"Unified_Ideograph", "Ideographic"},
    184337: {"Unified_Ideograph", "Ideographic"},
    184338: {"Unified_Ideograph", "Ideographic"},
    184339: {"Unified_Ideograph", "Ideographic"},
    184340: {"Unified_Ideograph", "Ideographic"},
    184341: {"Unified_Ideograph", "Ideographic"},
    184342: {"Unified_Ideograph", "Ideographic"},
    184343: {"Unified_Ideograph", "Ideographic"},
    184344: {"Unified_Ideograph", "Ideographic"},
    184345: {"Unified_Ideograph", "Ideographic"},
    184346: {"Unified_Ideograph", "Ideographic"},
    184347: {"Unified_Ideograph", "Ideographic"},
    184348: {"Unified_Ideograph", "Ideographic"},
    184349: {"Unified_Ideograph", "Ideographic"},
    184350: {"Unified_Ideograph", "Ideographic"},
    184351: {"Unified_Ideograph", "Ideographic"},
    184352: {"Unified_Ideograph", "Ideographic"},
    184353: {"Unified_Ideograph", "Ideographic"},
    184354: {"Unified_Ideograph", "Ideographic"},
    184355: {"Unified_Ideograph", "Ideographic"},
    184356: {"Unified_Ideograph", "Ideographic"},
    184357: {"Unified_Ideograph", "Ideographic"},
    184358: {"Unified_Ideograph", "Ideographic"},
    184359: {"Unified_Ideograph", "Ideographic"},
    184360: {"Unified_Ideograph", "Ideographic"},
    184361: {"Unified_Ideograph", "Ideographic"},
    184362: {"Unified_Ideograph", "Ideographic"},
    184363: {"Unified_Ideograph", "Ideographic"},
    184364: {"Unified_Ideograph", "Ideographic"},
    184365: {"Unified_Ideograph", "Ideographic"},
    184366: {"Unified_Ideograph", "Ideographic"},
    184367: {"Unified_Ideograph", "Ideographic"},
    184368: {"Unified_Ideograph", "Ideographic"},
    184369: {"Unified_Ideograph", "Ideographic"},
    184370: {"Unified_Ideograph", "Ideographic"},
    184371: {"Unified_Ideograph", "Ideographic"},
    184372: {"Unified_Ideograph", "Ideographic"},
    184373: {"Unified_Ideograph", "Ideographic"},
    184374: {"Unified_Ideograph", "Ideographic"},
    184375: {"Unified_Ideograph", "Ideographic"},
    184376: {"Unified_Ideograph", "Ideographic"},
    184377: {"Unified_Ideograph", "Ideographic"},
    184378: {"Unified_Ideograph", "Ideographic"},
    184379: {"Unified_Ideograph", "Ideographic"},
    184380: {"Unified_Ideograph", "Ideographic"},
    184381: {"Unified_Ideograph", "Ideographic"},
    184382: {"Unified_Ideograph", "Ideographic"},
    184383: {"Unified_Ideograph", "Ideographic"},
    184384: {"Unified_Ideograph", "Ideographic"},
    184385: {"Unified_Ideograph", "Ideographic"},
    184386: {"Unified_Ideograph", "Ideographic"},
    184387: {"Unified_Ideograph", "Ideographic"},
    184388: {"Unified_Ideograph", "Ideographic"},
    184389: {"Unified_Ideograph", "Ideographic"},
    184390: {"Unified_Ideograph", "Ideographic"},
    184391: {"Unified_Ideograph", "Ideographic"},
    184392: {"Unified_Ideograph", "Ideographic"},
    184393: {"Unified_Ideograph", "Ideographic"},
    184394: {"Unified_Ideograph", "Ideographic"},
    184395: {"Unified_Ideograph", "Ideographic"},
    184396: {"Unified_Ideograph", "Ideographic"},
    184397: {"Unified_Ideograph", "Ideographic"},
    184398: {"Unified_Ideograph", "Ideographic"},
    184399: {"Unified_Ideograph", "Ideographic"},
    184400: {"Unified_Ideograph", "Ideographic"},
    184401: {"Unified_Ideograph", "Ideographic"},
    184402: {"Unified_Ideograph", "Ideographic"},
    184403: {"Unified_Ideograph", "Ideographic"},
    184404: {"Unified_Ideograph", "Ideographic"},
    184405: {"Unified_Ideograph", "Ideographic"},
    184406: {"Unified_Ideograph", "Ideographic"},
    184407: {"Unified_Ideograph", "Ideographic"},
    184408: {"Unified_Ideograph", "Ideographic"},
    184409: {"Unified_Ideograph", "Ideographic"},
    184410: {"Unified_Ideograph", "Ideographic"},
    184411: {"Unified_Ideograph", "Ideographic"},
    184412: {"Unified_Ideograph", "Ideographic"},
    184413: {"Unified_Ideograph", "Ideographic"},
    184414: {"Unified_Ideograph", "Ideographic"},
    184415: {"Unified_Ideograph", "Ideographic"},
    184416: {"Unified_Ideograph", "Ideographic"},
    184417: {"Unified_Ideograph", "Ideographic"},
    184418: {"Unified_Ideograph", "Ideographic"},
    184419: {"Unified_Ideograph", "Ideographic"},
    184420: {"Unified_Ideograph", "Ideographic"},
    184421: {"Unified_Ideograph", "Ideographic"},
    184422: {"Unified_Ideograph", "Ideographic"},
    184423: {"Unified_Ideograph", "Ideographic"},
    184424: {"Unified_Ideograph", "Ideographic"},
    184425: {"Unified_Ideograph", "Ideographic"},
    184426: {"Unified_Ideograph", "Ideographic"},
    184427: {"Unified_Ideograph", "Ideographic"},
    184428: {"Unified_Ideograph", "Ideographic"},
    184429: {"Unified_Ideograph", "Ideographic"},
    184430: {"Unified_Ideograph", "Ideographic"},
    184431: {"Unified_Ideograph", "Ideographic"},
    184432: {"Unified_Ideograph", "Ideographic"},
    184433: {"Unified_Ideograph", "Ideographic"},
    184434: {"Unified_Ideograph", "Ideographic"},
    184435: {"Unified_Ideograph", "Ideographic"},
    184436: {"Unified_Ideograph", "Ideographic"},
    184437: {"Unified_Ideograph", "Ideographic"},
    184438: {"Unified_Ideograph", "Ideographic"},
    184439: {"Unified_Ideograph", "Ideographic"},
    184440: {"Unified_Ideograph", "Ideographic"},
    184441: {"Unified_Ideograph", "Ideographic"},
    184442: {"Unified_Ideograph", "Ideographic"},
    184443: {"Unified_Ideograph", "Ideographic"},
    184444: {"Unified_Ideograph", "Ideographic"},
    184445: {"Unified_Ideograph", "Ideographic"},
    184446: {"Unified_Ideograph", "Ideographic"},
    184447: {"Unified_Ideograph", "Ideographic"},
    184448: {"Unified_Ideograph", "Ideographic"},
    184449: {"Unified_Ideograph", "Ideographic"},
    184450: {"Unified_Ideograph", "Ideographic"},
    184451: {"Unified_Ideograph", "Ideographic"},
    184452: {"Unified_Ideograph", "Ideographic"},
    184453: {"Unified_Ideograph", "Ideographic"},
    184454: {"Unified_Ideograph", "Ideographic"},
    184455: {"Unified_Ideograph", "Ideographic"},
    184456: {"Unified_Ideograph", "Ideographic"},
    184457: {"Unified_Ideograph", "Ideographic"},
    184458: {"Unified_Ideograph", "Ideographic"},
    184459: {"Unified_Ideograph", "Ideographic"},
    184460: {"Unified_Ideograph", "Ideographic"},
    184461: {"Unified_Ideograph", "Ideographic"},
    184462: {"Unified_Ideograph", "Ideographic"},
    184463: {"Unified_Ideograph", "Ideographic"},
    184464: {"Unified_Ideograph", "Ideographic"},
    184465: {"Unified_Ideograph", "Ideographic"},
    184466: {"Unified_Ideograph", "Ideographic"},
    184467: {"Unified_Ideograph", "Ideographic"},
    184468: {"Unified_Ideograph", "Ideographic"},
    184469: {"Unified_Ideograph", "Ideographic"},
    184470: {"Unified_Ideograph", "Ideographic"},
    184471: {"Unified_Ideograph", "Ideographic"},
    184472: {"Unified_Ideograph", "Ideographic"},
    184473: {"Unified_Ideograph", "Ideographic"},
    184474: {"Unified_Ideograph", "Ideographic"},
    184475: {"Unified_Ideograph", "Ideographic"},
    184476: {"Unified_Ideograph", "Ideographic"},
    184477: {"Unified_Ideograph", "Ideographic"},
    184478: {"Unified_Ideograph", "Ideographic"},
    184479: {"Unified_Ideograph", "Ideographic"},
    184480: {"Unified_Ideograph", "Ideographic"},
    184481: {"Unified_Ideograph", "Ideographic"},
    184482: {"Unified_Ideograph", "Ideographic"},
    184483: {"Unified_Ideograph", "Ideographic"},
    184484: {"Unified_Ideograph", "Ideographic"},
    184485: {"Unified_Ideograph", "Ideographic"},
    184486: {"Unified_Ideograph", "Ideographic"},
    184487: {"Unified_Ideograph", "Ideographic"},
    184488: {"Unified_Ideograph", "Ideographic"},
    184489: {"Unified_Ideograph", "Ideographic"},
    184490: {"Unified_Ideograph", "Ideographic"},
    184491: {"Unified_Ideograph", "Ideographic"},
    184492: {"Unified_Ideograph", "Ideographic"},
    184493: {"Unified_Ideograph", "Ideographic"},
    184494: {"Unified_Ideograph", "Ideographic"},
    184495: {"Unified_Ideograph", "Ideographic"},
    184496: {"Unified_Ideograph", "Ideographic"},
    184497: {"Unified_Ideograph", "Ideographic"},
    184498: {"Unified_Ideograph", "Ideographic"},
    184499: {"Unified_Ideograph", "Ideographic"},
    184500: {"Unified_Ideograph", "Ideographic"},
    184501: {"Unified_Ideograph", "Ideographic"},
    184502: {"Unified_Ideograph", "Ideographic"},
    184503: {"Unified_Ideograph", "Ideographic"},
    184504: {"Unified_Ideograph", "Ideographic"},
    184505: {"Unified_Ideograph", "Ideographic"},
    184506: {"Unified_Ideograph", "Ideographic"},
    184507: {"Unified_Ideograph", "Ideographic"},
    184508: {"Unified_Ideograph", "Ideographic"},
    184509: {"Unified_Ideograph", "Ideographic"},
    184510: {"Unified_Ideograph", "Ideographic"},
    184511: {"Unified_Ideograph", "Ideographic"},
    184512: {"Unified_Ideograph", "Ideographic"},
    184513: {"Unified_Ideograph", "Ideographic"},
    184514: {"Unified_Ideograph", "Ideographic"},
    184515: {"Unified_Ideograph", "Ideographic"},
    184516: {"Unified_Ideograph", "Ideographic"},
    184517: {"Unified_Ideograph", "Ideographic"},
    184518: {"Unified_Ideograph", "Ideographic"},
    184519: {"Unified_Ideograph", "Ideographic"},
    184520: {"Unified_Ideograph", "Ideographic"},
    184521: {"Unified_Ideograph", "Ideographic"},
    184522: {"Unified_Ideograph", "Ideographic"},
    184523: {"Unified_Ideograph", "Ideographic"},
    184524: {"Unified_Ideograph", "Ideographic"},
    184525: {"Unified_Ideograph", "Ideographic"},
    184526: {"Unified_Ideograph", "Ideographic"},
    184527: {"Unified_Ideograph", "Ideographic"},
    184528: {"Unified_Ideograph", "Ideographic"},
    184529: {"Unified_Ideograph", "Ideographic"},
    184530: {"Unified_Ideograph", "Ideographic"},
    184531: {"Unified_Ideograph", "Ideographic"},
    184532: {"Unified_Ideograph", "Ideographic"},
    184533: {"Unified_Ideograph", "Ideographic"},
    184534: {"Unified_Ideograph", "Ideographic"},
    184535: {"Unified_Ideograph", "Ideographic"},
    184536: {"Unified_Ideograph", "Ideographic"},
    184537: {"Unified_Ideograph", "Ideographic"},
    184538: {"Unified_Ideograph", "Ideographic"},
    184539: {"Unified_Ideograph", "Ideographic"},
    184540: {"Unified_Ideograph", "Ideographic"},
    184541: {"Unified_Ideograph", "Ideographic"},
    184542: {"Unified_Ideograph", "Ideographic"},
    184543: {"Unified_Ideograph", "Ideographic"},
    184544: {"Unified_Ideograph", "Ideographic"},
    184545: {"Unified_Ideograph", "Ideographic"},
    184546: {"Unified_Ideograph", "Ideographic"},
    184547: {"Unified_Ideograph", "Ideographic"},
    184548: {"Unified_Ideograph", "Ideographic"},
    184549: {"Unified_Ideograph", "Ideographic"},
    184550: {"Unified_Ideograph", "Ideographic"},
    184551: {"Unified_Ideograph", "Ideographic"},
    184552: {"Unified_Ideograph", "Ideographic"},
    184553: {"Unified_Ideograph", "Ideographic"},
    184554: {"Unified_Ideograph", "Ideographic"},
    184555: {"Unified_Ideograph", "Ideographic"},
    184556: {"Unified_Ideograph", "Ideographic"},
    184557: {"Unified_Ideograph", "Ideographic"},
    184558: {"Unified_Ideograph", "Ideographic"},
    184559: {"Unified_Ideograph", "Ideographic"},
    184560: {"Unified_Ideograph", "Ideographic"},
    184561: {"Unified_Ideograph", "Ideographic"},
    184562: {"Unified_Ideograph", "Ideographic"},
    184563: {"Unified_Ideograph", "Ideographic"},
    184564: {"Unified_Ideograph", "Ideographic"},
    184565: {"Unified_Ideograph", "Ideographic"},
    184566: {"Unified_Ideograph", "Ideographic"},
    184567: {"Unified_Ideograph", "Ideographic"},
    184568: {"Unified_Ideograph", "Ideographic"},
    184569: {"Unified_Ideograph", "Ideographic"},
    184570: {"Unified_Ideograph", "Ideographic"},
    184571: {"Unified_Ideograph", "Ideographic"},
    184572: {"Unified_Ideograph", "Ideographic"},
    184573: {"Unified_Ideograph", "Ideographic"},
    184574: {"Unified_Ideograph", "Ideographic"},
    184575: {"Unified_Ideograph", "Ideographic"},
    184576: {"Unified_Ideograph", "Ideographic"},
    184577: {"Unified_Ideograph", "Ideographic"},
    184578: {"Unified_Ideograph", "Ideographic"},
    184579: {"Unified_Ideograph", "Ideographic"},
    184580: {"Unified_Ideograph", "Ideographic"},
    184581: {"Unified_Ideograph", "Ideographic"},
    184582: {"Unified_Ideograph", "Ideographic"},
    184583: {"Unified_Ideograph", "Ideographic"},
    184584: {"Unified_Ideograph", "Ideographic"},
    184585: {"Unified_Ideograph", "Ideographic"},
    184586: {"Unified_Ideograph", "Ideographic"},
    184587: {"Unified_Ideograph", "Ideographic"},
    184588: {"Unified_Ideograph", "Ideographic"},
    184589: {"Unified_Ideograph", "Ideographic"},
    184590: {"Unified_Ideograph", "Ideographic"},
    184591: {"Unified_Ideograph", "Ideographic"},
    184592: {"Unified_Ideograph", "Ideographic"},
    184593: {"Unified_Ideograph", "Ideographic"},
    184594: {"Unified_Ideograph", "Ideographic"},
    184595: {"Unified_Ideograph", "Ideographic"},
    184596: {"Unified_Ideograph", "Ideographic"},
    184597: {"Unified_Ideograph", "Ideographic"},
    184598: {"Unified_Ideograph", "Ideographic"},
    184599: {"Unified_Ideograph", "Ideographic"},
    184600: {"Unified_Ideograph", "Ideographic"},
    184601: {"Unified_Ideograph", "Ideographic"},
    184602: {"Unified_Ideograph", "Ideographic"},
    184603: {"Unified_Ideograph", "Ideographic"},
    184604: {"Unified_Ideograph", "Ideographic"},
    184605: {"Unified_Ideograph", "Ideographic"},
    184606: {"Unified_Ideograph", "Ideographic"},
    184607: {"Unified_Ideograph", "Ideographic"},
    184608: {"Unified_Ideograph", "Ideographic"},
    184609: {"Unified_Ideograph", "Ideographic"},
    184610: {"Unified_Ideograph", "Ideographic"},
    184611: {"Unified_Ideograph", "Ideographic"},
    184612: {"Unified_Ideograph", "Ideographic"},
    184613: {"Unified_Ideograph", "Ideographic"},
    184614: {"Unified_Ideograph", "Ideographic"},
    184615: {"Unified_Ideograph", "Ideographic"},
    184616: {"Unified_Ideograph", "Ideographic"},
    184617: {"Unified_Ideograph", "Ideographic"},
    184618: {"Unified_Ideograph", "Ideographic"},
    184619: {"Unified_Ideograph", "Ideographic"},
    184620: {"Unified_Ideograph", "Ideographic"},
    184621: {"Unified_Ideograph", "Ideographic"},
    184622: {"Unified_Ideograph", "Ideographic"},
    184623: {"Unified_Ideograph", "Ideographic"},
    184624: {"Unified_Ideograph", "Ideographic"},
    184625: {"Unified_Ideograph", "Ideographic"},
    184626: {"Unified_Ideograph", "Ideographic"},
    184627: {"Unified_Ideograph", "Ideographic"},
    184628: {"Unified_Ideograph", "Ideographic"},
    184629: {"Unified_Ideograph", "Ideographic"},
    184630: {"Unified_Ideograph", "Ideographic"},
    184631: {"Unified_Ideograph", "Ideographic"},
    184632: {"Unified_Ideograph", "Ideographic"},
    184633: {"Unified_Ideograph", "Ideographic"},
    184634: {"Unified_Ideograph", "Ideographic"},
    184635: {"Unified_Ideograph", "Ideographic"},
    184636: {"Unified_Ideograph", "Ideographic"},
    184637: {"Unified_Ideograph", "Ideographic"},
    184638: {"Unified_Ideograph", "Ideographic"},
    184639: {"Unified_Ideograph", "Ideographic"},
    184640: {"Unified_Ideograph", "Ideographic"},
    184641: {"Unified_Ideograph", "Ideographic"},
    184642: {"Unified_Ideograph", "Ideographic"},
    184643: {"Unified_Ideograph", "Ideographic"},
    184644: {"Unified_Ideograph", "Ideographic"},
    184645: {"Unified_Ideograph", "Ideographic"},
    184646: {"Unified_Ideograph", "Ideographic"},
    184647: {"Unified_Ideograph", "Ideographic"},
    184648: {"Unified_Ideograph", "Ideographic"},
    184649: {"Unified_Ideograph", "Ideographic"},
    184650: {"Unified_Ideograph", "Ideographic"},
    184651: {"Unified_Ideograph", "Ideographic"},
    184652: {"Unified_Ideograph", "Ideographic"},
    184653: {"Unified_Ideograph", "Ideographic"},
    184654: {"Unified_Ideograph", "Ideographic"},
    184655: {"Unified_Ideograph", "Ideographic"},
    184656: {"Unified_Ideograph", "Ideographic"},
    184657: {"Unified_Ideograph", "Ideographic"},
    184658: {"Unified_Ideograph", "Ideographic"},
    184659: {"Unified_Ideograph", "Ideographic"},
    184660: {"Unified_Ideograph", "Ideographic"},
    184661: {"Unified_Ideograph", "Ideographic"},
    184662: {"Unified_Ideograph", "Ideographic"},
    184663: {"Unified_Ideograph", "Ideographic"},
    184664: {"Unified_Ideograph", "Ideographic"},
    184665: {"Unified_Ideograph", "Ideographic"},
    184666: {"Unified_Ideograph", "Ideographic"},
    184667: {"Unified_Ideograph", "Ideographic"},
    184668: {"Unified_Ideograph", "Ideographic"},
    184669: {"Unified_Ideograph", "Ideographic"},
    184670: {"Unified_Ideograph", "Ideographic"},
    184671: {"Unified_Ideograph", "Ideographic"},
    184672: {"Unified_Ideograph", "Ideographic"},
    184673: {"Unified_Ideograph", "Ideographic"},
    184674: {"Unified_Ideograph", "Ideographic"},
    184675: {"Unified_Ideograph", "Ideographic"},
    184676: {"Unified_Ideograph", "Ideographic"},
    184677: {"Unified_Ideograph", "Ideographic"},
    184678: {"Unified_Ideograph", "Ideographic"},
    184679: {"Unified_Ideograph", "Ideographic"},
    184680: {"Unified_Ideograph", "Ideographic"},
    184681: {"Unified_Ideograph", "Ideographic"},
    184682: {"Unified_Ideograph", "Ideographic"},
    184683: {"Unified_Ideograph", "Ideographic"},
    184684: {"Unified_Ideograph", "Ideographic"},
    184685: {"Unified_Ideograph", "Ideographic"},
    184686: {"Unified_Ideograph", "Ideographic"},
    184687: {"Unified_Ideograph", "Ideographic"},
    184688: {"Unified_Ideograph", "Ideographic"},
    184689: {"Unified_Ideograph", "Ideographic"},
    184690: {"Unified_Ideograph", "Ideographic"},
    184691: {"Unified_Ideograph", "Ideographic"},
    184692: {"Unified_Ideograph", "Ideographic"},
    184693: {"Unified_Ideograph", "Ideographic"},
    184694: {"Unified_Ideograph", "Ideographic"},
    184695: {"Unified_Ideograph", "Ideographic"},
    184696: {"Unified_Ideograph", "Ideographic"},
    184697: {"Unified_Ideograph", "Ideographic"},
    184698: {"Unified_Ideograph", "Ideographic"},
    184699: {"Unified_Ideograph", "Ideographic"},
    184700: {"Unified_Ideograph", "Ideographic"},
    184701: {"Unified_Ideograph", "Ideographic"},
    184702: {"Unified_Ideograph", "Ideographic"},
    184703: {"Unified_Ideograph", "Ideographic"},
    184704: {"Unified_Ideograph", "Ideographic"},
    184705: {"Unified_Ideograph", "Ideographic"},
    184706: {"Unified_Ideograph", "Ideographic"},
    184707: {"Unified_Ideograph", "Ideographic"},
    184708: {"Unified_Ideograph", "Ideographic"},
    184709: {"Unified_Ideograph", "Ideographic"},
    184710: {"Unified_Ideograph", "Ideographic"},
    184711: {"Unified_Ideograph", "Ideographic"},
    184712: {"Unified_Ideograph", "Ideographic"},
    184713: {"Unified_Ideograph", "Ideographic"},
    184714: {"Unified_Ideograph", "Ideographic"},
    184715: {"Unified_Ideograph", "Ideographic"},
    184716: {"Unified_Ideograph", "Ideographic"},
    184717: {"Unified_Ideograph", "Ideographic"},
    184718: {"Unified_Ideograph", "Ideographic"},
    184719: {"Unified_Ideograph", "Ideographic"},
    184720: {"Unified_Ideograph", "Ideographic"},
    184721: {"Unified_Ideograph", "Ideographic"},
    184722: {"Unified_Ideograph", "Ideographic"},
    184723: {"Unified_Ideograph", "Ideographic"},
    184724: {"Unified_Ideograph", "Ideographic"},
    184725: {"Unified_Ideograph", "Ideographic"},
    184726: {"Unified_Ideograph", "Ideographic"},
    184727: {"Unified_Ideograph", "Ideographic"},
    184728: {"Unified_Ideograph", "Ideographic"},
    184729: {"Unified_Ideograph", "Ideographic"},
    184730: {"Unified_Ideograph", "Ideographic"},
    184731: {"Unified_Ideograph", "Ideographic"},
    184732: {"Unified_Ideograph", "Ideographic"},
    184733: {"Unified_Ideograph", "Ideographic"},
    184734: {"Unified_Ideograph", "Ideographic"},
    184735: {"Unified_Ideograph", "Ideographic"},
    184736: {"Unified_Ideograph", "Ideographic"},
    184737: {"Unified_Ideograph", "Ideographic"},
    184738: {"Unified_Ideograph", "Ideographic"},
    184739: {"Unified_Ideograph", "Ideographic"},
    184740: {"Unified_Ideograph", "Ideographic"},
    184741: {"Unified_Ideograph", "Ideographic"},
    184742: {"Unified_Ideograph", "Ideographic"},
    184743: {"Unified_Ideograph", "Ideographic"},
    184744: {"Unified_Ideograph", "Ideographic"},
    184745: {"Unified_Ideograph", "Ideographic"},
    184746: {"Unified_Ideograph", "Ideographic"},
    184747: {"Unified_Ideograph", "Ideographic"},
    184748: {"Unified_Ideograph", "Ideographic"},
    184749: {"Unified_Ideograph", "Ideographic"},
    184750: {"Unified_Ideograph", "Ideographic"},
    184751: {"Unified_Ideograph", "Ideographic"},
    184752: {"Unified_Ideograph", "Ideographic"},
    184753: {"Unified_Ideograph", "Ideographic"},
    184754: {"Unified_Ideograph", "Ideographic"},
    184755: {"Unified_Ideograph", "Ideographic"},
    184756: {"Unified_Ideograph", "Ideographic"},
    184757: {"Unified_Ideograph", "Ideographic"},
    184758: {"Unified_Ideograph", "Ideographic"},
    184759: {"Unified_Ideograph", "Ideographic"},
    184760: {"Unified_Ideograph", "Ideographic"},
    184761: {"Unified_Ideograph", "Ideographic"},
    184762: {"Unified_Ideograph", "Ideographic"},
    184763: {"Unified_Ideograph", "Ideographic"},
    184764: {"Unified_Ideograph", "Ideographic"},
    184765: {"Unified_Ideograph", "Ideographic"},
    184766: {"Unified_Ideograph", "Ideographic"},
    184767: {"Unified_Ideograph", "Ideographic"},
    184768: {"Unified_Ideograph", "Ideographic"},
    184769: {"Unified_Ideograph", "Ideographic"},
    184770: {"Unified_Ideograph", "Ideographic"},
    184771: {"Unified_Ideograph", "Ideographic"},
    184772: {"Unified_Ideograph", "Ideographic"},
    184773: {"Unified_Ideograph", "Ideographic"},
    184774: {"Unified_Ideograph", "Ideographic"},
    184775: {"Unified_Ideograph", "Ideographic"},
    184776: {"Unified_Ideograph", "Ideographic"},
    184777: {"Unified_Ideograph", "Ideographic"},
    184778: {"Unified_Ideograph", "Ideographic"},
    184779: {"Unified_Ideograph", "Ideographic"},
    184780: {"Unified_Ideograph", "Ideographic"},
    184781: {"Unified_Ideograph", "Ideographic"},
    184782: {"Unified_Ideograph", "Ideographic"},
    184783: {"Unified_Ideograph", "Ideographic"},
    184784: {"Unified_Ideograph", "Ideographic"},
    184785: {"Unified_Ideograph", "Ideographic"},
    184786: {"Unified_Ideograph", "Ideographic"},
    184787: {"Unified_Ideograph", "Ideographic"},
    184788: {"Unified_Ideograph", "Ideographic"},
    184789: {"Unified_Ideograph", "Ideographic"},
    184790: {"Unified_Ideograph", "Ideographic"},
    184791: {"Unified_Ideograph", "Ideographic"},
    184792: {"Unified_Ideograph", "Ideographic"},
    184793: {"Unified_Ideograph", "Ideographic"},
    184794: {"Unified_Ideograph", "Ideographic"},
    184795: {"Unified_Ideograph", "Ideographic"},
    184796: {"Unified_Ideograph", "Ideographic"},
    184797: {"Unified_Ideograph", "Ideographic"},
    184798: {"Unified_Ideograph", "Ideographic"},
    184799: {"Unified_Ideograph", "Ideographic"},
    184800: {"Unified_Ideograph", "Ideographic"},
    184801: {"Unified_Ideograph", "Ideographic"},
    184802: {"Unified_Ideograph", "Ideographic"},
    184803: {"Unified_Ideograph", "Ideographic"},
    184804: {"Unified_Ideograph", "Ideographic"},
    184805: {"Unified_Ideograph", "Ideographic"},
    184806: {"Unified_Ideograph", "Ideographic"},
    184807: {"Unified_Ideograph", "Ideographic"},
    184808: {"Unified_Ideograph", "Ideographic"},
    184809: {"Unified_Ideograph", "Ideographic"},
    184810: {"Unified_Ideograph", "Ideographic"},
    184811: {"Unified_Ideograph", "Ideographic"},
    184812: {"Unified_Ideograph", "Ideographic"},
    184813: {"Unified_Ideograph", "Ideographic"},
    184814: {"Unified_Ideograph", "Ideographic"},
    184815: {"Unified_Ideograph", "Ideographic"},
    184816: {"Unified_Ideograph", "Ideographic"},
    184817: {"Unified_Ideograph", "Ideographic"},
    184818: {"Unified_Ideograph", "Ideographic"},
    184819: {"Unified_Ideograph", "Ideographic"},
    184820: {"Unified_Ideograph", "Ideographic"},
    184821: {"Unified_Ideograph", "Ideographic"},
    184822: {"Unified_Ideograph", "Ideographic"},
    184823: {"Unified_Ideograph", "Ideographic"},
    184824: {"Unified_Ideograph", "Ideographic"},
    184825: {"Unified_Ideograph", "Ideographic"},
    184826: {"Unified_Ideograph", "Ideographic"},
    184827: {"Unified_Ideograph", "Ideographic"},
    184828: {"Unified_Ideograph", "Ideographic"},
    184829: {"Unified_Ideograph", "Ideographic"},
    184830: {"Unified_Ideograph", "Ideographic"},
    184831: {"Unified_Ideograph", "Ideographic"},
    184832: {"Unified_Ideograph", "Ideographic"},
    184833: {"Unified_Ideograph", "Ideographic"},
    184834: {"Unified_Ideograph", "Ideographic"},
    184835: {"Unified_Ideograph", "Ideographic"},
    184836: {"Unified_Ideograph", "Ideographic"},
    184837: {"Unified_Ideograph", "Ideographic"},
    184838: {"Unified_Ideograph", "Ideographic"},
    184839: {"Unified_Ideograph", "Ideographic"},
    184840: {"Unified_Ideograph", "Ideographic"},
    184841: {"Unified_Ideograph", "Ideographic"},
    184842: {"Unified_Ideograph", "Ideographic"},
    184843: {"Unified_Ideograph", "Ideographic"},
    184844: {"Unified_Ideograph", "Ideographic"},
    184845: {"Unified_Ideograph", "Ideographic"},
    184846: {"Unified_Ideograph", "Ideographic"},
    184847: {"Unified_Ideograph", "Ideographic"},
    184848: {"Unified_Ideograph", "Ideographic"},
    184849: {"Unified_Ideograph", "Ideographic"},
    184850: {"Unified_Ideograph", "Ideographic"},
    184851: {"Unified_Ideograph", "Ideographic"},
    184852: {"Unified_Ideograph", "Ideographic"},
    184853: {"Unified_Ideograph", "Ideographic"},
    184854: {"Unified_Ideograph", "Ideographic"},
    184855: {"Unified_Ideograph", "Ideographic"},
    184856: {"Unified_Ideograph", "Ideographic"},
    184857: {"Unified_Ideograph", "Ideographic"},
    184858: {"Unified_Ideograph", "Ideographic"},
    184859: {"Unified_Ideograph", "Ideographic"},
    184860: {"Unified_Ideograph", "Ideographic"},
    184861: {"Unified_Ideograph", "Ideographic"},
    184862: {"Unified_Ideograph", "Ideographic"},
    184863: {"Unified_Ideograph", "Ideographic"},
    184864: {"Unified_Ideograph", "Ideographic"},
    184865: {"Unified_Ideograph", "Ideographic"},
    184866: {"Unified_Ideograph", "Ideographic"},
    184867: {"Unified_Ideograph", "Ideographic"},
    184868: {"Unified_Ideograph", "Ideographic"},
    184869: {"Unified_Ideograph", "Ideographic"},
    184870: {"Unified_Ideograph", "Ideographic"},
    184871: {"Unified_Ideograph", "Ideographic"},
    184872: {"Unified_Ideograph", "Ideographic"},
    184873: {"Unified_Ideograph", "Ideographic"},
    184874: {"Unified_Ideograph", "Ideographic"},
    184875: {"Unified_Ideograph", "Ideographic"},
    184876: {"Unified_Ideograph", "Ideographic"},
    184877: {"Unified_Ideograph", "Ideographic"},
    184878: {"Unified_Ideograph", "Ideographic"},
    184879: {"Unified_Ideograph", "Ideographic"},
    184880: {"Unified_Ideograph", "Ideographic"},
    184881: {"Unified_Ideograph", "Ideographic"},
    184882: {"Unified_Ideograph", "Ideographic"},
    184883: {"Unified_Ideograph", "Ideographic"},
    184884: {"Unified_Ideograph", "Ideographic"},
    184885: {"Unified_Ideograph", "Ideographic"},
    184886: {"Unified_Ideograph", "Ideographic"},
    184887: {"Unified_Ideograph", "Ideographic"},
    184888: {"Unified_Ideograph", "Ideographic"},
    184889: {"Unified_Ideograph", "Ideographic"},
    184890: {"Unified_Ideograph", "Ideographic"},
    184891: {"Unified_Ideograph", "Ideographic"},
    184892: {"Unified_Ideograph", "Ideographic"},
    184893: {"Unified_Ideograph", "Ideographic"},
    184894: {"Unified_Ideograph", "Ideographic"},
    184895: {"Unified_Ideograph", "Ideographic"},
    184896: {"Unified_Ideograph", "Ideographic"},
    184897: {"Unified_Ideograph", "Ideographic"},
    184898: {"Unified_Ideograph", "Ideographic"},
    184899: {"Unified_Ideograph", "Ideographic"},
    184900: {"Unified_Ideograph", "Ideographic"},
    184901: {"Unified_Ideograph", "Ideographic"},
    184902: {"Unified_Ideograph", "Ideographic"},
    184903: {"Unified_Ideograph", "Ideographic"},
    184904: {"Unified_Ideograph", "Ideographic"},
    184905: {"Unified_Ideograph", "Ideographic"},
    184906: {"Unified_Ideograph", "Ideographic"},
    184907: {"Unified_Ideograph", "Ideographic"},
    184908: {"Unified_Ideograph", "Ideographic"},
    184909: {"Unified_Ideograph", "Ideographic"},
    184910: {"Unified_Ideograph", "Ideographic"},
    184911: {"Unified_Ideograph", "Ideographic"},
    184912: {"Unified_Ideograph", "Ideographic"},
    184913: {"Unified_Ideograph", "Ideographic"},
    184914: {"Unified_Ideograph", "Ideographic"},
    184915: {"Unified_Ideograph", "Ideographic"},
    184916: {"Unified_Ideograph", "Ideographic"},
    184917: {"Unified_Ideograph", "Ideographic"},
    184918: {"Unified_Ideograph", "Ideographic"},
    184919: {"Unified_Ideograph", "Ideographic"},
    184920: {"Unified_Ideograph", "Ideographic"},
    184921: {"Unified_Ideograph", "Ideographic"},
    184922: {"Unified_Ideograph", "Ideographic"},
    184923: {"Unified_Ideograph", "Ideographic"},
    184924: {"Unified_Ideograph", "Ideographic"},
    184925: {"Unified_Ideograph", "Ideographic"},
    184926: {"Unified_Ideograph", "Ideographic"},
    184927: {"Unified_Ideograph", "Ideographic"},
    184928: {"Unified_Ideograph", "Ideographic"},
    184929: {"Unified_Ideograph", "Ideographic"},
    184930: {"Unified_Ideograph", "Ideographic"},
    184931: {"Unified_Ideograph", "Ideographic"},
    184932: {"Unified_Ideograph", "Ideographic"},
    184933: {"Unified_Ideograph", "Ideographic"},
    184934: {"Unified_Ideograph", "Ideographic"},
    184935: {"Unified_Ideograph", "Ideographic"},
    184936: {"Unified_Ideograph", "Ideographic"},
    184937: {"Unified_Ideograph", "Ideographic"},
    184938: {"Unified_Ideograph", "Ideographic"},
    184939: {"Unified_Ideograph", "Ideographic"},
    184940: {"Unified_Ideograph", "Ideographic"},
    184941: {"Unified_Ideograph", "Ideographic"},
    184942: {"Unified_Ideograph", "Ideographic"},
    184943: {"Unified_Ideograph", "Ideographic"},
    184944: {"Unified_Ideograph", "Ideographic"},
    184945: {"Unified_Ideograph", "Ideographic"},
    184946: {"Unified_Ideograph", "Ideographic"},
    184947: {"Unified_Ideograph", "Ideographic"},
    184948: {"Unified_Ideograph", "Ideographic"},
    184949: {"Unified_Ideograph", "Ideographic"},
    184950: {"Unified_Ideograph", "Ideographic"},
    184951: {"Unified_Ideograph", "Ideographic"},
    184952: {"Unified_Ideograph", "Ideographic"},
    184953: {"Unified_Ideograph", "Ideographic"},
    184954: {"Unified_Ideograph", "Ideographic"},
    184955: {"Unified_Ideograph", "Ideographic"},
    184956: {"Unified_Ideograph", "Ideographic"},
    184957: {"Unified_Ideograph", "Ideographic"},
    184958: {"Unified_Ideograph", "Ideographic"},
    184959: {"Unified_Ideograph", "Ideographic"},
    184960: {"Unified_Ideograph", "Ideographic"},
    184961: {"Unified_Ideograph", "Ideographic"},
    184962: {"Unified_Ideograph", "Ideographic"},
    184963: {"Unified_Ideograph", "Ideographic"},
    184964: {"Unified_Ideograph", "Ideographic"},
    184965: {"Unified_Ideograph", "Ideographic"},
    184966: {"Unified_Ideograph", "Ideographic"},
    184967: {"Unified_Ideograph", "Ideographic"},
    184968: {"Unified_Ideograph", "Ideographic"},
    184969: {"Unified_Ideograph", "Ideographic"},
    184970: {"Unified_Ideograph", "Ideographic"},
    184971: {"Unified_Ideograph", "Ideographic"},
    184972: {"Unified_Ideograph", "Ideographic"},
    184973: {"Unified_Ideograph", "Ideographic"},
    184974: {"Unified_Ideograph", "Ideographic"},
    184975: {"Unified_Ideograph", "Ideographic"},
    184976: {"Unified_Ideograph", "Ideographic"},
    184977: {"Unified_Ideograph", "Ideographic"},
    184978: {"Unified_Ideograph", "Ideographic"},
    184979: {"Unified_Ideograph", "Ideographic"},
    184980: {"Unified_Ideograph", "Ideographic"},
    184981: {"Unified_Ideograph", "Ideographic"},
    184982: {"Unified_Ideograph", "Ideographic"},
    184983: {"Unified_Ideograph", "Ideographic"},
    184984: {"Unified_Ideograph", "Ideographic"},
    184985: {"Unified_Ideograph", "Ideographic"},
    184986: {"Unified_Ideograph", "Ideographic"},
    184987: {"Unified_Ideograph", "Ideographic"},
    184988: {"Unified_Ideograph", "Ideographic"},
    184989: {"Unified_Ideograph", "Ideographic"},
    184990: {"Unified_Ideograph", "Ideographic"},
    184991: {"Unified_Ideograph", "Ideographic"},
    184992: {"Unified_Ideograph", "Ideographic"},
    184993: {"Unified_Ideograph", "Ideographic"},
    184994: {"Unified_Ideograph", "Ideographic"},
    184995: {"Unified_Ideograph", "Ideographic"},
    184996: {"Unified_Ideograph", "Ideographic"},
    184997: {"Unified_Ideograph", "Ideographic"},
    184998: {"Unified_Ideograph", "Ideographic"},
    184999: {"Unified_Ideograph", "Ideographic"},
    185000: {"Unified_Ideograph", "Ideographic"},
    185001: {"Unified_Ideograph", "Ideographic"},
    185002: {"Unified_Ideograph", "Ideographic"},
    185003: {"Unified_Ideograph", "Ideographic"},
    185004: {"Unified_Ideograph", "Ideographic"},
    185005: {"Unified_Ideograph", "Ideographic"},
    185006: {"Unified_Ideograph", "Ideographic"},
    185007: {"Unified_Ideograph", "Ideographic"},
    185008: {"Unified_Ideograph", "Ideographic"},
    185009: {"Unified_Ideograph", "Ideographic"},
    185010: {"Unified_Ideograph", "Ideographic"},
    185011: {"Unified_Ideograph", "Ideographic"},
    185012: {"Unified_Ideograph", "Ideographic"},
    185013: {"Unified_Ideograph", "Ideographic"},
    185014: {"Unified_Ideograph", "Ideographic"},
    185015: {"Unified_Ideograph", "Ideographic"},
    185016: {"Unified_Ideograph", "Ideographic"},
    185017: {"Unified_Ideograph", "Ideographic"},
    185018: {"Unified_Ideograph", "Ideographic"},
    185019: {"Unified_Ideograph", "Ideographic"},
    185020: {"Unified_Ideograph", "Ideographic"},
    185021: {"Unified_Ideograph", "Ideographic"},
    185022: {"Unified_Ideograph", "Ideographic"},
    185023: {"Unified_Ideograph", "Ideographic"},
    185024: {"Unified_Ideograph", "Ideographic"},
    185025: {"Unified_Ideograph", "Ideographic"},
    185026: {"Unified_Ideograph", "Ideographic"},
    185027: {"Unified_Ideograph", "Ideographic"},
    185028: {"Unified_Ideograph", "Ideographic"},
    185029: {"Unified_Ideograph", "Ideographic"},
    185030: {"Unified_Ideograph", "Ideographic"},
    185031: {"Unified_Ideograph", "Ideographic"},
    185032: {"Unified_Ideograph", "Ideographic"},
    185033: {"Unified_Ideograph", "Ideographic"},
    185034: {"Unified_Ideograph", "Ideographic"},
    185035: {"Unified_Ideograph", "Ideographic"},
    185036: {"Unified_Ideograph", "Ideographic"},
    185037: {"Unified_Ideograph", "Ideographic"},
    185038: {"Unified_Ideograph", "Ideographic"},
    185039: {"Unified_Ideograph", "Ideographic"},
    185040: {"Unified_Ideograph", "Ideographic"},
    185041: {"Unified_Ideograph", "Ideographic"},
    185042: {"Unified_Ideograph", "Ideographic"},
    185043: {"Unified_Ideograph", "Ideographic"},
    185044: {"Unified_Ideograph", "Ideographic"},
    185045: {"Unified_Ideograph", "Ideographic"},
    185046: {"Unified_Ideograph", "Ideographic"},
    185047: {"Unified_Ideograph", "Ideographic"},
    185048: {"Unified_Ideograph", "Ideographic"},
    185049: {"Unified_Ideograph", "Ideographic"},
    185050: {"Unified_Ideograph", "Ideographic"},
    185051: {"Unified_Ideograph", "Ideographic"},
    185052: {"Unified_Ideograph", "Ideographic"},
    185053: {"Unified_Ideograph", "Ideographic"},
    185054: {"Unified_Ideograph", "Ideographic"},
    185055: {"Unified_Ideograph", "Ideographic"},
    185056: {"Unified_Ideograph", "Ideographic"},
    185057: {"Unified_Ideograph", "Ideographic"},
    185058: {"Unified_Ideograph", "Ideographic"},
    185059: {"Unified_Ideograph", "Ideographic"},
    185060: {"Unified_Ideograph", "Ideographic"},
    185061: {"Unified_Ideograph", "Ideographic"},
    185062: {"Unified_Ideograph", "Ideographic"},
    185063: {"Unified_Ideograph", "Ideographic"},
    185064: {"Unified_Ideograph", "Ideographic"},
    185065: {"Unified_Ideograph", "Ideographic"},
    185066: {"Unified_Ideograph", "Ideographic"},
    185067: {"Unified_Ideograph", "Ideographic"},
    185068: {"Unified_Ideograph", "Ideographic"},
    185069: {"Unified_Ideograph", "Ideographic"},
    185070: {"Unified_Ideograph", "Ideographic"},
    185071: {"Unified_Ideograph", "Ideographic"},
    185072: {"Unified_Ideograph", "Ideographic"},
    185073: {"Unified_Ideograph", "Ideographic"},
    185074: {"Unified_Ideograph", "Ideographic"},
    185075: {"Unified_Ideograph", "Ideographic"},
    185076: {"Unified_Ideograph", "Ideographic"},
    185077: {"Unified_Ideograph", "Ideographic"},
    185078: {"Unified_Ideograph", "Ideographic"},
    185079: {"Unified_Ideograph", "Ideographic"},
    185080: {"Unified_Ideograph", "Ideographic"},
    185081: {"Unified_Ideograph", "Ideographic"},
    185082: {"Unified_Ideograph", "Ideographic"},
    185083: {"Unified_Ideograph", "Ideographic"},
    185084: {"Unified_Ideograph", "Ideographic"},
    185085: {"Unified_Ideograph", "Ideographic"},
    185086: {"Unified_Ideograph", "Ideographic"},
    185087: {"Unified_Ideograph", "Ideographic"},
    185088: {"Unified_Ideograph", "Ideographic"},
    185089: {"Unified_Ideograph", "Ideographic"},
    185090: {"Unified_Ideograph", "Ideographic"},
    185091: {"Unified_Ideograph", "Ideographic"},
    185092: {"Unified_Ideograph", "Ideographic"},
    185093: {"Unified_Ideograph", "Ideographic"},
    185094: {"Unified_Ideograph", "Ideographic"},
    185095: {"Unified_Ideograph", "Ideographic"},
    185096: {"Unified_Ideograph", "Ideographic"},
    185097: {"Unified_Ideograph", "Ideographic"},
    185098: {"Unified_Ideograph", "Ideographic"},
    185099: {"Unified_Ideograph", "Ideographic"},
    185100: {"Unified_Ideograph", "Ideographic"},
    185101: {"Unified_Ideograph", "Ideographic"},
    185102: {"Unified_Ideograph", "Ideographic"},
    185103: {"Unified_Ideograph", "Ideographic"},
    185104: {"Unified_Ideograph", "Ideographic"},
    185105: {"Unified_Ideograph", "Ideographic"},
    185106: {"Unified_Ideograph", "Ideographic"},
    185107: {"Unified_Ideograph", "Ideographic"},
    185108: {"Unified_Ideograph", "Ideographic"},
    185109: {"Unified_Ideograph", "Ideographic"},
    185110: {"Unified_Ideograph", "Ideographic"},
    185111: {"Unified_Ideograph", "Ideographic"},
    185112: {"Unified_Ideograph", "Ideographic"},
    185113: {"Unified_Ideograph", "Ideographic"},
    185114: {"Unified_Ideograph", "Ideographic"},
    185115: {"Unified_Ideograph", "Ideographic"},
    185116: {"Unified_Ideograph", "Ideographic"},
    185117: {"Unified_Ideograph", "Ideographic"},
    185118: {"Unified_Ideograph", "Ideographic"},
    185119: {"Unified_Ideograph", "Ideographic"},
    185120: {"Unified_Ideograph", "Ideographic"},
    185121: {"Unified_Ideograph", "Ideographic"},
    185122: {"Unified_Ideograph", "Ideographic"},
    185123: {"Unified_Ideograph", "Ideographic"},
    185124: {"Unified_Ideograph", "Ideographic"},
    185125: {"Unified_Ideograph", "Ideographic"},
    185126: {"Unified_Ideograph", "Ideographic"},
    185127: {"Unified_Ideograph", "Ideographic"},
    185128: {"Unified_Ideograph", "Ideographic"},
    185129: {"Unified_Ideograph", "Ideographic"},
    185130: {"Unified_Ideograph", "Ideographic"},
    185131: {"Unified_Ideograph", "Ideographic"},
    185132: {"Unified_Ideograph", "Ideographic"},
    185133: {"Unified_Ideograph", "Ideographic"},
    185134: {"Unified_Ideograph", "Ideographic"},
    185135: {"Unified_Ideograph", "Ideographic"},
    185136: {"Unified_Ideograph", "Ideographic"},
    185137: {"Unified_Ideograph", "Ideographic"},
    185138: {"Unified_Ideograph", "Ideographic"},
    185139: {"Unified_Ideograph", "Ideographic"},
    185140: {"Unified_Ideograph", "Ideographic"},
    185141: {"Unified_Ideograph", "Ideographic"},
    185142: {"Unified_Ideograph", "Ideographic"},
    185143: {"Unified_Ideograph", "Ideographic"},
    185144: {"Unified_Ideograph", "Ideographic"},
    185145: {"Unified_Ideograph", "Ideographic"},
    185146: {"Unified_Ideograph", "Ideographic"},
    185147: {"Unified_Ideograph", "Ideographic"},
    185148: {"Unified_Ideograph", "Ideographic"},
    185149: {"Unified_Ideograph", "Ideographic"},
    185150: {"Unified_Ideograph", "Ideographic"},
    185151: {"Unified_Ideograph", "Ideographic"},
    185152: {"Unified_Ideograph", "Ideographic"},
    185153: {"Unified_Ideograph", "Ideographic"},
    185154: {"Unified_Ideograph", "Ideographic"},
    185155: {"Unified_Ideograph", "Ideographic"},
    185156: {"Unified_Ideograph", "Ideographic"},
    185157: {"Unified_Ideograph", "Ideographic"},
    185158: {"Unified_Ideograph", "Ideographic"},
    185159: {"Unified_Ideograph", "Ideographic"},
    185160: {"Unified_Ideograph", "Ideographic"},
    185161: {"Unified_Ideograph", "Ideographic"},
    185162: {"Unified_Ideograph", "Ideographic"},
    185163: {"Unified_Ideograph", "Ideographic"},
    185164: {"Unified_Ideograph", "Ideographic"},
    185165: {"Unified_Ideograph", "Ideographic"},
    185166: {"Unified_Ideograph", "Ideographic"},
    185167: {"Unified_Ideograph", "Ideographic"},
    185168: {"Unified_Ideograph", "Ideographic"},
    185169: {"Unified_Ideograph", "Ideographic"},
    185170: {"Unified_Ideograph", "Ideographic"},
    185171: {"Unified_Ideograph", "Ideographic"},
    185172: {"Unified_Ideograph", "Ideographic"},
    185173: {"Unified_Ideograph", "Ideographic"},
    185174: {"Unified_Ideograph", "Ideographic"},
    185175: {"Unified_Ideograph", "Ideographic"},
    185176: {"Unified_Ideograph", "Ideographic"},
    185177: {"Unified_Ideograph", "Ideographic"},
    185178: {"Unified_Ideograph", "Ideographic"},
    185179: {"Unified_Ideograph", "Ideographic"},
    185180: {"Unified_Ideograph", "Ideographic"},
    185181: {"Unified_Ideograph", "Ideographic"},
    185182: {"Unified_Ideograph", "Ideographic"},
    185183: {"Unified_Ideograph", "Ideographic"},
    185184: {"Unified_Ideograph", "Ideographic"},
    185185: {"Unified_Ideograph", "Ideographic"},
    185186: {"Unified_Ideograph", "Ideographic"},
    185187: {"Unified_Ideograph", "Ideographic"},
    185188: {"Unified_Ideograph", "Ideographic"},
    185189: {"Unified_Ideograph", "Ideographic"},
    185190: {"Unified_Ideograph", "Ideographic"},
    185191: {"Unified_Ideograph", "Ideographic"},
    185192: {"Unified_Ideograph", "Ideographic"},
    185193: {"Unified_Ideograph", "Ideographic"},
    185194: {"Unified_Ideograph", "Ideographic"},
    185195: {"Unified_Ideograph", "Ideographic"},
    185196: {"Unified_Ideograph", "Ideographic"},
    185197: {"Unified_Ideograph", "Ideographic"},
    185198: {"Unified_Ideograph", "Ideographic"},
    185199: {"Unified_Ideograph", "Ideographic"},
    185200: {"Unified_Ideograph", "Ideographic"},
    185201: {"Unified_Ideograph", "Ideographic"},
    185202: {"Unified_Ideograph", "Ideographic"},
    185203: {"Unified_Ideograph", "Ideographic"},
    185204: {"Unified_Ideograph", "Ideographic"},
    185205: {"Unified_Ideograph", "Ideographic"},
    185206: {"Unified_Ideograph", "Ideographic"},
    185207: {"Unified_Ideograph", "Ideographic"},
    185208: {"Unified_Ideograph", "Ideographic"},
    185209: {"Unified_Ideograph", "Ideographic"},
    185210: {"Unified_Ideograph", "Ideographic"},
    185211: {"Unified_Ideograph", "Ideographic"},
    185212: {"Unified_Ideograph", "Ideographic"},
    185213: {"Unified_Ideograph", "Ideographic"},
    185214: {"Unified_Ideograph", "Ideographic"},
    185215: {"Unified_Ideograph", "Ideographic"},
    185216: {"Unified_Ideograph", "Ideographic"},
    185217: {"Unified_Ideograph", "Ideographic"},
    185218: {"Unified_Ideograph", "Ideographic"},
    185219: {"Unified_Ideograph", "Ideographic"},
    185220: {"Unified_Ideograph", "Ideographic"},
    185221: {"Unified_Ideograph", "Ideographic"},
    185222: {"Unified_Ideograph", "Ideographic"},
    185223: {"Unified_Ideograph", "Ideographic"},
    185224: {"Unified_Ideograph", "Ideographic"},
    185225: {"Unified_Ideograph", "Ideographic"},
    185226: {"Unified_Ideograph", "Ideographic"},
    185227: {"Unified_Ideograph", "Ideographic"},
    185228: {"Unified_Ideograph", "Ideographic"},
    185229: {"Unified_Ideograph", "Ideographic"},
    185230: {"Unified_Ideograph", "Ideographic"},
    185231: {"Unified_Ideograph", "Ideographic"},
    185232: {"Unified_Ideograph", "Ideographic"},
    185233: {"Unified_Ideograph", "Ideographic"},
    185234: {"Unified_Ideograph", "Ideographic"},
    185235: {"Unified_Ideograph", "Ideographic"},
    185236: {"Unified_Ideograph", "Ideographic"},
    185237: {"Unified_Ideograph", "Ideographic"},
    185238: {"Unified_Ideograph", "Ideographic"},
    185239: {"Unified_Ideograph", "Ideographic"},
    185240: {"Unified_Ideograph", "Ideographic"},
    185241: {"Unified_Ideograph", "Ideographic"},
    185242: {"Unified_Ideograph", "Ideographic"},
    185243: {"Unified_Ideograph", "Ideographic"},
    185244: {"Unified_Ideograph", "Ideographic"},
    185245: {"Unified_Ideograph", "Ideographic"},
    185246: {"Unified_Ideograph", "Ideographic"},
    185247: {"Unified_Ideograph", "Ideographic"},
    185248: {"Unified_Ideograph", "Ideographic"},
    185249: {"Unified_Ideograph", "Ideographic"},
    185250: {"Unified_Ideograph", "Ideographic"},
    185251: {"Unified_Ideograph", "Ideographic"},
    185252: {"Unified_Ideograph", "Ideographic"},
    185253: {"Unified_Ideograph", "Ideographic"},
    185254: {"Unified_Ideograph", "Ideographic"},
    185255: {"Unified_Ideograph", "Ideographic"},
    185256: {"Unified_Ideograph", "Ideographic"},
    185257: {"Unified_Ideograph", "Ideographic"},
    185258: {"Unified_Ideograph", "Ideographic"},
    185259: {"Unified_Ideograph", "Ideographic"},
    185260: {"Unified_Ideograph", "Ideographic"},
    185261: {"Unified_Ideograph", "Ideographic"},
    185262: {"Unified_Ideograph", "Ideographic"},
    185263: {"Unified_Ideograph", "Ideographic"},
    185264: {"Unified_Ideograph", "Ideographic"},
    185265: {"Unified_Ideograph", "Ideographic"},
    185266: {"Unified_Ideograph", "Ideographic"},
    185267: {"Unified_Ideograph", "Ideographic"},
    185268: {"Unified_Ideograph", "Ideographic"},
    185269: {"Unified_Ideograph", "Ideographic"},
    185270: {"Unified_Ideograph", "Ideographic"},
    185271: {"Unified_Ideograph", "Ideographic"},
    185272: {"Unified_Ideograph", "Ideographic"},
    185273: {"Unified_Ideograph", "Ideographic"},
    185274: {"Unified_Ideograph", "Ideographic"},
    185275: {"Unified_Ideograph", "Ideographic"},
    185276: {"Unified_Ideograph", "Ideographic"},
    185277: {"Unified_Ideograph", "Ideographic"},
    185278: {"Unified_Ideograph", "Ideographic"},
    185279: {"Unified_Ideograph", "Ideographic"},
    185280: {"Unified_Ideograph", "Ideographic"},
    185281: {"Unified_Ideograph", "Ideographic"},
    185282: {"Unified_Ideograph", "Ideographic"},
    185283: {"Unified_Ideograph", "Ideographic"},
    185284: {"Unified_Ideograph", "Ideographic"},
    185285: {"Unified_Ideograph", "Ideographic"},
    185286: {"Unified_Ideograph", "Ideographic"},
    185287: {"Unified_Ideograph", "Ideographic"},
    185288: {"Unified_Ideograph", "Ideographic"},
    185289: {"Unified_Ideograph", "Ideographic"},
    185290: {"Unified_Ideograph", "Ideographic"},
    185291: {"Unified_Ideograph", "Ideographic"},
    185292: {"Unified_Ideograph", "Ideographic"},
    185293: {"Unified_Ideograph", "Ideographic"},
    185294: {"Unified_Ideograph", "Ideographic"},
    185295: {"Unified_Ideograph", "Ideographic"},
    185296: {"Unified_Ideograph", "Ideographic"},
    185297: {"Unified_Ideograph", "Ideographic"},
    185298: {"Unified_Ideograph", "Ideographic"},
    185299: {"Unified_Ideograph", "Ideographic"},
    185300: {"Unified_Ideograph", "Ideographic"},
    185301: {"Unified_Ideograph", "Ideographic"},
    185302: {"Unified_Ideograph", "Ideographic"},
    185303: {"Unified_Ideograph", "Ideographic"},
    185304: {"Unified_Ideograph", "Ideographic"},
    185305: {"Unified_Ideograph", "Ideographic"},
    185306: {"Unified_Ideograph", "Ideographic"},
    185307: {"Unified_Ideograph", "Ideographic"},
    185308: {"Unified_Ideograph", "Ideographic"},
    185309: {"Unified_Ideograph", "Ideographic"},
    185310: {"Unified_Ideograph", "Ideographic"},
    185311: {"Unified_Ideograph", "Ideographic"},
    185312: {"Unified_Ideograph", "Ideographic"},
    185313: {"Unified_Ideograph", "Ideographic"},
    185314: {"Unified_Ideograph", "Ideographic"},
    185315: {"Unified_Ideograph", "Ideographic"},
    185316: {"Unified_Ideograph", "Ideographic"},
    185317: {"Unified_Ideograph", "Ideographic"},
    185318: {"Unified_Ideograph", "Ideographic"},
    185319: {"Unified_Ideograph", "Ideographic"},
    185320: {"Unified_Ideograph", "Ideographic"},
    185321: {"Unified_Ideograph", "Ideographic"},
    185322: {"Unified_Ideograph", "Ideographic"},
    185323: {"Unified_Ideograph", "Ideographic"},
    185324: {"Unified_Ideograph", "Ideographic"},
    185325: {"Unified_Ideograph", "Ideographic"},
    185326: {"Unified_Ideograph", "Ideographic"},
    185327: {"Unified_Ideograph", "Ideographic"},
    185328: {"Unified_Ideograph", "Ideographic"},
    185329: {"Unified_Ideograph", "Ideographic"},
    185330: {"Unified_Ideograph", "Ideographic"},
    185331: {"Unified_Ideograph", "Ideographic"},
    185332: {"Unified_Ideograph", "Ideographic"},
    185333: {"Unified_Ideograph", "Ideographic"},
    185334: {"Unified_Ideograph", "Ideographic"},
    185335: {"Unified_Ideograph", "Ideographic"},
    185336: {"Unified_Ideograph", "Ideographic"},
    185337: {"Unified_Ideograph", "Ideographic"},
    185338: {"Unified_Ideograph", "Ideographic"},
    185339: {"Unified_Ideograph", "Ideographic"},
    185340: {"Unified_Ideograph", "Ideographic"},
    185341: {"Unified_Ideograph", "Ideographic"},
    185342: {"Unified_Ideograph", "Ideographic"},
    185343: {"Unified_Ideograph", "Ideographic"},
    185344: {"Unified_Ideograph", "Ideographic"},
    185345: {"Unified_Ideograph", "Ideographic"},
    185346: {"Unified_Ideograph", "Ideographic"},
    185347: {"Unified_Ideograph", "Ideographic"},
    185348: {"Unified_Ideograph", "Ideographic"},
    185349: {"Unified_Ideograph", "Ideographic"},
    185350: {"Unified_Ideograph", "Ideographic"},
    185351: {"Unified_Ideograph", "Ideographic"},
    185352: {"Unified_Ideograph", "Ideographic"},
    185353: {"Unified_Ideograph", "Ideographic"},
    185354: {"Unified_Ideograph", "Ideographic"},
    185355: {"Unified_Ideograph", "Ideographic"},
    185356: {"Unified_Ideograph", "Ideographic"},
    185357: {"Unified_Ideograph", "Ideographic"},
    185358: {"Unified_Ideograph", "Ideographic"},
    185359: {"Unified_Ideograph", "Ideographic"},
    185360: {"Unified_Ideograph", "Ideographic"},
    185361: {"Unified_Ideograph", "Ideographic"},
    185362: {"Unified_Ideograph", "Ideographic"},
    185363: {"Unified_Ideograph", "Ideographic"},
    185364: {"Unified_Ideograph", "Ideographic"},
    185365: {"Unified_Ideograph", "Ideographic"},
    185366: {"Unified_Ideograph", "Ideographic"},
    185367: {"Unified_Ideograph", "Ideographic"},
    185368: {"Unified_Ideograph", "Ideographic"},
    185369: {"Unified_Ideograph", "Ideographic"},
    185370: {"Unified_Ideograph", "Ideographic"},
    185371: {"Unified_Ideograph", "Ideographic"},
    185372: {"Unified_Ideograph", "Ideographic"},
    185373: {"Unified_Ideograph", "Ideographic"},
    185374: {"Unified_Ideograph", "Ideographic"},
    185375: {"Unified_Ideograph", "Ideographic"},
    185376: {"Unified_Ideograph", "Ideographic"},
    185377: {"Unified_Ideograph", "Ideographic"},
    185378: {"Unified_Ideograph", "Ideographic"},
    185379: {"Unified_Ideograph", "Ideographic"},
    185380: {"Unified_Ideograph", "Ideographic"},
    185381: {"Unified_Ideograph", "Ideographic"},
    185382: {"Unified_Ideograph", "Ideographic"},
    185383: {"Unified_Ideograph", "Ideographic"},
    185384: {"Unified_Ideograph", "Ideographic"},
    185385: {"Unified_Ideograph", "Ideographic"},
    185386: {"Unified_Ideograph", "Ideographic"},
    185387: {"Unified_Ideograph", "Ideographic"},
    185388: {"Unified_Ideograph", "Ideographic"},
    185389: {"Unified_Ideograph", "Ideographic"},
    185390: {"Unified_Ideograph", "Ideographic"},
    185391: {"Unified_Ideograph", "Ideographic"},
    185392: {"Unified_Ideograph", "Ideographic"},
    185393: {"Unified_Ideograph", "Ideographic"},
    185394: {"Unified_Ideograph", "Ideographic"},
    185395: {"Unified_Ideograph", "Ideographic"},
    185396: {"Unified_Ideograph", "Ideographic"},
    185397: {"Unified_Ideograph", "Ideographic"},
    185398: {"Unified_Ideograph", "Ideographic"},
    185399: {"Unified_Ideograph", "Ideographic"},
    185400: {"Unified_Ideograph", "Ideographic"},
    185401: {"Unified_Ideograph", "Ideographic"},
    185402: {"Unified_Ideograph", "Ideographic"},
    185403: {"Unified_Ideograph", "Ideographic"},
    185404: {"Unified_Ideograph", "Ideographic"},
    185405: {"Unified_Ideograph", "Ideographic"},
    185406: {"Unified_Ideograph", "Ideographic"},
    185407: {"Unified_Ideograph", "Ideographic"},
    185408: {"Unified_Ideograph", "Ideographic"},
    185409: {"Unified_Ideograph", "Ideographic"},
    185410: {"Unified_Ideograph", "Ideographic"},
    185411: {"Unified_Ideograph", "Ideographic"},
    185412: {"Unified_Ideograph", "Ideographic"},
    185413: {"Unified_Ideograph", "Ideographic"},
    185414: {"Unified_Ideograph", "Ideographic"},
    185415: {"Unified_Ideograph", "Ideographic"},
    185416: {"Unified_Ideograph", "Ideographic"},
    185417: {"Unified_Ideograph", "Ideographic"},
    185418: {"Unified_Ideograph", "Ideographic"},
    185419: {"Unified_Ideograph", "Ideographic"},
    185420: {"Unified_Ideograph", "Ideographic"},
    185421: {"Unified_Ideograph", "Ideographic"},
    185422: {"Unified_Ideograph", "Ideographic"},
    185423: {"Unified_Ideograph", "Ideographic"},
    185424: {"Unified_Ideograph", "Ideographic"},
    185425: {"Unified_Ideograph", "Ideographic"},
    185426: {"Unified_Ideograph", "Ideographic"},
    185427: {"Unified_Ideograph", "Ideographic"},
    185428: {"Unified_Ideograph", "Ideographic"},
    185429: {"Unified_Ideograph", "Ideographic"},
    185430: {"Unified_Ideograph", "Ideographic"},
    185431: {"Unified_Ideograph", "Ideographic"},
    185432: {"Unified_Ideograph", "Ideographic"},
    185433: {"Unified_Ideograph", "Ideographic"},
    185434: {"Unified_Ideograph", "Ideographic"},
    185435: {"Unified_Ideograph", "Ideographic"},
    185436: {"Unified_Ideograph", "Ideographic"},
    185437: {"Unified_Ideograph", "Ideographic"},
    185438: {"Unified_Ideograph", "Ideographic"},
    185439: {"Unified_Ideograph", "Ideographic"},
    185440: {"Unified_Ideograph", "Ideographic"},
    185441: {"Unified_Ideograph", "Ideographic"},
    185442: {"Unified_Ideograph", "Ideographic"},
    185443: {"Unified_Ideograph", "Ideographic"},
    185444: {"Unified_Ideograph", "Ideographic"},
    185445: {"Unified_Ideograph", "Ideographic"},
    185446: {"Unified_Ideograph", "Ideographic"},
    185447: {"Unified_Ideograph", "Ideographic"},
    185448: {"Unified_Ideograph", "Ideographic"},
    185449: {"Unified_Ideograph", "Ideographic"},
    185450: {"Unified_Ideograph", "Ideographic"},
    185451: {"Unified_Ideograph", "Ideographic"},
    185452: {"Unified_Ideograph", "Ideographic"},
    185453: {"Unified_Ideograph", "Ideographic"},
    185454: {"Unified_Ideograph", "Ideographic"},
    185455: {"Unified_Ideograph", "Ideographic"},
    185456: {"Unified_Ideograph", "Ideographic"},
    185457: {"Unified_Ideograph", "Ideographic"},
    185458: {"Unified_Ideograph", "Ideographic"},
    185459: {"Unified_Ideograph", "Ideographic"},
    185460: {"Unified_Ideograph", "Ideographic"},
    185461: {"Unified_Ideograph", "Ideographic"},
    185462: {"Unified_Ideograph", "Ideographic"},
    185463: {"Unified_Ideograph", "Ideographic"},
    185464: {"Unified_Ideograph", "Ideographic"},
    185465: {"Unified_Ideograph", "Ideographic"},
    185466: {"Unified_Ideograph", "Ideographic"},
    185467: {"Unified_Ideograph", "Ideographic"},
    185468: {"Unified_Ideograph", "Ideographic"},
    185469: {"Unified_Ideograph", "Ideographic"},
    185470: {"Unified_Ideograph", "Ideographic"},
    185471: {"Unified_Ideograph", "Ideographic"},
    185472: {"Unified_Ideograph", "Ideographic"},
    185473: {"Unified_Ideograph", "Ideographic"},
    185474: {"Unified_Ideograph", "Ideographic"},
    185475: {"Unified_Ideograph", "Ideographic"},
    185476: {"Unified_Ideograph", "Ideographic"},
    185477: {"Unified_Ideograph", "Ideographic"},
    185478: {"Unified_Ideograph", "Ideographic"},
    185479: {"Unified_Ideograph", "Ideographic"},
    185480: {"Unified_Ideograph", "Ideographic"},
    185481: {"Unified_Ideograph", "Ideographic"},
    185482: {"Unified_Ideograph", "Ideographic"},
    185483: {"Unified_Ideograph", "Ideographic"},
    185484: {"Unified_Ideograph", "Ideographic"},
    185485: {"Unified_Ideograph", "Ideographic"},
    185486: {"Unified_Ideograph", "Ideographic"},
    185487: {"Unified_Ideograph", "Ideographic"},
    185488: {"Unified_Ideograph", "Ideographic"},
    185489: {"Unified_Ideograph", "Ideographic"},
    185490: {"Unified_Ideograph", "Ideographic"},
    185491: {"Unified_Ideograph", "Ideographic"},
    185492: {"Unified_Ideograph", "Ideographic"},
    185493: {"Unified_Ideograph", "Ideographic"},
    185494: {"Unified_Ideograph", "Ideographic"},
    185495: {"Unified_Ideograph", "Ideographic"},
    185496: {"Unified_Ideograph", "Ideographic"},
    185497: {"Unified_Ideograph", "Ideographic"},
    185498: {"Unified_Ideograph", "Ideographic"},
    185499: {"Unified_Ideograph", "Ideographic"},
    185500: {"Unified_Ideograph", "Ideographic"},
    185501: {"Unified_Ideograph", "Ideographic"},
    185502: {"Unified_Ideograph", "Ideographic"},
    185503: {"Unified_Ideograph", "Ideographic"},
    185504: {"Unified_Ideograph", "Ideographic"},
    185505: {"Unified_Ideograph", "Ideographic"},
    185506: {"Unified_Ideograph", "Ideographic"},
    185507: {"Unified_Ideograph", "Ideographic"},
    185508: {"Unified_Ideograph", "Ideographic"},
    185509: {"Unified_Ideograph", "Ideographic"},
    185510: {"Unified_Ideograph", "Ideographic"},
    185511: {"Unified_Ideograph", "Ideographic"},
    185512: {"Unified_Ideograph", "Ideographic"},
    185513: {"Unified_Ideograph", "Ideographic"},
    185514: {"Unified_Ideograph", "Ideographic"},
    185515: {"Unified_Ideograph", "Ideographic"},
    185516: {"Unified_Ideograph", "Ideographic"},
    185517: {"Unified_Ideograph", "Ideographic"},
    185518: {"Unified_Ideograph", "Ideographic"},
    185519: {"Unified_Ideograph", "Ideographic"},
    185520: {"Unified_Ideograph", "Ideographic"},
    185521: {"Unified_Ideograph", "Ideographic"},
    185522: {"Unified_Ideograph", "Ideographic"},
    185523: {"Unified_Ideograph", "Ideographic"},
    185524: {"Unified_Ideograph", "Ideographic"},
    185525: {"Unified_Ideograph", "Ideographic"},
    185526: {"Unified_Ideograph", "Ideographic"},
    185527: {"Unified_Ideograph", "Ideographic"},
    185528: {"Unified_Ideograph", "Ideographic"},
    185529: {"Unified_Ideograph", "Ideographic"},
    185530: {"Unified_Ideograph", "Ideographic"},
    185531: {"Unified_Ideograph", "Ideographic"},
    185532: {"Unified_Ideograph", "Ideographic"},
    185533: {"Unified_Ideograph", "Ideographic"},
    185534: {"Unified_Ideograph", "Ideographic"},
    185535: {"Unified_Ideograph", "Ideographic"},
    185536: {"Unified_Ideograph", "Ideographic"},
    185537: {"Unified_Ideograph", "Ideographic"},
    185538: {"Unified_Ideograph", "Ideographic"},
    185539: {"Unified_Ideograph", "Ideographic"},
    185540: {"Unified_Ideograph", "Ideographic"},
    185541: {"Unified_Ideograph", "Ideographic"},
    185542: {"Unified_Ideograph", "Ideographic"},
    185543: {"Unified_Ideograph", "Ideographic"},
    185544: {"Unified_Ideograph", "Ideographic"},
    185545: {"Unified_Ideograph", "Ideographic"},
    185546: {"Unified_Ideograph", "Ideographic"},
    185547: {"Unified_Ideograph", "Ideographic"},
    185548: {"Unified_Ideograph", "Ideographic"},
    185549: {"Unified_Ideograph", "Ideographic"},
    185550: {"Unified_Ideograph", "Ideographic"},
    185551: {"Unified_Ideograph", "Ideographic"},
    185552: {"Unified_Ideograph", "Ideographic"},
    185553: {"Unified_Ideograph", "Ideographic"},
    185554: {"Unified_Ideograph", "Ideographic"},
    185555: {"Unified_Ideograph", "Ideographic"},
    185556: {"Unified_Ideograph", "Ideographic"},
    185557: {"Unified_Ideograph", "Ideographic"},
    185558: {"Unified_Ideograph", "Ideographic"},
    185559: {"Unified_Ideograph", "Ideographic"},
    185560: {"Unified_Ideograph", "Ideographic"},
    185561: {"Unified_Ideograph", "Ideographic"},
    185562: {"Unified_Ideograph", "Ideographic"},
    185563: {"Unified_Ideograph", "Ideographic"},
    185564: {"Unified_Ideograph", "Ideographic"},
    185565: {"Unified_Ideograph", "Ideographic"},
    185566: {"Unified_Ideograph", "Ideographic"},
    185567: {"Unified_Ideograph", "Ideographic"},
    185568: {"Unified_Ideograph", "Ideographic"},
    185569: {"Unified_Ideograph", "Ideographic"},
    185570: {"Unified_Ideograph", "Ideographic"},
    185571: {"Unified_Ideograph", "Ideographic"},
    185572: {"Unified_Ideograph", "Ideographic"},
    185573: {"Unified_Ideograph", "Ideographic"},
    185574: {"Unified_Ideograph", "Ideographic"},
    185575: {"Unified_Ideograph", "Ideographic"},
    185576: {"Unified_Ideograph", "Ideographic"},
    185577: {"Unified_Ideograph", "Ideographic"},
    185578: {"Unified_Ideograph", "Ideographic"},
    185579: {"Unified_Ideograph", "Ideographic"},
    185580: {"Unified_Ideograph", "Ideographic"},
    185581: {"Unified_Ideograph", "Ideographic"},
    185582: {"Unified_Ideograph", "Ideographic"},
    185583: {"Unified_Ideograph", "Ideographic"},
    185584: {"Unified_Ideograph", "Ideographic"},
    185585: {"Unified_Ideograph", "Ideographic"},
    185586: {"Unified_Ideograph", "Ideographic"},
    185587: {"Unified_Ideograph", "Ideographic"},
    185588: {"Unified_Ideograph", "Ideographic"},
    185589: {"Unified_Ideograph", "Ideographic"},
    185590: {"Unified_Ideograph", "Ideographic"},
    185591: {"Unified_Ideograph", "Ideographic"},
    185592: {"Unified_Ideograph", "Ideographic"},
    185593: {"Unified_Ideograph", "Ideographic"},
    185594: {"Unified_Ideograph", "Ideographic"},
    185595: {"Unified_Ideograph", "Ideographic"},
    185596: {"Unified_Ideograph", "Ideographic"},
    185597: {"Unified_Ideograph", "Ideographic"},
    185598: {"Unified_Ideograph", "Ideographic"},
    185599: {"Unified_Ideograph", "Ideographic"},
    185600: {"Unified_Ideograph", "Ideographic"},
    185601: {"Unified_Ideograph", "Ideographic"},
    185602: {"Unified_Ideograph", "Ideographic"},
    185603: {"Unified_Ideograph", "Ideographic"},
    185604: {"Unified_Ideograph", "Ideographic"},
    185605: {"Unified_Ideograph", "Ideographic"},
    185606: {"Unified_Ideograph", "Ideographic"},
    185607: {"Unified_Ideograph", "Ideographic"},
    185608: {"Unified_Ideograph", "Ideographic"},
    185609: {"Unified_Ideograph", "Ideographic"},
    185610: {"Unified_Ideograph", "Ideographic"},
    185611: {"Unified_Ideograph", "Ideographic"},
    185612: {"Unified_Ideograph", "Ideographic"},
    185613: {"Unified_Ideograph", "Ideographic"},
    185614: {"Unified_Ideograph", "Ideographic"},
    185615: {"Unified_Ideograph", "Ideographic"},
    185616: {"Unified_Ideograph", "Ideographic"},
    185617: {"Unified_Ideograph", "Ideographic"},
    185618: {"Unified_Ideograph", "Ideographic"},
    185619: {"Unified_Ideograph", "Ideographic"},
    185620: {"Unified_Ideograph", "Ideographic"},
    185621: {"Unified_Ideograph", "Ideographic"},
    185622: {"Unified_Ideograph", "Ideographic"},
    185623: {"Unified_Ideograph", "Ideographic"},
    185624: {"Unified_Ideograph", "Ideographic"},
    185625: {"Unified_Ideograph", "Ideographic"},
    185626: {"Unified_Ideograph", "Ideographic"},
    185627: {"Unified_Ideograph", "Ideographic"},
    185628: {"Unified_Ideograph", "Ideographic"},
    185629: {"Unified_Ideograph", "Ideographic"},
    185630: {"Unified_Ideograph", "Ideographic"},
    185631: {"Unified_Ideograph", "Ideographic"},
    185632: {"Unified_Ideograph", "Ideographic"},
    185633: {"Unified_Ideograph", "Ideographic"},
    185634: {"Unified_Ideograph", "Ideographic"},
    185635: {"Unified_Ideograph", "Ideographic"},
    185636: {"Unified_Ideograph", "Ideographic"},
    185637: {"Unified_Ideograph", "Ideographic"},
    185638: {"Unified_Ideograph", "Ideographic"},
    185639: {"Unified_Ideograph", "Ideographic"},
    185640: {"Unified_Ideograph", "Ideographic"},
    185641: {"Unified_Ideograph", "Ideographic"},
    185642: {"Unified_Ideograph", "Ideographic"},
    185643: {"Unified_Ideograph", "Ideographic"},
    185644: {"Unified_Ideograph", "Ideographic"},
    185645: {"Unified_Ideograph", "Ideographic"},
    185646: {"Unified_Ideograph", "Ideographic"},
    185647: {"Unified_Ideograph", "Ideographic"},
    185648: {"Unified_Ideograph", "Ideographic"},
    185649: {"Unified_Ideograph", "Ideographic"},
    185650: {"Unified_Ideograph", "Ideographic"},
    185651: {"Unified_Ideograph", "Ideographic"},
    185652: {"Unified_Ideograph", "Ideographic"},
    185653: {"Unified_Ideograph", "Ideographic"},
    185654: {"Unified_Ideograph", "Ideographic"},
    185655: {"Unified_Ideograph", "Ideographic"},
    185656: {"Unified_Ideograph", "Ideographic"},
    185657: {"Unified_Ideograph", "Ideographic"},
    185658: {"Unified_Ideograph", "Ideographic"},
    185659: {"Unified_Ideograph", "Ideographic"},
    185660: {"Unified_Ideograph", "Ideographic"},
    185661: {"Unified_Ideograph", "Ideographic"},
    185662: {"Unified_Ideograph", "Ideographic"},
    185663: {"Unified_Ideograph", "Ideographic"},
    185664: {"Unified_Ideograph", "Ideographic"},
    185665: {"Unified_Ideograph", "Ideographic"},
    185666: {"Unified_Ideograph", "Ideographic"},
    185667: {"Unified_Ideograph", "Ideographic"},
    185668: {"Unified_Ideograph", "Ideographic"},
    185669: {"Unified_Ideograph", "Ideographic"},
    185670: {"Unified_Ideograph", "Ideographic"},
    185671: {"Unified_Ideograph", "Ideographic"},
    185672: {"Unified_Ideograph", "Ideographic"},
    185673: {"Unified_Ideograph", "Ideographic"},
    185674: {"Unified_Ideograph", "Ideographic"},
    185675: {"Unified_Ideograph", "Ideographic"},
    185676: {"Unified_Ideograph", "Ideographic"},
    185677: {"Unified_Ideograph", "Ideographic"},
    185678: {"Unified_Ideograph", "Ideographic"},
    185679: {"Unified_Ideograph", "Ideographic"},
    185680: {"Unified_Ideograph", "Ideographic"},
    185681: {"Unified_Ideograph", "Ideographic"},
    185682: {"Unified_Ideograph", "Ideographic"},
    185683: {"Unified_Ideograph", "Ideographic"},
    185684: {"Unified_Ideograph", "Ideographic"},
    185685: {"Unified_Ideograph", "Ideographic"},
    185686: {"Unified_Ideograph", "Ideographic"},
    185687: {"Unified_Ideograph", "Ideographic"},
    185688: {"Unified_Ideograph", "Ideographic"},
    185689: {"Unified_Ideograph", "Ideographic"},
    185690: {"Unified_Ideograph", "Ideographic"},
    185691: {"Unified_Ideograph", "Ideographic"},
    185692: {"Unified_Ideograph", "Ideographic"},
    185693: {"Unified_Ideograph", "Ideographic"},
    185694: {"Unified_Ideograph", "Ideographic"},
    185695: {"Unified_Ideograph", "Ideographic"},
    185696: {"Unified_Ideograph", "Ideographic"},
    185697: {"Unified_Ideograph", "Ideographic"},
    185698: {"Unified_Ideograph", "Ideographic"},
    185699: {"Unified_Ideograph", "Ideographic"},
    185700: {"Unified_Ideograph", "Ideographic"},
    185701: {"Unified_Ideograph", "Ideographic"},
    185702: {"Unified_Ideograph", "Ideographic"},
    185703: {"Unified_Ideograph", "Ideographic"},
    185704: {"Unified_Ideograph", "Ideographic"},
    185705: {"Unified_Ideograph", "Ideographic"},
    185706: {"Unified_Ideograph", "Ideographic"},
    185707: {"Unified_Ideograph", "Ideographic"},
    185708: {"Unified_Ideograph", "Ideographic"},
    185709: {"Unified_Ideograph", "Ideographic"},
    185710: {"Unified_Ideograph", "Ideographic"},
    185711: {"Unified_Ideograph", "Ideographic"},
    185712: {"Unified_Ideograph", "Ideographic"},
    185713: {"Unified_Ideograph", "Ideographic"},
    185714: {"Unified_Ideograph", "Ideographic"},
    185715: {"Unified_Ideograph", "Ideographic"},
    185716: {"Unified_Ideograph", "Ideographic"},
    185717: {"Unified_Ideograph", "Ideographic"},
    185718: {"Unified_Ideograph", "Ideographic"},
    185719: {"Unified_Ideograph", "Ideographic"},
    185720: {"Unified_Ideograph", "Ideographic"},
    185721: {"Unified_Ideograph", "Ideographic"},
    185722: {"Unified_Ideograph", "Ideographic"},
    185723: {"Unified_Ideograph", "Ideographic"},
    185724: {"Unified_Ideograph", "Ideographic"},
    185725: {"Unified_Ideograph", "Ideographic"},
    185726: {"Unified_Ideograph", "Ideographic"},
    185727: {"Unified_Ideograph", "Ideographic"},
    185728: {"Unified_Ideograph", "Ideographic"},
    185729: {"Unified_Ideograph", "Ideographic"},
    185730: {"Unified_Ideograph", "Ideographic"},
    185731: {"Unified_Ideograph", "Ideographic"},
    185732: {"Unified_Ideograph", "Ideographic"},
    185733: {"Unified_Ideograph", "Ideographic"},
    185734: {"Unified_Ideograph", "Ideographic"},
    185735: {"Unified_Ideograph", "Ideographic"},
    185736: {"Unified_Ideograph", "Ideographic"},
    185737: {"Unified_Ideograph", "Ideographic"},
    185738: {"Unified_Ideograph", "Ideographic"},
    185739: {"Unified_Ideograph", "Ideographic"},
    185740: {"Unified_Ideograph", "Ideographic"},
    185741: {"Unified_Ideograph", "Ideographic"},
    185742: {"Unified_Ideograph", "Ideographic"},
    185743: {"Unified_Ideograph", "Ideographic"},
    185744: {"Unified_Ideograph", "Ideographic"},
    185745: {"Unified_Ideograph", "Ideographic"},
    185746: {"Unified_Ideograph", "Ideographic"},
    185747: {"Unified_Ideograph", "Ideographic"},
    185748: {"Unified_Ideograph", "Ideographic"},
    185749: {"Unified_Ideograph", "Ideographic"},
    185750: {"Unified_Ideograph", "Ideographic"},
    185751: {"Unified_Ideograph", "Ideographic"},
    185752: {"Unified_Ideograph", "Ideographic"},
    185753: {"Unified_Ideograph", "Ideographic"},
    185754: {"Unified_Ideograph", "Ideographic"},
    185755: {"Unified_Ideograph", "Ideographic"},
    185756: {"Unified_Ideograph", "Ideographic"},
    185757: {"Unified_Ideograph", "Ideographic"},
    185758: {"Unified_Ideograph", "Ideographic"},
    185759: {"Unified_Ideograph", "Ideographic"},
    185760: {"Unified_Ideograph", "Ideographic"},
    185761: {"Unified_Ideograph", "Ideographic"},
    185762: {"Unified_Ideograph", "Ideographic"},
    185763: {"Unified_Ideograph", "Ideographic"},
    185764: {"Unified_Ideograph", "Ideographic"},
    185765: {"Unified_Ideograph", "Ideographic"},
    185766: {"Unified_Ideograph", "Ideographic"},
    185767: {"Unified_Ideograph", "Ideographic"},
    185768: {"Unified_Ideograph", "Ideographic"},
    185769: {"Unified_Ideograph", "Ideographic"},
    185770: {"Unified_Ideograph", "Ideographic"},
    185771: {"Unified_Ideograph", "Ideographic"},
    185772: {"Unified_Ideograph", "Ideographic"},
    185773: {"Unified_Ideograph", "Ideographic"},
    185774: {"Unified_Ideograph", "Ideographic"},
    185775: {"Unified_Ideograph", "Ideographic"},
    185776: {"Unified_Ideograph", "Ideographic"},
    185777: {"Unified_Ideograph", "Ideographic"},
    185778: {"Unified_Ideograph", "Ideographic"},
    185779: {"Unified_Ideograph", "Ideographic"},
    185780: {"Unified_Ideograph", "Ideographic"},
    185781: {"Unified_Ideograph", "Ideographic"},
    185782: {"Unified_Ideograph", "Ideographic"},
    185783: {"Unified_Ideograph", "Ideographic"},
    185784: {"Unified_Ideograph", "Ideographic"},
    185785: {"Unified_Ideograph", "Ideographic"},
    185786: {"Unified_Ideograph", "Ideographic"},
    185787: {"Unified_Ideograph", "Ideographic"},
    185788: {"Unified_Ideograph", "Ideographic"},
    185789: {"Unified_Ideograph", "Ideographic"},
    185790: {"Unified_Ideograph", "Ideographic"},
    185791: {"Unified_Ideograph", "Ideographic"},
    185792: {"Unified_Ideograph", "Ideographic"},
    185793: {"Unified_Ideograph", "Ideographic"},
    185794: {"Unified_Ideograph", "Ideographic"},
    185795: {"Unified_Ideograph", "Ideographic"},
    185796: {"Unified_Ideograph", "Ideographic"},
    185797: {"Unified_Ideograph", "Ideographic"},
    185798: {"Unified_Ideograph", "Ideographic"},
    185799: {"Unified_Ideograph", "Ideographic"},
    185800: {"Unified_Ideograph", "Ideographic"},
    185801: {"Unified_Ideograph", "Ideographic"},
    185802: {"Unified_Ideograph", "Ideographic"},
    185803: {"Unified_Ideograph", "Ideographic"},
    185804: {"Unified_Ideograph", "Ideographic"},
    185805: {"Unified_Ideograph", "Ideographic"},
    185806: {"Unified_Ideograph", "Ideographic"},
    185807: {"Unified_Ideograph", "Ideographic"},
    185808: {"Unified_Ideograph", "Ideographic"},
    185809: {"Unified_Ideograph", "Ideographic"},
    185810: {"Unified_Ideograph", "Ideographic"},
    185811: {"Unified_Ideograph", "Ideographic"},
    185812: {"Unified_Ideograph", "Ideographic"},
    185813: {"Unified_Ideograph", "Ideographic"},
    185814: {"Unified_Ideograph", "Ideographic"},
    185815: {"Unified_Ideograph", "Ideographic"},
    185816: {"Unified_Ideograph", "Ideographic"},
    185817: {"Unified_Ideograph", "Ideographic"},
    185818: {"Unified_Ideograph", "Ideographic"},
    185819: {"Unified_Ideograph", "Ideographic"},
    185820: {"Unified_Ideograph", "Ideographic"},
    185821: {"Unified_Ideograph", "Ideographic"},
    185822: {"Unified_Ideograph", "Ideographic"},
    185823: {"Unified_Ideograph", "Ideographic"},
    185824: {"Unified_Ideograph", "Ideographic"},
    185825: {"Unified_Ideograph", "Ideographic"},
    185826: {"Unified_Ideograph", "Ideographic"},
    185827: {"Unified_Ideograph", "Ideographic"},
    185828: {"Unified_Ideograph", "Ideographic"},
    185829: {"Unified_Ideograph", "Ideographic"},
    185830: {"Unified_Ideograph", "Ideographic"},
    185831: {"Unified_Ideograph", "Ideographic"},
    185832: {"Unified_Ideograph", "Ideographic"},
    185833: {"Unified_Ideograph", "Ideographic"},
    185834: {"Unified_Ideograph", "Ideographic"},
    185835: {"Unified_Ideograph", "Ideographic"},
    185836: {"Unified_Ideograph", "Ideographic"},
    185837: {"Unified_Ideograph", "Ideographic"},
    185838: {"Unified_Ideograph", "Ideographic"},
    185839: {"Unified_Ideograph", "Ideographic"},
    185840: {"Unified_Ideograph", "Ideographic"},
    185841: {"Unified_Ideograph", "Ideographic"},
    185842: {"Unified_Ideograph", "Ideographic"},
    185843: {"Unified_Ideograph", "Ideographic"},
    185844: {"Unified_Ideograph", "Ideographic"},
    185845: {"Unified_Ideograph", "Ideographic"},
    185846: {"Unified_Ideograph", "Ideographic"},
    185847: {"Unified_Ideograph", "Ideographic"},
    185848: {"Unified_Ideograph", "Ideographic"},
    185849: {"Unified_Ideograph", "Ideographic"},
    185850: {"Unified_Ideograph", "Ideographic"},
    185851: {"Unified_Ideograph", "Ideographic"},
    185852: {"Unified_Ideograph", "Ideographic"},
    185853: {"Unified_Ideograph", "Ideographic"},
    185854: {"Unified_Ideograph", "Ideographic"},
    185855: {"Unified_Ideograph", "Ideographic"},
    185856: {"Unified_Ideograph", "Ideographic"},
    185857: {"Unified_Ideograph", "Ideographic"},
    185858: {"Unified_Ideograph", "Ideographic"},
    185859: {"Unified_Ideograph", "Ideographic"},
    185860: {"Unified_Ideograph", "Ideographic"},
    185861: {"Unified_Ideograph", "Ideographic"},
    185862: {"Unified_Ideograph", "Ideographic"},
    185863: {"Unified_Ideograph", "Ideographic"},
    185864: {"Unified_Ideograph", "Ideographic"},
    185865: {"Unified_Ideograph", "Ideographic"},
    185866: {"Unified_Ideograph", "Ideographic"},
    185867: {"Unified_Ideograph", "Ideographic"},
    185868: {"Unified_Ideograph", "Ideographic"},
    185869: {"Unified_Ideograph", "Ideographic"},
    185870: {"Unified_Ideograph", "Ideographic"},
    185871: {"Unified_Ideograph", "Ideographic"},
    185872: {"Unified_Ideograph", "Ideographic"},
    185873: {"Unified_Ideograph", "Ideographic"},
    185874: {"Unified_Ideograph", "Ideographic"},
    185875: {"Unified_Ideograph", "Ideographic"},
    185876: {"Unified_Ideograph", "Ideographic"},
    185877: {"Unified_Ideograph", "Ideographic"},
    185878: {"Unified_Ideograph", "Ideographic"},
    185879: {"Unified_Ideograph", "Ideographic"},
    185880: {"Unified_Ideograph", "Ideographic"},
    185881: {"Unified_Ideograph", "Ideographic"},
    185882: {"Unified_Ideograph", "Ideographic"},
    185883: {"Unified_Ideograph", "Ideographic"},
    185884: {"Unified_Ideograph", "Ideographic"},
    185885: {"Unified_Ideograph", "Ideographic"},
    185886: {"Unified_Ideograph", "Ideographic"},
    185887: {"Unified_Ideograph", "Ideographic"},
    185888: {"Unified_Ideograph", "Ideographic"},
    185889: {"Unified_Ideograph", "Ideographic"},
    185890: {"Unified_Ideograph", "Ideographic"},
    185891: {"Unified_Ideograph", "Ideographic"},
    185892: {"Unified_Ideograph", "Ideographic"},
    185893: {"Unified_Ideograph", "Ideographic"},
    185894: {"Unified_Ideograph", "Ideographic"},
    185895: {"Unified_Ideograph", "Ideographic"},
    185896: {"Unified_Ideograph", "Ideographic"},
    185897: {"Unified_Ideograph", "Ideographic"},
    185898: {"Unified_Ideograph", "Ideographic"},
    185899: {"Unified_Ideograph", "Ideographic"},
    185900: {"Unified_Ideograph", "Ideographic"},
    185901: {"Unified_Ideograph", "Ideographic"},
    185902: {"Unified_Ideograph", "Ideographic"},
    185903: {"Unified_Ideograph", "Ideographic"},
    185904: {"Unified_Ideograph", "Ideographic"},
    185905: {"Unified_Ideograph", "Ideographic"},
    185906: {"Unified_Ideograph", "Ideographic"},
    185907: {"Unified_Ideograph", "Ideographic"},
    185908: {"Unified_Ideograph", "Ideographic"},
    185909: {"Unified_Ideograph", "Ideographic"},
    185910: {"Unified_Ideograph", "Ideographic"},
    185911: {"Unified_Ideograph", "Ideographic"},
    185912: {"Unified_Ideograph", "Ideographic"},
    185913: {"Unified_Ideograph", "Ideographic"},
    185914: {"Unified_Ideograph", "Ideographic"},
    185915: {"Unified_Ideograph", "Ideographic"},
    185916: {"Unified_Ideograph", "Ideographic"},
    185917: {"Unified_Ideograph", "Ideographic"},
    185918: {"Unified_Ideograph", "Ideographic"},
    185919: {"Unified_Ideograph", "Ideographic"},
    185920: {"Unified_Ideograph", "Ideographic"},
    185921: {"Unified_Ideograph", "Ideographic"},
    185922: {"Unified_Ideograph", "Ideographic"},
    185923: {"Unified_Ideograph", "Ideographic"},
    185924: {"Unified_Ideograph", "Ideographic"},
    185925: {"Unified_Ideograph", "Ideographic"},
    185926: {"Unified_Ideograph", "Ideographic"},
    185927: {"Unified_Ideograph", "Ideographic"},
    185928: {"Unified_Ideograph", "Ideographic"},
    185929: {"Unified_Ideograph", "Ideographic"},
    185930: {"Unified_Ideograph", "Ideographic"},
    185931: {"Unified_Ideograph", "Ideographic"},
    185932: {"Unified_Ideograph", "Ideographic"},
    185933: {"Unified_Ideograph", "Ideographic"},
    185934: {"Unified_Ideograph", "Ideographic"},
    185935: {"Unified_Ideograph", "Ideographic"},
    185936: {"Unified_Ideograph", "Ideographic"},
    185937: {"Unified_Ideograph", "Ideographic"},
    185938: {"Unified_Ideograph", "Ideographic"},
    185939: {"Unified_Ideograph", "Ideographic"},
    185940: {"Unified_Ideograph", "Ideographic"},
    185941: {"Unified_Ideograph", "Ideographic"},
    185942: {"Unified_Ideograph", "Ideographic"},
    185943: {"Unified_Ideograph", "Ideographic"},
    185944: {"Unified_Ideograph", "Ideographic"},
    185945: {"Unified_Ideograph", "Ideographic"},
    185946: {"Unified_Ideograph", "Ideographic"},
    185947: {"Unified_Ideograph", "Ideographic"},
    185948: {"Unified_Ideograph", "Ideographic"},
    185949: {"Unified_Ideograph", "Ideographic"},
    185950: {"Unified_Ideograph", "Ideographic"},
    185951: {"Unified_Ideograph", "Ideographic"},
    185952: {"Unified_Ideograph", "Ideographic"},
    185953: {"Unified_Ideograph", "Ideographic"},
    185954: {"Unified_Ideograph", "Ideographic"},
    185955: {"Unified_Ideograph", "Ideographic"},
    185956: {"Unified_Ideograph", "Ideographic"},
    185957: {"Unified_Ideograph", "Ideographic"},
    185958: {"Unified_Ideograph", "Ideographic"},
    185959: {"Unified_Ideograph", "Ideographic"},
    185960: {"Unified_Ideograph", "Ideographic"},
    185961: {"Unified_Ideograph", "Ideographic"},
    185962: {"Unified_Ideograph", "Ideographic"},
    185963: {"Unified_Ideograph", "Ideographic"},
    185964: {"Unified_Ideograph", "Ideographic"},
    185965: {"Unified_Ideograph", "Ideographic"},
    185966: {"Unified_Ideograph", "Ideographic"},
    185967: {"Unified_Ideograph", "Ideographic"},
    185968: {"Unified_Ideograph", "Ideographic"},
    185969: {"Unified_Ideograph", "Ideographic"},
    185970: {"Unified_Ideograph", "Ideographic"},
    185971: {"Unified_Ideograph", "Ideographic"},
    185972: {"Unified_Ideograph", "Ideographic"},
    185973: {"Unified_Ideograph", "Ideographic"},
    185974: {"Unified_Ideograph", "Ideographic"},
    185975: {"Unified_Ideograph", "Ideographic"},
    185976: {"Unified_Ideograph", "Ideographic"},
    185977: {"Unified_Ideograph", "Ideographic"},
    185978: {"Unified_Ideograph", "Ideographic"},
    185979: {"Unified_Ideograph", "Ideographic"},
    185980: {"Unified_Ideograph", "Ideographic"},
    185981: {"Unified_Ideograph", "Ideographic"},
    185982: {"Unified_Ideograph", "Ideographic"},
    185983: {"Unified_Ideograph", "Ideographic"},
    185984: {"Unified_Ideograph", "Ideographic"},
    185985: {"Unified_Ideograph", "Ideographic"},
    185986: {"Unified_Ideograph", "Ideographic"},
    185987: {"Unified_Ideograph", "Ideographic"},
    185988: {"Unified_Ideograph", "Ideographic"},
    185989: {"Unified_Ideograph", "Ideographic"},
    185990: {"Unified_Ideograph", "Ideographic"},
    185991: {"Unified_Ideograph", "Ideographic"},
    185992: {"Unified_Ideograph", "Ideographic"},
    185993: {"Unified_Ideograph", "Ideographic"},
    185994: {"Unified_Ideograph", "Ideographic"},
    185995: {"Unified_Ideograph", "Ideographic"},
    185996: {"Unified_Ideograph", "Ideographic"},
    185997: {"Unified_Ideograph", "Ideographic"},
    185998: {"Unified_Ideograph", "Ideographic"},
    185999: {"Unified_Ideograph", "Ideographic"},
    186000: {"Unified_Ideograph", "Ideographic"},
    186001: {"Unified_Ideograph", "Ideographic"},
    186002: {"Unified_Ideograph", "Ideographic"},
    186003: {"Unified_Ideograph", "Ideographic"},
    186004: {"Unified_Ideograph", "Ideographic"},
    186005: {"Unified_Ideograph", "Ideographic"},
    186006: {"Unified_Ideograph", "Ideographic"},
    186007: {"Unified_Ideograph", "Ideographic"},
    186008: {"Unified_Ideograph", "Ideographic"},
    186009: {"Unified_Ideograph", "Ideographic"},
    186010: {"Unified_Ideograph", "Ideographic"},
    186011: {"Unified_Ideograph", "Ideographic"},
    186012: {"Unified_Ideograph", "Ideographic"},
    186013: {"Unified_Ideograph", "Ideographic"},
    186014: {"Unified_Ideograph", "Ideographic"},
    186015: {"Unified_Ideograph", "Ideographic"},
    186016: {"Unified_Ideograph", "Ideographic"},
    186017: {"Unified_Ideograph", "Ideographic"},
    186018: {"Unified_Ideograph", "Ideographic"},
    186019: {"Unified_Ideograph", "Ideographic"},
    186020: {"Unified_Ideograph", "Ideographic"},
    186021: {"Unified_Ideograph", "Ideographic"},
    186022: {"Unified_Ideograph", "Ideographic"},
    186023: {"Unified_Ideograph", "Ideographic"},
    186024: {"Unified_Ideograph", "Ideographic"},
    186025: {"Unified_Ideograph", "Ideographic"},
    186026: {"Unified_Ideograph", "Ideographic"},
    186027: {"Unified_Ideograph", "Ideographic"},
    186028: {"Unified_Ideograph", "Ideographic"},
    186029: {"Unified_Ideograph", "Ideographic"},
    186030: {"Unified_Ideograph", "Ideographic"},
    186031: {"Unified_Ideograph", "Ideographic"},
    186032: {"Unified_Ideograph", "Ideographic"},
    186033: {"Unified_Ideograph", "Ideographic"},
    186034: {"Unified_Ideograph", "Ideographic"},
    186035: {"Unified_Ideograph", "Ideographic"},
    186036: {"Unified_Ideograph", "Ideographic"},
    186037: {"Unified_Ideograph", "Ideographic"},
    186038: {"Unified_Ideograph", "Ideographic"},
    186039: {"Unified_Ideograph", "Ideographic"},
    186040: {"Unified_Ideograph", "Ideographic"},
    186041: {"Unified_Ideograph", "Ideographic"},
    186042: {"Unified_Ideograph", "Ideographic"},
    186043: {"Unified_Ideograph", "Ideographic"},
    186044: {"Unified_Ideograph", "Ideographic"},
    186045: {"Unified_Ideograph", "Ideographic"},
    186046: {"Unified_Ideograph", "Ideographic"},
    186047: {"Unified_Ideograph", "Ideographic"},
    186048: {"Unified_Ideograph", "Ideographic"},
    186049: {"Unified_Ideograph", "Ideographic"},
    186050: {"Unified_Ideograph", "Ideographic"},
    186051: {"Unified_Ideograph", "Ideographic"},
    186052: {"Unified_Ideograph", "Ideographic"},
    186053: {"Unified_Ideograph", "Ideographic"},
    186054: {"Unified_Ideograph", "Ideographic"},
    186055: {"Unified_Ideograph", "Ideographic"},
    186056: {"Unified_Ideograph", "Ideographic"},
    186057: {"Unified_Ideograph", "Ideographic"},
    186058: {"Unified_Ideograph", "Ideographic"},
    186059: {"Unified_Ideograph", "Ideographic"},
    186060: {"Unified_Ideograph", "Ideographic"},
    186061: {"Unified_Ideograph", "Ideographic"},
    186062: {"Unified_Ideograph", "Ideographic"},
    186063: {"Unified_Ideograph", "Ideographic"},
    186064: {"Unified_Ideograph", "Ideographic"},
    186065: {"Unified_Ideograph", "Ideographic"},
    186066: {"Unified_Ideograph", "Ideographic"},
    186067: {"Unified_Ideograph", "Ideographic"},
    186068: {"Unified_Ideograph", "Ideographic"},
    186069: {"Unified_Ideograph", "Ideographic"},
    186070: {"Unified_Ideograph", "Ideographic"},
    186071: {"Unified_Ideograph", "Ideographic"},
    186072: {"Unified_Ideograph", "Ideographic"},
    186073: {"Unified_Ideograph", "Ideographic"},
    186074: {"Unified_Ideograph", "Ideographic"},
    186075: {"Unified_Ideograph", "Ideographic"},
    186076: {"Unified_Ideograph", "Ideographic"},
    186077: {"Unified_Ideograph", "Ideographic"},
    186078: {"Unified_Ideograph", "Ideographic"},
    186079: {"Unified_Ideograph", "Ideographic"},
    186080: {"Unified_Ideograph", "Ideographic"},
    186081: {"Unified_Ideograph", "Ideographic"},
    186082: {"Unified_Ideograph", "Ideographic"},
    186083: {"Unified_Ideograph", "Ideographic"},
    186084: {"Unified_Ideograph", "Ideographic"},
    186085: {"Unified_Ideograph", "Ideographic"},
    186086: {"Unified_Ideograph", "Ideographic"},
    186087: {"Unified_Ideograph", "Ideographic"},
    186088: {"Unified_Ideograph", "Ideographic"},
    186089: {"Unified_Ideograph", "Ideographic"},
    186090: {"Unified_Ideograph", "Ideographic"},
    186091: {"Unified_Ideograph", "Ideographic"},
    186092: {"Unified_Ideograph", "Ideographic"},
    186093: {"Unified_Ideograph", "Ideographic"},
    186094: {"Unified_Ideograph", "Ideographic"},
    186095: {"Unified_Ideograph", "Ideographic"},
    186096: {"Unified_Ideograph", "Ideographic"},
    186097: {"Unified_Ideograph", "Ideographic"},
    186098: {"Unified_Ideograph", "Ideographic"},
    186099: {"Unified_Ideograph", "Ideographic"},
    186100: {"Unified_Ideograph", "Ideographic"},
    186101: {"Unified_Ideograph", "Ideographic"},
    186102: {"Unified_Ideograph", "Ideographic"},
    186103: {"Unified_Ideograph", "Ideographic"},
    186104: {"Unified_Ideograph", "Ideographic"},
    186105: {"Unified_Ideograph", "Ideographic"},
    186106: {"Unified_Ideograph", "Ideographic"},
    186107: {"Unified_Ideograph", "Ideographic"},
    186108: {"Unified_Ideograph", "Ideographic"},
    186109: {"Unified_Ideograph", "Ideographic"},
    186110: {"Unified_Ideograph", "Ideographic"},
    186111: {"Unified_Ideograph", "Ideographic"},
    186112: {"Unified_Ideograph", "Ideographic"},
    186113: {"Unified_Ideograph", "Ideographic"},
    186114: {"Unified_Ideograph", "Ideographic"},
    186115: {"Unified_Ideograph", "Ideographic"},
    186116: {"Unified_Ideograph", "Ideographic"},
    186117: {"Unified_Ideograph", "Ideographic"},
    186118: {"Unified_Ideograph", "Ideographic"},
    186119: {"Unified_Ideograph", "Ideographic"},
    186120: {"Unified_Ideograph", "Ideographic"},
    186121: {"Unified_Ideograph", "Ideographic"},
    186122: {"Unified_Ideograph", "Ideographic"},
    186123: {"Unified_Ideograph", "Ideographic"},
    186124: {"Unified_Ideograph", "Ideographic"},
    186125: {"Unified_Ideograph", "Ideographic"},
    186126: {"Unified_Ideograph", "Ideographic"},
    186127: {"Unified_Ideograph", "Ideographic"},
    186128: {"Unified_Ideograph", "Ideographic"},
    186129: {"Unified_Ideograph", "Ideographic"},
    186130: {"Unified_Ideograph", "Ideographic"},
    186131: {"Unified_Ideograph", "Ideographic"},
    186132: {"Unified_Ideograph", "Ideographic"},
    186133: {"Unified_Ideograph", "Ideographic"},
    186134: {"Unified_Ideograph", "Ideographic"},
    186135: {"Unified_Ideograph", "Ideographic"},
    186136: {"Unified_Ideograph", "Ideographic"},
    186137: {"Unified_Ideograph", "Ideographic"},
    186138: {"Unified_Ideograph", "Ideographic"},
    186139: {"Unified_Ideograph", "Ideographic"},
    186140: {"Unified_Ideograph", "Ideographic"},
    186141: {"Unified_Ideograph", "Ideographic"},
    186142: {"Unified_Ideograph", "Ideographic"},
    186143: {"Unified_Ideograph", "Ideographic"},
    186144: {"Unified_Ideograph", "Ideographic"},
    186145: {"Unified_Ideograph", "Ideographic"},
    186146: {"Unified_Ideograph", "Ideographic"},
    186147: {"Unified_Ideograph", "Ideographic"},
    186148: {"Unified_Ideograph", "Ideographic"},
    186149: {"Unified_Ideograph", "Ideographic"},
    186150: {"Unified_Ideograph", "Ideographic"},
    186151: {"Unified_Ideograph", "Ideographic"},
    186152: {"Unified_Ideograph", "Ideographic"},
    186153: {"Unified_Ideograph", "Ideographic"},
    186154: {"Unified_Ideograph", "Ideographic"},
    186155: {"Unified_Ideograph", "Ideographic"},
    186156: {"Unified_Ideograph", "Ideographic"},
    186157: {"Unified_Ideograph", "Ideographic"},
    186158: {"Unified_Ideograph", "Ideographic"},
    186159: {"Unified_Ideograph", "Ideographic"},
    186160: {"Unified_Ideograph", "Ideographic"},
    186161: {"Unified_Ideograph", "Ideographic"},
    186162: {"Unified_Ideograph", "Ideographic"},
    186163: {"Unified_Ideograph", "Ideographic"},
    186164: {"Unified_Ideograph", "Ideographic"},
    186165: {"Unified_Ideograph", "Ideographic"},
    186166: {"Unified_Ideograph", "Ideographic"},
    186167: {"Unified_Ideograph", "Ideographic"},
    186168: {"Unified_Ideograph", "Ideographic"},
    186169: {"Unified_Ideograph", "Ideographic"},
    186170: {"Unified_Ideograph", "Ideographic"},
    186171: {"Unified_Ideograph", "Ideographic"},
    186172: {"Unified_Ideograph", "Ideographic"},
    186173: {"Unified_Ideograph", "Ideographic"},
    186174: {"Unified_Ideograph", "Ideographic"},
    186175: {"Unified_Ideograph", "Ideographic"},
    186176: {"Unified_Ideograph", "Ideographic"},
    186177: {"Unified_Ideograph", "Ideographic"},
    186178: {"Unified_Ideograph", "Ideographic"},
    186179: {"Unified_Ideograph", "Ideographic"},
    186180: {"Unified_Ideograph", "Ideographic"},
    186181: {"Unified_Ideograph", "Ideographic"},
    186182: {"Unified_Ideograph", "Ideographic"},
    186183: {"Unified_Ideograph", "Ideographic"},
    186184: {"Unified_Ideograph", "Ideographic"},
    186185: {"Unified_Ideograph", "Ideographic"},
    186186: {"Unified_Ideograph", "Ideographic"},
    186187: {"Unified_Ideograph", "Ideographic"},
    186188: {"Unified_Ideograph", "Ideographic"},
    186189: {"Unified_Ideograph", "Ideographic"},
    186190: {"Unified_Ideograph", "Ideographic"},
    186191: {"Unified_Ideograph", "Ideographic"},
    186192: {"Unified_Ideograph", "Ideographic"},
    186193: {"Unified_Ideograph", "Ideographic"},
    186194: {"Unified_Ideograph", "Ideographic"},
    186195: {"Unified_Ideograph", "Ideographic"},
    186196: {"Unified_Ideograph", "Ideographic"},
    186197: {"Unified_Ideograph", "Ideographic"},
    186198: {"Unified_Ideograph", "Ideographic"},
    186199: {"Unified_Ideograph", "Ideographic"},
    186200: {"Unified_Ideograph", "Ideographic"},
    186201: {"Unified_Ideograph", "Ideographic"},
    186202: {"Unified_Ideograph", "Ideographic"},
    186203: {"Unified_Ideograph", "Ideographic"},
    186204: {"Unified_Ideograph", "Ideographic"},
    186205: {"Unified_Ideograph", "Ideographic"},
    186206: {"Unified_Ideograph", "Ideographic"},
    186207: {"Unified_Ideograph", "Ideographic"},
    186208: {"Unified_Ideograph", "Ideographic"},
    186209: {"Unified_Ideograph", "Ideographic"},
    186210: {"Unified_Ideograph", "Ideographic"},
    186211: {"Unified_Ideograph", "Ideographic"},
    186212: {"Unified_Ideograph", "Ideographic"},
    186213: {"Unified_Ideograph", "Ideographic"},
    186214: {"Unified_Ideograph", "Ideographic"},
    186215: {"Unified_Ideograph", "Ideographic"},
    186216: {"Unified_Ideograph", "Ideographic"},
    186217: {"Unified_Ideograph", "Ideographic"},
    186218: {"Unified_Ideograph", "Ideographic"},
    186219: {"Unified_Ideograph", "Ideographic"},
    186220: {"Unified_Ideograph", "Ideographic"},
    186221: {"Unified_Ideograph", "Ideographic"},
    186222: {"Unified_Ideograph", "Ideographic"},
    186223: {"Unified_Ideograph", "Ideographic"},
    186224: {"Unified_Ideograph", "Ideographic"},
    186225: {"Unified_Ideograph", "Ideographic"},
    186226: {"Unified_Ideograph", "Ideographic"},
    186227: {"Unified_Ideograph", "Ideographic"},
    186228: {"Unified_Ideograph", "Ideographic"},
    186229: {"Unified_Ideograph", "Ideographic"},
    186230: {"Unified_Ideograph", "Ideographic"},
    186231: {"Unified_Ideograph", "Ideographic"},
    186232: {"Unified_Ideograph", "Ideographic"},
    186233: {"Unified_Ideograph", "Ideographic"},
    186234: {"Unified_Ideograph", "Ideographic"},
    186235: {"Unified_Ideograph", "Ideographic"},
    186236: {"Unified_Ideograph", "Ideographic"},
    186237: {"Unified_Ideograph", "Ideographic"},
    186238: {"Unified_Ideograph", "Ideographic"},
    186239: {"Unified_Ideograph", "Ideographic"},
    186240: {"Unified_Ideograph", "Ideographic"},
    186241: {"Unified_Ideograph", "Ideographic"},
    186242: {"Unified_Ideograph", "Ideographic"},
    186243: {"Unified_Ideograph", "Ideographic"},
    186244: {"Unified_Ideograph", "Ideographic"},
    186245: {"Unified_Ideograph", "Ideographic"},
    186246: {"Unified_Ideograph", "Ideographic"},
    186247: {"Unified_Ideograph", "Ideographic"},
    186248: {"Unified_Ideograph", "Ideographic"},
    186249: {"Unified_Ideograph", "Ideographic"},
    186250: {"Unified_Ideograph", "Ideographic"},
    186251: {"Unified_Ideograph", "Ideographic"},
    186252: {"Unified_Ideograph", "Ideographic"},
    186253: {"Unified_Ideograph", "Ideographic"},
    186254: {"Unified_Ideograph", "Ideographic"},
    186255: {"Unified_Ideograph", "Ideographic"},
    186256: {"Unified_Ideograph", "Ideographic"},
    186257: {"Unified_Ideograph", "Ideographic"},
    186258: {"Unified_Ideograph", "Ideographic"},
    186259: {"Unified_Ideograph", "Ideographic"},
    186260: {"Unified_Ideograph", "Ideographic"},
    186261: {"Unified_Ideograph", "Ideographic"},
    186262: {"Unified_Ideograph", "Ideographic"},
    186263: {"Unified_Ideograph", "Ideographic"},
    186264: {"Unified_Ideograph", "Ideographic"},
    186265: {"Unified_Ideograph", "Ideographic"},
    186266: {"Unified_Ideograph", "Ideographic"},
    186267: {"Unified_Ideograph", "Ideographic"},
    186268: {"Unified_Ideograph", "Ideographic"},
    186269: {"Unified_Ideograph", "Ideographic"},
    186270: {"Unified_Ideograph", "Ideographic"},
    186271: {"Unified_Ideograph", "Ideographic"},
    186272: {"Unified_Ideograph", "Ideographic"},
    186273: {"Unified_Ideograph", "Ideographic"},
    186274: {"Unified_Ideograph", "Ideographic"},
    186275: {"Unified_Ideograph", "Ideographic"},
    186276: {"Unified_Ideograph", "Ideographic"},
    186277: {"Unified_Ideograph", "Ideographic"},
    186278: {"Unified_Ideograph", "Ideographic"},
    186279: {"Unified_Ideograph", "Ideographic"},
    186280: {"Unified_Ideograph", "Ideographic"},
    186281: {"Unified_Ideograph", "Ideographic"},
    186282: {"Unified_Ideograph", "Ideographic"},
    186283: {"Unified_Ideograph", "Ideographic"},
    186284: {"Unified_Ideograph", "Ideographic"},
    186285: {"Unified_Ideograph", "Ideographic"},
    186286: {"Unified_Ideograph", "Ideographic"},
    186287: {"Unified_Ideograph", "Ideographic"},
    186288: {"Unified_Ideograph", "Ideographic"},
    186289: {"Unified_Ideograph", "Ideographic"},
    186290: {"Unified_Ideograph", "Ideographic"},
    186291: {"Unified_Ideograph", "Ideographic"},
    186292: {"Unified_Ideograph", "Ideographic"},
    186293: {"Unified_Ideograph", "Ideographic"},
    186294: {"Unified_Ideograph", "Ideographic"},
    186295: {"Unified_Ideograph", "Ideographic"},
    186296: {"Unified_Ideograph", "Ideographic"},
    186297: {"Unified_Ideograph", "Ideographic"},
    186298: {"Unified_Ideograph", "Ideographic"},
    186299: {"Unified_Ideograph", "Ideographic"},
    186300: {"Unified_Ideograph", "Ideographic"},
    186301: {"Unified_Ideograph", "Ideographic"},
    186302: {"Unified_Ideograph", "Ideographic"},
    186303: {"Unified_Ideograph", "Ideographic"},
    186304: {"Unified_Ideograph", "Ideographic"},
    186305: {"Unified_Ideograph", "Ideographic"},
    186306: {"Unified_Ideograph", "Ideographic"},
    186307: {"Unified_Ideograph", "Ideographic"},
    186308: {"Unified_Ideograph", "Ideographic"},
    186309: {"Unified_Ideograph", "Ideographic"},
    186310: {"Unified_Ideograph", "Ideographic"},
    186311: {"Unified_Ideograph", "Ideographic"},
    186312: {"Unified_Ideograph", "Ideographic"},
    186313: {"Unified_Ideograph", "Ideographic"},
    186314: {"Unified_Ideograph", "Ideographic"},
    186315: {"Unified_Ideograph", "Ideographic"},
    186316: {"Unified_Ideograph", "Ideographic"},
    186317: {"Unified_Ideograph", "Ideographic"},
    186318: {"Unified_Ideograph", "Ideographic"},
    186319: {"Unified_Ideograph", "Ideographic"},
    186320: {"Unified_Ideograph", "Ideographic"},
    186321: {"Unified_Ideograph", "Ideographic"},
    186322: {"Unified_Ideograph", "Ideographic"},
    186323: {"Unified_Ideograph", "Ideographic"},
    186324: {"Unified_Ideograph", "Ideographic"},
    186325: {"Unified_Ideograph", "Ideographic"},
    186326: {"Unified_Ideograph", "Ideographic"},
    186327: {"Unified_Ideograph", "Ideographic"},
    186328: {"Unified_Ideograph", "Ideographic"},
    186329: {"Unified_Ideograph", "Ideographic"},
    186330: {"Unified_Ideograph", "Ideographic"},
    186331: {"Unified_Ideograph", "Ideographic"},
    186332: {"Unified_Ideograph", "Ideographic"},
    186333: {"Unified_Ideograph", "Ideographic"},
    186334: {"Unified_Ideograph", "Ideographic"},
    186335: {"Unified_Ideograph", "Ideographic"},
    186336: {"Unified_Ideograph", "Ideographic"},
    186337: {"Unified_Ideograph", "Ideographic"},
    186338: {"Unified_Ideograph", "Ideographic"},
    186339: {"Unified_Ideograph", "Ideographic"},
    186340: {"Unified_Ideograph", "Ideographic"},
    186341: {"Unified_Ideograph", "Ideographic"},
    186342: {"Unified_Ideograph", "Ideographic"},
    186343: {"Unified_Ideograph", "Ideographic"},
    186344: {"Unified_Ideograph", "Ideographic"},
    186345: {"Unified_Ideograph", "Ideographic"},
    186346: {"Unified_Ideograph", "Ideographic"},
    186347: {"Unified_Ideograph", "Ideographic"},
    186348: {"Unified_Ideograph", "Ideographic"},
    186349: {"Unified_Ideograph", "Ideographic"},
    186350: {"Unified_Ideograph", "Ideographic"},
    186351: {"Unified_Ideograph", "Ideographic"},
    186352: {"Unified_Ideograph", "Ideographic"},
    186353: {"Unified_Ideograph", "Ideographic"},
    186354: {"Unified_Ideograph", "Ideographic"},
    186355: {"Unified_Ideograph", "Ideographic"},
    186356: {"Unified_Ideograph", "Ideographic"},
    186357: {"Unified_Ideograph", "Ideographic"},
    186358: {"Unified_Ideograph", "Ideographic"},
    186359: {"Unified_Ideograph", "Ideographic"},
    186360: {"Unified_Ideograph", "Ideographic"},
    186361: {"Unified_Ideograph", "Ideographic"},
    186362: {"Unified_Ideograph", "Ideographic"},
    186363: {"Unified_Ideograph", "Ideographic"},
    186364: {"Unified_Ideograph", "Ideographic"},
    186365: {"Unified_Ideograph", "Ideographic"},
    186366: {"Unified_Ideograph", "Ideographic"},
    186367: {"Unified_Ideograph", "Ideographic"},
    186368: {"Unified_Ideograph", "Ideographic"},
    186369: {"Unified_Ideograph", "Ideographic"},
    186370: {"Unified_Ideograph", "Ideographic"},
    186371: {"Unified_Ideograph", "Ideographic"},
    186372: {"Unified_Ideograph", "Ideographic"},
    186373: {"Unified_Ideograph", "Ideographic"},
    186374: {"Unified_Ideograph", "Ideographic"},
    186375: {"Unified_Ideograph", "Ideographic"},
    186376: {"Unified_Ideograph", "Ideographic"},
    186377: {"Unified_Ideograph", "Ideographic"},
    186378: {"Unified_Ideograph", "Ideographic"},
    186379: {"Unified_Ideograph", "Ideographic"},
    186380: {"Unified_Ideograph", "Ideographic"},
    186381: {"Unified_Ideograph", "Ideographic"},
    186382: {"Unified_Ideograph", "Ideographic"},
    186383: {"Unified_Ideograph", "Ideographic"},
    186384: {"Unified_Ideograph", "Ideographic"},
    186385: {"Unified_Ideograph", "Ideographic"},
    186386: {"Unified_Ideograph", "Ideographic"},
    186387: {"Unified_Ideograph", "Ideographic"},
    186388: {"Unified_Ideograph", "Ideographic"},
    186389: {"Unified_Ideograph", "Ideographic"},
    186390: {"Unified_Ideograph", "Ideographic"},
    186391: {"Unified_Ideograph", "Ideographic"},
    186392: {"Unified_Ideograph", "Ideographic"},
    186393: {"Unified_Ideograph", "Ideographic"},
    186394: {"Unified_Ideograph", "Ideographic"},
    186395: {"Unified_Ideograph", "Ideographic"},
    186396: {"Unified_Ideograph", "Ideographic"},
    186397: {"Unified_Ideograph", "Ideographic"},
    186398: {"Unified_Ideograph", "Ideographic"},
    186399: {"Unified_Ideograph", "Ideographic"},
    186400: {"Unified_Ideograph", "Ideographic"},
    186401: {"Unified_Ideograph", "Ideographic"},
    186402: {"Unified_Ideograph", "Ideographic"},
    186403: {"Unified_Ideograph", "Ideographic"},
    186404: {"Unified_Ideograph", "Ideographic"},
    186405: {"Unified_Ideograph", "Ideographic"},
    186406: {"Unified_Ideograph", "Ideographic"},
    186407: {"Unified_Ideograph", "Ideographic"},
    186408: {"Unified_Ideograph", "Ideographic"},
    186409: {"Unified_Ideograph", "Ideographic"},
    186410: {"Unified_Ideograph", "Ideographic"},
    186411: {"Unified_Ideograph", "Ideographic"},
    186412: {"Unified_Ideograph", "Ideographic"},
    186413: {"Unified_Ideograph", "Ideographic"},
    186414: {"Unified_Ideograph", "Ideographic"},
    186415: {"Unified_Ideograph", "Ideographic"},
    186416: {"Unified_Ideograph", "Ideographic"},
    186417: {"Unified_Ideograph", "Ideographic"},
    186418: {"Unified_Ideograph", "Ideographic"},
    186419: {"Unified_Ideograph", "Ideographic"},
    186420: {"Unified_Ideograph", "Ideographic"},
    186421: {"Unified_Ideograph", "Ideographic"},
    186422: {"Unified_Ideograph", "Ideographic"},
    186423: {"Unified_Ideograph", "Ideographic"},
    186424: {"Unified_Ideograph", "Ideographic"},
    186425: {"Unified_Ideograph", "Ideographic"},
    186426: {"Unified_Ideograph", "Ideographic"},
    186427: {"Unified_Ideograph", "Ideographic"},
    186428: {"Unified_Ideograph", "Ideographic"},
    186429: {"Unified_Ideograph", "Ideographic"},
    186430: {"Unified_Ideograph", "Ideographic"},
    186431: {"Unified_Ideograph", "Ideographic"},
    186432: {"Unified_Ideograph", "Ideographic"},
    186433: {"Unified_Ideograph", "Ideographic"},
    186434: {"Unified_Ideograph", "Ideographic"},
    186435: {"Unified_Ideograph", "Ideographic"},
    186436: {"Unified_Ideograph", "Ideographic"},
    186437: {"Unified_Ideograph", "Ideographic"},
    186438: {"Unified_Ideograph", "Ideographic"},
    186439: {"Unified_Ideograph", "Ideographic"},
    186440: {"Unified_Ideograph", "Ideographic"},
    186441: {"Unified_Ideograph", "Ideographic"},
    186442: {"Unified_Ideograph", "Ideographic"},
    186443: {"Unified_Ideograph", "Ideographic"},
    186444: {"Unified_Ideograph", "Ideographic"},
    186445: {"Unified_Ideograph", "Ideographic"},
    186446: {"Unified_Ideograph", "Ideographic"},
    186447: {"Unified_Ideograph", "Ideographic"},
    186448: {"Unified_Ideograph", "Ideographic"},
    186449: {"Unified_Ideograph", "Ideographic"},
    186450: {"Unified_Ideograph", "Ideographic"},
    186451: {"Unified_Ideograph", "Ideographic"},
    186452: {"Unified_Ideograph", "Ideographic"},
    186453: {"Unified_Ideograph", "Ideographic"},
    186454: {"Unified_Ideograph", "Ideographic"},
    186455: {"Unified_Ideograph", "Ideographic"},
    186456: {"Unified_Ideograph", "Ideographic"},
    186457: {"Unified_Ideograph", "Ideographic"},
    186458: {"Unified_Ideograph", "Ideographic"},
    186459: {"Unified_Ideograph", "Ideographic"},
    186460: {"Unified_Ideograph", "Ideographic"},
    186461: {"Unified_Ideograph", "Ideographic"},
    186462: {"Unified_Ideograph", "Ideographic"},
    186463: {"Unified_Ideograph", "Ideographic"},
    186464: {"Unified_Ideograph", "Ideographic"},
    186465: {"Unified_Ideograph", "Ideographic"},
    186466: {"Unified_Ideograph", "Ideographic"},
    186467: {"Unified_Ideograph", "Ideographic"},
    186468: {"Unified_Ideograph", "Ideographic"},
    186469: {"Unified_Ideograph", "Ideographic"},
    186470: {"Unified_Ideograph", "Ideographic"},
    186471: {"Unified_Ideograph", "Ideographic"},
    186472: {"Unified_Ideograph", "Ideographic"},
    186473: {"Unified_Ideograph", "Ideographic"},
    186474: {"Unified_Ideograph", "Ideographic"},
    186475: {"Unified_Ideograph", "Ideographic"},
    186476: {"Unified_Ideograph", "Ideographic"},
    186477: {"Unified_Ideograph", "Ideographic"},
    186478: {"Unified_Ideograph", "Ideographic"},
    186479: {"Unified_Ideograph", "Ideographic"},
    186480: {"Unified_Ideograph", "Ideographic"},
    186481: {"Unified_Ideograph", "Ideographic"},
    186482: {"Unified_Ideograph", "Ideographic"},
    186483: {"Unified_Ideograph", "Ideographic"},
    186484: {"Unified_Ideograph", "Ideographic"},
    186485: {"Unified_Ideograph", "Ideographic"},
    186486: {"Unified_Ideograph", "Ideographic"},
    186487: {"Unified_Ideograph", "Ideographic"},
    186488: {"Unified_Ideograph", "Ideographic"},
    186489: {"Unified_Ideograph", "Ideographic"},
    186490: {"Unified_Ideograph", "Ideographic"},
    186491: {"Unified_Ideograph", "Ideographic"},
    186492: {"Unified_Ideograph", "Ideographic"},
    186493: {"Unified_Ideograph", "Ideographic"},
    186494: {"Unified_Ideograph", "Ideographic"},
    186495: {"Unified_Ideograph", "Ideographic"},
    186496: {"Unified_Ideograph", "Ideographic"},
    186497: {"Unified_Ideograph", "Ideographic"},
    186498: {"Unified_Ideograph", "Ideographic"},
    186499: {"Unified_Ideograph", "Ideographic"},
    186500: {"Unified_Ideograph", "Ideographic"},
    186501: {"Unified_Ideograph", "Ideographic"},
    186502: {"Unified_Ideograph", "Ideographic"},
    186503: {"Unified_Ideograph", "Ideographic"},
    186504: {"Unified_Ideograph", "Ideographic"},
    186505: {"Unified_Ideograph", "Ideographic"},
    186506: {"Unified_Ideograph", "Ideographic"},
    186507: {"Unified_Ideograph", "Ideographic"},
    186508: {"Unified_Ideograph", "Ideographic"},
    186509: {"Unified_Ideograph", "Ideographic"},
    186510: {"Unified_Ideograph", "Ideographic"},
    186511: {"Unified_Ideograph", "Ideographic"},
    186512: {"Unified_Ideograph", "Ideographic"},
    186513: {"Unified_Ideograph", "Ideographic"},
    186514: {"Unified_Ideograph", "Ideographic"},
    186515: {"Unified_Ideograph", "Ideographic"},
    186516: {"Unified_Ideograph", "Ideographic"},
    186517: {"Unified_Ideograph", "Ideographic"},
    186518: {"Unified_Ideograph", "Ideographic"},
    186519: {"Unified_Ideograph", "Ideographic"},
    186520: {"Unified_Ideograph", "Ideographic"},
    186521: {"Unified_Ideograph", "Ideographic"},
    186522: {"Unified_Ideograph", "Ideographic"},
    186523: {"Unified_Ideograph", "Ideographic"},
    186524: {"Unified_Ideograph", "Ideographic"},
    186525: {"Unified_Ideograph", "Ideographic"},
    186526: {"Unified_Ideograph", "Ideographic"},
    186527: {"Unified_Ideograph", "Ideographic"},
    186528: {"Unified_Ideograph", "Ideographic"},
    186529: {"Unified_Ideograph", "Ideographic"},
    186530: {"Unified_Ideograph", "Ideographic"},
    186531: {"Unified_Ideograph", "Ideographic"},
    186532: {"Unified_Ideograph", "Ideographic"},
    186533: {"Unified_Ideograph", "Ideographic"},
    186534: {"Unified_Ideograph", "Ideographic"},
    186535: {"Unified_Ideograph", "Ideographic"},
    186536: {"Unified_Ideograph", "Ideographic"},
    186537: {"Unified_Ideograph", "Ideographic"},
    186538: {"Unified_Ideograph", "Ideographic"},
    186539: {"Unified_Ideograph", "Ideographic"},
    186540: {"Unified_Ideograph", "Ideographic"},
    186541: {"Unified_Ideograph", "Ideographic"},
    186542: {"Unified_Ideograph", "Ideographic"},
    186543: {"Unified_Ideograph", "Ideographic"},
    186544: {"Unified_Ideograph", "Ideographic"},
    186545: {"Unified_Ideograph", "Ideographic"},
    186546: {"Unified_Ideograph", "Ideographic"},
    186547: {"Unified_Ideograph", "Ideographic"},
    186548: {"Unified_Ideograph", "Ideographic"},
    186549: {"Unified_Ideograph", "Ideographic"},
    186550: {"Unified_Ideograph", "Ideographic"},
    186551: {"Unified_Ideograph", "Ideographic"},
    186552: {"Unified_Ideograph", "Ideographic"},
    186553: {"Unified_Ideograph", "Ideographic"},
    186554: {"Unified_Ideograph", "Ideographic"},
    186555: {"Unified_Ideograph", "Ideographic"},
    186556: {"Unified_Ideograph", "Ideographic"},
    186557: {"Unified_Ideograph", "Ideographic"},
    186558: {"Unified_Ideograph", "Ideographic"},
    186559: {"Unified_Ideograph", "Ideographic"},
    186560: {"Unified_Ideograph", "Ideographic"},
    186561: {"Unified_Ideograph", "Ideographic"},
    186562: {"Unified_Ideograph", "Ideographic"},
    186563: {"Unified_Ideograph", "Ideographic"},
    186564: {"Unified_Ideograph", "Ideographic"},
    186565: {"Unified_Ideograph", "Ideographic"},
    186566: {"Unified_Ideograph", "Ideographic"},
    186567: {"Unified_Ideograph", "Ideographic"},
    186568: {"Unified_Ideograph", "Ideographic"},
    186569: {"Unified_Ideograph", "Ideographic"},
    186570: {"Unified_Ideograph", "Ideographic"},
    186571: {"Unified_Ideograph", "Ideographic"},
    186572: {"Unified_Ideograph", "Ideographic"},
    186573: {"Unified_Ideograph", "Ideographic"},
    186574: {"Unified_Ideograph", "Ideographic"},
    186575: {"Unified_Ideograph", "Ideographic"},
    186576: {"Unified_Ideograph", "Ideographic"},
    186577: {"Unified_Ideograph", "Ideographic"},
    186578: {"Unified_Ideograph", "Ideographic"},
    186579: {"Unified_Ideograph", "Ideographic"},
    186580: {"Unified_Ideograph", "Ideographic"},
    186581: {"Unified_Ideograph", "Ideographic"},
    186582: {"Unified_Ideograph", "Ideographic"},
    186583: {"Unified_Ideograph", "Ideographic"},
    186584: {"Unified_Ideograph", "Ideographic"},
    186585: {"Unified_Ideograph", "Ideographic"},
    186586: {"Unified_Ideograph", "Ideographic"},
    186587: {"Unified_Ideograph", "Ideographic"},
    186588: {"Unified_Ideograph", "Ideographic"},
    186589: {"Unified_Ideograph", "Ideographic"},
    186590: {"Unified_Ideograph", "Ideographic"},
    186591: {"Unified_Ideograph", "Ideographic"},
    186592: {"Unified_Ideograph", "Ideographic"},
    186593: {"Unified_Ideograph", "Ideographic"},
    186594: {"Unified_Ideograph", "Ideographic"},
    186595: {"Unified_Ideograph", "Ideographic"},
    186596: {"Unified_Ideograph", "Ideographic"},
    186597: {"Unified_Ideograph", "Ideographic"},
    186598: {"Unified_Ideograph", "Ideographic"},
    186599: {"Unified_Ideograph", "Ideographic"},
    186600: {"Unified_Ideograph", "Ideographic"},
    186601: {"Unified_Ideograph", "Ideographic"},
    186602: {"Unified_Ideograph", "Ideographic"},
    186603: {"Unified_Ideograph", "Ideographic"},
    186604: {"Unified_Ideograph", "Ideographic"},
    186605: {"Unified_Ideograph", "Ideographic"},
    186606: {"Unified_Ideograph", "Ideographic"},
    186607: {"Unified_Ideograph", "Ideographic"},
    186608: {"Unified_Ideograph", "Ideographic"},
    186609: {"Unified_Ideograph", "Ideographic"},
    186610: {"Unified_Ideograph", "Ideographic"},
    186611: {"Unified_Ideograph", "Ideographic"},
    186612: {"Unified_Ideograph", "Ideographic"},
    186613: {"Unified_Ideograph", "Ideographic"},
    186614: {"Unified_Ideograph", "Ideographic"},
    186615: {"Unified_Ideograph", "Ideographic"},
    186616: {"Unified_Ideograph", "Ideographic"},
    186617: {"Unified_Ideograph", "Ideographic"},
    186618: {"Unified_Ideograph", "Ideographic"},
    186619: {"Unified_Ideograph", "Ideographic"},
    186620: {"Unified_Ideograph", "Ideographic"},
    186621: {"Unified_Ideograph", "Ideographic"},
    186622: {"Unified_Ideograph", "Ideographic"},
    186623: {"Unified_Ideograph", "Ideographic"},
    186624: {"Unified_Ideograph", "Ideographic"},
    186625: {"Unified_Ideograph", "Ideographic"},
    186626: {"Unified_Ideograph", "Ideographic"},
    186627: {"Unified_Ideograph", "Ideographic"},
    186628: {"Unified_Ideograph", "Ideographic"},
    186629: {"Unified_Ideograph", "Ideographic"},
    186630: {"Unified_Ideograph", "Ideographic"},
    186631: {"Unified_Ideograph", "Ideographic"},
    186632: {"Unified_Ideograph", "Ideographic"},
    186633: {"Unified_Ideograph", "Ideographic"},
    186634: {"Unified_Ideograph", "Ideographic"},
    186635: {"Unified_Ideograph", "Ideographic"},
    186636: {"Unified_Ideograph", "Ideographic"},
    186637: {"Unified_Ideograph", "Ideographic"},
    186638: {"Unified_Ideograph", "Ideographic"},
    186639: {"Unified_Ideograph", "Ideographic"},
    186640: {"Unified_Ideograph", "Ideographic"},
    186641: {"Unified_Ideograph", "Ideographic"},
    186642: {"Unified_Ideograph", "Ideographic"},
    186643: {"Unified_Ideograph", "Ideographic"},
    186644: {"Unified_Ideograph", "Ideographic"},
    186645: {"Unified_Ideograph", "Ideographic"},
    186646: {"Unified_Ideograph", "Ideographic"},
    186647: {"Unified_Ideograph", "Ideographic"},
    186648: {"Unified_Ideograph", "Ideographic"},
    186649: {"Unified_Ideograph", "Ideographic"},
    186650: {"Unified_Ideograph", "Ideographic"},
    186651: {"Unified_Ideograph", "Ideographic"},
    186652: {"Unified_Ideograph", "Ideographic"},
    186653: {"Unified_Ideograph", "Ideographic"},
    186654: {"Unified_Ideograph", "Ideographic"},
    186655: {"Unified_Ideograph", "Ideographic"},
    186656: {"Unified_Ideograph", "Ideographic"},
    186657: {"Unified_Ideograph", "Ideographic"},
    186658: {"Unified_Ideograph", "Ideographic"},
    186659: {"Unified_Ideograph", "Ideographic"},
    186660: {"Unified_Ideograph", "Ideographic"},
    186661: {"Unified_Ideograph", "Ideographic"},
    186662: {"Unified_Ideograph", "Ideographic"},
    186663: {"Unified_Ideograph", "Ideographic"},
    186664: {"Unified_Ideograph", "Ideographic"},
    186665: {"Unified_Ideograph", "Ideographic"},
    186666: {"Unified_Ideograph", "Ideographic"},
    186667: {"Unified_Ideograph", "Ideographic"},
    186668: {"Unified_Ideograph", "Ideographic"},
    186669: {"Unified_Ideograph", "Ideographic"},
    186670: {"Unified_Ideograph", "Ideographic"},
    186671: {"Unified_Ideograph", "Ideographic"},
    186672: {"Unified_Ideograph", "Ideographic"},
    186673: {"Unified_Ideograph", "Ideographic"},
    186674: {"Unified_Ideograph", "Ideographic"},
    186675: {"Unified_Ideograph", "Ideographic"},
    186676: {"Unified_Ideograph", "Ideographic"},
    186677: {"Unified_Ideograph", "Ideographic"},
    186678: {"Unified_Ideograph", "Ideographic"},
    186679: {"Unified_Ideograph", "Ideographic"},
    186680: {"Unified_Ideograph", "Ideographic"},
    186681: {"Unified_Ideograph", "Ideographic"},
    186682: {"Unified_Ideograph", "Ideographic"},
    186683: {"Unified_Ideograph", "Ideographic"},
    186684: {"Unified_Ideograph", "Ideographic"},
    186685: {"Unified_Ideograph", "Ideographic"},
    186686: {"Unified_Ideograph", "Ideographic"},
    186687: {"Unified_Ideograph", "Ideographic"},
    186688: {"Unified_Ideograph", "Ideographic"},
    186689: {"Unified_Ideograph", "Ideographic"},
    186690: {"Unified_Ideograph", "Ideographic"},
    186691: {"Unified_Ideograph", "Ideographic"},
    186692: {"Unified_Ideograph", "Ideographic"},
    186693: {"Unified_Ideograph", "Ideographic"},
    186694: {"Unified_Ideograph", "Ideographic"},
    186695: {"Unified_Ideograph", "Ideographic"},
    186696: {"Unified_Ideograph", "Ideographic"},
    186697: {"Unified_Ideograph", "Ideographic"},
    186698: {"Unified_Ideograph", "Ideographic"},
    186699: {"Unified_Ideograph", "Ideographic"},
    186700: {"Unified_Ideograph", "Ideographic"},
    186701: {"Unified_Ideograph", "Ideographic"},
    186702: {"Unified_Ideograph", "Ideographic"},
    186703: {"Unified_Ideograph", "Ideographic"},
    186704: {"Unified_Ideograph", "Ideographic"},
    186705: {"Unified_Ideograph", "Ideographic"},
    186706: {"Unified_Ideograph", "Ideographic"},
    186707: {"Unified_Ideograph", "Ideographic"},
    186708: {"Unified_Ideograph", "Ideographic"},
    186709: {"Unified_Ideograph", "Ideographic"},
    186710: {"Unified_Ideograph", "Ideographic"},
    186711: {"Unified_Ideograph", "Ideographic"},
    186712: {"Unified_Ideograph", "Ideographic"},
    186713: {"Unified_Ideograph", "Ideographic"},
    186714: {"Unified_Ideograph", "Ideographic"},
    186715: {"Unified_Ideograph", "Ideographic"},
    186716: {"Unified_Ideograph", "Ideographic"},
    186717: {"Unified_Ideograph", "Ideographic"},
    186718: {"Unified_Ideograph", "Ideographic"},
    186719: {"Unified_Ideograph", "Ideographic"},
    186720: {"Unified_Ideograph", "Ideographic"},
    186721: {"Unified_Ideograph", "Ideographic"},
    186722: {"Unified_Ideograph", "Ideographic"},
    186723: {"Unified_Ideograph", "Ideographic"},
    186724: {"Unified_Ideograph", "Ideographic"},
    186725: {"Unified_Ideograph", "Ideographic"},
    186726: {"Unified_Ideograph", "Ideographic"},
    186727: {"Unified_Ideograph", "Ideographic"},
    186728: {"Unified_Ideograph", "Ideographic"},
    186729: {"Unified_Ideograph", "Ideographic"},
    186730: {"Unified_Ideograph", "Ideographic"},
    186731: {"Unified_Ideograph", "Ideographic"},
    186732: {"Unified_Ideograph", "Ideographic"},
    186733: {"Unified_Ideograph", "Ideographic"},
    186734: {"Unified_Ideograph", "Ideographic"},
    186735: {"Unified_Ideograph", "Ideographic"},
    186736: {"Unified_Ideograph", "Ideographic"},
    186737: {"Unified_Ideograph", "Ideographic"},
    186738: {"Unified_Ideograph", "Ideographic"},
    186739: {"Unified_Ideograph", "Ideographic"},
    186740: {"Unified_Ideograph", "Ideographic"},
    186741: {"Unified_Ideograph", "Ideographic"},
    186742: {"Unified_Ideograph", "Ideographic"},
    186743: {"Unified_Ideograph", "Ideographic"},
    186744: {"Unified_Ideograph", "Ideographic"},
    186745: {"Unified_Ideograph", "Ideographic"},
    186746: {"Unified_Ideograph", "Ideographic"},
    186747: {"Unified_Ideograph", "Ideographic"},
    186748: {"Unified_Ideograph", "Ideographic"},
    186749: {"Unified_Ideograph", "Ideographic"},
    186750: {"Unified_Ideograph", "Ideographic"},
    186751: {"Unified_Ideograph", "Ideographic"},
    186752: {"Unified_Ideograph", "Ideographic"},
    186753: {"Unified_Ideograph", "Ideographic"},
    186754: {"Unified_Ideograph", "Ideographic"},
    186755: {"Unified_Ideograph", "Ideographic"},
    186756: {"Unified_Ideograph", "Ideographic"},
    186757: {"Unified_Ideograph", "Ideographic"},
    186758: {"Unified_Ideograph", "Ideographic"},
    186759: {"Unified_Ideograph", "Ideographic"},
    186760: {"Unified_Ideograph", "Ideographic"},
    186761: {"Unified_Ideograph", "Ideographic"},
    186762: {"Unified_Ideograph", "Ideographic"},
    186763: {"Unified_Ideograph", "Ideographic"},
    186764: {"Unified_Ideograph", "Ideographic"},
    186765: {"Unified_Ideograph", "Ideographic"},
    186766: {"Unified_Ideograph", "Ideographic"},
    186767: {"Unified_Ideograph", "Ideographic"},
    186768: {"Unified_Ideograph", "Ideographic"},
    186769: {"Unified_Ideograph", "Ideographic"},
    186770: {"Unified_Ideograph", "Ideographic"},
    186771: {"Unified_Ideograph", "Ideographic"},
    186772: {"Unified_Ideograph", "Ideographic"},
    186773: {"Unified_Ideograph", "Ideographic"},
    186774: {"Unified_Ideograph", "Ideographic"},
    186775: {"Unified_Ideograph", "Ideographic"},
    186776: {"Unified_Ideograph", "Ideographic"},
    186777: {"Unified_Ideograph", "Ideographic"},
    186778: {"Unified_Ideograph", "Ideographic"},
    186779: {"Unified_Ideograph", "Ideographic"},
    186780: {"Unified_Ideograph", "Ideographic"},
    186781: {"Unified_Ideograph", "Ideographic"},
    186782: {"Unified_Ideograph", "Ideographic"},
    186783: {"Unified_Ideograph", "Ideographic"},
    186784: {"Unified_Ideograph", "Ideographic"},
    186785: {"Unified_Ideograph", "Ideographic"},
    186786: {"Unified_Ideograph", "Ideographic"},
    186787: {"Unified_Ideograph", "Ideographic"},
    186788: {"Unified_Ideograph", "Ideographic"},
    186789: {"Unified_Ideograph", "Ideographic"},
    186790: {"Unified_Ideograph", "Ideographic"},
    186791: {"Unified_Ideograph", "Ideographic"},
    186792: {"Unified_Ideograph", "Ideographic"},
    186793: {"Unified_Ideograph", "Ideographic"},
    186794: {"Unified_Ideograph", "Ideographic"},
    186795: {"Unified_Ideograph", "Ideographic"},
    186796: {"Unified_Ideograph", "Ideographic"},
    186797: {"Unified_Ideograph", "Ideographic"},
    186798: {"Unified_Ideograph", "Ideographic"},
    186799: {"Unified_Ideograph", "Ideographic"},
    186800: {"Unified_Ideograph", "Ideographic"},
    186801: {"Unified_Ideograph", "Ideographic"},
    186802: {"Unified_Ideograph", "Ideographic"},
    186803: {"Unified_Ideograph", "Ideographic"},
    186804: {"Unified_Ideograph", "Ideographic"},
    186805: {"Unified_Ideograph", "Ideographic"},
    186806: {"Unified_Ideograph", "Ideographic"},
    186807: {"Unified_Ideograph", "Ideographic"},
    186808: {"Unified_Ideograph", "Ideographic"},
    186809: {"Unified_Ideograph", "Ideographic"},
    186810: {"Unified_Ideograph", "Ideographic"},
    186811: {"Unified_Ideograph", "Ideographic"},
    186812: {"Unified_Ideograph", "Ideographic"},
    186813: {"Unified_Ideograph", "Ideographic"},
    186814: {"Unified_Ideograph", "Ideographic"},
    186815: {"Unified_Ideograph", "Ideographic"},
    186816: {"Unified_Ideograph", "Ideographic"},
    186817: {"Unified_Ideograph", "Ideographic"},
    186818: {"Unified_Ideograph", "Ideographic"},
    186819: {"Unified_Ideograph", "Ideographic"},
    186820: {"Unified_Ideograph", "Ideographic"},
    186821: {"Unified_Ideograph", "Ideographic"},
    186822: {"Unified_Ideograph", "Ideographic"},
    186823: {"Unified_Ideograph", "Ideographic"},
    186824: {"Unified_Ideograph", "Ideographic"},
    186825: {"Unified_Ideograph", "Ideographic"},
    186826: {"Unified_Ideograph", "Ideographic"},
    186827: {"Unified_Ideograph", "Ideographic"},
    186828: {"Unified_Ideograph", "Ideographic"},
    186829: {"Unified_Ideograph", "Ideographic"},
    186830: {"Unified_Ideograph", "Ideographic"},
    186831: {"Unified_Ideograph", "Ideographic"},
    186832: {"Unified_Ideograph", "Ideographic"},
    186833: {"Unified_Ideograph", "Ideographic"},
    186834: {"Unified_Ideograph", "Ideographic"},
    186835: {"Unified_Ideograph", "Ideographic"},
    186836: {"Unified_Ideograph", "Ideographic"},
    186837: {"Unified_Ideograph", "Ideographic"},
    186838: {"Unified_Ideograph", "Ideographic"},
    186839: {"Unified_Ideograph", "Ideographic"},
    186840: {"Unified_Ideograph", "Ideographic"},
    186841: {"Unified_Ideograph", "Ideographic"},
    186842: {"Unified_Ideograph", "Ideographic"},
    186843: {"Unified_Ideograph", "Ideographic"},
    186844: {"Unified_Ideograph", "Ideographic"},
    186845: {"Unified_Ideograph", "Ideographic"},
    186846: {"Unified_Ideograph", "Ideographic"},
    186847: {"Unified_Ideograph", "Ideographic"},
    186848: {"Unified_Ideograph", "Ideographic"},
    186849: {"Unified_Ideograph", "Ideographic"},
    186850: {"Unified_Ideograph", "Ideographic"},
    186851: {"Unified_Ideograph", "Ideographic"},
    186852: {"Unified_Ideograph", "Ideographic"},
    186853: {"Unified_Ideograph", "Ideographic"},
    186854: {"Unified_Ideograph", "Ideographic"},
    186855: {"Unified_Ideograph", "Ideographic"},
    186856: {"Unified_Ideograph", "Ideographic"},
    186857: {"Unified_Ideograph", "Ideographic"},
    186858: {"Unified_Ideograph", "Ideographic"},
    186859: {"Unified_Ideograph", "Ideographic"},
    186860: {"Unified_Ideograph", "Ideographic"},
    186861: {"Unified_Ideograph", "Ideographic"},
    186862: {"Unified_Ideograph", "Ideographic"},
    186863: {"Unified_Ideograph", "Ideographic"},
    186864: {"Unified_Ideograph", "Ideographic"},
    186865: {"Unified_Ideograph", "Ideographic"},
    186866: {"Unified_Ideograph", "Ideographic"},
    186867: {"Unified_Ideograph", "Ideographic"},
    186868: {"Unified_Ideograph", "Ideographic"},
    186869: {"Unified_Ideograph", "Ideographic"},
    186870: {"Unified_Ideograph", "Ideographic"},
    186871: {"Unified_Ideograph", "Ideographic"},
    186872: {"Unified_Ideograph", "Ideographic"},
    186873: {"Unified_Ideograph", "Ideographic"},
    186874: {"Unified_Ideograph", "Ideographic"},
    186875: {"Unified_Ideograph", "Ideographic"},
    186876: {"Unified_Ideograph", "Ideographic"},
    186877: {"Unified_Ideograph", "Ideographic"},
    186878: {"Unified_Ideograph", "Ideographic"},
    186879: {"Unified_Ideograph", "Ideographic"},
    186880: {"Unified_Ideograph", "Ideographic"},
    186881: {"Unified_Ideograph", "Ideographic"},
    186882: {"Unified_Ideograph", "Ideographic"},
    186883: {"Unified_Ideograph", "Ideographic"},
    186884: {"Unified_Ideograph", "Ideographic"},
    186885: {"Unified_Ideograph", "Ideographic"},
    186886: {"Unified_Ideograph", "Ideographic"},
    186887: {"Unified_Ideograph", "Ideographic"},
    186888: {"Unified_Ideograph", "Ideographic"},
    186889: {"Unified_Ideograph", "Ideographic"},
    186890: {"Unified_Ideograph", "Ideographic"},
    186891: {"Unified_Ideograph", "Ideographic"},
    186892: {"Unified_Ideograph", "Ideographic"},
    186893: {"Unified_Ideograph", "Ideographic"},
    186894: {"Unified_Ideograph", "Ideographic"},
    186895: {"Unified_Ideograph", "Ideographic"},
    186896: {"Unified_Ideograph", "Ideographic"},
    186897: {"Unified_Ideograph", "Ideographic"},
    186898: {"Unified_Ideograph", "Ideographic"},
    186899: {"Unified_Ideograph", "Ideographic"},
    186900: {"Unified_Ideograph", "Ideographic"},
    186901: {"Unified_Ideograph", "Ideographic"},
    186902: {"Unified_Ideograph", "Ideographic"},
    186903: {"Unified_Ideograph", "Ideographic"},
    186904: {"Unified_Ideograph", "Ideographic"},
    186905: {"Unified_Ideograph", "Ideographic"},
    186906: {"Unified_Ideograph", "Ideographic"},
    186907: {"Unified_Ideograph", "Ideographic"},
    186908: {"Unified_Ideograph", "Ideographic"},
    186909: {"Unified_Ideograph", "Ideographic"},
    186910: {"Unified_Ideograph", "Ideographic"},
    186911: {"Unified_Ideograph", "Ideographic"},
    186912: {"Unified_Ideograph", "Ideographic"},
    186913: {"Unified_Ideograph", "Ideographic"},
    186914: {"Unified_Ideograph", "Ideographic"},
    186915: {"Unified_Ideograph", "Ideographic"},
    186916: {"Unified_Ideograph", "Ideographic"},
    186917: {"Unified_Ideograph", "Ideographic"},
    186918: {"Unified_Ideograph", "Ideographic"},
    186919: {"Unified_Ideograph", "Ideographic"},
    186920: {"Unified_Ideograph", "Ideographic"},
    186921: {"Unified_Ideograph", "Ideographic"},
    186922: {"Unified_Ideograph", "Ideographic"},
    186923: {"Unified_Ideograph", "Ideographic"},
    186924: {"Unified_Ideograph", "Ideographic"},
    186925: {"Unified_Ideograph", "Ideographic"},
    186926: {"Unified_Ideograph", "Ideographic"},
    186927: {"Unified_Ideograph", "Ideographic"},
    186928: {"Unified_Ideograph", "Ideographic"},
    186929: {"Unified_Ideograph", "Ideographic"},
    186930: {"Unified_Ideograph", "Ideographic"},
    186931: {"Unified_Ideograph", "Ideographic"},
    186932: {"Unified_Ideograph", "Ideographic"},
    186933: {"Unified_Ideograph", "Ideographic"},
    186934: {"Unified_Ideograph", "Ideographic"},
    186935: {"Unified_Ideograph", "Ideographic"},
    186936: {"Unified_Ideograph", "Ideographic"},
    186937: {"Unified_Ideograph", "Ideographic"},
    186938: {"Unified_Ideograph", "Ideographic"},
    186939: {"Unified_Ideograph", "Ideographic"},
    186940: {"Unified_Ideograph", "Ideographic"},
    186941: {"Unified_Ideograph", "Ideographic"},
    186942: {"Unified_Ideograph", "Ideographic"},
    186943: {"Unified_Ideograph", "Ideographic"},
    186944: {"Unified_Ideograph", "Ideographic"},
    186945: {"Unified_Ideograph", "Ideographic"},
    186946: {"Unified_Ideograph", "Ideographic"},
    186947: {"Unified_Ideograph", "Ideographic"},
    186948: {"Unified_Ideograph", "Ideographic"},
    186949: {"Unified_Ideograph", "Ideographic"},
    186950: {"Unified_Ideograph", "Ideographic"},
    186951: {"Unified_Ideograph", "Ideographic"},
    186952: {"Unified_Ideograph", "Ideographic"},
    186953: {"Unified_Ideograph", "Ideographic"},
    186954: {"Unified_Ideograph", "Ideographic"},
    186955: {"Unified_Ideograph", "Ideographic"},
    186956: {"Unified_Ideograph", "Ideographic"},
    186957: {"Unified_Ideograph", "Ideographic"},
    186958: {"Unified_Ideograph", "Ideographic"},
    186959: {"Unified_Ideograph", "Ideographic"},
    186960: {"Unified_Ideograph", "Ideographic"},
    186961: {"Unified_Ideograph", "Ideographic"},
    186962: {"Unified_Ideograph", "Ideographic"},
    186963: {"Unified_Ideograph", "Ideographic"},
    186964: {"Unified_Ideograph", "Ideographic"},
    186965: {"Unified_Ideograph", "Ideographic"},
    186966: {"Unified_Ideograph", "Ideographic"},
    186967: {"Unified_Ideograph", "Ideographic"},
    186968: {"Unified_Ideograph", "Ideographic"},
    186969: {"Unified_Ideograph", "Ideographic"},
    186970: {"Unified_Ideograph", "Ideographic"},
    186971: {"Unified_Ideograph", "Ideographic"},
    186972: {"Unified_Ideograph", "Ideographic"},
    186973: {"Unified_Ideograph", "Ideographic"},
    186974: {"Unified_Ideograph", "Ideographic"},
    186975: {"Unified_Ideograph", "Ideographic"},
    186976: {"Unified_Ideograph", "Ideographic"},
    186977: {"Unified_Ideograph", "Ideographic"},
    186978: {"Unified_Ideograph", "Ideographic"},
    186979: {"Unified_Ideograph", "Ideographic"},
    186980: {"Unified_Ideograph", "Ideographic"},
    186981: {"Unified_Ideograph", "Ideographic"},
    186982: {"Unified_Ideograph", "Ideographic"},
    186983: {"Unified_Ideograph", "Ideographic"},
    186984: {"Unified_Ideograph", "Ideographic"},
    186985: {"Unified_Ideograph", "Ideographic"},
    186986: {"Unified_Ideograph", "Ideographic"},
    186987: {"Unified_Ideograph", "Ideographic"},
    186988: {"Unified_Ideograph", "Ideographic"},
    186989: {"Unified_Ideograph", "Ideographic"},
    186990: {"Unified_Ideograph", "Ideographic"},
    186991: {"Unified_Ideograph", "Ideographic"},
    186992: {"Unified_Ideograph", "Ideographic"},
    186993: {"Unified_Ideograph", "Ideographic"},
    186994: {"Unified_Ideograph", "Ideographic"},
    186995: {"Unified_Ideograph", "Ideographic"},
    186996: {"Unified_Ideograph", "Ideographic"},
    186997: {"Unified_Ideograph", "Ideographic"},
    186998: {"Unified_Ideograph", "Ideographic"},
    186999: {"Unified_Ideograph", "Ideographic"},
    187000: {"Unified_Ideograph", "Ideographic"},
    187001: {"Unified_Ideograph", "Ideographic"},
    187002: {"Unified_Ideograph", "Ideographic"},
    187003: {"Unified_Ideograph", "Ideographic"},
    187004: {"Unified_Ideograph", "Ideographic"},
    187005: {"Unified_Ideograph", "Ideographic"},
    187006: {"Unified_Ideograph", "Ideographic"},
    187007: {"Unified_Ideograph", "Ideographic"},
    187008: {"Unified_Ideograph", "Ideographic"},
    187009: {"Unified_Ideograph", "Ideographic"},
    187010: {"Unified_Ideograph", "Ideographic"},
    187011: {"Unified_Ideograph", "Ideographic"},
    187012: {"Unified_Ideograph", "Ideographic"},
    187013: {"Unified_Ideograph", "Ideographic"},
    187014: {"Unified_Ideograph", "Ideographic"},
    187015: {"Unified_Ideograph", "Ideographic"},
    187016: {"Unified_Ideograph", "Ideographic"},
    187017: {"Unified_Ideograph", "Ideographic"},
    187018: {"Unified_Ideograph", "Ideographic"},
    187019: {"Unified_Ideograph", "Ideographic"},
    187020: {"Unified_Ideograph", "Ideographic"},
    187021: {"Unified_Ideograph", "Ideographic"},
    187022: {"Unified_Ideograph", "Ideographic"},
    187023: {"Unified_Ideograph", "Ideographic"},
    187024: {"Unified_Ideograph", "Ideographic"},
    187025: {"Unified_Ideograph", "Ideographic"},
    187026: {"Unified_Ideograph", "Ideographic"},
    187027: {"Unified_Ideograph", "Ideographic"},
    187028: {"Unified_Ideograph", "Ideographic"},
    187029: {"Unified_Ideograph", "Ideographic"},
    187030: {"Unified_Ideograph", "Ideographic"},
    187031: {"Unified_Ideograph", "Ideographic"},
    187032: {"Unified_Ideograph", "Ideographic"},
    187033: {"Unified_Ideograph", "Ideographic"},
    187034: {"Unified_Ideograph", "Ideographic"},
    187035: {"Unified_Ideograph", "Ideographic"},
    187036: {"Unified_Ideograph", "Ideographic"},
    187037: {"Unified_Ideograph", "Ideographic"},
    187038: {"Unified_Ideograph", "Ideographic"},
    187039: {"Unified_Ideograph", "Ideographic"},
    187040: {"Unified_Ideograph", "Ideographic"},
    187041: {"Unified_Ideograph", "Ideographic"},
    187042: {"Unified_Ideograph", "Ideographic"},
    187043: {"Unified_Ideograph", "Ideographic"},
    187044: {"Unified_Ideograph", "Ideographic"},
    187045: {"Unified_Ideograph", "Ideographic"},
    187046: {"Unified_Ideograph", "Ideographic"},
    187047: {"Unified_Ideograph", "Ideographic"},
    187048: {"Unified_Ideograph", "Ideographic"},
    187049: {"Unified_Ideograph", "Ideographic"},
    187050: {"Unified_Ideograph", "Ideographic"},
    187051: {"Unified_Ideograph", "Ideographic"},
    187052: {"Unified_Ideograph", "Ideographic"},
    187053: {"Unified_Ideograph", "Ideographic"},
    187054: {"Unified_Ideograph", "Ideographic"},
    187055: {"Unified_Ideograph", "Ideographic"},
    187056: {"Unified_Ideograph", "Ideographic"},
    187057: {"Unified_Ideograph", "Ideographic"},
    187058: {"Unified_Ideograph", "Ideographic"},
    187059: {"Unified_Ideograph", "Ideographic"},
    187060: {"Unified_Ideograph", "Ideographic"},
    187061: {"Unified_Ideograph", "Ideographic"},
    187062: {"Unified_Ideograph", "Ideographic"},
    187063: {"Unified_Ideograph", "Ideographic"},
    187064: {"Unified_Ideograph", "Ideographic"},
    187065: {"Unified_Ideograph", "Ideographic"},
    187066: {"Unified_Ideograph", "Ideographic"},
    187067: {"Unified_Ideograph", "Ideographic"},
    187068: {"Unified_Ideograph", "Ideographic"},
    187069: {"Unified_Ideograph", "Ideographic"},
    187070: {"Unified_Ideograph", "Ideographic"},
    187071: {"Unified_Ideograph", "Ideographic"},
    187072: {"Unified_Ideograph", "Ideographic"},
    187073: {"Unified_Ideograph", "Ideographic"},
    187074: {"Unified_Ideograph", "Ideographic"},
    187075: {"Unified_Ideograph", "Ideographic"},
    187076: {"Unified_Ideograph", "Ideographic"},
    187077: {"Unified_Ideograph", "Ideographic"},
    187078: {"Unified_Ideograph", "Ideographic"},
    187079: {"Unified_Ideograph", "Ideographic"},
    187080: {"Unified_Ideograph", "Ideographic"},
    187081: {"Unified_Ideograph", "Ideographic"},
    187082: {"Unified_Ideograph", "Ideographic"},
    187083: {"Unified_Ideograph", "Ideographic"},
    187084: {"Unified_Ideograph", "Ideographic"},
    187085: {"Unified_Ideograph", "Ideographic"},
    187086: {"Unified_Ideograph", "Ideographic"},
    187087: {"Unified_Ideograph", "Ideographic"},
    187088: {"Unified_Ideograph", "Ideographic"},
    187089: {"Unified_Ideograph", "Ideographic"},
    187090: {"Unified_Ideograph", "Ideographic"},
    187091: {"Unified_Ideograph", "Ideographic"},
    187092: {"Unified_Ideograph", "Ideographic"},
    187093: {"Unified_Ideograph", "Ideographic"},
    187094: {"Unified_Ideograph", "Ideographic"},
    187095: {"Unified_Ideograph", "Ideographic"},
    187096: {"Unified_Ideograph", "Ideographic"},
    187097: {"Unified_Ideograph", "Ideographic"},
    187098: {"Unified_Ideograph", "Ideographic"},
    187099: {"Unified_Ideograph", "Ideographic"},
    187100: {"Unified_Ideograph", "Ideographic"},
    187101: {"Unified_Ideograph", "Ideographic"},
    187102: {"Unified_Ideograph", "Ideographic"},
    187103: {"Unified_Ideograph", "Ideographic"},
    187104: {"Unified_Ideograph", "Ideographic"},
    187105: {"Unified_Ideograph", "Ideographic"},
    187106: {"Unified_Ideograph", "Ideographic"},
    187107: {"Unified_Ideograph", "Ideographic"},
    187108: {"Unified_Ideograph", "Ideographic"},
    187109: {"Unified_Ideograph", "Ideographic"},
    187110: {"Unified_Ideograph", "Ideographic"},
    187111: {"Unified_Ideograph", "Ideographic"},
    187112: {"Unified_Ideograph", "Ideographic"},
    187113: {"Unified_Ideograph", "Ideographic"},
    187114: {"Unified_Ideograph", "Ideographic"},
    187115: {"Unified_Ideograph", "Ideographic"},
    187116: {"Unified_Ideograph", "Ideographic"},
    187117: {"Unified_Ideograph", "Ideographic"},
    187118: {"Unified_Ideograph", "Ideographic"},
    187119: {"Unified_Ideograph", "Ideographic"},
    187120: {"Unified_Ideograph", "Ideographic"},
    187121: {"Unified_Ideograph", "Ideographic"},
    187122: {"Unified_Ideograph", "Ideographic"},
    187123: {"Unified_Ideograph", "Ideographic"},
    187124: {"Unified_Ideograph", "Ideographic"},
    187125: {"Unified_Ideograph", "Ideographic"},
    187126: {"Unified_Ideograph", "Ideographic"},
    187127: {"Unified_Ideograph", "Ideographic"},
    187128: {"Unified_Ideograph", "Ideographic"},
    187129: {"Unified_Ideograph", "Ideographic"},
    187130: {"Unified_Ideograph", "Ideographic"},
    187131: {"Unified_Ideograph", "Ideographic"},
    187132: {"Unified_Ideograph", "Ideographic"},
    187133: {"Unified_Ideograph", "Ideographic"},
    187134: {"Unified_Ideograph", "Ideographic"},
    187135: {"Unified_Ideograph", "Ideographic"},
    187136: {"Unified_Ideograph", "Ideographic"},
    187137: {"Unified_Ideograph", "Ideographic"},
    187138: {"Unified_Ideograph", "Ideographic"},
    187139: {"Unified_Ideograph", "Ideographic"},
    187140: {"Unified_Ideograph", "Ideographic"},
    187141: {"Unified_Ideograph", "Ideographic"},
    187142: {"Unified_Ideograph", "Ideographic"},
    187143: {"Unified_Ideograph", "Ideographic"},
    187144: {"Unified_Ideograph", "Ideographic"},
    187145: {"Unified_Ideograph", "Ideographic"},
    187146: {"Unified_Ideograph", "Ideographic"},
    187147: {"Unified_Ideograph", "Ideographic"},
    187148: {"Unified_Ideograph", "Ideographic"},
    187149: {"Unified_Ideograph", "Ideographic"},
    187150: {"Unified_Ideograph", "Ideographic"},
    187151: {"Unified_Ideograph", "Ideographic"},
    187152: {"Unified_Ideograph", "Ideographic"},
    187153: {"Unified_Ideograph", "Ideographic"},
    187154: {"Unified_Ideograph", "Ideographic"},
    187155: {"Unified_Ideograph", "Ideographic"},
    187156: {"Unified_Ideograph", "Ideographic"},
    187157: {"Unified_Ideograph", "Ideographic"},
    187158: {"Unified_Ideograph", "Ideographic"},
    187159: {"Unified_Ideograph", "Ideographic"},
    187160: {"Unified_Ideograph", "Ideographic"},
    187161: {"Unified_Ideograph", "Ideographic"},
    187162: {"Unified_Ideograph", "Ideographic"},
    187163: {"Unified_Ideograph", "Ideographic"},
    187164: {"Unified_Ideograph", "Ideographic"},
    187165: {"Unified_Ideograph", "Ideographic"},
    187166: {"Unified_Ideograph", "Ideographic"},
    187167: {"Unified_Ideograph", "Ideographic"},
    187168: {"Unified_Ideograph", "Ideographic"},
    187169: {"Unified_Ideograph", "Ideographic"},
    187170: {"Unified_Ideograph", "Ideographic"},
    187171: {"Unified_Ideograph", "Ideographic"},
    187172: {"Unified_Ideograph", "Ideographic"},
    187173: {"Unified_Ideograph", "Ideographic"},
    187174: {"Unified_Ideograph", "Ideographic"},
    187175: {"Unified_Ideograph", "Ideographic"},
    187176: {"Unified_Ideograph", "Ideographic"},
    187177: {"Unified_Ideograph", "Ideographic"},
    187178: {"Unified_Ideograph", "Ideographic"},
    187179: {"Unified_Ideograph", "Ideographic"},
    187180: {"Unified_Ideograph", "Ideographic"},
    187181: {"Unified_Ideograph", "Ideographic"},
    187182: {"Unified_Ideograph", "Ideographic"},
    187183: {"Unified_Ideograph", "Ideographic"},
    187184: {"Unified_Ideograph", "Ideographic"},
    187185: {"Unified_Ideograph", "Ideographic"},
    187186: {"Unified_Ideograph", "Ideographic"},
    187187: {"Unified_Ideograph", "Ideographic"},
    187188: {"Unified_Ideograph", "Ideographic"},
    187189: {"Unified_Ideograph", "Ideographic"},
    187190: {"Unified_Ideograph", "Ideographic"},
    187191: {"Unified_Ideograph", "Ideographic"},
    187192: {"Unified_Ideograph", "Ideographic"},
    187193: {"Unified_Ideograph", "Ideographic"},
    187194: {"Unified_Ideograph", "Ideographic"},
    187195: {"Unified_Ideograph", "Ideographic"},
    187196: {"Unified_Ideograph", "Ideographic"},
    187197: {"Unified_Ideograph", "Ideographic"},
    187198: {"Unified_Ideograph", "Ideographic"},
    187199: {"Unified_Ideograph", "Ideographic"},
    187200: {"Unified_Ideograph", "Ideographic"},
    187201: {"Unified_Ideograph", "Ideographic"},
    187202: {"Unified_Ideograph", "Ideographic"},
    187203: {"Unified_Ideograph", "Ideographic"},
    187204: {"Unified_Ideograph", "Ideographic"},
    187205: {"Unified_Ideograph", "Ideographic"},
    187206: {"Unified_Ideograph", "Ideographic"},
    187207: {"Unified_Ideograph", "Ideographic"},
    187208: {"Unified_Ideograph", "Ideographic"},
    187209: {"Unified_Ideograph", "Ideographic"},
    187210: {"Unified_Ideograph", "Ideographic"},
    187211: {"Unified_Ideograph", "Ideographic"},
    187212: {"Unified_Ideograph", "Ideographic"},
    187213: {"Unified_Ideograph", "Ideographic"},
    187214: {"Unified_Ideograph", "Ideographic"},
    187215: {"Unified_Ideograph", "Ideographic"},
    187216: {"Unified_Ideograph", "Ideographic"},
    187217: {"Unified_Ideograph", "Ideographic"},
    187218: {"Unified_Ideograph", "Ideographic"},
    187219: {"Unified_Ideograph", "Ideographic"},
    187220: {"Unified_Ideograph", "Ideographic"},
    187221: {"Unified_Ideograph", "Ideographic"},
    187222: {"Unified_Ideograph", "Ideographic"},
    187223: {"Unified_Ideograph", "Ideographic"},
    187224: {"Unified_Ideograph", "Ideographic"},
    187225: {"Unified_Ideograph", "Ideographic"},
    187226: {"Unified_Ideograph", "Ideographic"},
    187227: {"Unified_Ideograph", "Ideographic"},
    187228: {"Unified_Ideograph", "Ideographic"},
    187229: {"Unified_Ideograph", "Ideographic"},
    187230: {"Unified_Ideograph", "Ideographic"},
    187231: {"Unified_Ideograph", "Ideographic"},
    187232: {"Unified_Ideograph", "Ideographic"},
    187233: {"Unified_Ideograph", "Ideographic"},
    187234: {"Unified_Ideograph", "Ideographic"},
    187235: {"Unified_Ideograph", "Ideographic"},
    187236: {"Unified_Ideograph", "Ideographic"},
    187237: {"Unified_Ideograph", "Ideographic"},
    187238: {"Unified_Ideograph", "Ideographic"},
    187239: {"Unified_Ideograph", "Ideographic"},
    187240: {"Unified_Ideograph", "Ideographic"},
    187241: {"Unified_Ideograph", "Ideographic"},
    187242: {"Unified_Ideograph", "Ideographic"},
    187243: {"Unified_Ideograph", "Ideographic"},
    187244: {"Unified_Ideograph", "Ideographic"},
    187245: {"Unified_Ideograph", "Ideographic"},
    187246: {"Unified_Ideograph", "Ideographic"},
    187247: {"Unified_Ideograph", "Ideographic"},
    187248: {"Unified_Ideograph", "Ideographic"},
    187249: {"Unified_Ideograph", "Ideographic"},
    187250: {"Unified_Ideograph", "Ideographic"},
    187251: {"Unified_Ideograph", "Ideographic"},
    187252: {"Unified_Ideograph", "Ideographic"},
    187253: {"Unified_Ideograph", "Ideographic"},
    187254: {"Unified_Ideograph", "Ideographic"},
    187255: {"Unified_Ideograph", "Ideographic"},
    187256: {"Unified_Ideograph", "Ideographic"},
    187257: {"Unified_Ideograph", "Ideographic"},
    187258: {"Unified_Ideograph", "Ideographic"},
    187259: {"Unified_Ideograph", "Ideographic"},
    187260: {"Unified_Ideograph", "Ideographic"},
    187261: {"Unified_Ideograph", "Ideographic"},
    187262: {"Unified_Ideograph", "Ideographic"},
    187263: {"Unified_Ideograph", "Ideographic"},
    187264: {"Unified_Ideograph", "Ideographic"},
    187265: {"Unified_Ideograph", "Ideographic"},
    187266: {"Unified_Ideograph", "Ideographic"},
    187267: {"Unified_Ideograph", "Ideographic"},
    187268: {"Unified_Ideograph", "Ideographic"},
    187269: {"Unified_Ideograph", "Ideographic"},
    187270: {"Unified_Ideograph", "Ideographic"},
    187271: {"Unified_Ideograph", "Ideographic"},
    187272: {"Unified_Ideograph", "Ideographic"},
    187273: {"Unified_Ideograph", "Ideographic"},
    187274: {"Unified_Ideograph", "Ideographic"},
    187275: {"Unified_Ideograph", "Ideographic"},
    187276: {"Unified_Ideograph", "Ideographic"},
    187277: {"Unified_Ideograph", "Ideographic"},
    187278: {"Unified_Ideograph", "Ideographic"},
    187279: {"Unified_Ideograph", "Ideographic"},
    187280: {"Unified_Ideograph", "Ideographic"},
    187281: {"Unified_Ideograph", "Ideographic"},
    187282: {"Unified_Ideograph", "Ideographic"},
    187283: {"Unified_Ideograph", "Ideographic"},
    187284: {"Unified_Ideograph", "Ideographic"},
    187285: {"Unified_Ideograph", "Ideographic"},
    187286: {"Unified_Ideograph", "Ideographic"},
    187287: {"Unified_Ideograph", "Ideographic"},
    187288: {"Unified_Ideograph", "Ideographic"},
    187289: {"Unified_Ideograph", "Ideographic"},
    187290: {"Unified_Ideograph", "Ideographic"},
    187291: {"Unified_Ideograph", "Ideographic"},
    187292: {"Unified_Ideograph", "Ideographic"},
    187293: {"Unified_Ideograph", "Ideographic"},
    187294: {"Unified_Ideograph", "Ideographic"},
    187295: {"Unified_Ideograph", "Ideographic"},
    187296: {"Unified_Ideograph", "Ideographic"},
    187297: {"Unified_Ideograph", "Ideographic"},
    187298: {"Unified_Ideograph", "Ideographic"},
    187299: {"Unified_Ideograph", "Ideographic"},
    187300: {"Unified_Ideograph", "Ideographic"},
    187301: {"Unified_Ideograph", "Ideographic"},
    187302: {"Unified_Ideograph", "Ideographic"},
    187303: {"Unified_Ideograph", "Ideographic"},
    187304: {"Unified_Ideograph", "Ideographic"},
    187305: {"Unified_Ideograph", "Ideographic"},
    187306: {"Unified_Ideograph", "Ideographic"},
    187307: {"Unified_Ideograph", "Ideographic"},
    187308: {"Unified_Ideograph", "Ideographic"},
    187309: {"Unified_Ideograph", "Ideographic"},
    187310: {"Unified_Ideograph", "Ideographic"},
    187311: {"Unified_Ideograph", "Ideographic"},
    187312: {"Unified_Ideograph", "Ideographic"},
    187313: {"Unified_Ideograph", "Ideographic"},
    187314: {"Unified_Ideograph", "Ideographic"},
    187315: {"Unified_Ideograph", "Ideographic"},
    187316: {"Unified_Ideograph", "Ideographic"},
    187317: {"Unified_Ideograph", "Ideographic"},
    187318: {"Unified_Ideograph", "Ideographic"},
    187319: {"Unified_Ideograph", "Ideographic"},
    187320: {"Unified_Ideograph", "Ideographic"},
    187321: {"Unified_Ideograph", "Ideographic"},
    187322: {"Unified_Ideograph", "Ideographic"},
    187323: {"Unified_Ideograph", "Ideographic"},
    187324: {"Unified_Ideograph", "Ideographic"},
    187325: {"Unified_Ideograph", "Ideographic"},
    187326: {"Unified_Ideograph", "Ideographic"},
    187327: {"Unified_Ideograph", "Ideographic"},
    187328: {"Unified_Ideograph", "Ideographic"},
    187329: {"Unified_Ideograph", "Ideographic"},
    187330: {"Unified_Ideograph", "Ideographic"},
    187331: {"Unified_Ideograph", "Ideographic"},
    187332: {"Unified_Ideograph", "Ideographic"},
    187333: {"Unified_Ideograph", "Ideographic"},
    187334: {"Unified_Ideograph", "Ideographic"},
    187335: {"Unified_Ideograph", "Ideographic"},
    187336: {"Unified_Ideograph", "Ideographic"},
    187337: {"Unified_Ideograph", "Ideographic"},
    187338: {"Unified_Ideograph", "Ideographic"},
    187339: {"Unified_Ideograph", "Ideographic"},
    187340: {"Unified_Ideograph", "Ideographic"},
    187341: {"Unified_Ideograph", "Ideographic"},
    187342: {"Unified_Ideograph", "Ideographic"},
    187343: {"Unified_Ideograph", "Ideographic"},
    187344: {"Unified_Ideograph", "Ideographic"},
    187345: {"Unified_Ideograph", "Ideographic"},
    187346: {"Unified_Ideograph", "Ideographic"},
    187347: {"Unified_Ideograph", "Ideographic"},
    187348: {"Unified_Ideograph", "Ideographic"},
    187349: {"Unified_Ideograph", "Ideographic"},
    187350: {"Unified_Ideograph", "Ideographic"},
    187351: {"Unified_Ideograph", "Ideographic"},
    187352: {"Unified_Ideograph", "Ideographic"},
    187353: {"Unified_Ideograph", "Ideographic"},
    187354: {"Unified_Ideograph", "Ideographic"},
    187355: {"Unified_Ideograph", "Ideographic"},
    187356: {"Unified_Ideograph", "Ideographic"},
    187357: {"Unified_Ideograph", "Ideographic"},
    187358: {"Unified_Ideograph", "Ideographic"},
    187359: {"Unified_Ideograph", "Ideographic"},
    187360: {"Unified_Ideograph", "Ideographic"},
    187361: {"Unified_Ideograph", "Ideographic"},
    187362: {"Unified_Ideograph", "Ideographic"},
    187363: {"Unified_Ideograph", "Ideographic"},
    187364: {"Unified_Ideograph", "Ideographic"},
    187365: {"Unified_Ideograph", "Ideographic"},
    187366: {"Unified_Ideograph", "Ideographic"},
    187367: {"Unified_Ideograph", "Ideographic"},
    187368: {"Unified_Ideograph", "Ideographic"},
    187369: {"Unified_Ideograph", "Ideographic"},
    187370: {"Unified_Ideograph", "Ideographic"},
    187371: {"Unified_Ideograph", "Ideographic"},
    187372: {"Unified_Ideograph", "Ideographic"},
    187373: {"Unified_Ideograph", "Ideographic"},
    187374: {"Unified_Ideograph", "Ideographic"},
    187375: {"Unified_Ideograph", "Ideographic"},
    187376: {"Unified_Ideograph", "Ideographic"},
    187377: {"Unified_Ideograph", "Ideographic"},
    187378: {"Unified_Ideograph", "Ideographic"},
    187379: {"Unified_Ideograph", "Ideographic"},
    187380: {"Unified_Ideograph", "Ideographic"},
    187381: {"Unified_Ideograph", "Ideographic"},
    187382: {"Unified_Ideograph", "Ideographic"},
    187383: {"Unified_Ideograph", "Ideographic"},
    187384: {"Unified_Ideograph", "Ideographic"},
    187385: {"Unified_Ideograph", "Ideographic"},
    187386: {"Unified_Ideograph", "Ideographic"},
    187387: {"Unified_Ideograph", "Ideographic"},
    187388: {"Unified_Ideograph", "Ideographic"},
    187389: {"Unified_Ideograph", "Ideographic"},
    187390: {"Unified_Ideograph", "Ideographic"},
    187391: {"Unified_Ideograph", "Ideographic"},
    187392: {"Unified_Ideograph", "Ideographic"},
    187393: {"Unified_Ideograph", "Ideographic"},
    187394: {"Unified_Ideograph", "Ideographic"},
    187395: {"Unified_Ideograph", "Ideographic"},
    187396: {"Unified_Ideograph", "Ideographic"},
    187397: {"Unified_Ideograph", "Ideographic"},
    187398: {"Unified_Ideograph", "Ideographic"},
    187399: {"Unified_Ideograph", "Ideographic"},
    187400: {"Unified_Ideograph", "Ideographic"},
    187401: {"Unified_Ideograph", "Ideographic"},
    187402: {"Unified_Ideograph", "Ideographic"},
    187403: {"Unified_Ideograph", "Ideographic"},
    187404: {"Unified_Ideograph", "Ideographic"},
    187405: {"Unified_Ideograph", "Ideographic"},
    187406: {"Unified_Ideograph", "Ideographic"},
    187407: {"Unified_Ideograph", "Ideographic"},
    187408: {"Unified_Ideograph", "Ideographic"},
    187409: {"Unified_Ideograph", "Ideographic"},
    187410: {"Unified_Ideograph", "Ideographic"},
    187411: {"Unified_Ideograph", "Ideographic"},
    187412: {"Unified_Ideograph", "Ideographic"},
    187413: {"Unified_Ideograph", "Ideographic"},
    187414: {"Unified_Ideograph", "Ideographic"},
    187415: {"Unified_Ideograph", "Ideographic"},
    187416: {"Unified_Ideograph", "Ideographic"},
    187417: {"Unified_Ideograph", "Ideographic"},
    187418: {"Unified_Ideograph", "Ideographic"},
    187419: {"Unified_Ideograph", "Ideographic"},
    187420: {"Unified_Ideograph", "Ideographic"},
    187421: {"Unified_Ideograph", "Ideographic"},
    187422: {"Unified_Ideograph", "Ideographic"},
    187423: {"Unified_Ideograph", "Ideographic"},
    187424: {"Unified_Ideograph", "Ideographic"},
    187425: {"Unified_Ideograph", "Ideographic"},
    187426: {"Unified_Ideograph", "Ideographic"},
    187427: {"Unified_Ideograph", "Ideographic"},
    187428: {"Unified_Ideograph", "Ideographic"},
    187429: {"Unified_Ideograph", "Ideographic"},
    187430: {"Unified_Ideograph", "Ideographic"},
    187431: {"Unified_Ideograph", "Ideographic"},
    187432: {"Unified_Ideograph", "Ideographic"},
    187433: {"Unified_Ideograph", "Ideographic"},
    187434: {"Unified_Ideograph", "Ideographic"},
    187435: {"Unified_Ideograph", "Ideographic"},
    187436: {"Unified_Ideograph", "Ideographic"},
    187437: {"Unified_Ideograph", "Ideographic"},
    187438: {"Unified_Ideograph", "Ideographic"},
    187439: {"Unified_Ideograph", "Ideographic"},
    187440: {"Unified_Ideograph", "Ideographic"},
    187441: {"Unified_Ideograph", "Ideographic"},
    187442: {"Unified_Ideograph", "Ideographic"},
    187443: {"Unified_Ideograph", "Ideographic"},
    187444: {"Unified_Ideograph", "Ideographic"},
    187445: {"Unified_Ideograph", "Ideographic"},
    187446: {"Unified_Ideograph", "Ideographic"},
    187447: {"Unified_Ideograph", "Ideographic"},
    187448: {"Unified_Ideograph", "Ideographic"},
    187449: {"Unified_Ideograph", "Ideographic"},
    187450: {"Unified_Ideograph", "Ideographic"},
    187451: {"Unified_Ideograph", "Ideographic"},
    187452: {"Unified_Ideograph", "Ideographic"},
    187453: {"Unified_Ideograph", "Ideographic"},
    187454: {"Unified_Ideograph", "Ideographic"},
    187455: {"Unified_Ideograph", "Ideographic"},
    187456: {"Unified_Ideograph", "Ideographic"},
    187457: {"Unified_Ideograph", "Ideographic"},
    187458: {"Unified_Ideograph", "Ideographic"},
    187459: {"Unified_Ideograph", "Ideographic"},
    187460: {"Unified_Ideograph", "Ideographic"},
    187461: {"Unified_Ideograph", "Ideographic"},
    187462: {"Unified_Ideograph", "Ideographic"},
    187463: {"Unified_Ideograph", "Ideographic"},
    187464: {"Unified_Ideograph", "Ideographic"},
    187465: {"Unified_Ideograph", "Ideographic"},
    187466: {"Unified_Ideograph", "Ideographic"},
    187467: {"Unified_Ideograph", "Ideographic"},
    187468: {"Unified_Ideograph", "Ideographic"},
    187469: {"Unified_Ideograph", "Ideographic"},
    187470: {"Unified_Ideograph", "Ideographic"},
    187471: {"Unified_Ideograph", "Ideographic"},
    187472: {"Unified_Ideograph", "Ideographic"},
    187473: {"Unified_Ideograph", "Ideographic"},
    187474: {"Unified_Ideograph", "Ideographic"},
    187475: {"Unified_Ideograph", "Ideographic"},
    187476: {"Unified_Ideograph", "Ideographic"},
    187477: {"Unified_Ideograph", "Ideographic"},
    187478: {"Unified_Ideograph", "Ideographic"},
    187479: {"Unified_Ideograph", "Ideographic"},
    187480: {"Unified_Ideograph", "Ideographic"},
    187481: {"Unified_Ideograph", "Ideographic"},
    187482: {"Unified_Ideograph", "Ideographic"},
    187483: {"Unified_Ideograph", "Ideographic"},
    187484: {"Unified_Ideograph", "Ideographic"},
    187485: {"Unified_Ideograph", "Ideographic"},
    187486: {"Unified_Ideograph", "Ideographic"},
    187487: {"Unified_Ideograph", "Ideographic"},
    187488: {"Unified_Ideograph", "Ideographic"},
    187489: {"Unified_Ideograph", "Ideographic"},
    187490: {"Unified_Ideograph", "Ideographic"},
    187491: {"Unified_Ideograph", "Ideographic"},
    187492: {"Unified_Ideograph", "Ideographic"},
    187493: {"Unified_Ideograph", "Ideographic"},
    187494: {"Unified_Ideograph", "Ideographic"},
    187495: {"Unified_Ideograph", "Ideographic"},
    187496: {"Unified_Ideograph", "Ideographic"},
    187497: {"Unified_Ideograph", "Ideographic"},
    187498: {"Unified_Ideograph", "Ideographic"},
    187499: {"Unified_Ideograph", "Ideographic"},
    187500: {"Unified_Ideograph", "Ideographic"},
    187501: {"Unified_Ideograph", "Ideographic"},
    187502: {"Unified_Ideograph", "Ideographic"},
    187503: {"Unified_Ideograph", "Ideographic"},
    187504: {"Unified_Ideograph", "Ideographic"},
    187505: {"Unified_Ideograph", "Ideographic"},
    187506: {"Unified_Ideograph", "Ideographic"},
    187507: {"Unified_Ideograph", "Ideographic"},
    187508: {"Unified_Ideograph", "Ideographic"},
    187509: {"Unified_Ideograph", "Ideographic"},
    187510: {"Unified_Ideograph", "Ideographic"},
    187511: {"Unified_Ideograph", "Ideographic"},
    187512: {"Unified_Ideograph", "Ideographic"},
    187513: {"Unified_Ideograph", "Ideographic"},
    187514: {"Unified_Ideograph", "Ideographic"},
    187515: {"Unified_Ideograph", "Ideographic"},
    187516: {"Unified_Ideograph", "Ideographic"},
    187517: {"Unified_Ideograph", "Ideographic"},
    187518: {"Unified_Ideograph", "Ideographic"},
    187519: {"Unified_Ideograph", "Ideographic"},
    187520: {"Unified_Ideograph", "Ideographic"},
    187521: {"Unified_Ideograph", "Ideographic"},
    187522: {"Unified_Ideograph", "Ideographic"},
    187523: {"Unified_Ideograph", "Ideographic"},
    187524: {"Unified_Ideograph", "Ideographic"},
    187525: {"Unified_Ideograph", "Ideographic"},
    187526: {"Unified_Ideograph", "Ideographic"},
    187527: {"Unified_Ideograph", "Ideographic"},
    187528: {"Unified_Ideograph", "Ideographic"},
    187529: {"Unified_Ideograph", "Ideographic"},
    187530: {"Unified_Ideograph", "Ideographic"},
    187531: {"Unified_Ideograph", "Ideographic"},
    187532: {"Unified_Ideograph", "Ideographic"},
    187533: {"Unified_Ideograph", "Ideographic"},
    187534: {"Unified_Ideograph", "Ideographic"},
    187535: {"Unified_Ideograph", "Ideographic"},
    187536: {"Unified_Ideograph", "Ideographic"},
    187537: {"Unified_Ideograph", "Ideographic"},
    187538: {"Unified_Ideograph", "Ideographic"},
    187539: {"Unified_Ideograph", "Ideographic"},
    187540: {"Unified_Ideograph", "Ideographic"},
    187541: {"Unified_Ideograph", "Ideographic"},
    187542: {"Unified_Ideograph", "Ideographic"},
    187543: {"Unified_Ideograph", "Ideographic"},
    187544: {"Unified_Ideograph", "Ideographic"},
    187545: {"Unified_Ideograph", "Ideographic"},
    187546: {"Unified_Ideograph", "Ideographic"},
    187547: {"Unified_Ideograph", "Ideographic"},
    187548: {"Unified_Ideograph", "Ideographic"},
    187549: {"Unified_Ideograph", "Ideographic"},
    187550: {"Unified_Ideograph", "Ideographic"},
    187551: {"Unified_Ideograph", "Ideographic"},
    187552: {"Unified_Ideograph", "Ideographic"},
    187553: {"Unified_Ideograph", "Ideographic"},
    187554: {"Unified_Ideograph", "Ideographic"},
    187555: {"Unified_Ideograph", "Ideographic"},
    187556: {"Unified_Ideograph", "Ideographic"},
    187557: {"Unified_Ideograph", "Ideographic"},
    187558: {"Unified_Ideograph", "Ideographic"},
    187559: {"Unified_Ideograph", "Ideographic"},
    187560: {"Unified_Ideograph", "Ideographic"},
    187561: {"Unified_Ideograph", "Ideographic"},
    187562: {"Unified_Ideograph", "Ideographic"},
    187563: {"Unified_Ideograph", "Ideographic"},
    187564: {"Unified_Ideograph", "Ideographic"},
    187565: {"Unified_Ideograph", "Ideographic"},
    187566: {"Unified_Ideograph", "Ideographic"},
    187567: {"Unified_Ideograph", "Ideographic"},
    187568: {"Unified_Ideograph", "Ideographic"},
    187569: {"Unified_Ideograph", "Ideographic"},
    187570: {"Unified_Ideograph", "Ideographic"},
    187571: {"Unified_Ideograph", "Ideographic"},
    187572: {"Unified_Ideograph", "Ideographic"},
    187573: {"Unified_Ideograph", "Ideographic"},
    187574: {"Unified_Ideograph", "Ideographic"},
    187575: {"Unified_Ideograph", "Ideographic"},
    187576: {"Unified_Ideograph", "Ideographic"},
    187577: {"Unified_Ideograph", "Ideographic"},
    187578: {"Unified_Ideograph", "Ideographic"},
    187579: {"Unified_Ideograph", "Ideographic"},
    187580: {"Unified_Ideograph", "Ideographic"},
    187581: {"Unified_Ideograph", "Ideographic"},
    187582: {"Unified_Ideograph", "Ideographic"},
    187583: {"Unified_Ideograph", "Ideographic"},
    187584: {"Unified_Ideograph", "Ideographic"},
    187585: {"Unified_Ideograph", "Ideographic"},
    187586: {"Unified_Ideograph", "Ideographic"},
    187587: {"Unified_Ideograph", "Ideographic"},
    187588: {"Unified_Ideograph", "Ideographic"},
    187589: {"Unified_Ideograph", "Ideographic"},
    187590: {"Unified_Ideograph", "Ideographic"},
    187591: {"Unified_Ideograph", "Ideographic"},
    187592: {"Unified_Ideograph", "Ideographic"},
    187593: {"Unified_Ideograph", "Ideographic"},
    187594: {"Unified_Ideograph", "Ideographic"},
    187595: {"Unified_Ideograph", "Ideographic"},
    187596: {"Unified_Ideograph", "Ideographic"},
    187597: {"Unified_Ideograph", "Ideographic"},
    187598: {"Unified_Ideograph", "Ideographic"},
    187599: {"Unified_Ideograph", "Ideographic"},
    187600: {"Unified_Ideograph", "Ideographic"},
    187601: {"Unified_Ideograph", "Ideographic"},
    187602: {"Unified_Ideograph", "Ideographic"},
    187603: {"Unified_Ideograph", "Ideographic"},
    187604: {"Unified_Ideograph", "Ideographic"},
    187605: {"Unified_Ideograph", "Ideographic"},
    187606: {"Unified_Ideograph", "Ideographic"},
    187607: {"Unified_Ideograph", "Ideographic"},
    187608: {"Unified_Ideograph", "Ideographic"},
    187609: {"Unified_Ideograph", "Ideographic"},
    187610: {"Unified_Ideograph", "Ideographic"},
    187611: {"Unified_Ideograph", "Ideographic"},
    187612: {"Unified_Ideograph", "Ideographic"},
    187613: {"Unified_Ideograph", "Ideographic"},
    187614: {"Unified_Ideograph", "Ideographic"},
    187615: {"Unified_Ideograph", "Ideographic"},
    187616: {"Unified_Ideograph", "Ideographic"},
    187617: {"Unified_Ideograph", "Ideographic"},
    187618: {"Unified_Ideograph", "Ideographic"},
    187619: {"Unified_Ideograph", "Ideographic"},
    187620: {"Unified_Ideograph", "Ideographic"},
    187621: {"Unified_Ideograph", "Ideographic"},
    187622: {"Unified_Ideograph", "Ideographic"},
    187623: {"Unified_Ideograph", "Ideographic"},
    187624: {"Unified_Ideograph", "Ideographic"},
    187625: {"Unified_Ideograph", "Ideographic"},
    187626: {"Unified_Ideograph", "Ideographic"},
    187627: {"Unified_Ideograph", "Ideographic"},
    187628: {"Unified_Ideograph", "Ideographic"},
    187629: {"Unified_Ideograph", "Ideographic"},
    187630: {"Unified_Ideograph", "Ideographic"},
    187631: {"Unified_Ideograph", "Ideographic"},
    187632: {"Unified_Ideograph", "Ideographic"},
    187633: {"Unified_Ideograph", "Ideographic"},
    187634: {"Unified_Ideograph", "Ideographic"},
    187635: {"Unified_Ideograph", "Ideographic"},
    187636: {"Unified_Ideograph", "Ideographic"},
    187637: {"Unified_Ideograph", "Ideographic"},
    187638: {"Unified_Ideograph", "Ideographic"},
    187639: {"Unified_Ideograph", "Ideographic"},
    187640: {"Unified_Ideograph", "Ideographic"},
    187641: {"Unified_Ideograph", "Ideographic"},
    187642: {"Unified_Ideograph", "Ideographic"},
    187643: {"Unified_Ideograph", "Ideographic"},
    187644: {"Unified_Ideograph", "Ideographic"},
    187645: {"Unified_Ideograph", "Ideographic"},
    187646: {"Unified_Ideograph", "Ideographic"},
    187647: {"Unified_Ideograph", "Ideographic"},
    187648: {"Unified_Ideograph", "Ideographic"},
    187649: {"Unified_Ideograph", "Ideographic"},
    187650: {"Unified_Ideograph", "Ideographic"},
    187651: {"Unified_Ideograph", "Ideographic"},
    187652: {"Unified_Ideograph", "Ideographic"},
    187653: {"Unified_Ideograph", "Ideographic"},
    187654: {"Unified_Ideograph", "Ideographic"},
    187655: {"Unified_Ideograph", "Ideographic"},
    187656: {"Unified_Ideograph", "Ideographic"},
    187657: {"Unified_Ideograph", "Ideographic"},
    187658: {"Unified_Ideograph", "Ideographic"},
    187659: {"Unified_Ideograph", "Ideographic"},
    187660: {"Unified_Ideograph", "Ideographic"},
    187661: {"Unified_Ideograph", "Ideographic"},
    187662: {"Unified_Ideograph", "Ideographic"},
    187663: {"Unified_Ideograph", "Ideographic"},
    187664: {"Unified_Ideograph", "Ideographic"},
    187665: {"Unified_Ideograph", "Ideographic"},
    187666: {"Unified_Ideograph", "Ideographic"},
    187667: {"Unified_Ideograph", "Ideographic"},
    187668: {"Unified_Ideograph", "Ideographic"},
    187669: {"Unified_Ideograph", "Ideographic"},
    187670: {"Unified_Ideograph", "Ideographic"},
    187671: {"Unified_Ideograph", "Ideographic"},
    187672: {"Unified_Ideograph", "Ideographic"},
    187673: {"Unified_Ideograph", "Ideographic"},
    187674: {"Unified_Ideograph", "Ideographic"},
    187675: {"Unified_Ideograph", "Ideographic"},
    187676: {"Unified_Ideograph", "Ideographic"},
    187677: {"Unified_Ideograph", "Ideographic"},
    187678: {"Unified_Ideograph", "Ideographic"},
    187679: {"Unified_Ideograph", "Ideographic"},
    187680: {"Unified_Ideograph", "Ideographic"},
    187681: {"Unified_Ideograph", "Ideographic"},
    187682: {"Unified_Ideograph", "Ideographic"},
    187683: {"Unified_Ideograph", "Ideographic"},
    187684: {"Unified_Ideograph", "Ideographic"},
    187685: {"Unified_Ideograph", "Ideographic"},
    187686: {"Unified_Ideograph", "Ideographic"},
    187687: {"Unified_Ideograph", "Ideographic"},
    187688: {"Unified_Ideograph", "Ideographic"},
    187689: {"Unified_Ideograph", "Ideographic"},
    187690: {"Unified_Ideograph", "Ideographic"},
    187691: {"Unified_Ideograph", "Ideographic"},
    187692: {"Unified_Ideograph", "Ideographic"},
    187693: {"Unified_Ideograph", "Ideographic"},
    187694: {"Unified_Ideograph", "Ideographic"},
    187695: {"Unified_Ideograph", "Ideographic"},
    187696: {"Unified_Ideograph", "Ideographic"},
    187697: {"Unified_Ideograph", "Ideographic"},
    187698: {"Unified_Ideograph", "Ideographic"},
    187699: {"Unified_Ideograph", "Ideographic"},
    187700: {"Unified_Ideograph", "Ideographic"},
    187701: {"Unified_Ideograph", "Ideographic"},
    187702: {"Unified_Ideograph", "Ideographic"},
    187703: {"Unified_Ideograph", "Ideographic"},
    187704: {"Unified_Ideograph", "Ideographic"},
    187705: {"Unified_Ideograph", "Ideographic"},
    187706: {"Unified_Ideograph", "Ideographic"},
    187707: {"Unified_Ideograph", "Ideographic"},
    187708: {"Unified_Ideograph", "Ideographic"},
    187709: {"Unified_Ideograph", "Ideographic"},
    187710: {"Unified_Ideograph", "Ideographic"},
    187711: {"Unified_Ideograph", "Ideographic"},
    187712: {"Unified_Ideograph", "Ideographic"},
    187713: {"Unified_Ideograph", "Ideographic"},
    187714: {"Unified_Ideograph", "Ideographic"},
    187715: {"Unified_Ideograph", "Ideographic"},
    187716: {"Unified_Ideograph", "Ideographic"},
    187717: {"Unified_Ideograph", "Ideographic"},
    187718: {"Unified_Ideograph", "Ideographic"},
    187719: {"Unified_Ideograph", "Ideographic"},
    187720: {"Unified_Ideograph", "Ideographic"},
    187721: {"Unified_Ideograph", "Ideographic"},
    187722: {"Unified_Ideograph", "Ideographic"},
    187723: {"Unified_Ideograph", "Ideographic"},
    187724: {"Unified_Ideograph", "Ideographic"},
    187725: {"Unified_Ideograph", "Ideographic"},
    187726: {"Unified_Ideograph", "Ideographic"},
    187727: {"Unified_Ideograph", "Ideographic"},
    187728: {"Unified_Ideograph", "Ideographic"},
    187729: {"Unified_Ideograph", "Ideographic"},
    187730: {"Unified_Ideograph", "Ideographic"},
    187731: {"Unified_Ideograph", "Ideographic"},
    187732: {"Unified_Ideograph", "Ideographic"},
    187733: {"Unified_Ideograph", "Ideographic"},
    187734: {"Unified_Ideograph", "Ideographic"},
    187735: {"Unified_Ideograph", "Ideographic"},
    187736: {"Unified_Ideograph", "Ideographic"},
    187737: {"Unified_Ideograph", "Ideographic"},
    187738: {"Unified_Ideograph", "Ideographic"},
    187739: {"Unified_Ideograph", "Ideographic"},
    187740: {"Unified_Ideograph", "Ideographic"},
    187741: {"Unified_Ideograph", "Ideographic"},
    187742: {"Unified_Ideograph", "Ideographic"},
    187743: {"Unified_Ideograph", "Ideographic"},
    187744: {"Unified_Ideograph", "Ideographic"},
    187745: {"Unified_Ideograph", "Ideographic"},
    187746: {"Unified_Ideograph", "Ideographic"},
    187747: {"Unified_Ideograph", "Ideographic"},
    187748: {"Unified_Ideograph", "Ideographic"},
    187749: {"Unified_Ideograph", "Ideographic"},
    187750: {"Unified_Ideograph", "Ideographic"},
    187751: {"Unified_Ideograph", "Ideographic"},
    187752: {"Unified_Ideograph", "Ideographic"},
    187753: {"Unified_Ideograph", "Ideographic"},
    187754: {"Unified_Ideograph", "Ideographic"},
    187755: {"Unified_Ideograph", "Ideographic"},
    187756: {"Unified_Ideograph", "Ideographic"},
    187757: {"Unified_Ideograph", "Ideographic"},
    187758: {"Unified_Ideograph", "Ideographic"},
    187759: {"Unified_Ideograph", "Ideographic"},
    187760: {"Unified_Ideograph", "Ideographic"},
    187761: {"Unified_Ideograph", "Ideographic"},
    187762: {"Unified_Ideograph", "Ideographic"},
    187763: {"Unified_Ideograph", "Ideographic"},
    187764: {"Unified_Ideograph", "Ideographic"},
    187765: {"Unified_Ideograph", "Ideographic"},
    187766: {"Unified_Ideograph", "Ideographic"},
    187767: {"Unified_Ideograph", "Ideographic"},
    187768: {"Unified_Ideograph", "Ideographic"},
    187769: {"Unified_Ideograph", "Ideographic"},
    187770: {"Unified_Ideograph", "Ideographic"},
    187771: {"Unified_Ideograph", "Ideographic"},
    187772: {"Unified_Ideograph", "Ideographic"},
    187773: {"Unified_Ideograph", "Ideographic"},
    187774: {"Unified_Ideograph", "Ideographic"},
    187775: {"Unified_Ideograph", "Ideographic"},
    187776: {"Unified_Ideograph", "Ideographic"},
    187777: {"Unified_Ideograph", "Ideographic"},
    187778: {"Unified_Ideograph", "Ideographic"},
    187779: {"Unified_Ideograph", "Ideographic"},
    187780: {"Unified_Ideograph", "Ideographic"},
    187781: {"Unified_Ideograph", "Ideographic"},
    187782: {"Unified_Ideograph", "Ideographic"},
    187783: {"Unified_Ideograph", "Ideographic"},
    187784: {"Unified_Ideograph", "Ideographic"},
    187785: {"Unified_Ideograph", "Ideographic"},
    187786: {"Unified_Ideograph", "Ideographic"},
    187787: {"Unified_Ideograph", "Ideographic"},
    187788: {"Unified_Ideograph", "Ideographic"},
    187789: {"Unified_Ideograph", "Ideographic"},
    187790: {"Unified_Ideograph", "Ideographic"},
    187791: {"Unified_Ideograph", "Ideographic"},
    187792: {"Unified_Ideograph", "Ideographic"},
    187793: {"Unified_Ideograph", "Ideographic"},
    187794: {"Unified_Ideograph", "Ideographic"},
    187795: {"Unified_Ideograph", "Ideographic"},
    187796: {"Unified_Ideograph", "Ideographic"},
    187797: {"Unified_Ideograph", "Ideographic"},
    187798: {"Unified_Ideograph", "Ideographic"},
    187799: {"Unified_Ideograph", "Ideographic"},
    187800: {"Unified_Ideograph", "Ideographic"},
    187801: {"Unified_Ideograph", "Ideographic"},
    187802: {"Unified_Ideograph", "Ideographic"},
    187803: {"Unified_Ideograph", "Ideographic"},
    187804: {"Unified_Ideograph", "Ideographic"},
    187805: {"Unified_Ideograph", "Ideographic"},
    187806: {"Unified_Ideograph", "Ideographic"},
    187807: {"Unified_Ideograph", "Ideographic"},
    187808: {"Unified_Ideograph", "Ideographic"},
    187809: {"Unified_Ideograph", "Ideographic"},
    187810: {"Unified_Ideograph", "Ideographic"},
    187811: {"Unified_Ideograph", "Ideographic"},
    187812: {"Unified_Ideograph", "Ideographic"},
    187813: {"Unified_Ideograph", "Ideographic"},
    187814: {"Unified_Ideograph", "Ideographic"},
    187815: {"Unified_Ideograph", "Ideographic"},
    187816: {"Unified_Ideograph", "Ideographic"},
    187817: {"Unified_Ideograph", "Ideographic"},
    187818: {"Unified_Ideograph", "Ideographic"},
    187819: {"Unified_Ideograph", "Ideographic"},
    187820: {"Unified_Ideograph", "Ideographic"},
    187821: {"Unified_Ideograph", "Ideographic"},
    187822: {"Unified_Ideograph", "Ideographic"},
    187823: {"Unified_Ideograph", "Ideographic"},
    187824: {"Unified_Ideograph", "Ideographic"},
    187825: {"Unified_Ideograph", "Ideographic"},
    187826: {"Unified_Ideograph", "Ideographic"},
    187827: {"Unified_Ideograph", "Ideographic"},
    187828: {"Unified_Ideograph", "Ideographic"},
    187829: {"Unified_Ideograph", "Ideographic"},
    187830: {"Unified_Ideograph", "Ideographic"},
    187831: {"Unified_Ideograph", "Ideographic"},
    187832: {"Unified_Ideograph", "Ideographic"},
    187833: {"Unified_Ideograph", "Ideographic"},
    187834: {"Unified_Ideograph", "Ideographic"},
    187835: {"Unified_Ideograph", "Ideographic"},
    187836: {"Unified_Ideograph", "Ideographic"},
    187837: {"Unified_Ideograph", "Ideographic"},
    187838: {"Unified_Ideograph", "Ideographic"},
    187839: {"Unified_Ideograph", "Ideographic"},
    187840: {"Unified_Ideograph", "Ideographic"},
    187841: {"Unified_Ideograph", "Ideographic"},
    187842: {"Unified_Ideograph", "Ideographic"},
    187843: {"Unified_Ideograph", "Ideographic"},
    187844: {"Unified_Ideograph", "Ideographic"},
    187845: {"Unified_Ideograph", "Ideographic"},
    187846: {"Unified_Ideograph", "Ideographic"},
    187847: {"Unified_Ideograph", "Ideographic"},
    187848: {"Unified_Ideograph", "Ideographic"},
    187849: {"Unified_Ideograph", "Ideographic"},
    187850: {"Unified_Ideograph", "Ideographic"},
    187851: {"Unified_Ideograph", "Ideographic"},
    187852: {"Unified_Ideograph", "Ideographic"},
    187853: {"Unified_Ideograph", "Ideographic"},
    187854: {"Unified_Ideograph", "Ideographic"},
    187855: {"Unified_Ideograph", "Ideographic"},
    187856: {"Unified_Ideograph", "Ideographic"},
    187857: {"Unified_Ideograph", "Ideographic"},
    187858: {"Unified_Ideograph", "Ideographic"},
    187859: {"Unified_Ideograph", "Ideographic"},
    187860: {"Unified_Ideograph", "Ideographic"},
    187861: {"Unified_Ideograph", "Ideographic"},
    187862: {"Unified_Ideograph", "Ideographic"},
    187863: {"Unified_Ideograph", "Ideographic"},
    187864: {"Unified_Ideograph", "Ideographic"},
    187865: {"Unified_Ideograph", "Ideographic"},
    187866: {"Unified_Ideograph", "Ideographic"},
    187867: {"Unified_Ideograph", "Ideographic"},
    187868: {"Unified_Ideograph", "Ideographic"},
    187869: {"Unified_Ideograph", "Ideographic"},
    187870: {"Unified_Ideograph", "Ideographic"},
    187871: {"Unified_Ideograph", "Ideographic"},
    187872: {"Unified_Ideograph", "Ideographic"},
    187873: {"Unified_Ideograph", "Ideographic"},
    187874: {"Unified_Ideograph", "Ideographic"},
    187875: {"Unified_Ideograph", "Ideographic"},
    187876: {"Unified_Ideograph", "Ideographic"},
    187877: {"Unified_Ideograph", "Ideographic"},
    187878: {"Unified_Ideograph", "Ideographic"},
    187879: {"Unified_Ideograph", "Ideographic"},
    187880: {"Unified_Ideograph", "Ideographic"},
    187881: {"Unified_Ideograph", "Ideographic"},
    187882: {"Unified_Ideograph", "Ideographic"},
    187883: {"Unified_Ideograph", "Ideographic"},
    187884: {"Unified_Ideograph", "Ideographic"},
    187885: {"Unified_Ideograph", "Ideographic"},
    187886: {"Unified_Ideograph", "Ideographic"},
    187887: {"Unified_Ideograph", "Ideographic"},
    187888: {"Unified_Ideograph", "Ideographic"},
    187889: {"Unified_Ideograph", "Ideographic"},
    187890: {"Unified_Ideograph", "Ideographic"},
    187891: {"Unified_Ideograph", "Ideographic"},
    187892: {"Unified_Ideograph", "Ideographic"},
    187893: {"Unified_Ideograph", "Ideographic"},
    187894: {"Unified_Ideograph", "Ideographic"},
    187895: {"Unified_Ideograph", "Ideographic"},
    187896: {"Unified_Ideograph", "Ideographic"},
    187897: {"Unified_Ideograph", "Ideographic"},
    187898: {"Unified_Ideograph", "Ideographic"},
    187899: {"Unified_Ideograph", "Ideographic"},
    187900: {"Unified_Ideograph", "Ideographic"},
    187901: {"Unified_Ideograph", "Ideographic"},
    187902: {"Unified_Ideograph", "Ideographic"},
    187903: {"Unified_Ideograph", "Ideographic"},
    187904: {"Unified_Ideograph", "Ideographic"},
    187905: {"Unified_Ideograph", "Ideographic"},
    187906: {"Unified_Ideograph", "Ideographic"},
    187907: {"Unified_Ideograph", "Ideographic"},
    187908: {"Unified_Ideograph", "Ideographic"},
    187909: {"Unified_Ideograph", "Ideographic"},
    187910: {"Unified_Ideograph", "Ideographic"},
    187911: {"Unified_Ideograph", "Ideographic"},
    187912: {"Unified_Ideograph", "Ideographic"},
    187913: {"Unified_Ideograph", "Ideographic"},
    187914: {"Unified_Ideograph", "Ideographic"},
    187915: {"Unified_Ideograph", "Ideographic"},
    187916: {"Unified_Ideograph", "Ideographic"},
    187917: {"Unified_Ideograph", "Ideographic"},
    187918: {"Unified_Ideograph", "Ideographic"},
    187919: {"Unified_Ideograph", "Ideographic"},
    187920: {"Unified_Ideograph", "Ideographic"},
    187921: {"Unified_Ideograph", "Ideographic"},
    187922: {"Unified_Ideograph", "Ideographic"},
    187923: {"Unified_Ideograph", "Ideographic"},
    187924: {"Unified_Ideograph", "Ideographic"},
    187925: {"Unified_Ideograph", "Ideographic"},
    187926: {"Unified_Ideograph", "Ideographic"},
    187927: {"Unified_Ideograph", "Ideographic"},
    187928: {"Unified_Ideograph", "Ideographic"},
    187929: {"Unified_Ideograph", "Ideographic"},
    187930: {"Unified_Ideograph", "Ideographic"},
    187931: {"Unified_Ideograph", "Ideographic"},
    187932: {"Unified_Ideograph", "Ideographic"},
    187933: {"Unified_Ideograph", "Ideographic"},
    187934: {"Unified_Ideograph", "Ideographic"},
    187935: {"Unified_Ideograph", "Ideographic"},
    187936: {"Unified_Ideograph", "Ideographic"},
    187937: {"Unified_Ideograph", "Ideographic"},
    187938: {"Unified_Ideograph", "Ideographic"},
    187939: {"Unified_Ideograph", "Ideographic"},
    187940: {"Unified_Ideograph", "Ideographic"},
    187941: {"Unified_Ideograph", "Ideographic"},
    187942: {"Unified_Ideograph", "Ideographic"},
    187943: {"Unified_Ideograph", "Ideographic"},
    187944: {"Unified_Ideograph", "Ideographic"},
    187945: {"Unified_Ideograph", "Ideographic"},
    187946: {"Unified_Ideograph", "Ideographic"},
    187947: {"Unified_Ideograph", "Ideographic"},
    187948: {"Unified_Ideograph", "Ideographic"},
    187949: {"Unified_Ideograph", "Ideographic"},
    187950: {"Unified_Ideograph", "Ideographic"},
    187951: {"Unified_Ideograph", "Ideographic"},
    187952: {"Unified_Ideograph", "Ideographic"},
    187953: {"Unified_Ideograph", "Ideographic"},
    187954: {"Unified_Ideograph", "Ideographic"},
    187955: {"Unified_Ideograph", "Ideographic"},
    187956: {"Unified_Ideograph", "Ideographic"},
    187957: {"Unified_Ideograph", "Ideographic"},
    187958: {"Unified_Ideograph", "Ideographic"},
    187959: {"Unified_Ideograph", "Ideographic"},
    187960: {"Unified_Ideograph", "Ideographic"},
    187961: {"Unified_Ideograph", "Ideographic"},
    187962: {"Unified_Ideograph", "Ideographic"},
    187963: {"Unified_Ideograph", "Ideographic"},
    187964: {"Unified_Ideograph", "Ideographic"},
    187965: {"Unified_Ideograph", "Ideographic"},
    187966: {"Unified_Ideograph", "Ideographic"},
    187967: {"Unified_Ideograph", "Ideographic"},
    187968: {"Unified_Ideograph", "Ideographic"},
    187969: {"Unified_Ideograph", "Ideographic"},
    187970: {"Unified_Ideograph", "Ideographic"},
    187971: {"Unified_Ideograph", "Ideographic"},
    187972: {"Unified_Ideograph", "Ideographic"},
    187973: {"Unified_Ideograph", "Ideographic"},
    187974: {"Unified_Ideograph", "Ideographic"},
    187975: {"Unified_Ideograph", "Ideographic"},
    187976: {"Unified_Ideograph", "Ideographic"},
    187977: {"Unified_Ideograph", "Ideographic"},
    187978: {"Unified_Ideograph", "Ideographic"},
    187979: {"Unified_Ideograph", "Ideographic"},
    187980: {"Unified_Ideograph", "Ideographic"},
    187981: {"Unified_Ideograph", "Ideographic"},
    187982: {"Unified_Ideograph", "Ideographic"},
    187983: {"Unified_Ideograph", "Ideographic"},
    187984: {"Unified_Ideograph", "Ideographic"},
    187985: {"Unified_Ideograph", "Ideographic"},
    187986: {"Unified_Ideograph", "Ideographic"},
    187987: {"Unified_Ideograph", "Ideographic"},
    187988: {"Unified_Ideograph", "Ideographic"},
    187989: {"Unified_Ideograph", "Ideographic"},
    187990: {"Unified_Ideograph", "Ideographic"},
    187991: {"Unified_Ideograph", "Ideographic"},
    187992: {"Unified_Ideograph", "Ideographic"},
    187993: {"Unified_Ideograph", "Ideographic"},
    187994: {"Unified_Ideograph", "Ideographic"},
    187995: {"Unified_Ideograph", "Ideographic"},
    187996: {"Unified_Ideograph", "Ideographic"},
    187997: {"Unified_Ideograph", "Ideographic"},
    187998: {"Unified_Ideograph", "Ideographic"},
    187999: {"Unified_Ideograph", "Ideographic"},
    188000: {"Unified_Ideograph", "Ideographic"},
    188001: {"Unified_Ideograph", "Ideographic"},
    188002: {"Unified_Ideograph", "Ideographic"},
    188003: {"Unified_Ideograph", "Ideographic"},
    188004: {"Unified_Ideograph", "Ideographic"},
    188005: {"Unified_Ideograph", "Ideographic"},
    188006: {"Unified_Ideograph", "Ideographic"},
    188007: {"Unified_Ideograph", "Ideographic"},
    188008: {"Unified_Ideograph", "Ideographic"},
    188009: {"Unified_Ideograph", "Ideographic"},
    188010: {"Unified_Ideograph", "Ideographic"},
    188011: {"Unified_Ideograph", "Ideographic"},
    188012: {"Unified_Ideograph", "Ideographic"},
    188013: {"Unified_Ideograph", "Ideographic"},
    188014: {"Unified_Ideograph", "Ideographic"},
    188015: {"Unified_Ideograph", "Ideographic"},
    188016: {"Unified_Ideograph", "Ideographic"},
    188017: {"Unified_Ideograph", "Ideographic"},
    188018: {"Unified_Ideograph", "Ideographic"},
    188019: {"Unified_Ideograph", "Ideographic"},
    188020: {"Unified_Ideograph", "Ideographic"},
    188021: {"Unified_Ideograph", "Ideographic"},
    188022: {"Unified_Ideograph", "Ideographic"},
    188023: {"Unified_Ideograph", "Ideographic"},
    188024: {"Unified_Ideograph", "Ideographic"},
    188025: {"Unified_Ideograph", "Ideographic"},
    188026: {"Unified_Ideograph", "Ideographic"},
    188027: {"Unified_Ideograph", "Ideographic"},
    188028: {"Unified_Ideograph", "Ideographic"},
    188029: {"Unified_Ideograph", "Ideographic"},
    188030: {"Unified_Ideograph", "Ideographic"},
    188031: {"Unified_Ideograph", "Ideographic"},
    188032: {"Unified_Ideograph", "Ideographic"},
    188033: {"Unified_Ideograph", "Ideographic"},
    188034: {"Unified_Ideograph", "Ideographic"},
    188035: {"Unified_Ideograph", "Ideographic"},
    188036: {"Unified_Ideograph", "Ideographic"},
    188037: {"Unified_Ideograph", "Ideographic"},
    188038: {"Unified_Ideograph", "Ideographic"},
    188039: {"Unified_Ideograph", "Ideographic"},
    188040: {"Unified_Ideograph", "Ideographic"},
    188041: {"Unified_Ideograph", "Ideographic"},
    188042: {"Unified_Ideograph", "Ideographic"},
    188043: {"Unified_Ideograph", "Ideographic"},
    188044: {"Unified_Ideograph", "Ideographic"},
    188045: {"Unified_Ideograph", "Ideographic"},
    188046: {"Unified_Ideograph", "Ideographic"},
    188047: {"Unified_Ideograph", "Ideographic"},
    188048: {"Unified_Ideograph", "Ideographic"},
    188049: {"Unified_Ideograph", "Ideographic"},
    188050: {"Unified_Ideograph", "Ideographic"},
    188051: {"Unified_Ideograph", "Ideographic"},
    188052: {"Unified_Ideograph", "Ideographic"},
    188053: {"Unified_Ideograph", "Ideographic"},
    188054: {"Unified_Ideograph", "Ideographic"},
    188055: {"Unified_Ideograph", "Ideographic"},
    188056: {"Unified_Ideograph", "Ideographic"},
    188057: {"Unified_Ideograph", "Ideographic"},
    188058: {"Unified_Ideograph", "Ideographic"},
    188059: {"Unified_Ideograph", "Ideographic"},
    188060: {"Unified_Ideograph", "Ideographic"},
    188061: {"Unified_Ideograph", "Ideographic"},
    188062: {"Unified_Ideograph", "Ideographic"},
    188063: {"Unified_Ideograph", "Ideographic"},
    188064: {"Unified_Ideograph", "Ideographic"},
    188065: {"Unified_Ideograph", "Ideographic"},
    188066: {"Unified_Ideograph", "Ideographic"},
    188067: {"Unified_Ideograph", "Ideographic"},
    188068: {"Unified_Ideograph", "Ideographic"},
    188069: {"Unified_Ideograph", "Ideographic"},
    188070: {"Unified_Ideograph", "Ideographic"},
    188071: {"Unified_Ideograph", "Ideographic"},
    188072: {"Unified_Ideograph", "Ideographic"},
    188073: {"Unified_Ideograph", "Ideographic"},
    188074: {"Unified_Ideograph", "Ideographic"},
    188075: {"Unified_Ideograph", "Ideographic"},
    188076: {"Unified_Ideograph", "Ideographic"},
    188077: {"Unified_Ideograph", "Ideographic"},
    188078: {"Unified_Ideograph", "Ideographic"},
    188079: {"Unified_Ideograph", "Ideographic"},
    188080: {"Unified_Ideograph", "Ideographic"},
    188081: {"Unified_Ideograph", "Ideographic"},
    188082: {"Unified_Ideograph", "Ideographic"},
    188083: {"Unified_Ideograph", "Ideographic"},
    188084: {"Unified_Ideograph", "Ideographic"},
    188085: {"Unified_Ideograph", "Ideographic"},
    188086: {"Unified_Ideograph", "Ideographic"},
    188087: {"Unified_Ideograph", "Ideographic"},
    188088: {"Unified_Ideograph", "Ideographic"},
    188089: {"Unified_Ideograph", "Ideographic"},
    188090: {"Unified_Ideograph", "Ideographic"},
    188091: {"Unified_Ideograph", "Ideographic"},
    188092: {"Unified_Ideograph", "Ideographic"},
    188093: {"Unified_Ideograph", "Ideographic"},
    188094: {"Unified_Ideograph", "Ideographic"},
    188095: {"Unified_Ideograph", "Ideographic"},
    188096: {"Unified_Ideograph", "Ideographic"},
    188097: {"Unified_Ideograph", "Ideographic"},
    188098: {"Unified_Ideograph", "Ideographic"},
    188099: {"Unified_Ideograph", "Ideographic"},
    188100: {"Unified_Ideograph", "Ideographic"},
    188101: {"Unified_Ideograph", "Ideographic"},
    188102: {"Unified_Ideograph", "Ideographic"},
    188103: {"Unified_Ideograph", "Ideographic"},
    188104: {"Unified_Ideograph", "Ideographic"},
    188105: {"Unified_Ideograph", "Ideographic"},
    188106: {"Unified_Ideograph", "Ideographic"},
    188107: {"Unified_Ideograph", "Ideographic"},
    188108: {"Unified_Ideograph", "Ideographic"},
    188109: {"Unified_Ideograph", "Ideographic"},
    188110: {"Unified_Ideograph", "Ideographic"},
    188111: {"Unified_Ideograph", "Ideographic"},
    188112: {"Unified_Ideograph", "Ideographic"},
    188113: {"Unified_Ideograph", "Ideographic"},
    188114: {"Unified_Ideograph", "Ideographic"},
    188115: {"Unified_Ideograph", "Ideographic"},
    188116: {"Unified_Ideograph", "Ideographic"},
    188117: {"Unified_Ideograph", "Ideographic"},
    188118: {"Unified_Ideograph", "Ideographic"},
    188119: {"Unified_Ideograph", "Ideographic"},
    188120: {"Unified_Ideograph", "Ideographic"},
    188121: {"Unified_Ideograph", "Ideographic"},
    188122: {"Unified_Ideograph", "Ideographic"},
    188123: {"Unified_Ideograph", "Ideographic"},
    188124: {"Unified_Ideograph", "Ideographic"},
    188125: {"Unified_Ideograph", "Ideographic"},
    188126: {"Unified_Ideograph", "Ideographic"},
    188127: {"Unified_Ideograph", "Ideographic"},
    188128: {"Unified_Ideograph", "Ideographic"},
    188129: {"Unified_Ideograph", "Ideographic"},
    188130: {"Unified_Ideograph", "Ideographic"},
    188131: {"Unified_Ideograph", "Ideographic"},
    188132: {"Unified_Ideograph", "Ideographic"},
    188133: {"Unified_Ideograph", "Ideographic"},
    188134: {"Unified_Ideograph", "Ideographic"},
    188135: {"Unified_Ideograph", "Ideographic"},
    188136: {"Unified_Ideograph", "Ideographic"},
    188137: {"Unified_Ideograph", "Ideographic"},
    188138: {"Unified_Ideograph", "Ideographic"},
    188139: {"Unified_Ideograph", "Ideographic"},
    188140: {"Unified_Ideograph", "Ideographic"},
    188141: {"Unified_Ideograph", "Ideographic"},
    188142: {"Unified_Ideograph", "Ideographic"},
    188143: {"Unified_Ideograph", "Ideographic"},
    188144: {"Unified_Ideograph", "Ideographic"},
    188145: {"Unified_Ideograph", "Ideographic"},
    188146: {"Unified_Ideograph", "Ideographic"},
    188147: {"Unified_Ideograph", "Ideographic"},
    188148: {"Unified_Ideograph", "Ideographic"},
    188149: {"Unified_Ideograph", "Ideographic"},
    188150: {"Unified_Ideograph", "Ideographic"},
    188151: {"Unified_Ideograph", "Ideographic"},
    188152: {"Unified_Ideograph", "Ideographic"},
    188153: {"Unified_Ideograph", "Ideographic"},
    188154: {"Unified_Ideograph", "Ideographic"},
    188155: {"Unified_Ideograph", "Ideographic"},
    188156: {"Unified_Ideograph", "Ideographic"},
    188157: {"Unified_Ideograph", "Ideographic"},
    188158: {"Unified_Ideograph", "Ideographic"},
    188159: {"Unified_Ideograph", "Ideographic"},
    188160: {"Unified_Ideograph", "Ideographic"},
    188161: {"Unified_Ideograph", "Ideographic"},
    188162: {"Unified_Ideograph", "Ideographic"},
    188163: {"Unified_Ideograph", "Ideographic"},
    188164: {"Unified_Ideograph", "Ideographic"},
    188165: {"Unified_Ideograph", "Ideographic"},
    188166: {"Unified_Ideograph", "Ideographic"},
    188167: {"Unified_Ideograph", "Ideographic"},
    188168: {"Unified_Ideograph", "Ideographic"},
    188169: {"Unified_Ideograph", "Ideographic"},
    188170: {"Unified_Ideograph", "Ideographic"},
    188171: {"Unified_Ideograph", "Ideographic"},
    188172: {"Unified_Ideograph", "Ideographic"},
    188173: {"Unified_Ideograph", "Ideographic"},
    188174: {"Unified_Ideograph", "Ideographic"},
    188175: {"Unified_Ideograph", "Ideographic"},
    188176: {"Unified_Ideograph", "Ideographic"},
    188177: {"Unified_Ideograph", "Ideographic"},
    188178: {"Unified_Ideograph", "Ideographic"},
    188179: {"Unified_Ideograph", "Ideographic"},
    188180: {"Unified_Ideograph", "Ideographic"},
    188181: {"Unified_Ideograph", "Ideographic"},
    188182: {"Unified_Ideograph", "Ideographic"},
    188183: {"Unified_Ideograph", "Ideographic"},
    188184: {"Unified_Ideograph", "Ideographic"},
    188185: {"Unified_Ideograph", "Ideographic"},
    188186: {"Unified_Ideograph", "Ideographic"},
    188187: {"Unified_Ideograph", "Ideographic"},
    188188: {"Unified_Ideograph", "Ideographic"},
    188189: {"Unified_Ideograph", "Ideographic"},
    188190: {"Unified_Ideograph", "Ideographic"},
    188191: {"Unified_Ideograph", "Ideographic"},
    188192: {"Unified_Ideograph", "Ideographic"},
    188193: {"Unified_Ideograph", "Ideographic"},
    188194: {"Unified_Ideograph", "Ideographic"},
    188195: {"Unified_Ideograph", "Ideographic"},
    188196: {"Unified_Ideograph", "Ideographic"},
    188197: {"Unified_Ideograph", "Ideographic"},
    188198: {"Unified_Ideograph", "Ideographic"},
    188199: {"Unified_Ideograph", "Ideographic"},
    188200: {"Unified_Ideograph", "Ideographic"},
    188201: {"Unified_Ideograph", "Ideographic"},
    188202: {"Unified_Ideograph", "Ideographic"},
    188203: {"Unified_Ideograph", "Ideographic"},
    188204: {"Unified_Ideograph", "Ideographic"},
    188205: {"Unified_Ideograph", "Ideographic"},
    188206: {"Unified_Ideograph", "Ideographic"},
    188207: {"Unified_Ideograph", "Ideographic"},
    188208: {"Unified_Ideograph", "Ideographic"},
    188209: {"Unified_Ideograph", "Ideographic"},
    188210: {"Unified_Ideograph", "Ideographic"},
    188211: {"Unified_Ideograph", "Ideographic"},
    188212: {"Unified_Ideograph", "Ideographic"},
    188213: {"Unified_Ideograph", "Ideographic"},
    188214: {"Unified_Ideograph", "Ideographic"},
    188215: {"Unified_Ideograph", "Ideographic"},
    188216: {"Unified_Ideograph", "Ideographic"},
    188217: {"Unified_Ideograph", "Ideographic"},
    188218: {"Unified_Ideograph", "Ideographic"},
    188219: {"Unified_Ideograph", "Ideographic"},
    188220: {"Unified_Ideograph", "Ideographic"},
    188221: {"Unified_Ideograph", "Ideographic"},
    188222: {"Unified_Ideograph", "Ideographic"},
    188223: {"Unified_Ideograph", "Ideographic"},
    188224: {"Unified_Ideograph", "Ideographic"},
    188225: {"Unified_Ideograph", "Ideographic"},
    188226: {"Unified_Ideograph", "Ideographic"},
    188227: {"Unified_Ideograph", "Ideographic"},
    188228: {"Unified_Ideograph", "Ideographic"},
    188229: {"Unified_Ideograph", "Ideographic"},
    188230: {"Unified_Ideograph", "Ideographic"},
    188231: {"Unified_Ideograph", "Ideographic"},
    188232: {"Unified_Ideograph", "Ideographic"},
    188233: {"Unified_Ideograph", "Ideographic"},
    188234: {"Unified_Ideograph", "Ideographic"},
    188235: {"Unified_Ideograph", "Ideographic"},
    188236: {"Unified_Ideograph", "Ideographic"},
    188237: {"Unified_Ideograph", "Ideographic"},
    188238: {"Unified_Ideograph", "Ideographic"},
    188239: {"Unified_Ideograph", "Ideographic"},
    188240: {"Unified_Ideograph", "Ideographic"},
    188241: {"Unified_Ideograph", "Ideographic"},
    188242: {"Unified_Ideograph", "Ideographic"},
    188243: {"Unified_Ideograph", "Ideographic"},
    188244: {"Unified_Ideograph", "Ideographic"},
    188245: {"Unified_Ideograph", "Ideographic"},
    188246: {"Unified_Ideograph", "Ideographic"},
    188247: {"Unified_Ideograph", "Ideographic"},
    188248: {"Unified_Ideograph", "Ideographic"},
    188249: {"Unified_Ideograph", "Ideographic"},
    188250: {"Unified_Ideograph", "Ideographic"},
    188251: {"Unified_Ideograph", "Ideographic"},
    188252: {"Unified_Ideograph", "Ideographic"},
    188253: {"Unified_Ideograph", "Ideographic"},
    188254: {"Unified_Ideograph", "Ideographic"},
    188255: {"Unified_Ideograph", "Ideographic"},
    188256: {"Unified_Ideograph", "Ideographic"},
    188257: {"Unified_Ideograph", "Ideographic"},
    188258: {"Unified_Ideograph", "Ideographic"},
    188259: {"Unified_Ideograph", "Ideographic"},
    188260: {"Unified_Ideograph", "Ideographic"},
    188261: {"Unified_Ideograph", "Ideographic"},
    188262: {"Unified_Ideograph", "Ideographic"},
    188263: {"Unified_Ideograph", "Ideographic"},
    188264: {"Unified_Ideograph", "Ideographic"},
    188265: {"Unified_Ideograph", "Ideographic"},
    188266: {"Unified_Ideograph", "Ideographic"},
    188267: {"Unified_Ideograph", "Ideographic"},
    188268: {"Unified_Ideograph", "Ideographic"},
    188269: {"Unified_Ideograph", "Ideographic"},
    188270: {"Unified_Ideograph", "Ideographic"},
    188271: {"Unified_Ideograph", "Ideographic"},
    188272: {"Unified_Ideograph", "Ideographic"},
    188273: {"Unified_Ideograph", "Ideographic"},
    188274: {"Unified_Ideograph", "Ideographic"},
    188275: {"Unified_Ideograph", "Ideographic"},
    188276: {"Unified_Ideograph", "Ideographic"},
    188277: {"Unified_Ideograph", "Ideographic"},
    188278: {"Unified_Ideograph", "Ideographic"},
    188279: {"Unified_Ideograph", "Ideographic"},
    188280: {"Unified_Ideograph", "Ideographic"},
    188281: {"Unified_Ideograph", "Ideographic"},
    188282: {"Unified_Ideograph", "Ideographic"},
    188283: {"Unified_Ideograph", "Ideographic"},
    188284: {"Unified_Ideograph", "Ideographic"},
    188285: {"Unified_Ideograph", "Ideographic"},
    188286: {"Unified_Ideograph", "Ideographic"},
    188287: {"Unified_Ideograph", "Ideographic"},
    188288: {"Unified_Ideograph", "Ideographic"},
    188289: {"Unified_Ideograph", "Ideographic"},
    188290: {"Unified_Ideograph", "Ideographic"},
    188291: {"Unified_Ideograph", "Ideographic"},
    188292: {"Unified_Ideograph", "Ideographic"},
    188293: {"Unified_Ideograph", "Ideographic"},
    188294: {"Unified_Ideograph", "Ideographic"},
    188295: {"Unified_Ideograph", "Ideographic"},
    188296: {"Unified_Ideograph", "Ideographic"},
    188297: {"Unified_Ideograph", "Ideographic"},
    188298: {"Unified_Ideograph", "Ideographic"},
    188299: {"Unified_Ideograph", "Ideographic"},
    188300: {"Unified_Ideograph", "Ideographic"},
    188301: {"Unified_Ideograph", "Ideographic"},
    188302: {"Unified_Ideograph", "Ideographic"},
    188303: {"Unified_Ideograph", "Ideographic"},
    188304: {"Unified_Ideograph", "Ideographic"},
    188305: {"Unified_Ideograph", "Ideographic"},
    188306: {"Unified_Ideograph", "Ideographic"},
    188307: {"Unified_Ideograph", "Ideographic"},
    188308: {"Unified_Ideograph", "Ideographic"},
    188309: {"Unified_Ideograph", "Ideographic"},
    188310: {"Unified_Ideograph", "Ideographic"},
    188311: {"Unified_Ideograph", "Ideographic"},
    188312: {"Unified_Ideograph", "Ideographic"},
    188313: {"Unified_Ideograph", "Ideographic"},
    188314: {"Unified_Ideograph", "Ideographic"},
    188315: {"Unified_Ideograph", "Ideographic"},
    188316: {"Unified_Ideograph", "Ideographic"},
    188317: {"Unified_Ideograph", "Ideographic"},
    188318: {"Unified_Ideograph", "Ideographic"},
    188319: {"Unified_Ideograph", "Ideographic"},
    188320: {"Unified_Ideograph", "Ideographic"},
    188321: {"Unified_Ideograph", "Ideographic"},
    188322: {"Unified_Ideograph", "Ideographic"},
    188323: {"Unified_Ideograph", "Ideographic"},
    188324: {"Unified_Ideograph", "Ideographic"},
    188325: {"Unified_Ideograph", "Ideographic"},
    188326: {"Unified_Ideograph", "Ideographic"},
    188327: {"Unified_Ideograph", "Ideographic"},
    188328: {"Unified_Ideograph", "Ideographic"},
    188329: {"Unified_Ideograph", "Ideographic"},
    188330: {"Unified_Ideograph", "Ideographic"},
    188331: {"Unified_Ideograph", "Ideographic"},
    188332: {"Unified_Ideograph", "Ideographic"},
    188333: {"Unified_Ideograph", "Ideographic"},
    188334: {"Unified_Ideograph", "Ideographic"},
    188335: {"Unified_Ideograph", "Ideographic"},
    188336: {"Unified_Ideograph", "Ideographic"},
    188337: {"Unified_Ideograph", "Ideographic"},
    188338: {"Unified_Ideograph", "Ideographic"},
    188339: {"Unified_Ideograph", "Ideographic"},
    188340: {"Unified_Ideograph", "Ideographic"},
    188341: {"Unified_Ideograph", "Ideographic"},
    188342: {"Unified_Ideograph", "Ideographic"},
    188343: {"Unified_Ideograph", "Ideographic"},
    188344: {"Unified_Ideograph", "Ideographic"},
    188345: {"Unified_Ideograph", "Ideographic"},
    188346: {"Unified_Ideograph", "Ideographic"},
    188347: {"Unified_Ideograph", "Ideographic"},
    188348: {"Unified_Ideograph", "Ideographic"},
    188349: {"Unified_Ideograph", "Ideographic"},
    188350: {"Unified_Ideograph", "Ideographic"},
    188351: {"Unified_Ideograph", "Ideographic"},
    188352: {"Unified_Ideograph", "Ideographic"},
    188353: {"Unified_Ideograph", "Ideographic"},
    188354: {"Unified_Ideograph", "Ideographic"},
    188355: {"Unified_Ideograph", "Ideographic"},
    188356: {"Unified_Ideograph", "Ideographic"},
    188357: {"Unified_Ideograph", "Ideographic"},
    188358: {"Unified_Ideograph", "Ideographic"},
    188359: {"Unified_Ideograph", "Ideographic"},
    188360: {"Unified_Ideograph", "Ideographic"},
    188361: {"Unified_Ideograph", "Ideographic"},
    188362: {"Unified_Ideograph", "Ideographic"},
    188363: {"Unified_Ideograph", "Ideographic"},
    188364: {"Unified_Ideograph", "Ideographic"},
    188365: {"Unified_Ideograph", "Ideographic"},
    188366: {"Unified_Ideograph", "Ideographic"},
    188367: {"Unified_Ideograph", "Ideographic"},
    188368: {"Unified_Ideograph", "Ideographic"},
    188369: {"Unified_Ideograph", "Ideographic"},
    188370: {"Unified_Ideograph", "Ideographic"},
    188371: {"Unified_Ideograph", "Ideographic"},
    188372: {"Unified_Ideograph", "Ideographic"},
    188373: {"Unified_Ideograph", "Ideographic"},
    188374: {"Unified_Ideograph", "Ideographic"},
    188375: {"Unified_Ideograph", "Ideographic"},
    188376: {"Unified_Ideograph", "Ideographic"},
    188377: {"Unified_Ideograph", "Ideographic"},
    188378: {"Unified_Ideograph", "Ideographic"},
    188379: {"Unified_Ideograph", "Ideographic"},
    188380: {"Unified_Ideograph", "Ideographic"},
    188381: {"Unified_Ideograph", "Ideographic"},
    188382: {"Unified_Ideograph", "Ideographic"},
    188383: {"Unified_Ideograph", "Ideographic"},
    188384: {"Unified_Ideograph", "Ideographic"},
    188385: {"Unified_Ideograph", "Ideographic"},
    188386: {"Unified_Ideograph", "Ideographic"},
    188387: {"Unified_Ideograph", "Ideographic"},
    188388: {"Unified_Ideograph", "Ideographic"},
    188389: {"Unified_Ideograph", "Ideographic"},
    188390: {"Unified_Ideograph", "Ideographic"},
    188391: {"Unified_Ideograph", "Ideographic"},
    188392: {"Unified_Ideograph", "Ideographic"},
    188393: {"Unified_Ideograph", "Ideographic"},
    188394: {"Unified_Ideograph", "Ideographic"},
    188395: {"Unified_Ideograph", "Ideographic"},
    188396: {"Unified_Ideograph", "Ideographic"},
    188397: {"Unified_Ideograph", "Ideographic"},
    188398: {"Unified_Ideograph", "Ideographic"},
    188399: {"Unified_Ideograph", "Ideographic"},
    188400: {"Unified_Ideograph", "Ideographic"},
    188401: {"Unified_Ideograph", "Ideographic"},
    188402: {"Unified_Ideograph", "Ideographic"},
    188403: {"Unified_Ideograph", "Ideographic"},
    188404: {"Unified_Ideograph", "Ideographic"},
    188405: {"Unified_Ideograph", "Ideographic"},
    188406: {"Unified_Ideograph", "Ideographic"},
    188407: {"Unified_Ideograph", "Ideographic"},
    188408: {"Unified_Ideograph", "Ideographic"},
    188409: {"Unified_Ideograph", "Ideographic"},
    188410: {"Unified_Ideograph", "Ideographic"},
    188411: {"Unified_Ideograph", "Ideographic"},
    188412: {"Unified_Ideograph", "Ideographic"},
    188413: {"Unified_Ideograph", "Ideographic"},
    188414: {"Unified_Ideograph", "Ideographic"},
    188415: {"Unified_Ideograph", "Ideographic"},
    188416: {"Unified_Ideograph", "Ideographic"},
    188417: {"Unified_Ideograph", "Ideographic"},
    188418: {"Unified_Ideograph", "Ideographic"},
    188419: {"Unified_Ideograph", "Ideographic"},
    188420: {"Unified_Ideograph", "Ideographic"},
    188421: {"Unified_Ideograph", "Ideographic"},
    188422: {"Unified_Ideograph", "Ideographic"},
    188423: {"Unified_Ideograph", "Ideographic"},
    188424: {"Unified_Ideograph", "Ideographic"},
    188425: {"Unified_Ideograph", "Ideographic"},
    188426: {"Unified_Ideograph", "Ideographic"},
    188427: {"Unified_Ideograph", "Ideographic"},
    188428: {"Unified_Ideograph", "Ideographic"},
    188429: {"Unified_Ideograph", "Ideographic"},
    188430: {"Unified_Ideograph", "Ideographic"},
    188431: {"Unified_Ideograph", "Ideographic"},
    188432: {"Unified_Ideograph", "Ideographic"},
    188433: {"Unified_Ideograph", "Ideographic"},
    188434: {"Unified_Ideograph", "Ideographic"},
    188435: {"Unified_Ideograph", "Ideographic"},
    188436: {"Unified_Ideograph", "Ideographic"},
    188437: {"Unified_Ideograph", "Ideographic"},
    188438: {"Unified_Ideograph", "Ideographic"},
    188439: {"Unified_Ideograph", "Ideographic"},
    188440: {"Unified_Ideograph", "Ideographic"},
    188441: {"Unified_Ideograph", "Ideographic"},
    188442: {"Unified_Ideograph", "Ideographic"},
    188443: {"Unified_Ideograph", "Ideographic"},
    188444: {"Unified_Ideograph", "Ideographic"},
    188445: {"Unified_Ideograph", "Ideographic"},
    188446: {"Unified_Ideograph", "Ideographic"},
    188447: {"Unified_Ideograph", "Ideographic"},
    188448: {"Unified_Ideograph", "Ideographic"},
    188449: {"Unified_Ideograph", "Ideographic"},
    188450: {"Unified_Ideograph", "Ideographic"},
    188451: {"Unified_Ideograph", "Ideographic"},
    188452: {"Unified_Ideograph", "Ideographic"},
    188453: {"Unified_Ideograph", "Ideographic"},
    188454: {"Unified_Ideograph", "Ideographic"},
    188455: {"Unified_Ideograph", "Ideographic"},
    188456: {"Unified_Ideograph", "Ideographic"},
    188457: {"Unified_Ideograph", "Ideographic"},
    188458: {"Unified_Ideograph", "Ideographic"},
    188459: {"Unified_Ideograph", "Ideographic"},
    188460: {"Unified_Ideograph", "Ideographic"},
    188461: {"Unified_Ideograph", "Ideographic"},
    188462: {"Unified_Ideograph", "Ideographic"},
    188463: {"Unified_Ideograph", "Ideographic"},
    188464: {"Unified_Ideograph", "Ideographic"},
    188465: {"Unified_Ideograph", "Ideographic"},
    188466: {"Unified_Ideograph", "Ideographic"},
    188467: {"Unified_Ideograph", "Ideographic"},
    188468: {"Unified_Ideograph", "Ideographic"},
    188469: {"Unified_Ideograph", "Ideographic"},
    188470: {"Unified_Ideograph", "Ideographic"},
    188471: {"Unified_Ideograph", "Ideographic"},
    188472: {"Unified_Ideograph", "Ideographic"},
    188473: {"Unified_Ideograph", "Ideographic"},
    188474: {"Unified_Ideograph", "Ideographic"},
    188475: {"Unified_Ideograph", "Ideographic"},
    188476: {"Unified_Ideograph", "Ideographic"},
    188477: {"Unified_Ideograph", "Ideographic"},
    188478: {"Unified_Ideograph", "Ideographic"},
    188479: {"Unified_Ideograph", "Ideographic"},
    188480: {"Unified_Ideograph", "Ideographic"},
    188481: {"Unified_Ideograph", "Ideographic"},
    188482: {"Unified_Ideograph", "Ideographic"},
    188483: {"Unified_Ideograph", "Ideographic"},
    188484: {"Unified_Ideograph", "Ideographic"},
    188485: {"Unified_Ideograph", "Ideographic"},
    188486: {"Unified_Ideograph", "Ideographic"},
    188487: {"Unified_Ideograph", "Ideographic"},
    188488: {"Unified_Ideograph", "Ideographic"},
    188489: {"Unified_Ideograph", "Ideographic"},
    188490: {"Unified_Ideograph", "Ideographic"},
    188491: {"Unified_Ideograph", "Ideographic"},
    188492: {"Unified_Ideograph", "Ideographic"},
    188493: {"Unified_Ideograph", "Ideographic"},
    188494: {"Unified_Ideograph", "Ideographic"},
    188495: {"Unified_Ideograph", "Ideographic"},
    188496: {"Unified_Ideograph", "Ideographic"},
    188497: {"Unified_Ideograph", "Ideographic"},
    188498: {"Unified_Ideograph", "Ideographic"},
    188499: {"Unified_Ideograph", "Ideographic"},
    188500: {"Unified_Ideograph", "Ideographic"},
    188501: {"Unified_Ideograph", "Ideographic"},
    188502: {"Unified_Ideograph", "Ideographic"},
    188503: {"Unified_Ideograph", "Ideographic"},
    188504: {"Unified_Ideograph", "Ideographic"},
    188505: {"Unified_Ideograph", "Ideographic"},
    188506: {"Unified_Ideograph", "Ideographic"},
    188507: {"Unified_Ideograph", "Ideographic"},
    188508: {"Unified_Ideograph", "Ideographic"},
    188509: {"Unified_Ideograph", "Ideographic"},
    188510: {"Unified_Ideograph", "Ideographic"},
    188511: {"Unified_Ideograph", "Ideographic"},
    188512: {"Unified_Ideograph", "Ideographic"},
    188513: {"Unified_Ideograph", "Ideographic"},
    188514: {"Unified_Ideograph", "Ideographic"},
    188515: {"Unified_Ideograph", "Ideographic"},
    188516: {"Unified_Ideograph", "Ideographic"},
    188517: {"Unified_Ideograph", "Ideographic"},
    188518: {"Unified_Ideograph", "Ideographic"},
    188519: {"Unified_Ideograph", "Ideographic"},
    188520: {"Unified_Ideograph", "Ideographic"},
    188521: {"Unified_Ideograph", "Ideographic"},
    188522: {"Unified_Ideograph", "Ideographic"},
    188523: {"Unified_Ideograph", "Ideographic"},
    188524: {"Unified_Ideograph", "Ideographic"},
    188525: {"Unified_Ideograph", "Ideographic"},
    188526: {"Unified_Ideograph", "Ideographic"},
    188527: {"Unified_Ideograph", "Ideographic"},
    188528: {"Unified_Ideograph", "Ideographic"},
    188529: {"Unified_Ideograph", "Ideographic"},
    188530: {"Unified_Ideograph", "Ideographic"},
    188531: {"Unified_Ideograph", "Ideographic"},
    188532: {"Unified_Ideograph", "Ideographic"},
    188533: {"Unified_Ideograph", "Ideographic"},
    188534: {"Unified_Ideograph", "Ideographic"},
    188535: {"Unified_Ideograph", "Ideographic"},
    188536: {"Unified_Ideograph", "Ideographic"},
    188537: {"Unified_Ideograph", "Ideographic"},
    188538: {"Unified_Ideograph", "Ideographic"},
    188539: {"Unified_Ideograph", "Ideographic"},
    188540: {"Unified_Ideograph", "Ideographic"},
    188541: {"Unified_Ideograph", "Ideographic"},
    188542: {"Unified_Ideograph", "Ideographic"},
    188543: {"Unified_Ideograph", "Ideographic"},
    188544: {"Unified_Ideograph", "Ideographic"},
    188545: {"Unified_Ideograph", "Ideographic"},
    188546: {"Unified_Ideograph", "Ideographic"},
    188547: {"Unified_Ideograph", "Ideographic"},
    188548: {"Unified_Ideograph", "Ideographic"},
    188549: {"Unified_Ideograph", "Ideographic"},
    188550: {"Unified_Ideograph", "Ideographic"},
    188551: {"Unified_Ideograph", "Ideographic"},
    188552: {"Unified_Ideograph", "Ideographic"},
    188553: {"Unified_Ideograph", "Ideographic"},
    188554: {"Unified_Ideograph", "Ideographic"},
    188555: {"Unified_Ideograph", "Ideographic"},
    188556: {"Unified_Ideograph", "Ideographic"},
    188557: {"Unified_Ideograph", "Ideographic"},
    188558: {"Unified_Ideograph", "Ideographic"},
    188559: {"Unified_Ideograph", "Ideographic"},
    188560: {"Unified_Ideograph", "Ideographic"},
    188561: {"Unified_Ideograph", "Ideographic"},
    188562: {"Unified_Ideograph", "Ideographic"},
    188563: {"Unified_Ideograph", "Ideographic"},
    188564: {"Unified_Ideograph", "Ideographic"},
    188565: {"Unified_Ideograph", "Ideographic"},
    188566: {"Unified_Ideograph", "Ideographic"},
    188567: {"Unified_Ideograph", "Ideographic"},
    188568: {"Unified_Ideograph", "Ideographic"},
    188569: {"Unified_Ideograph", "Ideographic"},
    188570: {"Unified_Ideograph", "Ideographic"},
    188571: {"Unified_Ideograph", "Ideographic"},
    188572: {"Unified_Ideograph", "Ideographic"},
    188573: {"Unified_Ideograph", "Ideographic"},
    188574: {"Unified_Ideograph", "Ideographic"},
    188575: {"Unified_Ideograph", "Ideographic"},
    188576: {"Unified_Ideograph", "Ideographic"},
    188577: {"Unified_Ideograph", "Ideographic"},
    188578: {"Unified_Ideograph", "Ideographic"},
    188579: {"Unified_Ideograph", "Ideographic"},
    188580: {"Unified_Ideograph", "Ideographic"},
    188581: {"Unified_Ideograph", "Ideographic"},
    188582: {"Unified_Ideograph", "Ideographic"},
    188583: {"Unified_Ideograph", "Ideographic"},
    188584: {"Unified_Ideograph", "Ideographic"},
    188585: {"Unified_Ideograph", "Ideographic"},
    188586: {"Unified_Ideograph", "Ideographic"},
    188587: {"Unified_Ideograph", "Ideographic"},
    188588: {"Unified_Ideograph", "Ideographic"},
    188589: {"Unified_Ideograph", "Ideographic"},
    188590: {"Unified_Ideograph", "Ideographic"},
    188591: {"Unified_Ideograph", "Ideographic"},
    188592: {"Unified_Ideograph", "Ideographic"},
    188593: {"Unified_Ideograph", "Ideographic"},
    188594: {"Unified_Ideograph", "Ideographic"},
    188595: {"Unified_Ideograph", "Ideographic"},
    188596: {"Unified_Ideograph", "Ideographic"},
    188597: {"Unified_Ideograph", "Ideographic"},
    188598: {"Unified_Ideograph", "Ideographic"},
    188599: {"Unified_Ideograph", "Ideographic"},
    188600: {"Unified_Ideograph", "Ideographic"},
    188601: {"Unified_Ideograph", "Ideographic"},
    188602: {"Unified_Ideograph", "Ideographic"},
    188603: {"Unified_Ideograph", "Ideographic"},
    188604: {"Unified_Ideograph", "Ideographic"},
    188605: {"Unified_Ideograph", "Ideographic"},
    188606: {"Unified_Ideograph", "Ideographic"},
    188607: {"Unified_Ideograph", "Ideographic"},
    188608: {"Unified_Ideograph", "Ideographic"},
    188609: {"Unified_Ideograph", "Ideographic"},
    188610: {"Unified_Ideograph", "Ideographic"},
    188611: {"Unified_Ideograph", "Ideographic"},
    188612: {"Unified_Ideograph", "Ideographic"},
    188613: {"Unified_Ideograph", "Ideographic"},
    188614: {"Unified_Ideograph", "Ideographic"},
    188615: {"Unified_Ideograph", "Ideographic"},
    188616: {"Unified_Ideograph", "Ideographic"},
    188617: {"Unified_Ideograph", "Ideographic"},
    188618: {"Unified_Ideograph", "Ideographic"},
    188619: {"Unified_Ideograph", "Ideographic"},
    188620: {"Unified_Ideograph", "Ideographic"},
    188621: {"Unified_Ideograph", "Ideographic"},
    188622: {"Unified_Ideograph", "Ideographic"},
    188623: {"Unified_Ideograph", "Ideographic"},
    188624: {"Unified_Ideograph", "Ideographic"},
    188625: {"Unified_Ideograph", "Ideographic"},
    188626: {"Unified_Ideograph", "Ideographic"},
    188627: {"Unified_Ideograph", "Ideographic"},
    188628: {"Unified_Ideograph", "Ideographic"},
    188629: {"Unified_Ideograph", "Ideographic"},
    188630: {"Unified_Ideograph", "Ideographic"},
    188631: {"Unified_Ideograph", "Ideographic"},
    188632: {"Unified_Ideograph", "Ideographic"},
    188633: {"Unified_Ideograph", "Ideographic"},
    188634: {"Unified_Ideograph", "Ideographic"},
    188635: {"Unified_Ideograph", "Ideographic"},
    188636: {"Unified_Ideograph", "Ideographic"},
    188637: {"Unified_Ideograph", "Ideographic"},
    188638: {"Unified_Ideograph", "Ideographic"},
    188639: {"Unified_Ideograph", "Ideographic"},
    188640: {"Unified_Ideograph", "Ideographic"},
    188641: {"Unified_Ideograph", "Ideographic"},
    188642: {"Unified_Ideograph", "Ideographic"},
    188643: {"Unified_Ideograph", "Ideographic"},
    188644: {"Unified_Ideograph", "Ideographic"},
    188645: {"Unified_Ideograph", "Ideographic"},
    188646: {"Unified_Ideograph", "Ideographic"},
    188647: {"Unified_Ideograph", "Ideographic"},
    188648: {"Unified_Ideograph", "Ideographic"},
    188649: {"Unified_Ideograph", "Ideographic"},
    188650: {"Unified_Ideograph", "Ideographic"},
    188651: {"Unified_Ideograph", "Ideographic"},
    188652: {"Unified_Ideograph", "Ideographic"},
    188653: {"Unified_Ideograph", "Ideographic"},
    188654: {"Unified_Ideograph", "Ideographic"},
    188655: {"Unified_Ideograph", "Ideographic"},
    188656: {"Unified_Ideograph", "Ideographic"},
    188657: {"Unified_Ideograph", "Ideographic"},
    188658: {"Unified_Ideograph", "Ideographic"},
    188659: {"Unified_Ideograph", "Ideographic"},
    188660: {"Unified_Ideograph", "Ideographic"},
    188661: {"Unified_Ideograph", "Ideographic"},
    188662: {"Unified_Ideograph", "Ideographic"},
    188663: {"Unified_Ideograph", "Ideographic"},
    188664: {"Unified_Ideograph", "Ideographic"},
    188665: {"Unified_Ideograph", "Ideographic"},
    188666: {"Unified_Ideograph", "Ideographic"},
    188667: {"Unified_Ideograph", "Ideographic"},
    188668: {"Unified_Ideograph", "Ideographic"},
    188669: {"Unified_Ideograph", "Ideographic"},
    188670: {"Unified_Ideograph", "Ideographic"},
    188671: {"Unified_Ideograph", "Ideographic"},
    188672: {"Unified_Ideograph", "Ideographic"},
    188673: {"Unified_Ideograph", "Ideographic"},
    188674: {"Unified_Ideograph", "Ideographic"},
    188675: {"Unified_Ideograph", "Ideographic"},
    188676: {"Unified_Ideograph", "Ideographic"},
    188677: {"Unified_Ideograph", "Ideographic"},
    188678: {"Unified_Ideograph", "Ideographic"},
    188679: {"Unified_Ideograph", "Ideographic"},
    188680: {"Unified_Ideograph", "Ideographic"},
    188681: {"Unified_Ideograph", "Ideographic"},
    188682: {"Unified_Ideograph", "Ideographic"},
    188683: {"Unified_Ideograph", "Ideographic"},
    188684: {"Unified_Ideograph", "Ideographic"},
    188685: {"Unified_Ideograph", "Ideographic"},
    188686: {"Unified_Ideograph", "Ideographic"},
    188687: {"Unified_Ideograph", "Ideographic"},
    188688: {"Unified_Ideograph", "Ideographic"},
    188689: {"Unified_Ideograph", "Ideographic"},
    188690: {"Unified_Ideograph", "Ideographic"},
    188691: {"Unified_Ideograph", "Ideographic"},
    188692: {"Unified_Ideograph", "Ideographic"},
    188693: {"Unified_Ideograph", "Ideographic"},
    188694: {"Unified_Ideograph", "Ideographic"},
    188695: {"Unified_Ideograph", "Ideographic"},
    188696: {"Unified_Ideograph", "Ideographic"},
    188697: {"Unified_Ideograph", "Ideographic"},
    188698: {"Unified_Ideograph", "Ideographic"},
    188699: {"Unified_Ideograph", "Ideographic"},
    188700: {"Unified_Ideograph", "Ideographic"},
    188701: {"Unified_Ideograph", "Ideographic"},
    188702: {"Unified_Ideograph", "Ideographic"},
    188703: {"Unified_Ideograph", "Ideographic"},
    188704: {"Unified_Ideograph", "Ideographic"},
    188705: {"Unified_Ideograph", "Ideographic"},
    188706: {"Unified_Ideograph", "Ideographic"},
    188707: {"Unified_Ideograph", "Ideographic"},
    188708: {"Unified_Ideograph", "Ideographic"},
    188709: {"Unified_Ideograph", "Ideographic"},
    188710: {"Unified_Ideograph", "Ideographic"},
    188711: {"Unified_Ideograph", "Ideographic"},
    188712: {"Unified_Ideograph", "Ideographic"},
    188713: {"Unified_Ideograph", "Ideographic"},
    188714: {"Unified_Ideograph", "Ideographic"},
    188715: {"Unified_Ideograph", "Ideographic"},
    188716: {"Unified_Ideograph", "Ideographic"},
    188717: {"Unified_Ideograph", "Ideographic"},
    188718: {"Unified_Ideograph", "Ideographic"},
    188719: {"Unified_Ideograph", "Ideographic"},
    188720: {"Unified_Ideograph", "Ideographic"},
    188721: {"Unified_Ideograph", "Ideographic"},
    188722: {"Unified_Ideograph", "Ideographic"},
    188723: {"Unified_Ideograph", "Ideographic"},
    188724: {"Unified_Ideograph", "Ideographic"},
    188725: {"Unified_Ideograph", "Ideographic"},
    188726: {"Unified_Ideograph", "Ideographic"},
    188727: {"Unified_Ideograph", "Ideographic"},
    188728: {"Unified_Ideograph", "Ideographic"},
    188729: {"Unified_Ideograph", "Ideographic"},
    188730: {"Unified_Ideograph", "Ideographic"},
    188731: {"Unified_Ideograph", "Ideographic"},
    188732: {"Unified_Ideograph", "Ideographic"},
    188733: {"Unified_Ideograph", "Ideographic"},
    188734: {"Unified_Ideograph", "Ideographic"},
    188735: {"Unified_Ideograph", "Ideographic"},
    188736: {"Unified_Ideograph", "Ideographic"},
    188737: {"Unified_Ideograph", "Ideographic"},
    188738: {"Unified_Ideograph", "Ideographic"},
    188739: {"Unified_Ideograph", "Ideographic"},
    188740: {"Unified_Ideograph", "Ideographic"},
    188741: {"Unified_Ideograph", "Ideographic"},
    188742: {"Unified_Ideograph", "Ideographic"},
    188743: {"Unified_Ideograph", "Ideographic"},
    188744: {"Unified_Ideograph", "Ideographic"},
    188745: {"Unified_Ideograph", "Ideographic"},
    188746: {"Unified_Ideograph", "Ideographic"},
    188747: {"Unified_Ideograph", "Ideographic"},
    188748: {"Unified_Ideograph", "Ideographic"},
    188749: {"Unified_Ideograph", "Ideographic"},
    188750: {"Unified_Ideograph", "Ideographic"},
    188751: {"Unified_Ideograph", "Ideographic"},
    188752: {"Unified_Ideograph", "Ideographic"},
    188753: {"Unified_Ideograph", "Ideographic"},
    188754: {"Unified_Ideograph", "Ideographic"},
    188755: {"Unified_Ideograph", "Ideographic"},
    188756: {"Unified_Ideograph", "Ideographic"},
    188757: {"Unified_Ideograph", "Ideographic"},
    188758: {"Unified_Ideograph", "Ideographic"},
    188759: {"Unified_Ideograph", "Ideographic"},
    188760: {"Unified_Ideograph", "Ideographic"},
    188761: {"Unified_Ideograph", "Ideographic"},
    188762: {"Unified_Ideograph", "Ideographic"},
    188763: {"Unified_Ideograph", "Ideographic"},
    188764: {"Unified_Ideograph", "Ideographic"},
    188765: {"Unified_Ideograph", "Ideographic"},
    188766: {"Unified_Ideograph", "Ideographic"},
    188767: {"Unified_Ideograph", "Ideographic"},
    188768: {"Unified_Ideograph", "Ideographic"},
    188769: {"Unified_Ideograph", "Ideographic"},
    188770: {"Unified_Ideograph", "Ideographic"},
    188771: {"Unified_Ideograph", "Ideographic"},
    188772: {"Unified_Ideograph", "Ideographic"},
    188773: {"Unified_Ideograph", "Ideographic"},
    188774: {"Unified_Ideograph", "Ideographic"},
    188775: {"Unified_Ideograph", "Ideographic"},
    188776: {"Unified_Ideograph", "Ideographic"},
    188777: {"Unified_Ideograph", "Ideographic"},
    188778: {"Unified_Ideograph", "Ideographic"},
    188779: {"Unified_Ideograph", "Ideographic"},
    188780: {"Unified_Ideograph", "Ideographic"},
    188781: {"Unified_Ideograph", "Ideographic"},
    188782: {"Unified_Ideograph", "Ideographic"},
    188783: {"Unified_Ideograph", "Ideographic"},
    188784: {"Unified_Ideograph", "Ideographic"},
    188785: {"Unified_Ideograph", "Ideographic"},
    188786: {"Unified_Ideograph", "Ideographic"},
    188787: {"Unified_Ideograph", "Ideographic"},
    188788: {"Unified_Ideograph", "Ideographic"},
    188789: {"Unified_Ideograph", "Ideographic"},
    188790: {"Unified_Ideograph", "Ideographic"},
    188791: {"Unified_Ideograph", "Ideographic"},
    188792: {"Unified_Ideograph", "Ideographic"},
    188793: {"Unified_Ideograph", "Ideographic"},
    188794: {"Unified_Ideograph", "Ideographic"},
    188795: {"Unified_Ideograph", "Ideographic"},
    188796: {"Unified_Ideograph", "Ideographic"},
    188797: {"Unified_Ideograph", "Ideographic"},
    188798: {"Unified_Ideograph", "Ideographic"},
    188799: {"Unified_Ideograph", "Ideographic"},
    188800: {"Unified_Ideograph", "Ideographic"},
    188801: {"Unified_Ideograph", "Ideographic"},
    188802: {"Unified_Ideograph", "Ideographic"},
    188803: {"Unified_Ideograph", "Ideographic"},
    188804: {"Unified_Ideograph", "Ideographic"},
    188805: {"Unified_Ideograph", "Ideographic"},
    188806: {"Unified_Ideograph", "Ideographic"},
    188807: {"Unified_Ideograph", "Ideographic"},
    188808: {"Unified_Ideograph", "Ideographic"},
    188809: {"Unified_Ideograph", "Ideographic"},
    188810: {"Unified_Ideograph", "Ideographic"},
    188811: {"Unified_Ideograph", "Ideographic"},
    188812: {"Unified_Ideograph", "Ideographic"},
    188813: {"Unified_Ideograph", "Ideographic"},
    188814: {"Unified_Ideograph", "Ideographic"},
    188815: {"Unified_Ideograph", "Ideographic"},
    188816: {"Unified_Ideograph", "Ideographic"},
    188817: {"Unified_Ideograph", "Ideographic"},
    188818: {"Unified_Ideograph", "Ideographic"},
    188819: {"Unified_Ideograph", "Ideographic"},
    188820: {"Unified_Ideograph", "Ideographic"},
    188821: {"Unified_Ideograph", "Ideographic"},
    188822: {"Unified_Ideograph", "Ideographic"},
    188823: {"Unified_Ideograph", "Ideographic"},
    188824: {"Unified_Ideograph", "Ideographic"},
    188825: {"Unified_Ideograph", "Ideographic"},
    188826: {"Unified_Ideograph", "Ideographic"},
    188827: {"Unified_Ideograph", "Ideographic"},
    188828: {"Unified_Ideograph", "Ideographic"},
    188829: {"Unified_Ideograph", "Ideographic"},
    188830: {"Unified_Ideograph", "Ideographic"},
    188831: {"Unified_Ideograph", "Ideographic"},
    188832: {"Unified_Ideograph", "Ideographic"},
    188833: {"Unified_Ideograph", "Ideographic"},
    188834: {"Unified_Ideograph", "Ideographic"},
    188835: {"Unified_Ideograph", "Ideographic"},
    188836: {"Unified_Ideograph", "Ideographic"},
    188837: {"Unified_Ideograph", "Ideographic"},
    188838: {"Unified_Ideograph", "Ideographic"},
    188839: {"Unified_Ideograph", "Ideographic"},
    188840: {"Unified_Ideograph", "Ideographic"},
    188841: {"Unified_Ideograph", "Ideographic"},
    188842: {"Unified_Ideograph", "Ideographic"},
    188843: {"Unified_Ideograph", "Ideographic"},
    188844: {"Unified_Ideograph", "Ideographic"},
    188845: {"Unified_Ideograph", "Ideographic"},
    188846: {"Unified_Ideograph", "Ideographic"},
    188847: {"Unified_Ideograph", "Ideographic"},
    188848: {"Unified_Ideograph", "Ideographic"},
    188849: {"Unified_Ideograph", "Ideographic"},
    188850: {"Unified_Ideograph", "Ideographic"},
    188851: {"Unified_Ideograph", "Ideographic"},
    188852: {"Unified_Ideograph", "Ideographic"},
    188853: {"Unified_Ideograph", "Ideographic"},
    188854: {"Unified_Ideograph", "Ideographic"},
    188855: {"Unified_Ideograph", "Ideographic"},
    188856: {"Unified_Ideograph", "Ideographic"},
    188857: {"Unified_Ideograph", "Ideographic"},
    188858: {"Unified_Ideograph", "Ideographic"},
    188859: {"Unified_Ideograph", "Ideographic"},
    188860: {"Unified_Ideograph", "Ideographic"},
    188861: {"Unified_Ideograph", "Ideographic"},
    188862: {"Unified_Ideograph", "Ideographic"},
    188863: {"Unified_Ideograph", "Ideographic"},
    188864: {"Unified_Ideograph", "Ideographic"},
    188865: {"Unified_Ideograph", "Ideographic"},
    188866: {"Unified_Ideograph", "Ideographic"},
    188867: {"Unified_Ideograph", "Ideographic"},
    188868: {"Unified_Ideograph", "Ideographic"},
    188869: {"Unified_Ideograph", "Ideographic"},
    188870: {"Unified_Ideograph", "Ideographic"},
    188871: {"Unified_Ideograph", "Ideographic"},
    188872: {"Unified_Ideograph", "Ideographic"},
    188873: {"Unified_Ideograph", "Ideographic"},
    188874: {"Unified_Ideograph", "Ideographic"},
    188875: {"Unified_Ideograph", "Ideographic"},
    188876: {"Unified_Ideograph", "Ideographic"},
    188877: {"Unified_Ideograph", "Ideographic"},
    188878: {"Unified_Ideograph", "Ideographic"},
    188879: {"Unified_Ideograph", "Ideographic"},
    188880: {"Unified_Ideograph", "Ideographic"},
    188881: {"Unified_Ideograph", "Ideographic"},
    188882: {"Unified_Ideograph", "Ideographic"},
    188883: {"Unified_Ideograph", "Ideographic"},
    188884: {"Unified_Ideograph", "Ideographic"},
    188885: {"Unified_Ideograph", "Ideographic"},
    188886: {"Unified_Ideograph", "Ideographic"},
    188887: {"Unified_Ideograph", "Ideographic"},
    188888: {"Unified_Ideograph", "Ideographic"},
    188889: {"Unified_Ideograph", "Ideographic"},
    188890: {"Unified_Ideograph", "Ideographic"},
    188891: {"Unified_Ideograph", "Ideographic"},
    188892: {"Unified_Ideograph", "Ideographic"},
    188893: {"Unified_Ideograph", "Ideographic"},
    188894: {"Unified_Ideograph", "Ideographic"},
    188895: {"Unified_Ideograph", "Ideographic"},
    188896: {"Unified_Ideograph", "Ideographic"},
    188897: {"Unified_Ideograph", "Ideographic"},
    188898: {"Unified_Ideograph", "Ideographic"},
    188899: {"Unified_Ideograph", "Ideographic"},
    188900: {"Unified_Ideograph", "Ideographic"},
    188901: {"Unified_Ideograph", "Ideographic"},
    188902: {"Unified_Ideograph", "Ideographic"},
    188903: {"Unified_Ideograph", "Ideographic"},
    188904: {"Unified_Ideograph", "Ideographic"},
    188905: {"Unified_Ideograph", "Ideographic"},
    188906: {"Unified_Ideograph", "Ideographic"},
    188907: {"Unified_Ideograph", "Ideographic"},
    188908: {"Unified_Ideograph", "Ideographic"},
    188909: {"Unified_Ideograph", "Ideographic"},
    188910: {"Unified_Ideograph", "Ideographic"},
    188911: {"Unified_Ideograph", "Ideographic"},
    188912: {"Unified_Ideograph", "Ideographic"},
    188913: {"Unified_Ideograph", "Ideographic"},
    188914: {"Unified_Ideograph", "Ideographic"},
    188915: {"Unified_Ideograph", "Ideographic"},
    188916: {"Unified_Ideograph", "Ideographic"},
    188917: {"Unified_Ideograph", "Ideographic"},
    188918: {"Unified_Ideograph", "Ideographic"},
    188919: {"Unified_Ideograph", "Ideographic"},
    188920: {"Unified_Ideograph", "Ideographic"},
    188921: {"Unified_Ideograph", "Ideographic"},
    188922: {"Unified_Ideograph", "Ideographic"},
    188923: {"Unified_Ideograph", "Ideographic"},
    188924: {"Unified_Ideograph", "Ideographic"},
    188925: {"Unified_Ideograph", "Ideographic"},
    188926: {"Unified_Ideograph", "Ideographic"},
    188927: {"Unified_Ideograph", "Ideographic"},
    188928: {"Unified_Ideograph", "Ideographic"},
    188929: {"Unified_Ideograph", "Ideographic"},
    188930: {"Unified_Ideograph", "Ideographic"},
    188931: {"Unified_Ideograph", "Ideographic"},
    188932: {"Unified_Ideograph", "Ideographic"},
    188933: {"Unified_Ideograph", "Ideographic"},
    188934: {"Unified_Ideograph", "Ideographic"},
    188935: {"Unified_Ideograph", "Ideographic"},
    188936: {"Unified_Ideograph", "Ideographic"},
    188937: {"Unified_Ideograph", "Ideographic"},
    188938: {"Unified_Ideograph", "Ideographic"},
    188939: {"Unified_Ideograph", "Ideographic"},
    188940: {"Unified_Ideograph", "Ideographic"},
    188941: {"Unified_Ideograph", "Ideographic"},
    188942: {"Unified_Ideograph", "Ideographic"},
    188943: {"Unified_Ideograph", "Ideographic"},
    188944: {"Unified_Ideograph", "Ideographic"},
    188945: {"Unified_Ideograph", "Ideographic"},
    188946: {"Unified_Ideograph", "Ideographic"},
    188947: {"Unified_Ideograph", "Ideographic"},
    188948: {"Unified_Ideograph", "Ideographic"},
    188949: {"Unified_Ideograph", "Ideographic"},
    188950: {"Unified_Ideograph", "Ideographic"},
    188951: {"Unified_Ideograph", "Ideographic"},
    188952: {"Unified_Ideograph", "Ideographic"},
    188953: {"Unified_Ideograph", "Ideographic"},
    188954: {"Unified_Ideograph", "Ideographic"},
    188955: {"Unified_Ideograph", "Ideographic"},
    188956: {"Unified_Ideograph", "Ideographic"},
    188957: {"Unified_Ideograph", "Ideographic"},
    188958: {"Unified_Ideograph", "Ideographic"},
    188959: {"Unified_Ideograph", "Ideographic"},
    188960: {"Unified_Ideograph", "Ideographic"},
    188961: {"Unified_Ideograph", "Ideographic"},
    188962: {"Unified_Ideograph", "Ideographic"},
    188963: {"Unified_Ideograph", "Ideographic"},
    188964: {"Unified_Ideograph", "Ideographic"},
    188965: {"Unified_Ideograph", "Ideographic"},
    188966: {"Unified_Ideograph", "Ideographic"},
    188967: {"Unified_Ideograph", "Ideographic"},
    188968: {"Unified_Ideograph", "Ideographic"},
    188969: {"Unified_Ideograph", "Ideographic"},
    188970: {"Unified_Ideograph", "Ideographic"},
    188971: {"Unified_Ideograph", "Ideographic"},
    188972: {"Unified_Ideograph", "Ideographic"},
    188973: {"Unified_Ideograph", "Ideographic"},
    188974: {"Unified_Ideograph", "Ideographic"},
    188975: {"Unified_Ideograph", "Ideographic"},
    188976: {"Unified_Ideograph", "Ideographic"},
    188977: {"Unified_Ideograph", "Ideographic"},
    188978: {"Unified_Ideograph", "Ideographic"},
    188979: {"Unified_Ideograph", "Ideographic"},
    188980: {"Unified_Ideograph", "Ideographic"},
    188981: {"Unified_Ideograph", "Ideographic"},
    188982: {"Unified_Ideograph", "Ideographic"},
    188983: {"Unified_Ideograph", "Ideographic"},
    188984: {"Unified_Ideograph", "Ideographic"},
    188985: {"Unified_Ideograph", "Ideographic"},
    188986: {"Unified_Ideograph", "Ideographic"},
    188987: {"Unified_Ideograph", "Ideographic"},
    188988: {"Unified_Ideograph", "Ideographic"},
    188989: {"Unified_Ideograph", "Ideographic"},
    188990: {"Unified_Ideograph", "Ideographic"},
    188991: {"Unified_Ideograph", "Ideographic"},
    188992: {"Unified_Ideograph", "Ideographic"},
    188993: {"Unified_Ideograph", "Ideographic"},
    188994: {"Unified_Ideograph", "Ideographic"},
    188995: {"Unified_Ideograph", "Ideographic"},
    188996: {"Unified_Ideograph", "Ideographic"},
    188997: {"Unified_Ideograph", "Ideographic"},
    188998: {"Unified_Ideograph", "Ideographic"},
    188999: {"Unified_Ideograph", "Ideographic"},
    189000: {"Unified_Ideograph", "Ideographic"},
    189001: {"Unified_Ideograph", "Ideographic"},
    189002: {"Unified_Ideograph", "Ideographic"},
    189003: {"Unified_Ideograph", "Ideographic"},
    189004: {"Unified_Ideograph", "Ideographic"},
    189005: {"Unified_Ideograph", "Ideographic"},
    189006: {"Unified_Ideograph", "Ideographic"},
    189007: {"Unified_Ideograph", "Ideographic"},
    189008: {"Unified_Ideograph", "Ideographic"},
    189009: {"Unified_Ideograph", "Ideographic"},
    189010: {"Unified_Ideograph", "Ideographic"},
    189011: {"Unified_Ideograph", "Ideographic"},
    189012: {"Unified_Ideograph", "Ideographic"},
    189013: {"Unified_Ideograph", "Ideographic"},
    189014: {"Unified_Ideograph", "Ideographic"},
    189015: {"Unified_Ideograph", "Ideographic"},
    189016: {"Unified_Ideograph", "Ideographic"},
    189017: {"Unified_Ideograph", "Ideographic"},
    189018: {"Unified_Ideograph", "Ideographic"},
    189019: {"Unified_Ideograph", "Ideographic"},
    189020: {"Unified_Ideograph", "Ideographic"},
    189021: {"Unified_Ideograph", "Ideographic"},
    189022: {"Unified_Ideograph", "Ideographic"},
    189023: {"Unified_Ideograph", "Ideographic"},
    189024: {"Unified_Ideograph", "Ideographic"},
    189025: {"Unified_Ideograph", "Ideographic"},
    189026: {"Unified_Ideograph", "Ideographic"},
    189027: {"Unified_Ideograph", "Ideographic"},
    189028: {"Unified_Ideograph", "Ideographic"},
    189029: {"Unified_Ideograph", "Ideographic"},
    189030: {"Unified_Ideograph", "Ideographic"},
    189031: {"Unified_Ideograph", "Ideographic"},
    189032: {"Unified_Ideograph", "Ideographic"},
    189033: {"Unified_Ideograph", "Ideographic"},
    189034: {"Unified_Ideograph", "Ideographic"},
    189035: {"Unified_Ideograph", "Ideographic"},
    189036: {"Unified_Ideograph", "Ideographic"},
    189037: {"Unified_Ideograph", "Ideographic"},
    189038: {"Unified_Ideograph", "Ideographic"},
    189039: {"Unified_Ideograph", "Ideographic"},
    189040: {"Unified_Ideograph", "Ideographic"},
    189041: {"Unified_Ideograph", "Ideographic"},
    189042: {"Unified_Ideograph", "Ideographic"},
    189043: {"Unified_Ideograph", "Ideographic"},
    189044: {"Unified_Ideograph", "Ideographic"},
    189045: {"Unified_Ideograph", "Ideographic"},
    189046: {"Unified_Ideograph", "Ideographic"},
    189047: {"Unified_Ideograph", "Ideographic"},
    189048: {"Unified_Ideograph", "Ideographic"},
    189049: {"Unified_Ideograph", "Ideographic"},
    189050: {"Unified_Ideograph", "Ideographic"},
    189051: {"Unified_Ideograph", "Ideographic"},
    189052: {"Unified_Ideograph", "Ideographic"},
    189053: {"Unified_Ideograph", "Ideographic"},
    189054: {"Unified_Ideograph", "Ideographic"},
    189055: {"Unified_Ideograph", "Ideographic"},
    189056: {"Unified_Ideograph", "Ideographic"},
    189057: {"Unified_Ideograph", "Ideographic"},
    189058: {"Unified_Ideograph", "Ideographic"},
    189059: {"Unified_Ideograph", "Ideographic"},
    189060: {"Unified_Ideograph", "Ideographic"},
    189061: {"Unified_Ideograph", "Ideographic"},
    189062: {"Unified_Ideograph", "Ideographic"},
    189063: {"Unified_Ideograph", "Ideographic"},
    189064: {"Unified_Ideograph", "Ideographic"},
    189065: {"Unified_Ideograph", "Ideographic"},
    189066: {"Unified_Ideograph", "Ideographic"},
    189067: {"Unified_Ideograph", "Ideographic"},
    189068: {"Unified_Ideograph", "Ideographic"},
    189069: {"Unified_Ideograph", "Ideographic"},
    189070: {"Unified_Ideograph", "Ideographic"},
    189071: {"Unified_Ideograph", "Ideographic"},
    189072: {"Unified_Ideograph", "Ideographic"},
    189073: {"Unified_Ideograph", "Ideographic"},
    189074: {"Unified_Ideograph", "Ideographic"},
    189075: {"Unified_Ideograph", "Ideographic"},
    189076: {"Unified_Ideograph", "Ideographic"},
    189077: {"Unified_Ideograph", "Ideographic"},
    189078: {"Unified_Ideograph", "Ideographic"},
    189079: {"Unified_Ideograph", "Ideographic"},
    189080: {"Unified_Ideograph", "Ideographic"},
    189081: {"Unified_Ideograph", "Ideographic"},
    189082: {"Unified_Ideograph", "Ideographic"},
    189083: {"Unified_Ideograph", "Ideographic"},
    189084: {"Unified_Ideograph", "Ideographic"},
    189085: {"Unified_Ideograph", "Ideographic"},
    189086: {"Unified_Ideograph", "Ideographic"},
    189087: {"Unified_Ideograph", "Ideographic"},
    189088: {"Unified_Ideograph", "Ideographic"},
    189089: {"Unified_Ideograph", "Ideographic"},
    189090: {"Unified_Ideograph", "Ideographic"},
    189091: {"Unified_Ideograph", "Ideographic"},
    189092: {"Unified_Ideograph", "Ideographic"},
    189093: {"Unified_Ideograph", "Ideographic"},
    189094: {"Unified_Ideograph", "Ideographic"},
    189095: {"Unified_Ideograph", "Ideographic"},
    189096: {"Unified_Ideograph", "Ideographic"},
    189097: {"Unified_Ideograph", "Ideographic"},
    189098: {"Unified_Ideograph", "Ideographic"},
    189099: {"Unified_Ideograph", "Ideographic"},
    189100: {"Unified_Ideograph", "Ideographic"},
    189101: {"Unified_Ideograph", "Ideographic"},
    189102: {"Unified_Ideograph", "Ideographic"},
    189103: {"Unified_Ideograph", "Ideographic"},
    189104: {"Unified_Ideograph", "Ideographic"},
    189105: {"Unified_Ideograph", "Ideographic"},
    189106: {"Unified_Ideograph", "Ideographic"},
    189107: {"Unified_Ideograph", "Ideographic"},
    189108: {"Unified_Ideograph", "Ideographic"},
    189109: {"Unified_Ideograph", "Ideographic"},
    189110: {"Unified_Ideograph", "Ideographic"},
    189111: {"Unified_Ideograph", "Ideographic"},
    189112: {"Unified_Ideograph", "Ideographic"},
    189113: {"Unified_Ideograph", "Ideographic"},
    189114: {"Unified_Ideograph", "Ideographic"},
    189115: {"Unified_Ideograph", "Ideographic"},
    189116: {"Unified_Ideograph", "Ideographic"},
    189117: {"Unified_Ideograph", "Ideographic"},
    189118: {"Unified_Ideograph", "Ideographic"},
    189119: {"Unified_Ideograph", "Ideographic"},
    189120: {"Unified_Ideograph", "Ideographic"},
    189121: {"Unified_Ideograph", "Ideographic"},
    189122: {"Unified_Ideograph", "Ideographic"},
    189123: {"Unified_Ideograph", "Ideographic"},
    189124: {"Unified_Ideograph", "Ideographic"},
    189125: {"Unified_Ideograph", "Ideographic"},
    189126: {"Unified_Ideograph", "Ideographic"},
    189127: {"Unified_Ideograph", "Ideographic"},
    189128: {"Unified_Ideograph", "Ideographic"},
    189129: {"Unified_Ideograph", "Ideographic"},
    189130: {"Unified_Ideograph", "Ideographic"},
    189131: {"Unified_Ideograph", "Ideographic"},
    189132: {"Unified_Ideograph", "Ideographic"},
    189133: {"Unified_Ideograph", "Ideographic"},
    189134: {"Unified_Ideograph", "Ideographic"},
    189135: {"Unified_Ideograph", "Ideographic"},
    189136: {"Unified_Ideograph", "Ideographic"},
    189137: {"Unified_Ideograph", "Ideographic"},
    189138: {"Unified_Ideograph", "Ideographic"},
    189139: {"Unified_Ideograph", "Ideographic"},
    189140: {"Unified_Ideograph", "Ideographic"},
    189141: {"Unified_Ideograph", "Ideographic"},
    189142: {"Unified_Ideograph", "Ideographic"},
    189143: {"Unified_Ideograph", "Ideographic"},
    189144: {"Unified_Ideograph", "Ideographic"},
    189145: {"Unified_Ideograph", "Ideographic"},
    189146: {"Unified_Ideograph", "Ideographic"},
    189147: {"Unified_Ideograph", "Ideographic"},
    189148: {"Unified_Ideograph", "Ideographic"},
    189149: {"Unified_Ideograph", "Ideographic"},
    189150: {"Unified_Ideograph", "Ideographic"},
    189151: {"Unified_Ideograph", "Ideographic"},
    189152: {"Unified_Ideograph", "Ideographic"},
    189153: {"Unified_Ideograph", "Ideographic"},
    189154: {"Unified_Ideograph", "Ideographic"},
    189155: {"Unified_Ideograph", "Ideographic"},
    189156: {"Unified_Ideograph", "Ideographic"},
    189157: {"Unified_Ideograph", "Ideographic"},
    189158: {"Unified_Ideograph", "Ideographic"},
    189159: {"Unified_Ideograph", "Ideographic"},
    189160: {"Unified_Ideograph", "Ideographic"},
    189161: {"Unified_Ideograph", "Ideographic"},
    189162: {"Unified_Ideograph", "Ideographic"},
    189163: {"Unified_Ideograph", "Ideographic"},
    189164: {"Unified_Ideograph", "Ideographic"},
    189165: {"Unified_Ideograph", "Ideographic"},
    189166: {"Unified_Ideograph", "Ideographic"},
    189167: {"Unified_Ideograph", "Ideographic"},
    189168: {"Unified_Ideograph", "Ideographic"},
    189169: {"Unified_Ideograph", "Ideographic"},
    189170: {"Unified_Ideograph", "Ideographic"},
    189171: {"Unified_Ideograph", "Ideographic"},
    189172: {"Unified_Ideograph", "Ideographic"},
    189173: {"Unified_Ideograph", "Ideographic"},
    189174: {"Unified_Ideograph", "Ideographic"},
    189175: {"Unified_Ideograph", "Ideographic"},
    189176: {"Unified_Ideograph", "Ideographic"},
    189177: {"Unified_Ideograph", "Ideographic"},
    189178: {"Unified_Ideograph", "Ideographic"},
    189179: {"Unified_Ideograph", "Ideographic"},
    189180: {"Unified_Ideograph", "Ideographic"},
    189181: {"Unified_Ideograph", "Ideographic"},
    189182: {"Unified_Ideograph", "Ideographic"},
    189183: {"Unified_Ideograph", "Ideographic"},
    189184: {"Unified_Ideograph", "Ideographic"},
    189185: {"Unified_Ideograph", "Ideographic"},
    189186: {"Unified_Ideograph", "Ideographic"},
    189187: {"Unified_Ideograph", "Ideographic"},
    189188: {"Unified_Ideograph", "Ideographic"},
    189189: {"Unified_Ideograph", "Ideographic"},
    189190: {"Unified_Ideograph", "Ideographic"},
    189191: {"Unified_Ideograph", "Ideographic"},
    189192: {"Unified_Ideograph", "Ideographic"},
    189193: {"Unified_Ideograph", "Ideographic"},
    189194: {"Unified_Ideograph", "Ideographic"},
    189195: {"Unified_Ideograph", "Ideographic"},
    189196: {"Unified_Ideograph", "Ideographic"},
    189197: {"Unified_Ideograph", "Ideographic"},
    189198: {"Unified_Ideograph", "Ideographic"},
    189199: {"Unified_Ideograph", "Ideographic"},
    189200: {"Unified_Ideograph", "Ideographic"},
    189201: {"Unified_Ideograph", "Ideographic"},
    189202: {"Unified_Ideograph", "Ideographic"},
    189203: {"Unified_Ideograph", "Ideographic"},
    189204: {"Unified_Ideograph", "Ideographic"},
    189205: {"Unified_Ideograph", "Ideographic"},
    189206: {"Unified_Ideograph", "Ideographic"},
    189207: {"Unified_Ideograph", "Ideographic"},
    189208: {"Unified_Ideograph", "Ideographic"},
    189209: {"Unified_Ideograph", "Ideographic"},
    189210: {"Unified_Ideograph", "Ideographic"},
    189211: {"Unified_Ideograph", "Ideographic"},
    189212: {"Unified_Ideograph", "Ideographic"},
    189213: {"Unified_Ideograph", "Ideographic"},
    189214: {"Unified_Ideograph", "Ideographic"},
    189215: {"Unified_Ideograph", "Ideographic"},
    189216: {"Unified_Ideograph", "Ideographic"},
    189217: {"Unified_Ideograph", "Ideographic"},
    189218: {"Unified_Ideograph", "Ideographic"},
    189219: {"Unified_Ideograph", "Ideographic"},
    189220: {"Unified_Ideograph", "Ideographic"},
    189221: {"Unified_Ideograph", "Ideographic"},
    189222: {"Unified_Ideograph", "Ideographic"},
    189223: {"Unified_Ideograph", "Ideographic"},
    189224: {"Unified_Ideograph", "Ideographic"},
    189225: {"Unified_Ideograph", "Ideographic"},
    189226: {"Unified_Ideograph", "Ideographic"},
    189227: {"Unified_Ideograph", "Ideographic"},
    189228: {"Unified_Ideograph", "Ideographic"},
    189229: {"Unified_Ideograph", "Ideographic"},
    189230: {"Unified_Ideograph", "Ideographic"},
    189231: {"Unified_Ideograph", "Ideographic"},
    189232: {"Unified_Ideograph", "Ideographic"},
    189233: {"Unified_Ideograph", "Ideographic"},
    189234: {"Unified_Ideograph", "Ideographic"},
    189235: {"Unified_Ideograph", "Ideographic"},
    189236: {"Unified_Ideograph", "Ideographic"},
    189237: {"Unified_Ideograph", "Ideographic"},
    189238: {"Unified_Ideograph", "Ideographic"},
    189239: {"Unified_Ideograph", "Ideographic"},
    189240: {"Unified_Ideograph", "Ideographic"},
    189241: {"Unified_Ideograph", "Ideographic"},
    189242: {"Unified_Ideograph", "Ideographic"},
    189243: {"Unified_Ideograph", "Ideographic"},
    189244: {"Unified_Ideograph", "Ideographic"},
    189245: {"Unified_Ideograph", "Ideographic"},
    189246: {"Unified_Ideograph", "Ideographic"},
    189247: {"Unified_Ideograph", "Ideographic"},
    189248: {"Unified_Ideograph", "Ideographic"},
    189249: {"Unified_Ideograph", "Ideographic"},
    189250: {"Unified_Ideograph", "Ideographic"},
    189251: {"Unified_Ideograph", "Ideographic"},
    189252: {"Unified_Ideograph", "Ideographic"},
    189253: {"Unified_Ideograph", "Ideographic"},
    189254: {"Unified_Ideograph", "Ideographic"},
    189255: {"Unified_Ideograph", "Ideographic"},
    189256: {"Unified_Ideograph", "Ideographic"},
    189257: {"Unified_Ideograph", "Ideographic"},
    189258: {"Unified_Ideograph", "Ideographic"},
    189259: {"Unified_Ideograph", "Ideographic"},
    189260: {"Unified_Ideograph", "Ideographic"},
    189261: {"Unified_Ideograph", "Ideographic"},
    189262: {"Unified_Ideograph", "Ideographic"},
    189263: {"Unified_Ideograph", "Ideographic"},
    189264: {"Unified_Ideograph", "Ideographic"},
    189265: {"Unified_Ideograph", "Ideographic"},
    189266: {"Unified_Ideograph", "Ideographic"},
    189267: {"Unified_Ideograph", "Ideographic"},
    189268: {"Unified_Ideograph", "Ideographic"},
    189269: {"Unified_Ideograph", "Ideographic"},
    189270: {"Unified_Ideograph", "Ideographic"},
    189271: {"Unified_Ideograph", "Ideographic"},
    189272: {"Unified_Ideograph", "Ideographic"},
    189273: {"Unified_Ideograph", "Ideographic"},
    189274: {"Unified_Ideograph", "Ideographic"},
    189275: {"Unified_Ideograph", "Ideographic"},
    189276: {"Unified_Ideograph", "Ideographic"},
    189277: {"Unified_Ideograph", "Ideographic"},
    189278: {"Unified_Ideograph", "Ideographic"},
    189279: {"Unified_Ideograph", "Ideographic"},
    189280: {"Unified_Ideograph", "Ideographic"},
    189281: {"Unified_Ideograph", "Ideographic"},
    189282: {"Unified_Ideograph", "Ideographic"},
    189283: {"Unified_Ideograph", "Ideographic"},
    189284: {"Unified_Ideograph", "Ideographic"},
    189285: {"Unified_Ideograph", "Ideographic"},
    189286: {"Unified_Ideograph", "Ideographic"},
    189287: {"Unified_Ideograph", "Ideographic"},
    189288: {"Unified_Ideograph", "Ideographic"},
    189289: {"Unified_Ideograph", "Ideographic"},
    189290: {"Unified_Ideograph", "Ideographic"},
    189291: {"Unified_Ideograph", "Ideographic"},
    189292: {"Unified_Ideograph", "Ideographic"},
    189293: {"Unified_Ideograph", "Ideographic"},
    189294: {"Unified_Ideograph", "Ideographic"},
    189295: {"Unified_Ideograph", "Ideographic"},
    189296: {"Unified_Ideograph", "Ideographic"},
    189297: {"Unified_Ideograph", "Ideographic"},
    189298: {"Unified_Ideograph", "Ideographic"},
    189299: {"Unified_Ideograph", "Ideographic"},
    189300: {"Unified_Ideograph", "Ideographic"},
    189301: {"Unified_Ideograph", "Ideographic"},
    189302: {"Unified_Ideograph", "Ideographic"},
    189303: {"Unified_Ideograph", "Ideographic"},
    189304: {"Unified_Ideograph", "Ideographic"},
    189305: {"Unified_Ideograph", "Ideographic"},
    189306: {"Unified_Ideograph", "Ideographic"},
    189307: {"Unified_Ideograph", "Ideographic"},
    189308: {"Unified_Ideograph", "Ideographic"},
    189309: {"Unified_Ideograph", "Ideographic"},
    189310: {"Unified_Ideograph", "Ideographic"},
    189311: {"Unified_Ideograph", "Ideographic"},
    189312: {"Unified_Ideograph", "Ideographic"},
    189313: {"Unified_Ideograph", "Ideographic"},
    189314: {"Unified_Ideograph", "Ideographic"},
    189315: {"Unified_Ideograph", "Ideographic"},
    189316: {"Unified_Ideograph", "Ideographic"},
    189317: {"Unified_Ideograph", "Ideographic"},
    189318: {"Unified_Ideograph", "Ideographic"},
    189319: {"Unified_Ideograph", "Ideographic"},
    189320: {"Unified_Ideograph", "Ideographic"},
    189321: {"Unified_Ideograph", "Ideographic"},
    189322: {"Unified_Ideograph", "Ideographic"},
    189323: {"Unified_Ideograph", "Ideographic"},
    189324: {"Unified_Ideograph", "Ideographic"},
    189325: {"Unified_Ideograph", "Ideographic"},
    189326: {"Unified_Ideograph", "Ideographic"},
    189327: {"Unified_Ideograph", "Ideographic"},
    189328: {"Unified_Ideograph", "Ideographic"},
    189329: {"Unified_Ideograph", "Ideographic"},
    189330: {"Unified_Ideograph", "Ideographic"},
    189331: {"Unified_Ideograph", "Ideographic"},
    189332: {"Unified_Ideograph", "Ideographic"},
    189333: {"Unified_Ideograph", "Ideographic"},
    189334: {"Unified_Ideograph", "Ideographic"},
    189335: {"Unified_Ideograph", "Ideographic"},
    189336: {"Unified_Ideograph", "Ideographic"},
    189337: {"Unified_Ideograph", "Ideographic"},
    189338: {"Unified_Ideograph", "Ideographic"},
    189339: {"Unified_Ideograph", "Ideographic"},
    189340: {"Unified_Ideograph", "Ideographic"},
    189341: {"Unified_Ideograph", "Ideographic"},
    189342: {"Unified_Ideograph", "Ideographic"},
    189343: {"Unified_Ideograph", "Ideographic"},
    189344: {"Unified_Ideograph", "Ideographic"},
    189345: {"Unified_Ideograph", "Ideographic"},
    189346: {"Unified_Ideograph", "Ideographic"},
    189347: {"Unified_Ideograph", "Ideographic"},
    189348: {"Unified_Ideograph", "Ideographic"},
    189349: {"Unified_Ideograph", "Ideographic"},
    189350: {"Unified_Ideograph", "Ideographic"},
    189351: {"Unified_Ideograph", "Ideographic"},
    189352: {"Unified_Ideograph", "Ideographic"},
    189353: {"Unified_Ideograph", "Ideographic"},
    189354: {"Unified_Ideograph", "Ideographic"},
    189355: {"Unified_Ideograph", "Ideographic"},
    189356: {"Unified_Ideograph", "Ideographic"},
    189357: {"Unified_Ideograph", "Ideographic"},
    189358: {"Unified_Ideograph", "Ideographic"},
    189359: {"Unified_Ideograph", "Ideographic"},
    189360: {"Unified_Ideograph", "Ideographic"},
    189361: {"Unified_Ideograph", "Ideographic"},
    189362: {"Unified_Ideograph", "Ideographic"},
    189363: {"Unified_Ideograph", "Ideographic"},
    189364: {"Unified_Ideograph", "Ideographic"},
    189365: {"Unified_Ideograph", "Ideographic"},
    189366: {"Unified_Ideograph", "Ideographic"},
    189367: {"Unified_Ideograph", "Ideographic"},
    189368: {"Unified_Ideograph", "Ideographic"},
    189369: {"Unified_Ideograph", "Ideographic"},
    189370: {"Unified_Ideograph", "Ideographic"},
    189371: {"Unified_Ideograph", "Ideographic"},
    189372: {"Unified_Ideograph", "Ideographic"},
    189373: {"Unified_Ideograph", "Ideographic"},
    189374: {"Unified_Ideograph", "Ideographic"},
    189375: {"Unified_Ideograph", "Ideographic"},
    189376: {"Unified_Ideograph", "Ideographic"},
    189377: {"Unified_Ideograph", "Ideographic"},
    189378: {"Unified_Ideograph", "Ideographic"},
    189379: {"Unified_Ideograph", "Ideographic"},
    189380: {"Unified_Ideograph", "Ideographic"},
    189381: {"Unified_Ideograph", "Ideographic"},
    189382: {"Unified_Ideograph", "Ideographic"},
    189383: {"Unified_Ideograph", "Ideographic"},
    189384: {"Unified_Ideograph", "Ideographic"},
    189385: {"Unified_Ideograph", "Ideographic"},
    189386: {"Unified_Ideograph", "Ideographic"},
    189387: {"Unified_Ideograph", "Ideographic"},
    189388: {"Unified_Ideograph", "Ideographic"},
    189389: {"Unified_Ideograph", "Ideographic"},
    189390: {"Unified_Ideograph", "Ideographic"},
    189391: {"Unified_Ideograph", "Ideographic"},
    189392: {"Unified_Ideograph", "Ideographic"},
    189393: {"Unified_Ideograph", "Ideographic"},
    189394: {"Unified_Ideograph", "Ideographic"},
    189395: {"Unified_Ideograph", "Ideographic"},
    189396: {"Unified_Ideograph", "Ideographic"},
    189397: {"Unified_Ideograph", "Ideographic"},
    189398: {"Unified_Ideograph", "Ideographic"},
    189399: {"Unified_Ideograph", "Ideographic"},
    189400: {"Unified_Ideograph", "Ideographic"},
    189401: {"Unified_Ideograph", "Ideographic"},
    189402: {"Unified_Ideograph", "Ideographic"},
    189403: {"Unified_Ideograph", "Ideographic"},
    189404: {"Unified_Ideograph", "Ideographic"},
    189405: {"Unified_Ideograph", "Ideographic"},
    189406: {"Unified_Ideograph", "Ideographic"},
    189407: {"Unified_Ideograph", "Ideographic"},
    189408: {"Unified_Ideograph", "Ideographic"},
    189409: {"Unified_Ideograph", "Ideographic"},
    189410: {"Unified_Ideograph", "Ideographic"},
    189411: {"Unified_Ideograph", "Ideographic"},
    189412: {"Unified_Ideograph", "Ideographic"},
    189413: {"Unified_Ideograph", "Ideographic"},
    189414: {"Unified_Ideograph", "Ideographic"},
    189415: {"Unified_Ideograph", "Ideographic"},
    189416: {"Unified_Ideograph", "Ideographic"},
    189417: {"Unified_Ideograph", "Ideographic"},
    189418: {"Unified_Ideograph", "Ideographic"},
    189419: {"Unified_Ideograph", "Ideographic"},
    189420: {"Unified_Ideograph", "Ideographic"},
    189421: {"Unified_Ideograph", "Ideographic"},
    189422: {"Unified_Ideograph", "Ideographic"},
    189423: {"Unified_Ideograph", "Ideographic"},
    189424: {"Unified_Ideograph", "Ideographic"},
    189425: {"Unified_Ideograph", "Ideographic"},
    189426: {"Unified_Ideograph", "Ideographic"},
    189427: {"Unified_Ideograph", "Ideographic"},
    189428: {"Unified_Ideograph", "Ideographic"},
    189429: {"Unified_Ideograph", "Ideographic"},
    189430: {"Unified_Ideograph", "Ideographic"},
    189431: {"Unified_Ideograph", "Ideographic"},
    189432: {"Unified_Ideograph", "Ideographic"},
    189433: {"Unified_Ideograph", "Ideographic"},
    189434: {"Unified_Ideograph", "Ideographic"},
    189435: {"Unified_Ideograph", "Ideographic"},
    189436: {"Unified_Ideograph", "Ideographic"},
    189437: {"Unified_Ideograph", "Ideographic"},
    189438: {"Unified_Ideograph", "Ideographic"},
    189439: {"Unified_Ideograph", "Ideographic"},
    189440: {"Unified_Ideograph", "Ideographic"},
    189441: {"Unified_Ideograph", "Ideographic"},
    189442: {"Unified_Ideograph", "Ideographic"},
    189443: {"Unified_Ideograph", "Ideographic"},
    189444: {"Unified_Ideograph", "Ideographic"},
    189445: {"Unified_Ideograph", "Ideographic"},
    189446: {"Unified_Ideograph", "Ideographic"},
    189447: {"Unified_Ideograph", "Ideographic"},
    189448: {"Unified_Ideograph", "Ideographic"},
    189449: {"Unified_Ideograph", "Ideographic"},
    189450: {"Unified_Ideograph", "Ideographic"},
    189451: {"Unified_Ideograph", "Ideographic"},
    189452: {"Unified_Ideograph", "Ideographic"},
    189453: {"Unified_Ideograph", "Ideographic"},
    189454: {"Unified_Ideograph", "Ideographic"},
    189455: {"Unified_Ideograph", "Ideographic"},
    189456: {"Unified_Ideograph", "Ideographic"},
    189457: {"Unified_Ideograph", "Ideographic"},
    189458: {"Unified_Ideograph", "Ideographic"},
    189459: {"Unified_Ideograph", "Ideographic"},
    189460: {"Unified_Ideograph", "Ideographic"},
    189461: {"Unified_Ideograph", "Ideographic"},
    189462: {"Unified_Ideograph", "Ideographic"},
    189463: {"Unified_Ideograph", "Ideographic"},
    189464: {"Unified_Ideograph", "Ideographic"},
    189465: {"Unified_Ideograph", "Ideographic"},
    189466: {"Unified_Ideograph", "Ideographic"},
    189467: {"Unified_Ideograph", "Ideographic"},
    189468: {"Unified_Ideograph", "Ideographic"},
    189469: {"Unified_Ideograph", "Ideographic"},
    189470: {"Unified_Ideograph", "Ideographic"},
    189471: {"Unified_Ideograph", "Ideographic"},
    189472: {"Unified_Ideograph", "Ideographic"},
    189473: {"Unified_Ideograph", "Ideographic"},
    189474: {"Unified_Ideograph", "Ideographic"},
    189475: {"Unified_Ideograph", "Ideographic"},
    189476: {"Unified_Ideograph", "Ideographic"},
    189477: {"Unified_Ideograph", "Ideographic"},
    189478: {"Unified_Ideograph", "Ideographic"},
    189479: {"Unified_Ideograph", "Ideographic"},
    189480: {"Unified_Ideograph", "Ideographic"},
    189481: {"Unified_Ideograph", "Ideographic"},
    189482: {"Unified_Ideograph", "Ideographic"},
    189483: {"Unified_Ideograph", "Ideographic"},
    189484: {"Unified_Ideograph", "Ideographic"},
    189485: {"Unified_Ideograph", "Ideographic"},
    189486: {"Unified_Ideograph", "Ideographic"},
    189487: {"Unified_Ideograph", "Ideographic"},
    189488: {"Unified_Ideograph", "Ideographic"},
    189489: {"Unified_Ideograph", "Ideographic"},
    189490: {"Unified_Ideograph", "Ideographic"},
    189491: {"Unified_Ideograph", "Ideographic"},
    189492: {"Unified_Ideograph", "Ideographic"},
    189493: {"Unified_Ideograph", "Ideographic"},
    189494: {"Unified_Ideograph", "Ideographic"},
    189495: {"Unified_Ideograph", "Ideographic"},
    189496: {"Unified_Ideograph", "Ideographic"},
    189497: {"Unified_Ideograph", "Ideographic"},
    189498: {"Unified_Ideograph", "Ideographic"},
    189499: {"Unified_Ideograph", "Ideographic"},
    189500: {"Unified_Ideograph", "Ideographic"},
    189501: {"Unified_Ideograph", "Ideographic"},
    189502: {"Unified_Ideograph", "Ideographic"},
    189503: {"Unified_Ideograph", "Ideographic"},
    189504: {"Unified_Ideograph", "Ideographic"},
    189505: {"Unified_Ideograph", "Ideographic"},
    189506: {"Unified_Ideograph", "Ideographic"},
    189507: {"Unified_Ideograph", "Ideographic"},
    189508: {"Unified_Ideograph", "Ideographic"},
    189509: {"Unified_Ideograph", "Ideographic"},
    189510: {"Unified_Ideograph", "Ideographic"},
    189511: {"Unified_Ideograph", "Ideographic"},
    189512: {"Unified_Ideograph", "Ideographic"},
    189513: {"Unified_Ideograph", "Ideographic"},
    189514: {"Unified_Ideograph", "Ideographic"},
    189515: {"Unified_Ideograph", "Ideographic"},
    189516: {"Unified_Ideograph", "Ideographic"},
    189517: {"Unified_Ideograph", "Ideographic"},
    189518: {"Unified_Ideograph", "Ideographic"},
    189519: {"Unified_Ideograph", "Ideographic"},
    189520: {"Unified_Ideograph", "Ideographic"},
    189521: {"Unified_Ideograph", "Ideographic"},
    189522: {"Unified_Ideograph", "Ideographic"},
    189523: {"Unified_Ideograph", "Ideographic"},
    189524: {"Unified_Ideograph", "Ideographic"},
    189525: {"Unified_Ideograph", "Ideographic"},
    189526: {"Unified_Ideograph", "Ideographic"},
    189527: {"Unified_Ideograph", "Ideographic"},
    189528: {"Unified_Ideograph", "Ideographic"},
    189529: {"Unified_Ideograph", "Ideographic"},
    189530: {"Unified_Ideograph", "Ideographic"},
    189531: {"Unified_Ideograph", "Ideographic"},
    189532: {"Unified_Ideograph", "Ideographic"},
    189533: {"Unified_Ideograph", "Ideographic"},
    189534: {"Unified_Ideograph", "Ideographic"},
    189535: {"Unified_Ideograph", "Ideographic"},
    189536: {"Unified_Ideograph", "Ideographic"},
    189537: {"Unified_Ideograph", "Ideographic"},
    189538: {"Unified_Ideograph", "Ideographic"},
    189539: {"Unified_Ideograph", "Ideographic"},
    189540: {"Unified_Ideograph", "Ideographic"},
    189541: {"Unified_Ideograph", "Ideographic"},
    189542: {"Unified_Ideograph", "Ideographic"},
    189543: {"Unified_Ideograph", "Ideographic"},
    189544: {"Unified_Ideograph", "Ideographic"},
    189545: {"Unified_Ideograph", "Ideographic"},
    189546: {"Unified_Ideograph", "Ideographic"},
    189547: {"Unified_Ideograph", "Ideographic"},
    189548: {"Unified_Ideograph", "Ideographic"},
    189549: {"Unified_Ideograph", "Ideographic"},
    189550: {"Unified_Ideograph", "Ideographic"},
    189551: {"Unified_Ideograph", "Ideographic"},
    189552: {"Unified_Ideograph", "Ideographic"},
    189553: {"Unified_Ideograph", "Ideographic"},
    189554: {"Unified_Ideograph", "Ideographic"},
    189555: {"Unified_Ideograph", "Ideographic"},
    189556: {"Unified_Ideograph", "Ideographic"},
    189557: {"Unified_Ideograph", "Ideographic"},
    189558: {"Unified_Ideograph", "Ideographic"},
    189559: {"Unified_Ideograph", "Ideographic"},
    189560: {"Unified_Ideograph", "Ideographic"},
    189561: {"Unified_Ideograph", "Ideographic"},
    189562: {"Unified_Ideograph", "Ideographic"},
    189563: {"Unified_Ideograph", "Ideographic"},
    189564: {"Unified_Ideograph", "Ideographic"},
    189565: {"Unified_Ideograph", "Ideographic"},
    189566: {"Unified_Ideograph", "Ideographic"},
    189567: {"Unified_Ideograph", "Ideographic"},
    189568: {"Unified_Ideograph", "Ideographic"},
    189569: {"Unified_Ideograph", "Ideographic"},
    189570: {"Unified_Ideograph", "Ideographic"},
    189571: {"Unified_Ideograph", "Ideographic"},
    189572: {"Unified_Ideograph", "Ideographic"},
    189573: {"Unified_Ideograph", "Ideographic"},
    189574: {"Unified_Ideograph", "Ideographic"},
    189575: {"Unified_Ideograph", "Ideographic"},
    189576: {"Unified_Ideograph", "Ideographic"},
    189577: {"Unified_Ideograph", "Ideographic"},
    189578: {"Unified_Ideograph", "Ideographic"},
    189579: {"Unified_Ideograph", "Ideographic"},
    189580: {"Unified_Ideograph", "Ideographic"},
    189581: {"Unified_Ideograph", "Ideographic"},
    189582: {"Unified_Ideograph", "Ideographic"},
    189583: {"Unified_Ideograph", "Ideographic"},
    189584: {"Unified_Ideograph", "Ideographic"},
    189585: {"Unified_Ideograph", "Ideographic"},
    189586: {"Unified_Ideograph", "Ideographic"},
    189587: {"Unified_Ideograph", "Ideographic"},
    189588: {"Unified_Ideograph", "Ideographic"},
    189589: {"Unified_Ideograph", "Ideographic"},
    189590: {"Unified_Ideograph", "Ideographic"},
    189591: {"Unified_Ideograph", "Ideographic"},
    189592: {"Unified_Ideograph", "Ideographic"},
    189593: {"Unified_Ideograph", "Ideographic"},
    189594: {"Unified_Ideograph", "Ideographic"},
    189595: {"Unified_Ideograph", "Ideographic"},
    189596: {"Unified_Ideograph", "Ideographic"},
    189597: {"Unified_Ideograph", "Ideographic"},
    189598: {"Unified_Ideograph", "Ideographic"},
    189599: {"Unified_Ideograph", "Ideographic"},
    189600: {"Unified_Ideograph", "Ideographic"},
    189601: {"Unified_Ideograph", "Ideographic"},
    189602: {"Unified_Ideograph", "Ideographic"},
    189603: {"Unified_Ideograph", "Ideographic"},
    189604: {"Unified_Ideograph", "Ideographic"},
    189605: {"Unified_Ideograph", "Ideographic"},
    189606: {"Unified_Ideograph", "Ideographic"},
    189607: {"Unified_Ideograph", "Ideographic"},
    189608: {"Unified_Ideograph", "Ideographic"},
    189609: {"Unified_Ideograph", "Ideographic"},
    189610: {"Unified_Ideograph", "Ideographic"},
    189611: {"Unified_Ideograph", "Ideographic"},
    189612: {"Unified_Ideograph", "Ideographic"},
    189613: {"Unified_Ideograph", "Ideographic"},
    189614: {"Unified_Ideograph", "Ideographic"},
    189615: {"Unified_Ideograph", "Ideographic"},
    189616: {"Unified_Ideograph", "Ideographic"},
    189617: {"Unified_Ideograph", "Ideographic"},
    189618: {"Unified_Ideograph", "Ideographic"},
    189619: {"Unified_Ideograph", "Ideographic"},
    189620: {"Unified_Ideograph", "Ideographic"},
    189621: {"Unified_Ideograph", "Ideographic"},
    189622: {"Unified_Ideograph", "Ideographic"},
    189623: {"Unified_Ideograph", "Ideographic"},
    189624: {"Unified_Ideograph", "Ideographic"},
    189625: {"Unified_Ideograph", "Ideographic"},
    189626: {"Unified_Ideograph", "Ideographic"},
    189627: {"Unified_Ideograph", "Ideographic"},
    189628: {"Unified_Ideograph", "Ideographic"},
    189629: {"Unified_Ideograph", "Ideographic"},
    189630: {"Unified_Ideograph", "Ideographic"},
    189631: {"Unified_Ideograph", "Ideographic"},
    189632: {"Unified_Ideograph", "Ideographic"},
    189633: {"Unified_Ideograph", "Ideographic"},
    189634: {"Unified_Ideograph", "Ideographic"},
    189635: {"Unified_Ideograph", "Ideographic"},
    189636: {"Unified_Ideograph", "Ideographic"},
    189637: {"Unified_Ideograph", "Ideographic"},
    189638: {"Unified_Ideograph", "Ideographic"},
    189639: {"Unified_Ideograph", "Ideographic"},
    189640: {"Unified_Ideograph", "Ideographic"},
    189641: {"Unified_Ideograph", "Ideographic"},
    189642: {"Unified_Ideograph", "Ideographic"},
    189643: {"Unified_Ideograph", "Ideographic"},
    189644: {"Unified_Ideograph", "Ideographic"},
    189645: {"Unified_Ideograph", "Ideographic"},
    189646: {"Unified_Ideograph", "Ideographic"},
    189647: {"Unified_Ideograph", "Ideographic"},
    189648: {"Unified_Ideograph", "Ideographic"},
    189649: {"Unified_Ideograph", "Ideographic"},
    189650: {"Unified_Ideograph", "Ideographic"},
    189651: {"Unified_Ideograph", "Ideographic"},
    189652: {"Unified_Ideograph", "Ideographic"},
    189653: {"Unified_Ideograph", "Ideographic"},
    189654: {"Unified_Ideograph", "Ideographic"},
    189655: {"Unified_Ideograph", "Ideographic"},
    189656: {"Unified_Ideograph", "Ideographic"},
    189657: {"Unified_Ideograph", "Ideographic"},
    189658: {"Unified_Ideograph", "Ideographic"},
    189659: {"Unified_Ideograph", "Ideographic"},
    189660: {"Unified_Ideograph", "Ideographic"},
    189661: {"Unified_Ideograph", "Ideographic"},
    189662: {"Unified_Ideograph", "Ideographic"},
    189663: {"Unified_Ideograph", "Ideographic"},
    189664: {"Unified_Ideograph", "Ideographic"},
    189665: {"Unified_Ideograph", "Ideographic"},
    189666: {"Unified_Ideograph", "Ideographic"},
    189667: {"Unified_Ideograph", "Ideographic"},
    189668: {"Unified_Ideograph", "Ideographic"},
    189669: {"Unified_Ideograph", "Ideographic"},
    189670: {"Unified_Ideograph", "Ideographic"},
    189671: {"Unified_Ideograph", "Ideographic"},
    189672: {"Unified_Ideograph", "Ideographic"},
    189673: {"Unified_Ideograph", "Ideographic"},
    189674: {"Unified_Ideograph", "Ideographic"},
    189675: {"Unified_Ideograph", "Ideographic"},
    189676: {"Unified_Ideograph", "Ideographic"},
    189677: {"Unified_Ideograph", "Ideographic"},
    189678: {"Unified_Ideograph", "Ideographic"},
    189679: {"Unified_Ideograph", "Ideographic"},
    189680: {"Unified_Ideograph", "Ideographic"},
    189681: {"Unified_Ideograph", "Ideographic"},
    189682: {"Unified_Ideograph", "Ideographic"},
    189683: {"Unified_Ideograph", "Ideographic"},
    189684: {"Unified_Ideograph", "Ideographic"},
    189685: {"Unified_Ideograph", "Ideographic"},
    189686: {"Unified_Ideograph", "Ideographic"},
    189687: {"Unified_Ideograph", "Ideographic"},
    189688: {"Unified_Ideograph", "Ideographic"},
    189689: {"Unified_Ideograph", "Ideographic"},
    189690: {"Unified_Ideograph", "Ideographic"},
    189691: {"Unified_Ideograph", "Ideographic"},
    189692: {"Unified_Ideograph", "Ideographic"},
    189693: {"Unified_Ideograph", "Ideographic"},
    189694: {"Unified_Ideograph", "Ideographic"},
    189695: {"Unified_Ideograph", "Ideographic"},
    189696: {"Unified_Ideograph", "Ideographic"},
    189697: {"Unified_Ideograph", "Ideographic"},
    189698: {"Unified_Ideograph", "Ideographic"},
    189699: {"Unified_Ideograph", "Ideographic"},
    189700: {"Unified_Ideograph", "Ideographic"},
    189701: {"Unified_Ideograph", "Ideographic"},
    189702: {"Unified_Ideograph", "Ideographic"},
    189703: {"Unified_Ideograph", "Ideographic"},
    189704: {"Unified_Ideograph", "Ideographic"},
    189705: {"Unified_Ideograph", "Ideographic"},
    189706: {"Unified_Ideograph", "Ideographic"},
    189707: {"Unified_Ideograph", "Ideographic"},
    189708: {"Unified_Ideograph", "Ideographic"},
    189709: {"Unified_Ideograph", "Ideographic"},
    189710: {"Unified_Ideograph", "Ideographic"},
    189711: {"Unified_Ideograph", "Ideographic"},
    189712: {"Unified_Ideograph", "Ideographic"},
    189713: {"Unified_Ideograph", "Ideographic"},
    189714: {"Unified_Ideograph", "Ideographic"},
    189715: {"Unified_Ideograph", "Ideographic"},
    189716: {"Unified_Ideograph", "Ideographic"},
    189717: {"Unified_Ideograph", "Ideographic"},
    189718: {"Unified_Ideograph", "Ideographic"},
    189719: {"Unified_Ideograph", "Ideographic"},
    189720: {"Unified_Ideograph", "Ideographic"},
    189721: {"Unified_Ideograph", "Ideographic"},
    189722: {"Unified_Ideograph", "Ideographic"},
    189723: {"Unified_Ideograph", "Ideographic"},
    189724: {"Unified_Ideograph", "Ideographic"},
    189725: {"Unified_Ideograph", "Ideographic"},
    189726: {"Unified_Ideograph", "Ideographic"},
    189727: {"Unified_Ideograph", "Ideographic"},
    189728: {"Unified_Ideograph", "Ideographic"},
    189729: {"Unified_Ideograph", "Ideographic"},
    189730: {"Unified_Ideograph", "Ideographic"},
    189731: {"Unified_Ideograph", "Ideographic"},
    189732: {"Unified_Ideograph", "Ideographic"},
    189733: {"Unified_Ideograph", "Ideographic"},
    189734: {"Unified_Ideograph", "Ideographic"},
    189735: {"Unified_Ideograph", "Ideographic"},
    189736: {"Unified_Ideograph", "Ideographic"},
    189737: {"Unified_Ideograph", "Ideographic"},
    189738: {"Unified_Ideograph", "Ideographic"},
    189739: {"Unified_Ideograph", "Ideographic"},
    189740: {"Unified_Ideograph", "Ideographic"},
    189741: {"Unified_Ideograph", "Ideographic"},
    189742: {"Unified_Ideograph", "Ideographic"},
    189743: {"Unified_Ideograph", "Ideographic"},
    189744: {"Unified_Ideograph", "Ideographic"},
    189745: {"Unified_Ideograph", "Ideographic"},
    189746: {"Unified_Ideograph", "Ideographic"},
    189747: {"Unified_Ideograph", "Ideographic"},
    189748: {"Unified_Ideograph", "Ideographic"},
    189749: {"Unified_Ideograph", "Ideographic"},
    189750: {"Unified_Ideograph", "Ideographic"},
    189751: {"Unified_Ideograph", "Ideographic"},
    189752: {"Unified_Ideograph", "Ideographic"},
    189753: {"Unified_Ideograph", "Ideographic"},
    189754: {"Unified_Ideograph", "Ideographic"},
    189755: {"Unified_Ideograph", "Ideographic"},
    189756: {"Unified_Ideograph", "Ideographic"},
    189757: {"Unified_Ideograph", "Ideographic"},
    189758: {"Unified_Ideograph", "Ideographic"},
    189759: {"Unified_Ideograph", "Ideographic"},
    189760: {"Unified_Ideograph", "Ideographic"},
    189761: {"Unified_Ideograph", "Ideographic"},
    189762: {"Unified_Ideograph", "Ideographic"},
    189763: {"Unified_Ideograph", "Ideographic"},
    189764: {"Unified_Ideograph", "Ideographic"},
    189765: {"Unified_Ideograph", "Ideographic"},
    189766: {"Unified_Ideograph", "Ideographic"},
    189767: {"Unified_Ideograph", "Ideographic"},
    189768: {"Unified_Ideograph", "Ideographic"},
    189769: {"Unified_Ideograph", "Ideographic"},
    189770: {"Unified_Ideograph", "Ideographic"},
    189771: {"Unified_Ideograph", "Ideographic"},
    189772: {"Unified_Ideograph", "Ideographic"},
    189773: {"Unified_Ideograph", "Ideographic"},
    189774: {"Unified_Ideograph", "Ideographic"},
    189775: {"Unified_Ideograph", "Ideographic"},
    189776: {"Unified_Ideograph", "Ideographic"},
    189777: {"Unified_Ideograph", "Ideographic"},
    189778: {"Unified_Ideograph", "Ideographic"},
    189779: {"Unified_Ideograph", "Ideographic"},
    189780: {"Unified_Ideograph", "Ideographic"},
    189781: {"Unified_Ideograph", "Ideographic"},
    189782: {"Unified_Ideograph", "Ideographic"},
    189783: {"Unified_Ideograph", "Ideographic"},
    189784: {"Unified_Ideograph", "Ideographic"},
    189785: {"Unified_Ideograph", "Ideographic"},
    189786: {"Unified_Ideograph", "Ideographic"},
    189787: {"Unified_Ideograph", "Ideographic"},
    189788: {"Unified_Ideograph", "Ideographic"},
    189789: {"Unified_Ideograph", "Ideographic"},
    189790: {"Unified_Ideograph", "Ideographic"},
    189791: {"Unified_Ideograph", "Ideographic"},
    189792: {"Unified_Ideograph", "Ideographic"},
    189793: {"Unified_Ideograph", "Ideographic"},
    189794: {"Unified_Ideograph", "Ideographic"},
    189795: {"Unified_Ideograph", "Ideographic"},
    189796: {"Unified_Ideograph", "Ideographic"},
    189797: {"Unified_Ideograph", "Ideographic"},
    189798: {"Unified_Ideograph", "Ideographic"},
    189799: {"Unified_Ideograph", "Ideographic"},
    189800: {"Unified_Ideograph", "Ideographic"},
    189801: {"Unified_Ideograph", "Ideographic"},
    189802: {"Unified_Ideograph", "Ideographic"},
    189803: {"Unified_Ideograph", "Ideographic"},
    189804: {"Unified_Ideograph", "Ideographic"},
    189805: {"Unified_Ideograph", "Ideographic"},
    189806: {"Unified_Ideograph", "Ideographic"},
    189807: {"Unified_Ideograph", "Ideographic"},
    189808: {"Unified_Ideograph", "Ideographic"},
    189809: {"Unified_Ideograph", "Ideographic"},
    189810: {"Unified_Ideograph", "Ideographic"},
    189811: {"Unified_Ideograph", "Ideographic"},
    189812: {"Unified_Ideograph", "Ideographic"},
    189813: {"Unified_Ideograph", "Ideographic"},
    189814: {"Unified_Ideograph", "Ideographic"},
    189815: {"Unified_Ideograph", "Ideographic"},
    189816: {"Unified_Ideograph", "Ideographic"},
    189817: {"Unified_Ideograph", "Ideographic"},
    189818: {"Unified_Ideograph", "Ideographic"},
    189819: {"Unified_Ideograph", "Ideographic"},
    189820: {"Unified_Ideograph", "Ideographic"},
    189821: {"Unified_Ideograph", "Ideographic"},
    189822: {"Unified_Ideograph", "Ideographic"},
    189823: {"Unified_Ideograph", "Ideographic"},
    189824: {"Unified_Ideograph", "Ideographic"},
    189825: {"Unified_Ideograph", "Ideographic"},
    189826: {"Unified_Ideograph", "Ideographic"},
    189827: {"Unified_Ideograph", "Ideographic"},
    189828: {"Unified_Ideograph", "Ideographic"},
    189829: {"Unified_Ideograph", "Ideographic"},
    189830: {"Unified_Ideograph", "Ideographic"},
    189831: {"Unified_Ideograph", "Ideographic"},
    189832: {"Unified_Ideograph", "Ideographic"},
    189833: {"Unified_Ideograph", "Ideographic"},
    189834: {"Unified_Ideograph", "Ideographic"},
    189835: {"Unified_Ideograph", "Ideographic"},
    189836: {"Unified_Ideograph", "Ideographic"},
    189837: {"Unified_Ideograph", "Ideographic"},
    189838: {"Unified_Ideograph", "Ideographic"},
    189839: {"Unified_Ideograph", "Ideographic"},
    189840: {"Unified_Ideograph", "Ideographic"},
    189841: {"Unified_Ideograph", "Ideographic"},
    189842: {"Unified_Ideograph", "Ideographic"},
    189843: {"Unified_Ideograph", "Ideographic"},
    189844: {"Unified_Ideograph", "Ideographic"},
    189845: {"Unified_Ideograph", "Ideographic"},
    189846: {"Unified_Ideograph", "Ideographic"},
    189847: {"Unified_Ideograph", "Ideographic"},
    189848: {"Unified_Ideograph", "Ideographic"},
    189849: {"Unified_Ideograph", "Ideographic"},
    189850: {"Unified_Ideograph", "Ideographic"},
    189851: {"Unified_Ideograph", "Ideographic"},
    189852: {"Unified_Ideograph", "Ideographic"},
    189853: {"Unified_Ideograph", "Ideographic"},
    189854: {"Unified_Ideograph", "Ideographic"},
    189855: {"Unified_Ideograph", "Ideographic"},
    189856: {"Unified_Ideograph", "Ideographic"},
    189857: {"Unified_Ideograph", "Ideographic"},
    189858: {"Unified_Ideograph", "Ideographic"},
    189859: {"Unified_Ideograph", "Ideographic"},
    189860: {"Unified_Ideograph", "Ideographic"},
    189861: {"Unified_Ideograph", "Ideographic"},
    189862: {"Unified_Ideograph", "Ideographic"},
    189863: {"Unified_Ideograph", "Ideographic"},
    189864: {"Unified_Ideograph", "Ideographic"},
    189865: {"Unified_Ideograph", "Ideographic"},
    189866: {"Unified_Ideograph", "Ideographic"},
    189867: {"Unified_Ideograph", "Ideographic"},
    189868: {"Unified_Ideograph", "Ideographic"},
    189869: {"Unified_Ideograph", "Ideographic"},
    189870: {"Unified_Ideograph", "Ideographic"},
    189871: {"Unified_Ideograph", "Ideographic"},
    189872: {"Unified_Ideograph", "Ideographic"},
    189873: {"Unified_Ideograph", "Ideographic"},
    189874: {"Unified_Ideograph", "Ideographic"},
    189875: {"Unified_Ideograph", "Ideographic"},
    189876: {"Unified_Ideograph", "Ideographic"},
    189877: {"Unified_Ideograph", "Ideographic"},
    189878: {"Unified_Ideograph", "Ideographic"},
    189879: {"Unified_Ideograph", "Ideographic"},
    189880: {"Unified_Ideograph", "Ideographic"},
    189881: {"Unified_Ideograph", "Ideographic"},
    189882: {"Unified_Ideograph", "Ideographic"},
    189883: {"Unified_Ideograph", "Ideographic"},
    189884: {"Unified_Ideograph", "Ideographic"},
    189885: {"Unified_Ideograph", "Ideographic"},
    189886: {"Unified_Ideograph", "Ideographic"},
    189887: {"Unified_Ideograph", "Ideographic"},
    189888: {"Unified_Ideograph", "Ideographic"},
    189889: {"Unified_Ideograph", "Ideographic"},
    189890: {"Unified_Ideograph", "Ideographic"},
    189891: {"Unified_Ideograph", "Ideographic"},
    189892: {"Unified_Ideograph", "Ideographic"},
    189893: {"Unified_Ideograph", "Ideographic"},
    189894: {"Unified_Ideograph", "Ideographic"},
    189895: {"Unified_Ideograph", "Ideographic"},
    189896: {"Unified_Ideograph", "Ideographic"},
    189897: {"Unified_Ideograph", "Ideographic"},
    189898: {"Unified_Ideograph", "Ideographic"},
    189899: {"Unified_Ideograph", "Ideographic"},
    189900: {"Unified_Ideograph", "Ideographic"},
    189901: {"Unified_Ideograph", "Ideographic"},
    189902: {"Unified_Ideograph", "Ideographic"},
    189903: {"Unified_Ideograph", "Ideographic"},
    189904: {"Unified_Ideograph", "Ideographic"},
    189905: {"Unified_Ideograph", "Ideographic"},
    189906: {"Unified_Ideograph", "Ideographic"},
    189907: {"Unified_Ideograph", "Ideographic"},
    189908: {"Unified_Ideograph", "Ideographic"},
    189909: {"Unified_Ideograph", "Ideographic"},
    189910: {"Unified_Ideograph", "Ideographic"},
    189911: {"Unified_Ideograph", "Ideographic"},
    189912: {"Unified_Ideograph", "Ideographic"},
    189913: {"Unified_Ideograph", "Ideographic"},
    189914: {"Unified_Ideograph", "Ideographic"},
    189915: {"Unified_Ideograph", "Ideographic"},
    189916: {"Unified_Ideograph", "Ideographic"},
    189917: {"Unified_Ideograph", "Ideographic"},
    189918: {"Unified_Ideograph", "Ideographic"},
    189919: {"Unified_Ideograph", "Ideographic"},
    189920: {"Unified_Ideograph", "Ideographic"},
    189921: {"Unified_Ideograph", "Ideographic"},
    189922: {"Unified_Ideograph", "Ideographic"},
    189923: {"Unified_Ideograph", "Ideographic"},
    189924: {"Unified_Ideograph", "Ideographic"},
    189925: {"Unified_Ideograph", "Ideographic"},
    189926: {"Unified_Ideograph", "Ideographic"},
    189927: {"Unified_Ideograph", "Ideographic"},
    189928: {"Unified_Ideograph", "Ideographic"},
    189929: {"Unified_Ideograph", "Ideographic"},
    189930: {"Unified_Ideograph", "Ideographic"},
    189931: {"Unified_Ideograph", "Ideographic"},
    189932: {"Unified_Ideograph", "Ideographic"},
    189933: {"Unified_Ideograph", "Ideographic"},
    189934: {"Unified_Ideograph", "Ideographic"},
    189935: {"Unified_Ideograph", "Ideographic"},
    189936: {"Unified_Ideograph", "Ideographic"},
    189937: {"Unified_Ideograph", "Ideographic"},
    189938: {"Unified_Ideograph", "Ideographic"},
    189939: {"Unified_Ideograph", "Ideographic"},
    189940: {"Unified_Ideograph", "Ideographic"},
    189941: {"Unified_Ideograph", "Ideographic"},
    189942: {"Unified_Ideograph", "Ideographic"},
    189943: {"Unified_Ideograph", "Ideographic"},
    189944: {"Unified_Ideograph", "Ideographic"},
    189945: {"Unified_Ideograph", "Ideographic"},
    189946: {"Unified_Ideograph", "Ideographic"},
    189947: {"Unified_Ideograph", "Ideographic"},
    189948: {"Unified_Ideograph", "Ideographic"},
    189949: {"Unified_Ideograph", "Ideographic"},
    189950: {"Unified_Ideograph", "Ideographic"},
    189951: {"Unified_Ideograph", "Ideographic"},
    189952: {"Unified_Ideograph", "Ideographic"},
    189953: {"Unified_Ideograph", "Ideographic"},
    189954: {"Unified_Ideograph", "Ideographic"},
    189955: {"Unified_Ideograph", "Ideographic"},
    189956: {"Unified_Ideograph", "Ideographic"},
    189957: {"Unified_Ideograph", "Ideographic"},
    189958: {"Unified_Ideograph", "Ideographic"},
    189959: {"Unified_Ideograph", "Ideographic"},
    189960: {"Unified_Ideograph", "Ideographic"},
    189961: {"Unified_Ideograph", "Ideographic"},
    189962: {"Unified_Ideograph", "Ideographic"},
    189963: {"Unified_Ideograph", "Ideographic"},
    189964: {"Unified_Ideograph", "Ideographic"},
    189965: {"Unified_Ideograph", "Ideographic"},
    189966: {"Unified_Ideograph", "Ideographic"},
    189967: {"Unified_Ideograph", "Ideographic"},
    189968: {"Unified_Ideograph", "Ideographic"},
    189969: {"Unified_Ideograph", "Ideographic"},
    189970: {"Unified_Ideograph", "Ideographic"},
    189971: {"Unified_Ideograph", "Ideographic"},
    189972: {"Unified_Ideograph", "Ideographic"},
    189973: {"Unified_Ideograph", "Ideographic"},
    189974: {"Unified_Ideograph", "Ideographic"},
    189975: {"Unified_Ideograph", "Ideographic"},
    189976: {"Unified_Ideograph", "Ideographic"},
    189977: {"Unified_Ideograph", "Ideographic"},
    189978: {"Unified_Ideograph", "Ideographic"},
    189979: {"Unified_Ideograph", "Ideographic"},
    189980: {"Unified_Ideograph", "Ideographic"},
    189981: {"Unified_Ideograph", "Ideographic"},
    189982: {"Unified_Ideograph", "Ideographic"},
    189983: {"Unified_Ideograph", "Ideographic"},
    189984: {"Unified_Ideograph", "Ideographic"},
    189985: {"Unified_Ideograph", "Ideographic"},
    189986: {"Unified_Ideograph", "Ideographic"},
    189987: {"Unified_Ideograph", "Ideographic"},
    189988: {"Unified_Ideograph", "Ideographic"},
    189989: {"Unified_Ideograph", "Ideographic"},
    189990: {"Unified_Ideograph", "Ideographic"},
    189991: {"Unified_Ideograph", "Ideographic"},
    189992: {"Unified_Ideograph", "Ideographic"},
    189993: {"Unified_Ideograph", "Ideographic"},
    189994: {"Unified_Ideograph", "Ideographic"},
    189995: {"Unified_Ideograph", "Ideographic"},
    189996: {"Unified_Ideograph", "Ideographic"},
    189997: {"Unified_Ideograph", "Ideographic"},
    189998: {"Unified_Ideograph", "Ideographic"},
    189999: {"Unified_Ideograph", "Ideographic"},
    190000: {"Unified_Ideograph", "Ideographic"},
    190001: {"Unified_Ideograph", "Ideographic"},
    190002: {"Unified_Ideograph", "Ideographic"},
    190003: {"Unified_Ideograph", "Ideographic"},
    190004: {"Unified_Ideograph", "Ideographic"},
    190005: {"Unified_Ideograph", "Ideographic"},
    190006: {"Unified_Ideograph", "Ideographic"},
    190007: {"Unified_Ideograph", "Ideographic"},
    190008: {"Unified_Ideograph", "Ideographic"},
    190009: {"Unified_Ideograph", "Ideographic"},
    190010: {"Unified_Ideograph", "Ideographic"},
    190011: {"Unified_Ideograph", "Ideographic"},
    190012: {"Unified_Ideograph", "Ideographic"},
    190013: {"Unified_Ideograph", "Ideographic"},
    190014: {"Unified_Ideograph", "Ideographic"},
    190015: {"Unified_Ideograph", "Ideographic"},
    190016: {"Unified_Ideograph", "Ideographic"},
    190017: {"Unified_Ideograph", "Ideographic"},
    190018: {"Unified_Ideograph", "Ideographic"},
    190019: {"Unified_Ideograph", "Ideographic"},
    190020: {"Unified_Ideograph", "Ideographic"},
    190021: {"Unified_Ideograph", "Ideographic"},
    190022: {"Unified_Ideograph", "Ideographic"},
    190023: {"Unified_Ideograph", "Ideographic"},
    190024: {"Unified_Ideograph", "Ideographic"},
    190025: {"Unified_Ideograph", "Ideographic"},
    190026: {"Unified_Ideograph", "Ideographic"},
    190027: {"Unified_Ideograph", "Ideographic"},
    190028: {"Unified_Ideograph", "Ideographic"},
    190029: {"Unified_Ideograph", "Ideographic"},
    190030: {"Unified_Ideograph", "Ideographic"},
    190031: {"Unified_Ideograph", "Ideographic"},
    190032: {"Unified_Ideograph", "Ideographic"},
    190033: {"Unified_Ideograph", "Ideographic"},
    190034: {"Unified_Ideograph", "Ideographic"},
    190035: {"Unified_Ideograph", "Ideographic"},
    190036: {"Unified_Ideograph", "Ideographic"},
    190037: {"Unified_Ideograph", "Ideographic"},
    190038: {"Unified_Ideograph", "Ideographic"},
    190039: {"Unified_Ideograph", "Ideographic"},
    190040: {"Unified_Ideograph", "Ideographic"},
    190041: {"Unified_Ideograph", "Ideographic"},
    190042: {"Unified_Ideograph", "Ideographic"},
    190043: {"Unified_Ideograph", "Ideographic"},
    190044: {"Unified_Ideograph", "Ideographic"},
    190045: {"Unified_Ideograph", "Ideographic"},
    190046: {"Unified_Ideograph", "Ideographic"},
    190047: {"Unified_Ideograph", "Ideographic"},
    190048: {"Unified_Ideograph", "Ideographic"},
    190049: {"Unified_Ideograph", "Ideographic"},
    190050: {"Unified_Ideograph", "Ideographic"},
    190051: {"Unified_Ideograph", "Ideographic"},
    190052: {"Unified_Ideograph", "Ideographic"},
    190053: {"Unified_Ideograph", "Ideographic"},
    190054: {"Unified_Ideograph", "Ideographic"},
    190055: {"Unified_Ideograph", "Ideographic"},
    190056: {"Unified_Ideograph", "Ideographic"},
    190057: {"Unified_Ideograph", "Ideographic"},
    190058: {"Unified_Ideograph", "Ideographic"},
    190059: {"Unified_Ideograph", "Ideographic"},
    190060: {"Unified_Ideograph", "Ideographic"},
    190061: {"Unified_Ideograph", "Ideographic"},
    190062: {"Unified_Ideograph", "Ideographic"},
    190063: {"Unified_Ideograph", "Ideographic"},
    190064: {"Unified_Ideograph", "Ideographic"},
    190065: {"Unified_Ideograph", "Ideographic"},
    190066: {"Unified_Ideograph", "Ideographic"},
    190067: {"Unified_Ideograph", "Ideographic"},
    190068: {"Unified_Ideograph", "Ideographic"},
    190069: {"Unified_Ideograph", "Ideographic"},
    190070: {"Unified_Ideograph", "Ideographic"},
    190071: {"Unified_Ideograph", "Ideographic"},
    190072: {"Unified_Ideograph", "Ideographic"},
    190073: {"Unified_Ideograph", "Ideographic"},
    190074: {"Unified_Ideograph", "Ideographic"},
    190075: {"Unified_Ideograph", "Ideographic"},
    190076: {"Unified_Ideograph", "Ideographic"},
    190077: {"Unified_Ideograph", "Ideographic"},
    190078: {"Unified_Ideograph", "Ideographic"},
    190079: {"Unified_Ideograph", "Ideographic"},
    190080: {"Unified_Ideograph", "Ideographic"},
    190081: {"Unified_Ideograph", "Ideographic"},
    190082: {"Unified_Ideograph", "Ideographic"},
    190083: {"Unified_Ideograph", "Ideographic"},
    190084: {"Unified_Ideograph", "Ideographic"},
    190085: {"Unified_Ideograph", "Ideographic"},
    190086: {"Unified_Ideograph", "Ideographic"},
    190087: {"Unified_Ideograph", "Ideographic"},
    190088: {"Unified_Ideograph", "Ideographic"},
    190089: {"Unified_Ideograph", "Ideographic"},
    190090: {"Unified_Ideograph", "Ideographic"},
    190091: {"Unified_Ideograph", "Ideographic"},
    190092: {"Unified_Ideograph", "Ideographic"},
    190093: {"Unified_Ideograph", "Ideographic"},
    190094: {"Unified_Ideograph", "Ideographic"},
    190095: {"Unified_Ideograph", "Ideographic"},
    190096: {"Unified_Ideograph", "Ideographic"},
    190097: {"Unified_Ideograph", "Ideographic"},
    190098: {"Unified_Ideograph", "Ideographic"},
    190099: {"Unified_Ideograph", "Ideographic"},
    190100: {"Unified_Ideograph", "Ideographic"},
    190101: {"Unified_Ideograph", "Ideographic"},
    190102: {"Unified_Ideograph", "Ideographic"},
    190103: {"Unified_Ideograph", "Ideographic"},
    190104: {"Unified_Ideograph", "Ideographic"},
    190105: {"Unified_Ideograph", "Ideographic"},
    190106: {"Unified_Ideograph", "Ideographic"},
    190107: {"Unified_Ideograph", "Ideographic"},
    190108: {"Unified_Ideograph", "Ideographic"},
    190109: {"Unified_Ideograph", "Ideographic"},
    190110: {"Unified_Ideograph", "Ideographic"},
    190111: {"Unified_Ideograph", "Ideographic"},
    190112: {"Unified_Ideograph", "Ideographic"},
    190113: {"Unified_Ideograph", "Ideographic"},
    190114: {"Unified_Ideograph", "Ideographic"},
    190115: {"Unified_Ideograph", "Ideographic"},
    190116: {"Unified_Ideograph", "Ideographic"},
    190117: {"Unified_Ideograph", "Ideographic"},
    190118: {"Unified_Ideograph", "Ideographic"},
    190119: {"Unified_Ideograph", "Ideographic"},
    190120: {"Unified_Ideograph", "Ideographic"},
    190121: {"Unified_Ideograph", "Ideographic"},
    190122: {"Unified_Ideograph", "Ideographic"},
    190123: {"Unified_Ideograph", "Ideographic"},
    190124: {"Unified_Ideograph", "Ideographic"},
    190125: {"Unified_Ideograph", "Ideographic"},
    190126: {"Unified_Ideograph", "Ideographic"},
    190127: {"Unified_Ideograph", "Ideographic"},
    190128: {"Unified_Ideograph", "Ideographic"},
    190129: {"Unified_Ideograph", "Ideographic"},
    190130: {"Unified_Ideograph", "Ideographic"},
    190131: {"Unified_Ideograph", "Ideographic"},
    190132: {"Unified_Ideograph", "Ideographic"},
    190133: {"Unified_Ideograph", "Ideographic"},
    190134: {"Unified_Ideograph", "Ideographic"},
    190135: {"Unified_Ideograph", "Ideographic"},
    190136: {"Unified_Ideograph", "Ideographic"},
    190137: {"Unified_Ideograph", "Ideographic"},
    190138: {"Unified_Ideograph", "Ideographic"},
    190139: {"Unified_Ideograph", "Ideographic"},
    190140: {"Unified_Ideograph", "Ideographic"},
    190141: {"Unified_Ideograph", "Ideographic"},
    190142: {"Unified_Ideograph", "Ideographic"},
    190143: {"Unified_Ideograph", "Ideographic"},
    190144: {"Unified_Ideograph", "Ideographic"},
    190145: {"Unified_Ideograph", "Ideographic"},
    190146: {"Unified_Ideograph", "Ideographic"},
    190147: {"Unified_Ideograph", "Ideographic"},
    190148: {"Unified_Ideograph", "Ideographic"},
    190149: {"Unified_Ideograph", "Ideographic"},
    190150: {"Unified_Ideograph", "Ideographic"},
    190151: {"Unified_Ideograph", "Ideographic"},
    190152: {"Unified_Ideograph", "Ideographic"},
    190153: {"Unified_Ideograph", "Ideographic"},
    190154: {"Unified_Ideograph", "Ideographic"},
    190155: {"Unified_Ideograph", "Ideographic"},
    190156: {"Unified_Ideograph", "Ideographic"},
    190157: {"Unified_Ideograph", "Ideographic"},
    190158: {"Unified_Ideograph", "Ideographic"},
    190159: {"Unified_Ideograph", "Ideographic"},
    190160: {"Unified_Ideograph", "Ideographic"},
    190161: {"Unified_Ideograph", "Ideographic"},
    190162: {"Unified_Ideograph", "Ideographic"},
    190163: {"Unified_Ideograph", "Ideographic"},
    190164: {"Unified_Ideograph", "Ideographic"},
    190165: {"Unified_Ideograph", "Ideographic"},
    190166: {"Unified_Ideograph", "Ideographic"},
    190167: {"Unified_Ideograph", "Ideographic"},
    190168: {"Unified_Ideograph", "Ideographic"},
    190169: {"Unified_Ideograph", "Ideographic"},
    190170: {"Unified_Ideograph", "Ideographic"},
    190171: {"Unified_Ideograph", "Ideographic"},
    190172: {"Unified_Ideograph", "Ideographic"},
    190173: {"Unified_Ideograph", "Ideographic"},
    190174: {"Unified_Ideograph", "Ideographic"},
    190175: {"Unified_Ideograph", "Ideographic"},
    190176: {"Unified_Ideograph", "Ideographic"},
    190177: {"Unified_Ideograph", "Ideographic"},
    190178: {"Unified_Ideograph", "Ideographic"},
    190179: {"Unified_Ideograph", "Ideographic"},
    190180: {"Unified_Ideograph", "Ideographic"},
    190181: {"Unified_Ideograph", "Ideographic"},
    190182: {"Unified_Ideograph", "Ideographic"},
    190183: {"Unified_Ideograph", "Ideographic"},
    190184: {"Unified_Ideograph", "Ideographic"},
    190185: {"Unified_Ideograph", "Ideographic"},
    190186: {"Unified_Ideograph", "Ideographic"},
    190187: {"Unified_Ideograph", "Ideographic"},
    190188: {"Unified_Ideograph", "Ideographic"},
    190189: {"Unified_Ideograph", "Ideographic"},
    190190: {"Unified_Ideograph", "Ideographic"},
    190191: {"Unified_Ideograph", "Ideographic"},
    190192: {"Unified_Ideograph", "Ideographic"},
    190193: {"Unified_Ideograph", "Ideographic"},
    190194: {"Unified_Ideograph", "Ideographic"},
    190195: {"Unified_Ideograph", "Ideographic"},
    190196: {"Unified_Ideograph", "Ideographic"},
    190197: {"Unified_Ideograph", "Ideographic"},
    190198: {"Unified_Ideograph", "Ideographic"},
    190199: {"Unified_Ideograph", "Ideographic"},
    190200: {"Unified_Ideograph", "Ideographic"},
    190201: {"Unified_Ideograph", "Ideographic"},
    190202: {"Unified_Ideograph", "Ideographic"},
    190203: {"Unified_Ideograph", "Ideographic"},
    190204: {"Unified_Ideograph", "Ideographic"},
    190205: {"Unified_Ideograph", "Ideographic"},
    190206: {"Unified_Ideograph", "Ideographic"},
    190207: {"Unified_Ideograph", "Ideographic"},
    190208: {"Unified_Ideograph", "Ideographic"},
    190209: {"Unified_Ideograph", "Ideographic"},
    190210: {"Unified_Ideograph", "Ideographic"},
    190211: {"Unified_Ideograph", "Ideographic"},
    190212: {"Unified_Ideograph", "Ideographic"},
    190213: {"Unified_Ideograph", "Ideographic"},
    190214: {"Unified_Ideograph", "Ideographic"},
    190215: {"Unified_Ideograph", "Ideographic"},
    190216: {"Unified_Ideograph", "Ideographic"},
    190217: {"Unified_Ideograph", "Ideographic"},
    190218: {"Unified_Ideograph", "Ideographic"},
    190219: {"Unified_Ideograph", "Ideographic"},
    190220: {"Unified_Ideograph", "Ideographic"},
    190221: {"Unified_Ideograph", "Ideographic"},
    190222: {"Unified_Ideograph", "Ideographic"},
    190223: {"Unified_Ideograph", "Ideographic"},
    190224: {"Unified_Ideograph", "Ideographic"},
    190225: {"Unified_Ideograph", "Ideographic"},
    190226: {"Unified_Ideograph", "Ideographic"},
    190227: {"Unified_Ideograph", "Ideographic"},
    190228: {"Unified_Ideograph", "Ideographic"},
    190229: {"Unified_Ideograph", "Ideographic"},
    190230: {"Unified_Ideograph", "Ideographic"},
    190231: {"Unified_Ideograph", "Ideographic"},
    190232: {"Unified_Ideograph", "Ideographic"},
    190233: {"Unified_Ideograph", "Ideographic"},
    190234: {"Unified_Ideograph", "Ideographic"},
    190235: {"Unified_Ideograph", "Ideographic"},
    190236: {"Unified_Ideograph", "Ideographic"},
    190237: {"Unified_Ideograph", "Ideographic"},
    190238: {"Unified_Ideograph", "Ideographic"},
    190239: {"Unified_Ideograph", "Ideographic"},
    190240: {"Unified_Ideograph", "Ideographic"},
    190241: {"Unified_Ideograph", "Ideographic"},
    190242: {"Unified_Ideograph", "Ideographic"},
    190243: {"Unified_Ideograph", "Ideographic"},
    190244: {"Unified_Ideograph", "Ideographic"},
    190245: {"Unified_Ideograph", "Ideographic"},
    190246: {"Unified_Ideograph", "Ideographic"},
    190247: {"Unified_Ideograph", "Ideographic"},
    190248: {"Unified_Ideograph", "Ideographic"},
    190249: {"Unified_Ideograph", "Ideographic"},
    190250: {"Unified_Ideograph", "Ideographic"},
    190251: {"Unified_Ideograph", "Ideographic"},
    190252: {"Unified_Ideograph", "Ideographic"},
    190253: {"Unified_Ideograph", "Ideographic"},
    190254: {"Unified_Ideograph", "Ideographic"},
    190255: {"Unified_Ideograph", "Ideographic"},
    190256: {"Unified_Ideograph", "Ideographic"},
    190257: {"Unified_Ideograph", "Ideographic"},
    190258: {"Unified_Ideograph", "Ideographic"},
    190259: {"Unified_Ideograph", "Ideographic"},
    190260: {"Unified_Ideograph", "Ideographic"},
    190261: {"Unified_Ideograph", "Ideographic"},
    190262: {"Unified_Ideograph", "Ideographic"},
    190263: {"Unified_Ideograph", "Ideographic"},
    190264: {"Unified_Ideograph", "Ideographic"},
    190265: {"Unified_Ideograph", "Ideographic"},
    190266: {"Unified_Ideograph", "Ideographic"},
    190267: {"Unified_Ideograph", "Ideographic"},
    190268: {"Unified_Ideograph", "Ideographic"},
    190269: {"Unified_Ideograph", "Ideographic"},
    190270: {"Unified_Ideograph", "Ideographic"},
    190271: {"Unified_Ideograph", "Ideographic"},
    190272: {"Unified_Ideograph", "Ideographic"},
    190273: {"Unified_Ideograph", "Ideographic"},
    190274: {"Unified_Ideograph", "Ideographic"},
    190275: {"Unified_Ideograph", "Ideographic"},
    190276: {"Unified_Ideograph", "Ideographic"},
    190277: {"Unified_Ideograph", "Ideographic"},
    190278: {"Unified_Ideograph", "Ideographic"},
    190279: {"Unified_Ideograph", "Ideographic"},
    190280: {"Unified_Ideograph", "Ideographic"},
    190281: {"Unified_Ideograph", "Ideographic"},
    190282: {"Unified_Ideograph", "Ideographic"},
    190283: {"Unified_Ideograph", "Ideographic"},
    190284: {"Unified_Ideograph", "Ideographic"},
    190285: {"Unified_Ideograph", "Ideographic"},
    190286: {"Unified_Ideograph", "Ideographic"},
    190287: {"Unified_Ideograph", "Ideographic"},
    190288: {"Unified_Ideograph", "Ideographic"},
    190289: {"Unified_Ideograph", "Ideographic"},
    190290: {"Unified_Ideograph", "Ideographic"},
    190291: {"Unified_Ideograph", "Ideographic"},
    190292: {"Unified_Ideograph", "Ideographic"},
    190293: {"Unified_Ideograph", "Ideographic"},
    190294: {"Unified_Ideograph", "Ideographic"},
    190295: {"Unified_Ideograph", "Ideographic"},
    190296: {"Unified_Ideograph", "Ideographic"},
    190297: {"Unified_Ideograph", "Ideographic"},
    190298: {"Unified_Ideograph", "Ideographic"},
    190299: {"Unified_Ideograph", "Ideographic"},
    190300: {"Unified_Ideograph", "Ideographic"},
    190301: {"Unified_Ideograph", "Ideographic"},
    190302: {"Unified_Ideograph", "Ideographic"},
    190303: {"Unified_Ideograph", "Ideographic"},
    190304: {"Unified_Ideograph", "Ideographic"},
    190305: {"Unified_Ideograph", "Ideographic"},
    190306: {"Unified_Ideograph", "Ideographic"},
    190307: {"Unified_Ideograph", "Ideographic"},
    190308: {"Unified_Ideograph", "Ideographic"},
    190309: {"Unified_Ideograph", "Ideographic"},
    190310: {"Unified_Ideograph", "Ideographic"},
    190311: {"Unified_Ideograph", "Ideographic"},
    190312: {"Unified_Ideograph", "Ideographic"},
    190313: {"Unified_Ideograph", "Ideographic"},
    190314: {"Unified_Ideograph", "Ideographic"},
    190315: {"Unified_Ideograph", "Ideographic"},
    190316: {"Unified_Ideograph", "Ideographic"},
    190317: {"Unified_Ideograph", "Ideographic"},
    190318: {"Unified_Ideograph", "Ideographic"},
    190319: {"Unified_Ideograph", "Ideographic"},
    190320: {"Unified_Ideograph", "Ideographic"},
    190321: {"Unified_Ideograph", "Ideographic"},
    190322: {"Unified_Ideograph", "Ideographic"},
    190323: {"Unified_Ideograph", "Ideographic"},
    190324: {"Unified_Ideograph", "Ideographic"},
    190325: {"Unified_Ideograph", "Ideographic"},
    190326: {"Unified_Ideograph", "Ideographic"},
    190327: {"Unified_Ideograph", "Ideographic"},
    190328: {"Unified_Ideograph", "Ideographic"},
    190329: {"Unified_Ideograph", "Ideographic"},
    190330: {"Unified_Ideograph", "Ideographic"},
    190331: {"Unified_Ideograph", "Ideographic"},
    190332: {"Unified_Ideograph", "Ideographic"},
    190333: {"Unified_Ideograph", "Ideographic"},
    190334: {"Unified_Ideograph", "Ideographic"},
    190335: {"Unified_Ideograph", "Ideographic"},
    190336: {"Unified_Ideograph", "Ideographic"},
    190337: {"Unified_Ideograph", "Ideographic"},
    190338: {"Unified_Ideograph", "Ideographic"},
    190339: {"Unified_Ideograph", "Ideographic"},
    190340: {"Unified_Ideograph", "Ideographic"},
    190341: {"Unified_Ideograph", "Ideographic"},
    190342: {"Unified_Ideograph", "Ideographic"},
    190343: {"Unified_Ideograph", "Ideographic"},
    190344: {"Unified_Ideograph", "Ideographic"},
    190345: {"Unified_Ideograph", "Ideographic"},
    190346: {"Unified_Ideograph", "Ideographic"},
    190347: {"Unified_Ideograph", "Ideographic"},
    190348: {"Unified_Ideograph", "Ideographic"},
    190349: {"Unified_Ideograph", "Ideographic"},
    190350: {"Unified_Ideograph", "Ideographic"},
    190351: {"Unified_Ideograph", "Ideographic"},
    190352: {"Unified_Ideograph", "Ideographic"},
    190353: {"Unified_Ideograph", "Ideographic"},
    190354: {"Unified_Ideograph", "Ideographic"},
    190355: {"Unified_Ideograph", "Ideographic"},
    190356: {"Unified_Ideograph", "Ideographic"},
    190357: {"Unified_Ideograph", "Ideographic"},
    190358: {"Unified_Ideograph", "Ideographic"},
    190359: {"Unified_Ideograph", "Ideographic"},
    190360: {"Unified_Ideograph", "Ideographic"},
    190361: {"Unified_Ideograph", "Ideographic"},
    190362: {"Unified_Ideograph", "Ideographic"},
    190363: {"Unified_Ideograph", "Ideographic"},
    190364: {"Unified_Ideograph", "Ideographic"},
    190365: {"Unified_Ideograph", "Ideographic"},
    190366: {"Unified_Ideograph", "Ideographic"},
    190367: {"Unified_Ideograph", "Ideographic"},
    190368: {"Unified_Ideograph", "Ideographic"},
    190369: {"Unified_Ideograph", "Ideographic"},
    190370: {"Unified_Ideograph", "Ideographic"},
    190371: {"Unified_Ideograph", "Ideographic"},
    190372: {"Unified_Ideograph", "Ideographic"},
    190373: {"Unified_Ideograph", "Ideographic"},
    190374: {"Unified_Ideograph", "Ideographic"},
    190375: {"Unified_Ideograph", "Ideographic"},
    190376: {"Unified_Ideograph", "Ideographic"},
    190377: {"Unified_Ideograph", "Ideographic"},
    190378: {"Unified_Ideograph", "Ideographic"},
    190379: {"Unified_Ideograph", "Ideographic"},
    190380: {"Unified_Ideograph", "Ideographic"},
    190381: {"Unified_Ideograph", "Ideographic"},
    190382: {"Unified_Ideograph", "Ideographic"},
    190383: {"Unified_Ideograph", "Ideographic"},
    190384: {"Unified_Ideograph", "Ideographic"},
    190385: {"Unified_Ideograph", "Ideographic"},
    190386: {"Unified_Ideograph", "Ideographic"},
    190387: {"Unified_Ideograph", "Ideographic"},
    190388: {"Unified_Ideograph", "Ideographic"},
    190389: {"Unified_Ideograph", "Ideographic"},
    190390: {"Unified_Ideograph", "Ideographic"},
    190391: {"Unified_Ideograph", "Ideographic"},
    190392: {"Unified_Ideograph", "Ideographic"},
    190393: {"Unified_Ideograph", "Ideographic"},
    190394: {"Unified_Ideograph", "Ideographic"},
    190395: {"Unified_Ideograph", "Ideographic"},
    190396: {"Unified_Ideograph", "Ideographic"},
    190397: {"Unified_Ideograph", "Ideographic"},
    190398: {"Unified_Ideograph", "Ideographic"},
    190399: {"Unified_Ideograph", "Ideographic"},
    190400: {"Unified_Ideograph", "Ideographic"},
    190401: {"Unified_Ideograph", "Ideographic"},
    190402: {"Unified_Ideograph", "Ideographic"},
    190403: {"Unified_Ideograph", "Ideographic"},
    190404: {"Unified_Ideograph", "Ideographic"},
    190405: {"Unified_Ideograph", "Ideographic"},
    190406: {"Unified_Ideograph", "Ideographic"},
    190407: {"Unified_Ideograph", "Ideographic"},
    190408: {"Unified_Ideograph", "Ideographic"},
    190409: {"Unified_Ideograph", "Ideographic"},
    190410: {"Unified_Ideograph", "Ideographic"},
    190411: {"Unified_Ideograph", "Ideographic"},
    190412: {"Unified_Ideograph", "Ideographic"},
    190413: {"Unified_Ideograph", "Ideographic"},
    190414: {"Unified_Ideograph", "Ideographic"},
    190415: {"Unified_Ideograph", "Ideographic"},
    190416: {"Unified_Ideograph", "Ideographic"},
    190417: {"Unified_Ideograph", "Ideographic"},
    190418: {"Unified_Ideograph", "Ideographic"},
    190419: {"Unified_Ideograph", "Ideographic"},
    190420: {"Unified_Ideograph", "Ideographic"},
    190421: {"Unified_Ideograph", "Ideographic"},
    190422: {"Unified_Ideograph", "Ideographic"},
    190423: {"Unified_Ideograph", "Ideographic"},
    190424: {"Unified_Ideograph", "Ideographic"},
    190425: {"Unified_Ideograph", "Ideographic"},
    190426: {"Unified_Ideograph", "Ideographic"},
    190427: {"Unified_Ideograph", "Ideographic"},
    190428: {"Unified_Ideograph", "Ideographic"},
    190429: {"Unified_Ideograph", "Ideographic"},
    190430: {"Unified_Ideograph", "Ideographic"},
    190431: {"Unified_Ideograph", "Ideographic"},
    190432: {"Unified_Ideograph", "Ideographic"},
    190433: {"Unified_Ideograph", "Ideographic"},
    190434: {"Unified_Ideograph", "Ideographic"},
    190435: {"Unified_Ideograph", "Ideographic"},
    190436: {"Unified_Ideograph", "Ideographic"},
    190437: {"Unified_Ideograph", "Ideographic"},
    190438: {"Unified_Ideograph", "Ideographic"},
    190439: {"Unified_Ideograph", "Ideographic"},
    190440: {"Unified_Ideograph", "Ideographic"},
    190441: {"Unified_Ideograph", "Ideographic"},
    190442: {"Unified_Ideograph", "Ideographic"},
    190443: {"Unified_Ideograph", "Ideographic"},
    190444: {"Unified_Ideograph", "Ideographic"},
    190445: {"Unified_Ideograph", "Ideographic"},
    190446: {"Unified_Ideograph", "Ideographic"},
    190447: {"Unified_Ideograph", "Ideographic"},
    190448: {"Unified_Ideograph", "Ideographic"},
    190449: {"Unified_Ideograph", "Ideographic"},
    190450: {"Unified_Ideograph", "Ideographic"},
    190451: {"Unified_Ideograph", "Ideographic"},
    190452: {"Unified_Ideograph", "Ideographic"},
    190453: {"Unified_Ideograph", "Ideographic"},
    190454: {"Unified_Ideograph", "Ideographic"},
    190455: {"Unified_Ideograph", "Ideographic"},
    190456: {"Unified_Ideograph", "Ideographic"},
    190457: {"Unified_Ideograph", "Ideographic"},
    190458: {"Unified_Ideograph", "Ideographic"},
    190459: {"Unified_Ideograph", "Ideographic"},
    190460: {"Unified_Ideograph", "Ideographic"},
    190461: {"Unified_Ideograph", "Ideographic"},
    190462: {"Unified_Ideograph", "Ideographic"},
    190463: {"Unified_Ideograph", "Ideographic"},
    190464: {"Unified_Ideograph", "Ideographic"},
    190465: {"Unified_Ideograph", "Ideographic"},
    190466: {"Unified_Ideograph", "Ideographic"},
    190467: {"Unified_Ideograph", "Ideographic"},
    190468: {"Unified_Ideograph", "Ideographic"},
    190469: {"Unified_Ideograph", "Ideographic"},
    190470: {"Unified_Ideograph", "Ideographic"},
    190471: {"Unified_Ideograph", "Ideographic"},
    190472: {"Unified_Ideograph", "Ideographic"},
    190473: {"Unified_Ideograph", "Ideographic"},
    190474: {"Unified_Ideograph", "Ideographic"},
    190475: {"Unified_Ideograph", "Ideographic"},
    190476: {"Unified_Ideograph", "Ideographic"},
    190477: {"Unified_Ideograph", "Ideographic"},
    190478: {"Unified_Ideograph", "Ideographic"},
    190479: {"Unified_Ideograph", "Ideographic"},
    190480: {"Unified_Ideograph", "Ideographic"},
    190481: {"Unified_Ideograph", "Ideographic"},
    190482: {"Unified_Ideograph", "Ideographic"},
    190483: {"Unified_Ideograph", "Ideographic"},
    190484: {"Unified_Ideograph", "Ideographic"},
    190485: {"Unified_Ideograph", "Ideographic"},
    190486: {"Unified_Ideograph", "Ideographic"},
    190487: {"Unified_Ideograph", "Ideographic"},
    190488: {"Unified_Ideograph", "Ideographic"},
    190489: {"Unified_Ideograph", "Ideographic"},
    190490: {"Unified_Ideograph", "Ideographic"},
    190491: {"Unified_Ideograph", "Ideographic"},
    190492: {"Unified_Ideograph", "Ideographic"},
    190493: {"Unified_Ideograph", "Ideographic"},
    190494: {"Unified_Ideograph", "Ideographic"},
    190495: {"Unified_Ideograph", "Ideographic"},
    190496: {"Unified_Ideograph", "Ideographic"},
    190497: {"Unified_Ideograph", "Ideographic"},
    190498: {"Unified_Ideograph", "Ideographic"},
    190499: {"Unified_Ideograph", "Ideographic"},
    190500: {"Unified_Ideograph", "Ideographic"},
    190501: {"Unified_Ideograph", "Ideographic"},
    190502: {"Unified_Ideograph", "Ideographic"},
    190503: {"Unified_Ideograph", "Ideographic"},
    190504: {"Unified_Ideograph", "Ideographic"},
    190505: {"Unified_Ideograph", "Ideographic"},
    190506: {"Unified_Ideograph", "Ideographic"},
    190507: {"Unified_Ideograph", "Ideographic"},
    190508: {"Unified_Ideograph", "Ideographic"},
    190509: {"Unified_Ideograph", "Ideographic"},
    190510: {"Unified_Ideograph", "Ideographic"},
    190511: {"Unified_Ideograph", "Ideographic"},
    190512: {"Unified_Ideograph", "Ideographic"},
    190513: {"Unified_Ideograph", "Ideographic"},
    190514: {"Unified_Ideograph", "Ideographic"},
    190515: {"Unified_Ideograph", "Ideographic"},
    190516: {"Unified_Ideograph", "Ideographic"},
    190517: {"Unified_Ideograph", "Ideographic"},
    190518: {"Unified_Ideograph", "Ideographic"},
    190519: {"Unified_Ideograph", "Ideographic"},
    190520: {"Unified_Ideograph", "Ideographic"},
    190521: {"Unified_Ideograph", "Ideographic"},
    190522: {"Unified_Ideograph", "Ideographic"},
    190523: {"Unified_Ideograph", "Ideographic"},
    190524: {"Unified_Ideograph", "Ideographic"},
    190525: {"Unified_Ideograph", "Ideographic"},
    190526: {"Unified_Ideograph", "Ideographic"},
    190527: {"Unified_Ideograph", "Ideographic"},
    190528: {"Unified_Ideograph", "Ideographic"},
    190529: {"Unified_Ideograph", "Ideographic"},
    190530: {"Unified_Ideograph", "Ideographic"},
    190531: {"Unified_Ideograph", "Ideographic"},
    190532: {"Unified_Ideograph", "Ideographic"},
    190533: {"Unified_Ideograph", "Ideographic"},
    190534: {"Unified_Ideograph", "Ideographic"},
    190535: {"Unified_Ideograph", "Ideographic"},
    190536: {"Unified_Ideograph", "Ideographic"},
    190537: {"Unified_Ideograph", "Ideographic"},
    190538: {"Unified_Ideograph", "Ideographic"},
    190539: {"Unified_Ideograph", "Ideographic"},
    190540: {"Unified_Ideograph", "Ideographic"},
    190541: {"Unified_Ideograph", "Ideographic"},
    190542: {"Unified_Ideograph", "Ideographic"},
    190543: {"Unified_Ideograph", "Ideographic"},
    190544: {"Unified_Ideograph", "Ideographic"},
    190545: {"Unified_Ideograph", "Ideographic"},
    190546: {"Unified_Ideograph", "Ideographic"},
    190547: {"Unified_Ideograph", "Ideographic"},
    190548: {"Unified_Ideograph", "Ideographic"},
    190549: {"Unified_Ideograph", "Ideographic"},
    190550: {"Unified_Ideograph", "Ideographic"},
    190551: {"Unified_Ideograph", "Ideographic"},
    190552: {"Unified_Ideograph", "Ideographic"},
    190553: {"Unified_Ideograph", "Ideographic"},
    190554: {"Unified_Ideograph", "Ideographic"},
    190555: {"Unified_Ideograph", "Ideographic"},
    190556: {"Unified_Ideograph", "Ideographic"},
    190557: {"Unified_Ideograph", "Ideographic"},
    190558: {"Unified_Ideograph", "Ideographic"},
    190559: {"Unified_Ideograph", "Ideographic"},
    190560: {"Unified_Ideograph", "Ideographic"},
    190561: {"Unified_Ideograph", "Ideographic"},
    190562: {"Unified_Ideograph", "Ideographic"},
    190563: {"Unified_Ideograph", "Ideographic"},
    190564: {"Unified_Ideograph", "Ideographic"},
    190565: {"Unified_Ideograph", "Ideographic"},
    190566: {"Unified_Ideograph", "Ideographic"},
    190567: {"Unified_Ideograph", "Ideographic"},
    190568: {"Unified_Ideograph", "Ideographic"},
    190569: {"Unified_Ideograph", "Ideographic"},
    190570: {"Unified_Ideograph", "Ideographic"},
    190571: {"Unified_Ideograph", "Ideographic"},
    190572: {"Unified_Ideograph", "Ideographic"},
    190573: {"Unified_Ideograph", "Ideographic"},
    190574: {"Unified_Ideograph", "Ideographic"},
    190575: {"Unified_Ideograph", "Ideographic"},
    190576: {"Unified_Ideograph", "Ideographic"},
    190577: {"Unified_Ideograph", "Ideographic"},
    190578: {"Unified_Ideograph", "Ideographic"},
    190579: {"Unified_Ideograph", "Ideographic"},
    190580: {"Unified_Ideograph", "Ideographic"},
    190581: {"Unified_Ideograph", "Ideographic"},
    190582: {"Unified_Ideograph", "Ideographic"},
    190583: {"Unified_Ideograph", "Ideographic"},
    190584: {"Unified_Ideograph", "Ideographic"},
    190585: {"Unified_Ideograph", "Ideographic"},
    190586: {"Unified_Ideograph", "Ideographic"},
    190587: {"Unified_Ideograph", "Ideographic"},
    190588: {"Unified_Ideograph", "Ideographic"},
    190589: {"Unified_Ideograph", "Ideographic"},
    190590: {"Unified_Ideograph", "Ideographic"},
    190591: {"Unified_Ideograph", "Ideographic"},
    190592: {"Unified_Ideograph", "Ideographic"},
    190593: {"Unified_Ideograph", "Ideographic"},
    190594: {"Unified_Ideograph", "Ideographic"},
    190595: {"Unified_Ideograph", "Ideographic"},
    190596: {"Unified_Ideograph", "Ideographic"},
    190597: {"Unified_Ideograph", "Ideographic"},
    190598: {"Unified_Ideograph", "Ideographic"},
    190599: {"Unified_Ideograph", "Ideographic"},
    190600: {"Unified_Ideograph", "Ideographic"},
    190601: {"Unified_Ideograph", "Ideographic"},
    190602: {"Unified_Ideograph", "Ideographic"},
    190603: {"Unified_Ideograph", "Ideographic"},
    190604: {"Unified_Ideograph", "Ideographic"},
    190605: {"Unified_Ideograph", "Ideographic"},
    190606: {"Unified_Ideograph", "Ideographic"},
    190607: {"Unified_Ideograph", "Ideographic"},
    190608: {"Unified_Ideograph", "Ideographic"},
    190609: {"Unified_Ideograph", "Ideographic"},
    190610: {"Unified_Ideograph", "Ideographic"},
    190611: {"Unified_Ideograph", "Ideographic"},
    190612: {"Unified_Ideograph", "Ideographic"},
    190613: {"Unified_Ideograph", "Ideographic"},
    190614: {"Unified_Ideograph", "Ideographic"},
    190615: {"Unified_Ideograph", "Ideographic"},
    190616: {"Unified_Ideograph", "Ideographic"},
    190617: {"Unified_Ideograph", "Ideographic"},
    190618: {"Unified_Ideograph", "Ideographic"},
    190619: {"Unified_Ideograph", "Ideographic"},
    190620: {"Unified_Ideograph", "Ideographic"},
    190621: {"Unified_Ideograph", "Ideographic"},
    190622: {"Unified_Ideograph", "Ideographic"},
    190623: {"Unified_Ideograph", "Ideographic"},
    190624: {"Unified_Ideograph", "Ideographic"},
    190625: {"Unified_Ideograph", "Ideographic"},
    190626: {"Unified_Ideograph", "Ideographic"},
    190627: {"Unified_Ideograph", "Ideographic"},
    190628: {"Unified_Ideograph", "Ideographic"},
    190629: {"Unified_Ideograph", "Ideographic"},
    190630: {"Unified_Ideograph", "Ideographic"},
    190631: {"Unified_Ideograph", "Ideographic"},
    190632: {"Unified_Ideograph", "Ideographic"},
    190633: {"Unified_Ideograph", "Ideographic"},
    190634: {"Unified_Ideograph", "Ideographic"},
    190635: {"Unified_Ideograph", "Ideographic"},
    190636: {"Unified_Ideograph", "Ideographic"},
    190637: {"Unified_Ideograph", "Ideographic"},
    190638: {"Unified_Ideograph", "Ideographic"},
    190639: {"Unified_Ideograph", "Ideographic"},
    190640: {"Unified_Ideograph", "Ideographic"},
    190641: {"Unified_Ideograph", "Ideographic"},
    190642: {"Unified_Ideograph", "Ideographic"},
    190643: {"Unified_Ideograph", "Ideographic"},
    190644: {"Unified_Ideograph", "Ideographic"},
    190645: {"Unified_Ideograph", "Ideographic"},
    190646: {"Unified_Ideograph", "Ideographic"},
    190647: {"Unified_Ideograph", "Ideographic"},
    190648: {"Unified_Ideograph", "Ideographic"},
    190649: {"Unified_Ideograph", "Ideographic"},
    190650: {"Unified_Ideograph", "Ideographic"},
    190651: {"Unified_Ideograph", "Ideographic"},
    190652: {"Unified_Ideograph", "Ideographic"},
    190653: {"Unified_Ideograph", "Ideographic"},
    190654: {"Unified_Ideograph", "Ideographic"},
    190655: {"Unified_Ideograph", "Ideographic"},
    190656: {"Unified_Ideograph", "Ideographic"},
    190657: {"Unified_Ideograph", "Ideographic"},
    190658: {"Unified_Ideograph", "Ideographic"},
    190659: {"Unified_Ideograph", "Ideographic"},
    190660: {"Unified_Ideograph", "Ideographic"},
    190661: {"Unified_Ideograph", "Ideographic"},
    190662: {"Unified_Ideograph", "Ideographic"},
    190663: {"Unified_Ideograph", "Ideographic"},
    190664: {"Unified_Ideograph", "Ideographic"},
    190665: {"Unified_Ideograph", "Ideographic"},
    190666: {"Unified_Ideograph", "Ideographic"},
    190667: {"Unified_Ideograph", "Ideographic"},
    190668: {"Unified_Ideograph", "Ideographic"},
    190669: {"Unified_Ideograph", "Ideographic"},
    190670: {"Unified_Ideograph", "Ideographic"},
    190671: {"Unified_Ideograph", "Ideographic"},
    190672: {"Unified_Ideograph", "Ideographic"},
    190673: {"Unified_Ideograph", "Ideographic"},
    190674: {"Unified_Ideograph", "Ideographic"},
    190675: {"Unified_Ideograph", "Ideographic"},
    190676: {"Unified_Ideograph", "Ideographic"},
    190677: {"Unified_Ideograph", "Ideographic"},
    190678: {"Unified_Ideograph", "Ideographic"},
    190679: {"Unified_Ideograph", "Ideographic"},
    190680: {"Unified_Ideograph", "Ideographic"},
    190681: {"Unified_Ideograph", "Ideographic"},
    190682: {"Unified_Ideograph", "Ideographic"},
    190683: {"Unified_Ideograph", "Ideographic"},
    190684: {"Unified_Ideograph", "Ideographic"},
    190685: {"Unified_Ideograph", "Ideographic"},
    190686: {"Unified_Ideograph", "Ideographic"},
    190687: {"Unified_Ideograph", "Ideographic"},
    190688: {"Unified_Ideograph", "Ideographic"},
    190689: {"Unified_Ideograph", "Ideographic"},
    190690: {"Unified_Ideograph", "Ideographic"},
    190691: {"Unified_Ideograph", "Ideographic"},
    190692: {"Unified_Ideograph", "Ideographic"},
    190693: {"Unified_Ideograph", "Ideographic"},
    190694: {"Unified_Ideograph", "Ideographic"},
    190695: {"Unified_Ideograph", "Ideographic"},
    190696: {"Unified_Ideograph", "Ideographic"},
    190697: {"Unified_Ideograph", "Ideographic"},
    190698: {"Unified_Ideograph", "Ideographic"},
    190699: {"Unified_Ideograph", "Ideographic"},
    190700: {"Unified_Ideograph", "Ideographic"},
    190701: {"Unified_Ideograph", "Ideographic"},
    190702: {"Unified_Ideograph", "Ideographic"},
    190703: {"Unified_Ideograph", "Ideographic"},
    190704: {"Unified_Ideograph", "Ideographic"},
    190705: {"Unified_Ideograph", "Ideographic"},
    190706: {"Unified_Ideograph", "Ideographic"},
    190707: {"Unified_Ideograph", "Ideographic"},
    190708: {"Unified_Ideograph", "Ideographic"},
    190709: {"Unified_Ideograph", "Ideographic"},
    190710: {"Unified_Ideograph", "Ideographic"},
    190711: {"Unified_Ideograph", "Ideographic"},
    190712: {"Unified_Ideograph", "Ideographic"},
    190713: {"Unified_Ideograph", "Ideographic"},
    190714: {"Unified_Ideograph", "Ideographic"},
    190715: {"Unified_Ideograph", "Ideographic"},
    190716: {"Unified_Ideograph", "Ideographic"},
    190717: {"Unified_Ideograph", "Ideographic"},
    190718: {"Unified_Ideograph", "Ideographic"},
    190719: {"Unified_Ideograph", "Ideographic"},
    190720: {"Unified_Ideograph", "Ideographic"},
    190721: {"Unified_Ideograph", "Ideographic"},
    190722: {"Unified_Ideograph", "Ideographic"},
    190723: {"Unified_Ideograph", "Ideographic"},
    190724: {"Unified_Ideograph", "Ideographic"},
    190725: {"Unified_Ideograph", "Ideographic"},
    190726: {"Unified_Ideograph", "Ideographic"},
    190727: {"Unified_Ideograph", "Ideographic"},
    190728: {"Unified_Ideograph", "Ideographic"},
    190729: {"Unified_Ideograph", "Ideographic"},
    190730: {"Unified_Ideograph", "Ideographic"},
    190731: {"Unified_Ideograph", "Ideographic"},
    190732: {"Unified_Ideograph", "Ideographic"},
    190733: {"Unified_Ideograph", "Ideographic"},
    190734: {"Unified_Ideograph", "Ideographic"},
    190735: {"Unified_Ideograph", "Ideographic"},
    190736: {"Unified_Ideograph", "Ideographic"},
    190737: {"Unified_Ideograph", "Ideographic"},
    190738: {"Unified_Ideograph", "Ideographic"},
    190739: {"Unified_Ideograph", "Ideographic"},
    190740: {"Unified_Ideograph", "Ideographic"},
    190741: {"Unified_Ideograph", "Ideographic"},
    190742: {"Unified_Ideograph", "Ideographic"},
    190743: {"Unified_Ideograph", "Ideographic"},
    190744: {"Unified_Ideograph", "Ideographic"},
    190745: {"Unified_Ideograph", "Ideographic"},
    190746: {"Unified_Ideograph", "Ideographic"},
    190747: {"Unified_Ideograph", "Ideographic"},
    190748: {"Unified_Ideograph", "Ideographic"},
    190749: {"Unified_Ideograph", "Ideographic"},
    190750: {"Unified_Ideograph", "Ideographic"},
    190751: {"Unified_Ideograph", "Ideographic"},
    190752: {"Unified_Ideograph", "Ideographic"},
    190753: {"Unified_Ideograph", "Ideographic"},
    190754: {"Unified_Ideograph", "Ideographic"},
    190755: {"Unified_Ideograph", "Ideographic"},
    190756: {"Unified_Ideograph", "Ideographic"},
    190757: {"Unified_Ideograph", "Ideographic"},
    190758: {"Unified_Ideograph", "Ideographic"},
    190759: {"Unified_Ideograph", "Ideographic"},
    190760: {"Unified_Ideograph", "Ideographic"},
    190761: {"Unified_Ideograph", "Ideographic"},
    190762: {"Unified_Ideograph", "Ideographic"},
    190763: {"Unified_Ideograph", "Ideographic"},
    190764: {"Unified_Ideograph", "Ideographic"},
    190765: {"Unified_Ideograph", "Ideographic"},
    190766: {"Unified_Ideograph", "Ideographic"},
    190767: {"Unified_Ideograph", "Ideographic"},
    190768: {"Unified_Ideograph", "Ideographic"},
    190769: {"Unified_Ideograph", "Ideographic"},
    190770: {"Unified_Ideograph", "Ideographic"},
    190771: {"Unified_Ideograph", "Ideographic"},
    190772: {"Unified_Ideograph", "Ideographic"},
    190773: {"Unified_Ideograph", "Ideographic"},
    190774: {"Unified_Ideograph", "Ideographic"},
    190775: {"Unified_Ideograph", "Ideographic"},
    190776: {"Unified_Ideograph", "Ideographic"},
    190777: {"Unified_Ideograph", "Ideographic"},
    190778: {"Unified_Ideograph", "Ideographic"},
    190779: {"Unified_Ideograph", "Ideographic"},
    190780: {"Unified_Ideograph", "Ideographic"},
    190781: {"Unified_Ideograph", "Ideographic"},
    190782: {"Unified_Ideograph", "Ideographic"},
    190783: {"Unified_Ideograph", "Ideographic"},
    190784: {"Unified_Ideograph", "Ideographic"},
    190785: {"Unified_Ideograph", "Ideographic"},
    190786: {"Unified_Ideograph", "Ideographic"},
    190787: {"Unified_Ideograph", "Ideographic"},
    190788: {"Unified_Ideograph", "Ideographic"},
    190789: {"Unified_Ideograph", "Ideographic"},
    190790: {"Unified_Ideograph", "Ideographic"},
    190791: {"Unified_Ideograph", "Ideographic"},
    190792: {"Unified_Ideograph", "Ideographic"},
    190793: {"Unified_Ideograph", "Ideographic"},
    190794: {"Unified_Ideograph", "Ideographic"},
    190795: {"Unified_Ideograph", "Ideographic"},
    190796: {"Unified_Ideograph", "Ideographic"},
    190797: {"Unified_Ideograph", "Ideographic"},
    190798: {"Unified_Ideograph", "Ideographic"},
    190799: {"Unified_Ideograph", "Ideographic"},
    190800: {"Unified_Ideograph", "Ideographic"},
    190801: {"Unified_Ideograph", "Ideographic"},
    190802: {"Unified_Ideograph", "Ideographic"},
    190803: {"Unified_Ideograph", "Ideographic"},
    190804: {"Unified_Ideograph", "Ideographic"},
    190805: {"Unified_Ideograph", "Ideographic"},
    190806: {"Unified_Ideograph", "Ideographic"},
    190807: {"Unified_Ideograph", "Ideographic"},
    190808: {"Unified_Ideograph", "Ideographic"},
    190809: {"Unified_Ideograph", "Ideographic"},
    190810: {"Unified_Ideograph", "Ideographic"},
    190811: {"Unified_Ideograph", "Ideographic"},
    190812: {"Unified_Ideograph", "Ideographic"},
    190813: {"Unified_Ideograph", "Ideographic"},
    190814: {"Unified_Ideograph", "Ideographic"},
    190815: {"Unified_Ideograph", "Ideographic"},
    190816: {"Unified_Ideograph", "Ideographic"},
    190817: {"Unified_Ideograph", "Ideographic"},
    190818: {"Unified_Ideograph", "Ideographic"},
    190819: {"Unified_Ideograph", "Ideographic"},
    190820: {"Unified_Ideograph", "Ideographic"},
    190821: {"Unified_Ideograph", "Ideographic"},
    190822: {"Unified_Ideograph", "Ideographic"},
    190823: {"Unified_Ideograph", "Ideographic"},
    190824: {"Unified_Ideograph", "Ideographic"},
    190825: {"Unified_Ideograph", "Ideographic"},
    190826: {"Unified_Ideograph", "Ideographic"},
    190827: {"Unified_Ideograph", "Ideographic"},
    190828: {"Unified_Ideograph", "Ideographic"},
    190829: {"Unified_Ideograph", "Ideographic"},
    190830: {"Unified_Ideograph", "Ideographic"},
    190831: {"Unified_Ideograph", "Ideographic"},
    190832: {"Unified_Ideograph", "Ideographic"},
    190833: {"Unified_Ideograph", "Ideographic"},
    190834: {"Unified_Ideograph", "Ideographic"},
    190835: {"Unified_Ideograph", "Ideographic"},
    190836: {"Unified_Ideograph", "Ideographic"},
    190837: {"Unified_Ideograph", "Ideographic"},
    190838: {"Unified_Ideograph", "Ideographic"},
    190839: {"Unified_Ideograph", "Ideographic"},
    190840: {"Unified_Ideograph", "Ideographic"},
    190841: {"Unified_Ideograph", "Ideographic"},
    190842: {"Unified_Ideograph", "Ideographic"},
    190843: {"Unified_Ideograph", "Ideographic"},
    190844: {"Unified_Ideograph", "Ideographic"},
    190845: {"Unified_Ideograph", "Ideographic"},
    190846: {"Unified_Ideograph", "Ideographic"},
    190847: {"Unified_Ideograph", "Ideographic"},
    190848: {"Unified_Ideograph", "Ideographic"},
    190849: {"Unified_Ideograph", "Ideographic"},
    190850: {"Unified_Ideograph", "Ideographic"},
    190851: {"Unified_Ideograph", "Ideographic"},
    190852: {"Unified_Ideograph", "Ideographic"},
    190853: {"Unified_Ideograph", "Ideographic"},
    190854: {"Unified_Ideograph", "Ideographic"},
    190855: {"Unified_Ideograph", "Ideographic"},
    190856: {"Unified_Ideograph", "Ideographic"},
    190857: {"Unified_Ideograph", "Ideographic"},
    190858: {"Unified_Ideograph", "Ideographic"},
    190859: {"Unified_Ideograph", "Ideographic"},
    190860: {"Unified_Ideograph", "Ideographic"},
    190861: {"Unified_Ideograph", "Ideographic"},
    190862: {"Unified_Ideograph", "Ideographic"},
    190863: {"Unified_Ideograph", "Ideographic"},
    190864: {"Unified_Ideograph", "Ideographic"},
    190865: {"Unified_Ideograph", "Ideographic"},
    190866: {"Unified_Ideograph", "Ideographic"},
    190867: {"Unified_Ideograph", "Ideographic"},
    190868: {"Unified_Ideograph", "Ideographic"},
    190869: {"Unified_Ideograph", "Ideographic"},
    190870: {"Unified_Ideograph", "Ideographic"},
    190871: {"Unified_Ideograph", "Ideographic"},
    190872: {"Unified_Ideograph", "Ideographic"},
    190873: {"Unified_Ideograph", "Ideographic"},
    190874: {"Unified_Ideograph", "Ideographic"},
    190875: {"Unified_Ideograph", "Ideographic"},
    190876: {"Unified_Ideograph", "Ideographic"},
    190877: {"Unified_Ideograph", "Ideographic"},
    190878: {"Unified_Ideograph", "Ideographic"},
    190879: {"Unified_Ideograph", "Ideographic"},
    190880: {"Unified_Ideograph", "Ideographic"},
    190881: {"Unified_Ideograph", "Ideographic"},
    190882: {"Unified_Ideograph", "Ideographic"},
    190883: {"Unified_Ideograph", "Ideographic"},
    190884: {"Unified_Ideograph", "Ideographic"},
    190885: {"Unified_Ideograph", "Ideographic"},
    190886: {"Unified_Ideograph", "Ideographic"},
    190887: {"Unified_Ideograph", "Ideographic"},
    190888: {"Unified_Ideograph", "Ideographic"},
    190889: {"Unified_Ideograph", "Ideographic"},
    190890: {"Unified_Ideograph", "Ideographic"},
    190891: {"Unified_Ideograph", "Ideographic"},
    190892: {"Unified_Ideograph", "Ideographic"},
    190893: {"Unified_Ideograph", "Ideographic"},
    190894: {"Unified_Ideograph", "Ideographic"},
    190895: {"Unified_Ideograph", "Ideographic"},
    190896: {"Unified_Ideograph", "Ideographic"},
    190897: {"Unified_Ideograph", "Ideographic"},
    190898: {"Unified_Ideograph", "Ideographic"},
    190899: {"Unified_Ideograph", "Ideographic"},
    190900: {"Unified_Ideograph", "Ideographic"},
    190901: {"Unified_Ideograph", "Ideographic"},
    190902: {"Unified_Ideograph", "Ideographic"},
    190903: {"Unified_Ideograph", "Ideographic"},
    190904: {"Unified_Ideograph", "Ideographic"},
    190905: {"Unified_Ideograph", "Ideographic"},
    190906: {"Unified_Ideograph", "Ideographic"},
    190907: {"Unified_Ideograph", "Ideographic"},
    190908: {"Unified_Ideograph", "Ideographic"},
    190909: {"Unified_Ideograph", "Ideographic"},
    190910: {"Unified_Ideograph", "Ideographic"},
    190911: {"Unified_Ideograph", "Ideographic"},
    190912: {"Unified_Ideograph", "Ideographic"},
    190913: {"Unified_Ideograph", "Ideographic"},
    190914: {"Unified_Ideograph", "Ideographic"},
    190915: {"Unified_Ideograph", "Ideographic"},
    190916: {"Unified_Ideograph", "Ideographic"},
    190917: {"Unified_Ideograph", "Ideographic"},
    190918: {"Unified_Ideograph", "Ideographic"},
    190919: {"Unified_Ideograph", "Ideographic"},
    190920: {"Unified_Ideograph", "Ideographic"},
    190921: {"Unified_Ideograph", "Ideographic"},
    190922: {"Unified_Ideograph", "Ideographic"},
    190923: {"Unified_Ideograph", "Ideographic"},
    190924: {"Unified_Ideograph", "Ideographic"},
    190925: {"Unified_Ideograph", "Ideographic"},
    190926: {"Unified_Ideograph", "Ideographic"},
    190927: {"Unified_Ideograph", "Ideographic"},
    190928: {"Unified_Ideograph", "Ideographic"},
    190929: {"Unified_Ideograph", "Ideographic"},
    190930: {"Unified_Ideograph", "Ideographic"},
    190931: {"Unified_Ideograph", "Ideographic"},
    190932: {"Unified_Ideograph", "Ideographic"},
    190933: {"Unified_Ideograph", "Ideographic"},
    190934: {"Unified_Ideograph", "Ideographic"},
    190935: {"Unified_Ideograph", "Ideographic"},
    190936: {"Unified_Ideograph", "Ideographic"},
    190937: {"Unified_Ideograph", "Ideographic"},
    190938: {"Unified_Ideograph", "Ideographic"},
    190939: {"Unified_Ideograph", "Ideographic"},
    190940: {"Unified_Ideograph", "Ideographic"},
    190941: {"Unified_Ideograph", "Ideographic"},
    190942: {"Unified_Ideograph", "Ideographic"},
    190943: {"Unified_Ideograph", "Ideographic"},
    190944: {"Unified_Ideograph", "Ideographic"},
    190945: {"Unified_Ideograph", "Ideographic"},
    190946: {"Unified_Ideograph", "Ideographic"},
    190947: {"Unified_Ideograph", "Ideographic"},
    190948: {"Unified_Ideograph", "Ideographic"},
    190949: {"Unified_Ideograph", "Ideographic"},
    190950: {"Unified_Ideograph", "Ideographic"},
    190951: {"Unified_Ideograph", "Ideographic"},
    190952: {"Unified_Ideograph", "Ideographic"},
    190953: {"Unified_Ideograph", "Ideographic"},
    190954: {"Unified_Ideograph", "Ideographic"},
    190955: {"Unified_Ideograph", "Ideographic"},
    190956: {"Unified_Ideograph", "Ideographic"},
    190957: {"Unified_Ideograph", "Ideographic"},
    190958: {"Unified_Ideograph", "Ideographic"},
    190959: {"Unified_Ideograph", "Ideographic"},
    190960: {"Unified_Ideograph", "Ideographic"},
    190961: {"Unified_Ideograph", "Ideographic"},
    190962: {"Unified_Ideograph", "Ideographic"},
    190963: {"Unified_Ideograph", "Ideographic"},
    190964: {"Unified_Ideograph", "Ideographic"},
    190965: {"Unified_Ideograph", "Ideographic"},
    190966: {"Unified_Ideograph", "Ideographic"},
    190967: {"Unified_Ideograph", "Ideographic"},
    190968: {"Unified_Ideograph", "Ideographic"},
    190969: {"Unified_Ideograph", "Ideographic"},
    190970: {"Unified_Ideograph", "Ideographic"},
    190971: {"Unified_Ideograph", "Ideographic"},
    190972: {"Unified_Ideograph", "Ideographic"},
    190973: {"Unified_Ideograph", "Ideographic"},
    190974: {"Unified_Ideograph", "Ideographic"},
    190975: {"Unified_Ideograph", "Ideographic"},
    190976: {"Unified_Ideograph", "Ideographic"},
    190977: {"Unified_Ideograph", "Ideographic"},
    190978: {"Unified_Ideograph", "Ideographic"},
    190979: {"Unified_Ideograph", "Ideographic"},
    190980: {"Unified_Ideograph", "Ideographic"},
    190981: {"Unified_Ideograph", "Ideographic"},
    190982: {"Unified_Ideograph", "Ideographic"},
    190983: {"Unified_Ideograph", "Ideographic"},
    190984: {"Unified_Ideograph", "Ideographic"},
    190985: {"Unified_Ideograph", "Ideographic"},
    190986: {"Unified_Ideograph", "Ideographic"},
    190987: {"Unified_Ideograph", "Ideographic"},
    190988: {"Unified_Ideograph", "Ideographic"},
    190989: {"Unified_Ideograph", "Ideographic"},
    190990: {"Unified_Ideograph", "Ideographic"},
    190991: {"Unified_Ideograph", "Ideographic"},
    190992: {"Unified_Ideograph", "Ideographic"},
    190993: {"Unified_Ideograph", "Ideographic"},
    190994: {"Unified_Ideograph", "Ideographic"},
    190995: {"Unified_Ideograph", "Ideographic"},
    190996: {"Unified_Ideograph", "Ideographic"},
    190997: {"Unified_Ideograph", "Ideographic"},
    190998: {"Unified_Ideograph", "Ideographic"},
    190999: {"Unified_Ideograph", "Ideographic"},
    191000: {"Unified_Ideograph", "Ideographic"},
    191001: {"Unified_Ideograph", "Ideographic"},
    191002: {"Unified_Ideograph", "Ideographic"},
    191003: {"Unified_Ideograph", "Ideographic"},
    191004: {"Unified_Ideograph", "Ideographic"},
    191005: {"Unified_Ideograph", "Ideographic"},
    191006: {"Unified_Ideograph", "Ideographic"},
    191007: {"Unified_Ideograph", "Ideographic"},
    191008: {"Unified_Ideograph", "Ideographic"},
    191009: {"Unified_Ideograph", "Ideographic"},
    191010: {"Unified_Ideograph", "Ideographic"},
    191011: {"Unified_Ideograph", "Ideographic"},
    191012: {"Unified_Ideograph", "Ideographic"},
    191013: {"Unified_Ideograph", "Ideographic"},
    191014: {"Unified_Ideograph", "Ideographic"},
    191015: {"Unified_Ideograph", "Ideographic"},
    191016: {"Unified_Ideograph", "Ideographic"},
    191017: {"Unified_Ideograph", "Ideographic"},
    191018: {"Unified_Ideograph", "Ideographic"},
    191019: {"Unified_Ideograph", "Ideographic"},
    191020: {"Unified_Ideograph", "Ideographic"},
    191021: {"Unified_Ideograph", "Ideographic"},
    191022: {"Unified_Ideograph", "Ideographic"},
    191023: {"Unified_Ideograph", "Ideographic"},
    191024: {"Unified_Ideograph", "Ideographic"},
    191025: {"Unified_Ideograph", "Ideographic"},
    191026: {"Unified_Ideograph", "Ideographic"},
    191027: {"Unified_Ideograph", "Ideographic"},
    191028: {"Unified_Ideograph", "Ideographic"},
    191029: {"Unified_Ideograph", "Ideographic"},
    191030: {"Unified_Ideograph", "Ideographic"},
    191031: {"Unified_Ideograph", "Ideographic"},
    191032: {"Unified_Ideograph", "Ideographic"},
    191033: {"Unified_Ideograph", "Ideographic"},
    191034: {"Unified_Ideograph", "Ideographic"},
    191035: {"Unified_Ideograph", "Ideographic"},
    191036: {"Unified_Ideograph", "Ideographic"},
    191037: {"Unified_Ideograph", "Ideographic"},
    191038: {"Unified_Ideograph", "Ideographic"},
    191039: {"Unified_Ideograph", "Ideographic"},
    191040: {"Unified_Ideograph", "Ideographic"},
    191041: {"Unified_Ideograph", "Ideographic"},
    191042: {"Unified_Ideograph", "Ideographic"},
    191043: {"Unified_Ideograph", "Ideographic"},
    191044: {"Unified_Ideograph", "Ideographic"},
    191045: {"Unified_Ideograph", "Ideographic"},
    191046: {"Unified_Ideograph", "Ideographic"},
    191047: {"Unified_Ideograph", "Ideographic"},
    191048: {"Unified_Ideograph", "Ideographic"},
    191049: {"Unified_Ideograph", "Ideographic"},
    191050: {"Unified_Ideograph", "Ideographic"},
    191051: {"Unified_Ideograph", "Ideographic"},
    191052: {"Unified_Ideograph", "Ideographic"},
    191053: {"Unified_Ideograph", "Ideographic"},
    191054: {"Unified_Ideograph", "Ideographic"},
    191055: {"Unified_Ideograph", "Ideographic"},
    191056: {"Unified_Ideograph", "Ideographic"},
    191057: {"Unified_Ideograph", "Ideographic"},
    191058: {"Unified_Ideograph", "Ideographic"},
    191059: {"Unified_Ideograph", "Ideographic"},
    191060: {"Unified_Ideograph", "Ideographic"},
    191061: {"Unified_Ideograph", "Ideographic"},
    191062: {"Unified_Ideograph", "Ideographic"},
    191063: {"Unified_Ideograph", "Ideographic"},
    191064: {"Unified_Ideograph", "Ideographic"},
    191065: {"Unified_Ideograph", "Ideographic"},
    191066: {"Unified_Ideograph", "Ideographic"},
    191067: {"Unified_Ideograph", "Ideographic"},
    191068: {"Unified_Ideograph", "Ideographic"},
    191069: {"Unified_Ideograph", "Ideographic"},
    191070: {"Unified_Ideograph", "Ideographic"},
    191071: {"Unified_Ideograph", "Ideographic"},
    191072: {"Unified_Ideograph", "Ideographic"},
    191073: {"Unified_Ideograph", "Ideographic"},
    191074: {"Unified_Ideograph", "Ideographic"},
    191075: {"Unified_Ideograph", "Ideographic"},
    191076: {"Unified_Ideograph", "Ideographic"},
    191077: {"Unified_Ideograph", "Ideographic"},
    191078: {"Unified_Ideograph", "Ideographic"},
    191079: {"Unified_Ideograph", "Ideographic"},
    191080: {"Unified_Ideograph", "Ideographic"},
    191081: {"Unified_Ideograph", "Ideographic"},
    191082: {"Unified_Ideograph", "Ideographic"},
    191083: {"Unified_Ideograph", "Ideographic"},
    191084: {"Unified_Ideograph", "Ideographic"},
    191085: {"Unified_Ideograph", "Ideographic"},
    191086: {"Unified_Ideograph", "Ideographic"},
    191087: {"Unified_Ideograph", "Ideographic"},
    191088: {"Unified_Ideograph", "Ideographic"},
    191089: {"Unified_Ideograph", "Ideographic"},
    191090: {"Unified_Ideograph", "Ideographic"},
    191091: {"Unified_Ideograph", "Ideographic"},
    191092: {"Unified_Ideograph", "Ideographic"},
    191093: {"Unified_Ideograph", "Ideographic"},
    191094: {"Unified_Ideograph", "Ideographic"},
    191095: {"Unified_Ideograph", "Ideographic"},
    191096: {"Unified_Ideograph", "Ideographic"},
    191097: {"Unified_Ideograph", "Ideographic"},
    191098: {"Unified_Ideograph", "Ideographic"},
    191099: {"Unified_Ideograph", "Ideographic"},
    191100: {"Unified_Ideograph", "Ideographic"},
    191101: {"Unified_Ideograph", "Ideographic"},
    191102: {"Unified_Ideograph", "Ideographic"},
    191103: {"Unified_Ideograph", "Ideographic"},
    191104: {"Unified_Ideograph", "Ideographic"},
    191105: {"Unified_Ideograph", "Ideographic"},
    191106: {"Unified_Ideograph", "Ideographic"},
    191107: {"Unified_Ideograph", "Ideographic"},
    191108: {"Unified_Ideograph", "Ideographic"},
    191109: {"Unified_Ideograph", "Ideographic"},
    191110: {"Unified_Ideograph", "Ideographic"},
    191111: {"Unified_Ideograph", "Ideographic"},
    191112: {"Unified_Ideograph", "Ideographic"},
    191113: {"Unified_Ideograph", "Ideographic"},
    191114: {"Unified_Ideograph", "Ideographic"},
    191115: {"Unified_Ideograph", "Ideographic"},
    191116: {"Unified_Ideograph", "Ideographic"},
    191117: {"Unified_Ideograph", "Ideographic"},
    191118: {"Unified_Ideograph", "Ideographic"},
    191119: {"Unified_Ideograph", "Ideographic"},
    191120: {"Unified_Ideograph", "Ideographic"},
    191121: {"Unified_Ideograph", "Ideographic"},
    191122: {"Unified_Ideograph", "Ideographic"},
    191123: {"Unified_Ideograph", "Ideographic"},
    191124: {"Unified_Ideograph", "Ideographic"},
    191125: {"Unified_Ideograph", "Ideographic"},
    191126: {"Unified_Ideograph", "Ideographic"},
    191127: {"Unified_Ideograph", "Ideographic"},
    191128: {"Unified_Ideograph", "Ideographic"},
    191129: {"Unified_Ideograph", "Ideographic"},
    191130: {"Unified_Ideograph", "Ideographic"},
    191131: {"Unified_Ideograph", "Ideographic"},
    191132: {"Unified_Ideograph", "Ideographic"},
    191133: {"Unified_Ideograph", "Ideographic"},
    191134: {"Unified_Ideograph", "Ideographic"},
    191135: {"Unified_Ideograph", "Ideographic"},
    191136: {"Unified_Ideograph", "Ideographic"},
    191137: {"Unified_Ideograph", "Ideographic"},
    191138: {"Unified_Ideograph", "Ideographic"},
    191139: {"Unified_Ideograph", "Ideographic"},
    191140: {"Unified_Ideograph", "Ideographic"},
    191141: {"Unified_Ideograph", "Ideographic"},
    191142: {"Unified_Ideograph", "Ideographic"},
    191143: {"Unified_Ideograph", "Ideographic"},
    191144: {"Unified_Ideograph", "Ideographic"},
    191145: {"Unified_Ideograph", "Ideographic"},
    191146: {"Unified_Ideograph", "Ideographic"},
    191147: {"Unified_Ideograph", "Ideographic"},
    191148: {"Unified_Ideograph", "Ideographic"},
    191149: {"Unified_Ideograph", "Ideographic"},
    191150: {"Unified_Ideograph", "Ideographic"},
    191151: {"Unified_Ideograph", "Ideographic"},
    191152: {"Unified_Ideograph", "Ideographic"},
    191153: {"Unified_Ideograph", "Ideographic"},
    191154: {"Unified_Ideograph", "Ideographic"},
    191155: {"Unified_Ideograph", "Ideographic"},
    191156: {"Unified_Ideograph", "Ideographic"},
    191157: {"Unified_Ideograph", "Ideographic"},
    191158: {"Unified_Ideograph", "Ideographic"},
    191159: {"Unified_Ideograph", "Ideographic"},
    191160: {"Unified_Ideograph", "Ideographic"},
    191161: {"Unified_Ideograph", "Ideographic"},
    191162: {"Unified_Ideograph", "Ideographic"},
    191163: {"Unified_Ideograph", "Ideographic"},
    191164: {"Unified_Ideograph", "Ideographic"},
    191165: {"Unified_Ideograph", "Ideographic"},
    191166: {"Unified_Ideograph", "Ideographic"},
    191167: {"Unified_Ideograph", "Ideographic"},
    191168: {"Unified_Ideograph", "Ideographic"},
    191169: {"Unified_Ideograph", "Ideographic"},
    191170: {"Unified_Ideograph", "Ideographic"},
    191171: {"Unified_Ideograph", "Ideographic"},
    191172: {"Unified_Ideograph", "Ideographic"},
    191173: {"Unified_Ideograph", "Ideographic"},
    191174: {"Unified_Ideograph", "Ideographic"},
    191175: {"Unified_Ideograph", "Ideographic"},
    191176: {"Unified_Ideograph", "Ideographic"},
    191177: {"Unified_Ideograph", "Ideographic"},
    191178: {"Unified_Ideograph", "Ideographic"},
    191179: {"Unified_Ideograph", "Ideographic"},
    191180: {"Unified_Ideograph", "Ideographic"},
    191181: {"Unified_Ideograph", "Ideographic"},
    191182: {"Unified_Ideograph", "Ideographic"},
    191183: {"Unified_Ideograph", "Ideographic"},
    191184: {"Unified_Ideograph", "Ideographic"},
    191185: {"Unified_Ideograph", "Ideographic"},
    191186: {"Unified_Ideograph", "Ideographic"},
    191187: {"Unified_Ideograph", "Ideographic"},
    191188: {"Unified_Ideograph", "Ideographic"},
    191189: {"Unified_Ideograph", "Ideographic"},
    191190: {"Unified_Ideograph", "Ideographic"},
    191191: {"Unified_Ideograph", "Ideographic"},
    191192: {"Unified_Ideograph", "Ideographic"},
    191193: {"Unified_Ideograph", "Ideographic"},
    191194: {"Unified_Ideograph", "Ideographic"},
    191195: {"Unified_Ideograph", "Ideographic"},
    191196: {"Unified_Ideograph", "Ideographic"},
    191197: {"Unified_Ideograph", "Ideographic"},
    191198: {"Unified_Ideograph", "Ideographic"},
    191199: {"Unified_Ideograph", "Ideographic"},
    191200: {"Unified_Ideograph", "Ideographic"},
    191201: {"Unified_Ideograph", "Ideographic"},
    191202: {"Unified_Ideograph", "Ideographic"},
    191203: {"Unified_Ideograph", "Ideographic"},
    191204: {"Unified_Ideograph", "Ideographic"},
    191205: {"Unified_Ideograph", "Ideographic"},
    191206: {"Unified_Ideograph", "Ideographic"},
    191207: {"Unified_Ideograph", "Ideographic"},
    191208: {"Unified_Ideograph", "Ideographic"},
    191209: {"Unified_Ideograph", "Ideographic"},
    191210: {"Unified_Ideograph", "Ideographic"},
    191211: {"Unified_Ideograph", "Ideographic"},
    191212: {"Unified_Ideograph", "Ideographic"},
    191213: {"Unified_Ideograph", "Ideographic"},
    191214: {"Unified_Ideograph", "Ideographic"},
    191215: {"Unified_Ideograph", "Ideographic"},
    191216: {"Unified_Ideograph", "Ideographic"},
    191217: {"Unified_Ideograph", "Ideographic"},
    191218: {"Unified_Ideograph", "Ideographic"},
    191219: {"Unified_Ideograph", "Ideographic"},
    191220: {"Unified_Ideograph", "Ideographic"},
    191221: {"Unified_Ideograph", "Ideographic"},
    191222: {"Unified_Ideograph", "Ideographic"},
    191223: {"Unified_Ideograph", "Ideographic"},
    191224: {"Unified_Ideograph", "Ideographic"},
    191225: {"Unified_Ideograph", "Ideographic"},
    191226: {"Unified_Ideograph", "Ideographic"},
    191227: {"Unified_Ideograph", "Ideographic"},
    191228: {"Unified_Ideograph", "Ideographic"},
    191229: {"Unified_Ideograph", "Ideographic"},
    191230: {"Unified_Ideograph", "Ideographic"},
    191231: {"Unified_Ideograph", "Ideographic"},
    191232: {"Unified_Ideograph", "Ideographic"},
    191233: {"Unified_Ideograph", "Ideographic"},
    191234: {"Unified_Ideograph", "Ideographic"},
    191235: {"Unified_Ideograph", "Ideographic"},
    191236: {"Unified_Ideograph", "Ideographic"},
    191237: {"Unified_Ideograph", "Ideographic"},
    191238: {"Unified_Ideograph", "Ideographic"},
    191239: {"Unified_Ideograph", "Ideographic"},
    191240: {"Unified_Ideograph", "Ideographic"},
    191241: {"Unified_Ideograph", "Ideographic"},
    191242: {"Unified_Ideograph", "Ideographic"},
    191243: {"Unified_Ideograph", "Ideographic"},
    191244: {"Unified_Ideograph", "Ideographic"},
    191245: {"Unified_Ideograph", "Ideographic"},
    191246: {"Unified_Ideograph", "Ideographic"},
    191247: {"Unified_Ideograph", "Ideographic"},
    191248: {"Unified_Ideograph", "Ideographic"},
    191249: {"Unified_Ideograph", "Ideographic"},
    191250: {"Unified_Ideograph", "Ideographic"},
    191251: {"Unified_Ideograph", "Ideographic"},
    191252: {"Unified_Ideograph", "Ideographic"},
    191253: {"Unified_Ideograph", "Ideographic"},
    191254: {"Unified_Ideograph", "Ideographic"},
    191255: {"Unified_Ideograph", "Ideographic"},
    191256: {"Unified_Ideograph", "Ideographic"},
    191257: {"Unified_Ideograph", "Ideographic"},
    191258: {"Unified_Ideograph", "Ideographic"},
    191259: {"Unified_Ideograph", "Ideographic"},
    191260: {"Unified_Ideograph", "Ideographic"},
    191261: {"Unified_Ideograph", "Ideographic"},
    191262: {"Unified_Ideograph", "Ideographic"},
    191263: {"Unified_Ideograph", "Ideographic"},
    191264: {"Unified_Ideograph", "Ideographic"},
    191265: {"Unified_Ideograph", "Ideographic"},
    191266: {"Unified_Ideograph", "Ideographic"},
    191267: {"Unified_Ideograph", "Ideographic"},
    191268: {"Unified_Ideograph", "Ideographic"},
    191269: {"Unified_Ideograph", "Ideographic"},
    191270: {"Unified_Ideograph", "Ideographic"},
    191271: {"Unified_Ideograph", "Ideographic"},
    191272: {"Unified_Ideograph", "Ideographic"},
    191273: {"Unified_Ideograph", "Ideographic"},
    191274: {"Unified_Ideograph", "Ideographic"},
    191275: {"Unified_Ideograph", "Ideographic"},
    191276: {"Unified_Ideograph", "Ideographic"},
    191277: {"Unified_Ideograph", "Ideographic"},
    191278: {"Unified_Ideograph", "Ideographic"},
    191279: {"Unified_Ideograph", "Ideographic"},
    191280: {"Unified_Ideograph", "Ideographic"},
    191281: {"Unified_Ideograph", "Ideographic"},
    191282: {"Unified_Ideograph", "Ideographic"},
    191283: {"Unified_Ideograph", "Ideographic"},
    191284: {"Unified_Ideograph", "Ideographic"},
    191285: {"Unified_Ideograph", "Ideographic"},
    191286: {"Unified_Ideograph", "Ideographic"},
    191287: {"Unified_Ideograph", "Ideographic"},
    191288: {"Unified_Ideograph", "Ideographic"},
    191289: {"Unified_Ideograph", "Ideographic"},
    191290: {"Unified_Ideograph", "Ideographic"},
    191291: {"Unified_Ideograph", "Ideographic"},
    191292: {"Unified_Ideograph", "Ideographic"},
    191293: {"Unified_Ideograph", "Ideographic"},
    191294: {"Unified_Ideograph", "Ideographic"},
    191295: {"Unified_Ideograph", "Ideographic"},
    191296: {"Unified_Ideograph", "Ideographic"},
    191297: {"Unified_Ideograph", "Ideographic"},
    191298: {"Unified_Ideograph", "Ideographic"},
    191299: {"Unified_Ideograph", "Ideographic"},
    191300: {"Unified_Ideograph", "Ideographic"},
    191301: {"Unified_Ideograph", "Ideographic"},
    191302: {"Unified_Ideograph", "Ideographic"},
    191303: {"Unified_Ideograph", "Ideographic"},
    191304: {"Unified_Ideograph", "Ideographic"},
    191305: {"Unified_Ideograph", "Ideographic"},
    191306: {"Unified_Ideograph", "Ideographic"},
    191307: {"Unified_Ideograph", "Ideographic"},
    191308: {"Unified_Ideograph", "Ideographic"},
    191309: {"Unified_Ideograph", "Ideographic"},
    191310: {"Unified_Ideograph", "Ideographic"},
    191311: {"Unified_Ideograph", "Ideographic"},
    191312: {"Unified_Ideograph", "Ideographic"},
    191313: {"Unified_Ideograph", "Ideographic"},
    191314: {"Unified_Ideograph", "Ideographic"},
    191315: {"Unified_Ideograph", "Ideographic"},
    191316: {"Unified_Ideograph", "Ideographic"},
    191317: {"Unified_Ideograph", "Ideographic"},
    191318: {"Unified_Ideograph", "Ideographic"},
    191319: {"Unified_Ideograph", "Ideographic"},
    191320: {"Unified_Ideograph", "Ideographic"},
    191321: {"Unified_Ideograph", "Ideographic"},
    191322: {"Unified_Ideograph", "Ideographic"},
    191323: {"Unified_Ideograph", "Ideographic"},
    191324: {"Unified_Ideograph", "Ideographic"},
    191325: {"Unified_Ideograph", "Ideographic"},
    191326: {"Unified_Ideograph", "Ideographic"},
    191327: {"Unified_Ideograph", "Ideographic"},
    191328: {"Unified_Ideograph", "Ideographic"},
    191329: {"Unified_Ideograph", "Ideographic"},
    191330: {"Unified_Ideograph", "Ideographic"},
    191331: {"Unified_Ideograph", "Ideographic"},
    191332: {"Unified_Ideograph", "Ideographic"},
    191333: {"Unified_Ideograph", "Ideographic"},
    191334: {"Unified_Ideograph", "Ideographic"},
    191335: {"Unified_Ideograph", "Ideographic"},
    191336: {"Unified_Ideograph", "Ideographic"},
    191337: {"Unified_Ideograph", "Ideographic"},
    191338: {"Unified_Ideograph", "Ideographic"},
    191339: {"Unified_Ideograph", "Ideographic"},
    191340: {"Unified_Ideograph", "Ideographic"},
    191341: {"Unified_Ideograph", "Ideographic"},
    191342: {"Unified_Ideograph", "Ideographic"},
    191343: {"Unified_Ideograph", "Ideographic"},
    191344: {"Unified_Ideograph", "Ideographic"},
    191345: {"Unified_Ideograph", "Ideographic"},
    191346: {"Unified_Ideograph", "Ideographic"},
    191347: {"Unified_Ideograph", "Ideographic"},
    191348: {"Unified_Ideograph", "Ideographic"},
    191349: {"Unified_Ideograph", "Ideographic"},
    191350: {"Unified_Ideograph", "Ideographic"},
    191351: {"Unified_Ideograph", "Ideographic"},
    191352: {"Unified_Ideograph", "Ideographic"},
    191353: {"Unified_Ideograph", "Ideographic"},
    191354: {"Unified_Ideograph", "Ideographic"},
    191355: {"Unified_Ideograph", "Ideographic"},
    191356: {"Unified_Ideograph", "Ideographic"},
    191357: {"Unified_Ideograph", "Ideographic"},
    191358: {"Unified_Ideograph", "Ideographic"},
    191359: {"Unified_Ideograph", "Ideographic"},
    191360: {"Unified_Ideograph", "Ideographic"},
    191361: {"Unified_Ideograph", "Ideographic"},
    191362: {"Unified_Ideograph", "Ideographic"},
    191363: {"Unified_Ideograph", "Ideographic"},
    191364: {"Unified_Ideograph", "Ideographic"},
    191365: {"Unified_Ideograph", "Ideographic"},
    191366: {"Unified_Ideograph", "Ideographic"},
    191367: {"Unified_Ideograph", "Ideographic"},
    191368: {"Unified_Ideograph", "Ideographic"},
    191369: {"Unified_Ideograph", "Ideographic"},
    191370: {"Unified_Ideograph", "Ideographic"},
    191371: {"Unified_Ideograph", "Ideographic"},
    191372: {"Unified_Ideograph", "Ideographic"},
    191373: {"Unified_Ideograph", "Ideographic"},
    191374: {"Unified_Ideograph", "Ideographic"},
    191375: {"Unified_Ideograph", "Ideographic"},
    191376: {"Unified_Ideograph", "Ideographic"},
    191377: {"Unified_Ideograph", "Ideographic"},
    191378: {"Unified_Ideograph", "Ideographic"},
    191379: {"Unified_Ideograph", "Ideographic"},
    191380: {"Unified_Ideograph", "Ideographic"},
    191381: {"Unified_Ideograph", "Ideographic"},
    191382: {"Unified_Ideograph", "Ideographic"},
    191383: {"Unified_Ideograph", "Ideographic"},
    191384: {"Unified_Ideograph", "Ideographic"},
    191385: {"Unified_Ideograph", "Ideographic"},
    191386: {"Unified_Ideograph", "Ideographic"},
    191387: {"Unified_Ideograph", "Ideographic"},
    191388: {"Unified_Ideograph", "Ideographic"},
    191389: {"Unified_Ideograph", "Ideographic"},
    191390: {"Unified_Ideograph", "Ideographic"},
    191391: {"Unified_Ideograph", "Ideographic"},
    191392: {"Unified_Ideograph", "Ideographic"},
    191393: {"Unified_Ideograph", "Ideographic"},
    191394: {"Unified_Ideograph", "Ideographic"},
    191395: {"Unified_Ideograph", "Ideographic"},
    191396: {"Unified_Ideograph", "Ideographic"},
    191397: {"Unified_Ideograph", "Ideographic"},
    191398: {"Unified_Ideograph", "Ideographic"},
    191399: {"Unified_Ideograph", "Ideographic"},
    191400: {"Unified_Ideograph", "Ideographic"},
    191401: {"Unified_Ideograph", "Ideographic"},
    191402: {"Unified_Ideograph", "Ideographic"},
    191403: {"Unified_Ideograph", "Ideographic"},
    191404: {"Unified_Ideograph", "Ideographic"},
    191405: {"Unified_Ideograph", "Ideographic"},
    191406: {"Unified_Ideograph", "Ideographic"},
    191407: {"Unified_Ideograph", "Ideographic"},
    191408: {"Unified_Ideograph", "Ideographic"},
    191409: {"Unified_Ideograph", "Ideographic"},
    191410: {"Unified_Ideograph", "Ideographic"},
    191411: {"Unified_Ideograph", "Ideographic"},
    191412: {"Unified_Ideograph", "Ideographic"},
    191413: {"Unified_Ideograph", "Ideographic"},
    191414: {"Unified_Ideograph", "Ideographic"},
    191415: {"Unified_Ideograph", "Ideographic"},
    191416: {"Unified_Ideograph", "Ideographic"},
    191417: {"Unified_Ideograph", "Ideographic"},
    191418: {"Unified_Ideograph", "Ideographic"},
    191419: {"Unified_Ideograph", "Ideographic"},
    191420: {"Unified_Ideograph", "Ideographic"},
    191421: {"Unified_Ideograph", "Ideographic"},
    191422: {"Unified_Ideograph", "Ideographic"},
    191423: {"Unified_Ideograph", "Ideographic"},
    191424: {"Unified_Ideograph", "Ideographic"},
    191425: {"Unified_Ideograph", "Ideographic"},
    191426: {"Unified_Ideograph", "Ideographic"},
    191427: {"Unified_Ideograph", "Ideographic"},
    191428: {"Unified_Ideograph", "Ideographic"},
    191429: {"Unified_Ideograph", "Ideographic"},
    191430: {"Unified_Ideograph", "Ideographic"},
    191431: {"Unified_Ideograph", "Ideographic"},
    191432: {"Unified_Ideograph", "Ideographic"},
    191433: {"Unified_Ideograph", "Ideographic"},
    191434: {"Unified_Ideograph", "Ideographic"},
    191435: {"Unified_Ideograph", "Ideographic"},
    191436: {"Unified_Ideograph", "Ideographic"},
    191437: {"Unified_Ideograph", "Ideographic"},
    191438: {"Unified_Ideograph", "Ideographic"},
    191439: {"Unified_Ideograph", "Ideographic"},
    191440: {"Unified_Ideograph", "Ideographic"},
    191441: {"Unified_Ideograph", "Ideographic"},
    191442: {"Unified_Ideograph", "Ideographic"},
    191443: {"Unified_Ideograph", "Ideographic"},
    191444: {"Unified_Ideograph", "Ideographic"},
    191445: {"Unified_Ideograph", "Ideographic"},
    191446: {"Unified_Ideograph", "Ideographic"},
    191447: {"Unified_Ideograph", "Ideographic"},
    191448: {"Unified_Ideograph", "Ideographic"},
    191449: {"Unified_Ideograph", "Ideographic"},
    191450: {"Unified_Ideograph", "Ideographic"},
    191451: {"Unified_Ideograph", "Ideographic"},
    191452: {"Unified_Ideograph", "Ideographic"},
    191453: {"Unified_Ideograph", "Ideographic"},
    191454: {"Unified_Ideograph", "Ideographic"},
    191455: {"Unified_Ideograph", "Ideographic"},
    191456: {"Unified_Ideograph", "Ideographic"},
    194560: {"Ideographic"},
    194561: {"Ideographic"},
    194562: {"Ideographic"},
    194563: {"Ideographic"},
    194564: {"Ideographic"},
    194565: {"Ideographic"},
    194566: {"Ideographic"},
    194567: {"Ideographic"},
    194568: {"Ideographic"},
    194569: {"Ideographic"},
    194570: {"Ideographic"},
    194571: {"Ideographic"},
    194572: {"Ideographic"},
    194573: {"Ideographic"},
    194574: {"Ideographic"},
    194575: {"Ideographic"},
    194576: {"Ideographic"},
    194577: {"Ideographic"},
    194578: {"Ideographic"},
    194579: {"Ideographic"},
    194580: {"Ideographic"},
    194581: {"Ideographic"},
    194582: {"Ideographic"},
    194583: {"Ideographic"},
    194584: {"Ideographic"},
    194585: {"Ideographic"},
    194586: {"Ideographic"},
    194587: {"Ideographic"},
    194588: {"Ideographic"},
    194589: {"Ideographic"},
    194590: {"Ideographic"},
    194591: {"Ideographic"},
    194592: {"Ideographic"},
    194593: {"Ideographic"},
    194594: {"Ideographic"},
    194595: {"Ideographic"},
    194596: {"Ideographic"},
    194597: {"Ideographic"},
    194598: {"Ideographic"},
    194599: {"Ideographic"},
    194600: {"Ideographic"},
    194601: {"Ideographic"},
    194602: {"Ideographic"},
    194603: {"Ideographic"},
    194604: {"Ideographic"},
    194605: {"Ideographic"},
    194606: {"Ideographic"},
    194607: {"Ideographic"},
    194608: {"Ideographic"},
    194609: {"Ideographic"},
    194610: {"Ideographic"},
    194611: {"Ideographic"},
    194612: {"Ideographic"},
    194613: {"Ideographic"},
    194614: {"Ideographic"},
    194615: {"Ideographic"},
    194616: {"Ideographic"},
    194617: {"Ideographic"},
    194618: {"Ideographic"},
    194619: {"Ideographic"},
    194620: {"Ideographic"},
    194621: {"Ideographic"},
    194622: {"Ideographic"},
    194623: {"Ideographic"},
    194624: {"Ideographic"},
    194625: {"Ideographic"},
    194626: {"Ideographic"},
    194627: {"Ideographic"},
    194628: {"Ideographic"},
    194629: {"Ideographic"},
    194630: {"Ideographic"},
    194631: {"Ideographic"},
    194632: {"Ideographic"},
    194633: {"Ideographic"},
    194634: {"Ideographic"},
    194635: {"Ideographic"},
    194636: {"Ideographic"},
    194637: {"Ideographic"},
    194638: {"Ideographic"},
    194639: {"Ideographic"},
    194640: {"Ideographic"},
    194641: {"Ideographic"},
    194642: {"Ideographic"},
    194643: {"Ideographic"},
    194644: {"Ideographic"},
    194645: {"Ideographic"},
    194646: {"Ideographic"},
    194647: {"Ideographic"},
    194648: {"Ideographic"},
    194649: {"Ideographic"},
    194650: {"Ideographic"},
    194651: {"Ideographic"},
    194652: {"Ideographic"},
    194653: {"Ideographic"},
    194654: {"Ideographic"},
    194655: {"Ideographic"},
    194656: {"Ideographic"},
    194657: {"Ideographic"},
    194658: {"Ideographic"},
    194659: {"Ideographic"},
    194660: {"Ideographic"},
    194661: {"Ideographic"},
    194662: {"Ideographic"},
    194663: {"Ideographic"},
    194664: {"Ideographic"},
    194665: {"Ideographic"},
    194666: {"Ideographic"},
    194667: {"Ideographic"},
    194668: {"Ideographic"},
    194669: {"Ideographic"},
    194670: {"Ideographic"},
    194671: {"Ideographic"},
    194672: {"Ideographic"},
    194673: {"Ideographic"},
    194674: {"Ideographic"},
    194675: {"Ideographic"},
    194676: {"Ideographic"},
    194677: {"Ideographic"},
    194678: {"Ideographic"},
    194679: {"Ideographic"},
    194680: {"Ideographic"},
    194681: {"Ideographic"},
    194682: {"Ideographic"},
    194683: {"Ideographic"},
    194684: {"Ideographic"},
    194685: {"Ideographic"},
    194686: {"Ideographic"},
    194687: {"Ideographic"},
    194688: {"Ideographic"},
    194689: {"Ideographic"},
    194690: {"Ideographic"},
    194691: {"Ideographic"},
    194692: {"Ideographic"},
    194693: {"Ideographic"},
    194694: {"Ideographic"},
    194695: {"Ideographic"},
    194696: {"Ideographic"},
    194697: {"Ideographic"},
    194698: {"Ideographic"},
    194699: {"Ideographic"},
    194700: {"Ideographic"},
    194701: {"Ideographic"},
    194702: {"Ideographic"},
    194703: {"Ideographic"},
    194704: {"Ideographic"},
    194705: {"Ideographic"},
    194706: {"Ideographic"},
    194707: {"Ideographic"},
    194708: {"Ideographic"},
    194709: {"Ideographic"},
    194710: {"Ideographic"},
    194711: {"Ideographic"},
    194712: {"Ideographic"},
    194713: {"Ideographic"},
    194714: {"Ideographic"},
    194715: {"Ideographic"},
    194716: {"Ideographic"},
    194717: {"Ideographic"},
    194718: {"Ideographic"},
    194719: {"Ideographic"},
    194720: {"Ideographic"},
    194721: {"Ideographic"},
    194722: {"Ideographic"},
    194723: {"Ideographic"},
    194724: {"Ideographic"},
    194725: {"Ideographic"},
    194726: {"Ideographic"},
    194727: {"Ideographic"},
    194728: {"Ideographic"},
    194729: {"Ideographic"},
    194730: {"Ideographic"},
    194731: {"Ideographic"},
    194732: {"Ideographic"},
    194733: {"Ideographic"},
    194734: {"Ideographic"},
    194735: {"Ideographic"},
    194736: {"Ideographic"},
    194737: {"Ideographic"},
    194738: {"Ideographic"},
    194739: {"Ideographic"},
    194740: {"Ideographic"},
    194741: {"Ideographic"},
    194742: {"Ideographic"},
    194743: {"Ideographic"},
    194744: {"Ideographic"},
    194745: {"Ideographic"},
    194746: {"Ideographic"},
    194747: {"Ideographic"},
    194748: {"Ideographic"},
    194749: {"Ideographic"},
    194750: {"Ideographic"},
    194751: {"Ideographic"},
    194752: {"Ideographic"},
    194753: {"Ideographic"},
    194754: {"Ideographic"},
    194755: {"Ideographic"},
    194756: {"Ideographic"},
    194757: {"Ideographic"},
    194758: {"Ideographic"},
    194759: {"Ideographic"},
    194760: {"Ideographic"},
    194761: {"Ideographic"},
    194762: {"Ideographic"},
    194763: {"Ideographic"},
    194764: {"Ideographic"},
    194765: {"Ideographic"},
    194766: {"Ideographic"},
    194767: {"Ideographic"},
    194768: {"Ideographic"},
    194769: {"Ideographic"},
    194770: {"Ideographic"},
    194771: {"Ideographic"},
    194772: {"Ideographic"},
    194773: {"Ideographic"},
    194774: {"Ideographic"},
    194775: {"Ideographic"},
    194776: {"Ideographic"},
    194777: {"Ideographic"},
    194778: {"Ideographic"},
    194779: {"Ideographic"},
    194780: {"Ideographic"},
    194781: {"Ideographic"},
    194782: {"Ideographic"},
    194783: {"Ideographic"},
    194784: {"Ideographic"},
    194785: {"Ideographic"},
    194786: {"Ideographic"},
    194787: {"Ideographic"},
    194788: {"Ideographic"},
    194789: {"Ideographic"},
    194790: {"Ideographic"},
    194791: {"Ideographic"},
    194792: {"Ideographic"},
    194793: {"Ideographic"},
    194794: {"Ideographic"},
    194795: {"Ideographic"},
    194796: {"Ideographic"},
    194797: {"Ideographic"},
    194798: {"Ideographic"},
    194799: {"Ideographic"},
    194800: {"Ideographic"},
    194801: {"Ideographic"},
    194802: {"Ideographic"},
    194803: {"Ideographic"},
    194804: {"Ideographic"},
    194805: {"Ideographic"},
    194806: {"Ideographic"},
    194807: {"Ideographic"},
    194808: {"Ideographic"},
    194809: {"Ideographic"},
    194810: {"Ideographic"},
    194811: {"Ideographic"},
    194812: {"Ideographic"},
    194813: {"Ideographic"},
    194814: {"Ideographic"},
    194815: {"Ideographic"},
    194816: {"Ideographic"},
    194817: {"Ideographic"},
    194818: {"Ideographic"},
    194819: {"Ideographic"},
    194820: {"Ideographic"},
    194821: {"Ideographic"},
    194822: {"Ideographic"},
    194823: {"Ideographic"},
    194824: {"Ideographic"},
    194825: {"Ideographic"},
    194826: {"Ideographic"},
    194827: {"Ideographic"},
    194828: {"Ideographic"},
    194829: {"Ideographic"},
    194830: {"Ideographic"},
    194831: {"Ideographic"},
    194832: {"Ideographic"},
    194833: {"Ideographic"},
    194834: {"Ideographic"},
    194835: {"Ideographic"},
    194836: {"Ideographic"},
    194837: {"Ideographic"},
    194838: {"Ideographic"},
    194839: {"Ideographic"},
    194840: {"Ideographic"},
    194841: {"Ideographic"},
    194842: {"Ideographic"},
    194843: {"Ideographic"},
    194844: {"Ideographic"},
    194845: {"Ideographic"},
    194846: {"Ideographic"},
    194847: {"Ideographic"},
    194848: {"Ideographic"},
    194849: {"Ideographic"},
    194850: {"Ideographic"},
    194851: {"Ideographic"},
    194852: {"Ideographic"},
    194853: {"Ideographic"},
    194854: {"Ideographic"},
    194855: {"Ideographic"},
    194856: {"Ideographic"},
    194857: {"Ideographic"},
    194858: {"Ideographic"},
    194859: {"Ideographic"},
    194860: {"Ideographic"},
    194861: {"Ideographic"},
    194862: {"Ideographic"},
    194863: {"Ideographic"},
    194864: {"Ideographic"},
    194865: {"Ideographic"},
    194866: {"Ideographic"},
    194867: {"Ideographic"},
    194868: {"Ideographic"},
    194869: {"Ideographic"},
    194870: {"Ideographic"},
    194871: {"Ideographic"},
    194872: {"Ideographic"},
    194873: {"Ideographic"},
    194874: {"Ideographic"},
    194875: {"Ideographic"},
    194876: {"Ideographic"},
    194877: {"Ideographic"},
    194878: {"Ideographic"},
    194879: {"Ideographic"},
    194880: {"Ideographic"},
    194881: {"Ideographic"},
    194882: {"Ideographic"},
    194883: {"Ideographic"},
    194884: {"Ideographic"},
    194885: {"Ideographic"},
    194886: {"Ideographic"},
    194887: {"Ideographic"},
    194888: {"Ideographic"},
    194889: {"Ideographic"},
    194890: {"Ideographic"},
    194891: {"Ideographic"},
    194892: {"Ideographic"},
    194893: {"Ideographic"},
    194894: {"Ideographic"},
    194895: {"Ideographic"},
    194896: {"Ideographic"},
    194897: {"Ideographic"},
    194898: {"Ideographic"},
    194899: {"Ideographic"},
    194900: {"Ideographic"},
    194901: {"Ideographic"},
    194902: {"Ideographic"},
    194903: {"Ideographic"},
    194904: {"Ideographic"},
    194905: {"Ideographic"},
    194906: {"Ideographic"},
    194907: {"Ideographic"},
    194908: {"Ideographic"},
    194909: {"Ideographic"},
    194910: {"Ideographic"},
    194911: {"Ideographic"},
    194912: {"Ideographic"},
    194913: {"Ideographic"},
    194914: {"Ideographic"},
    194915: {"Ideographic"},
    194916: {"Ideographic"},
    194917: {"Ideographic"},
    194918: {"Ideographic"},
    194919: {"Ideographic"},
    194920: {"Ideographic"},
    194921: {"Ideographic"},
    194922: {"Ideographic"},
    194923: {"Ideographic"},
    194924: {"Ideographic"},
    194925: {"Ideographic"},
    194926: {"Ideographic"},
    194927: {"Ideographic"},
    194928: {"Ideographic"},
    194929: {"Ideographic"},
    194930: {"Ideographic"},
    194931: {"Ideographic"},
    194932: {"Ideographic"},
    194933: {"Ideographic"},
    194934: {"Ideographic"},
    194935: {"Ideographic"},
    194936: {"Ideographic"},
    194937: {"Ideographic"},
    194938: {"Ideographic"},
    194939: {"Ideographic"},
    194940: {"Ideographic"},
    194941: {"Ideographic"},
    194942: {"Ideographic"},
    194943: {"Ideographic"},
    194944: {"Ideographic"},
    194945: {"Ideographic"},
    194946: {"Ideographic"},
    194947: {"Ideographic"},
    194948: {"Ideographic"},
    194949: {"Ideographic"},
    194950: {"Ideographic"},
    194951: {"Ideographic"},
    194952: {"Ideographic"},
    194953: {"Ideographic"},
    194954: {"Ideographic"},
    194955: {"Ideographic"},
    194956: {"Ideographic"},
    194957: {"Ideographic"},
    194958: {"Ideographic"},
    194959: {"Ideographic"},
    194960: {"Ideographic"},
    194961: {"Ideographic"},
    194962: {"Ideographic"},
    194963: {"Ideographic"},
    194964: {"Ideographic"},
    194965: {"Ideographic"},
    194966: {"Ideographic"},
    194967: {"Ideographic"},
    194968: {"Ideographic"},
    194969: {"Ideographic"},
    194970: {"Ideographic"},
    194971: {"Ideographic"},
    194972: {"Ideographic"},
    194973: {"Ideographic"},
    194974: {"Ideographic"},
    194975: {"Ideographic"},
    194976: {"Ideographic"},
    194977: {"Ideographic"},
    194978: {"Ideographic"},
    194979: {"Ideographic"},
    194980: {"Ideographic"},
    194981: {"Ideographic"},
    194982: {"Ideographic"},
    194983: {"Ideographic"},
    194984: {"Ideographic"},
    194985: {"Ideographic"},
    194986: {"Ideographic"},
    194987: {"Ideographic"},
    194988: {"Ideographic"},
    194989: {"Ideographic"},
    194990: {"Ideographic"},
    194991: {"Ideographic"},
    194992: {"Ideographic"},
    194993: {"Ideographic"},
    194994: {"Ideographic"},
    194995: {"Ideographic"},
    194996: {"Ideographic"},
    194997: {"Ideographic"},
    194998: {"Ideographic"},
    194999: {"Ideographic"},
    195000: {"Ideographic"},
    195001: {"Ideographic"},
    195002: {"Ideographic"},
    195003: {"Ideographic"},
    195004: {"Ideographic"},
    195005: {"Ideographic"},
    195006: {"Ideographic"},
    195007: {"Ideographic"},
    195008: {"Ideographic"},
    195009: {"Ideographic"},
    195010: {"Ideographic"},
    195011: {"Ideographic"},
    195012: {"Ideographic"},
    195013: {"Ideographic"},
    195014: {"Ideographic"},
    195015: {"Ideographic"},
    195016: {"Ideographic"},
    195017: {"Ideographic"},
    195018: {"Ideographic"},
    195019: {"Ideographic"},
    195020: {"Ideographic"},
    195021: {"Ideographic"},
    195022: {"Ideographic"},
    195023: {"Ideographic"},
    195024: {"Ideographic"},
    195025: {"Ideographic"},
    195026: {"Ideographic"},
    195027: {"Ideographic"},
    195028: {"Ideographic"},
    195029: {"Ideographic"},
    195030: {"Ideographic"},
    195031: {"Ideographic"},
    195032: {"Ideographic"},
    195033: {"Ideographic"},
    195034: {"Ideographic"},
    195035: {"Ideographic"},
    195036: {"Ideographic"},
    195037: {"Ideographic"},
    195038: {"Ideographic"},
    195039: {"Ideographic"},
    195040: {"Ideographic"},
    195041: {"Ideographic"},
    195042: {"Ideographic"},
    195043: {"Ideographic"},
    195044: {"Ideographic"},
    195045: {"Ideographic"},
    195046: {"Ideographic"},
    195047: {"Ideographic"},
    195048: {"Ideographic"},
    195049: {"Ideographic"},
    195050: {"Ideographic"},
    195051: {"Ideographic"},
    195052: {"Ideographic"},
    195053: {"Ideographic"},
    195054: {"Ideographic"},
    195055: {"Ideographic"},
    195056: {"Ideographic"},
    195057: {"Ideographic"},
    195058: {"Ideographic"},
    195059: {"Ideographic"},
    195060: {"Ideographic"},
    195061: {"Ideographic"},
    195062: {"Ideographic"},
    195063: {"Ideographic"},
    195064: {"Ideographic"},
    195065: {"Ideographic"},
    195066: {"Ideographic"},
    195067: {"Ideographic"},
    195068: {"Ideographic"},
    195069: {"Ideographic"},
    195070: {"Ideographic"},
    195071: {"Ideographic"},
    195072: {"Ideographic"},
    195073: {"Ideographic"},
    195074: {"Ideographic"},
    195075: {"Ideographic"},
    195076: {"Ideographic"},
    195077: {"Ideographic"},
    195078: {"Ideographic"},
    195079: {"Ideographic"},
    195080: {"Ideographic"},
    195081: {"Ideographic"},
    195082: {"Ideographic"},
    195083: {"Ideographic"},
    195084: {"Ideographic"},
    195085: {"Ideographic"},
    195086: {"Ideographic"},
    195087: {"Ideographic"},
    195088: {"Ideographic"},
    195089: {"Ideographic"},
    195090: {"Ideographic"},
    195091: {"Ideographic"},
    195092: {"Ideographic"},
    195093: {"Ideographic"},
    195094: {"Ideographic"},
    195095: {"Ideographic"},
    195096: {"Ideographic"},
    195097: {"Ideographic"},
    195098: {"Ideographic"},
    195099: {"Ideographic"},
    195100: {"Ideographic"},
    195101: {"Ideographic"},
    196606: {"Noncharacter_Code_Point"},
    196607: {"Noncharacter_Code_Point"},
    196608: {"Unified_Ideograph", "Ideographic"},
    196609: {"Unified_Ideograph", "Ideographic"},
    196610: {"Unified_Ideograph", "Ideographic"},
    196611: {"Unified_Ideograph", "Ideographic"},
    196612: {"Unified_Ideograph", "Ideographic"},
    196613: {"Unified_Ideograph", "Ideographic"},
    196614: {"Unified_Ideograph", "Ideographic"},
    196615: {"Unified_Ideograph", "Ideographic"},
    196616: {"Unified_Ideograph", "Ideographic"},
    196617: {"Unified_Ideograph", "Ideographic"},
    196618: {"Unified_Ideograph", "Ideographic"},
    196619: {"Unified_Ideograph", "Ideographic"},
    196620: {"Unified_Ideograph", "Ideographic"},
    196621: {"Unified_Ideograph", "Ideographic"},
    196622: {"Unified_Ideograph", "Ideographic"},
    196623: {"Unified_Ideograph", "Ideographic"},
    196624: {"Unified_Ideograph", "Ideographic"},
    196625: {"Unified_Ideograph", "Ideographic"},
    196626: {"Unified_Ideograph", "Ideographic"},
    196627: {"Unified_Ideograph", "Ideographic"},
    196628: {"Unified_Ideograph", "Ideographic"},
    196629: {"Unified_Ideograph", "Ideographic"},
    196630: {"Unified_Ideograph", "Ideographic"},
    196631: {"Unified_Ideograph", "Ideographic"},
    196632: {"Unified_Ideograph", "Ideographic"},
    196633: {"Unified_Ideograph", "Ideographic"},
    196634: {"Unified_Ideograph", "Ideographic"},
    196635: {"Unified_Ideograph", "Ideographic"},
    196636: {"Unified_Ideograph", "Ideographic"},
    196637: {"Unified_Ideograph", "Ideographic"},
    196638: {"Unified_Ideograph", "Ideographic"},
    196639: {"Unified_Ideograph", "Ideographic"},
    196640: {"Unified_Ideograph", "Ideographic"},
    196641: {"Unified_Ideograph", "Ideographic"},
    196642: {"Unified_Ideograph", "Ideographic"},
    196643: {"Unified_Ideograph", "Ideographic"},
    196644: {"Unified_Ideograph", "Ideographic"},
    196645: {"Unified_Ideograph", "Ideographic"},
    196646: {"Unified_Ideograph", "Ideographic"},
    196647: {"Unified_Ideograph", "Ideographic"},
    196648: {"Unified_Ideograph", "Ideographic"},
    196649: {"Unified_Ideograph", "Ideographic"},
    196650: {"Unified_Ideograph", "Ideographic"},
    196651: {"Unified_Ideograph", "Ideographic"},
    196652: {"Unified_Ideograph", "Ideographic"},
    196653: {"Unified_Ideograph", "Ideographic"},
    196654: {"Unified_Ideograph", "Ideographic"},
    196655: {"Unified_Ideograph", "Ideographic"},
    196656: {"Unified_Ideograph", "Ideographic"},
    196657: {"Unified_Ideograph", "Ideographic"},
    196658: {"Unified_Ideograph", "Ideographic"},
    196659: {"Unified_Ideograph", "Ideographic"},
    196660: {"Unified_Ideograph", "Ideographic"},
    196661: {"Unified_Ideograph", "Ideographic"},
    196662: {"Unified_Ideograph", "Ideographic"},
    196663: {"Unified_Ideograph", "Ideographic"},
    196664: {"Unified_Ideograph", "Ideographic"},
    196665: {"Unified_Ideograph", "Ideographic"},
    196666: {"Unified_Ideograph", "Ideographic"},
    196667: {"Unified_Ideograph", "Ideographic"},
    196668: {"Unified_Ideograph", "Ideographic"},
    196669: {"Unified_Ideograph", "Ideographic"},
    196670: {"Unified_Ideograph", "Ideographic"},
    196671: {"Unified_Ideograph", "Ideographic"},
    196672: {"Unified_Ideograph", "Ideographic"},
    196673: {"Unified_Ideograph", "Ideographic"},
    196674: {"Unified_Ideograph", "Ideographic"},
    196675: {"Unified_Ideograph", "Ideographic"},
    196676: {"Unified_Ideograph", "Ideographic"},
    196677: {"Unified_Ideograph", "Ideographic"},
    196678: {"Unified_Ideograph", "Ideographic"},
    196679: {"Unified_Ideograph", "Ideographic"},
    196680: {"Unified_Ideograph", "Ideographic"},
    196681: {"Unified_Ideograph", "Ideographic"},
    196682: {"Unified_Ideograph", "Ideographic"},
    196683: {"Unified_Ideograph", "Ideographic"},
    196684: {"Unified_Ideograph", "Ideographic"},
    196685: {"Unified_Ideograph", "Ideographic"},
    196686: {"Unified_Ideograph", "Ideographic"},
    196687: {"Unified_Ideograph", "Ideographic"},
    196688: {"Unified_Ideograph", "Ideographic"},
    196689: {"Unified_Ideograph", "Ideographic"},
    196690: {"Unified_Ideograph", "Ideographic"},
    196691: {"Unified_Ideograph", "Ideographic"},
    196692: {"Unified_Ideograph", "Ideographic"},
    196693: {"Unified_Ideograph", "Ideographic"},
    196694: {"Unified_Ideograph", "Ideographic"},
    196695: {"Unified_Ideograph", "Ideographic"},
    196696: {"Unified_Ideograph", "Ideographic"},
    196697: {"Unified_Ideograph", "Ideographic"},
    196698: {"Unified_Ideograph", "Ideographic"},
    196699: {"Unified_Ideograph", "Ideographic"},
    196700: {"Unified_Ideograph", "Ideographic"},
    196701: {"Unified_Ideograph", "Ideographic"},
    196702: {"Unified_Ideograph", "Ideographic"},
    196703: {"Unified_Ideograph", "Ideographic"},
    196704: {"Unified_Ideograph", "Ideographic"},
    196705: {"Unified_Ideograph", "Ideographic"},
    196706: {"Unified_Ideograph", "Ideographic"},
    196707: {"Unified_Ideograph", "Ideographic"},
    196708: {"Unified_Ideograph", "Ideographic"},
    196709: {"Unified_Ideograph", "Ideographic"},
    196710: {"Unified_Ideograph", "Ideographic"},
    196711: {"Unified_Ideograph", "Ideographic"},
    196712: {"Unified_Ideograph", "Ideographic"},
    196713: {"Unified_Ideograph", "Ideographic"},
    196714: {"Unified_Ideograph", "Ideographic"},
    196715: {"Unified_Ideograph", "Ideographic"},
    196716: {"Unified_Ideograph", "Ideographic"},
    196717: {"Unified_Ideograph", "Ideographic"},
    196718: {"Unified_Ideograph", "Ideographic"},
    196719: {"Unified_Ideograph", "Ideographic"},
    196720: {"Unified_Ideograph", "Ideographic"},
    196721: {"Unified_Ideograph", "Ideographic"},
    196722: {"Unified_Ideograph", "Ideographic"},
    196723: {"Unified_Ideograph", "Ideographic"},
    196724: {"Unified_Ideograph", "Ideographic"},
    196725: {"Unified_Ideograph", "Ideographic"},
    196726: {"Unified_Ideograph", "Ideographic"},
    196727: {"Unified_Ideograph", "Ideographic"},
    196728: {"Unified_Ideograph", "Ideographic"},
    196729: {"Unified_Ideograph", "Ideographic"},
    196730: {"Unified_Ideograph", "Ideographic"},
    196731: {"Unified_Ideograph", "Ideographic"},
    196732: {"Unified_Ideograph", "Ideographic"},
    196733: {"Unified_Ideograph", "Ideographic"},
    196734: {"Unified_Ideograph", "Ideographic"},
    196735: {"Unified_Ideograph", "Ideographic"},
    196736: {"Unified_Ideograph", "Ideographic"},
    196737: {"Unified_Ideograph", "Ideographic"},
    196738: {"Unified_Ideograph", "Ideographic"},
    196739: {"Unified_Ideograph", "Ideographic"},
    196740: {"Unified_Ideograph", "Ideographic"},
    196741: {"Unified_Ideograph", "Ideographic"},
    196742: {"Unified_Ideograph", "Ideographic"},
    196743: {"Unified_Ideograph", "Ideographic"},
    196744: {"Unified_Ideograph", "Ideographic"},
    196745: {"Unified_Ideograph", "Ideographic"},
    196746: {"Unified_Ideograph", "Ideographic"},
    196747: {"Unified_Ideograph", "Ideographic"},
    196748: {"Unified_Ideograph", "Ideographic"},
    196749: {"Unified_Ideograph", "Ideographic"},
    196750: {"Unified_Ideograph", "Ideographic"},
    196751: {"Unified_Ideograph", "Ideographic"},
    196752: {"Unified_Ideograph", "Ideographic"},
    196753: {"Unified_Ideograph", "Ideographic"},
    196754: {"Unified_Ideograph", "Ideographic"},
    196755: {"Unified_Ideograph", "Ideographic"},
    196756: {"Unified_Ideograph", "Ideographic"},
    196757: {"Unified_Ideograph", "Ideographic"},
    196758: {"Unified_Ideograph", "Ideographic"},
    196759: {"Unified_Ideograph", "Ideographic"},
    196760: {"Unified_Ideograph", "Ideographic"},
    196761: {"Unified_Ideograph", "Ideographic"},
    196762: {"Unified_Ideograph", "Ideographic"},
    196763: {"Unified_Ideograph", "Ideographic"},
    196764: {"Unified_Ideograph", "Ideographic"},
    196765: {"Unified_Ideograph", "Ideographic"},
    196766: {"Unified_Ideograph", "Ideographic"},
    196767: {"Unified_Ideograph", "Ideographic"},
    196768: {"Unified_Ideograph", "Ideographic"},
    196769: {"Unified_Ideograph", "Ideographic"},
    196770: {"Unified_Ideograph", "Ideographic"},
    196771: {"Unified_Ideograph", "Ideographic"},
    196772: {"Unified_Ideograph", "Ideographic"},
    196773: {"Unified_Ideograph", "Ideographic"},
    196774: {"Unified_Ideograph", "Ideographic"},
    196775: {"Unified_Ideograph", "Ideographic"},
    196776: {"Unified_Ideograph", "Ideographic"},
    196777: {"Unified_Ideograph", "Ideographic"},
    196778: {"Unified_Ideograph", "Ideographic"},
    196779: {"Unified_Ideograph", "Ideographic"},
    196780: {"Unified_Ideograph", "Ideographic"},
    196781: {"Unified_Ideograph", "Ideographic"},
    196782: {"Unified_Ideograph", "Ideographic"},
    196783: {"Unified_Ideograph", "Ideographic"},
    196784: {"Unified_Ideograph", "Ideographic"},
    196785: {"Unified_Ideograph", "Ideographic"},
    196786: {"Unified_Ideograph", "Ideographic"},
    196787: {"Unified_Ideograph", "Ideographic"},
    196788: {"Unified_Ideograph", "Ideographic"},
    196789: {"Unified_Ideograph", "Ideographic"},
    196790: {"Unified_Ideograph", "Ideographic"},
    196791: {"Unified_Ideograph", "Ideographic"},
    196792: {"Unified_Ideograph", "Ideographic"},
    196793: {"Unified_Ideograph", "Ideographic"},
    196794: {"Unified_Ideograph", "Ideographic"},
    196795: {"Unified_Ideograph", "Ideographic"},
    196796: {"Unified_Ideograph", "Ideographic"},
    196797: {"Unified_Ideograph", "Ideographic"},
    196798: {"Unified_Ideograph", "Ideographic"},
    196799: {"Unified_Ideograph", "Ideographic"},
    196800: {"Unified_Ideograph", "Ideographic"},
    196801: {"Unified_Ideograph", "Ideographic"},
    196802: {"Unified_Ideograph", "Ideographic"},
    196803: {"Unified_Ideograph", "Ideographic"},
    196804: {"Unified_Ideograph", "Ideographic"},
    196805: {"Unified_Ideograph", "Ideographic"},
    196806: {"Unified_Ideograph", "Ideographic"},
    196807: {"Unified_Ideograph", "Ideographic"},
    196808: {"Unified_Ideograph", "Ideographic"},
    196809: {"Unified_Ideograph", "Ideographic"},
    196810: {"Unified_Ideograph", "Ideographic"},
    196811: {"Unified_Ideograph", "Ideographic"},
    196812: {"Unified_Ideograph", "Ideographic"},
    196813: {"Unified_Ideograph", "Ideographic"},
    196814: {"Unified_Ideograph", "Ideographic"},
    196815: {"Unified_Ideograph", "Ideographic"},
    196816: {"Unified_Ideograph", "Ideographic"},
    196817: {"Unified_Ideograph", "Ideographic"},
    196818: {"Unified_Ideograph", "Ideographic"},
    196819: {"Unified_Ideograph", "Ideographic"},
    196820: {"Unified_Ideograph", "Ideographic"},
    196821: {"Unified_Ideograph", "Ideographic"},
    196822: {"Unified_Ideograph", "Ideographic"},
    196823: {"Unified_Ideograph", "Ideographic"},
    196824: {"Unified_Ideograph", "Ideographic"},
    196825: {"Unified_Ideograph", "Ideographic"},
    196826: {"Unified_Ideograph", "Ideographic"},
    196827: {"Unified_Ideograph", "Ideographic"},
    196828: {"Unified_Ideograph", "Ideographic"},
    196829: {"Unified_Ideograph", "Ideographic"},
    196830: {"Unified_Ideograph", "Ideographic"},
    196831: {"Unified_Ideograph", "Ideographic"},
    196832: {"Unified_Ideograph", "Ideographic"},
    196833: {"Unified_Ideograph", "Ideographic"},
    196834: {"Unified_Ideograph", "Ideographic"},
    196835: {"Unified_Ideograph", "Ideographic"},
    196836: {"Unified_Ideograph", "Ideographic"},
    196837: {"Unified_Ideograph", "Ideographic"},
    196838: {"Unified_Ideograph", "Ideographic"},
    196839: {"Unified_Ideograph", "Ideographic"},
    196840: {"Unified_Ideograph", "Ideographic"},
    196841: {"Unified_Ideograph", "Ideographic"},
    196842: {"Unified_Ideograph", "Ideographic"},
    196843: {"Unified_Ideograph", "Ideographic"},
    196844: {"Unified_Ideograph", "Ideographic"},
    196845: {"Unified_Ideograph", "Ideographic"},
    196846: {"Unified_Ideograph", "Ideographic"},
    196847: {"Unified_Ideograph", "Ideographic"},
    196848: {"Unified_Ideograph", "Ideographic"},
    196849: {"Unified_Ideograph", "Ideographic"},
    196850: {"Unified_Ideograph", "Ideographic"},
    196851: {"Unified_Ideograph", "Ideographic"},
    196852: {"Unified_Ideograph", "Ideographic"},
    196853: {"Unified_Ideograph", "Ideographic"},
    196854: {"Unified_Ideograph", "Ideographic"},
    196855: {"Unified_Ideograph", "Ideographic"},
    196856: {"Unified_Ideograph", "Ideographic"},
    196857: {"Unified_Ideograph", "Ideographic"},
    196858: {"Unified_Ideograph", "Ideographic"},
    196859: {"Unified_Ideograph", "Ideographic"},
    196860: {"Unified_Ideograph", "Ideographic"},
    196861: {"Unified_Ideograph", "Ideographic"},
    196862: {"Unified_Ideograph", "Ideographic"},
    196863: {"Unified_Ideograph", "Ideographic"},
    196864: {"Unified_Ideograph", "Ideographic"},
    196865: {"Unified_Ideograph", "Ideographic"},
    196866: {"Unified_Ideograph", "Ideographic"},
    196867: {"Unified_Ideograph", "Ideographic"},
    196868: {"Unified_Ideograph", "Ideographic"},
    196869: {"Unified_Ideograph", "Ideographic"},
    196870: {"Unified_Ideograph", "Ideographic"},
    196871: {"Unified_Ideograph", "Ideographic"},
    196872: {"Unified_Ideograph", "Ideographic"},
    196873: {"Unified_Ideograph", "Ideographic"},
    196874: {"Unified_Ideograph", "Ideographic"},
    196875: {"Unified_Ideograph", "Ideographic"},
    196876: {"Unified_Ideograph", "Ideographic"},
    196877: {"Unified_Ideograph", "Ideographic"},
    196878: {"Unified_Ideograph", "Ideographic"},
    196879: {"Unified_Ideograph", "Ideographic"},
    196880: {"Unified_Ideograph", "Ideographic"},
    196881: {"Unified_Ideograph", "Ideographic"},
    196882: {"Unified_Ideograph", "Ideographic"},
    196883: {"Unified_Ideograph", "Ideographic"},
    196884: {"Unified_Ideograph", "Ideographic"},
    196885: {"Unified_Ideograph", "Ideographic"},
    196886: {"Unified_Ideograph", "Ideographic"},
    196887: {"Unified_Ideograph", "Ideographic"},
    196888: {"Unified_Ideograph", "Ideographic"},
    196889: {"Unified_Ideograph", "Ideographic"},
    196890: {"Unified_Ideograph", "Ideographic"},
    196891: {"Unified_Ideograph", "Ideographic"},
    196892: {"Unified_Ideograph", "Ideographic"},
    196893: {"Unified_Ideograph", "Ideographic"},
    196894: {"Unified_Ideograph", "Ideographic"},
    196895: {"Unified_Ideograph", "Ideographic"},
    196896: {"Unified_Ideograph", "Ideographic"},
    196897: {"Unified_Ideograph", "Ideographic"},
    196898: {"Unified_Ideograph", "Ideographic"},
    196899: {"Unified_Ideograph", "Ideographic"},
    196900: {"Unified_Ideograph", "Ideographic"},
    196901: {"Unified_Ideograph", "Ideographic"},
    196902: {"Unified_Ideograph", "Ideographic"},
    196903: {"Unified_Ideograph", "Ideographic"},
    196904: {"Unified_Ideograph", "Ideographic"},
    196905: {"Unified_Ideograph", "Ideographic"},
    196906: {"Unified_Ideograph", "Ideographic"},
    196907: {"Unified_Ideograph", "Ideographic"},
    196908: {"Unified_Ideograph", "Ideographic"},
    196909: {"Unified_Ideograph", "Ideographic"},
    196910: {"Unified_Ideograph", "Ideographic"},
    196911: {"Unified_Ideograph", "Ideographic"},
    196912: {"Unified_Ideograph", "Ideographic"},
    196913: {"Unified_Ideograph", "Ideographic"},
    196914: {"Unified_Ideograph", "Ideographic"},
    196915: {"Unified_Ideograph", "Ideographic"},
    196916: {"Unified_Ideograph", "Ideographic"},
    196917: {"Unified_Ideograph", "Ideographic"},
    196918: {"Unified_Ideograph", "Ideographic"},
    196919: {"Unified_Ideograph", "Ideographic"},
    196920: {"Unified_Ideograph", "Ideographic"},
    196921: {"Unified_Ideograph", "Ideographic"},
    196922: {"Unified_Ideograph", "Ideographic"},
    196923: {"Unified_Ideograph", "Ideographic"},
    196924: {"Unified_Ideograph", "Ideographic"},
    196925: {"Unified_Ideograph", "Ideographic"},
    196926: {"Unified_Ideograph", "Ideographic"},
    196927: {"Unified_Ideograph", "Ideographic"},
    196928: {"Unified_Ideograph", "Ideographic"},
    196929: {"Unified_Ideograph", "Ideographic"},
    196930: {"Unified_Ideograph", "Ideographic"},
    196931: {"Unified_Ideograph", "Ideographic"},
    196932: {"Unified_Ideograph", "Ideographic"},
    196933: {"Unified_Ideograph", "Ideographic"},
    196934: {"Unified_Ideograph", "Ideographic"},
    196935: {"Unified_Ideograph", "Ideographic"},
    196936: {"Unified_Ideograph", "Ideographic"},
    196937: {"Unified_Ideograph", "Ideographic"},
    196938: {"Unified_Ideograph", "Ideographic"},
    196939: {"Unified_Ideograph", "Ideographic"},
    196940: {"Unified_Ideograph", "Ideographic"},
    196941: {"Unified_Ideograph", "Ideographic"},
    196942: {"Unified_Ideograph", "Ideographic"},
    196943: {"Unified_Ideograph", "Ideographic"},
    196944: {"Unified_Ideograph", "Ideographic"},
    196945: {"Unified_Ideograph", "Ideographic"},
    196946: {"Unified_Ideograph", "Ideographic"},
    196947: {"Unified_Ideograph", "Ideographic"},
    196948: {"Unified_Ideograph", "Ideographic"},
    196949: {"Unified_Ideograph", "Ideographic"},
    196950: {"Unified_Ideograph", "Ideographic"},
    196951: {"Unified_Ideograph", "Ideographic"},
    196952: {"Unified_Ideograph", "Ideographic"},
    196953: {"Unified_Ideograph", "Ideographic"},
    196954: {"Unified_Ideograph", "Ideographic"},
    196955: {"Unified_Ideograph", "Ideographic"},
    196956: {"Unified_Ideograph", "Ideographic"},
    196957: {"Unified_Ideograph", "Ideographic"},
    196958: {"Unified_Ideograph", "Ideographic"},
    196959: {"Unified_Ideograph", "Ideographic"},
    196960: {"Unified_Ideograph", "Ideographic"},
    196961: {"Unified_Ideograph", "Ideographic"},
    196962: {"Unified_Ideograph", "Ideographic"},
    196963: {"Unified_Ideograph", "Ideographic"},
    196964: {"Unified_Ideograph", "Ideographic"},
    196965: {"Unified_Ideograph", "Ideographic"},
    196966: {"Unified_Ideograph", "Ideographic"},
    196967: {"Unified_Ideograph", "Ideographic"},
    196968: {"Unified_Ideograph", "Ideographic"},
    196969: {"Unified_Ideograph", "Ideographic"},
    196970: {"Unified_Ideograph", "Ideographic"},
    196971: {"Unified_Ideograph", "Ideographic"},
    196972: {"Unified_Ideograph", "Ideographic"},
    196973: {"Unified_Ideograph", "Ideographic"},
    196974: {"Unified_Ideograph", "Ideographic"},
    196975: {"Unified_Ideograph", "Ideographic"},
    196976: {"Unified_Ideograph", "Ideographic"},
    196977: {"Unified_Ideograph", "Ideographic"},
    196978: {"Unified_Ideograph", "Ideographic"},
    196979: {"Unified_Ideograph", "Ideographic"},
    196980: {"Unified_Ideograph", "Ideographic"},
    196981: {"Unified_Ideograph", "Ideographic"},
    196982: {"Unified_Ideograph", "Ideographic"},
    196983: {"Unified_Ideograph", "Ideographic"},
    196984: {"Unified_Ideograph", "Ideographic"},
    196985: {"Unified_Ideograph", "Ideographic"},
    196986: {"Unified_Ideograph", "Ideographic"},
    196987: {"Unified_Ideograph", "Ideographic"},
    196988: {"Unified_Ideograph", "Ideographic"},
    196989: {"Unified_Ideograph", "Ideographic"},
    196990: {"Unified_Ideograph", "Ideographic"},
    196991: {"Unified_Ideograph", "Ideographic"},
    196992: {"Unified_Ideograph", "Ideographic"},
    196993: {"Unified_Ideograph", "Ideographic"},
    196994: {"Unified_Ideograph", "Ideographic"},
    196995: {"Unified_Ideograph", "Ideographic"},
    196996: {"Unified_Ideograph", "Ideographic"},
    196997: {"Unified_Ideograph", "Ideographic"},
    196998: {"Unified_Ideograph", "Ideographic"},
    196999: {"Unified_Ideograph", "Ideographic"},
    197000: {"Unified_Ideograph", "Ideographic"},
    197001: {"Unified_Ideograph", "Ideographic"},
    197002: {"Unified_Ideograph", "Ideographic"},
    197003: {"Unified_Ideograph", "Ideographic"},
    197004: {"Unified_Ideograph", "Ideographic"},
    197005: {"Unified_Ideograph", "Ideographic"},
    197006: {"Unified_Ideograph", "Ideographic"},
    197007: {"Unified_Ideograph", "Ideographic"},
    197008: {"Unified_Ideograph", "Ideographic"},
    197009: {"Unified_Ideograph", "Ideographic"},
    197010: {"Unified_Ideograph", "Ideographic"},
    197011: {"Unified_Ideograph", "Ideographic"},
    197012: {"Unified_Ideograph", "Ideographic"},
    197013: {"Unified_Ideograph", "Ideographic"},
    197014: {"Unified_Ideograph", "Ideographic"},
    197015: {"Unified_Ideograph", "Ideographic"},
    197016: {"Unified_Ideograph", "Ideographic"},
    197017: {"Unified_Ideograph", "Ideographic"},
    197018: {"Unified_Ideograph", "Ideographic"},
    197019: {"Unified_Ideograph", "Ideographic"},
    197020: {"Unified_Ideograph", "Ideographic"},
    197021: {"Unified_Ideograph", "Ideographic"},
    197022: {"Unified_Ideograph", "Ideographic"},
    197023: {"Unified_Ideograph", "Ideographic"},
    197024: {"Unified_Ideograph", "Ideographic"},
    197025: {"Unified_Ideograph", "Ideographic"},
    197026: {"Unified_Ideograph", "Ideographic"},
    197027: {"Unified_Ideograph", "Ideographic"},
    197028: {"Unified_Ideograph", "Ideographic"},
    197029: {"Unified_Ideograph", "Ideographic"},
    197030: {"Unified_Ideograph", "Ideographic"},
    197031: {"Unified_Ideograph", "Ideographic"},
    197032: {"Unified_Ideograph", "Ideographic"},
    197033: {"Unified_Ideograph", "Ideographic"},
    197034: {"Unified_Ideograph", "Ideographic"},
    197035: {"Unified_Ideograph", "Ideographic"},
    197036: {"Unified_Ideograph", "Ideographic"},
    197037: {"Unified_Ideograph", "Ideographic"},
    197038: {"Unified_Ideograph", "Ideographic"},
    197039: {"Unified_Ideograph", "Ideographic"},
    197040: {"Unified_Ideograph", "Ideographic"},
    197041: {"Unified_Ideograph", "Ideographic"},
    197042: {"Unified_Ideograph", "Ideographic"},
    197043: {"Unified_Ideograph", "Ideographic"},
    197044: {"Unified_Ideograph", "Ideographic"},
    197045: {"Unified_Ideograph", "Ideographic"},
    197046: {"Unified_Ideograph", "Ideographic"},
    197047: {"Unified_Ideograph", "Ideographic"},
    197048: {"Unified_Ideograph", "Ideographic"},
    197049: {"Unified_Ideograph", "Ideographic"},
    197050: {"Unified_Ideograph", "Ideographic"},
    197051: {"Unified_Ideograph", "Ideographic"},
    197052: {"Unified_Ideograph", "Ideographic"},
    197053: {"Unified_Ideograph", "Ideographic"},
    197054: {"Unified_Ideograph", "Ideographic"},
    197055: {"Unified_Ideograph", "Ideographic"},
    197056: {"Unified_Ideograph", "Ideographic"},
    197057: {"Unified_Ideograph", "Ideographic"},
    197058: {"Unified_Ideograph", "Ideographic"},
    197059: {"Unified_Ideograph", "Ideographic"},
    197060: {"Unified_Ideograph", "Ideographic"},
    197061: {"Unified_Ideograph", "Ideographic"},
    197062: {"Unified_Ideograph", "Ideographic"},
    197063: {"Unified_Ideograph", "Ideographic"},
    197064: {"Unified_Ideograph", "Ideographic"},
    197065: {"Unified_Ideograph", "Ideographic"},
    197066: {"Unified_Ideograph", "Ideographic"},
    197067: {"Unified_Ideograph", "Ideographic"},
    197068: {"Unified_Ideograph", "Ideographic"},
    197069: {"Unified_Ideograph", "Ideographic"},
    197070: {"Unified_Ideograph", "Ideographic"},
    197071: {"Unified_Ideograph", "Ideographic"},
    197072: {"Unified_Ideograph", "Ideographic"},
    197073: {"Unified_Ideograph", "Ideographic"},
    197074: {"Unified_Ideograph", "Ideographic"},
    197075: {"Unified_Ideograph", "Ideographic"},
    197076: {"Unified_Ideograph", "Ideographic"},
    197077: {"Unified_Ideograph", "Ideographic"},
    197078: {"Unified_Ideograph", "Ideographic"},
    197079: {"Unified_Ideograph", "Ideographic"},
    197080: {"Unified_Ideograph", "Ideographic"},
    197081: {"Unified_Ideograph", "Ideographic"},
    197082: {"Unified_Ideograph", "Ideographic"},
    197083: {"Unified_Ideograph", "Ideographic"},
    197084: {"Unified_Ideograph", "Ideographic"},
    197085: {"Unified_Ideograph", "Ideographic"},
    197086: {"Unified_Ideograph", "Ideographic"},
    197087: {"Unified_Ideograph", "Ideographic"},
    197088: {"Unified_Ideograph", "Ideographic"},
    197089: {"Unified_Ideograph", "Ideographic"},
    197090: {"Unified_Ideograph", "Ideographic"},
    197091: {"Unified_Ideograph", "Ideographic"},
    197092: {"Unified_Ideograph", "Ideographic"},
    197093: {"Unified_Ideograph", "Ideographic"},
    197094: {"Unified_Ideograph", "Ideographic"},
    197095: {"Unified_Ideograph", "Ideographic"},
    197096: {"Unified_Ideograph", "Ideographic"},
    197097: {"Unified_Ideograph", "Ideographic"},
    197098: {"Unified_Ideograph", "Ideographic"},
    197099: {"Unified_Ideograph", "Ideographic"},
    197100: {"Unified_Ideograph", "Ideographic"},
    197101: {"Unified_Ideograph", "Ideographic"},
    197102: {"Unified_Ideograph", "Ideographic"},
    197103: {"Unified_Ideograph", "Ideographic"},
    197104: {"Unified_Ideograph", "Ideographic"},
    197105: {"Unified_Ideograph", "Ideographic"},
    197106: {"Unified_Ideograph", "Ideographic"},
    197107: {"Unified_Ideograph", "Ideographic"},
    197108: {"Unified_Ideograph", "Ideographic"},
    197109: {"Unified_Ideograph", "Ideographic"},
    197110: {"Unified_Ideograph", "Ideographic"},
    197111: {"Unified_Ideograph", "Ideographic"},
    197112: {"Unified_Ideograph", "Ideographic"},
    197113: {"Unified_Ideograph", "Ideographic"},
    197114: {"Unified_Ideograph", "Ideographic"},
    197115: {"Unified_Ideograph", "Ideographic"},
    197116: {"Unified_Ideograph", "Ideographic"},
    197117: {"Unified_Ideograph", "Ideographic"},
    197118: {"Unified_Ideograph", "Ideographic"},
    197119: {"Unified_Ideograph", "Ideographic"},
    197120: {"Unified_Ideograph", "Ideographic"},
    197121: {"Unified_Ideograph", "Ideographic"},
    197122: {"Unified_Ideograph", "Ideographic"},
    197123: {"Unified_Ideograph", "Ideographic"},
    197124: {"Unified_Ideograph", "Ideographic"},
    197125: {"Unified_Ideograph", "Ideographic"},
    197126: {"Unified_Ideograph", "Ideographic"},
    197127: {"Unified_Ideograph", "Ideographic"},
    197128: {"Unified_Ideograph", "Ideographic"},
    197129: {"Unified_Ideograph", "Ideographic"},
    197130: {"Unified_Ideograph", "Ideographic"},
    197131: {"Unified_Ideograph", "Ideographic"},
    197132: {"Unified_Ideograph", "Ideographic"},
    197133: {"Unified_Ideograph", "Ideographic"},
    197134: {"Unified_Ideograph", "Ideographic"},
    197135: {"Unified_Ideograph", "Ideographic"},
    197136: {"Unified_Ideograph", "Ideographic"},
    197137: {"Unified_Ideograph", "Ideographic"},
    197138: {"Unified_Ideograph", "Ideographic"},
    197139: {"Unified_Ideograph", "Ideographic"},
    197140: {"Unified_Ideograph", "Ideographic"},
    197141: {"Unified_Ideograph", "Ideographic"},
    197142: {"Unified_Ideograph", "Ideographic"},
    197143: {"Unified_Ideograph", "Ideographic"},
    197144: {"Unified_Ideograph", "Ideographic"},
    197145: {"Unified_Ideograph", "Ideographic"},
    197146: {"Unified_Ideograph", "Ideographic"},
    197147: {"Unified_Ideograph", "Ideographic"},
    197148: {"Unified_Ideograph", "Ideographic"},
    197149: {"Unified_Ideograph", "Ideographic"},
    197150: {"Unified_Ideograph", "Ideographic"},
    197151: {"Unified_Ideograph", "Ideographic"},
    197152: {"Unified_Ideograph", "Ideographic"},
    197153: {"Unified_Ideograph", "Ideographic"},
    197154: {"Unified_Ideograph", "Ideographic"},
    197155: {"Unified_Ideograph", "Ideographic"},
    197156: {"Unified_Ideograph", "Ideographic"},
    197157: {"Unified_Ideograph", "Ideographic"},
    197158: {"Unified_Ideograph", "Ideographic"},
    197159: {"Unified_Ideograph", "Ideographic"},
    197160: {"Unified_Ideograph", "Ideographic"},
    197161: {"Unified_Ideograph", "Ideographic"},
    197162: {"Unified_Ideograph", "Ideographic"},
    197163: {"Unified_Ideograph", "Ideographic"},
    197164: {"Unified_Ideograph", "Ideographic"},
    197165: {"Unified_Ideograph", "Ideographic"},
    197166: {"Unified_Ideograph", "Ideographic"},
    197167: {"Unified_Ideograph", "Ideographic"},
    197168: {"Unified_Ideograph", "Ideographic"},
    197169: {"Unified_Ideograph", "Ideographic"},
    197170: {"Unified_Ideograph", "Ideographic"},
    197171: {"Unified_Ideograph", "Ideographic"},
    197172: {"Unified_Ideograph", "Ideographic"},
    197173: {"Unified_Ideograph", "Ideographic"},
    197174: {"Unified_Ideograph", "Ideographic"},
    197175: {"Unified_Ideograph", "Ideographic"},
    197176: {"Unified_Ideograph", "Ideographic"},
    197177: {"Unified_Ideograph", "Ideographic"},
    197178: {"Unified_Ideograph", "Ideographic"},
    197179: {"Unified_Ideograph", "Ideographic"},
    197180: {"Unified_Ideograph", "Ideographic"},
    197181: {"Unified_Ideograph", "Ideographic"},
    197182: {"Unified_Ideograph", "Ideographic"},
    197183: {"Unified_Ideograph", "Ideographic"},
    197184: {"Unified_Ideograph", "Ideographic"},
    197185: {"Unified_Ideograph", "Ideographic"},
    197186: {"Unified_Ideograph", "Ideographic"},
    197187: {"Unified_Ideograph", "Ideographic"},
    197188: {"Unified_Ideograph", "Ideographic"},
    197189: {"Unified_Ideograph", "Ideographic"},
    197190: {"Unified_Ideograph", "Ideographic"},
    197191: {"Unified_Ideograph", "Ideographic"},
    197192: {"Unified_Ideograph", "Ideographic"},
    197193: {"Unified_Ideograph", "Ideographic"},
    197194: {"Unified_Ideograph", "Ideographic"},
    197195: {"Unified_Ideograph", "Ideographic"},
    197196: {"Unified_Ideograph", "Ideographic"},
    197197: {"Unified_Ideograph", "Ideographic"},
    197198: {"Unified_Ideograph", "Ideographic"},
    197199: {"Unified_Ideograph", "Ideographic"},
    197200: {"Unified_Ideograph", "Ideographic"},
    197201: {"Unified_Ideograph", "Ideographic"},
    197202: {"Unified_Ideograph", "Ideographic"},
    197203: {"Unified_Ideograph", "Ideographic"},
    197204: {"Unified_Ideograph", "Ideographic"},
    197205: {"Unified_Ideograph", "Ideographic"},
    197206: {"Unified_Ideograph", "Ideographic"},
    197207: {"Unified_Ideograph", "Ideographic"},
    197208: {"Unified_Ideograph", "Ideographic"},
    197209: {"Unified_Ideograph", "Ideographic"},
    197210: {"Unified_Ideograph", "Ideographic"},
    197211: {"Unified_Ideograph", "Ideographic"},
    197212: {"Unified_Ideograph", "Ideographic"},
    197213: {"Unified_Ideograph", "Ideographic"},
    197214: {"Unified_Ideograph", "Ideographic"},
    197215: {"Unified_Ideograph", "Ideographic"},
    197216: {"Unified_Ideograph", "Ideographic"},
    197217: {"Unified_Ideograph", "Ideographic"},
    197218: {"Unified_Ideograph", "Ideographic"},
    197219: {"Unified_Ideograph", "Ideographic"},
    197220: {"Unified_Ideograph", "Ideographic"},
    197221: {"Unified_Ideograph", "Ideographic"},
    197222: {"Unified_Ideograph", "Ideographic"},
    197223: {"Unified_Ideograph", "Ideographic"},
    197224: {"Unified_Ideograph", "Ideographic"},
    197225: {"Unified_Ideograph", "Ideographic"},
    197226: {"Unified_Ideograph", "Ideographic"},
    197227: {"Unified_Ideograph", "Ideographic"},
    197228: {"Unified_Ideograph", "Ideographic"},
    197229: {"Unified_Ideograph", "Ideographic"},
    197230: {"Unified_Ideograph", "Ideographic"},
    197231: {"Unified_Ideograph", "Ideographic"},
    197232: {"Unified_Ideograph", "Ideographic"},
    197233: {"Unified_Ideograph", "Ideographic"},
    197234: {"Unified_Ideograph", "Ideographic"},
    197235: {"Unified_Ideograph", "Ideographic"},
    197236: {"Unified_Ideograph", "Ideographic"},
    197237: {"Unified_Ideograph", "Ideographic"},
    197238: {"Unified_Ideograph", "Ideographic"},
    197239: {"Unified_Ideograph", "Ideographic"},
    197240: {"Unified_Ideograph", "Ideographic"},
    197241: {"Unified_Ideograph", "Ideographic"},
    197242: {"Unified_Ideograph", "Ideographic"},
    197243: {"Unified_Ideograph", "Ideographic"},
    197244: {"Unified_Ideograph", "Ideographic"},
    197245: {"Unified_Ideograph", "Ideographic"},
    197246: {"Unified_Ideograph", "Ideographic"},
    197247: {"Unified_Ideograph", "Ideographic"},
    197248: {"Unified_Ideograph", "Ideographic"},
    197249: {"Unified_Ideograph", "Ideographic"},
    197250: {"Unified_Ideograph", "Ideographic"},
    197251: {"Unified_Ideograph", "Ideographic"},
    197252: {"Unified_Ideograph", "Ideographic"},
    197253: {"Unified_Ideograph", "Ideographic"},
    197254: {"Unified_Ideograph", "Ideographic"},
    197255: {"Unified_Ideograph", "Ideographic"},
    197256: {"Unified_Ideograph", "Ideographic"},
    197257: {"Unified_Ideograph", "Ideographic"},
    197258: {"Unified_Ideograph", "Ideographic"},
    197259: {"Unified_Ideograph", "Ideographic"},
    197260: {"Unified_Ideograph", "Ideographic"},
    197261: {"Unified_Ideograph", "Ideographic"},
    197262: {"Unified_Ideograph", "Ideographic"},
    197263: {"Unified_Ideograph", "Ideographic"},
    197264: {"Unified_Ideograph", "Ideographic"},
    197265: {"Unified_Ideograph", "Ideographic"},
    197266: {"Unified_Ideograph", "Ideographic"},
    197267: {"Unified_Ideograph", "Ideographic"},
    197268: {"Unified_Ideograph", "Ideographic"},
    197269: {"Unified_Ideograph", "Ideographic"},
    197270: {"Unified_Ideograph", "Ideographic"},
    197271: {"Unified_Ideograph", "Ideographic"},
    197272: {"Unified_Ideograph", "Ideographic"},
    197273: {"Unified_Ideograph", "Ideographic"},
    197274: {"Unified_Ideograph", "Ideographic"},
    197275: {"Unified_Ideograph", "Ideographic"},
    197276: {"Unified_Ideograph", "Ideographic"},
    197277: {"Unified_Ideograph", "Ideographic"},
    197278: {"Unified_Ideograph", "Ideographic"},
    197279: {"Unified_Ideograph", "Ideographic"},
    197280: {"Unified_Ideograph", "Ideographic"},
    197281: {"Unified_Ideograph", "Ideographic"},
    197282: {"Unified_Ideograph", "Ideographic"},
    197283: {"Unified_Ideograph", "Ideographic"},
    197284: {"Unified_Ideograph", "Ideographic"},
    197285: {"Unified_Ideograph", "Ideographic"},
    197286: {"Unified_Ideograph", "Ideographic"},
    197287: {"Unified_Ideograph", "Ideographic"},
    197288: {"Unified_Ideograph", "Ideographic"},
    197289: {"Unified_Ideograph", "Ideographic"},
    197290: {"Unified_Ideograph", "Ideographic"},
    197291: {"Unified_Ideograph", "Ideographic"},
    197292: {"Unified_Ideograph", "Ideographic"},
    197293: {"Unified_Ideograph", "Ideographic"},
    197294: {"Unified_Ideograph", "Ideographic"},
    197295: {"Unified_Ideograph", "Ideographic"},
    197296: {"Unified_Ideograph", "Ideographic"},
    197297: {"Unified_Ideograph", "Ideographic"},
    197298: {"Unified_Ideograph", "Ideographic"},
    197299: {"Unified_Ideograph", "Ideographic"},
    197300: {"Unified_Ideograph", "Ideographic"},
    197301: {"Unified_Ideograph", "Ideographic"},
    197302: {"Unified_Ideograph", "Ideographic"},
    197303: {"Unified_Ideograph", "Ideographic"},
    197304: {"Unified_Ideograph", "Ideographic"},
    197305: {"Unified_Ideograph", "Ideographic"},
    197306: {"Unified_Ideograph", "Ideographic"},
    197307: {"Unified_Ideograph", "Ideographic"},
    197308: {"Unified_Ideograph", "Ideographic"},
    197309: {"Unified_Ideograph", "Ideographic"},
    197310: {"Unified_Ideograph", "Ideographic"},
    197311: {"Unified_Ideograph", "Ideographic"},
    197312: {"Unified_Ideograph", "Ideographic"},
    197313: {"Unified_Ideograph", "Ideographic"},
    197314: {"Unified_Ideograph", "Ideographic"},
    197315: {"Unified_Ideograph", "Ideographic"},
    197316: {"Unified_Ideograph", "Ideographic"},
    197317: {"Unified_Ideograph", "Ideographic"},
    197318: {"Unified_Ideograph", "Ideographic"},
    197319: {"Unified_Ideograph", "Ideographic"},
    197320: {"Unified_Ideograph", "Ideographic"},
    197321: {"Unified_Ideograph", "Ideographic"},
    197322: {"Unified_Ideograph", "Ideographic"},
    197323: {"Unified_Ideograph", "Ideographic"},
    197324: {"Unified_Ideograph", "Ideographic"},
    197325: {"Unified_Ideograph", "Ideographic"},
    197326: {"Unified_Ideograph", "Ideographic"},
    197327: {"Unified_Ideograph", "Ideographic"},
    197328: {"Unified_Ideograph", "Ideographic"},
    197329: {"Unified_Ideograph", "Ideographic"},
    197330: {"Unified_Ideograph", "Ideographic"},
    197331: {"Unified_Ideograph", "Ideographic"},
    197332: {"Unified_Ideograph", "Ideographic"},
    197333: {"Unified_Ideograph", "Ideographic"},
    197334: {"Unified_Ideograph", "Ideographic"},
    197335: {"Unified_Ideograph", "Ideographic"},
    197336: {"Unified_Ideograph", "Ideographic"},
    197337: {"Unified_Ideograph", "Ideographic"},
    197338: {"Unified_Ideograph", "Ideographic"},
    197339: {"Unified_Ideograph", "Ideographic"},
    197340: {"Unified_Ideograph", "Ideographic"},
    197341: {"Unified_Ideograph", "Ideographic"},
    197342: {"Unified_Ideograph", "Ideographic"},
    197343: {"Unified_Ideograph", "Ideographic"},
    197344: {"Unified_Ideograph", "Ideographic"},
    197345: {"Unified_Ideograph", "Ideographic"},
    197346: {"Unified_Ideograph", "Ideographic"},
    197347: {"Unified_Ideograph", "Ideographic"},
    197348: {"Unified_Ideograph", "Ideographic"},
    197349: {"Unified_Ideograph", "Ideographic"},
    197350: {"Unified_Ideograph", "Ideographic"},
    197351: {"Unified_Ideograph", "Ideographic"},
    197352: {"Unified_Ideograph", "Ideographic"},
    197353: {"Unified_Ideograph", "Ideographic"},
    197354: {"Unified_Ideograph", "Ideographic"},
    197355: {"Unified_Ideograph", "Ideographic"},
    197356: {"Unified_Ideograph", "Ideographic"},
    197357: {"Unified_Ideograph", "Ideographic"},
    197358: {"Unified_Ideograph", "Ideographic"},
    197359: {"Unified_Ideograph", "Ideographic"},
    197360: {"Unified_Ideograph", "Ideographic"},
    197361: {"Unified_Ideograph", "Ideographic"},
    197362: {"Unified_Ideograph", "Ideographic"},
    197363: {"Unified_Ideograph", "Ideographic"},
    197364: {"Unified_Ideograph", "Ideographic"},
    197365: {"Unified_Ideograph", "Ideographic"},
    197366: {"Unified_Ideograph", "Ideographic"},
    197367: {"Unified_Ideograph", "Ideographic"},
    197368: {"Unified_Ideograph", "Ideographic"},
    197369: {"Unified_Ideograph", "Ideographic"},
    197370: {"Unified_Ideograph", "Ideographic"},
    197371: {"Unified_Ideograph", "Ideographic"},
    197372: {"Unified_Ideograph", "Ideographic"},
    197373: {"Unified_Ideograph", "Ideographic"},
    197374: {"Unified_Ideograph", "Ideographic"},
    197375: {"Unified_Ideograph", "Ideographic"},
    197376: {"Unified_Ideograph", "Ideographic"},
    197377: {"Unified_Ideograph", "Ideographic"},
    197378: {"Unified_Ideograph", "Ideographic"},
    197379: {"Unified_Ideograph", "Ideographic"},
    197380: {"Unified_Ideograph", "Ideographic"},
    197381: {"Unified_Ideograph", "Ideographic"},
    197382: {"Unified_Ideograph", "Ideographic"},
    197383: {"Unified_Ideograph", "Ideographic"},
    197384: {"Unified_Ideograph", "Ideographic"},
    197385: {"Unified_Ideograph", "Ideographic"},
    197386: {"Unified_Ideograph", "Ideographic"},
    197387: {"Unified_Ideograph", "Ideographic"},
    197388: {"Unified_Ideograph", "Ideographic"},
    197389: {"Unified_Ideograph", "Ideographic"},
    197390: {"Unified_Ideograph", "Ideographic"},
    197391: {"Unified_Ideograph", "Ideographic"},
    197392: {"Unified_Ideograph", "Ideographic"},
    197393: {"Unified_Ideograph", "Ideographic"},
    197394: {"Unified_Ideograph", "Ideographic"},
    197395: {"Unified_Ideograph", "Ideographic"},
    197396: {"Unified_Ideograph", "Ideographic"},
    197397: {"Unified_Ideograph", "Ideographic"},
    197398: {"Unified_Ideograph", "Ideographic"},
    197399: {"Unified_Ideograph", "Ideographic"},
    197400: {"Unified_Ideograph", "Ideographic"},
    197401: {"Unified_Ideograph", "Ideographic"},
    197402: {"Unified_Ideograph", "Ideographic"},
    197403: {"Unified_Ideograph", "Ideographic"},
    197404: {"Unified_Ideograph", "Ideographic"},
    197405: {"Unified_Ideograph", "Ideographic"},
    197406: {"Unified_Ideograph", "Ideographic"},
    197407: {"Unified_Ideograph", "Ideographic"},
    197408: {"Unified_Ideograph", "Ideographic"},
    197409: {"Unified_Ideograph", "Ideographic"},
    197410: {"Unified_Ideograph", "Ideographic"},
    197411: {"Unified_Ideograph", "Ideographic"},
    197412: {"Unified_Ideograph", "Ideographic"},
    197413: {"Unified_Ideograph", "Ideographic"},
    197414: {"Unified_Ideograph", "Ideographic"},
    197415: {"Unified_Ideograph", "Ideographic"},
    197416: {"Unified_Ideograph", "Ideographic"},
    197417: {"Unified_Ideograph", "Ideographic"},
    197418: {"Unified_Ideograph", "Ideographic"},
    197419: {"Unified_Ideograph", "Ideographic"},
    197420: {"Unified_Ideograph", "Ideographic"},
    197421: {"Unified_Ideograph", "Ideographic"},
    197422: {"Unified_Ideograph", "Ideographic"},
    197423: {"Unified_Ideograph", "Ideographic"},
    197424: {"Unified_Ideograph", "Ideographic"},
    197425: {"Unified_Ideograph", "Ideographic"},
    197426: {"Unified_Ideograph", "Ideographic"},
    197427: {"Unified_Ideograph", "Ideographic"},
    197428: {"Unified_Ideograph", "Ideographic"},
    197429: {"Unified_Ideograph", "Ideographic"},
    197430: {"Unified_Ideograph", "Ideographic"},
    197431: {"Unified_Ideograph", "Ideographic"},
    197432: {"Unified_Ideograph", "Ideographic"},
    197433: {"Unified_Ideograph", "Ideographic"},
    197434: {"Unified_Ideograph", "Ideographic"},
    197435: {"Unified_Ideograph", "Ideographic"},
    197436: {"Unified_Ideograph", "Ideographic"},
    197437: {"Unified_Ideograph", "Ideographic"},
    197438: {"Unified_Ideograph", "Ideographic"},
    197439: {"Unified_Ideograph", "Ideographic"},
    197440: {"Unified_Ideograph", "Ideographic"},
    197441: {"Unified_Ideograph", "Ideographic"},
    197442: {"Unified_Ideograph", "Ideographic"},
    197443: {"Unified_Ideograph", "Ideographic"},
    197444: {"Unified_Ideograph", "Ideographic"},
    197445: {"Unified_Ideograph", "Ideographic"},
    197446: {"Unified_Ideograph", "Ideographic"},
    197447: {"Unified_Ideograph", "Ideographic"},
    197448: {"Unified_Ideograph", "Ideographic"},
    197449: {"Unified_Ideograph", "Ideographic"},
    197450: {"Unified_Ideograph", "Ideographic"},
    197451: {"Unified_Ideograph", "Ideographic"},
    197452: {"Unified_Ideograph", "Ideographic"},
    197453: {"Unified_Ideograph", "Ideographic"},
    197454: {"Unified_Ideograph", "Ideographic"},
    197455: {"Unified_Ideograph", "Ideographic"},
    197456: {"Unified_Ideograph", "Ideographic"},
    197457: {"Unified_Ideograph", "Ideographic"},
    197458: {"Unified_Ideograph", "Ideographic"},
    197459: {"Unified_Ideograph", "Ideographic"},
    197460: {"Unified_Ideograph", "Ideographic"},
    197461: {"Unified_Ideograph", "Ideographic"},
    197462: {"Unified_Ideograph", "Ideographic"},
    197463: {"Unified_Ideograph", "Ideographic"},
    197464: {"Unified_Ideograph", "Ideographic"},
    197465: {"Unified_Ideograph", "Ideographic"},
    197466: {"Unified_Ideograph", "Ideographic"},
    197467: {"Unified_Ideograph", "Ideographic"},
    197468: {"Unified_Ideograph", "Ideographic"},
    197469: {"Unified_Ideograph", "Ideographic"},
    197470: {"Unified_Ideograph", "Ideographic"},
    197471: {"Unified_Ideograph", "Ideographic"},
    197472: {"Unified_Ideograph", "Ideographic"},
    197473: {"Unified_Ideograph", "Ideographic"},
    197474: {"Unified_Ideograph", "Ideographic"},
    197475: {"Unified_Ideograph", "Ideographic"},
    197476: {"Unified_Ideograph", "Ideographic"},
    197477: {"Unified_Ideograph", "Ideographic"},
    197478: {"Unified_Ideograph", "Ideographic"},
    197479: {"Unified_Ideograph", "Ideographic"},
    197480: {"Unified_Ideograph", "Ideographic"},
    197481: {"Unified_Ideograph", "Ideographic"},
    197482: {"Unified_Ideograph", "Ideographic"},
    197483: {"Unified_Ideograph", "Ideographic"},
    197484: {"Unified_Ideograph", "Ideographic"},
    197485: {"Unified_Ideograph", "Ideographic"},
    197486: {"Unified_Ideograph", "Ideographic"},
    197487: {"Unified_Ideograph", "Ideographic"},
    197488: {"Unified_Ideograph", "Ideographic"},
    197489: {"Unified_Ideograph", "Ideographic"},
    197490: {"Unified_Ideograph", "Ideographic"},
    197491: {"Unified_Ideograph", "Ideographic"},
    197492: {"Unified_Ideograph", "Ideographic"},
    197493: {"Unified_Ideograph", "Ideographic"},
    197494: {"Unified_Ideograph", "Ideographic"},
    197495: {"Unified_Ideograph", "Ideographic"},
    197496: {"Unified_Ideograph", "Ideographic"},
    197497: {"Unified_Ideograph", "Ideographic"},
    197498: {"Unified_Ideograph", "Ideographic"},
    197499: {"Unified_Ideograph", "Ideographic"},
    197500: {"Unified_Ideograph", "Ideographic"},
    197501: {"Unified_Ideograph", "Ideographic"},
    197502: {"Unified_Ideograph", "Ideographic"},
    197503: {"Unified_Ideograph", "Ideographic"},
    197504: {"Unified_Ideograph", "Ideographic"},
    197505: {"Unified_Ideograph", "Ideographic"},
    197506: {"Unified_Ideograph", "Ideographic"},
    197507: {"Unified_Ideograph", "Ideographic"},
    197508: {"Unified_Ideograph", "Ideographic"},
    197509: {"Unified_Ideograph", "Ideographic"},
    197510: {"Unified_Ideograph", "Ideographic"},
    197511: {"Unified_Ideograph", "Ideographic"},
    197512: {"Unified_Ideograph", "Ideographic"},
    197513: {"Unified_Ideograph", "Ideographic"},
    197514: {"Unified_Ideograph", "Ideographic"},
    197515: {"Unified_Ideograph", "Ideographic"},
    197516: {"Unified_Ideograph", "Ideographic"},
    197517: {"Unified_Ideograph", "Ideographic"},
    197518: {"Unified_Ideograph", "Ideographic"},
    197519: {"Unified_Ideograph", "Ideographic"},
    197520: {"Unified_Ideograph", "Ideographic"},
    197521: {"Unified_Ideograph", "Ideographic"},
    197522: {"Unified_Ideograph", "Ideographic"},
    197523: {"Unified_Ideograph", "Ideographic"},
    197524: {"Unified_Ideograph", "Ideographic"},
    197525: {"Unified_Ideograph", "Ideographic"},
    197526: {"Unified_Ideograph", "Ideographic"},
    197527: {"Unified_Ideograph", "Ideographic"},
    197528: {"Unified_Ideograph", "Ideographic"},
    197529: {"Unified_Ideograph", "Ideographic"},
    197530: {"Unified_Ideograph", "Ideographic"},
    197531: {"Unified_Ideograph", "Ideographic"},
    197532: {"Unified_Ideograph", "Ideographic"},
    197533: {"Unified_Ideograph", "Ideographic"},
    197534: {"Unified_Ideograph", "Ideographic"},
    197535: {"Unified_Ideograph", "Ideographic"},
    197536: {"Unified_Ideograph", "Ideographic"},
    197537: {"Unified_Ideograph", "Ideographic"},
    197538: {"Unified_Ideograph", "Ideographic"},
    197539: {"Unified_Ideograph", "Ideographic"},
    197540: {"Unified_Ideograph", "Ideographic"},
    197541: {"Unified_Ideograph", "Ideographic"},
    197542: {"Unified_Ideograph", "Ideographic"},
    197543: {"Unified_Ideograph", "Ideographic"},
    197544: {"Unified_Ideograph", "Ideographic"},
    197545: {"Unified_Ideograph", "Ideographic"},
    197546: {"Unified_Ideograph", "Ideographic"},
    197547: {"Unified_Ideograph", "Ideographic"},
    197548: {"Unified_Ideograph", "Ideographic"},
    197549: {"Unified_Ideograph", "Ideographic"},
    197550: {"Unified_Ideograph", "Ideographic"},
    197551: {"Unified_Ideograph", "Ideographic"},
    197552: {"Unified_Ideograph", "Ideographic"},
    197553: {"Unified_Ideograph", "Ideographic"},
    197554: {"Unified_Ideograph", "Ideographic"},
    197555: {"Unified_Ideograph", "Ideographic"},
    197556: {"Unified_Ideograph", "Ideographic"},
    197557: {"Unified_Ideograph", "Ideographic"},
    197558: {"Unified_Ideograph", "Ideographic"},
    197559: {"Unified_Ideograph", "Ideographic"},
    197560: {"Unified_Ideograph", "Ideographic"},
    197561: {"Unified_Ideograph", "Ideographic"},
    197562: {"Unified_Ideograph", "Ideographic"},
    197563: {"Unified_Ideograph", "Ideographic"},
    197564: {"Unified_Ideograph", "Ideographic"},
    197565: {"Unified_Ideograph", "Ideographic"},
    197566: {"Unified_Ideograph", "Ideographic"},
    197567: {"Unified_Ideograph", "Ideographic"},
    197568: {"Unified_Ideograph", "Ideographic"},
    197569: {"Unified_Ideograph", "Ideographic"},
    197570: {"Unified_Ideograph", "Ideographic"},
    197571: {"Unified_Ideograph", "Ideographic"},
    197572: {"Unified_Ideograph", "Ideographic"},
    197573: {"Unified_Ideograph", "Ideographic"},
    197574: {"Unified_Ideograph", "Ideographic"},
    197575: {"Unified_Ideograph", "Ideographic"},
    197576: {"Unified_Ideograph", "Ideographic"},
    197577: {"Unified_Ideograph", "Ideographic"},
    197578: {"Unified_Ideograph", "Ideographic"},
    197579: {"Unified_Ideograph", "Ideographic"},
    197580: {"Unified_Ideograph", "Ideographic"},
    197581: {"Unified_Ideograph", "Ideographic"},
    197582: {"Unified_Ideograph", "Ideographic"},
    197583: {"Unified_Ideograph", "Ideographic"},
    197584: {"Unified_Ideograph", "Ideographic"},
    197585: {"Unified_Ideograph", "Ideographic"},
    197586: {"Unified_Ideograph", "Ideographic"},
    197587: {"Unified_Ideograph", "Ideographic"},
    197588: {"Unified_Ideograph", "Ideographic"},
    197589: {"Unified_Ideograph", "Ideographic"},
    197590: {"Unified_Ideograph", "Ideographic"},
    197591: {"Unified_Ideograph", "Ideographic"},
    197592: {"Unified_Ideograph", "Ideographic"},
    197593: {"Unified_Ideograph", "Ideographic"},
    197594: {"Unified_Ideograph", "Ideographic"},
    197595: {"Unified_Ideograph", "Ideographic"},
    197596: {"Unified_Ideograph", "Ideographic"},
    197597: {"Unified_Ideograph", "Ideographic"},
    197598: {"Unified_Ideograph", "Ideographic"},
    197599: {"Unified_Ideograph", "Ideographic"},
    197600: {"Unified_Ideograph", "Ideographic"},
    197601: {"Unified_Ideograph", "Ideographic"},
    197602: {"Unified_Ideograph", "Ideographic"},
    197603: {"Unified_Ideograph", "Ideographic"},
    197604: {"Unified_Ideograph", "Ideographic"},
    197605: {"Unified_Ideograph", "Ideographic"},
    197606: {"Unified_Ideograph", "Ideographic"},
    197607: {"Unified_Ideograph", "Ideographic"},
    197608: {"Unified_Ideograph", "Ideographic"},
    197609: {"Unified_Ideograph", "Ideographic"},
    197610: {"Unified_Ideograph", "Ideographic"},
    197611: {"Unified_Ideograph", "Ideographic"},
    197612: {"Unified_Ideograph", "Ideographic"},
    197613: {"Unified_Ideograph", "Ideographic"},
    197614: {"Unified_Ideograph", "Ideographic"},
    197615: {"Unified_Ideograph", "Ideographic"},
    197616: {"Unified_Ideograph", "Ideographic"},
    197617: {"Unified_Ideograph", "Ideographic"},
    197618: {"Unified_Ideograph", "Ideographic"},
    197619: {"Unified_Ideograph", "Ideographic"},
    197620: {"Unified_Ideograph", "Ideographic"},
    197621: {"Unified_Ideograph", "Ideographic"},
    197622: {"Unified_Ideograph", "Ideographic"},
    197623: {"Unified_Ideograph", "Ideographic"},
    197624: {"Unified_Ideograph", "Ideographic"},
    197625: {"Unified_Ideograph", "Ideographic"},
    197626: {"Unified_Ideograph", "Ideographic"},
    197627: {"Unified_Ideograph", "Ideographic"},
    197628: {"Unified_Ideograph", "Ideographic"},
    197629: {"Unified_Ideograph", "Ideographic"},
    197630: {"Unified_Ideograph", "Ideographic"},
    197631: {"Unified_Ideograph", "Ideographic"},
    197632: {"Unified_Ideograph", "Ideographic"},
    197633: {"Unified_Ideograph", "Ideographic"},
    197634: {"Unified_Ideograph", "Ideographic"},
    197635: {"Unified_Ideograph", "Ideographic"},
    197636: {"Unified_Ideograph", "Ideographic"},
    197637: {"Unified_Ideograph", "Ideographic"},
    197638: {"Unified_Ideograph", "Ideographic"},
    197639: {"Unified_Ideograph", "Ideographic"},
    197640: {"Unified_Ideograph", "Ideographic"},
    197641: {"Unified_Ideograph", "Ideographic"},
    197642: {"Unified_Ideograph", "Ideographic"},
    197643: {"Unified_Ideograph", "Ideographic"},
    197644: {"Unified_Ideograph", "Ideographic"},
    197645: {"Unified_Ideograph", "Ideographic"},
    197646: {"Unified_Ideograph", "Ideographic"},
    197647: {"Unified_Ideograph", "Ideographic"},
    197648: {"Unified_Ideograph", "Ideographic"},
    197649: {"Unified_Ideograph", "Ideographic"},
    197650: {"Unified_Ideograph", "Ideographic"},
    197651: {"Unified_Ideograph", "Ideographic"},
    197652: {"Unified_Ideograph", "Ideographic"},
    197653: {"Unified_Ideograph", "Ideographic"},
    197654: {"Unified_Ideograph", "Ideographic"},
    197655: {"Unified_Ideograph", "Ideographic"},
    197656: {"Unified_Ideograph", "Ideographic"},
    197657: {"Unified_Ideograph", "Ideographic"},
    197658: {"Unified_Ideograph", "Ideographic"},
    197659: {"Unified_Ideograph", "Ideographic"},
    197660: {"Unified_Ideograph", "Ideographic"},
    197661: {"Unified_Ideograph", "Ideographic"},
    197662: {"Unified_Ideograph", "Ideographic"},
    197663: {"Unified_Ideograph", "Ideographic"},
    197664: {"Unified_Ideograph", "Ideographic"},
    197665: {"Unified_Ideograph", "Ideographic"},
    197666: {"Unified_Ideograph", "Ideographic"},
    197667: {"Unified_Ideograph", "Ideographic"},
    197668: {"Unified_Ideograph", "Ideographic"},
    197669: {"Unified_Ideograph", "Ideographic"},
    197670: {"Unified_Ideograph", "Ideographic"},
    197671: {"Unified_Ideograph", "Ideographic"},
    197672: {"Unified_Ideograph", "Ideographic"},
    197673: {"Unified_Ideograph", "Ideographic"},
    197674: {"Unified_Ideograph", "Ideographic"},
    197675: {"Unified_Ideograph", "Ideographic"},
    197676: {"Unified_Ideograph", "Ideographic"},
    197677: {"Unified_Ideograph", "Ideographic"},
    197678: {"Unified_Ideograph", "Ideographic"},
    197679: {"Unified_Ideograph", "Ideographic"},
    197680: {"Unified_Ideograph", "Ideographic"},
    197681: {"Unified_Ideograph", "Ideographic"},
    197682: {"Unified_Ideograph", "Ideographic"},
    197683: {"Unified_Ideograph", "Ideographic"},
    197684: {"Unified_Ideograph", "Ideographic"},
    197685: {"Unified_Ideograph", "Ideographic"},
    197686: {"Unified_Ideograph", "Ideographic"},
    197687: {"Unified_Ideograph", "Ideographic"},
    197688: {"Unified_Ideograph", "Ideographic"},
    197689: {"Unified_Ideograph", "Ideographic"},
    197690: {"Unified_Ideograph", "Ideographic"},
    197691: {"Unified_Ideograph", "Ideographic"},
    197692: {"Unified_Ideograph", "Ideographic"},
    197693: {"Unified_Ideograph", "Ideographic"},
    197694: {"Unified_Ideograph", "Ideographic"},
    197695: {"Unified_Ideograph", "Ideographic"},
    197696: {"Unified_Ideograph", "Ideographic"},
    197697: {"Unified_Ideograph", "Ideographic"},
    197698: {"Unified_Ideograph", "Ideographic"},
    197699: {"Unified_Ideograph", "Ideographic"},
    197700: {"Unified_Ideograph", "Ideographic"},
    197701: {"Unified_Ideograph", "Ideographic"},
    197702: {"Unified_Ideograph", "Ideographic"},
    197703: {"Unified_Ideograph", "Ideographic"},
    197704: {"Unified_Ideograph", "Ideographic"},
    197705: {"Unified_Ideograph", "Ideographic"},
    197706: {"Unified_Ideograph", "Ideographic"},
    197707: {"Unified_Ideograph", "Ideographic"},
    197708: {"Unified_Ideograph", "Ideographic"},
    197709: {"Unified_Ideograph", "Ideographic"},
    197710: {"Unified_Ideograph", "Ideographic"},
    197711: {"Unified_Ideograph", "Ideographic"},
    197712: {"Unified_Ideograph", "Ideographic"},
    197713: {"Unified_Ideograph", "Ideographic"},
    197714: {"Unified_Ideograph", "Ideographic"},
    197715: {"Unified_Ideograph", "Ideographic"},
    197716: {"Unified_Ideograph", "Ideographic"},
    197717: {"Unified_Ideograph", "Ideographic"},
    197718: {"Unified_Ideograph", "Ideographic"},
    197719: {"Unified_Ideograph", "Ideographic"},
    197720: {"Unified_Ideograph", "Ideographic"},
    197721: {"Unified_Ideograph", "Ideographic"},
    197722: {"Unified_Ideograph", "Ideographic"},
    197723: {"Unified_Ideograph", "Ideographic"},
    197724: {"Unified_Ideograph", "Ideographic"},
    197725: {"Unified_Ideograph", "Ideographic"},
    197726: {"Unified_Ideograph", "Ideographic"},
    197727: {"Unified_Ideograph", "Ideographic"},
    197728: {"Unified_Ideograph", "Ideographic"},
    197729: {"Unified_Ideograph", "Ideographic"},
    197730: {"Unified_Ideograph", "Ideographic"},
    197731: {"Unified_Ideograph", "Ideographic"},
    197732: {"Unified_Ideograph", "Ideographic"},
    197733: {"Unified_Ideograph", "Ideographic"},
    197734: {"Unified_Ideograph", "Ideographic"},
    197735: {"Unified_Ideograph", "Ideographic"},
    197736: {"Unified_Ideograph", "Ideographic"},
    197737: {"Unified_Ideograph", "Ideographic"},
    197738: {"Unified_Ideograph", "Ideographic"},
    197739: {"Unified_Ideograph", "Ideographic"},
    197740: {"Unified_Ideograph", "Ideographic"},
    197741: {"Unified_Ideograph", "Ideographic"},
    197742: {"Unified_Ideograph", "Ideographic"},
    197743: {"Unified_Ideograph", "Ideographic"},
    197744: {"Unified_Ideograph", "Ideographic"},
    197745: {"Unified_Ideograph", "Ideographic"},
    197746: {"Unified_Ideograph", "Ideographic"},
    197747: {"Unified_Ideograph", "Ideographic"},
    197748: {"Unified_Ideograph", "Ideographic"},
    197749: {"Unified_Ideograph", "Ideographic"},
    197750: {"Unified_Ideograph", "Ideographic"},
    197751: {"Unified_Ideograph", "Ideographic"},
    197752: {"Unified_Ideograph", "Ideographic"},
    197753: {"Unified_Ideograph", "Ideographic"},
    197754: {"Unified_Ideograph", "Ideographic"},
    197755: {"Unified_Ideograph", "Ideographic"},
    197756: {"Unified_Ideograph", "Ideographic"},
    197757: {"Unified_Ideograph", "Ideographic"},
    197758: {"Unified_Ideograph", "Ideographic"},
    197759: {"Unified_Ideograph", "Ideographic"},
    197760: {"Unified_Ideograph", "Ideographic"},
    197761: {"Unified_Ideograph", "Ideographic"},
    197762: {"Unified_Ideograph", "Ideographic"},
    197763: {"Unified_Ideograph", "Ideographic"},
    197764: {"Unified_Ideograph", "Ideographic"},
    197765: {"Unified_Ideograph", "Ideographic"},
    197766: {"Unified_Ideograph", "Ideographic"},
    197767: {"Unified_Ideograph", "Ideographic"},
    197768: {"Unified_Ideograph", "Ideographic"},
    197769: {"Unified_Ideograph", "Ideographic"},
    197770: {"Unified_Ideograph", "Ideographic"},
    197771: {"Unified_Ideograph", "Ideographic"},
    197772: {"Unified_Ideograph", "Ideographic"},
    197773: {"Unified_Ideograph", "Ideographic"},
    197774: {"Unified_Ideograph", "Ideographic"},
    197775: {"Unified_Ideograph", "Ideographic"},
    197776: {"Unified_Ideograph", "Ideographic"},
    197777: {"Unified_Ideograph", "Ideographic"},
    197778: {"Unified_Ideograph", "Ideographic"},
    197779: {"Unified_Ideograph", "Ideographic"},
    197780: {"Unified_Ideograph", "Ideographic"},
    197781: {"Unified_Ideograph", "Ideographic"},
    197782: {"Unified_Ideograph", "Ideographic"},
    197783: {"Unified_Ideograph", "Ideographic"},
    197784: {"Unified_Ideograph", "Ideographic"},
    197785: {"Unified_Ideograph", "Ideographic"},
    197786: {"Unified_Ideograph", "Ideographic"},
    197787: {"Unified_Ideograph", "Ideographic"},
    197788: {"Unified_Ideograph", "Ideographic"},
    197789: {"Unified_Ideograph", "Ideographic"},
    197790: {"Unified_Ideograph", "Ideographic"},
    197791: {"Unified_Ideograph", "Ideographic"},
    197792: {"Unified_Ideograph", "Ideographic"},
    197793: {"Unified_Ideograph", "Ideographic"},
    197794: {"Unified_Ideograph", "Ideographic"},
    197795: {"Unified_Ideograph", "Ideographic"},
    197796: {"Unified_Ideograph", "Ideographic"},
    197797: {"Unified_Ideograph", "Ideographic"},
    197798: {"Unified_Ideograph", "Ideographic"},
    197799: {"Unified_Ideograph", "Ideographic"},
    197800: {"Unified_Ideograph", "Ideographic"},
    197801: {"Unified_Ideograph", "Ideographic"},
    197802: {"Unified_Ideograph", "Ideographic"},
    197803: {"Unified_Ideograph", "Ideographic"},
    197804: {"Unified_Ideograph", "Ideographic"},
    197805: {"Unified_Ideograph", "Ideographic"},
    197806: {"Unified_Ideograph", "Ideographic"},
    197807: {"Unified_Ideograph", "Ideographic"},
    197808: {"Unified_Ideograph", "Ideographic"},
    197809: {"Unified_Ideograph", "Ideographic"},
    197810: {"Unified_Ideograph", "Ideographic"},
    197811: {"Unified_Ideograph", "Ideographic"},
    197812: {"Unified_Ideograph", "Ideographic"},
    197813: {"Unified_Ideograph", "Ideographic"},
    197814: {"Unified_Ideograph", "Ideographic"},
    197815: {"Unified_Ideograph", "Ideographic"},
    197816: {"Unified_Ideograph", "Ideographic"},
    197817: {"Unified_Ideograph", "Ideographic"},
    197818: {"Unified_Ideograph", "Ideographic"},
    197819: {"Unified_Ideograph", "Ideographic"},
    197820: {"Unified_Ideograph", "Ideographic"},
    197821: {"Unified_Ideograph", "Ideographic"},
    197822: {"Unified_Ideograph", "Ideographic"},
    197823: {"Unified_Ideograph", "Ideographic"},
    197824: {"Unified_Ideograph", "Ideographic"},
    197825: {"Unified_Ideograph", "Ideographic"},
    197826: {"Unified_Ideograph", "Ideographic"},
    197827: {"Unified_Ideograph", "Ideographic"},
    197828: {"Unified_Ideograph", "Ideographic"},
    197829: {"Unified_Ideograph", "Ideographic"},
    197830: {"Unified_Ideograph", "Ideographic"},
    197831: {"Unified_Ideograph", "Ideographic"},
    197832: {"Unified_Ideograph", "Ideographic"},
    197833: {"Unified_Ideograph", "Ideographic"},
    197834: {"Unified_Ideograph", "Ideographic"},
    197835: {"Unified_Ideograph", "Ideographic"},
    197836: {"Unified_Ideograph", "Ideographic"},
    197837: {"Unified_Ideograph", "Ideographic"},
    197838: {"Unified_Ideograph", "Ideographic"},
    197839: {"Unified_Ideograph", "Ideographic"},
    197840: {"Unified_Ideograph", "Ideographic"},
    197841: {"Unified_Ideograph", "Ideographic"},
    197842: {"Unified_Ideograph", "Ideographic"},
    197843: {"Unified_Ideograph", "Ideographic"},
    197844: {"Unified_Ideograph", "Ideographic"},
    197845: {"Unified_Ideograph", "Ideographic"},
    197846: {"Unified_Ideograph", "Ideographic"},
    197847: {"Unified_Ideograph", "Ideographic"},
    197848: {"Unified_Ideograph", "Ideographic"},
    197849: {"Unified_Ideograph", "Ideographic"},
    197850: {"Unified_Ideograph", "Ideographic"},
    197851: {"Unified_Ideograph", "Ideographic"},
    197852: {"Unified_Ideograph", "Ideographic"},
    197853: {"Unified_Ideograph", "Ideographic"},
    197854: {"Unified_Ideograph", "Ideographic"},
    197855: {"Unified_Ideograph", "Ideographic"},
    197856: {"Unified_Ideograph", "Ideographic"},
    197857: {"Unified_Ideograph", "Ideographic"},
    197858: {"Unified_Ideograph", "Ideographic"},
    197859: {"Unified_Ideograph", "Ideographic"},
    197860: {"Unified_Ideograph", "Ideographic"},
    197861: {"Unified_Ideograph", "Ideographic"},
    197862: {"Unified_Ideograph", "Ideographic"},
    197863: {"Unified_Ideograph", "Ideographic"},
    197864: {"Unified_Ideograph", "Ideographic"},
    197865: {"Unified_Ideograph", "Ideographic"},
    197866: {"Unified_Ideograph", "Ideographic"},
    197867: {"Unified_Ideograph", "Ideographic"},
    197868: {"Unified_Ideograph", "Ideographic"},
    197869: {"Unified_Ideograph", "Ideographic"},
    197870: {"Unified_Ideograph", "Ideographic"},
    197871: {"Unified_Ideograph", "Ideographic"},
    197872: {"Unified_Ideograph", "Ideographic"},
    197873: {"Unified_Ideograph", "Ideographic"},
    197874: {"Unified_Ideograph", "Ideographic"},
    197875: {"Unified_Ideograph", "Ideographic"},
    197876: {"Unified_Ideograph", "Ideographic"},
    197877: {"Unified_Ideograph", "Ideographic"},
    197878: {"Unified_Ideograph", "Ideographic"},
    197879: {"Unified_Ideograph", "Ideographic"},
    197880: {"Unified_Ideograph", "Ideographic"},
    197881: {"Unified_Ideograph", "Ideographic"},
    197882: {"Unified_Ideograph", "Ideographic"},
    197883: {"Unified_Ideograph", "Ideographic"},
    197884: {"Unified_Ideograph", "Ideographic"},
    197885: {"Unified_Ideograph", "Ideographic"},
    197886: {"Unified_Ideograph", "Ideographic"},
    197887: {"Unified_Ideograph", "Ideographic"},
    197888: {"Unified_Ideograph", "Ideographic"},
    197889: {"Unified_Ideograph", "Ideographic"},
    197890: {"Unified_Ideograph", "Ideographic"},
    197891: {"Unified_Ideograph", "Ideographic"},
    197892: {"Unified_Ideograph", "Ideographic"},
    197893: {"Unified_Ideograph", "Ideographic"},
    197894: {"Unified_Ideograph", "Ideographic"},
    197895: {"Unified_Ideograph", "Ideographic"},
    197896: {"Unified_Ideograph", "Ideographic"},
    197897: {"Unified_Ideograph", "Ideographic"},
    197898: {"Unified_Ideograph", "Ideographic"},
    197899: {"Unified_Ideograph", "Ideographic"},
    197900: {"Unified_Ideograph", "Ideographic"},
    197901: {"Unified_Ideograph", "Ideographic"},
    197902: {"Unified_Ideograph", "Ideographic"},
    197903: {"Unified_Ideograph", "Ideographic"},
    197904: {"Unified_Ideograph", "Ideographic"},
    197905: {"Unified_Ideograph", "Ideographic"},
    197906: {"Unified_Ideograph", "Ideographic"},
    197907: {"Unified_Ideograph", "Ideographic"},
    197908: {"Unified_Ideograph", "Ideographic"},
    197909: {"Unified_Ideograph", "Ideographic"},
    197910: {"Unified_Ideograph", "Ideographic"},
    197911: {"Unified_Ideograph", "Ideographic"},
    197912: {"Unified_Ideograph", "Ideographic"},
    197913: {"Unified_Ideograph", "Ideographic"},
    197914: {"Unified_Ideograph", "Ideographic"},
    197915: {"Unified_Ideograph", "Ideographic"},
    197916: {"Unified_Ideograph", "Ideographic"},
    197917: {"Unified_Ideograph", "Ideographic"},
    197918: {"Unified_Ideograph", "Ideographic"},
    197919: {"Unified_Ideograph", "Ideographic"},
    197920: {"Unified_Ideograph", "Ideographic"},
    197921: {"Unified_Ideograph", "Ideographic"},
    197922: {"Unified_Ideograph", "Ideographic"},
    197923: {"Unified_Ideograph", "Ideographic"},
    197924: {"Unified_Ideograph", "Ideographic"},
    197925: {"Unified_Ideograph", "Ideographic"},
    197926: {"Unified_Ideograph", "Ideographic"},
    197927: {"Unified_Ideograph", "Ideographic"},
    197928: {"Unified_Ideograph", "Ideographic"},
    197929: {"Unified_Ideograph", "Ideographic"},
    197930: {"Unified_Ideograph", "Ideographic"},
    197931: {"Unified_Ideograph", "Ideographic"},
    197932: {"Unified_Ideograph", "Ideographic"},
    197933: {"Unified_Ideograph", "Ideographic"},
    197934: {"Unified_Ideograph", "Ideographic"},
    197935: {"Unified_Ideograph", "Ideographic"},
    197936: {"Unified_Ideograph", "Ideographic"},
    197937: {"Unified_Ideograph", "Ideographic"},
    197938: {"Unified_Ideograph", "Ideographic"},
    197939: {"Unified_Ideograph", "Ideographic"},
    197940: {"Unified_Ideograph", "Ideographic"},
    197941: {"Unified_Ideograph", "Ideographic"},
    197942: {"Unified_Ideograph", "Ideographic"},
    197943: {"Unified_Ideograph", "Ideographic"},
    197944: {"Unified_Ideograph", "Ideographic"},
    197945: {"Unified_Ideograph", "Ideographic"},
    197946: {"Unified_Ideograph", "Ideographic"},
    197947: {"Unified_Ideograph", "Ideographic"},
    197948: {"Unified_Ideograph", "Ideographic"},
    197949: {"Unified_Ideograph", "Ideographic"},
    197950: {"Unified_Ideograph", "Ideographic"},
    197951: {"Unified_Ideograph", "Ideographic"},
    197952: {"Unified_Ideograph", "Ideographic"},
    197953: {"Unified_Ideograph", "Ideographic"},
    197954: {"Unified_Ideograph", "Ideographic"},
    197955: {"Unified_Ideograph", "Ideographic"},
    197956: {"Unified_Ideograph", "Ideographic"},
    197957: {"Unified_Ideograph", "Ideographic"},
    197958: {"Unified_Ideograph", "Ideographic"},
    197959: {"Unified_Ideograph", "Ideographic"},
    197960: {"Unified_Ideograph", "Ideographic"},
    197961: {"Unified_Ideograph", "Ideographic"},
    197962: {"Unified_Ideograph", "Ideographic"},
    197963: {"Unified_Ideograph", "Ideographic"},
    197964: {"Unified_Ideograph", "Ideographic"},
    197965: {"Unified_Ideograph", "Ideographic"},
    197966: {"Unified_Ideograph", "Ideographic"},
    197967: {"Unified_Ideograph", "Ideographic"},
    197968: {"Unified_Ideograph", "Ideographic"},
    197969: {"Unified_Ideograph", "Ideographic"},
    197970: {"Unified_Ideograph", "Ideographic"},
    197971: {"Unified_Ideograph", "Ideographic"},
    197972: {"Unified_Ideograph", "Ideographic"},
    197973: {"Unified_Ideograph", "Ideographic"},
    197974: {"Unified_Ideograph", "Ideographic"},
    197975: {"Unified_Ideograph", "Ideographic"},
    197976: {"Unified_Ideograph", "Ideographic"},
    197977: {"Unified_Ideograph", "Ideographic"},
    197978: {"Unified_Ideograph", "Ideographic"},
    197979: {"Unified_Ideograph", "Ideographic"},
    197980: {"Unified_Ideograph", "Ideographic"},
    197981: {"Unified_Ideograph", "Ideographic"},
    197982: {"Unified_Ideograph", "Ideographic"},
    197983: {"Unified_Ideograph", "Ideographic"},
    197984: {"Unified_Ideograph", "Ideographic"},
    197985: {"Unified_Ideograph", "Ideographic"},
    197986: {"Unified_Ideograph", "Ideographic"},
    197987: {"Unified_Ideograph", "Ideographic"},
    197988: {"Unified_Ideograph", "Ideographic"},
    197989: {"Unified_Ideograph", "Ideographic"},
    197990: {"Unified_Ideograph", "Ideographic"},
    197991: {"Unified_Ideograph", "Ideographic"},
    197992: {"Unified_Ideograph", "Ideographic"},
    197993: {"Unified_Ideograph", "Ideographic"},
    197994: {"Unified_Ideograph", "Ideographic"},
    197995: {"Unified_Ideograph", "Ideographic"},
    197996: {"Unified_Ideograph", "Ideographic"},
    197997: {"Unified_Ideograph", "Ideographic"},
    197998: {"Unified_Ideograph", "Ideographic"},
    197999: {"Unified_Ideograph", "Ideographic"},
    198000: {"Unified_Ideograph", "Ideographic"},
    198001: {"Unified_Ideograph", "Ideographic"},
    198002: {"Unified_Ideograph", "Ideographic"},
    198003: {"Unified_Ideograph", "Ideographic"},
    198004: {"Unified_Ideograph", "Ideographic"},
    198005: {"Unified_Ideograph", "Ideographic"},
    198006: {"Unified_Ideograph", "Ideographic"},
    198007: {"Unified_Ideograph", "Ideographic"},
    198008: {"Unified_Ideograph", "Ideographic"},
    198009: {"Unified_Ideograph", "Ideographic"},
    198010: {"Unified_Ideograph", "Ideographic"},
    198011: {"Unified_Ideograph", "Ideographic"},
    198012: {"Unified_Ideograph", "Ideographic"},
    198013: {"Unified_Ideograph", "Ideographic"},
    198014: {"Unified_Ideograph", "Ideographic"},
    198015: {"Unified_Ideograph", "Ideographic"},
    198016: {"Unified_Ideograph", "Ideographic"},
    198017: {"Unified_Ideograph", "Ideographic"},
    198018: {"Unified_Ideograph", "Ideographic"},
    198019: {"Unified_Ideograph", "Ideographic"},
    198020: {"Unified_Ideograph", "Ideographic"},
    198021: {"Unified_Ideograph", "Ideographic"},
    198022: {"Unified_Ideograph", "Ideographic"},
    198023: {"Unified_Ideograph", "Ideographic"},
    198024: {"Unified_Ideograph", "Ideographic"},
    198025: {"Unified_Ideograph", "Ideographic"},
    198026: {"Unified_Ideograph", "Ideographic"},
    198027: {"Unified_Ideograph", "Ideographic"},
    198028: {"Unified_Ideograph", "Ideographic"},
    198029: {"Unified_Ideograph", "Ideographic"},
    198030: {"Unified_Ideograph", "Ideographic"},
    198031: {"Unified_Ideograph", "Ideographic"},
    198032: {"Unified_Ideograph", "Ideographic"},
    198033: {"Unified_Ideograph", "Ideographic"},
    198034: {"Unified_Ideograph", "Ideographic"},
    198035: {"Unified_Ideograph", "Ideographic"},
    198036: {"Unified_Ideograph", "Ideographic"},
    198037: {"Unified_Ideograph", "Ideographic"},
    198038: {"Unified_Ideograph", "Ideographic"},
    198039: {"Unified_Ideograph", "Ideographic"},
    198040: {"Unified_Ideograph", "Ideographic"},
    198041: {"Unified_Ideograph", "Ideographic"},
    198042: {"Unified_Ideograph", "Ideographic"},
    198043: {"Unified_Ideograph", "Ideographic"},
    198044: {"Unified_Ideograph", "Ideographic"},
    198045: {"Unified_Ideograph", "Ideographic"},
    198046: {"Unified_Ideograph", "Ideographic"},
    198047: {"Unified_Ideograph", "Ideographic"},
    198048: {"Unified_Ideograph", "Ideographic"},
    198049: {"Unified_Ideograph", "Ideographic"},
    198050: {"Unified_Ideograph", "Ideographic"},
    198051: {"Unified_Ideograph", "Ideographic"},
    198052: {"Unified_Ideograph", "Ideographic"},
    198053: {"Unified_Ideograph", "Ideographic"},
    198054: {"Unified_Ideograph", "Ideographic"},
    198055: {"Unified_Ideograph", "Ideographic"},
    198056: {"Unified_Ideograph", "Ideographic"},
    198057: {"Unified_Ideograph", "Ideographic"},
    198058: {"Unified_Ideograph", "Ideographic"},
    198059: {"Unified_Ideograph", "Ideographic"},
    198060: {"Unified_Ideograph", "Ideographic"},
    198061: {"Unified_Ideograph", "Ideographic"},
    198062: {"Unified_Ideograph", "Ideographic"},
    198063: {"Unified_Ideograph", "Ideographic"},
    198064: {"Unified_Ideograph", "Ideographic"},
    198065: {"Unified_Ideograph", "Ideographic"},
    198066: {"Unified_Ideograph", "Ideographic"},
    198067: {"Unified_Ideograph", "Ideographic"},
    198068: {"Unified_Ideograph", "Ideographic"},
    198069: {"Unified_Ideograph", "Ideographic"},
    198070: {"Unified_Ideograph", "Ideographic"},
    198071: {"Unified_Ideograph", "Ideographic"},
    198072: {"Unified_Ideograph", "Ideographic"},
    198073: {"Unified_Ideograph", "Ideographic"},
    198074: {"Unified_Ideograph", "Ideographic"},
    198075: {"Unified_Ideograph", "Ideographic"},
    198076: {"Unified_Ideograph", "Ideographic"},
    198077: {"Unified_Ideograph", "Ideographic"},
    198078: {"Unified_Ideograph", "Ideographic"},
    198079: {"Unified_Ideograph", "Ideographic"},
    198080: {"Unified_Ideograph", "Ideographic"},
    198081: {"Unified_Ideograph", "Ideographic"},
    198082: {"Unified_Ideograph", "Ideographic"},
    198083: {"Unified_Ideograph", "Ideographic"},
    198084: {"Unified_Ideograph", "Ideographic"},
    198085: {"Unified_Ideograph", "Ideographic"},
    198086: {"Unified_Ideograph", "Ideographic"},
    198087: {"Unified_Ideograph", "Ideographic"},
    198088: {"Unified_Ideograph", "Ideographic"},
    198089: {"Unified_Ideograph", "Ideographic"},
    198090: {"Unified_Ideograph", "Ideographic"},
    198091: {"Unified_Ideograph", "Ideographic"},
    198092: {"Unified_Ideograph", "Ideographic"},
    198093: {"Unified_Ideograph", "Ideographic"},
    198094: {"Unified_Ideograph", "Ideographic"},
    198095: {"Unified_Ideograph", "Ideographic"},
    198096: {"Unified_Ideograph", "Ideographic"},
    198097: {"Unified_Ideograph", "Ideographic"},
    198098: {"Unified_Ideograph", "Ideographic"},
    198099: {"Unified_Ideograph", "Ideographic"},
    198100: {"Unified_Ideograph", "Ideographic"},
    198101: {"Unified_Ideograph", "Ideographic"},
    198102: {"Unified_Ideograph", "Ideographic"},
    198103: {"Unified_Ideograph", "Ideographic"},
    198104: {"Unified_Ideograph", "Ideographic"},
    198105: {"Unified_Ideograph", "Ideographic"},
    198106: {"Unified_Ideograph", "Ideographic"},
    198107: {"Unified_Ideograph", "Ideographic"},
    198108: {"Unified_Ideograph", "Ideographic"},
    198109: {"Unified_Ideograph", "Ideographic"},
    198110: {"Unified_Ideograph", "Ideographic"},
    198111: {"Unified_Ideograph", "Ideographic"},
    198112: {"Unified_Ideograph", "Ideographic"},
    198113: {"Unified_Ideograph", "Ideographic"},
    198114: {"Unified_Ideograph", "Ideographic"},
    198115: {"Unified_Ideograph", "Ideographic"},
    198116: {"Unified_Ideograph", "Ideographic"},
    198117: {"Unified_Ideograph", "Ideographic"},
    198118: {"Unified_Ideograph", "Ideographic"},
    198119: {"Unified_Ideograph", "Ideographic"},
    198120: {"Unified_Ideograph", "Ideographic"},
    198121: {"Unified_Ideograph", "Ideographic"},
    198122: {"Unified_Ideograph", "Ideographic"},
    198123: {"Unified_Ideograph", "Ideographic"},
    198124: {"Unified_Ideograph", "Ideographic"},
    198125: {"Unified_Ideograph", "Ideographic"},
    198126: {"Unified_Ideograph", "Ideographic"},
    198127: {"Unified_Ideograph", "Ideographic"},
    198128: {"Unified_Ideograph", "Ideographic"},
    198129: {"Unified_Ideograph", "Ideographic"},
    198130: {"Unified_Ideograph", "Ideographic"},
    198131: {"Unified_Ideograph", "Ideographic"},
    198132: {"Unified_Ideograph", "Ideographic"},
    198133: {"Unified_Ideograph", "Ideographic"},
    198134: {"Unified_Ideograph", "Ideographic"},
    198135: {"Unified_Ideograph", "Ideographic"},
    198136: {"Unified_Ideograph", "Ideographic"},
    198137: {"Unified_Ideograph", "Ideographic"},
    198138: {"Unified_Ideograph", "Ideographic"},
    198139: {"Unified_Ideograph", "Ideographic"},
    198140: {"Unified_Ideograph", "Ideographic"},
    198141: {"Unified_Ideograph", "Ideographic"},
    198142: {"Unified_Ideograph", "Ideographic"},
    198143: {"Unified_Ideograph", "Ideographic"},
    198144: {"Unified_Ideograph", "Ideographic"},
    198145: {"Unified_Ideograph", "Ideographic"},
    198146: {"Unified_Ideograph", "Ideographic"},
    198147: {"Unified_Ideograph", "Ideographic"},
    198148: {"Unified_Ideograph", "Ideographic"},
    198149: {"Unified_Ideograph", "Ideographic"},
    198150: {"Unified_Ideograph", "Ideographic"},
    198151: {"Unified_Ideograph", "Ideographic"},
    198152: {"Unified_Ideograph", "Ideographic"},
    198153: {"Unified_Ideograph", "Ideographic"},
    198154: {"Unified_Ideograph", "Ideographic"},
    198155: {"Unified_Ideograph", "Ideographic"},
    198156: {"Unified_Ideograph", "Ideographic"},
    198157: {"Unified_Ideograph", "Ideographic"},
    198158: {"Unified_Ideograph", "Ideographic"},
    198159: {"Unified_Ideograph", "Ideographic"},
    198160: {"Unified_Ideograph", "Ideographic"},
    198161: {"Unified_Ideograph", "Ideographic"},
    198162: {"Unified_Ideograph", "Ideographic"},
    198163: {"Unified_Ideograph", "Ideographic"},
    198164: {"Unified_Ideograph", "Ideographic"},
    198165: {"Unified_Ideograph", "Ideographic"},
    198166: {"Unified_Ideograph", "Ideographic"},
    198167: {"Unified_Ideograph", "Ideographic"},
    198168: {"Unified_Ideograph", "Ideographic"},
    198169: {"Unified_Ideograph", "Ideographic"},
    198170: {"Unified_Ideograph", "Ideographic"},
    198171: {"Unified_Ideograph", "Ideographic"},
    198172: {"Unified_Ideograph", "Ideographic"},
    198173: {"Unified_Ideograph", "Ideographic"},
    198174: {"Unified_Ideograph", "Ideographic"},
    198175: {"Unified_Ideograph", "Ideographic"},
    198176: {"Unified_Ideograph", "Ideographic"},
    198177: {"Unified_Ideograph", "Ideographic"},
    198178: {"Unified_Ideograph", "Ideographic"},
    198179: {"Unified_Ideograph", "Ideographic"},
    198180: {"Unified_Ideograph", "Ideographic"},
    198181: {"Unified_Ideograph", "Ideographic"},
    198182: {"Unified_Ideograph", "Ideographic"},
    198183: {"Unified_Ideograph", "Ideographic"},
    198184: {"Unified_Ideograph", "Ideographic"},
    198185: {"Unified_Ideograph", "Ideographic"},
    198186: {"Unified_Ideograph", "Ideographic"},
    198187: {"Unified_Ideograph", "Ideographic"},
    198188: {"Unified_Ideograph", "Ideographic"},
    198189: {"Unified_Ideograph", "Ideographic"},
    198190: {"Unified_Ideograph", "Ideographic"},
    198191: {"Unified_Ideograph", "Ideographic"},
    198192: {"Unified_Ideograph", "Ideographic"},
    198193: {"Unified_Ideograph", "Ideographic"},
    198194: {"Unified_Ideograph", "Ideographic"},
    198195: {"Unified_Ideograph", "Ideographic"},
    198196: {"Unified_Ideograph", "Ideographic"},
    198197: {"Unified_Ideograph", "Ideographic"},
    198198: {"Unified_Ideograph", "Ideographic"},
    198199: {"Unified_Ideograph", "Ideographic"},
    198200: {"Unified_Ideograph", "Ideographic"},
    198201: {"Unified_Ideograph", "Ideographic"},
    198202: {"Unified_Ideograph", "Ideographic"},
    198203: {"Unified_Ideograph", "Ideographic"},
    198204: {"Unified_Ideograph", "Ideographic"},
    198205: {"Unified_Ideograph", "Ideographic"},
    198206: {"Unified_Ideograph", "Ideographic"},
    198207: {"Unified_Ideograph", "Ideographic"},
    198208: {"Unified_Ideograph", "Ideographic"},
    198209: {"Unified_Ideograph", "Ideographic"},
    198210: {"Unified_Ideograph", "Ideographic"},
    198211: {"Unified_Ideograph", "Ideographic"},
    198212: {"Unified_Ideograph", "Ideographic"},
    198213: {"Unified_Ideograph", "Ideographic"},
    198214: {"Unified_Ideograph", "Ideographic"},
    198215: {"Unified_Ideograph", "Ideographic"},
    198216: {"Unified_Ideograph", "Ideographic"},
    198217: {"Unified_Ideograph", "Ideographic"},
    198218: {"Unified_Ideograph", "Ideographic"},
    198219: {"Unified_Ideograph", "Ideographic"},
    198220: {"Unified_Ideograph", "Ideographic"},
    198221: {"Unified_Ideograph", "Ideographic"},
    198222: {"Unified_Ideograph", "Ideographic"},
    198223: {"Unified_Ideograph", "Ideographic"},
    198224: {"Unified_Ideograph", "Ideographic"},
    198225: {"Unified_Ideograph", "Ideographic"},
    198226: {"Unified_Ideograph", "Ideographic"},
    198227: {"Unified_Ideograph", "Ideographic"},
    198228: {"Unified_Ideograph", "Ideographic"},
    198229: {"Unified_Ideograph", "Ideographic"},
    198230: {"Unified_Ideograph", "Ideographic"},
    198231: {"Unified_Ideograph", "Ideographic"},
    198232: {"Unified_Ideograph", "Ideographic"},
    198233: {"Unified_Ideograph", "Ideographic"},
    198234: {"Unified_Ideograph", "Ideographic"},
    198235: {"Unified_Ideograph", "Ideographic"},
    198236: {"Unified_Ideograph", "Ideographic"},
    198237: {"Unified_Ideograph", "Ideographic"},
    198238: {"Unified_Ideograph", "Ideographic"},
    198239: {"Unified_Ideograph", "Ideographic"},
    198240: {"Unified_Ideograph", "Ideographic"},
    198241: {"Unified_Ideograph", "Ideographic"},
    198242: {"Unified_Ideograph", "Ideographic"},
    198243: {"Unified_Ideograph", "Ideographic"},
    198244: {"Unified_Ideograph", "Ideographic"},
    198245: {"Unified_Ideograph", "Ideographic"},
    198246: {"Unified_Ideograph", "Ideographic"},
    198247: {"Unified_Ideograph", "Ideographic"},
    198248: {"Unified_Ideograph", "Ideographic"},
    198249: {"Unified_Ideograph", "Ideographic"},
    198250: {"Unified_Ideograph", "Ideographic"},
    198251: {"Unified_Ideograph", "Ideographic"},
    198252: {"Unified_Ideograph", "Ideographic"},
    198253: {"Unified_Ideograph", "Ideographic"},
    198254: {"Unified_Ideograph", "Ideographic"},
    198255: {"Unified_Ideograph", "Ideographic"},
    198256: {"Unified_Ideograph", "Ideographic"},
    198257: {"Unified_Ideograph", "Ideographic"},
    198258: {"Unified_Ideograph", "Ideographic"},
    198259: {"Unified_Ideograph", "Ideographic"},
    198260: {"Unified_Ideograph", "Ideographic"},
    198261: {"Unified_Ideograph", "Ideographic"},
    198262: {"Unified_Ideograph", "Ideographic"},
    198263: {"Unified_Ideograph", "Ideographic"},
    198264: {"Unified_Ideograph", "Ideographic"},
    198265: {"Unified_Ideograph", "Ideographic"},
    198266: {"Unified_Ideograph", "Ideographic"},
    198267: {"Unified_Ideograph", "Ideographic"},
    198268: {"Unified_Ideograph", "Ideographic"},
    198269: {"Unified_Ideograph", "Ideographic"},
    198270: {"Unified_Ideograph", "Ideographic"},
    198271: {"Unified_Ideograph", "Ideographic"},
    198272: {"Unified_Ideograph", "Ideographic"},
    198273: {"Unified_Ideograph", "Ideographic"},
    198274: {"Unified_Ideograph", "Ideographic"},
    198275: {"Unified_Ideograph", "Ideographic"},
    198276: {"Unified_Ideograph", "Ideographic"},
    198277: {"Unified_Ideograph", "Ideographic"},
    198278: {"Unified_Ideograph", "Ideographic"},
    198279: {"Unified_Ideograph", "Ideographic"},
    198280: {"Unified_Ideograph", "Ideographic"},
    198281: {"Unified_Ideograph", "Ideographic"},
    198282: {"Unified_Ideograph", "Ideographic"},
    198283: {"Unified_Ideograph", "Ideographic"},
    198284: {"Unified_Ideograph", "Ideographic"},
    198285: {"Unified_Ideograph", "Ideographic"},
    198286: {"Unified_Ideograph", "Ideographic"},
    198287: {"Unified_Ideograph", "Ideographic"},
    198288: {"Unified_Ideograph", "Ideographic"},
    198289: {"Unified_Ideograph", "Ideographic"},
    198290: {"Unified_Ideograph", "Ideographic"},
    198291: {"Unified_Ideograph", "Ideographic"},
    198292: {"Unified_Ideograph", "Ideographic"},
    198293: {"Unified_Ideograph", "Ideographic"},
    198294: {"Unified_Ideograph", "Ideographic"},
    198295: {"Unified_Ideograph", "Ideographic"},
    198296: {"Unified_Ideograph", "Ideographic"},
    198297: {"Unified_Ideograph", "Ideographic"},
    198298: {"Unified_Ideograph", "Ideographic"},
    198299: {"Unified_Ideograph", "Ideographic"},
    198300: {"Unified_Ideograph", "Ideographic"},
    198301: {"Unified_Ideograph", "Ideographic"},
    198302: {"Unified_Ideograph", "Ideographic"},
    198303: {"Unified_Ideograph", "Ideographic"},
    198304: {"Unified_Ideograph", "Ideographic"},
    198305: {"Unified_Ideograph", "Ideographic"},
    198306: {"Unified_Ideograph", "Ideographic"},
    198307: {"Unified_Ideograph", "Ideographic"},
    198308: {"Unified_Ideograph", "Ideographic"},
    198309: {"Unified_Ideograph", "Ideographic"},
    198310: {"Unified_Ideograph", "Ideographic"},
    198311: {"Unified_Ideograph", "Ideographic"},
    198312: {"Unified_Ideograph", "Ideographic"},
    198313: {"Unified_Ideograph", "Ideographic"},
    198314: {"Unified_Ideograph", "Ideographic"},
    198315: {"Unified_Ideograph", "Ideographic"},
    198316: {"Unified_Ideograph", "Ideographic"},
    198317: {"Unified_Ideograph", "Ideographic"},
    198318: {"Unified_Ideograph", "Ideographic"},
    198319: {"Unified_Ideograph", "Ideographic"},
    198320: {"Unified_Ideograph", "Ideographic"},
    198321: {"Unified_Ideograph", "Ideographic"},
    198322: {"Unified_Ideograph", "Ideographic"},
    198323: {"Unified_Ideograph", "Ideographic"},
    198324: {"Unified_Ideograph", "Ideographic"},
    198325: {"Unified_Ideograph", "Ideographic"},
    198326: {"Unified_Ideograph", "Ideographic"},
    198327: {"Unified_Ideograph", "Ideographic"},
    198328: {"Unified_Ideograph", "Ideographic"},
    198329: {"Unified_Ideograph", "Ideographic"},
    198330: {"Unified_Ideograph", "Ideographic"},
    198331: {"Unified_Ideograph", "Ideographic"},
    198332: {"Unified_Ideograph", "Ideographic"},
    198333: {"Unified_Ideograph", "Ideographic"},
    198334: {"Unified_Ideograph", "Ideographic"},
    198335: {"Unified_Ideograph", "Ideographic"},
    198336: {"Unified_Ideograph", "Ideographic"},
    198337: {"Unified_Ideograph", "Ideographic"},
    198338: {"Unified_Ideograph", "Ideographic"},
    198339: {"Unified_Ideograph", "Ideographic"},
    198340: {"Unified_Ideograph", "Ideographic"},
    198341: {"Unified_Ideograph", "Ideographic"},
    198342: {"Unified_Ideograph", "Ideographic"},
    198343: {"Unified_Ideograph", "Ideographic"},
    198344: {"Unified_Ideograph", "Ideographic"},
    198345: {"Unified_Ideograph", "Ideographic"},
    198346: {"Unified_Ideograph", "Ideographic"},
    198347: {"Unified_Ideograph", "Ideographic"},
    198348: {"Unified_Ideograph", "Ideographic"},
    198349: {"Unified_Ideograph", "Ideographic"},
    198350: {"Unified_Ideograph", "Ideographic"},
    198351: {"Unified_Ideograph", "Ideographic"},
    198352: {"Unified_Ideograph", "Ideographic"},
    198353: {"Unified_Ideograph", "Ideographic"},
    198354: {"Unified_Ideograph", "Ideographic"},
    198355: {"Unified_Ideograph", "Ideographic"},
    198356: {"Unified_Ideograph", "Ideographic"},
    198357: {"Unified_Ideograph", "Ideographic"},
    198358: {"Unified_Ideograph", "Ideographic"},
    198359: {"Unified_Ideograph", "Ideographic"},
    198360: {"Unified_Ideograph", "Ideographic"},
    198361: {"Unified_Ideograph", "Ideographic"},
    198362: {"Unified_Ideograph", "Ideographic"},
    198363: {"Unified_Ideograph", "Ideographic"},
    198364: {"Unified_Ideograph", "Ideographic"},
    198365: {"Unified_Ideograph", "Ideographic"},
    198366: {"Unified_Ideograph", "Ideographic"},
    198367: {"Unified_Ideograph", "Ideographic"},
    198368: {"Unified_Ideograph", "Ideographic"},
    198369: {"Unified_Ideograph", "Ideographic"},
    198370: {"Unified_Ideograph", "Ideographic"},
    198371: {"Unified_Ideograph", "Ideographic"},
    198372: {"Unified_Ideograph", "Ideographic"},
    198373: {"Unified_Ideograph", "Ideographic"},
    198374: {"Unified_Ideograph", "Ideographic"},
    198375: {"Unified_Ideograph", "Ideographic"},
    198376: {"Unified_Ideograph", "Ideographic"},
    198377: {"Unified_Ideograph", "Ideographic"},
    198378: {"Unified_Ideograph", "Ideographic"},
    198379: {"Unified_Ideograph", "Ideographic"},
    198380: {"Unified_Ideograph", "Ideographic"},
    198381: {"Unified_Ideograph", "Ideographic"},
    198382: {"Unified_Ideograph", "Ideographic"},
    198383: {"Unified_Ideograph", "Ideographic"},
    198384: {"Unified_Ideograph", "Ideographic"},
    198385: {"Unified_Ideograph", "Ideographic"},
    198386: {"Unified_Ideograph", "Ideographic"},
    198387: {"Unified_Ideograph", "Ideographic"},
    198388: {"Unified_Ideograph", "Ideographic"},
    198389: {"Unified_Ideograph", "Ideographic"},
    198390: {"Unified_Ideograph", "Ideographic"},
    198391: {"Unified_Ideograph", "Ideographic"},
    198392: {"Unified_Ideograph", "Ideographic"},
    198393: {"Unified_Ideograph", "Ideographic"},
    198394: {"Unified_Ideograph", "Ideographic"},
    198395: {"Unified_Ideograph", "Ideographic"},
    198396: {"Unified_Ideograph", "Ideographic"},
    198397: {"Unified_Ideograph", "Ideographic"},
    198398: {"Unified_Ideograph", "Ideographic"},
    198399: {"Unified_Ideograph", "Ideographic"},
    198400: {"Unified_Ideograph", "Ideographic"},
    198401: {"Unified_Ideograph", "Ideographic"},
    198402: {"Unified_Ideograph", "Ideographic"},
    198403: {"Unified_Ideograph", "Ideographic"},
    198404: {"Unified_Ideograph", "Ideographic"},
    198405: {"Unified_Ideograph", "Ideographic"},
    198406: {"Unified_Ideograph", "Ideographic"},
    198407: {"Unified_Ideograph", "Ideographic"},
    198408: {"Unified_Ideograph", "Ideographic"},
    198409: {"Unified_Ideograph", "Ideographic"},
    198410: {"Unified_Ideograph", "Ideographic"},
    198411: {"Unified_Ideograph", "Ideographic"},
    198412: {"Unified_Ideograph", "Ideographic"},
    198413: {"Unified_Ideograph", "Ideographic"},
    198414: {"Unified_Ideograph", "Ideographic"},
    198415: {"Unified_Ideograph", "Ideographic"},
    198416: {"Unified_Ideograph", "Ideographic"},
    198417: {"Unified_Ideograph", "Ideographic"},
    198418: {"Unified_Ideograph", "Ideographic"},
    198419: {"Unified_Ideograph", "Ideographic"},
    198420: {"Unified_Ideograph", "Ideographic"},
    198421: {"Unified_Ideograph", "Ideographic"},
    198422: {"Unified_Ideograph", "Ideographic"},
    198423: {"Unified_Ideograph", "Ideographic"},
    198424: {"Unified_Ideograph", "Ideographic"},
    198425: {"Unified_Ideograph", "Ideographic"},
    198426: {"Unified_Ideograph", "Ideographic"},
    198427: {"Unified_Ideograph", "Ideographic"},
    198428: {"Unified_Ideograph", "Ideographic"},
    198429: {"Unified_Ideograph", "Ideographic"},
    198430: {"Unified_Ideograph", "Ideographic"},
    198431: {"Unified_Ideograph", "Ideographic"},
    198432: {"Unified_Ideograph", "Ideographic"},
    198433: {"Unified_Ideograph", "Ideographic"},
    198434: {"Unified_Ideograph", "Ideographic"},
    198435: {"Unified_Ideograph", "Ideographic"},
    198436: {"Unified_Ideograph", "Ideographic"},
    198437: {"Unified_Ideograph", "Ideographic"},
    198438: {"Unified_Ideograph", "Ideographic"},
    198439: {"Unified_Ideograph", "Ideographic"},
    198440: {"Unified_Ideograph", "Ideographic"},
    198441: {"Unified_Ideograph", "Ideographic"},
    198442: {"Unified_Ideograph", "Ideographic"},
    198443: {"Unified_Ideograph", "Ideographic"},
    198444: {"Unified_Ideograph", "Ideographic"},
    198445: {"Unified_Ideograph", "Ideographic"},
    198446: {"Unified_Ideograph", "Ideographic"},
    198447: {"Unified_Ideograph", "Ideographic"},
    198448: {"Unified_Ideograph", "Ideographic"},
    198449: {"Unified_Ideograph", "Ideographic"},
    198450: {"Unified_Ideograph", "Ideographic"},
    198451: {"Unified_Ideograph", "Ideographic"},
    198452: {"Unified_Ideograph", "Ideographic"},
    198453: {"Unified_Ideograph", "Ideographic"},
    198454: {"Unified_Ideograph", "Ideographic"},
    198455: {"Unified_Ideograph", "Ideographic"},
    198456: {"Unified_Ideograph", "Ideographic"},
    198457: {"Unified_Ideograph", "Ideographic"},
    198458: {"Unified_Ideograph", "Ideographic"},
    198459: {"Unified_Ideograph", "Ideographic"},
    198460: {"Unified_Ideograph", "Ideographic"},
    198461: {"Unified_Ideograph", "Ideographic"},
    198462: {"Unified_Ideograph", "Ideographic"},
    198463: {"Unified_Ideograph", "Ideographic"},
    198464: {"Unified_Ideograph", "Ideographic"},
    198465: {"Unified_Ideograph", "Ideographic"},
    198466: {"Unified_Ideograph", "Ideographic"},
    198467: {"Unified_Ideograph", "Ideographic"},
    198468: {"Unified_Ideograph", "Ideographic"},
    198469: {"Unified_Ideograph", "Ideographic"},
    198470: {"Unified_Ideograph", "Ideographic"},
    198471: {"Unified_Ideograph", "Ideographic"},
    198472: {"Unified_Ideograph", "Ideographic"},
    198473: {"Unified_Ideograph", "Ideographic"},
    198474: {"Unified_Ideograph", "Ideographic"},
    198475: {"Unified_Ideograph", "Ideographic"},
    198476: {"Unified_Ideograph", "Ideographic"},
    198477: {"Unified_Ideograph", "Ideographic"},
    198478: {"Unified_Ideograph", "Ideographic"},
    198479: {"Unified_Ideograph", "Ideographic"},
    198480: {"Unified_Ideograph", "Ideographic"},
    198481: {"Unified_Ideograph", "Ideographic"},
    198482: {"Unified_Ideograph", "Ideographic"},
    198483: {"Unified_Ideograph", "Ideographic"},
    198484: {"Unified_Ideograph", "Ideographic"},
    198485: {"Unified_Ideograph", "Ideographic"},
    198486: {"Unified_Ideograph", "Ideographic"},
    198487: {"Unified_Ideograph", "Ideographic"},
    198488: {"Unified_Ideograph", "Ideographic"},
    198489: {"Unified_Ideograph", "Ideographic"},
    198490: {"Unified_Ideograph", "Ideographic"},
    198491: {"Unified_Ideograph", "Ideographic"},
    198492: {"Unified_Ideograph", "Ideographic"},
    198493: {"Unified_Ideograph", "Ideographic"},
    198494: {"Unified_Ideograph", "Ideographic"},
    198495: {"Unified_Ideograph", "Ideographic"},
    198496: {"Unified_Ideograph", "Ideographic"},
    198497: {"Unified_Ideograph", "Ideographic"},
    198498: {"Unified_Ideograph", "Ideographic"},
    198499: {"Unified_Ideograph", "Ideographic"},
    198500: {"Unified_Ideograph", "Ideographic"},
    198501: {"Unified_Ideograph", "Ideographic"},
    198502: {"Unified_Ideograph", "Ideographic"},
    198503: {"Unified_Ideograph", "Ideographic"},
    198504: {"Unified_Ideograph", "Ideographic"},
    198505: {"Unified_Ideograph", "Ideographic"},
    198506: {"Unified_Ideograph", "Ideographic"},
    198507: {"Unified_Ideograph", "Ideographic"},
    198508: {"Unified_Ideograph", "Ideographic"},
    198509: {"Unified_Ideograph", "Ideographic"},
    198510: {"Unified_Ideograph", "Ideographic"},
    198511: {"Unified_Ideograph", "Ideographic"},
    198512: {"Unified_Ideograph", "Ideographic"},
    198513: {"Unified_Ideograph", "Ideographic"},
    198514: {"Unified_Ideograph", "Ideographic"},
    198515: {"Unified_Ideograph", "Ideographic"},
    198516: {"Unified_Ideograph", "Ideographic"},
    198517: {"Unified_Ideograph", "Ideographic"},
    198518: {"Unified_Ideograph", "Ideographic"},
    198519: {"Unified_Ideograph", "Ideographic"},
    198520: {"Unified_Ideograph", "Ideographic"},
    198521: {"Unified_Ideograph", "Ideographic"},
    198522: {"Unified_Ideograph", "Ideographic"},
    198523: {"Unified_Ideograph", "Ideographic"},
    198524: {"Unified_Ideograph", "Ideographic"},
    198525: {"Unified_Ideograph", "Ideographic"},
    198526: {"Unified_Ideograph", "Ideographic"},
    198527: {"Unified_Ideograph", "Ideographic"},
    198528: {"Unified_Ideograph", "Ideographic"},
    198529: {"Unified_Ideograph", "Ideographic"},
    198530: {"Unified_Ideograph", "Ideographic"},
    198531: {"Unified_Ideograph", "Ideographic"},
    198532: {"Unified_Ideograph", "Ideographic"},
    198533: {"Unified_Ideograph", "Ideographic"},
    198534: {"Unified_Ideograph", "Ideographic"},
    198535: {"Unified_Ideograph", "Ideographic"},
    198536: {"Unified_Ideograph", "Ideographic"},
    198537: {"Unified_Ideograph", "Ideographic"},
    198538: {"Unified_Ideograph", "Ideographic"},
    198539: {"Unified_Ideograph", "Ideographic"},
    198540: {"Unified_Ideograph", "Ideographic"},
    198541: {"Unified_Ideograph", "Ideographic"},
    198542: {"Unified_Ideograph", "Ideographic"},
    198543: {"Unified_Ideograph", "Ideographic"},
    198544: {"Unified_Ideograph", "Ideographic"},
    198545: {"Unified_Ideograph", "Ideographic"},
    198546: {"Unified_Ideograph", "Ideographic"},
    198547: {"Unified_Ideograph", "Ideographic"},
    198548: {"Unified_Ideograph", "Ideographic"},
    198549: {"Unified_Ideograph", "Ideographic"},
    198550: {"Unified_Ideograph", "Ideographic"},
    198551: {"Unified_Ideograph", "Ideographic"},
    198552: {"Unified_Ideograph", "Ideographic"},
    198553: {"Unified_Ideograph", "Ideographic"},
    198554: {"Unified_Ideograph", "Ideographic"},
    198555: {"Unified_Ideograph", "Ideographic"},
    198556: {"Unified_Ideograph", "Ideographic"},
    198557: {"Unified_Ideograph", "Ideographic"},
    198558: {"Unified_Ideograph", "Ideographic"},
    198559: {"Unified_Ideograph", "Ideographic"},
    198560: {"Unified_Ideograph", "Ideographic"},
    198561: {"Unified_Ideograph", "Ideographic"},
    198562: {"Unified_Ideograph", "Ideographic"},
    198563: {"Unified_Ideograph", "Ideographic"},
    198564: {"Unified_Ideograph", "Ideographic"},
    198565: {"Unified_Ideograph", "Ideographic"},
    198566: {"Unified_Ideograph", "Ideographic"},
    198567: {"Unified_Ideograph", "Ideographic"},
    198568: {"Unified_Ideograph", "Ideographic"},
    198569: {"Unified_Ideograph", "Ideographic"},
    198570: {"Unified_Ideograph", "Ideographic"},
    198571: {"Unified_Ideograph", "Ideographic"},
    198572: {"Unified_Ideograph", "Ideographic"},
    198573: {"Unified_Ideograph", "Ideographic"},
    198574: {"Unified_Ideograph", "Ideographic"},
    198575: {"Unified_Ideograph", "Ideographic"},
    198576: {"Unified_Ideograph", "Ideographic"},
    198577: {"Unified_Ideograph", "Ideographic"},
    198578: {"Unified_Ideograph", "Ideographic"},
    198579: {"Unified_Ideograph", "Ideographic"},
    198580: {"Unified_Ideograph", "Ideographic"},
    198581: {"Unified_Ideograph", "Ideographic"},
    198582: {"Unified_Ideograph", "Ideographic"},
    198583: {"Unified_Ideograph", "Ideographic"},
    198584: {"Unified_Ideograph", "Ideographic"},
    198585: {"Unified_Ideograph", "Ideographic"},
    198586: {"Unified_Ideograph", "Ideographic"},
    198587: {"Unified_Ideograph", "Ideographic"},
    198588: {"Unified_Ideograph", "Ideographic"},
    198589: {"Unified_Ideograph", "Ideographic"},
    198590: {"Unified_Ideograph", "Ideographic"},
    198591: {"Unified_Ideograph", "Ideographic"},
    198592: {"Unified_Ideograph", "Ideographic"},
    198593: {"Unified_Ideograph", "Ideographic"},
    198594: {"Unified_Ideograph", "Ideographic"},
    198595: {"Unified_Ideograph", "Ideographic"},
    198596: {"Unified_Ideograph", "Ideographic"},
    198597: {"Unified_Ideograph", "Ideographic"},
    198598: {"Unified_Ideograph", "Ideographic"},
    198599: {"Unified_Ideograph", "Ideographic"},
    198600: {"Unified_Ideograph", "Ideographic"},
    198601: {"Unified_Ideograph", "Ideographic"},
    198602: {"Unified_Ideograph", "Ideographic"},
    198603: {"Unified_Ideograph", "Ideographic"},
    198604: {"Unified_Ideograph", "Ideographic"},
    198605: {"Unified_Ideograph", "Ideographic"},
    198606: {"Unified_Ideograph", "Ideographic"},
    198607: {"Unified_Ideograph", "Ideographic"},
    198608: {"Unified_Ideograph", "Ideographic"},
    198609: {"Unified_Ideograph", "Ideographic"},
    198610: {"Unified_Ideograph", "Ideographic"},
    198611: {"Unified_Ideograph", "Ideographic"},
    198612: {"Unified_Ideograph", "Ideographic"},
    198613: {"Unified_Ideograph", "Ideographic"},
    198614: {"Unified_Ideograph", "Ideographic"},
    198615: {"Unified_Ideograph", "Ideographic"},
    198616: {"Unified_Ideograph", "Ideographic"},
    198617: {"Unified_Ideograph", "Ideographic"},
    198618: {"Unified_Ideograph", "Ideographic"},
    198619: {"Unified_Ideograph", "Ideographic"},
    198620: {"Unified_Ideograph", "Ideographic"},
    198621: {"Unified_Ideograph", "Ideographic"},
    198622: {"Unified_Ideograph", "Ideographic"},
    198623: {"Unified_Ideograph", "Ideographic"},
    198624: {"Unified_Ideograph", "Ideographic"},
    198625: {"Unified_Ideograph", "Ideographic"},
    198626: {"Unified_Ideograph", "Ideographic"},
    198627: {"Unified_Ideograph", "Ideographic"},
    198628: {"Unified_Ideograph", "Ideographic"},
    198629: {"Unified_Ideograph", "Ideographic"},
    198630: {"Unified_Ideograph", "Ideographic"},
    198631: {"Unified_Ideograph", "Ideographic"},
    198632: {"Unified_Ideograph", "Ideographic"},
    198633: {"Unified_Ideograph", "Ideographic"},
    198634: {"Unified_Ideograph", "Ideographic"},
    198635: {"Unified_Ideograph", "Ideographic"},
    198636: {"Unified_Ideograph", "Ideographic"},
    198637: {"Unified_Ideograph", "Ideographic"},
    198638: {"Unified_Ideograph", "Ideographic"},
    198639: {"Unified_Ideograph", "Ideographic"},
    198640: {"Unified_Ideograph", "Ideographic"},
    198641: {"Unified_Ideograph", "Ideographic"},
    198642: {"Unified_Ideograph", "Ideographic"},
    198643: {"Unified_Ideograph", "Ideographic"},
    198644: {"Unified_Ideograph", "Ideographic"},
    198645: {"Unified_Ideograph", "Ideographic"},
    198646: {"Unified_Ideograph", "Ideographic"},
    198647: {"Unified_Ideograph", "Ideographic"},
    198648: {"Unified_Ideograph", "Ideographic"},
    198649: {"Unified_Ideograph", "Ideographic"},
    198650: {"Unified_Ideograph", "Ideographic"},
    198651: {"Unified_Ideograph", "Ideographic"},
    198652: {"Unified_Ideograph", "Ideographic"},
    198653: {"Unified_Ideograph", "Ideographic"},
    198654: {"Unified_Ideograph", "Ideographic"},
    198655: {"Unified_Ideograph", "Ideographic"},
    198656: {"Unified_Ideograph", "Ideographic"},
    198657: {"Unified_Ideograph", "Ideographic"},
    198658: {"Unified_Ideograph", "Ideographic"},
    198659: {"Unified_Ideograph", "Ideographic"},
    198660: {"Unified_Ideograph", "Ideographic"},
    198661: {"Unified_Ideograph", "Ideographic"},
    198662: {"Unified_Ideograph", "Ideographic"},
    198663: {"Unified_Ideograph", "Ideographic"},
    198664: {"Unified_Ideograph", "Ideographic"},
    198665: {"Unified_Ideograph", "Ideographic"},
    198666: {"Unified_Ideograph", "Ideographic"},
    198667: {"Unified_Ideograph", "Ideographic"},
    198668: {"Unified_Ideograph", "Ideographic"},
    198669: {"Unified_Ideograph", "Ideographic"},
    198670: {"Unified_Ideograph", "Ideographic"},
    198671: {"Unified_Ideograph", "Ideographic"},
    198672: {"Unified_Ideograph", "Ideographic"},
    198673: {"Unified_Ideograph", "Ideographic"},
    198674: {"Unified_Ideograph", "Ideographic"},
    198675: {"Unified_Ideograph", "Ideographic"},
    198676: {"Unified_Ideograph", "Ideographic"},
    198677: {"Unified_Ideograph", "Ideographic"},
    198678: {"Unified_Ideograph", "Ideographic"},
    198679: {"Unified_Ideograph", "Ideographic"},
    198680: {"Unified_Ideograph", "Ideographic"},
    198681: {"Unified_Ideograph", "Ideographic"},
    198682: {"Unified_Ideograph", "Ideographic"},
    198683: {"Unified_Ideograph", "Ideographic"},
    198684: {"Unified_Ideograph", "Ideographic"},
    198685: {"Unified_Ideograph", "Ideographic"},
    198686: {"Unified_Ideograph", "Ideographic"},
    198687: {"Unified_Ideograph", "Ideographic"},
    198688: {"Unified_Ideograph", "Ideographic"},
    198689: {"Unified_Ideograph", "Ideographic"},
    198690: {"Unified_Ideograph", "Ideographic"},
    198691: {"Unified_Ideograph", "Ideographic"},
    198692: {"Unified_Ideograph", "Ideographic"},
    198693: {"Unified_Ideograph", "Ideographic"},
    198694: {"Unified_Ideograph", "Ideographic"},
    198695: {"Unified_Ideograph", "Ideographic"},
    198696: {"Unified_Ideograph", "Ideographic"},
    198697: {"Unified_Ideograph", "Ideographic"},
    198698: {"Unified_Ideograph", "Ideographic"},
    198699: {"Unified_Ideograph", "Ideographic"},
    198700: {"Unified_Ideograph", "Ideographic"},
    198701: {"Unified_Ideograph", "Ideographic"},
    198702: {"Unified_Ideograph", "Ideographic"},
    198703: {"Unified_Ideograph", "Ideographic"},
    198704: {"Unified_Ideograph", "Ideographic"},
    198705: {"Unified_Ideograph", "Ideographic"},
    198706: {"Unified_Ideograph", "Ideographic"},
    198707: {"Unified_Ideograph", "Ideographic"},
    198708: {"Unified_Ideograph", "Ideographic"},
    198709: {"Unified_Ideograph", "Ideographic"},
    198710: {"Unified_Ideograph", "Ideographic"},
    198711: {"Unified_Ideograph", "Ideographic"},
    198712: {"Unified_Ideograph", "Ideographic"},
    198713: {"Unified_Ideograph", "Ideographic"},
    198714: {"Unified_Ideograph", "Ideographic"},
    198715: {"Unified_Ideograph", "Ideographic"},
    198716: {"Unified_Ideograph", "Ideographic"},
    198717: {"Unified_Ideograph", "Ideographic"},
    198718: {"Unified_Ideograph", "Ideographic"},
    198719: {"Unified_Ideograph", "Ideographic"},
    198720: {"Unified_Ideograph", "Ideographic"},
    198721: {"Unified_Ideograph", "Ideographic"},
    198722: {"Unified_Ideograph", "Ideographic"},
    198723: {"Unified_Ideograph", "Ideographic"},
    198724: {"Unified_Ideograph", "Ideographic"},
    198725: {"Unified_Ideograph", "Ideographic"},
    198726: {"Unified_Ideograph", "Ideographic"},
    198727: {"Unified_Ideograph", "Ideographic"},
    198728: {"Unified_Ideograph", "Ideographic"},
    198729: {"Unified_Ideograph", "Ideographic"},
    198730: {"Unified_Ideograph", "Ideographic"},
    198731: {"Unified_Ideograph", "Ideographic"},
    198732: {"Unified_Ideograph", "Ideographic"},
    198733: {"Unified_Ideograph", "Ideographic"},
    198734: {"Unified_Ideograph", "Ideographic"},
    198735: {"Unified_Ideograph", "Ideographic"},
    198736: {"Unified_Ideograph", "Ideographic"},
    198737: {"Unified_Ideograph", "Ideographic"},
    198738: {"Unified_Ideograph", "Ideographic"},
    198739: {"Unified_Ideograph", "Ideographic"},
    198740: {"Unified_Ideograph", "Ideographic"},
    198741: {"Unified_Ideograph", "Ideographic"},
    198742: {"Unified_Ideograph", "Ideographic"},
    198743: {"Unified_Ideograph", "Ideographic"},
    198744: {"Unified_Ideograph", "Ideographic"},
    198745: {"Unified_Ideograph", "Ideographic"},
    198746: {"Unified_Ideograph", "Ideographic"},
    198747: {"Unified_Ideograph", "Ideographic"},
    198748: {"Unified_Ideograph", "Ideographic"},
    198749: {"Unified_Ideograph", "Ideographic"},
    198750: {"Unified_Ideograph", "Ideographic"},
    198751: {"Unified_Ideograph", "Ideographic"},
    198752: {"Unified_Ideograph", "Ideographic"},
    198753: {"Unified_Ideograph", "Ideographic"},
    198754: {"Unified_Ideograph", "Ideographic"},
    198755: {"Unified_Ideograph", "Ideographic"},
    198756: {"Unified_Ideograph", "Ideographic"},
    198757: {"Unified_Ideograph", "Ideographic"},
    198758: {"Unified_Ideograph", "Ideographic"},
    198759: {"Unified_Ideograph", "Ideographic"},
    198760: {"Unified_Ideograph", "Ideographic"},
    198761: {"Unified_Ideograph", "Ideographic"},
    198762: {"Unified_Ideograph", "Ideographic"},
    198763: {"Unified_Ideograph", "Ideographic"},
    198764: {"Unified_Ideograph", "Ideographic"},
    198765: {"Unified_Ideograph", "Ideographic"},
    198766: {"Unified_Ideograph", "Ideographic"},
    198767: {"Unified_Ideograph", "Ideographic"},
    198768: {"Unified_Ideograph", "Ideographic"},
    198769: {"Unified_Ideograph", "Ideographic"},
    198770: {"Unified_Ideograph", "Ideographic"},
    198771: {"Unified_Ideograph", "Ideographic"},
    198772: {"Unified_Ideograph", "Ideographic"},
    198773: {"Unified_Ideograph", "Ideographic"},
    198774: {"Unified_Ideograph", "Ideographic"},
    198775: {"Unified_Ideograph", "Ideographic"},
    198776: {"Unified_Ideograph", "Ideographic"},
    198777: {"Unified_Ideograph", "Ideographic"},
    198778: {"Unified_Ideograph", "Ideographic"},
    198779: {"Unified_Ideograph", "Ideographic"},
    198780: {"Unified_Ideograph", "Ideographic"},
    198781: {"Unified_Ideograph", "Ideographic"},
    198782: {"Unified_Ideograph", "Ideographic"},
    198783: {"Unified_Ideograph", "Ideographic"},
    198784: {"Unified_Ideograph", "Ideographic"},
    198785: {"Unified_Ideograph", "Ideographic"},
    198786: {"Unified_Ideograph", "Ideographic"},
    198787: {"Unified_Ideograph", "Ideographic"},
    198788: {"Unified_Ideograph", "Ideographic"},
    198789: {"Unified_Ideograph", "Ideographic"},
    198790: {"Unified_Ideograph", "Ideographic"},
    198791: {"Unified_Ideograph", "Ideographic"},
    198792: {"Unified_Ideograph", "Ideographic"},
    198793: {"Unified_Ideograph", "Ideographic"},
    198794: {"Unified_Ideograph", "Ideographic"},
    198795: {"Unified_Ideograph", "Ideographic"},
    198796: {"Unified_Ideograph", "Ideographic"},
    198797: {"Unified_Ideograph", "Ideographic"},
    198798: {"Unified_Ideograph", "Ideographic"},
    198799: {"Unified_Ideograph", "Ideographic"},
    198800: {"Unified_Ideograph", "Ideographic"},
    198801: {"Unified_Ideograph", "Ideographic"},
    198802: {"Unified_Ideograph", "Ideographic"},
    198803: {"Unified_Ideograph", "Ideographic"},
    198804: {"Unified_Ideograph", "Ideographic"},
    198805: {"Unified_Ideograph", "Ideographic"},
    198806: {"Unified_Ideograph", "Ideographic"},
    198807: {"Unified_Ideograph", "Ideographic"},
    198808: {"Unified_Ideograph", "Ideographic"},
    198809: {"Unified_Ideograph", "Ideographic"},
    198810: {"Unified_Ideograph", "Ideographic"},
    198811: {"Unified_Ideograph", "Ideographic"},
    198812: {"Unified_Ideograph", "Ideographic"},
    198813: {"Unified_Ideograph", "Ideographic"},
    198814: {"Unified_Ideograph", "Ideographic"},
    198815: {"Unified_Ideograph", "Ideographic"},
    198816: {"Unified_Ideograph", "Ideographic"},
    198817: {"Unified_Ideograph", "Ideographic"},
    198818: {"Unified_Ideograph", "Ideographic"},
    198819: {"Unified_Ideograph", "Ideographic"},
    198820: {"Unified_Ideograph", "Ideographic"},
    198821: {"Unified_Ideograph", "Ideographic"},
    198822: {"Unified_Ideograph", "Ideographic"},
    198823: {"Unified_Ideograph", "Ideographic"},
    198824: {"Unified_Ideograph", "Ideographic"},
    198825: {"Unified_Ideograph", "Ideographic"},
    198826: {"Unified_Ideograph", "Ideographic"},
    198827: {"Unified_Ideograph", "Ideographic"},
    198828: {"Unified_Ideograph", "Ideographic"},
    198829: {"Unified_Ideograph", "Ideographic"},
    198830: {"Unified_Ideograph", "Ideographic"},
    198831: {"Unified_Ideograph", "Ideographic"},
    198832: {"Unified_Ideograph", "Ideographic"},
    198833: {"Unified_Ideograph", "Ideographic"},
    198834: {"Unified_Ideograph", "Ideographic"},
    198835: {"Unified_Ideograph", "Ideographic"},
    198836: {"Unified_Ideograph", "Ideographic"},
    198837: {"Unified_Ideograph", "Ideographic"},
    198838: {"Unified_Ideograph", "Ideographic"},
    198839: {"Unified_Ideograph", "Ideographic"},
    198840: {"Unified_Ideograph", "Ideographic"},
    198841: {"Unified_Ideograph", "Ideographic"},
    198842: {"Unified_Ideograph", "Ideographic"},
    198843: {"Unified_Ideograph", "Ideographic"},
    198844: {"Unified_Ideograph", "Ideographic"},
    198845: {"Unified_Ideograph", "Ideographic"},
    198846: {"Unified_Ideograph", "Ideographic"},
    198847: {"Unified_Ideograph", "Ideographic"},
    198848: {"Unified_Ideograph", "Ideographic"},
    198849: {"Unified_Ideograph", "Ideographic"},
    198850: {"Unified_Ideograph", "Ideographic"},
    198851: {"Unified_Ideograph", "Ideographic"},
    198852: {"Unified_Ideograph", "Ideographic"},
    198853: {"Unified_Ideograph", "Ideographic"},
    198854: {"Unified_Ideograph", "Ideographic"},
    198855: {"Unified_Ideograph", "Ideographic"},
    198856: {"Unified_Ideograph", "Ideographic"},
    198857: {"Unified_Ideograph", "Ideographic"},
    198858: {"Unified_Ideograph", "Ideographic"},
    198859: {"Unified_Ideograph", "Ideographic"},
    198860: {"Unified_Ideograph", "Ideographic"},
    198861: {"Unified_Ideograph", "Ideographic"},
    198862: {"Unified_Ideograph", "Ideographic"},
    198863: {"Unified_Ideograph", "Ideographic"},
    198864: {"Unified_Ideograph", "Ideographic"},
    198865: {"Unified_Ideograph", "Ideographic"},
    198866: {"Unified_Ideograph", "Ideographic"},
    198867: {"Unified_Ideograph", "Ideographic"},
    198868: {"Unified_Ideograph", "Ideographic"},
    198869: {"Unified_Ideograph", "Ideographic"},
    198870: {"Unified_Ideograph", "Ideographic"},
    198871: {"Unified_Ideograph", "Ideographic"},
    198872: {"Unified_Ideograph", "Ideographic"},
    198873: {"Unified_Ideograph", "Ideographic"},
    198874: {"Unified_Ideograph", "Ideographic"},
    198875: {"Unified_Ideograph", "Ideographic"},
    198876: {"Unified_Ideograph", "Ideographic"},
    198877: {"Unified_Ideograph", "Ideographic"},
    198878: {"Unified_Ideograph", "Ideographic"},
    198879: {"Unified_Ideograph", "Ideographic"},
    198880: {"Unified_Ideograph", "Ideographic"},
    198881: {"Unified_Ideograph", "Ideographic"},
    198882: {"Unified_Ideograph", "Ideographic"},
    198883: {"Unified_Ideograph", "Ideographic"},
    198884: {"Unified_Ideograph", "Ideographic"},
    198885: {"Unified_Ideograph", "Ideographic"},
    198886: {"Unified_Ideograph", "Ideographic"},
    198887: {"Unified_Ideograph", "Ideographic"},
    198888: {"Unified_Ideograph", "Ideographic"},
    198889: {"Unified_Ideograph", "Ideographic"},
    198890: {"Unified_Ideograph", "Ideographic"},
    198891: {"Unified_Ideograph", "Ideographic"},
    198892: {"Unified_Ideograph", "Ideographic"},
    198893: {"Unified_Ideograph", "Ideographic"},
    198894: {"Unified_Ideograph", "Ideographic"},
    198895: {"Unified_Ideograph", "Ideographic"},
    198896: {"Unified_Ideograph", "Ideographic"},
    198897: {"Unified_Ideograph", "Ideographic"},
    198898: {"Unified_Ideograph", "Ideographic"},
    198899: {"Unified_Ideograph", "Ideographic"},
    198900: {"Unified_Ideograph", "Ideographic"},
    198901: {"Unified_Ideograph", "Ideographic"},
    198902: {"Unified_Ideograph", "Ideographic"},
    198903: {"Unified_Ideograph", "Ideographic"},
    198904: {"Unified_Ideograph", "Ideographic"},
    198905: {"Unified_Ideograph", "Ideographic"},
    198906: {"Unified_Ideograph", "Ideographic"},
    198907: {"Unified_Ideograph", "Ideographic"},
    198908: {"Unified_Ideograph", "Ideographic"},
    198909: {"Unified_Ideograph", "Ideographic"},
    198910: {"Unified_Ideograph", "Ideographic"},
    198911: {"Unified_Ideograph", "Ideographic"},
    198912: {"Unified_Ideograph", "Ideographic"},
    198913: {"Unified_Ideograph", "Ideographic"},
    198914: {"Unified_Ideograph", "Ideographic"},
    198915: {"Unified_Ideograph", "Ideographic"},
    198916: {"Unified_Ideograph", "Ideographic"},
    198917: {"Unified_Ideograph", "Ideographic"},
    198918: {"Unified_Ideograph", "Ideographic"},
    198919: {"Unified_Ideograph", "Ideographic"},
    198920: {"Unified_Ideograph", "Ideographic"},
    198921: {"Unified_Ideograph", "Ideographic"},
    198922: {"Unified_Ideograph", "Ideographic"},
    198923: {"Unified_Ideograph", "Ideographic"},
    198924: {"Unified_Ideograph", "Ideographic"},
    198925: {"Unified_Ideograph", "Ideographic"},
    198926: {"Unified_Ideograph", "Ideographic"},
    198927: {"Unified_Ideograph", "Ideographic"},
    198928: {"Unified_Ideograph", "Ideographic"},
    198929: {"Unified_Ideograph", "Ideographic"},
    198930: {"Unified_Ideograph", "Ideographic"},
    198931: {"Unified_Ideograph", "Ideographic"},
    198932: {"Unified_Ideograph", "Ideographic"},
    198933: {"Unified_Ideograph", "Ideographic"},
    198934: {"Unified_Ideograph", "Ideographic"},
    198935: {"Unified_Ideograph", "Ideographic"},
    198936: {"Unified_Ideograph", "Ideographic"},
    198937: {"Unified_Ideograph", "Ideographic"},
    198938: {"Unified_Ideograph", "Ideographic"},
    198939: {"Unified_Ideograph", "Ideographic"},
    198940: {"Unified_Ideograph", "Ideographic"},
    198941: {"Unified_Ideograph", "Ideographic"},
    198942: {"Unified_Ideograph", "Ideographic"},
    198943: {"Unified_Ideograph", "Ideographic"},
    198944: {"Unified_Ideograph", "Ideographic"},
    198945: {"Unified_Ideograph", "Ideographic"},
    198946: {"Unified_Ideograph", "Ideographic"},
    198947: {"Unified_Ideograph", "Ideographic"},
    198948: {"Unified_Ideograph", "Ideographic"},
    198949: {"Unified_Ideograph", "Ideographic"},
    198950: {"Unified_Ideograph", "Ideographic"},
    198951: {"Unified_Ideograph", "Ideographic"},
    198952: {"Unified_Ideograph", "Ideographic"},
    198953: {"Unified_Ideograph", "Ideographic"},
    198954: {"Unified_Ideograph", "Ideographic"},
    198955: {"Unified_Ideograph", "Ideographic"},
    198956: {"Unified_Ideograph", "Ideographic"},
    198957: {"Unified_Ideograph", "Ideographic"},
    198958: {"Unified_Ideograph", "Ideographic"},
    198959: {"Unified_Ideograph", "Ideographic"},
    198960: {"Unified_Ideograph", "Ideographic"},
    198961: {"Unified_Ideograph", "Ideographic"},
    198962: {"Unified_Ideograph", "Ideographic"},
    198963: {"Unified_Ideograph", "Ideographic"},
    198964: {"Unified_Ideograph", "Ideographic"},
    198965: {"Unified_Ideograph", "Ideographic"},
    198966: {"Unified_Ideograph", "Ideographic"},
    198967: {"Unified_Ideograph", "Ideographic"},
    198968: {"Unified_Ideograph", "Ideographic"},
    198969: {"Unified_Ideograph", "Ideographic"},
    198970: {"Unified_Ideograph", "Ideographic"},
    198971: {"Unified_Ideograph", "Ideographic"},
    198972: {"Unified_Ideograph", "Ideographic"},
    198973: {"Unified_Ideograph", "Ideographic"},
    198974: {"Unified_Ideograph", "Ideographic"},
    198975: {"Unified_Ideograph", "Ideographic"},
    198976: {"Unified_Ideograph", "Ideographic"},
    198977: {"Unified_Ideograph", "Ideographic"},
    198978: {"Unified_Ideograph", "Ideographic"},
    198979: {"Unified_Ideograph", "Ideographic"},
    198980: {"Unified_Ideograph", "Ideographic"},
    198981: {"Unified_Ideograph", "Ideographic"},
    198982: {"Unified_Ideograph", "Ideographic"},
    198983: {"Unified_Ideograph", "Ideographic"},
    198984: {"Unified_Ideograph", "Ideographic"},
    198985: {"Unified_Ideograph", "Ideographic"},
    198986: {"Unified_Ideograph", "Ideographic"},
    198987: {"Unified_Ideograph", "Ideographic"},
    198988: {"Unified_Ideograph", "Ideographic"},
    198989: {"Unified_Ideograph", "Ideographic"},
    198990: {"Unified_Ideograph", "Ideographic"},
    198991: {"Unified_Ideograph", "Ideographic"},
    198992: {"Unified_Ideograph", "Ideographic"},
    198993: {"Unified_Ideograph", "Ideographic"},
    198994: {"Unified_Ideograph", "Ideographic"},
    198995: {"Unified_Ideograph", "Ideographic"},
    198996: {"Unified_Ideograph", "Ideographic"},
    198997: {"Unified_Ideograph", "Ideographic"},
    198998: {"Unified_Ideograph", "Ideographic"},
    198999: {"Unified_Ideograph", "Ideographic"},
    199000: {"Unified_Ideograph", "Ideographic"},
    199001: {"Unified_Ideograph", "Ideographic"},
    199002: {"Unified_Ideograph", "Ideographic"},
    199003: {"Unified_Ideograph", "Ideographic"},
    199004: {"Unified_Ideograph", "Ideographic"},
    199005: {"Unified_Ideograph", "Ideographic"},
    199006: {"Unified_Ideograph", "Ideographic"},
    199007: {"Unified_Ideograph", "Ideographic"},
    199008: {"Unified_Ideograph", "Ideographic"},
    199009: {"Unified_Ideograph", "Ideographic"},
    199010: {"Unified_Ideograph", "Ideographic"},
    199011: {"Unified_Ideograph", "Ideographic"},
    199012: {"Unified_Ideograph", "Ideographic"},
    199013: {"Unified_Ideograph", "Ideographic"},
    199014: {"Unified_Ideograph", "Ideographic"},
    199015: {"Unified_Ideograph", "Ideographic"},
    199016: {"Unified_Ideograph", "Ideographic"},
    199017: {"Unified_Ideograph", "Ideographic"},
    199018: {"Unified_Ideograph", "Ideographic"},
    199019: {"Unified_Ideograph", "Ideographic"},
    199020: {"Unified_Ideograph", "Ideographic"},
    199021: {"Unified_Ideograph", "Ideographic"},
    199022: {"Unified_Ideograph", "Ideographic"},
    199023: {"Unified_Ideograph", "Ideographic"},
    199024: {"Unified_Ideograph", "Ideographic"},
    199025: {"Unified_Ideograph", "Ideographic"},
    199026: {"Unified_Ideograph", "Ideographic"},
    199027: {"Unified_Ideograph", "Ideographic"},
    199028: {"Unified_Ideograph", "Ideographic"},
    199029: {"Unified_Ideograph", "Ideographic"},
    199030: {"Unified_Ideograph", "Ideographic"},
    199031: {"Unified_Ideograph", "Ideographic"},
    199032: {"Unified_Ideograph", "Ideographic"},
    199033: {"Unified_Ideograph", "Ideographic"},
    199034: {"Unified_Ideograph", "Ideographic"},
    199035: {"Unified_Ideograph", "Ideographic"},
    199036: {"Unified_Ideograph", "Ideographic"},
    199037: {"Unified_Ideograph", "Ideographic"},
    199038: {"Unified_Ideograph", "Ideographic"},
    199039: {"Unified_Ideograph", "Ideographic"},
    199040: {"Unified_Ideograph", "Ideographic"},
    199041: {"Unified_Ideograph", "Ideographic"},
    199042: {"Unified_Ideograph", "Ideographic"},
    199043: {"Unified_Ideograph", "Ideographic"},
    199044: {"Unified_Ideograph", "Ideographic"},
    199045: {"Unified_Ideograph", "Ideographic"},
    199046: {"Unified_Ideograph", "Ideographic"},
    199047: {"Unified_Ideograph", "Ideographic"},
    199048: {"Unified_Ideograph", "Ideographic"},
    199049: {"Unified_Ideograph", "Ideographic"},
    199050: {"Unified_Ideograph", "Ideographic"},
    199051: {"Unified_Ideograph", "Ideographic"},
    199052: {"Unified_Ideograph", "Ideographic"},
    199053: {"Unified_Ideograph", "Ideographic"},
    199054: {"Unified_Ideograph", "Ideographic"},
    199055: {"Unified_Ideograph", "Ideographic"},
    199056: {"Unified_Ideograph", "Ideographic"},
    199057: {"Unified_Ideograph", "Ideographic"},
    199058: {"Unified_Ideograph", "Ideographic"},
    199059: {"Unified_Ideograph", "Ideographic"},
    199060: {"Unified_Ideograph", "Ideographic"},
    199061: {"Unified_Ideograph", "Ideographic"},
    199062: {"Unified_Ideograph", "Ideographic"},
    199063: {"Unified_Ideograph", "Ideographic"},
    199064: {"Unified_Ideograph", "Ideographic"},
    199065: {"Unified_Ideograph", "Ideographic"},
    199066: {"Unified_Ideograph", "Ideographic"},
    199067: {"Unified_Ideograph", "Ideographic"},
    199068: {"Unified_Ideograph", "Ideographic"},
    199069: {"Unified_Ideograph", "Ideographic"},
    199070: {"Unified_Ideograph", "Ideographic"},
    199071: {"Unified_Ideograph", "Ideographic"},
    199072: {"Unified_Ideograph", "Ideographic"},
    199073: {"Unified_Ideograph", "Ideographic"},
    199074: {"Unified_Ideograph", "Ideographic"},
    199075: {"Unified_Ideograph", "Ideographic"},
    199076: {"Unified_Ideograph", "Ideographic"},
    199077: {"Unified_Ideograph", "Ideographic"},
    199078: {"Unified_Ideograph", "Ideographic"},
    199079: {"Unified_Ideograph", "Ideographic"},
    199080: {"Unified_Ideograph", "Ideographic"},
    199081: {"Unified_Ideograph", "Ideographic"},
    199082: {"Unified_Ideograph", "Ideographic"},
    199083: {"Unified_Ideograph", "Ideographic"},
    199084: {"Unified_Ideograph", "Ideographic"},
    199085: {"Unified_Ideograph", "Ideographic"},
    199086: {"Unified_Ideograph", "Ideographic"},
    199087: {"Unified_Ideograph", "Ideographic"},
    199088: {"Unified_Ideograph", "Ideographic"},
    199089: {"Unified_Ideograph", "Ideographic"},
    199090: {"Unified_Ideograph", "Ideographic"},
    199091: {"Unified_Ideograph", "Ideographic"},
    199092: {"Unified_Ideograph", "Ideographic"},
    199093: {"Unified_Ideograph", "Ideographic"},
    199094: {"Unified_Ideograph", "Ideographic"},
    199095: {"Unified_Ideograph", "Ideographic"},
    199096: {"Unified_Ideograph", "Ideographic"},
    199097: {"Unified_Ideograph", "Ideographic"},
    199098: {"Unified_Ideograph", "Ideographic"},
    199099: {"Unified_Ideograph", "Ideographic"},
    199100: {"Unified_Ideograph", "Ideographic"},
    199101: {"Unified_Ideograph", "Ideographic"},
    199102: {"Unified_Ideograph", "Ideographic"},
    199103: {"Unified_Ideograph", "Ideographic"},
    199104: {"Unified_Ideograph", "Ideographic"},
    199105: {"Unified_Ideograph", "Ideographic"},
    199106: {"Unified_Ideograph", "Ideographic"},
    199107: {"Unified_Ideograph", "Ideographic"},
    199108: {"Unified_Ideograph", "Ideographic"},
    199109: {"Unified_Ideograph", "Ideographic"},
    199110: {"Unified_Ideograph", "Ideographic"},
    199111: {"Unified_Ideograph", "Ideographic"},
    199112: {"Unified_Ideograph", "Ideographic"},
    199113: {"Unified_Ideograph", "Ideographic"},
    199114: {"Unified_Ideograph", "Ideographic"},
    199115: {"Unified_Ideograph", "Ideographic"},
    199116: {"Unified_Ideograph", "Ideographic"},
    199117: {"Unified_Ideograph", "Ideographic"},
    199118: {"Unified_Ideograph", "Ideographic"},
    199119: {"Unified_Ideograph", "Ideographic"},
    199120: {"Unified_Ideograph", "Ideographic"},
    199121: {"Unified_Ideograph", "Ideographic"},
    199122: {"Unified_Ideograph", "Ideographic"},
    199123: {"Unified_Ideograph", "Ideographic"},
    199124: {"Unified_Ideograph", "Ideographic"},
    199125: {"Unified_Ideograph", "Ideographic"},
    199126: {"Unified_Ideograph", "Ideographic"},
    199127: {"Unified_Ideograph", "Ideographic"},
    199128: {"Unified_Ideograph", "Ideographic"},
    199129: {"Unified_Ideograph", "Ideographic"},
    199130: {"Unified_Ideograph", "Ideographic"},
    199131: {"Unified_Ideograph", "Ideographic"},
    199132: {"Unified_Ideograph", "Ideographic"},
    199133: {"Unified_Ideograph", "Ideographic"},
    199134: {"Unified_Ideograph", "Ideographic"},
    199135: {"Unified_Ideograph", "Ideographic"},
    199136: {"Unified_Ideograph", "Ideographic"},
    199137: {"Unified_Ideograph", "Ideographic"},
    199138: {"Unified_Ideograph", "Ideographic"},
    199139: {"Unified_Ideograph", "Ideographic"},
    199140: {"Unified_Ideograph", "Ideographic"},
    199141: {"Unified_Ideograph", "Ideographic"},
    199142: {"Unified_Ideograph", "Ideographic"},
    199143: {"Unified_Ideograph", "Ideographic"},
    199144: {"Unified_Ideograph", "Ideographic"},
    199145: {"Unified_Ideograph", "Ideographic"},
    199146: {"Unified_Ideograph", "Ideographic"},
    199147: {"Unified_Ideograph", "Ideographic"},
    199148: {"Unified_Ideograph", "Ideographic"},
    199149: {"Unified_Ideograph", "Ideographic"},
    199150: {"Unified_Ideograph", "Ideographic"},
    199151: {"Unified_Ideograph", "Ideographic"},
    199152: {"Unified_Ideograph", "Ideographic"},
    199153: {"Unified_Ideograph", "Ideographic"},
    199154: {"Unified_Ideograph", "Ideographic"},
    199155: {"Unified_Ideograph", "Ideographic"},
    199156: {"Unified_Ideograph", "Ideographic"},
    199157: {"Unified_Ideograph", "Ideographic"},
    199158: {"Unified_Ideograph", "Ideographic"},
    199159: {"Unified_Ideograph", "Ideographic"},
    199160: {"Unified_Ideograph", "Ideographic"},
    199161: {"Unified_Ideograph", "Ideographic"},
    199162: {"Unified_Ideograph", "Ideographic"},
    199163: {"Unified_Ideograph", "Ideographic"},
    199164: {"Unified_Ideograph", "Ideographic"},
    199165: {"Unified_Ideograph", "Ideographic"},
    199166: {"Unified_Ideograph", "Ideographic"},
    199167: {"Unified_Ideograph", "Ideographic"},
    199168: {"Unified_Ideograph", "Ideographic"},
    199169: {"Unified_Ideograph", "Ideographic"},
    199170: {"Unified_Ideograph", "Ideographic"},
    199171: {"Unified_Ideograph", "Ideographic"},
    199172: {"Unified_Ideograph", "Ideographic"},
    199173: {"Unified_Ideograph", "Ideographic"},
    199174: {"Unified_Ideograph", "Ideographic"},
    199175: {"Unified_Ideograph", "Ideographic"},
    199176: {"Unified_Ideograph", "Ideographic"},
    199177: {"Unified_Ideograph", "Ideographic"},
    199178: {"Unified_Ideograph", "Ideographic"},
    199179: {"Unified_Ideograph", "Ideographic"},
    199180: {"Unified_Ideograph", "Ideographic"},
    199181: {"Unified_Ideograph", "Ideographic"},
    199182: {"Unified_Ideograph", "Ideographic"},
    199183: {"Unified_Ideograph", "Ideographic"},
    199184: {"Unified_Ideograph", "Ideographic"},
    199185: {"Unified_Ideograph", "Ideographic"},
    199186: {"Unified_Ideograph", "Ideographic"},
    199187: {"Unified_Ideograph", "Ideographic"},
    199188: {"Unified_Ideograph", "Ideographic"},
    199189: {"Unified_Ideograph", "Ideographic"},
    199190: {"Unified_Ideograph", "Ideographic"},
    199191: {"Unified_Ideograph", "Ideographic"},
    199192: {"Unified_Ideograph", "Ideographic"},
    199193: {"Unified_Ideograph", "Ideographic"},
    199194: {"Unified_Ideograph", "Ideographic"},
    199195: {"Unified_Ideograph", "Ideographic"},
    199196: {"Unified_Ideograph", "Ideographic"},
    199197: {"Unified_Ideograph", "Ideographic"},
    199198: {"Unified_Ideograph", "Ideographic"},
    199199: {"Unified_Ideograph", "Ideographic"},
    199200: {"Unified_Ideograph", "Ideographic"},
    199201: {"Unified_Ideograph", "Ideographic"},
    199202: {"Unified_Ideograph", "Ideographic"},
    199203: {"Unified_Ideograph", "Ideographic"},
    199204: {"Unified_Ideograph", "Ideographic"},
    199205: {"Unified_Ideograph", "Ideographic"},
    199206: {"Unified_Ideograph", "Ideographic"},
    199207: {"Unified_Ideograph", "Ideographic"},
    199208: {"Unified_Ideograph", "Ideographic"},
    199209: {"Unified_Ideograph", "Ideographic"},
    199210: {"Unified_Ideograph", "Ideographic"},
    199211: {"Unified_Ideograph", "Ideographic"},
    199212: {"Unified_Ideograph", "Ideographic"},
    199213: {"Unified_Ideograph", "Ideographic"},
    199214: {"Unified_Ideograph", "Ideographic"},
    199215: {"Unified_Ideograph", "Ideographic"},
    199216: {"Unified_Ideograph", "Ideographic"},
    199217: {"Unified_Ideograph", "Ideographic"},
    199218: {"Unified_Ideograph", "Ideographic"},
    199219: {"Unified_Ideograph", "Ideographic"},
    199220: {"Unified_Ideograph", "Ideographic"},
    199221: {"Unified_Ideograph", "Ideographic"},
    199222: {"Unified_Ideograph", "Ideographic"},
    199223: {"Unified_Ideograph", "Ideographic"},
    199224: {"Unified_Ideograph", "Ideographic"},
    199225: {"Unified_Ideograph", "Ideographic"},
    199226: {"Unified_Ideograph", "Ideographic"},
    199227: {"Unified_Ideograph", "Ideographic"},
    199228: {"Unified_Ideograph", "Ideographic"},
    199229: {"Unified_Ideograph", "Ideographic"},
    199230: {"Unified_Ideograph", "Ideographic"},
    199231: {"Unified_Ideograph", "Ideographic"},
    199232: {"Unified_Ideograph", "Ideographic"},
    199233: {"Unified_Ideograph", "Ideographic"},
    199234: {"Unified_Ideograph", "Ideographic"},
    199235: {"Unified_Ideograph", "Ideographic"},
    199236: {"Unified_Ideograph", "Ideographic"},
    199237: {"Unified_Ideograph", "Ideographic"},
    199238: {"Unified_Ideograph", "Ideographic"},
    199239: {"Unified_Ideograph", "Ideographic"},
    199240: {"Unified_Ideograph", "Ideographic"},
    199241: {"Unified_Ideograph", "Ideographic"},
    199242: {"Unified_Ideograph", "Ideographic"},
    199243: {"Unified_Ideograph", "Ideographic"},
    199244: {"Unified_Ideograph", "Ideographic"},
    199245: {"Unified_Ideograph", "Ideographic"},
    199246: {"Unified_Ideograph", "Ideographic"},
    199247: {"Unified_Ideograph", "Ideographic"},
    199248: {"Unified_Ideograph", "Ideographic"},
    199249: {"Unified_Ideograph", "Ideographic"},
    199250: {"Unified_Ideograph", "Ideographic"},
    199251: {"Unified_Ideograph", "Ideographic"},
    199252: {"Unified_Ideograph", "Ideographic"},
    199253: {"Unified_Ideograph", "Ideographic"},
    199254: {"Unified_Ideograph", "Ideographic"},
    199255: {"Unified_Ideograph", "Ideographic"},
    199256: {"Unified_Ideograph", "Ideographic"},
    199257: {"Unified_Ideograph", "Ideographic"},
    199258: {"Unified_Ideograph", "Ideographic"},
    199259: {"Unified_Ideograph", "Ideographic"},
    199260: {"Unified_Ideograph", "Ideographic"},
    199261: {"Unified_Ideograph", "Ideographic"},
    199262: {"Unified_Ideograph", "Ideographic"},
    199263: {"Unified_Ideograph", "Ideographic"},
    199264: {"Unified_Ideograph", "Ideographic"},
    199265: {"Unified_Ideograph", "Ideographic"},
    199266: {"Unified_Ideograph", "Ideographic"},
    199267: {"Unified_Ideograph", "Ideographic"},
    199268: {"Unified_Ideograph", "Ideographic"},
    199269: {"Unified_Ideograph", "Ideographic"},
    199270: {"Unified_Ideograph", "Ideographic"},
    199271: {"Unified_Ideograph", "Ideographic"},
    199272: {"Unified_Ideograph", "Ideographic"},
    199273: {"Unified_Ideograph", "Ideographic"},
    199274: {"Unified_Ideograph", "Ideographic"},
    199275: {"Unified_Ideograph", "Ideographic"},
    199276: {"Unified_Ideograph", "Ideographic"},
    199277: {"Unified_Ideograph", "Ideographic"},
    199278: {"Unified_Ideograph", "Ideographic"},
    199279: {"Unified_Ideograph", "Ideographic"},
    199280: {"Unified_Ideograph", "Ideographic"},
    199281: {"Unified_Ideograph", "Ideographic"},
    199282: {"Unified_Ideograph", "Ideographic"},
    199283: {"Unified_Ideograph", "Ideographic"},
    199284: {"Unified_Ideograph", "Ideographic"},
    199285: {"Unified_Ideograph", "Ideographic"},
    199286: {"Unified_Ideograph", "Ideographic"},
    199287: {"Unified_Ideograph", "Ideographic"},
    199288: {"Unified_Ideograph", "Ideographic"},
    199289: {"Unified_Ideograph", "Ideographic"},
    199290: {"Unified_Ideograph", "Ideographic"},
    199291: {"Unified_Ideograph", "Ideographic"},
    199292: {"Unified_Ideograph", "Ideographic"},
    199293: {"Unified_Ideograph", "Ideographic"},
    199294: {"Unified_Ideograph", "Ideographic"},
    199295: {"Unified_Ideograph", "Ideographic"},
    199296: {"Unified_Ideograph", "Ideographic"},
    199297: {"Unified_Ideograph", "Ideographic"},
    199298: {"Unified_Ideograph", "Ideographic"},
    199299: {"Unified_Ideograph", "Ideographic"},
    199300: {"Unified_Ideograph", "Ideographic"},
    199301: {"Unified_Ideograph", "Ideographic"},
    199302: {"Unified_Ideograph", "Ideographic"},
    199303: {"Unified_Ideograph", "Ideographic"},
    199304: {"Unified_Ideograph", "Ideographic"},
    199305: {"Unified_Ideograph", "Ideographic"},
    199306: {"Unified_Ideograph", "Ideographic"},
    199307: {"Unified_Ideograph", "Ideographic"},
    199308: {"Unified_Ideograph", "Ideographic"},
    199309: {"Unified_Ideograph", "Ideographic"},
    199310: {"Unified_Ideograph", "Ideographic"},
    199311: {"Unified_Ideograph", "Ideographic"},
    199312: {"Unified_Ideograph", "Ideographic"},
    199313: {"Unified_Ideograph", "Ideographic"},
    199314: {"Unified_Ideograph", "Ideographic"},
    199315: {"Unified_Ideograph", "Ideographic"},
    199316: {"Unified_Ideograph", "Ideographic"},
    199317: {"Unified_Ideograph", "Ideographic"},
    199318: {"Unified_Ideograph", "Ideographic"},
    199319: {"Unified_Ideograph", "Ideographic"},
    199320: {"Unified_Ideograph", "Ideographic"},
    199321: {"Unified_Ideograph", "Ideographic"},
    199322: {"Unified_Ideograph", "Ideographic"},
    199323: {"Unified_Ideograph", "Ideographic"},
    199324: {"Unified_Ideograph", "Ideographic"},
    199325: {"Unified_Ideograph", "Ideographic"},
    199326: {"Unified_Ideograph", "Ideographic"},
    199327: {"Unified_Ideograph", "Ideographic"},
    199328: {"Unified_Ideograph", "Ideographic"},
    199329: {"Unified_Ideograph", "Ideographic"},
    199330: {"Unified_Ideograph", "Ideographic"},
    199331: {"Unified_Ideograph", "Ideographic"},
    199332: {"Unified_Ideograph", "Ideographic"},
    199333: {"Unified_Ideograph", "Ideographic"},
    199334: {"Unified_Ideograph", "Ideographic"},
    199335: {"Unified_Ideograph", "Ideographic"},
    199336: {"Unified_Ideograph", "Ideographic"},
    199337: {"Unified_Ideograph", "Ideographic"},
    199338: {"Unified_Ideograph", "Ideographic"},
    199339: {"Unified_Ideograph", "Ideographic"},
    199340: {"Unified_Ideograph", "Ideographic"},
    199341: {"Unified_Ideograph", "Ideographic"},
    199342: {"Unified_Ideograph", "Ideographic"},
    199343: {"Unified_Ideograph", "Ideographic"},
    199344: {"Unified_Ideograph", "Ideographic"},
    199345: {"Unified_Ideograph", "Ideographic"},
    199346: {"Unified_Ideograph", "Ideographic"},
    199347: {"Unified_Ideograph", "Ideographic"},
    199348: {"Unified_Ideograph", "Ideographic"},
    199349: {"Unified_Ideograph", "Ideographic"},
    199350: {"Unified_Ideograph", "Ideographic"},
    199351: {"Unified_Ideograph", "Ideographic"},
    199352: {"Unified_Ideograph", "Ideographic"},
    199353: {"Unified_Ideograph", "Ideographic"},
    199354: {"Unified_Ideograph", "Ideographic"},
    199355: {"Unified_Ideograph", "Ideographic"},
    199356: {"Unified_Ideograph", "Ideographic"},
    199357: {"Unified_Ideograph", "Ideographic"},
    199358: {"Unified_Ideograph", "Ideographic"},
    199359: {"Unified_Ideograph", "Ideographic"},
    199360: {"Unified_Ideograph", "Ideographic"},
    199361: {"Unified_Ideograph", "Ideographic"},
    199362: {"Unified_Ideograph", "Ideographic"},
    199363: {"Unified_Ideograph", "Ideographic"},
    199364: {"Unified_Ideograph", "Ideographic"},
    199365: {"Unified_Ideograph", "Ideographic"},
    199366: {"Unified_Ideograph", "Ideographic"},
    199367: {"Unified_Ideograph", "Ideographic"},
    199368: {"Unified_Ideograph", "Ideographic"},
    199369: {"Unified_Ideograph", "Ideographic"},
    199370: {"Unified_Ideograph", "Ideographic"},
    199371: {"Unified_Ideograph", "Ideographic"},
    199372: {"Unified_Ideograph", "Ideographic"},
    199373: {"Unified_Ideograph", "Ideographic"},
    199374: {"Unified_Ideograph", "Ideographic"},
    199375: {"Unified_Ideograph", "Ideographic"},
    199376: {"Unified_Ideograph", "Ideographic"},
    199377: {"Unified_Ideograph", "Ideographic"},
    199378: {"Unified_Ideograph", "Ideographic"},
    199379: {"Unified_Ideograph", "Ideographic"},
    199380: {"Unified_Ideograph", "Ideographic"},
    199381: {"Unified_Ideograph", "Ideographic"},
    199382: {"Unified_Ideograph", "Ideographic"},
    199383: {"Unified_Ideograph", "Ideographic"},
    199384: {"Unified_Ideograph", "Ideographic"},
    199385: {"Unified_Ideograph", "Ideographic"},
    199386: {"Unified_Ideograph", "Ideographic"},
    199387: {"Unified_Ideograph", "Ideographic"},
    199388: {"Unified_Ideograph", "Ideographic"},
    199389: {"Unified_Ideograph", "Ideographic"},
    199390: {"Unified_Ideograph", "Ideographic"},
    199391: {"Unified_Ideograph", "Ideographic"},
    199392: {"Unified_Ideograph", "Ideographic"},
    199393: {"Unified_Ideograph", "Ideographic"},
    199394: {"Unified_Ideograph", "Ideographic"},
    199395: {"Unified_Ideograph", "Ideographic"},
    199396: {"Unified_Ideograph", "Ideographic"},
    199397: {"Unified_Ideograph", "Ideographic"},
    199398: {"Unified_Ideograph", "Ideographic"},
    199399: {"Unified_Ideograph", "Ideographic"},
    199400: {"Unified_Ideograph", "Ideographic"},
    199401: {"Unified_Ideograph", "Ideographic"},
    199402: {"Unified_Ideograph", "Ideographic"},
    199403: {"Unified_Ideograph", "Ideographic"},
    199404: {"Unified_Ideograph", "Ideographic"},
    199405: {"Unified_Ideograph", "Ideographic"},
    199406: {"Unified_Ideograph", "Ideographic"},
    199407: {"Unified_Ideograph", "Ideographic"},
    199408: {"Unified_Ideograph", "Ideographic"},
    199409: {"Unified_Ideograph", "Ideographic"},
    199410: {"Unified_Ideograph", "Ideographic"},
    199411: {"Unified_Ideograph", "Ideographic"},
    199412: {"Unified_Ideograph", "Ideographic"},
    199413: {"Unified_Ideograph", "Ideographic"},
    199414: {"Unified_Ideograph", "Ideographic"},
    199415: {"Unified_Ideograph", "Ideographic"},
    199416: {"Unified_Ideograph", "Ideographic"},
    199417: {"Unified_Ideograph", "Ideographic"},
    199418: {"Unified_Ideograph", "Ideographic"},
    199419: {"Unified_Ideograph", "Ideographic"},
    199420: {"Unified_Ideograph", "Ideographic"},
    199421: {"Unified_Ideograph", "Ideographic"},
    199422: {"Unified_Ideograph", "Ideographic"},
    199423: {"Unified_Ideograph", "Ideographic"},
    199424: {"Unified_Ideograph", "Ideographic"},
    199425: {"Unified_Ideograph", "Ideographic"},
    199426: {"Unified_Ideograph", "Ideographic"},
    199427: {"Unified_Ideograph", "Ideographic"},
    199428: {"Unified_Ideograph", "Ideographic"},
    199429: {"Unified_Ideograph", "Ideographic"},
    199430: {"Unified_Ideograph", "Ideographic"},
    199431: {"Unified_Ideograph", "Ideographic"},
    199432: {"Unified_Ideograph", "Ideographic"},
    199433: {"Unified_Ideograph", "Ideographic"},
    199434: {"Unified_Ideograph", "Ideographic"},
    199435: {"Unified_Ideograph", "Ideographic"},
    199436: {"Unified_Ideograph", "Ideographic"},
    199437: {"Unified_Ideograph", "Ideographic"},
    199438: {"Unified_Ideograph", "Ideographic"},
    199439: {"Unified_Ideograph", "Ideographic"},
    199440: {"Unified_Ideograph", "Ideographic"},
    199441: {"Unified_Ideograph", "Ideographic"},
    199442: {"Unified_Ideograph", "Ideographic"},
    199443: {"Unified_Ideograph", "Ideographic"},
    199444: {"Unified_Ideograph", "Ideographic"},
    199445: {"Unified_Ideograph", "Ideographic"},
    199446: {"Unified_Ideograph", "Ideographic"},
    199447: {"Unified_Ideograph", "Ideographic"},
    199448: {"Unified_Ideograph", "Ideographic"},
    199449: {"Unified_Ideograph", "Ideographic"},
    199450: {"Unified_Ideograph", "Ideographic"},
    199451: {"Unified_Ideograph", "Ideographic"},
    199452: {"Unified_Ideograph", "Ideographic"},
    199453: {"Unified_Ideograph", "Ideographic"},
    199454: {"Unified_Ideograph", "Ideographic"},
    199455: {"Unified_Ideograph", "Ideographic"},
    199456: {"Unified_Ideograph", "Ideographic"},
    199457: {"Unified_Ideograph", "Ideographic"},
    199458: {"Unified_Ideograph", "Ideographic"},
    199459: {"Unified_Ideograph", "Ideographic"},
    199460: {"Unified_Ideograph", "Ideographic"},
    199461: {"Unified_Ideograph", "Ideographic"},
    199462: {"Unified_Ideograph", "Ideographic"},
    199463: {"Unified_Ideograph", "Ideographic"},
    199464: {"Unified_Ideograph", "Ideographic"},
    199465: {"Unified_Ideograph", "Ideographic"},
    199466: {"Unified_Ideograph", "Ideographic"},
    199467: {"Unified_Ideograph", "Ideographic"},
    199468: {"Unified_Ideograph", "Ideographic"},
    199469: {"Unified_Ideograph", "Ideographic"},
    199470: {"Unified_Ideograph", "Ideographic"},
    199471: {"Unified_Ideograph", "Ideographic"},
    199472: {"Unified_Ideograph", "Ideographic"},
    199473: {"Unified_Ideograph", "Ideographic"},
    199474: {"Unified_Ideograph", "Ideographic"},
    199475: {"Unified_Ideograph", "Ideographic"},
    199476: {"Unified_Ideograph", "Ideographic"},
    199477: {"Unified_Ideograph", "Ideographic"},
    199478: {"Unified_Ideograph", "Ideographic"},
    199479: {"Unified_Ideograph", "Ideographic"},
    199480: {"Unified_Ideograph", "Ideographic"},
    199481: {"Unified_Ideograph", "Ideographic"},
    199482: {"Unified_Ideograph", "Ideographic"},
    199483: {"Unified_Ideograph", "Ideographic"},
    199484: {"Unified_Ideograph", "Ideographic"},
    199485: {"Unified_Ideograph", "Ideographic"},
    199486: {"Unified_Ideograph", "Ideographic"},
    199487: {"Unified_Ideograph", "Ideographic"},
    199488: {"Unified_Ideograph", "Ideographic"},
    199489: {"Unified_Ideograph", "Ideographic"},
    199490: {"Unified_Ideograph", "Ideographic"},
    199491: {"Unified_Ideograph", "Ideographic"},
    199492: {"Unified_Ideograph", "Ideographic"},
    199493: {"Unified_Ideograph", "Ideographic"},
    199494: {"Unified_Ideograph", "Ideographic"},
    199495: {"Unified_Ideograph", "Ideographic"},
    199496: {"Unified_Ideograph", "Ideographic"},
    199497: {"Unified_Ideograph", "Ideographic"},
    199498: {"Unified_Ideograph", "Ideographic"},
    199499: {"Unified_Ideograph", "Ideographic"},
    199500: {"Unified_Ideograph", "Ideographic"},
    199501: {"Unified_Ideograph", "Ideographic"},
    199502: {"Unified_Ideograph", "Ideographic"},
    199503: {"Unified_Ideograph", "Ideographic"},
    199504: {"Unified_Ideograph", "Ideographic"},
    199505: {"Unified_Ideograph", "Ideographic"},
    199506: {"Unified_Ideograph", "Ideographic"},
    199507: {"Unified_Ideograph", "Ideographic"},
    199508: {"Unified_Ideograph", "Ideographic"},
    199509: {"Unified_Ideograph", "Ideographic"},
    199510: {"Unified_Ideograph", "Ideographic"},
    199511: {"Unified_Ideograph", "Ideographic"},
    199512: {"Unified_Ideograph", "Ideographic"},
    199513: {"Unified_Ideograph", "Ideographic"},
    199514: {"Unified_Ideograph", "Ideographic"},
    199515: {"Unified_Ideograph", "Ideographic"},
    199516: {"Unified_Ideograph", "Ideographic"},
    199517: {"Unified_Ideograph", "Ideographic"},
    199518: {"Unified_Ideograph", "Ideographic"},
    199519: {"Unified_Ideograph", "Ideographic"},
    199520: {"Unified_Ideograph", "Ideographic"},
    199521: {"Unified_Ideograph", "Ideographic"},
    199522: {"Unified_Ideograph", "Ideographic"},
    199523: {"Unified_Ideograph", "Ideographic"},
    199524: {"Unified_Ideograph", "Ideographic"},
    199525: {"Unified_Ideograph", "Ideographic"},
    199526: {"Unified_Ideograph", "Ideographic"},
    199527: {"Unified_Ideograph", "Ideographic"},
    199528: {"Unified_Ideograph", "Ideographic"},
    199529: {"Unified_Ideograph", "Ideographic"},
    199530: {"Unified_Ideograph", "Ideographic"},
    199531: {"Unified_Ideograph", "Ideographic"},
    199532: {"Unified_Ideograph", "Ideographic"},
    199533: {"Unified_Ideograph", "Ideographic"},
    199534: {"Unified_Ideograph", "Ideographic"},
    199535: {"Unified_Ideograph", "Ideographic"},
    199536: {"Unified_Ideograph", "Ideographic"},
    199537: {"Unified_Ideograph", "Ideographic"},
    199538: {"Unified_Ideograph", "Ideographic"},
    199539: {"Unified_Ideograph", "Ideographic"},
    199540: {"Unified_Ideograph", "Ideographic"},
    199541: {"Unified_Ideograph", "Ideographic"},
    199542: {"Unified_Ideograph", "Ideographic"},
    199543: {"Unified_Ideograph", "Ideographic"},
    199544: {"Unified_Ideograph", "Ideographic"},
    199545: {"Unified_Ideograph", "Ideographic"},
    199546: {"Unified_Ideograph", "Ideographic"},
    199547: {"Unified_Ideograph", "Ideographic"},
    199548: {"Unified_Ideograph", "Ideographic"},
    199549: {"Unified_Ideograph", "Ideographic"},
    199550: {"Unified_Ideograph", "Ideographic"},
    199551: {"Unified_Ideograph", "Ideographic"},
    199552: {"Unified_Ideograph", "Ideographic"},
    199553: {"Unified_Ideograph", "Ideographic"},
    199554: {"Unified_Ideograph", "Ideographic"},
    199555: {"Unified_Ideograph", "Ideographic"},
    199556: {"Unified_Ideograph", "Ideographic"},
    199557: {"Unified_Ideograph", "Ideographic"},
    199558: {"Unified_Ideograph", "Ideographic"},
    199559: {"Unified_Ideograph", "Ideographic"},
    199560: {"Unified_Ideograph", "Ideographic"},
    199561: {"Unified_Ideograph", "Ideographic"},
    199562: {"Unified_Ideograph", "Ideographic"},
    199563: {"Unified_Ideograph", "Ideographic"},
    199564: {"Unified_Ideograph", "Ideographic"},
    199565: {"Unified_Ideograph", "Ideographic"},
    199566: {"Unified_Ideograph", "Ideographic"},
    199567: {"Unified_Ideograph", "Ideographic"},
    199568: {"Unified_Ideograph", "Ideographic"},
    199569: {"Unified_Ideograph", "Ideographic"},
    199570: {"Unified_Ideograph", "Ideographic"},
    199571: {"Unified_Ideograph", "Ideographic"},
    199572: {"Unified_Ideograph", "Ideographic"},
    199573: {"Unified_Ideograph", "Ideographic"},
    199574: {"Unified_Ideograph", "Ideographic"},
    199575: {"Unified_Ideograph", "Ideographic"},
    199576: {"Unified_Ideograph", "Ideographic"},
    199577: {"Unified_Ideograph", "Ideographic"},
    199578: {"Unified_Ideograph", "Ideographic"},
    199579: {"Unified_Ideograph", "Ideographic"},
    199580: {"Unified_Ideograph", "Ideographic"},
    199581: {"Unified_Ideograph", "Ideographic"},
    199582: {"Unified_Ideograph", "Ideographic"},
    199583: {"Unified_Ideograph", "Ideographic"},
    199584: {"Unified_Ideograph", "Ideographic"},
    199585: {"Unified_Ideograph", "Ideographic"},
    199586: {"Unified_Ideograph", "Ideographic"},
    199587: {"Unified_Ideograph", "Ideographic"},
    199588: {"Unified_Ideograph", "Ideographic"},
    199589: {"Unified_Ideograph", "Ideographic"},
    199590: {"Unified_Ideograph", "Ideographic"},
    199591: {"Unified_Ideograph", "Ideographic"},
    199592: {"Unified_Ideograph", "Ideographic"},
    199593: {"Unified_Ideograph", "Ideographic"},
    199594: {"Unified_Ideograph", "Ideographic"},
    199595: {"Unified_Ideograph", "Ideographic"},
    199596: {"Unified_Ideograph", "Ideographic"},
    199597: {"Unified_Ideograph", "Ideographic"},
    199598: {"Unified_Ideograph", "Ideographic"},
    199599: {"Unified_Ideograph", "Ideographic"},
    199600: {"Unified_Ideograph", "Ideographic"},
    199601: {"Unified_Ideograph", "Ideographic"},
    199602: {"Unified_Ideograph", "Ideographic"},
    199603: {"Unified_Ideograph", "Ideographic"},
    199604: {"Unified_Ideograph", "Ideographic"},
    199605: {"Unified_Ideograph", "Ideographic"},
    199606: {"Unified_Ideograph", "Ideographic"},
    199607: {"Unified_Ideograph", "Ideographic"},
    199608: {"Unified_Ideograph", "Ideographic"},
    199609: {"Unified_Ideograph", "Ideographic"},
    199610: {"Unified_Ideograph", "Ideographic"},
    199611: {"Unified_Ideograph", "Ideographic"},
    199612: {"Unified_Ideograph", "Ideographic"},
    199613: {"Unified_Ideograph", "Ideographic"},
    199614: {"Unified_Ideograph", "Ideographic"},
    199615: {"Unified_Ideograph", "Ideographic"},
    199616: {"Unified_Ideograph", "Ideographic"},
    199617: {"Unified_Ideograph", "Ideographic"},
    199618: {"Unified_Ideograph", "Ideographic"},
    199619: {"Unified_Ideograph", "Ideographic"},
    199620: {"Unified_Ideograph", "Ideographic"},
    199621: {"Unified_Ideograph", "Ideographic"},
    199622: {"Unified_Ideograph", "Ideographic"},
    199623: {"Unified_Ideograph", "Ideographic"},
    199624: {"Unified_Ideograph", "Ideographic"},
    199625: {"Unified_Ideograph", "Ideographic"},
    199626: {"Unified_Ideograph", "Ideographic"},
    199627: {"Unified_Ideograph", "Ideographic"},
    199628: {"Unified_Ideograph", "Ideographic"},
    199629: {"Unified_Ideograph", "Ideographic"},
    199630: {"Unified_Ideograph", "Ideographic"},
    199631: {"Unified_Ideograph", "Ideographic"},
    199632: {"Unified_Ideograph", "Ideographic"},
    199633: {"Unified_Ideograph", "Ideographic"},
    199634: {"Unified_Ideograph", "Ideographic"},
    199635: {"Unified_Ideograph", "Ideographic"},
    199636: {"Unified_Ideograph", "Ideographic"},
    199637: {"Unified_Ideograph", "Ideographic"},
    199638: {"Unified_Ideograph", "Ideographic"},
    199639: {"Unified_Ideograph", "Ideographic"},
    199640: {"Unified_Ideograph", "Ideographic"},
    199641: {"Unified_Ideograph", "Ideographic"},
    199642: {"Unified_Ideograph", "Ideographic"},
    199643: {"Unified_Ideograph", "Ideographic"},
    199644: {"Unified_Ideograph", "Ideographic"},
    199645: {"Unified_Ideograph", "Ideographic"},
    199646: {"Unified_Ideograph", "Ideographic"},
    199647: {"Unified_Ideograph", "Ideographic"},
    199648: {"Unified_Ideograph", "Ideographic"},
    199649: {"Unified_Ideograph", "Ideographic"},
    199650: {"Unified_Ideograph", "Ideographic"},
    199651: {"Unified_Ideograph", "Ideographic"},
    199652: {"Unified_Ideograph", "Ideographic"},
    199653: {"Unified_Ideograph", "Ideographic"},
    199654: {"Unified_Ideograph", "Ideographic"},
    199655: {"Unified_Ideograph", "Ideographic"},
    199656: {"Unified_Ideograph", "Ideographic"},
    199657: {"Unified_Ideograph", "Ideographic"},
    199658: {"Unified_Ideograph", "Ideographic"},
    199659: {"Unified_Ideograph", "Ideographic"},
    199660: {"Unified_Ideograph", "Ideographic"},
    199661: {"Unified_Ideograph", "Ideographic"},
    199662: {"Unified_Ideograph", "Ideographic"},
    199663: {"Unified_Ideograph", "Ideographic"},
    199664: {"Unified_Ideograph", "Ideographic"},
    199665: {"Unified_Ideograph", "Ideographic"},
    199666: {"Unified_Ideograph", "Ideographic"},
    199667: {"Unified_Ideograph", "Ideographic"},
    199668: {"Unified_Ideograph", "Ideographic"},
    199669: {"Unified_Ideograph", "Ideographic"},
    199670: {"Unified_Ideograph", "Ideographic"},
    199671: {"Unified_Ideograph", "Ideographic"},
    199672: {"Unified_Ideograph", "Ideographic"},
    199673: {"Unified_Ideograph", "Ideographic"},
    199674: {"Unified_Ideograph", "Ideographic"},
    199675: {"Unified_Ideograph", "Ideographic"},
    199676: {"Unified_Ideograph", "Ideographic"},
    199677: {"Unified_Ideograph", "Ideographic"},
    199678: {"Unified_Ideograph", "Ideographic"},
    199679: {"Unified_Ideograph", "Ideographic"},
    199680: {"Unified_Ideograph", "Ideographic"},
    199681: {"Unified_Ideograph", "Ideographic"},
    199682: {"Unified_Ideograph", "Ideographic"},
    199683: {"Unified_Ideograph", "Ideographic"},
    199684: {"Unified_Ideograph", "Ideographic"},
    199685: {"Unified_Ideograph", "Ideographic"},
    199686: {"Unified_Ideograph", "Ideographic"},
    199687: {"Unified_Ideograph", "Ideographic"},
    199688: {"Unified_Ideograph", "Ideographic"},
    199689: {"Unified_Ideograph", "Ideographic"},
    199690: {"Unified_Ideograph", "Ideographic"},
    199691: {"Unified_Ideograph", "Ideographic"},
    199692: {"Unified_Ideograph", "Ideographic"},
    199693: {"Unified_Ideograph", "Ideographic"},
    199694: {"Unified_Ideograph", "Ideographic"},
    199695: {"Unified_Ideograph", "Ideographic"},
    199696: {"Unified_Ideograph", "Ideographic"},
    199697: {"Unified_Ideograph", "Ideographic"},
    199698: {"Unified_Ideograph", "Ideographic"},
    199699: {"Unified_Ideograph", "Ideographic"},
    199700: {"Unified_Ideograph", "Ideographic"},
    199701: {"Unified_Ideograph", "Ideographic"},
    199702: {"Unified_Ideograph", "Ideographic"},
    199703: {"Unified_Ideograph", "Ideographic"},
    199704: {"Unified_Ideograph", "Ideographic"},
    199705: {"Unified_Ideograph", "Ideographic"},
    199706: {"Unified_Ideograph", "Ideographic"},
    199707: {"Unified_Ideograph", "Ideographic"},
    199708: {"Unified_Ideograph", "Ideographic"},
    199709: {"Unified_Ideograph", "Ideographic"},
    199710: {"Unified_Ideograph", "Ideographic"},
    199711: {"Unified_Ideograph", "Ideographic"},
    199712: {"Unified_Ideograph", "Ideographic"},
    199713: {"Unified_Ideograph", "Ideographic"},
    199714: {"Unified_Ideograph", "Ideographic"},
    199715: {"Unified_Ideograph", "Ideographic"},
    199716: {"Unified_Ideograph", "Ideographic"},
    199717: {"Unified_Ideograph", "Ideographic"},
    199718: {"Unified_Ideograph", "Ideographic"},
    199719: {"Unified_Ideograph", "Ideographic"},
    199720: {"Unified_Ideograph", "Ideographic"},
    199721: {"Unified_Ideograph", "Ideographic"},
    199722: {"Unified_Ideograph", "Ideographic"},
    199723: {"Unified_Ideograph", "Ideographic"},
    199724: {"Unified_Ideograph", "Ideographic"},
    199725: {"Unified_Ideograph", "Ideographic"},
    199726: {"Unified_Ideograph", "Ideographic"},
    199727: {"Unified_Ideograph", "Ideographic"},
    199728: {"Unified_Ideograph", "Ideographic"},
    199729: {"Unified_Ideograph", "Ideographic"},
    199730: {"Unified_Ideograph", "Ideographic"},
    199731: {"Unified_Ideograph", "Ideographic"},
    199732: {"Unified_Ideograph", "Ideographic"},
    199733: {"Unified_Ideograph", "Ideographic"},
    199734: {"Unified_Ideograph", "Ideographic"},
    199735: {"Unified_Ideograph", "Ideographic"},
    199736: {"Unified_Ideograph", "Ideographic"},
    199737: {"Unified_Ideograph", "Ideographic"},
    199738: {"Unified_Ideograph", "Ideographic"},
    199739: {"Unified_Ideograph", "Ideographic"},
    199740: {"Unified_Ideograph", "Ideographic"},
    199741: {"Unified_Ideograph", "Ideographic"},
    199742: {"Unified_Ideograph", "Ideographic"},
    199743: {"Unified_Ideograph", "Ideographic"},
    199744: {"Unified_Ideograph", "Ideographic"},
    199745: {"Unified_Ideograph", "Ideographic"},
    199746: {"Unified_Ideograph", "Ideographic"},
    199747: {"Unified_Ideograph", "Ideographic"},
    199748: {"Unified_Ideograph", "Ideographic"},
    199749: {"Unified_Ideograph", "Ideographic"},
    199750: {"Unified_Ideograph", "Ideographic"},
    199751: {"Unified_Ideograph", "Ideographic"},
    199752: {"Unified_Ideograph", "Ideographic"},
    199753: {"Unified_Ideograph", "Ideographic"},
    199754: {"Unified_Ideograph", "Ideographic"},
    199755: {"Unified_Ideograph", "Ideographic"},
    199756: {"Unified_Ideograph", "Ideographic"},
    199757: {"Unified_Ideograph", "Ideographic"},
    199758: {"Unified_Ideograph", "Ideographic"},
    199759: {"Unified_Ideograph", "Ideographic"},
    199760: {"Unified_Ideograph", "Ideographic"},
    199761: {"Unified_Ideograph", "Ideographic"},
    199762: {"Unified_Ideograph", "Ideographic"},
    199763: {"Unified_Ideograph", "Ideographic"},
    199764: {"Unified_Ideograph", "Ideographic"},
    199765: {"Unified_Ideograph", "Ideographic"},
    199766: {"Unified_Ideograph", "Ideographic"},
    199767: {"Unified_Ideograph", "Ideographic"},
    199768: {"Unified_Ideograph", "Ideographic"},
    199769: {"Unified_Ideograph", "Ideographic"},
    199770: {"Unified_Ideograph", "Ideographic"},
    199771: {"Unified_Ideograph", "Ideographic"},
    199772: {"Unified_Ideograph", "Ideographic"},
    199773: {"Unified_Ideograph", "Ideographic"},
    199774: {"Unified_Ideograph", "Ideographic"},
    199775: {"Unified_Ideograph", "Ideographic"},
    199776: {"Unified_Ideograph", "Ideographic"},
    199777: {"Unified_Ideograph", "Ideographic"},
    199778: {"Unified_Ideograph", "Ideographic"},
    199779: {"Unified_Ideograph", "Ideographic"},
    199780: {"Unified_Ideograph", "Ideographic"},
    199781: {"Unified_Ideograph", "Ideographic"},
    199782: {"Unified_Ideograph", "Ideographic"},
    199783: {"Unified_Ideograph", "Ideographic"},
    199784: {"Unified_Ideograph", "Ideographic"},
    199785: {"Unified_Ideograph", "Ideographic"},
    199786: {"Unified_Ideograph", "Ideographic"},
    199787: {"Unified_Ideograph", "Ideographic"},
    199788: {"Unified_Ideograph", "Ideographic"},
    199789: {"Unified_Ideograph", "Ideographic"},
    199790: {"Unified_Ideograph", "Ideographic"},
    199791: {"Unified_Ideograph", "Ideographic"},
    199792: {"Unified_Ideograph", "Ideographic"},
    199793: {"Unified_Ideograph", "Ideographic"},
    199794: {"Unified_Ideograph", "Ideographic"},
    199795: {"Unified_Ideograph", "Ideographic"},
    199796: {"Unified_Ideograph", "Ideographic"},
    199797: {"Unified_Ideograph", "Ideographic"},
    199798: {"Unified_Ideograph", "Ideographic"},
    199799: {"Unified_Ideograph", "Ideographic"},
    199800: {"Unified_Ideograph", "Ideographic"},
    199801: {"Unified_Ideograph", "Ideographic"},
    199802: {"Unified_Ideograph", "Ideographic"},
    199803: {"Unified_Ideograph", "Ideographic"},
    199804: {"Unified_Ideograph", "Ideographic"},
    199805: {"Unified_Ideograph", "Ideographic"},
    199806: {"Unified_Ideograph", "Ideographic"},
    199807: {"Unified_Ideograph", "Ideographic"},
    199808: {"Unified_Ideograph", "Ideographic"},
    199809: {"Unified_Ideograph", "Ideographic"},
    199810: {"Unified_Ideograph", "Ideographic"},
    199811: {"Unified_Ideograph", "Ideographic"},
    199812: {"Unified_Ideograph", "Ideographic"},
    199813: {"Unified_Ideograph", "Ideographic"},
    199814: {"Unified_Ideograph", "Ideographic"},
    199815: {"Unified_Ideograph", "Ideographic"},
    199816: {"Unified_Ideograph", "Ideographic"},
    199817: {"Unified_Ideograph", "Ideographic"},
    199818: {"Unified_Ideograph", "Ideographic"},
    199819: {"Unified_Ideograph", "Ideographic"},
    199820: {"Unified_Ideograph", "Ideographic"},
    199821: {"Unified_Ideograph", "Ideographic"},
    199822: {"Unified_Ideograph", "Ideographic"},
    199823: {"Unified_Ideograph", "Ideographic"},
    199824: {"Unified_Ideograph", "Ideographic"},
    199825: {"Unified_Ideograph", "Ideographic"},
    199826: {"Unified_Ideograph", "Ideographic"},
    199827: {"Unified_Ideograph", "Ideographic"},
    199828: {"Unified_Ideograph", "Ideographic"},
    199829: {"Unified_Ideograph", "Ideographic"},
    199830: {"Unified_Ideograph", "Ideographic"},
    199831: {"Unified_Ideograph", "Ideographic"},
    199832: {"Unified_Ideograph", "Ideographic"},
    199833: {"Unified_Ideograph", "Ideographic"},
    199834: {"Unified_Ideograph", "Ideographic"},
    199835: {"Unified_Ideograph", "Ideographic"},
    199836: {"Unified_Ideograph", "Ideographic"},
    199837: {"Unified_Ideograph", "Ideographic"},
    199838: {"Unified_Ideograph", "Ideographic"},
    199839: {"Unified_Ideograph", "Ideographic"},
    199840: {"Unified_Ideograph", "Ideographic"},
    199841: {"Unified_Ideograph", "Ideographic"},
    199842: {"Unified_Ideograph", "Ideographic"},
    199843: {"Unified_Ideograph", "Ideographic"},
    199844: {"Unified_Ideograph", "Ideographic"},
    199845: {"Unified_Ideograph", "Ideographic"},
    199846: {"Unified_Ideograph", "Ideographic"},
    199847: {"Unified_Ideograph", "Ideographic"},
    199848: {"Unified_Ideograph", "Ideographic"},
    199849: {"Unified_Ideograph", "Ideographic"},
    199850: {"Unified_Ideograph", "Ideographic"},
    199851: {"Unified_Ideograph", "Ideographic"},
    199852: {"Unified_Ideograph", "Ideographic"},
    199853: {"Unified_Ideograph", "Ideographic"},
    199854: {"Unified_Ideograph", "Ideographic"},
    199855: {"Unified_Ideograph", "Ideographic"},
    199856: {"Unified_Ideograph", "Ideographic"},
    199857: {"Unified_Ideograph", "Ideographic"},
    199858: {"Unified_Ideograph", "Ideographic"},
    199859: {"Unified_Ideograph", "Ideographic"},
    199860: {"Unified_Ideograph", "Ideographic"},
    199861: {"Unified_Ideograph", "Ideographic"},
    199862: {"Unified_Ideograph", "Ideographic"},
    199863: {"Unified_Ideograph", "Ideographic"},
    199864: {"Unified_Ideograph", "Ideographic"},
    199865: {"Unified_Ideograph", "Ideographic"},
    199866: {"Unified_Ideograph", "Ideographic"},
    199867: {"Unified_Ideograph", "Ideographic"},
    199868: {"Unified_Ideograph", "Ideographic"},
    199869: {"Unified_Ideograph", "Ideographic"},
    199870: {"Unified_Ideograph", "Ideographic"},
    199871: {"Unified_Ideograph", "Ideographic"},
    199872: {"Unified_Ideograph", "Ideographic"},
    199873: {"Unified_Ideograph", "Ideographic"},
    199874: {"Unified_Ideograph", "Ideographic"},
    199875: {"Unified_Ideograph", "Ideographic"},
    199876: {"Unified_Ideograph", "Ideographic"},
    199877: {"Unified_Ideograph", "Ideographic"},
    199878: {"Unified_Ideograph", "Ideographic"},
    199879: {"Unified_Ideograph", "Ideographic"},
    199880: {"Unified_Ideograph", "Ideographic"},
    199881: {"Unified_Ideograph", "Ideographic"},
    199882: {"Unified_Ideograph", "Ideographic"},
    199883: {"Unified_Ideograph", "Ideographic"},
    199884: {"Unified_Ideograph", "Ideographic"},
    199885: {"Unified_Ideograph", "Ideographic"},
    199886: {"Unified_Ideograph", "Ideographic"},
    199887: {"Unified_Ideograph", "Ideographic"},
    199888: {"Unified_Ideograph", "Ideographic"},
    199889: {"Unified_Ideograph", "Ideographic"},
    199890: {"Unified_Ideograph", "Ideographic"},
    199891: {"Unified_Ideograph", "Ideographic"},
    199892: {"Unified_Ideograph", "Ideographic"},
    199893: {"Unified_Ideograph", "Ideographic"},
    199894: {"Unified_Ideograph", "Ideographic"},
    199895: {"Unified_Ideograph", "Ideographic"},
    199896: {"Unified_Ideograph", "Ideographic"},
    199897: {"Unified_Ideograph", "Ideographic"},
    199898: {"Unified_Ideograph", "Ideographic"},
    199899: {"Unified_Ideograph", "Ideographic"},
    199900: {"Unified_Ideograph", "Ideographic"},
    199901: {"Unified_Ideograph", "Ideographic"},
    199902: {"Unified_Ideograph", "Ideographic"},
    199903: {"Unified_Ideograph", "Ideographic"},
    199904: {"Unified_Ideograph", "Ideographic"},
    199905: {"Unified_Ideograph", "Ideographic"},
    199906: {"Unified_Ideograph", "Ideographic"},
    199907: {"Unified_Ideograph", "Ideographic"},
    199908: {"Unified_Ideograph", "Ideographic"},
    199909: {"Unified_Ideograph", "Ideographic"},
    199910: {"Unified_Ideograph", "Ideographic"},
    199911: {"Unified_Ideograph", "Ideographic"},
    199912: {"Unified_Ideograph", "Ideographic"},
    199913: {"Unified_Ideograph", "Ideographic"},
    199914: {"Unified_Ideograph", "Ideographic"},
    199915: {"Unified_Ideograph", "Ideographic"},
    199916: {"Unified_Ideograph", "Ideographic"},
    199917: {"Unified_Ideograph", "Ideographic"},
    199918: {"Unified_Ideograph", "Ideographic"},
    199919: {"Unified_Ideograph", "Ideographic"},
    199920: {"Unified_Ideograph", "Ideographic"},
    199921: {"Unified_Ideograph", "Ideographic"},
    199922: {"Unified_Ideograph", "Ideographic"},
    199923: {"Unified_Ideograph", "Ideographic"},
    199924: {"Unified_Ideograph", "Ideographic"},
    199925: {"Unified_Ideograph", "Ideographic"},
    199926: {"Unified_Ideograph", "Ideographic"},
    199927: {"Unified_Ideograph", "Ideographic"},
    199928: {"Unified_Ideograph", "Ideographic"},
    199929: {"Unified_Ideograph", "Ideographic"},
    199930: {"Unified_Ideograph", "Ideographic"},
    199931: {"Unified_Ideograph", "Ideographic"},
    199932: {"Unified_Ideograph", "Ideographic"},
    199933: {"Unified_Ideograph", "Ideographic"},
    199934: {"Unified_Ideograph", "Ideographic"},
    199935: {"Unified_Ideograph", "Ideographic"},
    199936: {"Unified_Ideograph", "Ideographic"},
    199937: {"Unified_Ideograph", "Ideographic"},
    199938: {"Unified_Ideograph", "Ideographic"},
    199939: {"Unified_Ideograph", "Ideographic"},
    199940: {"Unified_Ideograph", "Ideographic"},
    199941: {"Unified_Ideograph", "Ideographic"},
    199942: {"Unified_Ideograph", "Ideographic"},
    199943: {"Unified_Ideograph", "Ideographic"},
    199944: {"Unified_Ideograph", "Ideographic"},
    199945: {"Unified_Ideograph", "Ideographic"},
    199946: {"Unified_Ideograph", "Ideographic"},
    199947: {"Unified_Ideograph", "Ideographic"},
    199948: {"Unified_Ideograph", "Ideographic"},
    199949: {"Unified_Ideograph", "Ideographic"},
    199950: {"Unified_Ideograph", "Ideographic"},
    199951: {"Unified_Ideograph", "Ideographic"},
    199952: {"Unified_Ideograph", "Ideographic"},
    199953: {"Unified_Ideograph", "Ideographic"},
    199954: {"Unified_Ideograph", "Ideographic"},
    199955: {"Unified_Ideograph", "Ideographic"},
    199956: {"Unified_Ideograph", "Ideographic"},
    199957: {"Unified_Ideograph", "Ideographic"},
    199958: {"Unified_Ideograph", "Ideographic"},
    199959: {"Unified_Ideograph", "Ideographic"},
    199960: {"Unified_Ideograph", "Ideographic"},
    199961: {"Unified_Ideograph", "Ideographic"},
    199962: {"Unified_Ideograph", "Ideographic"},
    199963: {"Unified_Ideograph", "Ideographic"},
    199964: {"Unified_Ideograph", "Ideographic"},
    199965: {"Unified_Ideograph", "Ideographic"},
    199966: {"Unified_Ideograph", "Ideographic"},
    199967: {"Unified_Ideograph", "Ideographic"},
    199968: {"Unified_Ideograph", "Ideographic"},
    199969: {"Unified_Ideograph", "Ideographic"},
    199970: {"Unified_Ideograph", "Ideographic"},
    199971: {"Unified_Ideograph", "Ideographic"},
    199972: {"Unified_Ideograph", "Ideographic"},
    199973: {"Unified_Ideograph", "Ideographic"},
    199974: {"Unified_Ideograph", "Ideographic"},
    199975: {"Unified_Ideograph", "Ideographic"},
    199976: {"Unified_Ideograph", "Ideographic"},
    199977: {"Unified_Ideograph", "Ideographic"},
    199978: {"Unified_Ideograph", "Ideographic"},
    199979: {"Unified_Ideograph", "Ideographic"},
    199980: {"Unified_Ideograph", "Ideographic"},
    199981: {"Unified_Ideograph", "Ideographic"},
    199982: {"Unified_Ideograph", "Ideographic"},
    199983: {"Unified_Ideograph", "Ideographic"},
    199984: {"Unified_Ideograph", "Ideographic"},
    199985: {"Unified_Ideograph", "Ideographic"},
    199986: {"Unified_Ideograph", "Ideographic"},
    199987: {"Unified_Ideograph", "Ideographic"},
    199988: {"Unified_Ideograph", "Ideographic"},
    199989: {"Unified_Ideograph", "Ideographic"},
    199990: {"Unified_Ideograph", "Ideographic"},
    199991: {"Unified_Ideograph", "Ideographic"},
    199992: {"Unified_Ideograph", "Ideographic"},
    199993: {"Unified_Ideograph", "Ideographic"},
    199994: {"Unified_Ideograph", "Ideographic"},
    199995: {"Unified_Ideograph", "Ideographic"},
    199996: {"Unified_Ideograph", "Ideographic"},
    199997: {"Unified_Ideograph", "Ideographic"},
    199998: {"Unified_Ideograph", "Ideographic"},
    199999: {"Unified_Ideograph", "Ideographic"},
    200000: {"Unified_Ideograph", "Ideographic"},
    200001: {"Unified_Ideograph", "Ideographic"},
    200002: {"Unified_Ideograph", "Ideographic"},
    200003: {"Unified_Ideograph", "Ideographic"},
    200004: {"Unified_Ideograph", "Ideographic"},
    200005: {"Unified_Ideograph", "Ideographic"},
    200006: {"Unified_Ideograph", "Ideographic"},
    200007: {"Unified_Ideograph", "Ideographic"},
    200008: {"Unified_Ideograph", "Ideographic"},
    200009: {"Unified_Ideograph", "Ideographic"},
    200010: {"Unified_Ideograph", "Ideographic"},
    200011: {"Unified_Ideograph", "Ideographic"},
    200012: {"Unified_Ideograph", "Ideographic"},
    200013: {"Unified_Ideograph", "Ideographic"},
    200014: {"Unified_Ideograph", "Ideographic"},
    200015: {"Unified_Ideograph", "Ideographic"},
    200016: {"Unified_Ideograph", "Ideographic"},
    200017: {"Unified_Ideograph", "Ideographic"},
    200018: {"Unified_Ideograph", "Ideographic"},
    200019: {"Unified_Ideograph", "Ideographic"},
    200020: {"Unified_Ideograph", "Ideographic"},
    200021: {"Unified_Ideograph", "Ideographic"},
    200022: {"Unified_Ideograph", "Ideographic"},
    200023: {"Unified_Ideograph", "Ideographic"},
    200024: {"Unified_Ideograph", "Ideographic"},
    200025: {"Unified_Ideograph", "Ideographic"},
    200026: {"Unified_Ideograph", "Ideographic"},
    200027: {"Unified_Ideograph", "Ideographic"},
    200028: {"Unified_Ideograph", "Ideographic"},
    200029: {"Unified_Ideograph", "Ideographic"},
    200030: {"Unified_Ideograph", "Ideographic"},
    200031: {"Unified_Ideograph", "Ideographic"},
    200032: {"Unified_Ideograph", "Ideographic"},
    200033: {"Unified_Ideograph", "Ideographic"},
    200034: {"Unified_Ideograph", "Ideographic"},
    200035: {"Unified_Ideograph", "Ideographic"},
    200036: {"Unified_Ideograph", "Ideographic"},
    200037: {"Unified_Ideograph", "Ideographic"},
    200038: {"Unified_Ideograph", "Ideographic"},
    200039: {"Unified_Ideograph", "Ideographic"},
    200040: {"Unified_Ideograph", "Ideographic"},
    200041: {"Unified_Ideograph", "Ideographic"},
    200042: {"Unified_Ideograph", "Ideographic"},
    200043: {"Unified_Ideograph", "Ideographic"},
    200044: {"Unified_Ideograph", "Ideographic"},
    200045: {"Unified_Ideograph", "Ideographic"},
    200046: {"Unified_Ideograph", "Ideographic"},
    200047: {"Unified_Ideograph", "Ideographic"},
    200048: {"Unified_Ideograph", "Ideographic"},
    200049: {"Unified_Ideograph", "Ideographic"},
    200050: {"Unified_Ideograph", "Ideographic"},
    200051: {"Unified_Ideograph", "Ideographic"},
    200052: {"Unified_Ideograph", "Ideographic"},
    200053: {"Unified_Ideograph", "Ideographic"},
    200054: {"Unified_Ideograph", "Ideographic"},
    200055: {"Unified_Ideograph", "Ideographic"},
    200056: {"Unified_Ideograph", "Ideographic"},
    200057: {"Unified_Ideograph", "Ideographic"},
    200058: {"Unified_Ideograph", "Ideographic"},
    200059: {"Unified_Ideograph", "Ideographic"},
    200060: {"Unified_Ideograph", "Ideographic"},
    200061: {"Unified_Ideograph", "Ideographic"},
    200062: {"Unified_Ideograph", "Ideographic"},
    200063: {"Unified_Ideograph", "Ideographic"},
    200064: {"Unified_Ideograph", "Ideographic"},
    200065: {"Unified_Ideograph", "Ideographic"},
    200066: {"Unified_Ideograph", "Ideographic"},
    200067: {"Unified_Ideograph", "Ideographic"},
    200068: {"Unified_Ideograph", "Ideographic"},
    200069: {"Unified_Ideograph", "Ideographic"},
    200070: {"Unified_Ideograph", "Ideographic"},
    200071: {"Unified_Ideograph", "Ideographic"},
    200072: {"Unified_Ideograph", "Ideographic"},
    200073: {"Unified_Ideograph", "Ideographic"},
    200074: {"Unified_Ideograph", "Ideographic"},
    200075: {"Unified_Ideograph", "Ideographic"},
    200076: {"Unified_Ideograph", "Ideographic"},
    200077: {"Unified_Ideograph", "Ideographic"},
    200078: {"Unified_Ideograph", "Ideographic"},
    200079: {"Unified_Ideograph", "Ideographic"},
    200080: {"Unified_Ideograph", "Ideographic"},
    200081: {"Unified_Ideograph", "Ideographic"},
    200082: {"Unified_Ideograph", "Ideographic"},
    200083: {"Unified_Ideograph", "Ideographic"},
    200084: {"Unified_Ideograph", "Ideographic"},
    200085: {"Unified_Ideograph", "Ideographic"},
    200086: {"Unified_Ideograph", "Ideographic"},
    200087: {"Unified_Ideograph", "Ideographic"},
    200088: {"Unified_Ideograph", "Ideographic"},
    200089: {"Unified_Ideograph", "Ideographic"},
    200090: {"Unified_Ideograph", "Ideographic"},
    200091: {"Unified_Ideograph", "Ideographic"},
    200092: {"Unified_Ideograph", "Ideographic"},
    200093: {"Unified_Ideograph", "Ideographic"},
    200094: {"Unified_Ideograph", "Ideographic"},
    200095: {"Unified_Ideograph", "Ideographic"},
    200096: {"Unified_Ideograph", "Ideographic"},
    200097: {"Unified_Ideograph", "Ideographic"},
    200098: {"Unified_Ideograph", "Ideographic"},
    200099: {"Unified_Ideograph", "Ideographic"},
    200100: {"Unified_Ideograph", "Ideographic"},
    200101: {"Unified_Ideograph", "Ideographic"},
    200102: {"Unified_Ideograph", "Ideographic"},
    200103: {"Unified_Ideograph", "Ideographic"},
    200104: {"Unified_Ideograph", "Ideographic"},
    200105: {"Unified_Ideograph", "Ideographic"},
    200106: {"Unified_Ideograph", "Ideographic"},
    200107: {"Unified_Ideograph", "Ideographic"},
    200108: {"Unified_Ideograph", "Ideographic"},
    200109: {"Unified_Ideograph", "Ideographic"},
    200110: {"Unified_Ideograph", "Ideographic"},
    200111: {"Unified_Ideograph", "Ideographic"},
    200112: {"Unified_Ideograph", "Ideographic"},
    200113: {"Unified_Ideograph", "Ideographic"},
    200114: {"Unified_Ideograph", "Ideographic"},
    200115: {"Unified_Ideograph", "Ideographic"},
    200116: {"Unified_Ideograph", "Ideographic"},
    200117: {"Unified_Ideograph", "Ideographic"},
    200118: {"Unified_Ideograph", "Ideographic"},
    200119: {"Unified_Ideograph", "Ideographic"},
    200120: {"Unified_Ideograph", "Ideographic"},
    200121: {"Unified_Ideograph", "Ideographic"},
    200122: {"Unified_Ideograph", "Ideographic"},
    200123: {"Unified_Ideograph", "Ideographic"},
    200124: {"Unified_Ideograph", "Ideographic"},
    200125: {"Unified_Ideograph", "Ideographic"},
    200126: {"Unified_Ideograph", "Ideographic"},
    200127: {"Unified_Ideograph", "Ideographic"},
    200128: {"Unified_Ideograph", "Ideographic"},
    200129: {"Unified_Ideograph", "Ideographic"},
    200130: {"Unified_Ideograph", "Ideographic"},
    200131: {"Unified_Ideograph", "Ideographic"},
    200132: {"Unified_Ideograph", "Ideographic"},
    200133: {"Unified_Ideograph", "Ideographic"},
    200134: {"Unified_Ideograph", "Ideographic"},
    200135: {"Unified_Ideograph", "Ideographic"},
    200136: {"Unified_Ideograph", "Ideographic"},
    200137: {"Unified_Ideograph", "Ideographic"},
    200138: {"Unified_Ideograph", "Ideographic"},
    200139: {"Unified_Ideograph", "Ideographic"},
    200140: {"Unified_Ideograph", "Ideographic"},
    200141: {"Unified_Ideograph", "Ideographic"},
    200142: {"Unified_Ideograph", "Ideographic"},
    200143: {"Unified_Ideograph", "Ideographic"},
    200144: {"Unified_Ideograph", "Ideographic"},
    200145: {"Unified_Ideograph", "Ideographic"},
    200146: {"Unified_Ideograph", "Ideographic"},
    200147: {"Unified_Ideograph", "Ideographic"},
    200148: {"Unified_Ideograph", "Ideographic"},
    200149: {"Unified_Ideograph", "Ideographic"},
    200150: {"Unified_Ideograph", "Ideographic"},
    200151: {"Unified_Ideograph", "Ideographic"},
    200152: {"Unified_Ideograph", "Ideographic"},
    200153: {"Unified_Ideograph", "Ideographic"},
    200154: {"Unified_Ideograph", "Ideographic"},
    200155: {"Unified_Ideograph", "Ideographic"},
    200156: {"Unified_Ideograph", "Ideographic"},
    200157: {"Unified_Ideograph", "Ideographic"},
    200158: {"Unified_Ideograph", "Ideographic"},
    200159: {"Unified_Ideograph", "Ideographic"},
    200160: {"Unified_Ideograph", "Ideographic"},
    200161: {"Unified_Ideograph", "Ideographic"},
    200162: {"Unified_Ideograph", "Ideographic"},
    200163: {"Unified_Ideograph", "Ideographic"},
    200164: {"Unified_Ideograph", "Ideographic"},
    200165: {"Unified_Ideograph", "Ideographic"},
    200166: {"Unified_Ideograph", "Ideographic"},
    200167: {"Unified_Ideograph", "Ideographic"},
    200168: {"Unified_Ideograph", "Ideographic"},
    200169: {"Unified_Ideograph", "Ideographic"},
    200170: {"Unified_Ideograph", "Ideographic"},
    200171: {"Unified_Ideograph", "Ideographic"},
    200172: {"Unified_Ideograph", "Ideographic"},
    200173: {"Unified_Ideograph", "Ideographic"},
    200174: {"Unified_Ideograph", "Ideographic"},
    200175: {"Unified_Ideograph", "Ideographic"},
    200176: {"Unified_Ideograph", "Ideographic"},
    200177: {"Unified_Ideograph", "Ideographic"},
    200178: {"Unified_Ideograph", "Ideographic"},
    200179: {"Unified_Ideograph", "Ideographic"},
    200180: {"Unified_Ideograph", "Ideographic"},
    200181: {"Unified_Ideograph", "Ideographic"},
    200182: {"Unified_Ideograph", "Ideographic"},
    200183: {"Unified_Ideograph", "Ideographic"},
    200184: {"Unified_Ideograph", "Ideographic"},
    200185: {"Unified_Ideograph", "Ideographic"},
    200186: {"Unified_Ideograph", "Ideographic"},
    200187: {"Unified_Ideograph", "Ideographic"},
    200188: {"Unified_Ideograph", "Ideographic"},
    200189: {"Unified_Ideograph", "Ideographic"},
    200190: {"Unified_Ideograph", "Ideographic"},
    200191: {"Unified_Ideograph", "Ideographic"},
    200192: {"Unified_Ideograph", "Ideographic"},
    200193: {"Unified_Ideograph", "Ideographic"},
    200194: {"Unified_Ideograph", "Ideographic"},
    200195: {"Unified_Ideograph", "Ideographic"},
    200196: {"Unified_Ideograph", "Ideographic"},
    200197: {"Unified_Ideograph", "Ideographic"},
    200198: {"Unified_Ideograph", "Ideographic"},
    200199: {"Unified_Ideograph", "Ideographic"},
    200200: {"Unified_Ideograph", "Ideographic"},
    200201: {"Unified_Ideograph", "Ideographic"},
    200202: {"Unified_Ideograph", "Ideographic"},
    200203: {"Unified_Ideograph", "Ideographic"},
    200204: {"Unified_Ideograph", "Ideographic"},
    200205: {"Unified_Ideograph", "Ideographic"},
    200206: {"Unified_Ideograph", "Ideographic"},
    200207: {"Unified_Ideograph", "Ideographic"},
    200208: {"Unified_Ideograph", "Ideographic"},
    200209: {"Unified_Ideograph", "Ideographic"},
    200210: {"Unified_Ideograph", "Ideographic"},
    200211: {"Unified_Ideograph", "Ideographic"},
    200212: {"Unified_Ideograph", "Ideographic"},
    200213: {"Unified_Ideograph", "Ideographic"},
    200214: {"Unified_Ideograph", "Ideographic"},
    200215: {"Unified_Ideograph", "Ideographic"},
    200216: {"Unified_Ideograph", "Ideographic"},
    200217: {"Unified_Ideograph", "Ideographic"},
    200218: {"Unified_Ideograph", "Ideographic"},
    200219: {"Unified_Ideograph", "Ideographic"},
    200220: {"Unified_Ideograph", "Ideographic"},
    200221: {"Unified_Ideograph", "Ideographic"},
    200222: {"Unified_Ideograph", "Ideographic"},
    200223: {"Unified_Ideograph", "Ideographic"},
    200224: {"Unified_Ideograph", "Ideographic"},
    200225: {"Unified_Ideograph", "Ideographic"},
    200226: {"Unified_Ideograph", "Ideographic"},
    200227: {"Unified_Ideograph", "Ideographic"},
    200228: {"Unified_Ideograph", "Ideographic"},
    200229: {"Unified_Ideograph", "Ideographic"},
    200230: {"Unified_Ideograph", "Ideographic"},
    200231: {"Unified_Ideograph", "Ideographic"},
    200232: {"Unified_Ideograph", "Ideographic"},
    200233: {"Unified_Ideograph", "Ideographic"},
    200234: {"Unified_Ideograph", "Ideographic"},
    200235: {"Unified_Ideograph", "Ideographic"},
    200236: {"Unified_Ideograph", "Ideographic"},
    200237: {"Unified_Ideograph", "Ideographic"},
    200238: {"Unified_Ideograph", "Ideographic"},
    200239: {"Unified_Ideograph", "Ideographic"},
    200240: {"Unified_Ideograph", "Ideographic"},
    200241: {"Unified_Ideograph", "Ideographic"},
    200242: {"Unified_Ideograph", "Ideographic"},
    200243: {"Unified_Ideograph", "Ideographic"},
    200244: {"Unified_Ideograph", "Ideographic"},
    200245: {"Unified_Ideograph", "Ideographic"},
    200246: {"Unified_Ideograph", "Ideographic"},
    200247: {"Unified_Ideograph", "Ideographic"},
    200248: {"Unified_Ideograph", "Ideographic"},
    200249: {"Unified_Ideograph", "Ideographic"},
    200250: {"Unified_Ideograph", "Ideographic"},
    200251: {"Unified_Ideograph", "Ideographic"},
    200252: {"Unified_Ideograph", "Ideographic"},
    200253: {"Unified_Ideograph", "Ideographic"},
    200254: {"Unified_Ideograph", "Ideographic"},
    200255: {"Unified_Ideograph", "Ideographic"},
    200256: {"Unified_Ideograph", "Ideographic"},
    200257: {"Unified_Ideograph", "Ideographic"},
    200258: {"Unified_Ideograph", "Ideographic"},
    200259: {"Unified_Ideograph", "Ideographic"},
    200260: {"Unified_Ideograph", "Ideographic"},
    200261: {"Unified_Ideograph", "Ideographic"},
    200262: {"Unified_Ideograph", "Ideographic"},
    200263: {"Unified_Ideograph", "Ideographic"},
    200264: {"Unified_Ideograph", "Ideographic"},
    200265: {"Unified_Ideograph", "Ideographic"},
    200266: {"Unified_Ideograph", "Ideographic"},
    200267: {"Unified_Ideograph", "Ideographic"},
    200268: {"Unified_Ideograph", "Ideographic"},
    200269: {"Unified_Ideograph", "Ideographic"},
    200270: {"Unified_Ideograph", "Ideographic"},
    200271: {"Unified_Ideograph", "Ideographic"},
    200272: {"Unified_Ideograph", "Ideographic"},
    200273: {"Unified_Ideograph", "Ideographic"},
    200274: {"Unified_Ideograph", "Ideographic"},
    200275: {"Unified_Ideograph", "Ideographic"},
    200276: {"Unified_Ideograph", "Ideographic"},
    200277: {"Unified_Ideograph", "Ideographic"},
    200278: {"Unified_Ideograph", "Ideographic"},
    200279: {"Unified_Ideograph", "Ideographic"},
    200280: {"Unified_Ideograph", "Ideographic"},
    200281: {"Unified_Ideograph", "Ideographic"},
    200282: {"Unified_Ideograph", "Ideographic"},
    200283: {"Unified_Ideograph", "Ideographic"},
    200284: {"Unified_Ideograph", "Ideographic"},
    200285: {"Unified_Ideograph", "Ideographic"},
    200286: {"Unified_Ideograph", "Ideographic"},
    200287: {"Unified_Ideograph", "Ideographic"},
    200288: {"Unified_Ideograph", "Ideographic"},
    200289: {"Unified_Ideograph", "Ideographic"},
    200290: {"Unified_Ideograph", "Ideographic"},
    200291: {"Unified_Ideograph", "Ideographic"},
    200292: {"Unified_Ideograph", "Ideographic"},
    200293: {"Unified_Ideograph", "Ideographic"},
    200294: {"Unified_Ideograph", "Ideographic"},
    200295: {"Unified_Ideograph", "Ideographic"},
    200296: {"Unified_Ideograph", "Ideographic"},
    200297: {"Unified_Ideograph", "Ideographic"},
    200298: {"Unified_Ideograph", "Ideographic"},
    200299: {"Unified_Ideograph", "Ideographic"},
    200300: {"Unified_Ideograph", "Ideographic"},
    200301: {"Unified_Ideograph", "Ideographic"},
    200302: {"Unified_Ideograph", "Ideographic"},
    200303: {"Unified_Ideograph", "Ideographic"},
    200304: {"Unified_Ideograph", "Ideographic"},
    200305: {"Unified_Ideograph", "Ideographic"},
    200306: {"Unified_Ideograph", "Ideographic"},
    200307: {"Unified_Ideograph", "Ideographic"},
    200308: {"Unified_Ideograph", "Ideographic"},
    200309: {"Unified_Ideograph", "Ideographic"},
    200310: {"Unified_Ideograph", "Ideographic"},
    200311: {"Unified_Ideograph", "Ideographic"},
    200312: {"Unified_Ideograph", "Ideographic"},
    200313: {"Unified_Ideograph", "Ideographic"},
    200314: {"Unified_Ideograph", "Ideographic"},
    200315: {"Unified_Ideograph", "Ideographic"},
    200316: {"Unified_Ideograph", "Ideographic"},
    200317: {"Unified_Ideograph", "Ideographic"},
    200318: {"Unified_Ideograph", "Ideographic"},
    200319: {"Unified_Ideograph", "Ideographic"},
    200320: {"Unified_Ideograph", "Ideographic"},
    200321: {"Unified_Ideograph", "Ideographic"},
    200322: {"Unified_Ideograph", "Ideographic"},
    200323: {"Unified_Ideograph", "Ideographic"},
    200324: {"Unified_Ideograph", "Ideographic"},
    200325: {"Unified_Ideograph", "Ideographic"},
    200326: {"Unified_Ideograph", "Ideographic"},
    200327: {"Unified_Ideograph", "Ideographic"},
    200328: {"Unified_Ideograph", "Ideographic"},
    200329: {"Unified_Ideograph", "Ideographic"},
    200330: {"Unified_Ideograph", "Ideographic"},
    200331: {"Unified_Ideograph", "Ideographic"},
    200332: {"Unified_Ideograph", "Ideographic"},
    200333: {"Unified_Ideograph", "Ideographic"},
    200334: {"Unified_Ideograph", "Ideographic"},
    200335: {"Unified_Ideograph", "Ideographic"},
    200336: {"Unified_Ideograph", "Ideographic"},
    200337: {"Unified_Ideograph", "Ideographic"},
    200338: {"Unified_Ideograph", "Ideographic"},
    200339: {"Unified_Ideograph", "Ideographic"},
    200340: {"Unified_Ideograph", "Ideographic"},
    200341: {"Unified_Ideograph", "Ideographic"},
    200342: {"Unified_Ideograph", "Ideographic"},
    200343: {"Unified_Ideograph", "Ideographic"},
    200344: {"Unified_Ideograph", "Ideographic"},
    200345: {"Unified_Ideograph", "Ideographic"},
    200346: {"Unified_Ideograph", "Ideographic"},
    200347: {"Unified_Ideograph", "Ideographic"},
    200348: {"Unified_Ideograph", "Ideographic"},
    200349: {"Unified_Ideograph", "Ideographic"},
    200350: {"Unified_Ideograph", "Ideographic"},
    200351: {"Unified_Ideograph", "Ideographic"},
    200352: {"Unified_Ideograph", "Ideographic"},
    200353: {"Unified_Ideograph", "Ideographic"},
    200354: {"Unified_Ideograph", "Ideographic"},
    200355: {"Unified_Ideograph", "Ideographic"},
    200356: {"Unified_Ideograph", "Ideographic"},
    200357: {"Unified_Ideograph", "Ideographic"},
    200358: {"Unified_Ideograph", "Ideographic"},
    200359: {"Unified_Ideograph", "Ideographic"},
    200360: {"Unified_Ideograph", "Ideographic"},
    200361: {"Unified_Ideograph", "Ideographic"},
    200362: {"Unified_Ideograph", "Ideographic"},
    200363: {"Unified_Ideograph", "Ideographic"},
    200364: {"Unified_Ideograph", "Ideographic"},
    200365: {"Unified_Ideograph", "Ideographic"},
    200366: {"Unified_Ideograph", "Ideographic"},
    200367: {"Unified_Ideograph", "Ideographic"},
    200368: {"Unified_Ideograph", "Ideographic"},
    200369: {"Unified_Ideograph", "Ideographic"},
    200370: {"Unified_Ideograph", "Ideographic"},
    200371: {"Unified_Ideograph", "Ideographic"},
    200372: {"Unified_Ideograph", "Ideographic"},
    200373: {"Unified_Ideograph", "Ideographic"},
    200374: {"Unified_Ideograph", "Ideographic"},
    200375: {"Unified_Ideograph", "Ideographic"},
    200376: {"Unified_Ideograph", "Ideographic"},
    200377: {"Unified_Ideograph", "Ideographic"},
    200378: {"Unified_Ideograph", "Ideographic"},
    200379: {"Unified_Ideograph", "Ideographic"},
    200380: {"Unified_Ideograph", "Ideographic"},
    200381: {"Unified_Ideograph", "Ideographic"},
    200382: {"Unified_Ideograph", "Ideographic"},
    200383: {"Unified_Ideograph", "Ideographic"},
    200384: {"Unified_Ideograph", "Ideographic"},
    200385: {"Unified_Ideograph", "Ideographic"},
    200386: {"Unified_Ideograph", "Ideographic"},
    200387: {"Unified_Ideograph", "Ideographic"},
    200388: {"Unified_Ideograph", "Ideographic"},
    200389: {"Unified_Ideograph", "Ideographic"},
    200390: {"Unified_Ideograph", "Ideographic"},
    200391: {"Unified_Ideograph", "Ideographic"},
    200392: {"Unified_Ideograph", "Ideographic"},
    200393: {"Unified_Ideograph", "Ideographic"},
    200394: {"Unified_Ideograph", "Ideographic"},
    200395: {"Unified_Ideograph", "Ideographic"},
    200396: {"Unified_Ideograph", "Ideographic"},
    200397: {"Unified_Ideograph", "Ideographic"},
    200398: {"Unified_Ideograph", "Ideographic"},
    200399: {"Unified_Ideograph", "Ideographic"},
    200400: {"Unified_Ideograph", "Ideographic"},
    200401: {"Unified_Ideograph", "Ideographic"},
    200402: {"Unified_Ideograph", "Ideographic"},
    200403: {"Unified_Ideograph", "Ideographic"},
    200404: {"Unified_Ideograph", "Ideographic"},
    200405: {"Unified_Ideograph", "Ideographic"},
    200406: {"Unified_Ideograph", "Ideographic"},
    200407: {"Unified_Ideograph", "Ideographic"},
    200408: {"Unified_Ideograph", "Ideographic"},
    200409: {"Unified_Ideograph", "Ideographic"},
    200410: {"Unified_Ideograph", "Ideographic"},
    200411: {"Unified_Ideograph", "Ideographic"},
    200412: {"Unified_Ideograph", "Ideographic"},
    200413: {"Unified_Ideograph", "Ideographic"},
    200414: {"Unified_Ideograph", "Ideographic"},
    200415: {"Unified_Ideograph", "Ideographic"},
    200416: {"Unified_Ideograph", "Ideographic"},
    200417: {"Unified_Ideograph", "Ideographic"},
    200418: {"Unified_Ideograph", "Ideographic"},
    200419: {"Unified_Ideograph", "Ideographic"},
    200420: {"Unified_Ideograph", "Ideographic"},
    200421: {"Unified_Ideograph", "Ideographic"},
    200422: {"Unified_Ideograph", "Ideographic"},
    200423: {"Unified_Ideograph", "Ideographic"},
    200424: {"Unified_Ideograph", "Ideographic"},
    200425: {"Unified_Ideograph", "Ideographic"},
    200426: {"Unified_Ideograph", "Ideographic"},
    200427: {"Unified_Ideograph", "Ideographic"},
    200428: {"Unified_Ideograph", "Ideographic"},
    200429: {"Unified_Ideograph", "Ideographic"},
    200430: {"Unified_Ideograph", "Ideographic"},
    200431: {"Unified_Ideograph", "Ideographic"},
    200432: {"Unified_Ideograph", "Ideographic"},
    200433: {"Unified_Ideograph", "Ideographic"},
    200434: {"Unified_Ideograph", "Ideographic"},
    200435: {"Unified_Ideograph", "Ideographic"},
    200436: {"Unified_Ideograph", "Ideographic"},
    200437: {"Unified_Ideograph", "Ideographic"},
    200438: {"Unified_Ideograph", "Ideographic"},
    200439: {"Unified_Ideograph", "Ideographic"},
    200440: {"Unified_Ideograph", "Ideographic"},
    200441: {"Unified_Ideograph", "Ideographic"},
    200442: {"Unified_Ideograph", "Ideographic"},
    200443: {"Unified_Ideograph", "Ideographic"},
    200444: {"Unified_Ideograph", "Ideographic"},
    200445: {"Unified_Ideograph", "Ideographic"},
    200446: {"Unified_Ideograph", "Ideographic"},
    200447: {"Unified_Ideograph", "Ideographic"},
    200448: {"Unified_Ideograph", "Ideographic"},
    200449: {"Unified_Ideograph", "Ideographic"},
    200450: {"Unified_Ideograph", "Ideographic"},
    200451: {"Unified_Ideograph", "Ideographic"},
    200452: {"Unified_Ideograph", "Ideographic"},
    200453: {"Unified_Ideograph", "Ideographic"},
    200454: {"Unified_Ideograph", "Ideographic"},
    200455: {"Unified_Ideograph", "Ideographic"},
    200456: {"Unified_Ideograph", "Ideographic"},
    200457: {"Unified_Ideograph", "Ideographic"},
    200458: {"Unified_Ideograph", "Ideographic"},
    200459: {"Unified_Ideograph", "Ideographic"},
    200460: {"Unified_Ideograph", "Ideographic"},
    200461: {"Unified_Ideograph", "Ideographic"},
    200462: {"Unified_Ideograph", "Ideographic"},
    200463: {"Unified_Ideograph", "Ideographic"},
    200464: {"Unified_Ideograph", "Ideographic"},
    200465: {"Unified_Ideograph", "Ideographic"},
    200466: {"Unified_Ideograph", "Ideographic"},
    200467: {"Unified_Ideograph", "Ideographic"},
    200468: {"Unified_Ideograph", "Ideographic"},
    200469: {"Unified_Ideograph", "Ideographic"},
    200470: {"Unified_Ideograph", "Ideographic"},
    200471: {"Unified_Ideograph", "Ideographic"},
    200472: {"Unified_Ideograph", "Ideographic"},
    200473: {"Unified_Ideograph", "Ideographic"},
    200474: {"Unified_Ideograph", "Ideographic"},
    200475: {"Unified_Ideograph", "Ideographic"},
    200476: {"Unified_Ideograph", "Ideographic"},
    200477: {"Unified_Ideograph", "Ideographic"},
    200478: {"Unified_Ideograph", "Ideographic"},
    200479: {"Unified_Ideograph", "Ideographic"},
    200480: {"Unified_Ideograph", "Ideographic"},
    200481: {"Unified_Ideograph", "Ideographic"},
    200482: {"Unified_Ideograph", "Ideographic"},
    200483: {"Unified_Ideograph", "Ideographic"},
    200484: {"Unified_Ideograph", "Ideographic"},
    200485: {"Unified_Ideograph", "Ideographic"},
    200486: {"Unified_Ideograph", "Ideographic"},
    200487: {"Unified_Ideograph", "Ideographic"},
    200488: {"Unified_Ideograph", "Ideographic"},
    200489: {"Unified_Ideograph", "Ideographic"},
    200490: {"Unified_Ideograph", "Ideographic"},
    200491: {"Unified_Ideograph", "Ideographic"},
    200492: {"Unified_Ideograph", "Ideographic"},
    200493: {"Unified_Ideograph", "Ideographic"},
    200494: {"Unified_Ideograph", "Ideographic"},
    200495: {"Unified_Ideograph", "Ideographic"},
    200496: {"Unified_Ideograph", "Ideographic"},
    200497: {"Unified_Ideograph", "Ideographic"},
    200498: {"Unified_Ideograph", "Ideographic"},
    200499: {"Unified_Ideograph", "Ideographic"},
    200500: {"Unified_Ideograph", "Ideographic"},
    200501: {"Unified_Ideograph", "Ideographic"},
    200502: {"Unified_Ideograph", "Ideographic"},
    200503: {"Unified_Ideograph", "Ideographic"},
    200504: {"Unified_Ideograph", "Ideographic"},
    200505: {"Unified_Ideograph", "Ideographic"},
    200506: {"Unified_Ideograph", "Ideographic"},
    200507: {"Unified_Ideograph", "Ideographic"},
    200508: {"Unified_Ideograph", "Ideographic"},
    200509: {"Unified_Ideograph", "Ideographic"},
    200510: {"Unified_Ideograph", "Ideographic"},
    200511: {"Unified_Ideograph", "Ideographic"},
    200512: {"Unified_Ideograph", "Ideographic"},
    200513: {"Unified_Ideograph", "Ideographic"},
    200514: {"Unified_Ideograph", "Ideographic"},
    200515: {"Unified_Ideograph", "Ideographic"},
    200516: {"Unified_Ideograph", "Ideographic"},
    200517: {"Unified_Ideograph", "Ideographic"},
    200518: {"Unified_Ideograph", "Ideographic"},
    200519: {"Unified_Ideograph", "Ideographic"},
    200520: {"Unified_Ideograph", "Ideographic"},
    200521: {"Unified_Ideograph", "Ideographic"},
    200522: {"Unified_Ideograph", "Ideographic"},
    200523: {"Unified_Ideograph", "Ideographic"},
    200524: {"Unified_Ideograph", "Ideographic"},
    200525: {"Unified_Ideograph", "Ideographic"},
    200526: {"Unified_Ideograph", "Ideographic"},
    200527: {"Unified_Ideograph", "Ideographic"},
    200528: {"Unified_Ideograph", "Ideographic"},
    200529: {"Unified_Ideograph", "Ideographic"},
    200530: {"Unified_Ideograph", "Ideographic"},
    200531: {"Unified_Ideograph", "Ideographic"},
    200532: {"Unified_Ideograph", "Ideographic"},
    200533: {"Unified_Ideograph", "Ideographic"},
    200534: {"Unified_Ideograph", "Ideographic"},
    200535: {"Unified_Ideograph", "Ideographic"},
    200536: {"Unified_Ideograph", "Ideographic"},
    200537: {"Unified_Ideograph", "Ideographic"},
    200538: {"Unified_Ideograph", "Ideographic"},
    200539: {"Unified_Ideograph", "Ideographic"},
    200540: {"Unified_Ideograph", "Ideographic"},
    200541: {"Unified_Ideograph", "Ideographic"},
    200542: {"Unified_Ideograph", "Ideographic"},
    200543: {"Unified_Ideograph", "Ideographic"},
    200544: {"Unified_Ideograph", "Ideographic"},
    200545: {"Unified_Ideograph", "Ideographic"},
    200546: {"Unified_Ideograph", "Ideographic"},
    200547: {"Unified_Ideograph", "Ideographic"},
    200548: {"Unified_Ideograph", "Ideographic"},
    200549: {"Unified_Ideograph", "Ideographic"},
    200550: {"Unified_Ideograph", "Ideographic"},
    200551: {"Unified_Ideograph", "Ideographic"},
    200552: {"Unified_Ideograph", "Ideographic"},
    200553: {"Unified_Ideograph", "Ideographic"},
    200554: {"Unified_Ideograph", "Ideographic"},
    200555: {"Unified_Ideograph", "Ideographic"},
    200556: {"Unified_Ideograph", "Ideographic"},
    200557: {"Unified_Ideograph", "Ideographic"},
    200558: {"Unified_Ideograph", "Ideographic"},
    200559: {"Unified_Ideograph", "Ideographic"},
    200560: {"Unified_Ideograph", "Ideographic"},
    200561: {"Unified_Ideograph", "Ideographic"},
    200562: {"Unified_Ideograph", "Ideographic"},
    200563: {"Unified_Ideograph", "Ideographic"},
    200564: {"Unified_Ideograph", "Ideographic"},
    200565: {"Unified_Ideograph", "Ideographic"},
    200566: {"Unified_Ideograph", "Ideographic"},
    200567: {"Unified_Ideograph", "Ideographic"},
    200568: {"Unified_Ideograph", "Ideographic"},
    200569: {"Unified_Ideograph", "Ideographic"},
    200570: {"Unified_Ideograph", "Ideographic"},
    200571: {"Unified_Ideograph", "Ideographic"},
    200572: {"Unified_Ideograph", "Ideographic"},
    200573: {"Unified_Ideograph", "Ideographic"},
    200574: {"Unified_Ideograph", "Ideographic"},
    200575: {"Unified_Ideograph", "Ideographic"},
    200576: {"Unified_Ideograph", "Ideographic"},
    200577: {"Unified_Ideograph", "Ideographic"},
    200578: {"Unified_Ideograph", "Ideographic"},
    200579: {"Unified_Ideograph", "Ideographic"},
    200580: {"Unified_Ideograph", "Ideographic"},
    200581: {"Unified_Ideograph", "Ideographic"},
    200582: {"Unified_Ideograph", "Ideographic"},
    200583: {"Unified_Ideograph", "Ideographic"},
    200584: {"Unified_Ideograph", "Ideographic"},
    200585: {"Unified_Ideograph", "Ideographic"},
    200586: {"Unified_Ideograph", "Ideographic"},
    200587: {"Unified_Ideograph", "Ideographic"},
    200588: {"Unified_Ideograph", "Ideographic"},
    200589: {"Unified_Ideograph", "Ideographic"},
    200590: {"Unified_Ideograph", "Ideographic"},
    200591: {"Unified_Ideograph", "Ideographic"},
    200592: {"Unified_Ideograph", "Ideographic"},
    200593: {"Unified_Ideograph", "Ideographic"},
    200594: {"Unified_Ideograph", "Ideographic"},
    200595: {"Unified_Ideograph", "Ideographic"},
    200596: {"Unified_Ideograph", "Ideographic"},
    200597: {"Unified_Ideograph", "Ideographic"},
    200598: {"Unified_Ideograph", "Ideographic"},
    200599: {"Unified_Ideograph", "Ideographic"},
    200600: {"Unified_Ideograph", "Ideographic"},
    200601: {"Unified_Ideograph", "Ideographic"},
    200602: {"Unified_Ideograph", "Ideographic"},
    200603: {"Unified_Ideograph", "Ideographic"},
    200604: {"Unified_Ideograph", "Ideographic"},
    200605: {"Unified_Ideograph", "Ideographic"},
    200606: {"Unified_Ideograph", "Ideographic"},
    200607: {"Unified_Ideograph", "Ideographic"},
    200608: {"Unified_Ideograph", "Ideographic"},
    200609: {"Unified_Ideograph", "Ideographic"},
    200610: {"Unified_Ideograph", "Ideographic"},
    200611: {"Unified_Ideograph", "Ideographic"},
    200612: {"Unified_Ideograph", "Ideographic"},
    200613: {"Unified_Ideograph", "Ideographic"},
    200614: {"Unified_Ideograph", "Ideographic"},
    200615: {"Unified_Ideograph", "Ideographic"},
    200616: {"Unified_Ideograph", "Ideographic"},
    200617: {"Unified_Ideograph", "Ideographic"},
    200618: {"Unified_Ideograph", "Ideographic"},
    200619: {"Unified_Ideograph", "Ideographic"},
    200620: {"Unified_Ideograph", "Ideographic"},
    200621: {"Unified_Ideograph", "Ideographic"},
    200622: {"Unified_Ideograph", "Ideographic"},
    200623: {"Unified_Ideograph", "Ideographic"},
    200624: {"Unified_Ideograph", "Ideographic"},
    200625: {"Unified_Ideograph", "Ideographic"},
    200626: {"Unified_Ideograph", "Ideographic"},
    200627: {"Unified_Ideograph", "Ideographic"},
    200628: {"Unified_Ideograph", "Ideographic"},
    200629: {"Unified_Ideograph", "Ideographic"},
    200630: {"Unified_Ideograph", "Ideographic"},
    200631: {"Unified_Ideograph", "Ideographic"},
    200632: {"Unified_Ideograph", "Ideographic"},
    200633: {"Unified_Ideograph", "Ideographic"},
    200634: {"Unified_Ideograph", "Ideographic"},
    200635: {"Unified_Ideograph", "Ideographic"},
    200636: {"Unified_Ideograph", "Ideographic"},
    200637: {"Unified_Ideograph", "Ideographic"},
    200638: {"Unified_Ideograph", "Ideographic"},
    200639: {"Unified_Ideograph", "Ideographic"},
    200640: {"Unified_Ideograph", "Ideographic"},
    200641: {"Unified_Ideograph", "Ideographic"},
    200642: {"Unified_Ideograph", "Ideographic"},
    200643: {"Unified_Ideograph", "Ideographic"},
    200644: {"Unified_Ideograph", "Ideographic"},
    200645: {"Unified_Ideograph", "Ideographic"},
    200646: {"Unified_Ideograph", "Ideographic"},
    200647: {"Unified_Ideograph", "Ideographic"},
    200648: {"Unified_Ideograph", "Ideographic"},
    200649: {"Unified_Ideograph", "Ideographic"},
    200650: {"Unified_Ideograph", "Ideographic"},
    200651: {"Unified_Ideograph", "Ideographic"},
    200652: {"Unified_Ideograph", "Ideographic"},
    200653: {"Unified_Ideograph", "Ideographic"},
    200654: {"Unified_Ideograph", "Ideographic"},
    200655: {"Unified_Ideograph", "Ideographic"},
    200656: {"Unified_Ideograph", "Ideographic"},
    200657: {"Unified_Ideograph", "Ideographic"},
    200658: {"Unified_Ideograph", "Ideographic"},
    200659: {"Unified_Ideograph", "Ideographic"},
    200660: {"Unified_Ideograph", "Ideographic"},
    200661: {"Unified_Ideograph", "Ideographic"},
    200662: {"Unified_Ideograph", "Ideographic"},
    200663: {"Unified_Ideograph", "Ideographic"},
    200664: {"Unified_Ideograph", "Ideographic"},
    200665: {"Unified_Ideograph", "Ideographic"},
    200666: {"Unified_Ideograph", "Ideographic"},
    200667: {"Unified_Ideograph", "Ideographic"},
    200668: {"Unified_Ideograph", "Ideographic"},
    200669: {"Unified_Ideograph", "Ideographic"},
    200670: {"Unified_Ideograph", "Ideographic"},
    200671: {"Unified_Ideograph", "Ideographic"},
    200672: {"Unified_Ideograph", "Ideographic"},
    200673: {"Unified_Ideograph", "Ideographic"},
    200674: {"Unified_Ideograph", "Ideographic"},
    200675: {"Unified_Ideograph", "Ideographic"},
    200676: {"Unified_Ideograph", "Ideographic"},
    200677: {"Unified_Ideograph", "Ideographic"},
    200678: {"Unified_Ideograph", "Ideographic"},
    200679: {"Unified_Ideograph", "Ideographic"},
    200680: {"Unified_Ideograph", "Ideographic"},
    200681: {"Unified_Ideograph", "Ideographic"},
    200682: {"Unified_Ideograph", "Ideographic"},
    200683: {"Unified_Ideograph", "Ideographic"},
    200684: {"Unified_Ideograph", "Ideographic"},
    200685: {"Unified_Ideograph", "Ideographic"},
    200686: {"Unified_Ideograph", "Ideographic"},
    200687: {"Unified_Ideograph", "Ideographic"},
    200688: {"Unified_Ideograph", "Ideographic"},
    200689: {"Unified_Ideograph", "Ideographic"},
    200690: {"Unified_Ideograph", "Ideographic"},
    200691: {"Unified_Ideograph", "Ideographic"},
    200692: {"Unified_Ideograph", "Ideographic"},
    200693: {"Unified_Ideograph", "Ideographic"},
    200694: {"Unified_Ideograph", "Ideographic"},
    200695: {"Unified_Ideograph", "Ideographic"},
    200696: {"Unified_Ideograph", "Ideographic"},
    200697: {"Unified_Ideograph", "Ideographic"},
    200698: {"Unified_Ideograph", "Ideographic"},
    200699: {"Unified_Ideograph", "Ideographic"},
    200700: {"Unified_Ideograph", "Ideographic"},
    200701: {"Unified_Ideograph", "Ideographic"},
    200702: {"Unified_Ideograph", "Ideographic"},
    200703: {"Unified_Ideograph", "Ideographic"},
    200704: {"Unified_Ideograph", "Ideographic"},
    200705: {"Unified_Ideograph", "Ideographic"},
    200706: {"Unified_Ideograph", "Ideographic"},
    200707: {"Unified_Ideograph", "Ideographic"},
    200708: {"Unified_Ideograph", "Ideographic"},
    200709: {"Unified_Ideograph", "Ideographic"},
    200710: {"Unified_Ideograph", "Ideographic"},
    200711: {"Unified_Ideograph", "Ideographic"},
    200712: {"Unified_Ideograph", "Ideographic"},
    200713: {"Unified_Ideograph", "Ideographic"},
    200714: {"Unified_Ideograph", "Ideographic"},
    200715: {"Unified_Ideograph", "Ideographic"},
    200716: {"Unified_Ideograph", "Ideographic"},
    200717: {"Unified_Ideograph", "Ideographic"},
    200718: {"Unified_Ideograph", "Ideographic"},
    200719: {"Unified_Ideograph", "Ideographic"},
    200720: {"Unified_Ideograph", "Ideographic"},
    200721: {"Unified_Ideograph", "Ideographic"},
    200722: {"Unified_Ideograph", "Ideographic"},
    200723: {"Unified_Ideograph", "Ideographic"},
    200724: {"Unified_Ideograph", "Ideographic"},
    200725: {"Unified_Ideograph", "Ideographic"},
    200726: {"Unified_Ideograph", "Ideographic"},
    200727: {"Unified_Ideograph", "Ideographic"},
    200728: {"Unified_Ideograph", "Ideographic"},
    200729: {"Unified_Ideograph", "Ideographic"},
    200730: {"Unified_Ideograph", "Ideographic"},
    200731: {"Unified_Ideograph", "Ideographic"},
    200732: {"Unified_Ideograph", "Ideographic"},
    200733: {"Unified_Ideograph", "Ideographic"},
    200734: {"Unified_Ideograph", "Ideographic"},
    200735: {"Unified_Ideograph", "Ideographic"},
    200736: {"Unified_Ideograph", "Ideographic"},
    200737: {"Unified_Ideograph", "Ideographic"},
    200738: {"Unified_Ideograph", "Ideographic"},
    200739: {"Unified_Ideograph", "Ideographic"},
    200740: {"Unified_Ideograph", "Ideographic"},
    200741: {"Unified_Ideograph", "Ideographic"},
    200742: {"Unified_Ideograph", "Ideographic"},
    200743: {"Unified_Ideograph", "Ideographic"},
    200744: {"Unified_Ideograph", "Ideographic"},
    200745: {"Unified_Ideograph", "Ideographic"},
    200746: {"Unified_Ideograph", "Ideographic"},
    200747: {"Unified_Ideograph", "Ideographic"},
    200748: {"Unified_Ideograph", "Ideographic"},
    200749: {"Unified_Ideograph", "Ideographic"},
    200750: {"Unified_Ideograph", "Ideographic"},
    200751: {"Unified_Ideograph", "Ideographic"},
    200752: {"Unified_Ideograph", "Ideographic"},
    200753: {"Unified_Ideograph", "Ideographic"},
    200754: {"Unified_Ideograph", "Ideographic"},
    200755: {"Unified_Ideograph", "Ideographic"},
    200756: {"Unified_Ideograph", "Ideographic"},
    200757: {"Unified_Ideograph", "Ideographic"},
    200758: {"Unified_Ideograph", "Ideographic"},
    200759: {"Unified_Ideograph", "Ideographic"},
    200760: {"Unified_Ideograph", "Ideographic"},
    200761: {"Unified_Ideograph", "Ideographic"},
    200762: {"Unified_Ideograph", "Ideographic"},
    200763: {"Unified_Ideograph", "Ideographic"},
    200764: {"Unified_Ideograph", "Ideographic"},
    200765: {"Unified_Ideograph", "Ideographic"},
    200766: {"Unified_Ideograph", "Ideographic"},
    200767: {"Unified_Ideograph", "Ideographic"},
    200768: {"Unified_Ideograph", "Ideographic"},
    200769: {"Unified_Ideograph", "Ideographic"},
    200770: {"Unified_Ideograph", "Ideographic"},
    200771: {"Unified_Ideograph", "Ideographic"},
    200772: {"Unified_Ideograph", "Ideographic"},
    200773: {"Unified_Ideograph", "Ideographic"},
    200774: {"Unified_Ideograph", "Ideographic"},
    200775: {"Unified_Ideograph", "Ideographic"},
    200776: {"Unified_Ideograph", "Ideographic"},
    200777: {"Unified_Ideograph", "Ideographic"},
    200778: {"Unified_Ideograph", "Ideographic"},
    200779: {"Unified_Ideograph", "Ideographic"},
    200780: {"Unified_Ideograph", "Ideographic"},
    200781: {"Unified_Ideograph", "Ideographic"},
    200782: {"Unified_Ideograph", "Ideographic"},
    200783: {"Unified_Ideograph", "Ideographic"},
    200784: {"Unified_Ideograph", "Ideographic"},
    200785: {"Unified_Ideograph", "Ideographic"},
    200786: {"Unified_Ideograph", "Ideographic"},
    200787: {"Unified_Ideograph", "Ideographic"},
    200788: {"Unified_Ideograph", "Ideographic"},
    200789: {"Unified_Ideograph", "Ideographic"},
    200790: {"Unified_Ideograph", "Ideographic"},
    200791: {"Unified_Ideograph", "Ideographic"},
    200792: {"Unified_Ideograph", "Ideographic"},
    200793: {"Unified_Ideograph", "Ideographic"},
    200794: {"Unified_Ideograph", "Ideographic"},
    200795: {"Unified_Ideograph", "Ideographic"},
    200796: {"Unified_Ideograph", "Ideographic"},
    200797: {"Unified_Ideograph", "Ideographic"},
    200798: {"Unified_Ideograph", "Ideographic"},
    200799: {"Unified_Ideograph", "Ideographic"},
    200800: {"Unified_Ideograph", "Ideographic"},
    200801: {"Unified_Ideograph", "Ideographic"},
    200802: {"Unified_Ideograph", "Ideographic"},
    200803: {"Unified_Ideograph", "Ideographic"},
    200804: {"Unified_Ideograph", "Ideographic"},
    200805: {"Unified_Ideograph", "Ideographic"},
    200806: {"Unified_Ideograph", "Ideographic"},
    200807: {"Unified_Ideograph", "Ideographic"},
    200808: {"Unified_Ideograph", "Ideographic"},
    200809: {"Unified_Ideograph", "Ideographic"},
    200810: {"Unified_Ideograph", "Ideographic"},
    200811: {"Unified_Ideograph", "Ideographic"},
    200812: {"Unified_Ideograph", "Ideographic"},
    200813: {"Unified_Ideograph", "Ideographic"},
    200814: {"Unified_Ideograph", "Ideographic"},
    200815: {"Unified_Ideograph", "Ideographic"},
    200816: {"Unified_Ideograph", "Ideographic"},
    200817: {"Unified_Ideograph", "Ideographic"},
    200818: {"Unified_Ideograph", "Ideographic"},
    200819: {"Unified_Ideograph", "Ideographic"},
    200820: {"Unified_Ideograph", "Ideographic"},
    200821: {"Unified_Ideograph", "Ideographic"},
    200822: {"Unified_Ideograph", "Ideographic"},
    200823: {"Unified_Ideograph", "Ideographic"},
    200824: {"Unified_Ideograph", "Ideographic"},
    200825: {"Unified_Ideograph", "Ideographic"},
    200826: {"Unified_Ideograph", "Ideographic"},
    200827: {"Unified_Ideograph", "Ideographic"},
    200828: {"Unified_Ideograph", "Ideographic"},
    200829: {"Unified_Ideograph", "Ideographic"},
    200830: {"Unified_Ideograph", "Ideographic"},
    200831: {"Unified_Ideograph", "Ideographic"},
    200832: {"Unified_Ideograph", "Ideographic"},
    200833: {"Unified_Ideograph", "Ideographic"},
    200834: {"Unified_Ideograph", "Ideographic"},
    200835: {"Unified_Ideograph", "Ideographic"},
    200836: {"Unified_Ideograph", "Ideographic"},
    200837: {"Unified_Ideograph", "Ideographic"},
    200838: {"Unified_Ideograph", "Ideographic"},
    200839: {"Unified_Ideograph", "Ideographic"},
    200840: {"Unified_Ideograph", "Ideographic"},
    200841: {"Unified_Ideograph", "Ideographic"},
    200842: {"Unified_Ideograph", "Ideographic"},
    200843: {"Unified_Ideograph", "Ideographic"},
    200844: {"Unified_Ideograph", "Ideographic"},
    200845: {"Unified_Ideograph", "Ideographic"},
    200846: {"Unified_Ideograph", "Ideographic"},
    200847: {"Unified_Ideograph", "Ideographic"},
    200848: {"Unified_Ideograph", "Ideographic"},
    200849: {"Unified_Ideograph", "Ideographic"},
    200850: {"Unified_Ideograph", "Ideographic"},
    200851: {"Unified_Ideograph", "Ideographic"},
    200852: {"Unified_Ideograph", "Ideographic"},
    200853: {"Unified_Ideograph", "Ideographic"},
    200854: {"Unified_Ideograph", "Ideographic"},
    200855: {"Unified_Ideograph", "Ideographic"},
    200856: {"Unified_Ideograph", "Ideographic"},
    200857: {"Unified_Ideograph", "Ideographic"},
    200858: {"Unified_Ideograph", "Ideographic"},
    200859: {"Unified_Ideograph", "Ideographic"},
    200860: {"Unified_Ideograph", "Ideographic"},
    200861: {"Unified_Ideograph", "Ideographic"},
    200862: {"Unified_Ideograph", "Ideographic"},
    200863: {"Unified_Ideograph", "Ideographic"},
    200864: {"Unified_Ideograph", "Ideographic"},
    200865: {"Unified_Ideograph", "Ideographic"},
    200866: {"Unified_Ideograph", "Ideographic"},
    200867: {"Unified_Ideograph", "Ideographic"},
    200868: {"Unified_Ideograph", "Ideographic"},
    200869: {"Unified_Ideograph", "Ideographic"},
    200870: {"Unified_Ideograph", "Ideographic"},
    200871: {"Unified_Ideograph", "Ideographic"},
    200872: {"Unified_Ideograph", "Ideographic"},
    200873: {"Unified_Ideograph", "Ideographic"},
    200874: {"Unified_Ideograph", "Ideographic"},
    200875: {"Unified_Ideograph", "Ideographic"},
    200876: {"Unified_Ideograph", "Ideographic"},
    200877: {"Unified_Ideograph", "Ideographic"},
    200878: {"Unified_Ideograph", "Ideographic"},
    200879: {"Unified_Ideograph", "Ideographic"},
    200880: {"Unified_Ideograph", "Ideographic"},
    200881: {"Unified_Ideograph", "Ideographic"},
    200882: {"Unified_Ideograph", "Ideographic"},
    200883: {"Unified_Ideograph", "Ideographic"},
    200884: {"Unified_Ideograph", "Ideographic"},
    200885: {"Unified_Ideograph", "Ideographic"},
    200886: {"Unified_Ideograph", "Ideographic"},
    200887: {"Unified_Ideograph", "Ideographic"},
    200888: {"Unified_Ideograph", "Ideographic"},
    200889: {"Unified_Ideograph", "Ideographic"},
    200890: {"Unified_Ideograph", "Ideographic"},
    200891: {"Unified_Ideograph", "Ideographic"},
    200892: {"Unified_Ideograph", "Ideographic"},
    200893: {"Unified_Ideograph", "Ideographic"},
    200894: {"Unified_Ideograph", "Ideographic"},
    200895: {"Unified_Ideograph", "Ideographic"},
    200896: {"Unified_Ideograph", "Ideographic"},
    200897: {"Unified_Ideograph", "Ideographic"},
    200898: {"Unified_Ideograph", "Ideographic"},
    200899: {"Unified_Ideograph", "Ideographic"},
    200900: {"Unified_Ideograph", "Ideographic"},
    200901: {"Unified_Ideograph", "Ideographic"},
    200902: {"Unified_Ideograph", "Ideographic"},
    200903: {"Unified_Ideograph", "Ideographic"},
    200904: {"Unified_Ideograph", "Ideographic"},
    200905: {"Unified_Ideograph", "Ideographic"},
    200906: {"Unified_Ideograph", "Ideographic"},
    200907: {"Unified_Ideograph", "Ideographic"},
    200908: {"Unified_Ideograph", "Ideographic"},
    200909: {"Unified_Ideograph", "Ideographic"},
    200910: {"Unified_Ideograph", "Ideographic"},
    200911: {"Unified_Ideograph", "Ideographic"},
    200912: {"Unified_Ideograph", "Ideographic"},
    200913: {"Unified_Ideograph", "Ideographic"},
    200914: {"Unified_Ideograph", "Ideographic"},
    200915: {"Unified_Ideograph", "Ideographic"},
    200916: {"Unified_Ideograph", "Ideographic"},
    200917: {"Unified_Ideograph", "Ideographic"},
    200918: {"Unified_Ideograph", "Ideographic"},
    200919: {"Unified_Ideograph", "Ideographic"},
    200920: {"Unified_Ideograph", "Ideographic"},
    200921: {"Unified_Ideograph", "Ideographic"},
    200922: {"Unified_Ideograph", "Ideographic"},
    200923: {"Unified_Ideograph", "Ideographic"},
    200924: {"Unified_Ideograph", "Ideographic"},
    200925: {"Unified_Ideograph", "Ideographic"},
    200926: {"Unified_Ideograph", "Ideographic"},
    200927: {"Unified_Ideograph", "Ideographic"},
    200928: {"Unified_Ideograph", "Ideographic"},
    200929: {"Unified_Ideograph", "Ideographic"},
    200930: {"Unified_Ideograph", "Ideographic"},
    200931: {"Unified_Ideograph", "Ideographic"},
    200932: {"Unified_Ideograph", "Ideographic"},
    200933: {"Unified_Ideograph", "Ideographic"},
    200934: {"Unified_Ideograph", "Ideographic"},
    200935: {"Unified_Ideograph", "Ideographic"},
    200936: {"Unified_Ideograph", "Ideographic"},
    200937: {"Unified_Ideograph", "Ideographic"},
    200938: {"Unified_Ideograph", "Ideographic"},
    200939: {"Unified_Ideograph", "Ideographic"},
    200940: {"Unified_Ideograph", "Ideographic"},
    200941: {"Unified_Ideograph", "Ideographic"},
    200942: {"Unified_Ideograph", "Ideographic"},
    200943: {"Unified_Ideograph", "Ideographic"},
    200944: {"Unified_Ideograph", "Ideographic"},
    200945: {"Unified_Ideograph", "Ideographic"},
    200946: {"Unified_Ideograph", "Ideographic"},
    200947: {"Unified_Ideograph", "Ideographic"},
    200948: {"Unified_Ideograph", "Ideographic"},
    200949: {"Unified_Ideograph", "Ideographic"},
    200950: {"Unified_Ideograph", "Ideographic"},
    200951: {"Unified_Ideograph", "Ideographic"},
    200952: {"Unified_Ideograph", "Ideographic"},
    200953: {"Unified_Ideograph", "Ideographic"},
    200954: {"Unified_Ideograph", "Ideographic"},
    200955: {"Unified_Ideograph", "Ideographic"},
    200956: {"Unified_Ideograph", "Ideographic"},
    200957: {"Unified_Ideograph", "Ideographic"},
    200958: {"Unified_Ideograph", "Ideographic"},
    200959: {"Unified_Ideograph", "Ideographic"},
    200960: {"Unified_Ideograph", "Ideographic"},
    200961: {"Unified_Ideograph", "Ideographic"},
    200962: {"Unified_Ideograph", "Ideographic"},
    200963: {"Unified_Ideograph", "Ideographic"},
    200964: {"Unified_Ideograph", "Ideographic"},
    200965: {"Unified_Ideograph", "Ideographic"},
    200966: {"Unified_Ideograph", "Ideographic"},
    200967: {"Unified_Ideograph", "Ideographic"},
    200968: {"Unified_Ideograph", "Ideographic"},
    200969: {"Unified_Ideograph", "Ideographic"},
    200970: {"Unified_Ideograph", "Ideographic"},
    200971: {"Unified_Ideograph", "Ideographic"},
    200972: {"Unified_Ideograph", "Ideographic"},
    200973: {"Unified_Ideograph", "Ideographic"},
    200974: {"Unified_Ideograph", "Ideographic"},
    200975: {"Unified_Ideograph", "Ideographic"},
    200976: {"Unified_Ideograph", "Ideographic"},
    200977: {"Unified_Ideograph", "Ideographic"},
    200978: {"Unified_Ideograph", "Ideographic"},
    200979: {"Unified_Ideograph", "Ideographic"},
    200980: {"Unified_Ideograph", "Ideographic"},
    200981: {"Unified_Ideograph", "Ideographic"},
    200982: {"Unified_Ideograph", "Ideographic"},
    200983: {"Unified_Ideograph", "Ideographic"},
    200984: {"Unified_Ideograph", "Ideographic"},
    200985: {"Unified_Ideograph", "Ideographic"},
    200986: {"Unified_Ideograph", "Ideographic"},
    200987: {"Unified_Ideograph", "Ideographic"},
    200988: {"Unified_Ideograph", "Ideographic"},
    200989: {"Unified_Ideograph", "Ideographic"},
    200990: {"Unified_Ideograph", "Ideographic"},
    200991: {"Unified_Ideograph", "Ideographic"},
    200992: {"Unified_Ideograph", "Ideographic"},
    200993: {"Unified_Ideograph", "Ideographic"},
    200994: {"Unified_Ideograph", "Ideographic"},
    200995: {"Unified_Ideograph", "Ideographic"},
    200996: {"Unified_Ideograph", "Ideographic"},
    200997: {"Unified_Ideograph", "Ideographic"},
    200998: {"Unified_Ideograph", "Ideographic"},
    200999: {"Unified_Ideograph", "Ideographic"},
    201000: {"Unified_Ideograph", "Ideographic"},
    201001: {"Unified_Ideograph", "Ideographic"},
    201002: {"Unified_Ideograph", "Ideographic"},
    201003: {"Unified_Ideograph", "Ideographic"},
    201004: {"Unified_Ideograph", "Ideographic"},
    201005: {"Unified_Ideograph", "Ideographic"},
    201006: {"Unified_Ideograph", "Ideographic"},
    201007: {"Unified_Ideograph", "Ideographic"},
    201008: {"Unified_Ideograph", "Ideographic"},
    201009: {"Unified_Ideograph", "Ideographic"},
    201010: {"Unified_Ideograph", "Ideographic"},
    201011: {"Unified_Ideograph", "Ideographic"},
    201012: {"Unified_Ideograph", "Ideographic"},
    201013: {"Unified_Ideograph", "Ideographic"},
    201014: {"Unified_Ideograph", "Ideographic"},
    201015: {"Unified_Ideograph", "Ideographic"},
    201016: {"Unified_Ideograph", "Ideographic"},
    201017: {"Unified_Ideograph", "Ideographic"},
    201018: {"Unified_Ideograph", "Ideographic"},
    201019: {"Unified_Ideograph", "Ideographic"},
    201020: {"Unified_Ideograph", "Ideographic"},
    201021: {"Unified_Ideograph", "Ideographic"},
    201022: {"Unified_Ideograph", "Ideographic"},
    201023: {"Unified_Ideograph", "Ideographic"},
    201024: {"Unified_Ideograph", "Ideographic"},
    201025: {"Unified_Ideograph", "Ideographic"},
    201026: {"Unified_Ideograph", "Ideographic"},
    201027: {"Unified_Ideograph", "Ideographic"},
    201028: {"Unified_Ideograph", "Ideographic"},
    201029: {"Unified_Ideograph", "Ideographic"},
    201030: {"Unified_Ideograph", "Ideographic"},
    201031: {"Unified_Ideograph", "Ideographic"},
    201032: {"Unified_Ideograph", "Ideographic"},
    201033: {"Unified_Ideograph", "Ideographic"},
    201034: {"Unified_Ideograph", "Ideographic"},
    201035: {"Unified_Ideograph", "Ideographic"},
    201036: {"Unified_Ideograph", "Ideographic"},
    201037: {"Unified_Ideograph", "Ideographic"},
    201038: {"Unified_Ideograph", "Ideographic"},
    201039: {"Unified_Ideograph", "Ideographic"},
    201040: {"Unified_Ideograph", "Ideographic"},
    201041: {"Unified_Ideograph", "Ideographic"},
    201042: {"Unified_Ideograph", "Ideographic"},
    201043: {"Unified_Ideograph", "Ideographic"},
    201044: {"Unified_Ideograph", "Ideographic"},
    201045: {"Unified_Ideograph", "Ideographic"},
    201046: {"Unified_Ideograph", "Ideographic"},
    201047: {"Unified_Ideograph", "Ideographic"},
    201048: {"Unified_Ideograph", "Ideographic"},
    201049: {"Unified_Ideograph", "Ideographic"},
    201050: {"Unified_Ideograph", "Ideographic"},
    201051: {"Unified_Ideograph", "Ideographic"},
    201052: {"Unified_Ideograph", "Ideographic"},
    201053: {"Unified_Ideograph", "Ideographic"},
    201054: {"Unified_Ideograph", "Ideographic"},
    201055: {"Unified_Ideograph", "Ideographic"},
    201056: {"Unified_Ideograph", "Ideographic"},
    201057: {"Unified_Ideograph", "Ideographic"},
    201058: {"Unified_Ideograph", "Ideographic"},
    201059: {"Unified_Ideograph", "Ideographic"},
    201060: {"Unified_Ideograph", "Ideographic"},
    201061: {"Unified_Ideograph", "Ideographic"},
    201062: {"Unified_Ideograph", "Ideographic"},
    201063: {"Unified_Ideograph", "Ideographic"},
    201064: {"Unified_Ideograph", "Ideographic"},
    201065: {"Unified_Ideograph", "Ideographic"},
    201066: {"Unified_Ideograph", "Ideographic"},
    201067: {"Unified_Ideograph", "Ideographic"},
    201068: {"Unified_Ideograph", "Ideographic"},
    201069: {"Unified_Ideograph", "Ideographic"},
    201070: {"Unified_Ideograph", "Ideographic"},
    201071: {"Unified_Ideograph", "Ideographic"},
    201072: {"Unified_Ideograph", "Ideographic"},
    201073: {"Unified_Ideograph", "Ideographic"},
    201074: {"Unified_Ideograph", "Ideographic"},
    201075: {"Unified_Ideograph", "Ideographic"},
    201076: {"Unified_Ideograph", "Ideographic"},
    201077: {"Unified_Ideograph", "Ideographic"},
    201078: {"Unified_Ideograph", "Ideographic"},
    201079: {"Unified_Ideograph", "Ideographic"},
    201080: {"Unified_Ideograph", "Ideographic"},
    201081: {"Unified_Ideograph", "Ideographic"},
    201082: {"Unified_Ideograph", "Ideographic"},
    201083: {"Unified_Ideograph", "Ideographic"},
    201084: {"Unified_Ideograph", "Ideographic"},
    201085: {"Unified_Ideograph", "Ideographic"},
    201086: {"Unified_Ideograph", "Ideographic"},
    201087: {"Unified_Ideograph", "Ideographic"},
    201088: {"Unified_Ideograph", "Ideographic"},
    201089: {"Unified_Ideograph", "Ideographic"},
    201090: {"Unified_Ideograph", "Ideographic"},
    201091: {"Unified_Ideograph", "Ideographic"},
    201092: {"Unified_Ideograph", "Ideographic"},
    201093: {"Unified_Ideograph", "Ideographic"},
    201094: {"Unified_Ideograph", "Ideographic"},
    201095: {"Unified_Ideograph", "Ideographic"},
    201096: {"Unified_Ideograph", "Ideographic"},
    201097: {"Unified_Ideograph", "Ideographic"},
    201098: {"Unified_Ideograph", "Ideographic"},
    201099: {"Unified_Ideograph", "Ideographic"},
    201100: {"Unified_Ideograph", "Ideographic"},
    201101: {"Unified_Ideograph", "Ideographic"},
    201102: {"Unified_Ideograph", "Ideographic"},
    201103: {"Unified_Ideograph", "Ideographic"},
    201104: {"Unified_Ideograph", "Ideographic"},
    201105: {"Unified_Ideograph", "Ideographic"},
    201106: {"Unified_Ideograph", "Ideographic"},
    201107: {"Unified_Ideograph", "Ideographic"},
    201108: {"Unified_Ideograph", "Ideographic"},
    201109: {"Unified_Ideograph", "Ideographic"},
    201110: {"Unified_Ideograph", "Ideographic"},
    201111: {"Unified_Ideograph", "Ideographic"},
    201112: {"Unified_Ideograph", "Ideographic"},
    201113: {"Unified_Ideograph", "Ideographic"},
    201114: {"Unified_Ideograph", "Ideographic"},
    201115: {"Unified_Ideograph", "Ideographic"},
    201116: {"Unified_Ideograph", "Ideographic"},
    201117: {"Unified_Ideograph", "Ideographic"},
    201118: {"Unified_Ideograph", "Ideographic"},
    201119: {"Unified_Ideograph", "Ideographic"},
    201120: {"Unified_Ideograph", "Ideographic"},
    201121: {"Unified_Ideograph", "Ideographic"},
    201122: {"Unified_Ideograph", "Ideographic"},
    201123: {"Unified_Ideograph", "Ideographic"},
    201124: {"Unified_Ideograph", "Ideographic"},
    201125: {"Unified_Ideograph", "Ideographic"},
    201126: {"Unified_Ideograph", "Ideographic"},
    201127: {"Unified_Ideograph", "Ideographic"},
    201128: {"Unified_Ideograph", "Ideographic"},
    201129: {"Unified_Ideograph", "Ideographic"},
    201130: {"Unified_Ideograph", "Ideographic"},
    201131: {"Unified_Ideograph", "Ideographic"},
    201132: {"Unified_Ideograph", "Ideographic"},
    201133: {"Unified_Ideograph", "Ideographic"},
    201134: {"Unified_Ideograph", "Ideographic"},
    201135: {"Unified_Ideograph", "Ideographic"},
    201136: {"Unified_Ideograph", "Ideographic"},
    201137: {"Unified_Ideograph", "Ideographic"},
    201138: {"Unified_Ideograph", "Ideographic"},
    201139: {"Unified_Ideograph", "Ideographic"},
    201140: {"Unified_Ideograph", "Ideographic"},
    201141: {"Unified_Ideograph", "Ideographic"},
    201142: {"Unified_Ideograph", "Ideographic"},
    201143: {"Unified_Ideograph", "Ideographic"},
    201144: {"Unified_Ideograph", "Ideographic"},
    201145: {"Unified_Ideograph", "Ideographic"},
    201146: {"Unified_Ideograph", "Ideographic"},
    201147: {"Unified_Ideograph", "Ideographic"},
    201148: {"Unified_Ideograph", "Ideographic"},
    201149: {"Unified_Ideograph", "Ideographic"},
    201150: {"Unified_Ideograph", "Ideographic"},
    201151: {"Unified_Ideograph", "Ideographic"},
    201152: {"Unified_Ideograph", "Ideographic"},
    201153: {"Unified_Ideograph", "Ideographic"},
    201154: {"Unified_Ideograph", "Ideographic"},
    201155: {"Unified_Ideograph", "Ideographic"},
    201156: {"Unified_Ideograph", "Ideographic"},
    201157: {"Unified_Ideograph", "Ideographic"},
    201158: {"Unified_Ideograph", "Ideographic"},
    201159: {"Unified_Ideograph", "Ideographic"},
    201160: {"Unified_Ideograph", "Ideographic"},
    201161: {"Unified_Ideograph", "Ideographic"},
    201162: {"Unified_Ideograph", "Ideographic"},
    201163: {"Unified_Ideograph", "Ideographic"},
    201164: {"Unified_Ideograph", "Ideographic"},
    201165: {"Unified_Ideograph", "Ideographic"},
    201166: {"Unified_Ideograph", "Ideographic"},
    201167: {"Unified_Ideograph", "Ideographic"},
    201168: {"Unified_Ideograph", "Ideographic"},
    201169: {"Unified_Ideograph", "Ideographic"},
    201170: {"Unified_Ideograph", "Ideographic"},
    201171: {"Unified_Ideograph", "Ideographic"},
    201172: {"Unified_Ideograph", "Ideographic"},
    201173: {"Unified_Ideograph", "Ideographic"},
    201174: {"Unified_Ideograph", "Ideographic"},
    201175: {"Unified_Ideograph", "Ideographic"},
    201176: {"Unified_Ideograph", "Ideographic"},
    201177: {"Unified_Ideograph", "Ideographic"},
    201178: {"Unified_Ideograph", "Ideographic"},
    201179: {"Unified_Ideograph", "Ideographic"},
    201180: {"Unified_Ideograph", "Ideographic"},
    201181: {"Unified_Ideograph", "Ideographic"},
    201182: {"Unified_Ideograph", "Ideographic"},
    201183: {"Unified_Ideograph", "Ideographic"},
    201184: {"Unified_Ideograph", "Ideographic"},
    201185: {"Unified_Ideograph", "Ideographic"},
    201186: {"Unified_Ideograph", "Ideographic"},
    201187: {"Unified_Ideograph", "Ideographic"},
    201188: {"Unified_Ideograph", "Ideographic"},
    201189: {"Unified_Ideograph", "Ideographic"},
    201190: {"Unified_Ideograph", "Ideographic"},
    201191: {"Unified_Ideograph", "Ideographic"},
    201192: {"Unified_Ideograph", "Ideographic"},
    201193: {"Unified_Ideograph", "Ideographic"},
    201194: {"Unified_Ideograph", "Ideographic"},
    201195: {"Unified_Ideograph", "Ideographic"},
    201196: {"Unified_Ideograph", "Ideographic"},
    201197: {"Unified_Ideograph", "Ideographic"},
    201198: {"Unified_Ideograph", "Ideographic"},
    201199: {"Unified_Ideograph", "Ideographic"},
    201200: {"Unified_Ideograph", "Ideographic"},
    201201: {"Unified_Ideograph", "Ideographic"},
    201202: {"Unified_Ideograph", "Ideographic"},
    201203: {"Unified_Ideograph", "Ideographic"},
    201204: {"Unified_Ideograph", "Ideographic"},
    201205: {"Unified_Ideograph", "Ideographic"},
    201206: {"Unified_Ideograph", "Ideographic"},
    201207: {"Unified_Ideograph", "Ideographic"},
    201208: {"Unified_Ideograph", "Ideographic"},
    201209: {"Unified_Ideograph", "Ideographic"},
    201210: {"Unified_Ideograph", "Ideographic"},
    201211: {"Unified_Ideograph", "Ideographic"},
    201212: {"Unified_Ideograph", "Ideographic"},
    201213: {"Unified_Ideograph", "Ideographic"},
    201214: {"Unified_Ideograph", "Ideographic"},
    201215: {"Unified_Ideograph", "Ideographic"},
    201216: {"Unified_Ideograph", "Ideographic"},
    201217: {"Unified_Ideograph", "Ideographic"},
    201218: {"Unified_Ideograph", "Ideographic"},
    201219: {"Unified_Ideograph", "Ideographic"},
    201220: {"Unified_Ideograph", "Ideographic"},
    201221: {"Unified_Ideograph", "Ideographic"},
    201222: {"Unified_Ideograph", "Ideographic"},
    201223: {"Unified_Ideograph", "Ideographic"},
    201224: {"Unified_Ideograph", "Ideographic"},
    201225: {"Unified_Ideograph", "Ideographic"},
    201226: {"Unified_Ideograph", "Ideographic"},
    201227: {"Unified_Ideograph", "Ideographic"},
    201228: {"Unified_Ideograph", "Ideographic"},
    201229: {"Unified_Ideograph", "Ideographic"},
    201230: {"Unified_Ideograph", "Ideographic"},
    201231: {"Unified_Ideograph", "Ideographic"},
    201232: {"Unified_Ideograph", "Ideographic"},
    201233: {"Unified_Ideograph", "Ideographic"},
    201234: {"Unified_Ideograph", "Ideographic"},
    201235: {"Unified_Ideograph", "Ideographic"},
    201236: {"Unified_Ideograph", "Ideographic"},
    201237: {"Unified_Ideograph", "Ideographic"},
    201238: {"Unified_Ideograph", "Ideographic"},
    201239: {"Unified_Ideograph", "Ideographic"},
    201240: {"Unified_Ideograph", "Ideographic"},
    201241: {"Unified_Ideograph", "Ideographic"},
    201242: {"Unified_Ideograph", "Ideographic"},
    201243: {"Unified_Ideograph", "Ideographic"},
    201244: {"Unified_Ideograph", "Ideographic"},
    201245: {"Unified_Ideograph", "Ideographic"},
    201246: {"Unified_Ideograph", "Ideographic"},
    201247: {"Unified_Ideograph", "Ideographic"},
    201248: {"Unified_Ideograph", "Ideographic"},
    201249: {"Unified_Ideograph", "Ideographic"},
    201250: {"Unified_Ideograph", "Ideographic"},
    201251: {"Unified_Ideograph", "Ideographic"},
    201252: {"Unified_Ideograph", "Ideographic"},
    201253: {"Unified_Ideograph", "Ideographic"},
    201254: {"Unified_Ideograph", "Ideographic"},
    201255: {"Unified_Ideograph", "Ideographic"},
    201256: {"Unified_Ideograph", "Ideographic"},
    201257: {"Unified_Ideograph", "Ideographic"},
    201258: {"Unified_Ideograph", "Ideographic"},
    201259: {"Unified_Ideograph", "Ideographic"},
    201260: {"Unified_Ideograph", "Ideographic"},
    201261: {"Unified_Ideograph", "Ideographic"},
    201262: {"Unified_Ideograph", "Ideographic"},
    201263: {"Unified_Ideograph", "Ideographic"},
    201264: {"Unified_Ideograph", "Ideographic"},
    201265: {"Unified_Ideograph", "Ideographic"},
    201266: {"Unified_Ideograph", "Ideographic"},
    201267: {"Unified_Ideograph", "Ideographic"},
    201268: {"Unified_Ideograph", "Ideographic"},
    201269: {"Unified_Ideograph", "Ideographic"},
    201270: {"Unified_Ideograph", "Ideographic"},
    201271: {"Unified_Ideograph", "Ideographic"},
    201272: {"Unified_Ideograph", "Ideographic"},
    201273: {"Unified_Ideograph", "Ideographic"},
    201274: {"Unified_Ideograph", "Ideographic"},
    201275: {"Unified_Ideograph", "Ideographic"},
    201276: {"Unified_Ideograph", "Ideographic"},
    201277: {"Unified_Ideograph", "Ideographic"},
    201278: {"Unified_Ideograph", "Ideographic"},
    201279: {"Unified_Ideograph", "Ideographic"},
    201280: {"Unified_Ideograph", "Ideographic"},
    201281: {"Unified_Ideograph", "Ideographic"},
    201282: {"Unified_Ideograph", "Ideographic"},
    201283: {"Unified_Ideograph", "Ideographic"},
    201284: {"Unified_Ideograph", "Ideographic"},
    201285: {"Unified_Ideograph", "Ideographic"},
    201286: {"Unified_Ideograph", "Ideographic"},
    201287: {"Unified_Ideograph", "Ideographic"},
    201288: {"Unified_Ideograph", "Ideographic"},
    201289: {"Unified_Ideograph", "Ideographic"},
    201290: {"Unified_Ideograph", "Ideographic"},
    201291: {"Unified_Ideograph", "Ideographic"},
    201292: {"Unified_Ideograph", "Ideographic"},
    201293: {"Unified_Ideograph", "Ideographic"},
    201294: {"Unified_Ideograph", "Ideographic"},
    201295: {"Unified_Ideograph", "Ideographic"},
    201296: {"Unified_Ideograph", "Ideographic"},
    201297: {"Unified_Ideograph", "Ideographic"},
    201298: {"Unified_Ideograph", "Ideographic"},
    201299: {"Unified_Ideograph", "Ideographic"},
    201300: {"Unified_Ideograph", "Ideographic"},
    201301: {"Unified_Ideograph", "Ideographic"},
    201302: {"Unified_Ideograph", "Ideographic"},
    201303: {"Unified_Ideograph", "Ideographic"},
    201304: {"Unified_Ideograph", "Ideographic"},
    201305: {"Unified_Ideograph", "Ideographic"},
    201306: {"Unified_Ideograph", "Ideographic"},
    201307: {"Unified_Ideograph", "Ideographic"},
    201308: {"Unified_Ideograph", "Ideographic"},
    201309: {"Unified_Ideograph", "Ideographic"},
    201310: {"Unified_Ideograph", "Ideographic"},
    201311: {"Unified_Ideograph", "Ideographic"},
    201312: {"Unified_Ideograph", "Ideographic"},
    201313: {"Unified_Ideograph", "Ideographic"},
    201314: {"Unified_Ideograph", "Ideographic"},
    201315: {"Unified_Ideograph", "Ideographic"},
    201316: {"Unified_Ideograph", "Ideographic"},
    201317: {"Unified_Ideograph", "Ideographic"},
    201318: {"Unified_Ideograph", "Ideographic"},
    201319: {"Unified_Ideograph", "Ideographic"},
    201320: {"Unified_Ideograph", "Ideographic"},
    201321: {"Unified_Ideograph", "Ideographic"},
    201322: {"Unified_Ideograph", "Ideographic"},
    201323: {"Unified_Ideograph", "Ideographic"},
    201324: {"Unified_Ideograph", "Ideographic"},
    201325: {"Unified_Ideograph", "Ideographic"},
    201326: {"Unified_Ideograph", "Ideographic"},
    201327: {"Unified_Ideograph", "Ideographic"},
    201328: {"Unified_Ideograph", "Ideographic"},
    201329: {"Unified_Ideograph", "Ideographic"},
    201330: {"Unified_Ideograph", "Ideographic"},
    201331: {"Unified_Ideograph", "Ideographic"},
    201332: {"Unified_Ideograph", "Ideographic"},
    201333: {"Unified_Ideograph", "Ideographic"},
    201334: {"Unified_Ideograph", "Ideographic"},
    201335: {"Unified_Ideograph", "Ideographic"},
    201336: {"Unified_Ideograph", "Ideographic"},
    201337: {"Unified_Ideograph", "Ideographic"},
    201338: {"Unified_Ideograph", "Ideographic"},
    201339: {"Unified_Ideograph", "Ideographic"},
    201340: {"Unified_Ideograph", "Ideographic"},
    201341: {"Unified_Ideograph", "Ideographic"},
    201342: {"Unified_Ideograph", "Ideographic"},
    201343: {"Unified_Ideograph", "Ideographic"},
    201344: {"Unified_Ideograph", "Ideographic"},
    201345: {"Unified_Ideograph", "Ideographic"},
    201346: {"Unified_Ideograph", "Ideographic"},
    201347: {"Unified_Ideograph", "Ideographic"},
    201348: {"Unified_Ideograph", "Ideographic"},
    201349: {"Unified_Ideograph", "Ideographic"},
    201350: {"Unified_Ideograph", "Ideographic"},
    201351: {"Unified_Ideograph", "Ideographic"},
    201352: {"Unified_Ideograph", "Ideographic"},
    201353: {"Unified_Ideograph", "Ideographic"},
    201354: {"Unified_Ideograph", "Ideographic"},
    201355: {"Unified_Ideograph", "Ideographic"},
    201356: {"Unified_Ideograph", "Ideographic"},
    201357: {"Unified_Ideograph", "Ideographic"},
    201358: {"Unified_Ideograph", "Ideographic"},
    201359: {"Unified_Ideograph", "Ideographic"},
    201360: {"Unified_Ideograph", "Ideographic"},
    201361: {"Unified_Ideograph", "Ideographic"},
    201362: {"Unified_Ideograph", "Ideographic"},
    201363: {"Unified_Ideograph", "Ideographic"},
    201364: {"Unified_Ideograph", "Ideographic"},
    201365: {"Unified_Ideograph", "Ideographic"},
    201366: {"Unified_Ideograph", "Ideographic"},
    201367: {"Unified_Ideograph", "Ideographic"},
    201368: {"Unified_Ideograph", "Ideographic"},
    201369: {"Unified_Ideograph", "Ideographic"},
    201370: {"Unified_Ideograph", "Ideographic"},
    201371: {"Unified_Ideograph", "Ideographic"},
    201372: {"Unified_Ideograph", "Ideographic"},
    201373: {"Unified_Ideograph", "Ideographic"},
    201374: {"Unified_Ideograph", "Ideographic"},
    201375: {"Unified_Ideograph", "Ideographic"},
    201376: {"Unified_Ideograph", "Ideographic"},
    201377: {"Unified_Ideograph", "Ideographic"},
    201378: {"Unified_Ideograph", "Ideographic"},
    201379: {"Unified_Ideograph", "Ideographic"},
    201380: {"Unified_Ideograph", "Ideographic"},
    201381: {"Unified_Ideograph", "Ideographic"},
    201382: {"Unified_Ideograph", "Ideographic"},
    201383: {"Unified_Ideograph", "Ideographic"},
    201384: {"Unified_Ideograph", "Ideographic"},
    201385: {"Unified_Ideograph", "Ideographic"},
    201386: {"Unified_Ideograph", "Ideographic"},
    201387: {"Unified_Ideograph", "Ideographic"},
    201388: {"Unified_Ideograph", "Ideographic"},
    201389: {"Unified_Ideograph", "Ideographic"},
    201390: {"Unified_Ideograph", "Ideographic"},
    201391: {"Unified_Ideograph", "Ideographic"},
    201392: {"Unified_Ideograph", "Ideographic"},
    201393: {"Unified_Ideograph", "Ideographic"},
    201394: {"Unified_Ideograph", "Ideographic"},
    201395: {"Unified_Ideograph", "Ideographic"},
    201396: {"Unified_Ideograph", "Ideographic"},
    201397: {"Unified_Ideograph", "Ideographic"},
    201398: {"Unified_Ideograph", "Ideographic"},
    201399: {"Unified_Ideograph", "Ideographic"},
    201400: {"Unified_Ideograph", "Ideographic"},
    201401: {"Unified_Ideograph", "Ideographic"},
    201402: {"Unified_Ideograph", "Ideographic"},
    201403: {"Unified_Ideograph", "Ideographic"},
    201404: {"Unified_Ideograph", "Ideographic"},
    201405: {"Unified_Ideograph", "Ideographic"},
    201406: {"Unified_Ideograph", "Ideographic"},
    201407: {"Unified_Ideograph", "Ideographic"},
    201408: {"Unified_Ideograph", "Ideographic"},
    201409: {"Unified_Ideograph", "Ideographic"},
    201410: {"Unified_Ideograph", "Ideographic"},
    201411: {"Unified_Ideograph", "Ideographic"},
    201412: {"Unified_Ideograph", "Ideographic"},
    201413: {"Unified_Ideograph", "Ideographic"},
    201414: {"Unified_Ideograph", "Ideographic"},
    201415: {"Unified_Ideograph", "Ideographic"},
    201416: {"Unified_Ideograph", "Ideographic"},
    201417: {"Unified_Ideograph", "Ideographic"},
    201418: {"Unified_Ideograph", "Ideographic"},
    201419: {"Unified_Ideograph", "Ideographic"},
    201420: {"Unified_Ideograph", "Ideographic"},
    201421: {"Unified_Ideograph", "Ideographic"},
    201422: {"Unified_Ideograph", "Ideographic"},
    201423: {"Unified_Ideograph", "Ideographic"},
    201424: {"Unified_Ideograph", "Ideographic"},
    201425: {"Unified_Ideograph", "Ideographic"},
    201426: {"Unified_Ideograph", "Ideographic"},
    201427: {"Unified_Ideograph", "Ideographic"},
    201428: {"Unified_Ideograph", "Ideographic"},
    201429: {"Unified_Ideograph", "Ideographic"},
    201430: {"Unified_Ideograph", "Ideographic"},
    201431: {"Unified_Ideograph", "Ideographic"},
    201432: {"Unified_Ideograph", "Ideographic"},
    201433: {"Unified_Ideograph", "Ideographic"},
    201434: {"Unified_Ideograph", "Ideographic"},
    201435: {"Unified_Ideograph", "Ideographic"},
    201436: {"Unified_Ideograph", "Ideographic"},
    201437: {"Unified_Ideograph", "Ideographic"},
    201438: {"Unified_Ideograph", "Ideographic"},
    201439: {"Unified_Ideograph", "Ideographic"},
    201440: {"Unified_Ideograph", "Ideographic"},
    201441: {"Unified_Ideograph", "Ideographic"},
    201442: {"Unified_Ideograph", "Ideographic"},
    201443: {"Unified_Ideograph", "Ideographic"},
    201444: {"Unified_Ideograph", "Ideographic"},
    201445: {"Unified_Ideograph", "Ideographic"},
    201446: {"Unified_Ideograph", "Ideographic"},
    201447: {"Unified_Ideograph", "Ideographic"},
    201448: {"Unified_Ideograph", "Ideographic"},
    201449: {"Unified_Ideograph", "Ideographic"},
    201450: {"Unified_Ideograph", "Ideographic"},
    201451: {"Unified_Ideograph", "Ideographic"},
    201452: {"Unified_Ideograph", "Ideographic"},
    201453: {"Unified_Ideograph", "Ideographic"},
    201454: {"Unified_Ideograph", "Ideographic"},
    201455: {"Unified_Ideograph", "Ideographic"},
    201456: {"Unified_Ideograph", "Ideographic"},
    201457: {"Unified_Ideograph", "Ideographic"},
    201458: {"Unified_Ideograph", "Ideographic"},
    201459: {"Unified_Ideograph", "Ideographic"},
    201460: {"Unified_Ideograph", "Ideographic"},
    201461: {"Unified_Ideograph", "Ideographic"},
    201462: {"Unified_Ideograph", "Ideographic"},
    201463: {"Unified_Ideograph", "Ideographic"},
    201464: {"Unified_Ideograph", "Ideographic"},
    201465: {"Unified_Ideograph", "Ideographic"},
    201466: {"Unified_Ideograph", "Ideographic"},
    201467: {"Unified_Ideograph", "Ideographic"},
    201468: {"Unified_Ideograph", "Ideographic"},
    201469: {"Unified_Ideograph", "Ideographic"},
    201470: {"Unified_Ideograph", "Ideographic"},
    201471: {"Unified_Ideograph", "Ideographic"},
    201472: {"Unified_Ideograph", "Ideographic"},
    201473: {"Unified_Ideograph", "Ideographic"},
    201474: {"Unified_Ideograph", "Ideographic"},
    201475: {"Unified_Ideograph", "Ideographic"},
    201476: {"Unified_Ideograph", "Ideographic"},
    201477: {"Unified_Ideograph", "Ideographic"},
    201478: {"Unified_Ideograph", "Ideographic"},
    201479: {"Unified_Ideograph", "Ideographic"},
    201480: {"Unified_Ideograph", "Ideographic"},
    201481: {"Unified_Ideograph", "Ideographic"},
    201482: {"Unified_Ideograph", "Ideographic"},
    201483: {"Unified_Ideograph", "Ideographic"},
    201484: {"Unified_Ideograph", "Ideographic"},
    201485: {"Unified_Ideograph", "Ideographic"},
    201486: {"Unified_Ideograph", "Ideographic"},
    201487: {"Unified_Ideograph", "Ideographic"},
    201488: {"Unified_Ideograph", "Ideographic"},
    201489: {"Unified_Ideograph", "Ideographic"},
    201490: {"Unified_Ideograph", "Ideographic"},
    201491: {"Unified_Ideograph", "Ideographic"},
    201492: {"Unified_Ideograph", "Ideographic"},
    201493: {"Unified_Ideograph", "Ideographic"},
    201494: {"Unified_Ideograph", "Ideographic"},
    201495: {"Unified_Ideograph", "Ideographic"},
    201496: {"Unified_Ideograph", "Ideographic"},
    201497: {"Unified_Ideograph", "Ideographic"},
    201498: {"Unified_Ideograph", "Ideographic"},
    201499: {"Unified_Ideograph", "Ideographic"},
    201500: {"Unified_Ideograph", "Ideographic"},
    201501: {"Unified_Ideograph", "Ideographic"},
    201502: {"Unified_Ideograph", "Ideographic"},
    201503: {"Unified_Ideograph", "Ideographic"},
    201504: {"Unified_Ideograph", "Ideographic"},
    201505: {"Unified_Ideograph", "Ideographic"},
    201506: {"Unified_Ideograph", "Ideographic"},
    201507: {"Unified_Ideograph", "Ideographic"},
    201508: {"Unified_Ideograph", "Ideographic"},
    201509: {"Unified_Ideograph", "Ideographic"},
    201510: {"Unified_Ideograph", "Ideographic"},
    201511: {"Unified_Ideograph", "Ideographic"},
    201512: {"Unified_Ideograph", "Ideographic"},
    201513: {"Unified_Ideograph", "Ideographic"},
    201514: {"Unified_Ideograph", "Ideographic"},
    201515: {"Unified_Ideograph", "Ideographic"},
    201516: {"Unified_Ideograph", "Ideographic"},
    201517: {"Unified_Ideograph", "Ideographic"},
    201518: {"Unified_Ideograph", "Ideographic"},
    201519: {"Unified_Ideograph", "Ideographic"},
    201520: {"Unified_Ideograph", "Ideographic"},
    201521: {"Unified_Ideograph", "Ideographic"},
    201522: {"Unified_Ideograph", "Ideographic"},
    201523: {"Unified_Ideograph", "Ideographic"},
    201524: {"Unified_Ideograph", "Ideographic"},
    201525: {"Unified_Ideograph", "Ideographic"},
    201526: {"Unified_Ideograph", "Ideographic"},
    201527: {"Unified_Ideograph", "Ideographic"},
    201528: {"Unified_Ideograph", "Ideographic"},
    201529: {"Unified_Ideograph", "Ideographic"},
    201530: {"Unified_Ideograph", "Ideographic"},
    201531: {"Unified_Ideograph", "Ideographic"},
    201532: {"Unified_Ideograph", "Ideographic"},
    201533: {"Unified_Ideograph", "Ideographic"},
    201534: {"Unified_Ideograph", "Ideographic"},
    201535: {"Unified_Ideograph", "Ideographic"},
    201536: {"Unified_Ideograph", "Ideographic"},
    201537: {"Unified_Ideograph", "Ideographic"},
    201538: {"Unified_Ideograph", "Ideographic"},
    201539: {"Unified_Ideograph", "Ideographic"},
    201540: {"Unified_Ideograph", "Ideographic"},
    201541: {"Unified_Ideograph", "Ideographic"},
    201542: {"Unified_Ideograph", "Ideographic"},
    201543: {"Unified_Ideograph", "Ideographic"},
    201544: {"Unified_Ideograph", "Ideographic"},
    201545: {"Unified_Ideograph", "Ideographic"},
    201546: {"Unified_Ideograph", "Ideographic"},
    262142: {"Noncharacter_Code_Point"},
    262143: {"Noncharacter_Code_Point"},
    327678: {"Noncharacter_Code_Point"},
    327679: {"Noncharacter_Code_Point"},
    393214: {"Noncharacter_Code_Point"},
    393215: {"Noncharacter_Code_Point"},
    458750: {"Noncharacter_Code_Point"},
    458751: {"Noncharacter_Code_Point"},
    524286: {"Noncharacter_Code_Point"},
    524287: {"Noncharacter_Code_Point"},
    589822: {"Noncharacter_Code_Point"},
    589823: {"Noncharacter_Code_Point"},
    655358: {"Noncharacter_Code_Point"},
    655359: {"Noncharacter_Code_Point"},
    720894: {"Noncharacter_Code_Point"},
    720895: {"Noncharacter_Code_Point"},
    786430: {"Noncharacter_Code_Point"},
    786431: {"Noncharacter_Code_Point"},
    851966: {"Noncharacter_Code_Point"},
    851967: {"Noncharacter_Code_Point"},
    917502: {"Noncharacter_Code_Point"},
    917503: {"Noncharacter_Code_Point"},
    917504: {"Other_Default_Ignorable_Code_Point"},
    917505: {"Deprecated"},
    917506: {"Other_Default_Ignorable_Code_Point"},
    917507: {"Other_Default_Ignorable_Code_Point"},
    917508: {"Other_Default_Ignorable_Code_Point"},
    917509: {"Other_Default_Ignorable_Code_Point"},
    917510: {"Other_Default_Ignorable_Code_Point"},
    917511: {"Other_Default_Ignorable_Code_Point"},
    917512: {"Other_Default_Ignorable_Code_Point"},
    917513: {"Other_Default_Ignorable_Code_Point"},
    917514: {"Other_Default_Ignorable_Code_Point"},
    917515: {"Other_Default_Ignorable_Code_Point"},
    917516: {"Other_Default_Ignorable_Code_Point"},
    917517: {"Other_Default_Ignorable_Code_Point"},
    917518: {"Other_Default_Ignorable_Code_Point"},
    917519: {"Other_Default_Ignorable_Code_Point"},
    917520: {"Other_Default_Ignorable_Code_Point"},
    917521: {"Other_Default_Ignorable_Code_Point"},
    917522: {"Other_Default_Ignorable_Code_Point"},
    917523: {"Other_Default_Ignorable_Code_Point"},
    917524: {"Other_Default_Ignorable_Code_Point"},
    917525: {"Other_Default_Ignorable_Code_Point"},
    917526: {"Other_Default_Ignorable_Code_Point"},
    917527: {"Other_Default_Ignorable_Code_Point"},
    917528: {"Other_Default_Ignorable_Code_Point"},
    917529: {"Other_Default_Ignorable_Code_Point"},
    917530: {"Other_Default_Ignorable_Code_Point"},
    917531: {"Other_Default_Ignorable_Code_Point"},
    917532: {"Other_Default_Ignorable_Code_Point"},
    917533: {"Other_Default_Ignorable_Code_Point"},
    917534: {"Other_Default_Ignorable_Code_Point"},
    917535: {"Other_Default_Ignorable_Code_Point"},
    917536: {"Other_Grapheme_Extend"},
    917537: {"Other_Grapheme_Extend"},
    917538: {"Other_Grapheme_Extend"},
    917539: {"Other_Grapheme_Extend"},
    917540: {"Other_Grapheme_Extend"},
    917541: {"Other_Grapheme_Extend"},
    917542: {"Other_Grapheme_Extend"},
    917543: {"Other_Grapheme_Extend"},
    917544: {"Other_Grapheme_Extend"},
    917545: {"Other_Grapheme_Extend"},
    917546: {"Other_Grapheme_Extend"},
    917547: {"Other_Grapheme_Extend"},
    917548: {"Other_Grapheme_Extend"},
    917549: {"Other_Grapheme_Extend"},
    917550: {"Other_Grapheme_Extend"},
    917551: {"Other_Grapheme_Extend"},
    917552: {"Other_Grapheme_Extend"},
    917553: {"Other_Grapheme_Extend"},
    917554: {"Other_Grapheme_Extend"},
    917555: {"Other_Grapheme_Extend"},
    917556: {"Other_Grapheme_Extend"},
    917557: {"Other_Grapheme_Extend"},
    917558: {"Other_Grapheme_Extend"},
    917559: {"Other_Grapheme_Extend"},
    917560: {"Other_Grapheme_Extend"},
    917561: {"Other_Grapheme_Extend"},
    917562: {"Other_Grapheme_Extend"},
    917563: {"Other_Grapheme_Extend"},
    917564: {"Other_Grapheme_Extend"},
    917565: {"Other_Grapheme_Extend"},
    917566: {"Other_Grapheme_Extend"},
    917567: {"Other_Grapheme_Extend"},
    917568: {"Other_Grapheme_Extend"},
    917569: {"Other_Grapheme_Extend"},
    917570: {"Other_Grapheme_Extend"},
    917571: {"Other_Grapheme_Extend"},
    917572: {"Other_Grapheme_Extend"},
    917573: {"Other_Grapheme_Extend"},
    917574: {"Other_Grapheme_Extend"},
    917575: {"Other_Grapheme_Extend"},
    917576: {"Other_Grapheme_Extend"},
    917577: {"Other_Grapheme_Extend"},
    917578: {"Other_Grapheme_Extend"},
    917579: {"Other_Grapheme_Extend"},
    917580: {"Other_Grapheme_Extend"},
    917581: {"Other_Grapheme_Extend"},
    917582: {"Other_Grapheme_Extend"},
    917583: {"Other_Grapheme_Extend"},
    917584: {"Other_Grapheme_Extend"},
    917585: {"Other_Grapheme_Extend"},
    917586: {"Other_Grapheme_Extend"},
    917587: {"Other_Grapheme_Extend"},
    917588: {"Other_Grapheme_Extend"},
    917589: {"Other_Grapheme_Extend"},
    917590: {"Other_Grapheme_Extend"},
    917591: {"Other_Grapheme_Extend"},
    917592: {"Other_Grapheme_Extend"},
    917593: {"Other_Grapheme_Extend"},
    917594: {"Other_Grapheme_Extend"},
    917595: {"Other_Grapheme_Extend"},
    917596: {"Other_Grapheme_Extend"},
    917597: {"Other_Grapheme_Extend"},
    917598: {"Other_Grapheme_Extend"},
    917599: {"Other_Grapheme_Extend"},
    917600: {"Other_Grapheme_Extend"},
    917601: {"Other_Grapheme_Extend"},
    917602: {"Other_Grapheme_Extend"},
    917603: {"Other_Grapheme_Extend"},
    917604: {"Other_Grapheme_Extend"},
    917605: {"Other_Grapheme_Extend"},
    917606: {"Other_Grapheme_Extend"},
    917607: {"Other_Grapheme_Extend"},
    917608: {"Other_Grapheme_Extend"},
    917609: {"Other_Grapheme_Extend"},
    917610: {"Other_Grapheme_Extend"},
    917611: {"Other_Grapheme_Extend"},
    917612: {"Other_Grapheme_Extend"},
    917613: {"Other_Grapheme_Extend"},
    917614: {"Other_Grapheme_Extend"},
    917615: {"Other_Grapheme_Extend"},
    917616: {"Other_Grapheme_Extend"},
    917617: {"Other_Grapheme_Extend"},
    917618: {"Other_Grapheme_Extend"},
    917619: {"Other_Grapheme_Extend"},
    917620: {"Other_Grapheme_Extend"},
    917621: {"Other_Grapheme_Extend"},
    917622: {"Other_Grapheme_Extend"},
    917623: {"Other_Grapheme_Extend"},
    917624: {"Other_Grapheme_Extend"},
    917625: {"Other_Grapheme_Extend"},
    917626: {"Other_Grapheme_Extend"},
    917627: {"Other_Grapheme_Extend"},
    917628: {"Other_Grapheme_Extend"},
    917629: {"Other_Grapheme_Extend"},
    917630: {"Other_Grapheme_Extend"},
    917631: {"Other_Grapheme_Extend"},
    917632: {"Other_Default_Ignorable_Code_Point"},
    917633: {"Other_Default_Ignorable_Code_Point"},
    917634: {"Other_Default_Ignorable_Code_Point"},
    917635: {"Other_Default_Ignorable_Code_Point"},
    917636: {"Other_Default_Ignorable_Code_Point"},
    917637: {"Other_Default_Ignorable_Code_Point"},
    917638: {"Other_Default_Ignorable_Code_Point"},
    917639: {"Other_Default_Ignorable_Code_Point"},
    917640: {"Other_Default_Ignorable_Code_Point"},
    917641: {"Other_Default_Ignorable_Code_Point"},
    917642: {"Other_Default_Ignorable_Code_Point"},
    917643: {"Other_Default_Ignorable_Code_Point"},
    917644: {"Other_Default_Ignorable_Code_Point"},
    917645: {"Other_Default_Ignorable_Code_Point"},
    917646: {"Other_Default_Ignorable_Code_Point"},
    917647: {"Other_Default_Ignorable_Code_Point"},
    917648: {"Other_Default_Ignorable_Code_Point"},
    917649: {"Other_Default_Ignorable_Code_Point"},
    917650: {"Other_Default_Ignorable_Code_Point"},
    917651: {"Other_Default_Ignorable_Code_Point"},
    917652: {"Other_Default_Ignorable_Code_Point"},
    917653: {"Other_Default_Ignorable_Code_Point"},
    917654: {"Other_Default_Ignorable_Code_Point"},
    917655: {"Other_Default_Ignorable_Code_Point"},
    917656: {"Other_Default_Ignorable_Code_Point"},
    917657: {"Other_Default_Ignorable_Code_Point"},
    917658: {"Other_Default_Ignorable_Code_Point"},
    917659: {"Other_Default_Ignorable_Code_Point"},
    917660: {"Other_Default_Ignorable_Code_Point"},
    917661: {"Other_Default_Ignorable_Code_Point"},
    917662: {"Other_Default_Ignorable_Code_Point"},
    917663: {"Other_Default_Ignorable_Code_Point"},
    917664: {"Other_Default_Ignorable_Code_Point"},
    917665: {"Other_Default_Ignorable_Code_Point"},
    917666: {"Other_Default_Ignorable_Code_Point"},
    917667: {"Other_Default_Ignorable_Code_Point"},
    917668: {"Other_Default_Ignorable_Code_Point"},
    917669: {"Other_Default_Ignorable_Code_Point"},
    917670: {"Other_Default_Ignorable_Code_Point"},
    917671: {"Other_Default_Ignorable_Code_Point"},
    917672: {"Other_Default_Ignorable_Code_Point"},
    917673: {"Other_Default_Ignorable_Code_Point"},
    917674: {"Other_Default_Ignorable_Code_Point"},
    917675: {"Other_Default_Ignorable_Code_Point"},
    917676: {"Other_Default_Ignorable_Code_Point"},
    917677: {"Other_Default_Ignorable_Code_Point"},
    917678: {"Other_Default_Ignorable_Code_Point"},
    917679: {"Other_Default_Ignorable_Code_Point"},
    917680: {"Other_Default_Ignorable_Code_Point"},
    917681: {"Other_Default_Ignorable_Code_Point"},
    917682: {"Other_Default_Ignorable_Code_Point"},
    917683: {"Other_Default_Ignorable_Code_Point"},
    917684: {"Other_Default_Ignorable_Code_Point"},
    917685: {"Other_Default_Ignorable_Code_Point"},
    917686: {"Other_Default_Ignorable_Code_Point"},
    917687: {"Other_Default_Ignorable_Code_Point"},
    917688: {"Other_Default_Ignorable_Code_Point"},
    917689: {"Other_Default_Ignorable_Code_Point"},
    917690: {"Other_Default_Ignorable_Code_Point"},
    917691: {"Other_Default_Ignorable_Code_Point"},
    917692: {"Other_Default_Ignorable_Code_Point"},
    917693: {"Other_Default_Ignorable_Code_Point"},
    917694: {"Other_Default_Ignorable_Code_Point"},
    917695: {"Other_Default_Ignorable_Code_Point"},
    917696: {"Other_Default_Ignorable_Code_Point"},
    917697: {"Other_Default_Ignorable_Code_Point"},
    917698: {"Other_Default_Ignorable_Code_Point"},
    917699: {"Other_Default_Ignorable_Code_Point"},
    917700: {"Other_Default_Ignorable_Code_Point"},
    917701: {"Other_Default_Ignorable_Code_Point"},
    917702: {"Other_Default_Ignorable_Code_Point"},
    917703: {"Other_Default_Ignorable_Code_Point"},
    917704: {"Other_Default_Ignorable_Code_Point"},
    917705: {"Other_Default_Ignorable_Code_Point"},
    917706: {"Other_Default_Ignorable_Code_Point"},
    917707: {"Other_Default_Ignorable_Code_Point"},
    917708: {"Other_Default_Ignorable_Code_Point"},
    917709: {"Other_Default_Ignorable_Code_Point"},
    917710: {"Other_Default_Ignorable_Code_Point"},
    917711: {"Other_Default_Ignorable_Code_Point"},
    917712: {"Other_Default_Ignorable_Code_Point"},
    917713: {"Other_Default_Ignorable_Code_Point"},
    917714: {"Other_Default_Ignorable_Code_Point"},
    917715: {"Other_Default_Ignorable_Code_Point"},
    917716: {"Other_Default_Ignorable_Code_Point"},
    917717: {"Other_Default_Ignorable_Code_Point"},
    917718: {"Other_Default_Ignorable_Code_Point"},
    917719: {"Other_Default_Ignorable_Code_Point"},
    917720: {"Other_Default_Ignorable_Code_Point"},
    917721: {"Other_Default_Ignorable_Code_Point"},
    917722: {"Other_Default_Ignorable_Code_Point"},
    917723: {"Other_Default_Ignorable_Code_Point"},
    917724: {"Other_Default_Ignorable_Code_Point"},
    917725: {"Other_Default_Ignorable_Code_Point"},
    917726: {"Other_Default_Ignorable_Code_Point"},
    917727: {"Other_Default_Ignorable_Code_Point"},
    917728: {"Other_Default_Ignorable_Code_Point"},
    917729: {"Other_Default_Ignorable_Code_Point"},
    917730: {"Other_Default_Ignorable_Code_Point"},
    917731: {"Other_Default_Ignorable_Code_Point"},
    917732: {"Other_Default_Ignorable_Code_Point"},
    917733: {"Other_Default_Ignorable_Code_Point"},
    917734: {"Other_Default_Ignorable_Code_Point"},
    917735: {"Other_Default_Ignorable_Code_Point"},
    917736: {"Other_Default_Ignorable_Code_Point"},
    917737: {"Other_Default_Ignorable_Code_Point"},
    917738: {"Other_Default_Ignorable_Code_Point"},
    917739: {"Other_Default_Ignorable_Code_Point"},
    917740: {"Other_Default_Ignorable_Code_Point"},
    917741: {"Other_Default_Ignorable_Code_Point"},
    917742: {"Other_Default_Ignorable_Code_Point"},
    917743: {"Other_Default_Ignorable_Code_Point"},
    917744: {"Other_Default_Ignorable_Code_Point"},
    917745: {"Other_Default_Ignorable_Code_Point"},
    917746: {"Other_Default_Ignorable_Code_Point"},
    917747: {"Other_Default_Ignorable_Code_Point"},
    917748: {"Other_Default_Ignorable_Code_Point"},
    917749: {"Other_Default_Ignorable_Code_Point"},
    917750: {"Other_Default_Ignorable_Code_Point"},
    917751: {"Other_Default_Ignorable_Code_Point"},
    917752: {"Other_Default_Ignorable_Code_Point"},
    917753: {"Other_Default_Ignorable_Code_Point"},
    917754: {"Other_Default_Ignorable_Code_Point"},
    917755: {"Other_Default_Ignorable_Code_Point"},
    917756: {"Other_Default_Ignorable_Code_Point"},
    917757: {"Other_Default_Ignorable_Code_Point"},
    917758: {"Other_Default_Ignorable_Code_Point"},
    917759: {"Other_Default_Ignorable_Code_Point"},
    917760: {"Variation_Selector"},
    917761: {"Variation_Selector"},
    917762: {"Variation_Selector"},
    917763: {"Variation_Selector"},
    917764: {"Variation_Selector"},
    917765: {"Variation_Selector"},
    917766: {"Variation_Selector"},
    917767: {"Variation_Selector"},
    917768: {"Variation_Selector"},
    917769: {"Variation_Selector"},
    917770: {"Variation_Selector"},
    917771: {"Variation_Selector"},
    917772: {"Variation_Selector"},
    917773: {"Variation_Selector"},
    917774: {"Variation_Selector"},
    917775: {"Variation_Selector"},
    917776: {"Variation_Selector"},
    917777: {"Variation_Selector"},
    917778: {"Variation_Selector"},
    917779: {"Variation_Selector"},
    917780: {"Variation_Selector"},
    917781: {"Variation_Selector"},
    917782: {"Variation_Selector"},
    917783: {"Variation_Selector"},
    917784: {"Variation_Selector"},
    917785: {"Variation_Selector"},
    917786: {"Variation_Selector"},
    917787: {"Variation_Selector"},
    917788: {"Variation_Selector"},
    917789: {"Variation_Selector"},
    917790: {"Variation_Selector"},
    917791: {"Variation_Selector"},
    917792: {"Variation_Selector"},
    917793: {"Variation_Selector"},
    917794: {"Variation_Selector"},
    917795: {"Variation_Selector"},
    917796: {"Variation_Selector"},
    917797: {"Variation_Selector"},
    917798: {"Variation_Selector"},
    917799: {"Variation_Selector"},
    917800: {"Variation_Selector"},
    917801: {"Variation_Selector"},
    917802: {"Variation_Selector"},
    917803: {"Variation_Selector"},
    917804: {"Variation_Selector"},
    917805: {"Variation_Selector"},
    917806: {"Variation_Selector"},
    917807: {"Variation_Selector"},
    917808: {"Variation_Selector"},
    917809: {"Variation_Selector"},
    917810: {"Variation_Selector"},
    917811: {"Variation_Selector"},
    917812: {"Variation_Selector"},
    917813: {"Variation_Selector"},
    917814: {"Variation_Selector"},
    917815: {"Variation_Selector"},
    917816: {"Variation_Selector"},
    917817: {"Variation_Selector"},
    917818: {"Variation_Selector"},
    917819: {"Variation_Selector"},
    917820: {"Variation_Selector"},
    917821: {"Variation_Selector"},
    917822: {"Variation_Selector"},
    917823: {"Variation_Selector"},
    917824: {"Variation_Selector"},
    917825: {"Variation_Selector"},
    917826: {"Variation_Selector"},
    917827: {"Variation_Selector"},
    917828: {"Variation_Selector"},
    917829: {"Variation_Selector"},
    917830: {"Variation_Selector"},
    917831: {"Variation_Selector"},
    917832: {"Variation_Selector"},
    917833: {"Variation_Selector"},
    917834: {"Variation_Selector"},
    917835: {"Variation_Selector"},
    917836: {"Variation_Selector"},
    917837: {"Variation_Selector"},
    917838: {"Variation_Selector"},
    917839: {"Variation_Selector"},
    917840: {"Variation_Selector"},
    917841: {"Variation_Selector"},
    917842: {"Variation_Selector"},
    917843: {"Variation_Selector"},
    917844: {"Variation_Selector"},
    917845: {"Variation_Selector"},
    917846: {"Variation_Selector"},
    917847: {"Variation_Selector"},
    917848: {"Variation_Selector"},
    917849: {"Variation_Selector"},
    917850: {"Variation_Selector"},
    917851: {"Variation_Selector"},
    917852: {"Variation_Selector"},
    917853: {"Variation_Selector"},
    917854: {"Variation_Selector"},
    917855: {"Variation_Selector"},
    917856: {"Variation_Selector"},
    917857: {"Variation_Selector"},
    917858: {"Variation_Selector"},
    917859: {"Variation_Selector"},
    917860: {"Variation_Selector"},
    917861: {"Variation_Selector"},
    917862: {"Variation_Selector"},
    917863: {"Variation_Selector"},
    917864: {"Variation_Selector"},
    917865: {"Variation_Selector"},
    917866: {"Variation_Selector"},
    917867: {"Variation_Selector"},
    917868: {"Variation_Selector"},
    917869: {"Variation_Selector"},
    917870: {"Variation_Selector"},
    917871: {"Variation_Selector"},
    917872: {"Variation_Selector"},
    917873: {"Variation_Selector"},
    917874: {"Variation_Selector"},
    917875: {"Variation_Selector"},
    917876: {"Variation_Selector"},
    917877: {"Variation_Selector"},
    917878: {"Variation_Selector"},
    917879: {"Variation_Selector"},
    917880: {"Variation_Selector"},
    917881: {"Variation_Selector"},
    917882: {"Variation_Selector"},
    917883: {"Variation_Selector"},
    917884: {"Variation_Selector"},
    917885: {"Variation_Selector"},
    917886: {"Variation_Selector"},
    917887: {"Variation_Selector"},
    917888: {"Variation_Selector"},
    917889: {"Variation_Selector"},
    917890: {"Variation_Selector"},
    917891: {"Variation_Selector"},
    917892: {"Variation_Selector"},
    917893: {"Variation_Selector"},
    917894: {"Variation_Selector"},
    917895: {"Variation_Selector"},
    917896: {"Variation_Selector"},
    917897: {"Variation_Selector"},
    917898: {"Variation_Selector"},
    917899: {"Variation_Selector"},
    917900: {"Variation_Selector"},
    917901: {"Variation_Selector"},
    917902: {"Variation_Selector"},
    917903: {"Variation_Selector"},
    917904: {"Variation_Selector"},
    917905: {"Variation_Selector"},
    917906: {"Variation_Selector"},
    917907: {"Variation_Selector"},
    917908: {"Variation_Selector"},
    917909: {"Variation_Selector"},
    917910: {"Variation_Selector"},
    917911: {"Variation_Selector"},
    917912: {"Variation_Selector"},
    917913: {"Variation_Selector"},
    917914: {"Variation_Selector"},
    917915: {"Variation_Selector"},
    917916: {"Variation_Selector"},
    917917: {"Variation_Selector"},
    917918: {"Variation_Selector"},
    917919: {"Variation_Selector"},
    917920: {"Variation_Selector"},
    917921: {"Variation_Selector"},
    917922: {"Variation_Selector"},
    917923: {"Variation_Selector"},
    917924: {"Variation_Selector"},
    917925: {"Variation_Selector"},
    917926: {"Variation_Selector"},
    917927: {"Variation_Selector"},
    917928: {"Variation_Selector"},
    917929: {"Variation_Selector"},
    917930: {"Variation_Selector"},
    917931: {"Variation_Selector"},
    917932: {"Variation_Selector"},
    917933: {"Variation_Selector"},
    917934: {"Variation_Selector"},
    917935: {"Variation_Selector"},
    917936: {"Variation_Selector"},
    917937: {"Variation_Selector"},
    917938: {"Variation_Selector"},
    917939: {"Variation_Selector"},
    917940: {"Variation_Selector"},
    917941: {"Variation_Selector"},
    917942: {"Variation_Selector"},
    917943: {"Variation_Selector"},
    917944: {"Variation_Selector"},
    917945: {"Variation_Selector"},
    917946: {"Variation_Selector"},
    917947: {"Variation_Selector"},
    917948: {"Variation_Selector"},
    917949: {"Variation_Selector"},
    917950: {"Variation_Selector"},
    917951: {"Variation_Selector"},
    917952: {"Variation_Selector"},
    917953: {"Variation_Selector"},
    917954: {"Variation_Selector"},
    917955: {"Variation_Selector"},
    917956: {"Variation_Selector"},
    917957: {"Variation_Selector"},
    917958: {"Variation_Selector"},
    917959: {"Variation_Selector"},
    917960: {"Variation_Selector"},
    917961: {"Variation_Selector"},
    917962: {"Variation_Selector"},
    917963: {"Variation_Selector"},
    917964: {"Variation_Selector"},
    917965: {"Variation_Selector"},
    917966: {"Variation_Selector"},
    917967: {"Variation_Selector"},
    917968: {"Variation_Selector"},
    917969: {"Variation_Selector"},
    917970: {"Variation_Selector"},
    917971: {"Variation_Selector"},
    917972: {"Variation_Selector"},
    917973: {"Variation_Selector"},
    917974: {"Variation_Selector"},
    917975: {"Variation_Selector"},
    917976: {"Variation_Selector"},
    917977: {"Variation_Selector"},
    917978: {"Variation_Selector"},
    917979: {"Variation_Selector"},
    917980: {"Variation_Selector"},
    917981: {"Variation_Selector"},
    917982: {"Variation_Selector"},
    917983: {"Variation_Selector"},
    917984: {"Variation_Selector"},
    917985: {"Variation_Selector"},
    917986: {"Variation_Selector"},
    917987: {"Variation_Selector"},
    917988: {"Variation_Selector"},
    917989: {"Variation_Selector"},
    917990: {"Variation_Selector"},
    917991: {"Variation_Selector"},
    917992: {"Variation_Selector"},
    917993: {"Variation_Selector"},
    917994: {"Variation_Selector"},
    917995: {"Variation_Selector"},
    917996: {"Variation_Selector"},
    917997: {"Variation_Selector"},
    917998: {"Variation_Selector"},
    917999: {"Variation_Selector"},
    918000: {"Other_Default_Ignorable_Code_Point"},
    918001: {"Other_Default_Ignorable_Code_Point"},
    918002: {"Other_Default_Ignorable_Code_Point"},
    918003: {"Other_Default_Ignorable_Code_Point"},
    918004: {"Other_Default_Ignorable_Code_Point"},
    918005: {"Other_Default_Ignorable_Code_Point"},
    918006: {"Other_Default_Ignorable_Code_Point"},
    918007: {"Other_Default_Ignorable_Code_Point"},
    918008: {"Other_Default_Ignorable_Code_Point"},
    918009: {"Other_Default_Ignorable_Code_Point"},
    918010: {"Other_Default_Ignorable_Code_Point"},
    918011: {"Other_Default_Ignorable_Code_Point"},
    918012: {"Other_Default_Ignorable_Code_Point"},
    918013: {"Other_Default_Ignorable_Code_Point"},
    918014: {"Other_Default_Ignorable_Code_Point"},
    918015: {"Other_Default_Ignorable_Code_Point"},
    918016: {"Other_Default_Ignorable_Code_Point"},
    918017: {"Other_Default_Ignorable_Code_Point"},
    918018: {"Other_Default_Ignorable_Code_Point"},
    918019: {"Other_Default_Ignorable_Code_Point"},
    918020: {"Other_Default_Ignorable_Code_Point"},
    918021: {"Other_Default_Ignorable_Code_Point"},
    918022: {"Other_Default_Ignorable_Code_Point"},
    918023: {"Other_Default_Ignorable_Code_Point"},
    918024: {"Other_Default_Ignorable_Code_Point"},
    918025: {"Other_Default_Ignorable_Code_Point"},
    918026: {"Other_Default_Ignorable_Code_Point"},
    918027: {"Other_Default_Ignorable_Code_Point"},
    918028: {"Other_Default_Ignorable_Code_Point"},
    918029: {"Other_Default_Ignorable_Code_Point"},
    918030: {"Other_Default_Ignorable_Code_Point"},
    918031: {"Other_Default_Ignorable_Code_Point"},
    918032: {"Other_Default_Ignorable_Code_Point"},
    918033: {"Other_Default_Ignorable_Code_Point"},
    918034: {"Other_Default_Ignorable_Code_Point"},
    918035: {"Other_Default_Ignorable_Code_Point"},
    918036: {"Other_Default_Ignorable_Code_Point"},
    918037: {"Other_Default_Ignorable_Code_Point"},
    918038: {"Other_Default_Ignorable_Code_Point"},
    918039: {"Other_Default_Ignorable_Code_Point"},
    918040: {"Other_Default_Ignorable_Code_Point"},
    918041: {"Other_Default_Ignorable_Code_Point"},
    918042: {"Other_Default_Ignorable_Code_Point"},
    918043: {"Other_Default_Ignorable_Code_Point"},
    918044: {"Other_Default_Ignorable_Code_Point"},
    918045: {"Other_Default_Ignorable_Code_Point"},
    918046: {"Other_Default_Ignorable_Code_Point"},
    918047: {"Other_Default_Ignorable_Code_Point"},
    918048: {"Other_Default_Ignorable_Code_Point"},
    918049: {"Other_Default_Ignorable_Code_Point"},
    918050: {"Other_Default_Ignorable_Code_Point"},
    918051: {"Other_Default_Ignorable_Code_Point"},
    918052: {"Other_Default_Ignorable_Code_Point"},
    918053: {"Other_Default_Ignorable_Code_Point"},
    918054: {"Other_Default_Ignorable_Code_Point"},
    918055: {"Other_Default_Ignorable_Code_Point"},
    918056: {"Other_Default_Ignorable_Code_Point"},
    918057: {"Other_Default_Ignorable_Code_Point"},
    918058: {"Other_Default_Ignorable_Code_Point"},
    918059: {"Other_Default_Ignorable_Code_Point"},
    918060: {"Other_Default_Ignorable_Code_Point"},
    918061: {"Other_Default_Ignorable_Code_Point"},
    918062: {"Other_Default_Ignorable_Code_Point"},
    918063: {"Other_Default_Ignorable_Code_Point"},
    918064: {"Other_Default_Ignorable_Code_Point"},
    918065: {"Other_Default_Ignorable_Code_Point"},
    918066: {"Other_Default_Ignorable_Code_Point"},
    918067: {"Other_Default_Ignorable_Code_Point"},
    918068: {"Other_Default_Ignorable_Code_Point"},
    918069: {"Other_Default_Ignorable_Code_Point"},
    918070: {"Other_Default_Ignorable_Code_Point"},
    918071: {"Other_Default_Ignorable_Code_Point"},
    918072: {"Other_Default_Ignorable_Code_Point"},
    918073: {"Other_Default_Ignorable_Code_Point"},
    918074: {"Other_Default_Ignorable_Code_Point"},
    918075: {"Other_Default_Ignorable_Code_Point"},
    918076: {"Other_Default_Ignorable_Code_Point"},
    918077: {"Other_Default_Ignorable_Code_Point"},
    918078: {"Other_Default_Ignorable_Code_Point"},
    918079: {"Other_Default_Ignorable_Code_Point"},
    918080: {"Other_Default_Ignorable_Code_Point"},
    918081: {"Other_Default_Ignorable_Code_Point"},
    918082: {"Other_Default_Ignorable_Code_Point"},
    918083: {"Other_Default_Ignorable_Code_Point"},
    918084: {"Other_Default_Ignorable_Code_Point"},
    918085: {"Other_Default_Ignorable_Code_Point"},
    918086: {"Other_Default_Ignorable_Code_Point"},
    918087: {"Other_Default_Ignorable_Code_Point"},
    918088: {"Other_Default_Ignorable_Code_Point"},
    918089: {"Other_Default_Ignorable_Code_Point"},
    918090: {"Other_Default_Ignorable_Code_Point"},
    918091: {"Other_Default_Ignorable_Code_Point"},
    918092: {"Other_Default_Ignorable_Code_Point"},
    918093: {"Other_Default_Ignorable_Code_Point"},
    918094: {"Other_Default_Ignorable_Code_Point"},
    918095: {"Other_Default_Ignorable_Code_Point"},
    918096: {"Other_Default_Ignorable_Code_Point"},
    918097: {"Other_Default_Ignorable_Code_Point"},
    918098: {"Other_Default_Ignorable_Code_Point"},
    918099: {"Other_Default_Ignorable_Code_Point"},
    918100: {"Other_Default_Ignorable_Code_Point"},
    918101: {"Other_Default_Ignorable_Code_Point"},
    918102: {"Other_Default_Ignorable_Code_Point"},
    918103: {"Other_Default_Ignorable_Code_Point"},
    918104: {"Other_Default_Ignorable_Code_Point"},
    918105: {"Other_Default_Ignorable_Code_Point"},
    918106: {"Other_Default_Ignorable_Code_Point"},
    918107: {"Other_Default_Ignorable_Code_Point"},
    918108: {"Other_Default_Ignorable_Code_Point"},
    918109: {"Other_Default_Ignorable_Code_Point"},
    918110: {"Other_Default_Ignorable_Code_Point"},
    918111: {"Other_Default_Ignorable_Code_Point"},
    918112: {"Other_Default_Ignorable_Code_Point"},
    918113: {"Other_Default_Ignorable_Code_Point"},
    918114: {"Other_Default_Ignorable_Code_Point"},
    918115: {"Other_Default_Ignorable_Code_Point"},
    918116: {"Other_Default_Ignorable_Code_Point"},
    918117: {"Other_Default_Ignorable_Code_Point"},
    918118: {"Other_Default_Ignorable_Code_Point"},
    918119: {"Other_Default_Ignorable_Code_Point"},
    918120: {"Other_Default_Ignorable_Code_Point"},
    918121: {"Other_Default_Ignorable_Code_Point"},
    918122: {"Other_Default_Ignorable_Code_Point"},
    918123: {"Other_Default_Ignorable_Code_Point"},
    918124: {"Other_Default_Ignorable_Code_Point"},
    918125: {"Other_Default_Ignorable_Code_Point"},
    918126: {"Other_Default_Ignorable_Code_Point"},
    918127: {"Other_Default_Ignorable_Code_Point"},
    918128: {"Other_Default_Ignorable_Code_Point"},
    918129: {"Other_Default_Ignorable_Code_Point"},
    918130: {"Other_Default_Ignorable_Code_Point"},
    918131: {"Other_Default_Ignorable_Code_Point"},
    918132: {"Other_Default_Ignorable_Code_Point"},
    918133: {"Other_Default_Ignorable_Code_Point"},
    918134: {"Other_Default_Ignorable_Code_Point"},
    918135: {"Other_Default_Ignorable_Code_Point"},
    918136: {"Other_Default_Ignorable_Code_Point"},
    918137: {"Other_Default_Ignorable_Code_Point"},
    918138: {"Other_Default_Ignorable_Code_Point"},
    918139: {"Other_Default_Ignorable_Code_Point"},
    918140: {"Other_Default_Ignorable_Code_Point"},
    918141: {"Other_Default_Ignorable_Code_Point"},
    918142: {"Other_Default_Ignorable_Code_Point"},
    918143: {"Other_Default_Ignorable_Code_Point"},
    918144: {"Other_Default_Ignorable_Code_Point"},
    918145: {"Other_Default_Ignorable_Code_Point"},
    918146: {"Other_Default_Ignorable_Code_Point"},
    918147: {"Other_Default_Ignorable_Code_Point"},
    918148: {"Other_Default_Ignorable_Code_Point"},
    918149: {"Other_Default_Ignorable_Code_Point"},
    918150: {"Other_Default_Ignorable_Code_Point"},
    918151: {"Other_Default_Ignorable_Code_Point"},
    918152: {"Other_Default_Ignorable_Code_Point"},
    918153: {"Other_Default_Ignorable_Code_Point"},
    918154: {"Other_Default_Ignorable_Code_Point"},
    918155: {"Other_Default_Ignorable_Code_Point"},
    918156: {"Other_Default_Ignorable_Code_Point"},
    918157: {"Other_Default_Ignorable_Code_Point"},
    918158: {"Other_Default_Ignorable_Code_Point"},
    918159: {"Other_Default_Ignorable_Code_Point"},
    918160: {"Other_Default_Ignorable_Code_Point"},
    918161: {"Other_Default_Ignorable_Code_Point"},
    918162: {"Other_Default_Ignorable_Code_Point"},
    918163: {"Other_Default_Ignorable_Code_Point"},
    918164: {"Other_Default_Ignorable_Code_Point"},
    918165: {"Other_Default_Ignorable_Code_Point"},
    918166: {"Other_Default_Ignorable_Code_Point"},
    918167: {"Other_Default_Ignorable_Code_Point"},
    918168: {"Other_Default_Ignorable_Code_Point"},
    918169: {"Other_Default_Ignorable_Code_Point"},
    918170: {"Other_Default_Ignorable_Code_Point"},
    918171: {"Other_Default_Ignorable_Code_Point"},
    918172: {"Other_Default_Ignorable_Code_Point"},
    918173: {"Other_Default_Ignorable_Code_Point"},
    918174: {"Other_Default_Ignorable_Code_Point"},
    918175: {"Other_Default_Ignorable_Code_Point"},
    918176: {"Other_Default_Ignorable_Code_Point"},
    918177: {"Other_Default_Ignorable_Code_Point"},
    918178: {"Other_Default_Ignorable_Code_Point"},
    918179: {"Other_Default_Ignorable_Code_Point"},
    918180: {"Other_Default_Ignorable_Code_Point"},
    918181: {"Other_Default_Ignorable_Code_Point"},
    918182: {"Other_Default_Ignorable_Code_Point"},
    918183: {"Other_Default_Ignorable_Code_Point"},
    918184: {"Other_Default_Ignorable_Code_Point"},
    918185: {"Other_Default_Ignorable_Code_Point"},
    918186: {"Other_Default_Ignorable_Code_Point"},
    918187: {"Other_Default_Ignorable_Code_Point"},
    918188: {"Other_Default_Ignorable_Code_Point"},
    918189: {"Other_Default_Ignorable_Code_Point"},
    918190: {"Other_Default_Ignorable_Code_Point"},
    918191: {"Other_Default_Ignorable_Code_Point"},
    918192: {"Other_Default_Ignorable_Code_Point"},
    918193: {"Other_Default_Ignorable_Code_Point"},
    918194: {"Other_Default_Ignorable_Code_Point"},
    918195: {"Other_Default_Ignorable_Code_Point"},
    918196: {"Other_Default_Ignorable_Code_Point"},
    918197: {"Other_Default_Ignorable_Code_Point"},
    918198: {"Other_Default_Ignorable_Code_Point"},
    918199: {"Other_Default_Ignorable_Code_Point"},
    918200: {"Other_Default_Ignorable_Code_Point"},
    918201: {"Other_Default_Ignorable_Code_Point"},
    918202: {"Other_Default_Ignorable_Code_Point"},
    918203: {"Other_Default_Ignorable_Code_Point"},
    918204: {"Other_Default_Ignorable_Code_Point"},
    918205: {"Other_Default_Ignorable_Code_Point"},
    918206: {"Other_Default_Ignorable_Code_Point"},
    918207: {"Other_Default_Ignorable_Code_Point"},
    918208: {"Other_Default_Ignorable_Code_Point"},
    918209: {"Other_Default_Ignorable_Code_Point"},
    918210: {"Other_Default_Ignorable_Code_Point"},
    918211: {"Other_Default_Ignorable_Code_Point"},
    918212: {"Other_Default_Ignorable_Code_Point"},
    918213: {"Other_Default_Ignorable_Code_Point"},
    918214: {"Other_Default_Ignorable_Code_Point"},
    918215: {"Other_Default_Ignorable_Code_Point"},
    918216: {"Other_Default_Ignorable_Code_Point"},
    918217: {"Other_Default_Ignorable_Code_Point"},
    918218: {"Other_Default_Ignorable_Code_Point"},
    918219: {"Other_Default_Ignorable_Code_Point"},
    918220: {"Other_Default_Ignorable_Code_Point"},
    918221: {"Other_Default_Ignorable_Code_Point"},
    918222: {"Other_Default_Ignorable_Code_Point"},
    918223: {"Other_Default_Ignorable_Code_Point"},
    918224: {"Other_Default_Ignorable_Code_Point"},
    918225: {"Other_Default_Ignorable_Code_Point"},
    918226: {"Other_Default_Ignorable_Code_Point"},
    918227: {"Other_Default_Ignorable_Code_Point"},
    918228: {"Other_Default_Ignorable_Code_Point"},
    918229: {"Other_Default_Ignorable_Code_Point"},
    918230: {"Other_Default_Ignorable_Code_Point"},
    918231: {"Other_Default_Ignorable_Code_Point"},
    918232: {"Other_Default_Ignorable_Code_Point"},
    918233: {"Other_Default_Ignorable_Code_Point"},
    918234: {"Other_Default_Ignorable_Code_Point"},
    918235: {"Other_Default_Ignorable_Code_Point"},
    918236: {"Other_Default_Ignorable_Code_Point"},
    918237: {"Other_Default_Ignorable_Code_Point"},
    918238: {"Other_Default_Ignorable_Code_Point"},
    918239: {"Other_Default_Ignorable_Code_Point"},
    918240: {"Other_Default_Ignorable_Code_Point"},
    918241: {"Other_Default_Ignorable_Code_Point"},
    918242: {"Other_Default_Ignorable_Code_Point"},
    918243: {"Other_Default_Ignorable_Code_Point"},
    918244: {"Other_Default_Ignorable_Code_Point"},
    918245: {"Other_Default_Ignorable_Code_Point"},
    918246: {"Other_Default_Ignorable_Code_Point"},
    918247: {"Other_Default_Ignorable_Code_Point"},
    918248: {"Other_Default_Ignorable_Code_Point"},
    918249: {"Other_Default_Ignorable_Code_Point"},
    918250: {"Other_Default_Ignorable_Code_Point"},
    918251: {"Other_Default_Ignorable_Code_Point"},
    918252: {"Other_Default_Ignorable_Code_Point"},
    918253: {"Other_Default_Ignorable_Code_Point"},
    918254: {"Other_Default_Ignorable_Code_Point"},
    918255: {"Other_Default_Ignorable_Code_Point"},
    918256: {"Other_Default_Ignorable_Code_Point"},
    918257: {"Other_Default_Ignorable_Code_Point"},
    918258: {"Other_Default_Ignorable_Code_Point"},
    918259: {"Other_Default_Ignorable_Code_Point"},
    918260: {"Other_Default_Ignorable_Code_Point"},
    918261: {"Other_Default_Ignorable_Code_Point"},
    918262: {"Other_Default_Ignorable_Code_Point"},
    918263: {"Other_Default_Ignorable_Code_Point"},
    918264: {"Other_Default_Ignorable_Code_Point"},
    918265: {"Other_Default_Ignorable_Code_Point"},
    918266: {"Other_Default_Ignorable_Code_Point"},
    918267: {"Other_Default_Ignorable_Code_Point"},
    918268: {"Other_Default_Ignorable_Code_Point"},
    918269: {"Other_Default_Ignorable_Code_Point"},
    918270: {"Other_Default_Ignorable_Code_Point"},
    918271: {"Other_Default_Ignorable_Code_Point"},
    918272: {"Other_Default_Ignorable_Code_Point"},
    918273: {"Other_Default_Ignorable_Code_Point"},
    918274: {"Other_Default_Ignorable_Code_Point"},
    918275: {"Other_Default_Ignorable_Code_Point"},
    918276: {"Other_Default_Ignorable_Code_Point"},
    918277: {"Other_Default_Ignorable_Code_Point"},
    918278: {"Other_Default_Ignorable_Code_Point"},
    918279: {"Other_Default_Ignorable_Code_Point"},
    918280: {"Other_Default_Ignorable_Code_Point"},
    918281: {"Other_Default_Ignorable_Code_Point"},
    918282: {"Other_Default_Ignorable_Code_Point"},
    918283: {"Other_Default_Ignorable_Code_Point"},
    918284: {"Other_Default_Ignorable_Code_Point"},
    918285: {"Other_Default_Ignorable_Code_Point"},
    918286: {"Other_Default_Ignorable_Code_Point"},
    918287: {"Other_Default_Ignorable_Code_Point"},
    918288: {"Other_Default_Ignorable_Code_Point"},
    918289: {"Other_Default_Ignorable_Code_Point"},
    918290: {"Other_Default_Ignorable_Code_Point"},
    918291: {"Other_Default_Ignorable_Code_Point"},
    918292: {"Other_Default_Ignorable_Code_Point"},
    918293: {"Other_Default_Ignorable_Code_Point"},
    918294: {"Other_Default_Ignorable_Code_Point"},
    918295: {"Other_Default_Ignorable_Code_Point"},
    918296: {"Other_Default_Ignorable_Code_Point"},
    918297: {"Other_Default_Ignorable_Code_Point"},
    918298: {"Other_Default_Ignorable_Code_Point"},
    918299: {"Other_Default_Ignorable_Code_Point"},
    918300: {"Other_Default_Ignorable_Code_Point"},
    918301: {"Other_Default_Ignorable_Code_Point"},
    918302: {"Other_Default_Ignorable_Code_Point"},
    918303: {"Other_Default_Ignorable_Code_Point"},
    918304: {"Other_Default_Ignorable_Code_Point"},
    918305: {"Other_Default_Ignorable_Code_Point"},
    918306: {"Other_Default_Ignorable_Code_Point"},
    918307: {"Other_Default_Ignorable_Code_Point"},
    918308: {"Other_Default_Ignorable_Code_Point"},
    918309: {"Other_Default_Ignorable_Code_Point"},
    918310: {"Other_Default_Ignorable_Code_Point"},
    918311: {"Other_Default_Ignorable_Code_Point"},
    918312: {"Other_Default_Ignorable_Code_Point"},
    918313: {"Other_Default_Ignorable_Code_Point"},
    918314: {"Other_Default_Ignorable_Code_Point"},
    918315: {"Other_Default_Ignorable_Code_Point"},
    918316: {"Other_Default_Ignorable_Code_Point"},
    918317: {"Other_Default_Ignorable_Code_Point"},
    918318: {"Other_Default_Ignorable_Code_Point"},
    918319: {"Other_Default_Ignorable_Code_Point"},
    918320: {"Other_Default_Ignorable_Code_Point"},
    918321: {"Other_Default_Ignorable_Code_Point"},
    918322: {"Other_Default_Ignorable_Code_Point"},
    918323: {"Other_Default_Ignorable_Code_Point"},
    918324: {"Other_Default_Ignorable_Code_Point"},
    918325: {"Other_Default_Ignorable_Code_Point"},
    918326: {"Other_Default_Ignorable_Code_Point"},
    918327: {"Other_Default_Ignorable_Code_Point"},
    918328: {"Other_Default_Ignorable_Code_Point"},
    918329: {"Other_Default_Ignorable_Code_Point"},
    918330: {"Other_Default_Ignorable_Code_Point"},
    918331: {"Other_Default_Ignorable_Code_Point"},
    918332: {"Other_Default_Ignorable_Code_Point"},
    918333: {"Other_Default_Ignorable_Code_Point"},
    918334: {"Other_Default_Ignorable_Code_Point"},
    918335: {"Other_Default_Ignorable_Code_Point"},
    918336: {"Other_Default_Ignorable_Code_Point"},
    918337: {"Other_Default_Ignorable_Code_Point"},
    918338: {"Other_Default_Ignorable_Code_Point"},
    918339: {"Other_Default_Ignorable_Code_Point"},
    918340: {"Other_Default_Ignorable_Code_Point"},
    918341: {"Other_Default_Ignorable_Code_Point"},
    918342: {"Other_Default_Ignorable_Code_Point"},
    918343: {"Other_Default_Ignorable_Code_Point"},
    918344: {"Other_Default_Ignorable_Code_Point"},
    918345: {"Other_Default_Ignorable_Code_Point"},
    918346: {"Other_Default_Ignorable_Code_Point"},
    918347: {"Other_Default_Ignorable_Code_Point"},
    918348: {"Other_Default_Ignorable_Code_Point"},
    918349: {"Other_Default_Ignorable_Code_Point"},
    918350: {"Other_Default_Ignorable_Code_Point"},
    918351: {"Other_Default_Ignorable_Code_Point"},
    918352: {"Other_Default_Ignorable_Code_Point"},
    918353: {"Other_Default_Ignorable_Code_Point"},
    918354: {"Other_Default_Ignorable_Code_Point"},
    918355: {"Other_Default_Ignorable_Code_Point"},
    918356: {"Other_Default_Ignorable_Code_Point"},
    918357: {"Other_Default_Ignorable_Code_Point"},
    918358: {"Other_Default_Ignorable_Code_Point"},
    918359: {"Other_Default_Ignorable_Code_Point"},
    918360: {"Other_Default_Ignorable_Code_Point"},
    918361: {"Other_Default_Ignorable_Code_Point"},
    918362: {"Other_Default_Ignorable_Code_Point"},
    918363: {"Other_Default_Ignorable_Code_Point"},
    918364: {"Other_Default_Ignorable_Code_Point"},
    918365: {"Other_Default_Ignorable_Code_Point"},
    918366: {"Other_Default_Ignorable_Code_Point"},
    918367: {"Other_Default_Ignorable_Code_Point"},
    918368: {"Other_Default_Ignorable_Code_Point"},
    918369: {"Other_Default_Ignorable_Code_Point"},
    918370: {"Other_Default_Ignorable_Code_Point"},
    918371: {"Other_Default_Ignorable_Code_Point"},
    918372: {"Other_Default_Ignorable_Code_Point"},
    918373: {"Other_Default_Ignorable_Code_Point"},
    918374: {"Other_Default_Ignorable_Code_Point"},
    918375: {"Other_Default_Ignorable_Code_Point"},
    918376: {"Other_Default_Ignorable_Code_Point"},
    918377: {"Other_Default_Ignorable_Code_Point"},
    918378: {"Other_Default_Ignorable_Code_Point"},
    918379: {"Other_Default_Ignorable_Code_Point"},
    918380: {"Other_Default_Ignorable_Code_Point"},
    918381: {"Other_Default_Ignorable_Code_Point"},
    918382: {"Other_Default_Ignorable_Code_Point"},
    918383: {"Other_Default_Ignorable_Code_Point"},
    918384: {"Other_Default_Ignorable_Code_Point"},
    918385: {"Other_Default_Ignorable_Code_Point"},
    918386: {"Other_Default_Ignorable_Code_Point"},
    918387: {"Other_Default_Ignorable_Code_Point"},
    918388: {"Other_Default_Ignorable_Code_Point"},
    918389: {"Other_Default_Ignorable_Code_Point"},
    918390: {"Other_Default_Ignorable_Code_Point"},
    918391: {"Other_Default_Ignorable_Code_Point"},
    918392: {"Other_Default_Ignorable_Code_Point"},
    918393: {"Other_Default_Ignorable_Code_Point"},
    918394: {"Other_Default_Ignorable_Code_Point"},
    918395: {"Other_Default_Ignorable_Code_Point"},
    918396: {"Other_Default_Ignorable_Code_Point"},
    918397: {"Other_Default_Ignorable_Code_Point"},
    918398: {"Other_Default_Ignorable_Code_Point"},
    918399: {"Other_Default_Ignorable_Code_Point"},
    918400: {"Other_Default_Ignorable_Code_Point"},
    918401: {"Other_Default_Ignorable_Code_Point"},
    918402: {"Other_Default_Ignorable_Code_Point"},
    918403: {"Other_Default_Ignorable_Code_Point"},
    918404: {"Other_Default_Ignorable_Code_Point"},
    918405: {"Other_Default_Ignorable_Code_Point"},
    918406: {"Other_Default_Ignorable_Code_Point"},
    918407: {"Other_Default_Ignorable_Code_Point"},
    918408: {"Other_Default_Ignorable_Code_Point"},
    918409: {"Other_Default_Ignorable_Code_Point"},
    918410: {"Other_Default_Ignorable_Code_Point"},
    918411: {"Other_Default_Ignorable_Code_Point"},
    918412: {"Other_Default_Ignorable_Code_Point"},
    918413: {"Other_Default_Ignorable_Code_Point"},
    918414: {"Other_Default_Ignorable_Code_Point"},
    918415: {"Other_Default_Ignorable_Code_Point"},
    918416: {"Other_Default_Ignorable_Code_Point"},
    918417: {"Other_Default_Ignorable_Code_Point"},
    918418: {"Other_Default_Ignorable_Code_Point"},
    918419: {"Other_Default_Ignorable_Code_Point"},
    918420: {"Other_Default_Ignorable_Code_Point"},
    918421: {"Other_Default_Ignorable_Code_Point"},
    918422: {"Other_Default_Ignorable_Code_Point"},
    918423: {"Other_Default_Ignorable_Code_Point"},
    918424: {"Other_Default_Ignorable_Code_Point"},
    918425: {"Other_Default_Ignorable_Code_Point"},
    918426: {"Other_Default_Ignorable_Code_Point"},
    918427: {"Other_Default_Ignorable_Code_Point"},
    918428: {"Other_Default_Ignorable_Code_Point"},
    918429: {"Other_Default_Ignorable_Code_Point"},
    918430: {"Other_Default_Ignorable_Code_Point"},
    918431: {"Other_Default_Ignorable_Code_Point"},
    918432: {"Other_Default_Ignorable_Code_Point"},
    918433: {"Other_Default_Ignorable_Code_Point"},
    918434: {"Other_Default_Ignorable_Code_Point"},
    918435: {"Other_Default_Ignorable_Code_Point"},
    918436: {"Other_Default_Ignorable_Code_Point"},
    918437: {"Other_Default_Ignorable_Code_Point"},
    918438: {"Other_Default_Ignorable_Code_Point"},
    918439: {"Other_Default_Ignorable_Code_Point"},
    918440: {"Other_Default_Ignorable_Code_Point"},
    918441: {"Other_Default_Ignorable_Code_Point"},
    918442: {"Other_Default_Ignorable_Code_Point"},
    918443: {"Other_Default_Ignorable_Code_Point"},
    918444: {"Other_Default_Ignorable_Code_Point"},
    918445: {"Other_Default_Ignorable_Code_Point"},
    918446: {"Other_Default_Ignorable_Code_Point"},
    918447: {"Other_Default_Ignorable_Code_Point"},
    918448: {"Other_Default_Ignorable_Code_Point"},
    918449: {"Other_Default_Ignorable_Code_Point"},
    918450: {"Other_Default_Ignorable_Code_Point"},
    918451: {"Other_Default_Ignorable_Code_Point"},
    918452: {"Other_Default_Ignorable_Code_Point"},
    918453: {"Other_Default_Ignorable_Code_Point"},
    918454: {"Other_Default_Ignorable_Code_Point"},
    918455: {"Other_Default_Ignorable_Code_Point"},
    918456: {"Other_Default_Ignorable_Code_Point"},
    918457: {"Other_Default_Ignorable_Code_Point"},
    918458: {"Other_Default_Ignorable_Code_Point"},
    918459: {"Other_Default_Ignorable_Code_Point"},
    918460: {"Other_Default_Ignorable_Code_Point"},
    918461: {"Other_Default_Ignorable_Code_Point"},
    918462: {"Other_Default_Ignorable_Code_Point"},
    918463: {"Other_Default_Ignorable_Code_Point"},
    918464: {"Other_Default_Ignorable_Code_Point"},
    918465: {"Other_Default_Ignorable_Code_Point"},
    918466: {"Other_Default_Ignorable_Code_Point"},
    918467: {"Other_Default_Ignorable_Code_Point"},
    918468: {"Other_Default_Ignorable_Code_Point"},
    918469: {"Other_Default_Ignorable_Code_Point"},
    918470: {"Other_Default_Ignorable_Code_Point"},
    918471: {"Other_Default_Ignorable_Code_Point"},
    918472: {"Other_Default_Ignorable_Code_Point"},
    918473: {"Other_Default_Ignorable_Code_Point"},
    918474: {"Other_Default_Ignorable_Code_Point"},
    918475: {"Other_Default_Ignorable_Code_Point"},
    918476: {"Other_Default_Ignorable_Code_Point"},
    918477: {"Other_Default_Ignorable_Code_Point"},
    918478: {"Other_Default_Ignorable_Code_Point"},
    918479: {"Other_Default_Ignorable_Code_Point"},
    918480: {"Other_Default_Ignorable_Code_Point"},
    918481: {"Other_Default_Ignorable_Code_Point"},
    918482: {"Other_Default_Ignorable_Code_Point"},
    918483: {"Other_Default_Ignorable_Code_Point"},
    918484: {"Other_Default_Ignorable_Code_Point"},
    918485: {"Other_Default_Ignorable_Code_Point"},
    918486: {"Other_Default_Ignorable_Code_Point"},
    918487: {"Other_Default_Ignorable_Code_Point"},
    918488: {"Other_Default_Ignorable_Code_Point"},
    918489: {"Other_Default_Ignorable_Code_Point"},
    918490: {"Other_Default_Ignorable_Code_Point"},
    918491: {"Other_Default_Ignorable_Code_Point"},
    918492: {"Other_Default_Ignorable_Code_Point"},
    918493: {"Other_Default_Ignorable_Code_Point"},
    918494: {"Other_Default_Ignorable_Code_Point"},
    918495: {"Other_Default_Ignorable_Code_Point"},
    918496: {"Other_Default_Ignorable_Code_Point"},
    918497: {"Other_Default_Ignorable_Code_Point"},
    918498: {"Other_Default_Ignorable_Code_Point"},
    918499: {"Other_Default_Ignorable_Code_Point"},
    918500: {"Other_Default_Ignorable_Code_Point"},
    918501: {"Other_Default_Ignorable_Code_Point"},
    918502: {"Other_Default_Ignorable_Code_Point"},
    918503: {"Other_Default_Ignorable_Code_Point"},
    918504: {"Other_Default_Ignorable_Code_Point"},
    918505: {"Other_Default_Ignorable_Code_Point"},
    918506: {"Other_Default_Ignorable_Code_Point"},
    918507: {"Other_Default_Ignorable_Code_Point"},
    918508: {"Other_Default_Ignorable_Code_Point"},
    918509: {"Other_Default_Ignorable_Code_Point"},
    918510: {"Other_Default_Ignorable_Code_Point"},
    918511: {"Other_Default_Ignorable_Code_Point"},
    918512: {"Other_Default_Ignorable_Code_Point"},
    918513: {"Other_Default_Ignorable_Code_Point"},
    918514: {"Other_Default_Ignorable_Code_Point"},
    918515: {"Other_Default_Ignorable_Code_Point"},
    918516: {"Other_Default_Ignorable_Code_Point"},
    918517: {"Other_Default_Ignorable_Code_Point"},
    918518: {"Other_Default_Ignorable_Code_Point"},
    918519: {"Other_Default_Ignorable_Code_Point"},
    918520: {"Other_Default_Ignorable_Code_Point"},
    918521: {"Other_Default_Ignorable_Code_Point"},
    918522: {"Other_Default_Ignorable_Code_Point"},
    918523: {"Other_Default_Ignorable_Code_Point"},
    918524: {"Other_Default_Ignorable_Code_Point"},
    918525: {"Other_Default_Ignorable_Code_Point"},
    918526: {"Other_Default_Ignorable_Code_Point"},
    918527: {"Other_Default_Ignorable_Code_Point"},
    918528: {"Other_Default_Ignorable_Code_Point"},
    918529: {"Other_Default_Ignorable_Code_Point"},
    918530: {"Other_Default_Ignorable_Code_Point"},
    918531: {"Other_Default_Ignorable_Code_Point"},
    918532: {"Other_Default_Ignorable_Code_Point"},
    918533: {"Other_Default_Ignorable_Code_Point"},
    918534: {"Other_Default_Ignorable_Code_Point"},
    918535: {"Other_Default_Ignorable_Code_Point"},
    918536: {"Other_Default_Ignorable_Code_Point"},
    918537: {"Other_Default_Ignorable_Code_Point"},
    918538: {"Other_Default_Ignorable_Code_Point"},
    918539: {"Other_Default_Ignorable_Code_Point"},
    918540: {"Other_Default_Ignorable_Code_Point"},
    918541: {"Other_Default_Ignorable_Code_Point"},
    918542: {"Other_Default_Ignorable_Code_Point"},
    918543: {"Other_Default_Ignorable_Code_Point"},
    918544: {"Other_Default_Ignorable_Code_Point"},
    918545: {"Other_Default_Ignorable_Code_Point"},
    918546: {"Other_Default_Ignorable_Code_Point"},
    918547: {"Other_Default_Ignorable_Code_Point"},
    918548: {"Other_Default_Ignorable_Code_Point"},
    918549: {"Other_Default_Ignorable_Code_Point"},
    918550: {"Other_Default_Ignorable_Code_Point"},
    918551: {"Other_Default_Ignorable_Code_Point"},
    918552: {"Other_Default_Ignorable_Code_Point"},
    918553: {"Other_Default_Ignorable_Code_Point"},
    918554: {"Other_Default_Ignorable_Code_Point"},
    918555: {"Other_Default_Ignorable_Code_Point"},
    918556: {"Other_Default_Ignorable_Code_Point"},
    918557: {"Other_Default_Ignorable_Code_Point"},
    918558: {"Other_Default_Ignorable_Code_Point"},
    918559: {"Other_Default_Ignorable_Code_Point"},
    918560: {"Other_Default_Ignorable_Code_Point"},
    918561: {"Other_Default_Ignorable_Code_Point"},
    918562: {"Other_Default_Ignorable_Code_Point"},
    918563: {"Other_Default_Ignorable_Code_Point"},
    918564: {"Other_Default_Ignorable_Code_Point"},
    918565: {"Other_Default_Ignorable_Code_Point"},
    918566: {"Other_Default_Ignorable_Code_Point"},
    918567: {"Other_Default_Ignorable_Code_Point"},
    918568: {"Other_Default_Ignorable_Code_Point"},
    918569: {"Other_Default_Ignorable_Code_Point"},
    918570: {"Other_Default_Ignorable_Code_Point"},
    918571: {"Other_Default_Ignorable_Code_Point"},
    918572: {"Other_Default_Ignorable_Code_Point"},
    918573: {"Other_Default_Ignorable_Code_Point"},
    918574: {"Other_Default_Ignorable_Code_Point"},
    918575: {"Other_Default_Ignorable_Code_Point"},
    918576: {"Other_Default_Ignorable_Code_Point"},
    918577: {"Other_Default_Ignorable_Code_Point"},
    918578: {"Other_Default_Ignorable_Code_Point"},
    918579: {"Other_Default_Ignorable_Code_Point"},
    918580: {"Other_Default_Ignorable_Code_Point"},
    918581: {"Other_Default_Ignorable_Code_Point"},
    918582: {"Other_Default_Ignorable_Code_Point"},
    918583: {"Other_Default_Ignorable_Code_Point"},
    918584: {"Other_Default_Ignorable_Code_Point"},
    918585: {"Other_Default_Ignorable_Code_Point"},
    918586: {"Other_Default_Ignorable_Code_Point"},
    918587: {"Other_Default_Ignorable_Code_Point"},
    918588: {"Other_Default_Ignorable_Code_Point"},
    918589: {"Other_Default_Ignorable_Code_Point"},
    918590: {"Other_Default_Ignorable_Code_Point"},
    918591: {"Other_Default_Ignorable_Code_Point"},
    918592: {"Other_Default_Ignorable_Code_Point"},
    918593: {"Other_Default_Ignorable_Code_Point"},
    918594: {"Other_Default_Ignorable_Code_Point"},
    918595: {"Other_Default_Ignorable_Code_Point"},
    918596: {"Other_Default_Ignorable_Code_Point"},
    918597: {"Other_Default_Ignorable_Code_Point"},
    918598: {"Other_Default_Ignorable_Code_Point"},
    918599: {"Other_Default_Ignorable_Code_Point"},
    918600: {"Other_Default_Ignorable_Code_Point"},
    918601: {"Other_Default_Ignorable_Code_Point"},
    918602: {"Other_Default_Ignorable_Code_Point"},
    918603: {"Other_Default_Ignorable_Code_Point"},
    918604: {"Other_Default_Ignorable_Code_Point"},
    918605: {"Other_Default_Ignorable_Code_Point"},
    918606: {"Other_Default_Ignorable_Code_Point"},
    918607: {"Other_Default_Ignorable_Code_Point"},
    918608: {"Other_Default_Ignorable_Code_Point"},
    918609: {"Other_Default_Ignorable_Code_Point"},
    918610: {"Other_Default_Ignorable_Code_Point"},
    918611: {"Other_Default_Ignorable_Code_Point"},
    918612: {"Other_Default_Ignorable_Code_Point"},
    918613: {"Other_Default_Ignorable_Code_Point"},
    918614: {"Other_Default_Ignorable_Code_Point"},
    918615: {"Other_Default_Ignorable_Code_Point"},
    918616: {"Other_Default_Ignorable_Code_Point"},
    918617: {"Other_Default_Ignorable_Code_Point"},
    918618: {"Other_Default_Ignorable_Code_Point"},
    918619: {"Other_Default_Ignorable_Code_Point"},
    918620: {"Other_Default_Ignorable_Code_Point"},
    918621: {"Other_Default_Ignorable_Code_Point"},
    918622: {"Other_Default_Ignorable_Code_Point"},
    918623: {"Other_Default_Ignorable_Code_Point"},
    918624: {"Other_Default_Ignorable_Code_Point"},
    918625: {"Other_Default_Ignorable_Code_Point"},
    918626: {"Other_Default_Ignorable_Code_Point"},
    918627: {"Other_Default_Ignorable_Code_Point"},
    918628: {"Other_Default_Ignorable_Code_Point"},
    918629: {"Other_Default_Ignorable_Code_Point"},
    918630: {"Other_Default_Ignorable_Code_Point"},
    918631: {"Other_Default_Ignorable_Code_Point"},
    918632: {"Other_Default_Ignorable_Code_Point"},
    918633: {"Other_Default_Ignorable_Code_Point"},
    918634: {"Other_Default_Ignorable_Code_Point"},
    918635: {"Other_Default_Ignorable_Code_Point"},
    918636: {"Other_Default_Ignorable_Code_Point"},
    918637: {"Other_Default_Ignorable_Code_Point"},
    918638: {"Other_Default_Ignorable_Code_Point"},
    918639: {"Other_Default_Ignorable_Code_Point"},
    918640: {"Other_Default_Ignorable_Code_Point"},
    918641: {"Other_Default_Ignorable_Code_Point"},
    918642: {"Other_Default_Ignorable_Code_Point"},
    918643: {"Other_Default_Ignorable_Code_Point"},
    918644: {"Other_Default_Ignorable_Code_Point"},
    918645: {"Other_Default_Ignorable_Code_Point"},
    918646: {"Other_Default_Ignorable_Code_Point"},
    918647: {"Other_Default_Ignorable_Code_Point"},
    918648: {"Other_Default_Ignorable_Code_Point"},
    918649: {"Other_Default_Ignorable_Code_Point"},
    918650: {"Other_Default_Ignorable_Code_Point"},
    918651: {"Other_Default_Ignorable_Code_Point"},
    918652: {"Other_Default_Ignorable_Code_Point"},
    918653: {"Other_Default_Ignorable_Code_Point"},
    918654: {"Other_Default_Ignorable_Code_Point"},
    918655: {"Other_Default_Ignorable_Code_Point"},
    918656: {"Other_Default_Ignorable_Code_Point"},
    918657: {"Other_Default_Ignorable_Code_Point"},
    918658: {"Other_Default_Ignorable_Code_Point"},
    918659: {"Other_Default_Ignorable_Code_Point"},
    918660: {"Other_Default_Ignorable_Code_Point"},
    918661: {"Other_Default_Ignorable_Code_Point"},
    918662: {"Other_Default_Ignorable_Code_Point"},
    918663: {"Other_Default_Ignorable_Code_Point"},
    918664: {"Other_Default_Ignorable_Code_Point"},
    918665: {"Other_Default_Ignorable_Code_Point"},
    918666: {"Other_Default_Ignorable_Code_Point"},
    918667: {"Other_Default_Ignorable_Code_Point"},
    918668: {"Other_Default_Ignorable_Code_Point"},
    918669: {"Other_Default_Ignorable_Code_Point"},
    918670: {"Other_Default_Ignorable_Code_Point"},
    918671: {"Other_Default_Ignorable_Code_Point"},
    918672: {"Other_Default_Ignorable_Code_Point"},
    918673: {"Other_Default_Ignorable_Code_Point"},
    918674: {"Other_Default_Ignorable_Code_Point"},
    918675: {"Other_Default_Ignorable_Code_Point"},
    918676: {"Other_Default_Ignorable_Code_Point"},
    918677: {"Other_Default_Ignorable_Code_Point"},
    918678: {"Other_Default_Ignorable_Code_Point"},
    918679: {"Other_Default_Ignorable_Code_Point"},
    918680: {"Other_Default_Ignorable_Code_Point"},
    918681: {"Other_Default_Ignorable_Code_Point"},
    918682: {"Other_Default_Ignorable_Code_Point"},
    918683: {"Other_Default_Ignorable_Code_Point"},
    918684: {"Other_Default_Ignorable_Code_Point"},
    918685: {"Other_Default_Ignorable_Code_Point"},
    918686: {"Other_Default_Ignorable_Code_Point"},
    918687: {"Other_Default_Ignorable_Code_Point"},
    918688: {"Other_Default_Ignorable_Code_Point"},
    918689: {"Other_Default_Ignorable_Code_Point"},
    918690: {"Other_Default_Ignorable_Code_Point"},
    918691: {"Other_Default_Ignorable_Code_Point"},
    918692: {"Other_Default_Ignorable_Code_Point"},
    918693: {"Other_Default_Ignorable_Code_Point"},
    918694: {"Other_Default_Ignorable_Code_Point"},
    918695: {"Other_Default_Ignorable_Code_Point"},
    918696: {"Other_Default_Ignorable_Code_Point"},
    918697: {"Other_Default_Ignorable_Code_Point"},
    918698: {"Other_Default_Ignorable_Code_Point"},
    918699: {"Other_Default_Ignorable_Code_Point"},
    918700: {"Other_Default_Ignorable_Code_Point"},
    918701: {"Other_Default_Ignorable_Code_Point"},
    918702: {"Other_Default_Ignorable_Code_Point"},
    918703: {"Other_Default_Ignorable_Code_Point"},
    918704: {"Other_Default_Ignorable_Code_Point"},
    918705: {"Other_Default_Ignorable_Code_Point"},
    918706: {"Other_Default_Ignorable_Code_Point"},
    918707: {"Other_Default_Ignorable_Code_Point"},
    918708: {"Other_Default_Ignorable_Code_Point"},
    918709: {"Other_Default_Ignorable_Code_Point"},
    918710: {"Other_Default_Ignorable_Code_Point"},
    918711: {"Other_Default_Ignorable_Code_Point"},
    918712: {"Other_Default_Ignorable_Code_Point"},
    918713: {"Other_Default_Ignorable_Code_Point"},
    918714: {"Other_Default_Ignorable_Code_Point"},
    918715: {"Other_Default_Ignorable_Code_Point"},
    918716: {"Other_Default_Ignorable_Code_Point"},
    918717: {"Other_Default_Ignorable_Code_Point"},
    918718: {"Other_Default_Ignorable_Code_Point"},
    918719: {"Other_Default_Ignorable_Code_Point"},
    918720: {"Other_Default_Ignorable_Code_Point"},
    918721: {"Other_Default_Ignorable_Code_Point"},
    918722: {"Other_Default_Ignorable_Code_Point"},
    918723: {"Other_Default_Ignorable_Code_Point"},
    918724: {"Other_Default_Ignorable_Code_Point"},
    918725: {"Other_Default_Ignorable_Code_Point"},
    918726: {"Other_Default_Ignorable_Code_Point"},
    918727: {"Other_Default_Ignorable_Code_Point"},
    918728: {"Other_Default_Ignorable_Code_Point"},
    918729: {"Other_Default_Ignorable_Code_Point"},
    918730: {"Other_Default_Ignorable_Code_Point"},
    918731: {"Other_Default_Ignorable_Code_Point"},
    918732: {"Other_Default_Ignorable_Code_Point"},
    918733: {"Other_Default_Ignorable_Code_Point"},
    918734: {"Other_Default_Ignorable_Code_Point"},
    918735: {"Other_Default_Ignorable_Code_Point"},
    918736: {"Other_Default_Ignorable_Code_Point"},
    918737: {"Other_Default_Ignorable_Code_Point"},
    918738: {"Other_Default_Ignorable_Code_Point"},
    918739: {"Other_Default_Ignorable_Code_Point"},
    918740: {"Other_Default_Ignorable_Code_Point"},
    918741: {"Other_Default_Ignorable_Code_Point"},
    918742: {"Other_Default_Ignorable_Code_Point"},
    918743: {"Other_Default_Ignorable_Code_Point"},
    918744: {"Other_Default_Ignorable_Code_Point"},
    918745: {"Other_Default_Ignorable_Code_Point"},
    918746: {"Other_Default_Ignorable_Code_Point"},
    918747: {"Other_Default_Ignorable_Code_Point"},
    918748: {"Other_Default_Ignorable_Code_Point"},
    918749: {"Other_Default_Ignorable_Code_Point"},
    918750: {"Other_Default_Ignorable_Code_Point"},
    918751: {"Other_Default_Ignorable_Code_Point"},
    918752: {"Other_Default_Ignorable_Code_Point"},
    918753: {"Other_Default_Ignorable_Code_Point"},
    918754: {"Other_Default_Ignorable_Code_Point"},
    918755: {"Other_Default_Ignorable_Code_Point"},
    918756: {"Other_Default_Ignorable_Code_Point"},
    918757: {"Other_Default_Ignorable_Code_Point"},
    918758: {"Other_Default_Ignorable_Code_Point"},
    918759: {"Other_Default_Ignorable_Code_Point"},
    918760: {"Other_Default_Ignorable_Code_Point"},
    918761: {"Other_Default_Ignorable_Code_Point"},
    918762: {"Other_Default_Ignorable_Code_Point"},
    918763: {"Other_Default_Ignorable_Code_Point"},
    918764: {"Other_Default_Ignorable_Code_Point"},
    918765: {"Other_Default_Ignorable_Code_Point"},
    918766: {"Other_Default_Ignorable_Code_Point"},
    918767: {"Other_Default_Ignorable_Code_Point"},
    918768: {"Other_Default_Ignorable_Code_Point"},
    918769: {"Other_Default_Ignorable_Code_Point"},
    918770: {"Other_Default_Ignorable_Code_Point"},
    918771: {"Other_Default_Ignorable_Code_Point"},
    918772: {"Other_Default_Ignorable_Code_Point"},
    918773: {"Other_Default_Ignorable_Code_Point"},
    918774: {"Other_Default_Ignorable_Code_Point"},
    918775: {"Other_Default_Ignorable_Code_Point"},
    918776: {"Other_Default_Ignorable_Code_Point"},
    918777: {"Other_Default_Ignorable_Code_Point"},
    918778: {"Other_Default_Ignorable_Code_Point"},
    918779: {"Other_Default_Ignorable_Code_Point"},
    918780: {"Other_Default_Ignorable_Code_Point"},
    918781: {"Other_Default_Ignorable_Code_Point"},
    918782: {"Other_Default_Ignorable_Code_Point"},
    918783: {"Other_Default_Ignorable_Code_Point"},
    918784: {"Other_Default_Ignorable_Code_Point"},
    918785: {"Other_Default_Ignorable_Code_Point"},
    918786: {"Other_Default_Ignorable_Code_Point"},
    918787: {"Other_Default_Ignorable_Code_Point"},
    918788: {"Other_Default_Ignorable_Code_Point"},
    918789: {"Other_Default_Ignorable_Code_Point"},
    918790: {"Other_Default_Ignorable_Code_Point"},
    918791: {"Other_Default_Ignorable_Code_Point"},
    918792: {"Other_Default_Ignorable_Code_Point"},
    918793: {"Other_Default_Ignorable_Code_Point"},
    918794: {"Other_Default_Ignorable_Code_Point"},
    918795: {"Other_Default_Ignorable_Code_Point"},
    918796: {"Other_Default_Ignorable_Code_Point"},
    918797: {"Other_Default_Ignorable_Code_Point"},
    918798: {"Other_Default_Ignorable_Code_Point"},
    918799: {"Other_Default_Ignorable_Code_Point"},
    918800: {"Other_Default_Ignorable_Code_Point"},
    918801: {"Other_Default_Ignorable_Code_Point"},
    918802: {"Other_Default_Ignorable_Code_Point"},
    918803: {"Other_Default_Ignorable_Code_Point"},
    918804: {"Other_Default_Ignorable_Code_Point"},
    918805: {"Other_Default_Ignorable_Code_Point"},
    918806: {"Other_Default_Ignorable_Code_Point"},
    918807: {"Other_Default_Ignorable_Code_Point"},
    918808: {"Other_Default_Ignorable_Code_Point"},
    918809: {"Other_Default_Ignorable_Code_Point"},
    918810: {"Other_Default_Ignorable_Code_Point"},
    918811: {"Other_Default_Ignorable_Code_Point"},
    918812: {"Other_Default_Ignorable_Code_Point"},
    918813: {"Other_Default_Ignorable_Code_Point"},
    918814: {"Other_Default_Ignorable_Code_Point"},
    918815: {"Other_Default_Ignorable_Code_Point"},
    918816: {"Other_Default_Ignorable_Code_Point"},
    918817: {"Other_Default_Ignorable_Code_Point"},
    918818: {"Other_Default_Ignorable_Code_Point"},
    918819: {"Other_Default_Ignorable_Code_Point"},
    918820: {"Other_Default_Ignorable_Code_Point"},
    918821: {"Other_Default_Ignorable_Code_Point"},
    918822: {"Other_Default_Ignorable_Code_Point"},
    918823: {"Other_Default_Ignorable_Code_Point"},
    918824: {"Other_Default_Ignorable_Code_Point"},
    918825: {"Other_Default_Ignorable_Code_Point"},
    918826: {"Other_Default_Ignorable_Code_Point"},
    918827: {"Other_Default_Ignorable_Code_Point"},
    918828: {"Other_Default_Ignorable_Code_Point"},
    918829: {"Other_Default_Ignorable_Code_Point"},
    918830: {"Other_Default_Ignorable_Code_Point"},
    918831: {"Other_Default_Ignorable_Code_Point"},
    918832: {"Other_Default_Ignorable_Code_Point"},
    918833: {"Other_Default_Ignorable_Code_Point"},
    918834: {"Other_Default_Ignorable_Code_Point"},
    918835: {"Other_Default_Ignorable_Code_Point"},
    918836: {"Other_Default_Ignorable_Code_Point"},
    918837: {"Other_Default_Ignorable_Code_Point"},
    918838: {"Other_Default_Ignorable_Code_Point"},
    918839: {"Other_Default_Ignorable_Code_Point"},
    918840: {"Other_Default_Ignorable_Code_Point"},
    918841: {"Other_Default_Ignorable_Code_Point"},
    918842: {"Other_Default_Ignorable_Code_Point"},
    918843: {"Other_Default_Ignorable_Code_Point"},
    918844: {"Other_Default_Ignorable_Code_Point"},
    918845: {"Other_Default_Ignorable_Code_Point"},
    918846: {"Other_Default_Ignorable_Code_Point"},
    918847: {"Other_Default_Ignorable_Code_Point"},
    918848: {"Other_Default_Ignorable_Code_Point"},
    918849: {"Other_Default_Ignorable_Code_Point"},
    918850: {"Other_Default_Ignorable_Code_Point"},
    918851: {"Other_Default_Ignorable_Code_Point"},
    918852: {"Other_Default_Ignorable_Code_Point"},
    918853: {"Other_Default_Ignorable_Code_Point"},
    918854: {"Other_Default_Ignorable_Code_Point"},
    918855: {"Other_Default_Ignorable_Code_Point"},
    918856: {"Other_Default_Ignorable_Code_Point"},
    918857: {"Other_Default_Ignorable_Code_Point"},
    918858: {"Other_Default_Ignorable_Code_Point"},
    918859: {"Other_Default_Ignorable_Code_Point"},
    918860: {"Other_Default_Ignorable_Code_Point"},
    918861: {"Other_Default_Ignorable_Code_Point"},
    918862: {"Other_Default_Ignorable_Code_Point"},
    918863: {"Other_Default_Ignorable_Code_Point"},
    918864: {"Other_Default_Ignorable_Code_Point"},
    918865: {"Other_Default_Ignorable_Code_Point"},
    918866: {"Other_Default_Ignorable_Code_Point"},
    918867: {"Other_Default_Ignorable_Code_Point"},
    918868: {"Other_Default_Ignorable_Code_Point"},
    918869: {"Other_Default_Ignorable_Code_Point"},
    918870: {"Other_Default_Ignorable_Code_Point"},
    918871: {"Other_Default_Ignorable_Code_Point"},
    918872: {"Other_Default_Ignorable_Code_Point"},
    918873: {"Other_Default_Ignorable_Code_Point"},
    918874: {"Other_Default_Ignorable_Code_Point"},
    918875: {"Other_Default_Ignorable_Code_Point"},
    918876: {"Other_Default_Ignorable_Code_Point"},
    918877: {"Other_Default_Ignorable_Code_Point"},
    918878: {"Other_Default_Ignorable_Code_Point"},
    918879: {"Other_Default_Ignorable_Code_Point"},
    918880: {"Other_Default_Ignorable_Code_Point"},
    918881: {"Other_Default_Ignorable_Code_Point"},
    918882: {"Other_Default_Ignorable_Code_Point"},
    918883: {"Other_Default_Ignorable_Code_Point"},
    918884: {"Other_Default_Ignorable_Code_Point"},
    918885: {"Other_Default_Ignorable_Code_Point"},
    918886: {"Other_Default_Ignorable_Code_Point"},
    918887: {"Other_Default_Ignorable_Code_Point"},
    918888: {"Other_Default_Ignorable_Code_Point"},
    918889: {"Other_Default_Ignorable_Code_Point"},
    918890: {"Other_Default_Ignorable_Code_Point"},
    918891: {"Other_Default_Ignorable_Code_Point"},
    918892: {"Other_Default_Ignorable_Code_Point"},
    918893: {"Other_Default_Ignorable_Code_Point"},
    918894: {"Other_Default_Ignorable_Code_Point"},
    918895: {"Other_Default_Ignorable_Code_Point"},
    918896: {"Other_Default_Ignorable_Code_Point"},
    918897: {"Other_Default_Ignorable_Code_Point"},
    918898: {"Other_Default_Ignorable_Code_Point"},
    918899: {"Other_Default_Ignorable_Code_Point"},
    918900: {"Other_Default_Ignorable_Code_Point"},
    918901: {"Other_Default_Ignorable_Code_Point"},
    918902: {"Other_Default_Ignorable_Code_Point"},
    918903: {"Other_Default_Ignorable_Code_Point"},
    918904: {"Other_Default_Ignorable_Code_Point"},
    918905: {"Other_Default_Ignorable_Code_Point"},
    918906: {"Other_Default_Ignorable_Code_Point"},
    918907: {"Other_Default_Ignorable_Code_Point"},
    918908: {"Other_Default_Ignorable_Code_Point"},
    918909: {"Other_Default_Ignorable_Code_Point"},
    918910: {"Other_Default_Ignorable_Code_Point"},
    918911: {"Other_Default_Ignorable_Code_Point"},
    918912: {"Other_Default_Ignorable_Code_Point"},
    918913: {"Other_Default_Ignorable_Code_Point"},
    918914: {"Other_Default_Ignorable_Code_Point"},
    918915: {"Other_Default_Ignorable_Code_Point"},
    918916: {"Other_Default_Ignorable_Code_Point"},
    918917: {"Other_Default_Ignorable_Code_Point"},
    918918: {"Other_Default_Ignorable_Code_Point"},
    918919: {"Other_Default_Ignorable_Code_Point"},
    918920: {"Other_Default_Ignorable_Code_Point"},
    918921: {"Other_Default_Ignorable_Code_Point"},
    918922: {"Other_Default_Ignorable_Code_Point"},
    918923: {"Other_Default_Ignorable_Code_Point"},
    918924: {"Other_Default_Ignorable_Code_Point"},
    918925: {"Other_Default_Ignorable_Code_Point"},
    918926: {"Other_Default_Ignorable_Code_Point"},
    918927: {"Other_Default_Ignorable_Code_Point"},
    918928: {"Other_Default_Ignorable_Code_Point"},
    918929: {"Other_Default_Ignorable_Code_Point"},
    918930: {"Other_Default_Ignorable_Code_Point"},
    918931: {"Other_Default_Ignorable_Code_Point"},
    918932: {"Other_Default_Ignorable_Code_Point"},
    918933: {"Other_Default_Ignorable_Code_Point"},
    918934: {"Other_Default_Ignorable_Code_Point"},
    918935: {"Other_Default_Ignorable_Code_Point"},
    918936: {"Other_Default_Ignorable_Code_Point"},
    918937: {"Other_Default_Ignorable_Code_Point"},
    918938: {"Other_Default_Ignorable_Code_Point"},
    918939: {"Other_Default_Ignorable_Code_Point"},
    918940: {"Other_Default_Ignorable_Code_Point"},
    918941: {"Other_Default_Ignorable_Code_Point"},
    918942: {"Other_Default_Ignorable_Code_Point"},
    918943: {"Other_Default_Ignorable_Code_Point"},
    918944: {"Other_Default_Ignorable_Code_Point"},
    918945: {"Other_Default_Ignorable_Code_Point"},
    918946: {"Other_Default_Ignorable_Code_Point"},
    918947: {"Other_Default_Ignorable_Code_Point"},
    918948: {"Other_Default_Ignorable_Code_Point"},
    918949: {"Other_Default_Ignorable_Code_Point"},
    918950: {"Other_Default_Ignorable_Code_Point"},
    918951: {"Other_Default_Ignorable_Code_Point"},
    918952: {"Other_Default_Ignorable_Code_Point"},
    918953: {"Other_Default_Ignorable_Code_Point"},
    918954: {"Other_Default_Ignorable_Code_Point"},
    918955: {"Other_Default_Ignorable_Code_Point"},
    918956: {"Other_Default_Ignorable_Code_Point"},
    918957: {"Other_Default_Ignorable_Code_Point"},
    918958: {"Other_Default_Ignorable_Code_Point"},
    918959: {"Other_Default_Ignorable_Code_Point"},
    918960: {"Other_Default_Ignorable_Code_Point"},
    918961: {"Other_Default_Ignorable_Code_Point"},
    918962: {"Other_Default_Ignorable_Code_Point"},
    918963: {"Other_Default_Ignorable_Code_Point"},
    918964: {"Other_Default_Ignorable_Code_Point"},
    918965: {"Other_Default_Ignorable_Code_Point"},
    918966: {"Other_Default_Ignorable_Code_Point"},
    918967: {"Other_Default_Ignorable_Code_Point"},
    918968: {"Other_Default_Ignorable_Code_Point"},
    918969: {"Other_Default_Ignorable_Code_Point"},
    918970: {"Other_Default_Ignorable_Code_Point"},
    918971: {"Other_Default_Ignorable_Code_Point"},
    918972: {"Other_Default_Ignorable_Code_Point"},
    918973: {"Other_Default_Ignorable_Code_Point"},
    918974: {"Other_Default_Ignorable_Code_Point"},
    918975: {"Other_Default_Ignorable_Code_Point"},
    918976: {"Other_Default_Ignorable_Code_Point"},
    918977: {"Other_Default_Ignorable_Code_Point"},
    918978: {"Other_Default_Ignorable_Code_Point"},
    918979: {"Other_Default_Ignorable_Code_Point"},
    918980: {"Other_Default_Ignorable_Code_Point"},
    918981: {"Other_Default_Ignorable_Code_Point"},
    918982: {"Other_Default_Ignorable_Code_Point"},
    918983: {"Other_Default_Ignorable_Code_Point"},
    918984: {"Other_Default_Ignorable_Code_Point"},
    918985: {"Other_Default_Ignorable_Code_Point"},
    918986: {"Other_Default_Ignorable_Code_Point"},
    918987: {"Other_Default_Ignorable_Code_Point"},
    918988: {"Other_Default_Ignorable_Code_Point"},
    918989: {"Other_Default_Ignorable_Code_Point"},
    918990: {"Other_Default_Ignorable_Code_Point"},
    918991: {"Other_Default_Ignorable_Code_Point"},
    918992: {"Other_Default_Ignorable_Code_Point"},
    918993: {"Other_Default_Ignorable_Code_Point"},
    918994: {"Other_Default_Ignorable_Code_Point"},
    918995: {"Other_Default_Ignorable_Code_Point"},
    918996: {"Other_Default_Ignorable_Code_Point"},
    918997: {"Other_Default_Ignorable_Code_Point"},
    918998: {"Other_Default_Ignorable_Code_Point"},
    918999: {"Other_Default_Ignorable_Code_Point"},
    919000: {"Other_Default_Ignorable_Code_Point"},
    919001: {"Other_Default_Ignorable_Code_Point"},
    919002: {"Other_Default_Ignorable_Code_Point"},
    919003: {"Other_Default_Ignorable_Code_Point"},
    919004: {"Other_Default_Ignorable_Code_Point"},
    919005: {"Other_Default_Ignorable_Code_Point"},
    919006: {"Other_Default_Ignorable_Code_Point"},
    919007: {"Other_Default_Ignorable_Code_Point"},
    919008: {"Other_Default_Ignorable_Code_Point"},
    919009: {"Other_Default_Ignorable_Code_Point"},
    919010: {"Other_Default_Ignorable_Code_Point"},
    919011: {"Other_Default_Ignorable_Code_Point"},
    919012: {"Other_Default_Ignorable_Code_Point"},
    919013: {"Other_Default_Ignorable_Code_Point"},
    919014: {"Other_Default_Ignorable_Code_Point"},
    919015: {"Other_Default_Ignorable_Code_Point"},
    919016: {"Other_Default_Ignorable_Code_Point"},
    919017: {"Other_Default_Ignorable_Code_Point"},
    919018: {"Other_Default_Ignorable_Code_Point"},
    919019: {"Other_Default_Ignorable_Code_Point"},
    919020: {"Other_Default_Ignorable_Code_Point"},
    919021: {"Other_Default_Ignorable_Code_Point"},
    919022: {"Other_Default_Ignorable_Code_Point"},
    919023: {"Other_Default_Ignorable_Code_Point"},
    919024: {"Other_Default_Ignorable_Code_Point"},
    919025: {"Other_Default_Ignorable_Code_Point"},
    919026: {"Other_Default_Ignorable_Code_Point"},
    919027: {"Other_Default_Ignorable_Code_Point"},
    919028: {"Other_Default_Ignorable_Code_Point"},
    919029: {"Other_Default_Ignorable_Code_Point"},
    919030: {"Other_Default_Ignorable_Code_Point"},
    919031: {"Other_Default_Ignorable_Code_Point"},
    919032: {"Other_Default_Ignorable_Code_Point"},
    919033: {"Other_Default_Ignorable_Code_Point"},
    919034: {"Other_Default_Ignorable_Code_Point"},
    919035: {"Other_Default_Ignorable_Code_Point"},
    919036: {"Other_Default_Ignorable_Code_Point"},
    919037: {"Other_Default_Ignorable_Code_Point"},
    919038: {"Other_Default_Ignorable_Code_Point"},
    919039: {"Other_Default_Ignorable_Code_Point"},
    919040: {"Other_Default_Ignorable_Code_Point"},
    919041: {"Other_Default_Ignorable_Code_Point"},
    919042: {"Other_Default_Ignorable_Code_Point"},
    919043: {"Other_Default_Ignorable_Code_Point"},
    919044: {"Other_Default_Ignorable_Code_Point"},
    919045: {"Other_Default_Ignorable_Code_Point"},
    919046: {"Other_Default_Ignorable_Code_Point"},
    919047: {"Other_Default_Ignorable_Code_Point"},
    919048: {"Other_Default_Ignorable_Code_Point"},
    919049: {"Other_Default_Ignorable_Code_Point"},
    919050: {"Other_Default_Ignorable_Code_Point"},
    919051: {"Other_Default_Ignorable_Code_Point"},
    919052: {"Other_Default_Ignorable_Code_Point"},
    919053: {"Other_Default_Ignorable_Code_Point"},
    919054: {"Other_Default_Ignorable_Code_Point"},
    919055: {"Other_Default_Ignorable_Code_Point"},
    919056: {"Other_Default_Ignorable_Code_Point"},
    919057: {"Other_Default_Ignorable_Code_Point"},
    919058: {"Other_Default_Ignorable_Code_Point"},
    919059: {"Other_Default_Ignorable_Code_Point"},
    919060: {"Other_Default_Ignorable_Code_Point"},
    919061: {"Other_Default_Ignorable_Code_Point"},
    919062: {"Other_Default_Ignorable_Code_Point"},
    919063: {"Other_Default_Ignorable_Code_Point"},
    919064: {"Other_Default_Ignorable_Code_Point"},
    919065: {"Other_Default_Ignorable_Code_Point"},
    919066: {"Other_Default_Ignorable_Code_Point"},
    919067: {"Other_Default_Ignorable_Code_Point"},
    919068: {"Other_Default_Ignorable_Code_Point"},
    919069: {"Other_Default_Ignorable_Code_Point"},
    919070: {"Other_Default_Ignorable_Code_Point"},
    919071: {"Other_Default_Ignorable_Code_Point"},
    919072: {"Other_Default_Ignorable_Code_Point"},
    919073: {"Other_Default_Ignorable_Code_Point"},
    919074: {"Other_Default_Ignorable_Code_Point"},
    919075: {"Other_Default_Ignorable_Code_Point"},
    919076: {"Other_Default_Ignorable_Code_Point"},
    919077: {"Other_Default_Ignorable_Code_Point"},
    919078: {"Other_Default_Ignorable_Code_Point"},
    919079: {"Other_Default_Ignorable_Code_Point"},
    919080: {"Other_Default_Ignorable_Code_Point"},
    919081: {"Other_Default_Ignorable_Code_Point"},
    919082: {"Other_Default_Ignorable_Code_Point"},
    919083: {"Other_Default_Ignorable_Code_Point"},
    919084: {"Other_Default_Ignorable_Code_Point"},
    919085: {"Other_Default_Ignorable_Code_Point"},
    919086: {"Other_Default_Ignorable_Code_Point"},
    919087: {"Other_Default_Ignorable_Code_Point"},
    919088: {"Other_Default_Ignorable_Code_Point"},
    919089: {"Other_Default_Ignorable_Code_Point"},
    919090: {"Other_Default_Ignorable_Code_Point"},
    919091: {"Other_Default_Ignorable_Code_Point"},
    919092: {"Other_Default_Ignorable_Code_Point"},
    919093: {"Other_Default_Ignorable_Code_Point"},
    919094: {"Other_Default_Ignorable_Code_Point"},
    919095: {"Other_Default_Ignorable_Code_Point"},
    919096: {"Other_Default_Ignorable_Code_Point"},
    919097: {"Other_Default_Ignorable_Code_Point"},
    919098: {"Other_Default_Ignorable_Code_Point"},
    919099: {"Other_Default_Ignorable_Code_Point"},
    919100: {"Other_Default_Ignorable_Code_Point"},
    919101: {"Other_Default_Ignorable_Code_Point"},
    919102: {"Other_Default_Ignorable_Code_Point"},
    919103: {"Other_Default_Ignorable_Code_Point"},
    919104: {"Other_Default_Ignorable_Code_Point"},
    919105: {"Other_Default_Ignorable_Code_Point"},
    919106: {"Other_Default_Ignorable_Code_Point"},
    919107: {"Other_Default_Ignorable_Code_Point"},
    919108: {"Other_Default_Ignorable_Code_Point"},
    919109: {"Other_Default_Ignorable_Code_Point"},
    919110: {"Other_Default_Ignorable_Code_Point"},
    919111: {"Other_Default_Ignorable_Code_Point"},
    919112: {"Other_Default_Ignorable_Code_Point"},
    919113: {"Other_Default_Ignorable_Code_Point"},
    919114: {"Other_Default_Ignorable_Code_Point"},
    919115: {"Other_Default_Ignorable_Code_Point"},
    919116: {"Other_Default_Ignorable_Code_Point"},
    919117: {"Other_Default_Ignorable_Code_Point"},
    919118: {"Other_Default_Ignorable_Code_Point"},
    919119: {"Other_Default_Ignorable_Code_Point"},
    919120: {"Other_Default_Ignorable_Code_Point"},
    919121: {"Other_Default_Ignorable_Code_Point"},
    919122: {"Other_Default_Ignorable_Code_Point"},
    919123: {"Other_Default_Ignorable_Code_Point"},
    919124: {"Other_Default_Ignorable_Code_Point"},
    919125: {"Other_Default_Ignorable_Code_Point"},
    919126: {"Other_Default_Ignorable_Code_Point"},
    919127: {"Other_Default_Ignorable_Code_Point"},
    919128: {"Other_Default_Ignorable_Code_Point"},
    919129: {"Other_Default_Ignorable_Code_Point"},
    919130: {"Other_Default_Ignorable_Code_Point"},
    919131: {"Other_Default_Ignorable_Code_Point"},
    919132: {"Other_Default_Ignorable_Code_Point"},
    919133: {"Other_Default_Ignorable_Code_Point"},
    919134: {"Other_Default_Ignorable_Code_Point"},
    919135: {"Other_Default_Ignorable_Code_Point"},
    919136: {"Other_Default_Ignorable_Code_Point"},
    919137: {"Other_Default_Ignorable_Code_Point"},
    919138: {"Other_Default_Ignorable_Code_Point"},
    919139: {"Other_Default_Ignorable_Code_Point"},
    919140: {"Other_Default_Ignorable_Code_Point"},
    919141: {"Other_Default_Ignorable_Code_Point"},
    919142: {"Other_Default_Ignorable_Code_Point"},
    919143: {"Other_Default_Ignorable_Code_Point"},
    919144: {"Other_Default_Ignorable_Code_Point"},
    919145: {"Other_Default_Ignorable_Code_Point"},
    919146: {"Other_Default_Ignorable_Code_Point"},
    919147: {"Other_Default_Ignorable_Code_Point"},
    919148: {"Other_Default_Ignorable_Code_Point"},
    919149: {"Other_Default_Ignorable_Code_Point"},
    919150: {"Other_Default_Ignorable_Code_Point"},
    919151: {"Other_Default_Ignorable_Code_Point"},
    919152: {"Other_Default_Ignorable_Code_Point"},
    919153: {"Other_Default_Ignorable_Code_Point"},
    919154: {"Other_Default_Ignorable_Code_Point"},
    919155: {"Other_Default_Ignorable_Code_Point"},
    919156: {"Other_Default_Ignorable_Code_Point"},
    919157: {"Other_Default_Ignorable_Code_Point"},
    919158: {"Other_Default_Ignorable_Code_Point"},
    919159: {"Other_Default_Ignorable_Code_Point"},
    919160: {"Other_Default_Ignorable_Code_Point"},
    919161: {"Other_Default_Ignorable_Code_Point"},
    919162: {"Other_Default_Ignorable_Code_Point"},
    919163: {"Other_Default_Ignorable_Code_Point"},
    919164: {"Other_Default_Ignorable_Code_Point"},
    919165: {"Other_Default_Ignorable_Code_Point"},
    919166: {"Other_Default_Ignorable_Code_Point"},
    919167: {"Other_Default_Ignorable_Code_Point"},
    919168: {"Other_Default_Ignorable_Code_Point"},
    919169: {"Other_Default_Ignorable_Code_Point"},
    919170: {"Other_Default_Ignorable_Code_Point"},
    919171: {"Other_Default_Ignorable_Code_Point"},
    919172: {"Other_Default_Ignorable_Code_Point"},
    919173: {"Other_Default_Ignorable_Code_Point"},
    919174: {"Other_Default_Ignorable_Code_Point"},
    919175: {"Other_Default_Ignorable_Code_Point"},
    919176: {"Other_Default_Ignorable_Code_Point"},
    919177: {"Other_Default_Ignorable_Code_Point"},
    919178: {"Other_Default_Ignorable_Code_Point"},
    919179: {"Other_Default_Ignorable_Code_Point"},
    919180: {"Other_Default_Ignorable_Code_Point"},
    919181: {"Other_Default_Ignorable_Code_Point"},
    919182: {"Other_Default_Ignorable_Code_Point"},
    919183: {"Other_Default_Ignorable_Code_Point"},
    919184: {"Other_Default_Ignorable_Code_Point"},
    919185: {"Other_Default_Ignorable_Code_Point"},
    919186: {"Other_Default_Ignorable_Code_Point"},
    919187: {"Other_Default_Ignorable_Code_Point"},
    919188: {"Other_Default_Ignorable_Code_Point"},
    919189: {"Other_Default_Ignorable_Code_Point"},
    919190: {"Other_Default_Ignorable_Code_Point"},
    919191: {"Other_Default_Ignorable_Code_Point"},
    919192: {"Other_Default_Ignorable_Code_Point"},
    919193: {"Other_Default_Ignorable_Code_Point"},
    919194: {"Other_Default_Ignorable_Code_Point"},
    919195: {"Other_Default_Ignorable_Code_Point"},
    919196: {"Other_Default_Ignorable_Code_Point"},
    919197: {"Other_Default_Ignorable_Code_Point"},
    919198: {"Other_Default_Ignorable_Code_Point"},
    919199: {"Other_Default_Ignorable_Code_Point"},
    919200: {"Other_Default_Ignorable_Code_Point"},
    919201: {"Other_Default_Ignorable_Code_Point"},
    919202: {"Other_Default_Ignorable_Code_Point"},
    919203: {"Other_Default_Ignorable_Code_Point"},
    919204: {"Other_Default_Ignorable_Code_Point"},
    919205: {"Other_Default_Ignorable_Code_Point"},
    919206: {"Other_Default_Ignorable_Code_Point"},
    919207: {"Other_Default_Ignorable_Code_Point"},
    919208: {"Other_Default_Ignorable_Code_Point"},
    919209: {"Other_Default_Ignorable_Code_Point"},
    919210: {"Other_Default_Ignorable_Code_Point"},
    919211: {"Other_Default_Ignorable_Code_Point"},
    919212: {"Other_Default_Ignorable_Code_Point"},
    919213: {"Other_Default_Ignorable_Code_Point"},
    919214: {"Other_Default_Ignorable_Code_Point"},
    919215: {"Other_Default_Ignorable_Code_Point"},
    919216: {"Other_Default_Ignorable_Code_Point"},
    919217: {"Other_Default_Ignorable_Code_Point"},
    919218: {"Other_Default_Ignorable_Code_Point"},
    919219: {"Other_Default_Ignorable_Code_Point"},
    919220: {"Other_Default_Ignorable_Code_Point"},
    919221: {"Other_Default_Ignorable_Code_Point"},
    919222: {"Other_Default_Ignorable_Code_Point"},
    919223: {"Other_Default_Ignorable_Code_Point"},
    919224: {"Other_Default_Ignorable_Code_Point"},
    919225: {"Other_Default_Ignorable_Code_Point"},
    919226: {"Other_Default_Ignorable_Code_Point"},
    919227: {"Other_Default_Ignorable_Code_Point"},
    919228: {"Other_Default_Ignorable_Code_Point"},
    919229: {"Other_Default_Ignorable_Code_Point"},
    919230: {"Other_Default_Ignorable_Code_Point"},
    919231: {"Other_Default_Ignorable_Code_Point"},
    919232: {"Other_Default_Ignorable_Code_Point"},
    919233: {"Other_Default_Ignorable_Code_Point"},
    919234: {"Other_Default_Ignorable_Code_Point"},
    919235: {"Other_Default_Ignorable_Code_Point"},
    919236: {"Other_Default_Ignorable_Code_Point"},
    919237: {"Other_Default_Ignorable_Code_Point"},
    919238: {"Other_Default_Ignorable_Code_Point"},
    919239: {"Other_Default_Ignorable_Code_Point"},
    919240: {"Other_Default_Ignorable_Code_Point"},
    919241: {"Other_Default_Ignorable_Code_Point"},
    919242: {"Other_Default_Ignorable_Code_Point"},
    919243: {"Other_Default_Ignorable_Code_Point"},
    919244: {"Other_Default_Ignorable_Code_Point"},
    919245: {"Other_Default_Ignorable_Code_Point"},
    919246: {"Other_Default_Ignorable_Code_Point"},
    919247: {"Other_Default_Ignorable_Code_Point"},
    919248: {"Other_Default_Ignorable_Code_Point"},
    919249: {"Other_Default_Ignorable_Code_Point"},
    919250: {"Other_Default_Ignorable_Code_Point"},
    919251: {"Other_Default_Ignorable_Code_Point"},
    919252: {"Other_Default_Ignorable_Code_Point"},
    919253: {"Other_Default_Ignorable_Code_Point"},
    919254: {"Other_Default_Ignorable_Code_Point"},
    919255: {"Other_Default_Ignorable_Code_Point"},
    919256: {"Other_Default_Ignorable_Code_Point"},
    919257: {"Other_Default_Ignorable_Code_Point"},
    919258: {"Other_Default_Ignorable_Code_Point"},
    919259: {"Other_Default_Ignorable_Code_Point"},
    919260: {"Other_Default_Ignorable_Code_Point"},
    919261: {"Other_Default_Ignorable_Code_Point"},
    919262: {"Other_Default_Ignorable_Code_Point"},
    919263: {"Other_Default_Ignorable_Code_Point"},
    919264: {"Other_Default_Ignorable_Code_Point"},
    919265: {"Other_Default_Ignorable_Code_Point"},
    919266: {"Other_Default_Ignorable_Code_Point"},
    919267: {"Other_Default_Ignorable_Code_Point"},
    919268: {"Other_Default_Ignorable_Code_Point"},
    919269: {"Other_Default_Ignorable_Code_Point"},
    919270: {"Other_Default_Ignorable_Code_Point"},
    919271: {"Other_Default_Ignorable_Code_Point"},
    919272: {"Other_Default_Ignorable_Code_Point"},
    919273: {"Other_Default_Ignorable_Code_Point"},
    919274: {"Other_Default_Ignorable_Code_Point"},
    919275: {"Other_Default_Ignorable_Code_Point"},
    919276: {"Other_Default_Ignorable_Code_Point"},
    919277: {"Other_Default_Ignorable_Code_Point"},
    919278: {"Other_Default_Ignorable_Code_Point"},
    919279: {"Other_Default_Ignorable_Code_Point"},
    919280: {"Other_Default_Ignorable_Code_Point"},
    919281: {"Other_Default_Ignorable_Code_Point"},
    919282: {"Other_Default_Ignorable_Code_Point"},
    919283: {"Other_Default_Ignorable_Code_Point"},
    919284: {"Other_Default_Ignorable_Code_Point"},
    919285: {"Other_Default_Ignorable_Code_Point"},
    919286: {"Other_Default_Ignorable_Code_Point"},
    919287: {"Other_Default_Ignorable_Code_Point"},
    919288: {"Other_Default_Ignorable_Code_Point"},
    919289: {"Other_Default_Ignorable_Code_Point"},
    919290: {"Other_Default_Ignorable_Code_Point"},
    919291: {"Other_Default_Ignorable_Code_Point"},
    919292: {"Other_Default_Ignorable_Code_Point"},
    919293: {"Other_Default_Ignorable_Code_Point"},
    919294: {"Other_Default_Ignorable_Code_Point"},
    919295: {"Other_Default_Ignorable_Code_Point"},
    919296: {"Other_Default_Ignorable_Code_Point"},
    919297: {"Other_Default_Ignorable_Code_Point"},
    919298: {"Other_Default_Ignorable_Code_Point"},
    919299: {"Other_Default_Ignorable_Code_Point"},
    919300: {"Other_Default_Ignorable_Code_Point"},
    919301: {"Other_Default_Ignorable_Code_Point"},
    919302: {"Other_Default_Ignorable_Code_Point"},
    919303: {"Other_Default_Ignorable_Code_Point"},
    919304: {"Other_Default_Ignorable_Code_Point"},
    919305: {"Other_Default_Ignorable_Code_Point"},
    919306: {"Other_Default_Ignorable_Code_Point"},
    919307: {"Other_Default_Ignorable_Code_Point"},
    919308: {"Other_Default_Ignorable_Code_Point"},
    919309: {"Other_Default_Ignorable_Code_Point"},
    919310: {"Other_Default_Ignorable_Code_Point"},
    919311: {"Other_Default_Ignorable_Code_Point"},
    919312: {"Other_Default_Ignorable_Code_Point"},
    919313: {"Other_Default_Ignorable_Code_Point"},
    919314: {"Other_Default_Ignorable_Code_Point"},
    919315: {"Other_Default_Ignorable_Code_Point"},
    919316: {"Other_Default_Ignorable_Code_Point"},
    919317: {"Other_Default_Ignorable_Code_Point"},
    919318: {"Other_Default_Ignorable_Code_Point"},
    919319: {"Other_Default_Ignorable_Code_Point"},
    919320: {"Other_Default_Ignorable_Code_Point"},
    919321: {"Other_Default_Ignorable_Code_Point"},
    919322: {"Other_Default_Ignorable_Code_Point"},
    919323: {"Other_Default_Ignorable_Code_Point"},
    919324: {"Other_Default_Ignorable_Code_Point"},
    919325: {"Other_Default_Ignorable_Code_Point"},
    919326: {"Other_Default_Ignorable_Code_Point"},
    919327: {"Other_Default_Ignorable_Code_Point"},
    919328: {"Other_Default_Ignorable_Code_Point"},
    919329: {"Other_Default_Ignorable_Code_Point"},
    919330: {"Other_Default_Ignorable_Code_Point"},
    919331: {"Other_Default_Ignorable_Code_Point"},
    919332: {"Other_Default_Ignorable_Code_Point"},
    919333: {"Other_Default_Ignorable_Code_Point"},
    919334: {"Other_Default_Ignorable_Code_Point"},
    919335: {"Other_Default_Ignorable_Code_Point"},
    919336: {"Other_Default_Ignorable_Code_Point"},
    919337: {"Other_Default_Ignorable_Code_Point"},
    919338: {"Other_Default_Ignorable_Code_Point"},
    919339: {"Other_Default_Ignorable_Code_Point"},
    919340: {"Other_Default_Ignorable_Code_Point"},
    919341: {"Other_Default_Ignorable_Code_Point"},
    919342: {"Other_Default_Ignorable_Code_Point"},
    919343: {"Other_Default_Ignorable_Code_Point"},
    919344: {"Other_Default_Ignorable_Code_Point"},
    919345: {"Other_Default_Ignorable_Code_Point"},
    919346: {"Other_Default_Ignorable_Code_Point"},
    919347: {"Other_Default_Ignorable_Code_Point"},
    919348: {"Other_Default_Ignorable_Code_Point"},
    919349: {"Other_Default_Ignorable_Code_Point"},
    919350: {"Other_Default_Ignorable_Code_Point"},
    919351: {"Other_Default_Ignorable_Code_Point"},
    919352: {"Other_Default_Ignorable_Code_Point"},
    919353: {"Other_Default_Ignorable_Code_Point"},
    919354: {"Other_Default_Ignorable_Code_Point"},
    919355: {"Other_Default_Ignorable_Code_Point"},
    919356: {"Other_Default_Ignorable_Code_Point"},
    919357: {"Other_Default_Ignorable_Code_Point"},
    919358: {"Other_Default_Ignorable_Code_Point"},
    919359: {"Other_Default_Ignorable_Code_Point"},
    919360: {"Other_Default_Ignorable_Code_Point"},
    919361: {"Other_Default_Ignorable_Code_Point"},
    919362: {"Other_Default_Ignorable_Code_Point"},
    919363: {"Other_Default_Ignorable_Code_Point"},
    919364: {"Other_Default_Ignorable_Code_Point"},
    919365: {"Other_Default_Ignorable_Code_Point"},
    919366: {"Other_Default_Ignorable_Code_Point"},
    919367: {"Other_Default_Ignorable_Code_Point"},
    919368: {"Other_Default_Ignorable_Code_Point"},
    919369: {"Other_Default_Ignorable_Code_Point"},
    919370: {"Other_Default_Ignorable_Code_Point"},
    919371: {"Other_Default_Ignorable_Code_Point"},
    919372: {"Other_Default_Ignorable_Code_Point"},
    919373: {"Other_Default_Ignorable_Code_Point"},
    919374: {"Other_Default_Ignorable_Code_Point"},
    919375: {"Other_Default_Ignorable_Code_Point"},
    919376: {"Other_Default_Ignorable_Code_Point"},
    919377: {"Other_Default_Ignorable_Code_Point"},
    919378: {"Other_Default_Ignorable_Code_Point"},
    919379: {"Other_Default_Ignorable_Code_Point"},
    919380: {"Other_Default_Ignorable_Code_Point"},
    919381: {"Other_Default_Ignorable_Code_Point"},
    919382: {"Other_Default_Ignorable_Code_Point"},
    919383: {"Other_Default_Ignorable_Code_Point"},
    919384: {"Other_Default_Ignorable_Code_Point"},
    919385: {"Other_Default_Ignorable_Code_Point"},
    919386: {"Other_Default_Ignorable_Code_Point"},
    919387: {"Other_Default_Ignorable_Code_Point"},
    919388: {"Other_Default_Ignorable_Code_Point"},
    919389: {"Other_Default_Ignorable_Code_Point"},
    919390: {"Other_Default_Ignorable_Code_Point"},
    919391: {"Other_Default_Ignorable_Code_Point"},
    919392: {"Other_Default_Ignorable_Code_Point"},
    919393: {"Other_Default_Ignorable_Code_Point"},
    919394: {"Other_Default_Ignorable_Code_Point"},
    919395: {"Other_Default_Ignorable_Code_Point"},
    919396: {"Other_Default_Ignorable_Code_Point"},
    919397: {"Other_Default_Ignorable_Code_Point"},
    919398: {"Other_Default_Ignorable_Code_Point"},
    919399: {"Other_Default_Ignorable_Code_Point"},
    919400: {"Other_Default_Ignorable_Code_Point"},
    919401: {"Other_Default_Ignorable_Code_Point"},
    919402: {"Other_Default_Ignorable_Code_Point"},
    919403: {"Other_Default_Ignorable_Code_Point"},
    919404: {"Other_Default_Ignorable_Code_Point"},
    919405: {"Other_Default_Ignorable_Code_Point"},
    919406: {"Other_Default_Ignorable_Code_Point"},
    919407: {"Other_Default_Ignorable_Code_Point"},
    919408: {"Other_Default_Ignorable_Code_Point"},
    919409: {"Other_Default_Ignorable_Code_Point"},
    919410: {"Other_Default_Ignorable_Code_Point"},
    919411: {"Other_Default_Ignorable_Code_Point"},
    919412: {"Other_Default_Ignorable_Code_Point"},
    919413: {"Other_Default_Ignorable_Code_Point"},
    919414: {"Other_Default_Ignorable_Code_Point"},
    919415: {"Other_Default_Ignorable_Code_Point"},
    919416: {"Other_Default_Ignorable_Code_Point"},
    919417: {"Other_Default_Ignorable_Code_Point"},
    919418: {"Other_Default_Ignorable_Code_Point"},
    919419: {"Other_Default_Ignorable_Code_Point"},
    919420: {"Other_Default_Ignorable_Code_Point"},
    919421: {"Other_Default_Ignorable_Code_Point"},
    919422: {"Other_Default_Ignorable_Code_Point"},
    919423: {"Other_Default_Ignorable_Code_Point"},
    919424: {"Other_Default_Ignorable_Code_Point"},
    919425: {"Other_Default_Ignorable_Code_Point"},
    919426: {"Other_Default_Ignorable_Code_Point"},
    919427: {"Other_Default_Ignorable_Code_Point"},
    919428: {"Other_Default_Ignorable_Code_Point"},
    919429: {"Other_Default_Ignorable_Code_Point"},
    919430: {"Other_Default_Ignorable_Code_Point"},
    919431: {"Other_Default_Ignorable_Code_Point"},
    919432: {"Other_Default_Ignorable_Code_Point"},
    919433: {"Other_Default_Ignorable_Code_Point"},
    919434: {"Other_Default_Ignorable_Code_Point"},
    919435: {"Other_Default_Ignorable_Code_Point"},
    919436: {"Other_Default_Ignorable_Code_Point"},
    919437: {"Other_Default_Ignorable_Code_Point"},
    919438: {"Other_Default_Ignorable_Code_Point"},
    919439: {"Other_Default_Ignorable_Code_Point"},
    919440: {"Other_Default_Ignorable_Code_Point"},
    919441: {"Other_Default_Ignorable_Code_Point"},
    919442: {"Other_Default_Ignorable_Code_Point"},
    919443: {"Other_Default_Ignorable_Code_Point"},
    919444: {"Other_Default_Ignorable_Code_Point"},
    919445: {"Other_Default_Ignorable_Code_Point"},
    919446: {"Other_Default_Ignorable_Code_Point"},
    919447: {"Other_Default_Ignorable_Code_Point"},
    919448: {"Other_Default_Ignorable_Code_Point"},
    919449: {"Other_Default_Ignorable_Code_Point"},
    919450: {"Other_Default_Ignorable_Code_Point"},
    919451: {"Other_Default_Ignorable_Code_Point"},
    919452: {"Other_Default_Ignorable_Code_Point"},
    919453: {"Other_Default_Ignorable_Code_Point"},
    919454: {"Other_Default_Ignorable_Code_Point"},
    919455: {"Other_Default_Ignorable_Code_Point"},
    919456: {"Other_Default_Ignorable_Code_Point"},
    919457: {"Other_Default_Ignorable_Code_Point"},
    919458: {"Other_Default_Ignorable_Code_Point"},
    919459: {"Other_Default_Ignorable_Code_Point"},
    919460: {"Other_Default_Ignorable_Code_Point"},
    919461: {"Other_Default_Ignorable_Code_Point"},
    919462: {"Other_Default_Ignorable_Code_Point"},
    919463: {"Other_Default_Ignorable_Code_Point"},
    919464: {"Other_Default_Ignorable_Code_Point"},
    919465: {"Other_Default_Ignorable_Code_Point"},
    919466: {"Other_Default_Ignorable_Code_Point"},
    919467: {"Other_Default_Ignorable_Code_Point"},
    919468: {"Other_Default_Ignorable_Code_Point"},
    919469: {"Other_Default_Ignorable_Code_Point"},
    919470: {"Other_Default_Ignorable_Code_Point"},
    919471: {"Other_Default_Ignorable_Code_Point"},
    919472: {"Other_Default_Ignorable_Code_Point"},
    919473: {"Other_Default_Ignorable_Code_Point"},
    919474: {"Other_Default_Ignorable_Code_Point"},
    919475: {"Other_Default_Ignorable_Code_Point"},
    919476: {"Other_Default_Ignorable_Code_Point"},
    919477: {"Other_Default_Ignorable_Code_Point"},
    919478: {"Other_Default_Ignorable_Code_Point"},
    919479: {"Other_Default_Ignorable_Code_Point"},
    919480: {"Other_Default_Ignorable_Code_Point"},
    919481: {"Other_Default_Ignorable_Code_Point"},
    919482: {"Other_Default_Ignorable_Code_Point"},
    919483: {"Other_Default_Ignorable_Code_Point"},
    919484: {"Other_Default_Ignorable_Code_Point"},
    919485: {"Other_Default_Ignorable_Code_Point"},
    919486: {"Other_Default_Ignorable_Code_Point"},
    919487: {"Other_Default_Ignorable_Code_Point"},
    919488: {"Other_Default_Ignorable_Code_Point"},
    919489: {"Other_Default_Ignorable_Code_Point"},
    919490: {"Other_Default_Ignorable_Code_Point"},
    919491: {"Other_Default_Ignorable_Code_Point"},
    919492: {"Other_Default_Ignorable_Code_Point"},
    919493: {"Other_Default_Ignorable_Code_Point"},
    919494: {"Other_Default_Ignorable_Code_Point"},
    919495: {"Other_Default_Ignorable_Code_Point"},
    919496: {"Other_Default_Ignorable_Code_Point"},
    919497: {"Other_Default_Ignorable_Code_Point"},
    919498: {"Other_Default_Ignorable_Code_Point"},
    919499: {"Other_Default_Ignorable_Code_Point"},
    919500: {"Other_Default_Ignorable_Code_Point"},
    919501: {"Other_Default_Ignorable_Code_Point"},
    919502: {"Other_Default_Ignorable_Code_Point"},
    919503: {"Other_Default_Ignorable_Code_Point"},
    919504: {"Other_Default_Ignorable_Code_Point"},
    919505: {"Other_Default_Ignorable_Code_Point"},
    919506: {"Other_Default_Ignorable_Code_Point"},
    919507: {"Other_Default_Ignorable_Code_Point"},
    919508: {"Other_Default_Ignorable_Code_Point"},
    919509: {"Other_Default_Ignorable_Code_Point"},
    919510: {"Other_Default_Ignorable_Code_Point"},
    919511: {"Other_Default_Ignorable_Code_Point"},
    919512: {"Other_Default_Ignorable_Code_Point"},
    919513: {"Other_Default_Ignorable_Code_Point"},
    919514: {"Other_Default_Ignorable_Code_Point"},
    919515: {"Other_Default_Ignorable_Code_Point"},
    919516: {"Other_Default_Ignorable_Code_Point"},
    919517: {"Other_Default_Ignorable_Code_Point"},
    919518: {"Other_Default_Ignorable_Code_Point"},
    919519: {"Other_Default_Ignorable_Code_Point"},
    919520: {"Other_Default_Ignorable_Code_Point"},
    919521: {"Other_Default_Ignorable_Code_Point"},
    919522: {"Other_Default_Ignorable_Code_Point"},
    919523: {"Other_Default_Ignorable_Code_Point"},
    919524: {"Other_Default_Ignorable_Code_Point"},
    919525: {"Other_Default_Ignorable_Code_Point"},
    919526: {"Other_Default_Ignorable_Code_Point"},
    919527: {"Other_Default_Ignorable_Code_Point"},
    919528: {"Other_Default_Ignorable_Code_Point"},
    919529: {"Other_Default_Ignorable_Code_Point"},
    919530: {"Other_Default_Ignorable_Code_Point"},
    919531: {"Other_Default_Ignorable_Code_Point"},
    919532: {"Other_Default_Ignorable_Code_Point"},
    919533: {"Other_Default_Ignorable_Code_Point"},
    919534: {"Other_Default_Ignorable_Code_Point"},
    919535: {"Other_Default_Ignorable_Code_Point"},
    919536: {"Other_Default_Ignorable_Code_Point"},
    919537: {"Other_Default_Ignorable_Code_Point"},
    919538: {"Other_Default_Ignorable_Code_Point"},
    919539: {"Other_Default_Ignorable_Code_Point"},
    919540: {"Other_Default_Ignorable_Code_Point"},
    919541: {"Other_Default_Ignorable_Code_Point"},
    919542: {"Other_Default_Ignorable_Code_Point"},
    919543: {"Other_Default_Ignorable_Code_Point"},
    919544: {"Other_Default_Ignorable_Code_Point"},
    919545: {"Other_Default_Ignorable_Code_Point"},
    919546: {"Other_Default_Ignorable_Code_Point"},
    919547: {"Other_Default_Ignorable_Code_Point"},
    919548: {"Other_Default_Ignorable_Code_Point"},
    919549: {"Other_Default_Ignorable_Code_Point"},
    919550: {"Other_Default_Ignorable_Code_Point"},
    919551: {"Other_Default_Ignorable_Code_Point"},
    919552: {"Other_Default_Ignorable_Code_Point"},
    919553: {"Other_Default_Ignorable_Code_Point"},
    919554: {"Other_Default_Ignorable_Code_Point"},
    919555: {"Other_Default_Ignorable_Code_Point"},
    919556: {"Other_Default_Ignorable_Code_Point"},
    919557: {"Other_Default_Ignorable_Code_Point"},
    919558: {"Other_Default_Ignorable_Code_Point"},
    919559: {"Other_Default_Ignorable_Code_Point"},
    919560: {"Other_Default_Ignorable_Code_Point"},
    919561: {"Other_Default_Ignorable_Code_Point"},
    919562: {"Other_Default_Ignorable_Code_Point"},
    919563: {"Other_Default_Ignorable_Code_Point"},
    919564: {"Other_Default_Ignorable_Code_Point"},
    919565: {"Other_Default_Ignorable_Code_Point"},
    919566: {"Other_Default_Ignorable_Code_Point"},
    919567: {"Other_Default_Ignorable_Code_Point"},
    919568: {"Other_Default_Ignorable_Code_Point"},
    919569: {"Other_Default_Ignorable_Code_Point"},
    919570: {"Other_Default_Ignorable_Code_Point"},
    919571: {"Other_Default_Ignorable_Code_Point"},
    919572: {"Other_Default_Ignorable_Code_Point"},
    919573: {"Other_Default_Ignorable_Code_Point"},
    919574: {"Other_Default_Ignorable_Code_Point"},
    919575: {"Other_Default_Ignorable_Code_Point"},
    919576: {"Other_Default_Ignorable_Code_Point"},
    919577: {"Other_Default_Ignorable_Code_Point"},
    919578: {"Other_Default_Ignorable_Code_Point"},
    919579: {"Other_Default_Ignorable_Code_Point"},
    919580: {"Other_Default_Ignorable_Code_Point"},
    919581: {"Other_Default_Ignorable_Code_Point"},
    919582: {"Other_Default_Ignorable_Code_Point"},
    919583: {"Other_Default_Ignorable_Code_Point"},
    919584: {"Other_Default_Ignorable_Code_Point"},
    919585: {"Other_Default_Ignorable_Code_Point"},
    919586: {"Other_Default_Ignorable_Code_Point"},
    919587: {"Other_Default_Ignorable_Code_Point"},
    919588: {"Other_Default_Ignorable_Code_Point"},
    919589: {"Other_Default_Ignorable_Code_Point"},
    919590: {"Other_Default_Ignorable_Code_Point"},
    919591: {"Other_Default_Ignorable_Code_Point"},
    919592: {"Other_Default_Ignorable_Code_Point"},
    919593: {"Other_Default_Ignorable_Code_Point"},
    919594: {"Other_Default_Ignorable_Code_Point"},
    919595: {"Other_Default_Ignorable_Code_Point"},
    919596: {"Other_Default_Ignorable_Code_Point"},
    919597: {"Other_Default_Ignorable_Code_Point"},
    919598: {"Other_Default_Ignorable_Code_Point"},
    919599: {"Other_Default_Ignorable_Code_Point"},
    919600: {"Other_Default_Ignorable_Code_Point"},
    919601: {"Other_Default_Ignorable_Code_Point"},
    919602: {"Other_Default_Ignorable_Code_Point"},
    919603: {"Other_Default_Ignorable_Code_Point"},
    919604: {"Other_Default_Ignorable_Code_Point"},
    919605: {"Other_Default_Ignorable_Code_Point"},
    919606: {"Other_Default_Ignorable_Code_Point"},
    919607: {"Other_Default_Ignorable_Code_Point"},
    919608: {"Other_Default_Ignorable_Code_Point"},
    919609: {"Other_Default_Ignorable_Code_Point"},
    919610: {"Other_Default_Ignorable_Code_Point"},
    919611: {"Other_Default_Ignorable_Code_Point"},
    919612: {"Other_Default_Ignorable_Code_Point"},
    919613: {"Other_Default_Ignorable_Code_Point"},
    919614: {"Other_Default_Ignorable_Code_Point"},
    919615: {"Other_Default_Ignorable_Code_Point"},
    919616: {"Other_Default_Ignorable_Code_Point"},
    919617: {"Other_Default_Ignorable_Code_Point"},
    919618: {"Other_Default_Ignorable_Code_Point"},
    919619: {"Other_Default_Ignorable_Code_Point"},
    919620: {"Other_Default_Ignorable_Code_Point"},
    919621: {"Other_Default_Ignorable_Code_Point"},
    919622: {"Other_Default_Ignorable_Code_Point"},
    919623: {"Other_Default_Ignorable_Code_Point"},
    919624: {"Other_Default_Ignorable_Code_Point"},
    919625: {"Other_Default_Ignorable_Code_Point"},
    919626: {"Other_Default_Ignorable_Code_Point"},
    919627: {"Other_Default_Ignorable_Code_Point"},
    919628: {"Other_Default_Ignorable_Code_Point"},
    919629: {"Other_Default_Ignorable_Code_Point"},
    919630: {"Other_Default_Ignorable_Code_Point"},
    919631: {"Other_Default_Ignorable_Code_Point"},
    919632: {"Other_Default_Ignorable_Code_Point"},
    919633: {"Other_Default_Ignorable_Code_Point"},
    919634: {"Other_Default_Ignorable_Code_Point"},
    919635: {"Other_Default_Ignorable_Code_Point"},
    919636: {"Other_Default_Ignorable_Code_Point"},
    919637: {"Other_Default_Ignorable_Code_Point"},
    919638: {"Other_Default_Ignorable_Code_Point"},
    919639: {"Other_Default_Ignorable_Code_Point"},
    919640: {"Other_Default_Ignorable_Code_Point"},
    919641: {"Other_Default_Ignorable_Code_Point"},
    919642: {"Other_Default_Ignorable_Code_Point"},
    919643: {"Other_Default_Ignorable_Code_Point"},
    919644: {"Other_Default_Ignorable_Code_Point"},
    919645: {"Other_Default_Ignorable_Code_Point"},
    919646: {"Other_Default_Ignorable_Code_Point"},
    919647: {"Other_Default_Ignorable_Code_Point"},
    919648: {"Other_Default_Ignorable_Code_Point"},
    919649: {"Other_Default_Ignorable_Code_Point"},
    919650: {"Other_Default_Ignorable_Code_Point"},
    919651: {"Other_Default_Ignorable_Code_Point"},
    919652: {"Other_Default_Ignorable_Code_Point"},
    919653: {"Other_Default_Ignorable_Code_Point"},
    919654: {"Other_Default_Ignorable_Code_Point"},
    919655: {"Other_Default_Ignorable_Code_Point"},
    919656: {"Other_Default_Ignorable_Code_Point"},
    919657: {"Other_Default_Ignorable_Code_Point"},
    919658: {"Other_Default_Ignorable_Code_Point"},
    919659: {"Other_Default_Ignorable_Code_Point"},
    919660: {"Other_Default_Ignorable_Code_Point"},
    919661: {"Other_Default_Ignorable_Code_Point"},
    919662: {"Other_Default_Ignorable_Code_Point"},
    919663: {"Other_Default_Ignorable_Code_Point"},
    919664: {"Other_Default_Ignorable_Code_Point"},
    919665: {"Other_Default_Ignorable_Code_Point"},
    919666: {"Other_Default_Ignorable_Code_Point"},
    919667: {"Other_Default_Ignorable_Code_Point"},
    919668: {"Other_Default_Ignorable_Code_Point"},
    919669: {"Other_Default_Ignorable_Code_Point"},
    919670: {"Other_Default_Ignorable_Code_Point"},
    919671: {"Other_Default_Ignorable_Code_Point"},
    919672: {"Other_Default_Ignorable_Code_Point"},
    919673: {"Other_Default_Ignorable_Code_Point"},
    919674: {"Other_Default_Ignorable_Code_Point"},
    919675: {"Other_Default_Ignorable_Code_Point"},
    919676: {"Other_Default_Ignorable_Code_Point"},
    919677: {"Other_Default_Ignorable_Code_Point"},
    919678: {"Other_Default_Ignorable_Code_Point"},
    919679: {"Other_Default_Ignorable_Code_Point"},
    919680: {"Other_Default_Ignorable_Code_Point"},
    919681: {"Other_Default_Ignorable_Code_Point"},
    919682: {"Other_Default_Ignorable_Code_Point"},
    919683: {"Other_Default_Ignorable_Code_Point"},
    919684: {"Other_Default_Ignorable_Code_Point"},
    919685: {"Other_Default_Ignorable_Code_Point"},
    919686: {"Other_Default_Ignorable_Code_Point"},
    919687: {"Other_Default_Ignorable_Code_Point"},
    919688: {"Other_Default_Ignorable_Code_Point"},
    919689: {"Other_Default_Ignorable_Code_Point"},
    919690: {"Other_Default_Ignorable_Code_Point"},
    919691: {"Other_Default_Ignorable_Code_Point"},
    919692: {"Other_Default_Ignorable_Code_Point"},
    919693: {"Other_Default_Ignorable_Code_Point"},
    919694: {"Other_Default_Ignorable_Code_Point"},
    919695: {"Other_Default_Ignorable_Code_Point"},
    919696: {"Other_Default_Ignorable_Code_Point"},
    919697: {"Other_Default_Ignorable_Code_Point"},
    919698: {"Other_Default_Ignorable_Code_Point"},
    919699: {"Other_Default_Ignorable_Code_Point"},
    919700: {"Other_Default_Ignorable_Code_Point"},
    919701: {"Other_Default_Ignorable_Code_Point"},
    919702: {"Other_Default_Ignorable_Code_Point"},
    919703: {"Other_Default_Ignorable_Code_Point"},
    919704: {"Other_Default_Ignorable_Code_Point"},
    919705: {"Other_Default_Ignorable_Code_Point"},
    919706: {"Other_Default_Ignorable_Code_Point"},
    919707: {"Other_Default_Ignorable_Code_Point"},
    919708: {"Other_Default_Ignorable_Code_Point"},
    919709: {"Other_Default_Ignorable_Code_Point"},
    919710: {"Other_Default_Ignorable_Code_Point"},
    919711: {"Other_Default_Ignorable_Code_Point"},
    919712: {"Other_Default_Ignorable_Code_Point"},
    919713: {"Other_Default_Ignorable_Code_Point"},
    919714: {"Other_Default_Ignorable_Code_Point"},
    919715: {"Other_Default_Ignorable_Code_Point"},
    919716: {"Other_Default_Ignorable_Code_Point"},
    919717: {"Other_Default_Ignorable_Code_Point"},
    919718: {"Other_Default_Ignorable_Code_Point"},
    919719: {"Other_Default_Ignorable_Code_Point"},
    919720: {"Other_Default_Ignorable_Code_Point"},
    919721: {"Other_Default_Ignorable_Code_Point"},
    919722: {"Other_Default_Ignorable_Code_Point"},
    919723: {"Other_Default_Ignorable_Code_Point"},
    919724: {"Other_Default_Ignorable_Code_Point"},
    919725: {"Other_Default_Ignorable_Code_Point"},
    919726: {"Other_Default_Ignorable_Code_Point"},
    919727: {"Other_Default_Ignorable_Code_Point"},
    919728: {"Other_Default_Ignorable_Code_Point"},
    919729: {"Other_Default_Ignorable_Code_Point"},
    919730: {"Other_Default_Ignorable_Code_Point"},
    919731: {"Other_Default_Ignorable_Code_Point"},
    919732: {"Other_Default_Ignorable_Code_Point"},
    919733: {"Other_Default_Ignorable_Code_Point"},
    919734: {"Other_Default_Ignorable_Code_Point"},
    919735: {"Other_Default_Ignorable_Code_Point"},
    919736: {"Other_Default_Ignorable_Code_Point"},
    919737: {"Other_Default_Ignorable_Code_Point"},
    919738: {"Other_Default_Ignorable_Code_Point"},
    919739: {"Other_Default_Ignorable_Code_Point"},
    919740: {"Other_Default_Ignorable_Code_Point"},
    919741: {"Other_Default_Ignorable_Code_Point"},
    919742: {"Other_Default_Ignorable_Code_Point"},
    919743: {"Other_Default_Ignorable_Code_Point"},
    919744: {"Other_Default_Ignorable_Code_Point"},
    919745: {"Other_Default_Ignorable_Code_Point"},
    919746: {"Other_Default_Ignorable_Code_Point"},
    919747: {"Other_Default_Ignorable_Code_Point"},
    919748: {"Other_Default_Ignorable_Code_Point"},
    919749: {"Other_Default_Ignorable_Code_Point"},
    919750: {"Other_Default_Ignorable_Code_Point"},
    919751: {"Other_Default_Ignorable_Code_Point"},
    919752: {"Other_Default_Ignorable_Code_Point"},
    919753: {"Other_Default_Ignorable_Code_Point"},
    919754: {"Other_Default_Ignorable_Code_Point"},
    919755: {"Other_Default_Ignorable_Code_Point"},
    919756: {"Other_Default_Ignorable_Code_Point"},
    919757: {"Other_Default_Ignorable_Code_Point"},
    919758: {"Other_Default_Ignorable_Code_Point"},
    919759: {"Other_Default_Ignorable_Code_Point"},
    919760: {"Other_Default_Ignorable_Code_Point"},
    919761: {"Other_Default_Ignorable_Code_Point"},
    919762: {"Other_Default_Ignorable_Code_Point"},
    919763: {"Other_Default_Ignorable_Code_Point"},
    919764: {"Other_Default_Ignorable_Code_Point"},
    919765: {"Other_Default_Ignorable_Code_Point"},
    919766: {"Other_Default_Ignorable_Code_Point"},
    919767: {"Other_Default_Ignorable_Code_Point"},
    919768: {"Other_Default_Ignorable_Code_Point"},
    919769: {"Other_Default_Ignorable_Code_Point"},
    919770: {"Other_Default_Ignorable_Code_Point"},
    919771: {"Other_Default_Ignorable_Code_Point"},
    919772: {"Other_Default_Ignorable_Code_Point"},
    919773: {"Other_Default_Ignorable_Code_Point"},
    919774: {"Other_Default_Ignorable_Code_Point"},
    919775: {"Other_Default_Ignorable_Code_Point"},
    919776: {"Other_Default_Ignorable_Code_Point"},
    919777: {"Other_Default_Ignorable_Code_Point"},
    919778: {"Other_Default_Ignorable_Code_Point"},
    919779: {"Other_Default_Ignorable_Code_Point"},
    919780: {"Other_Default_Ignorable_Code_Point"},
    919781: {"Other_Default_Ignorable_Code_Point"},
    919782: {"Other_Default_Ignorable_Code_Point"},
    919783: {"Other_Default_Ignorable_Code_Point"},
    919784: {"Other_Default_Ignorable_Code_Point"},
    919785: {"Other_Default_Ignorable_Code_Point"},
    919786: {"Other_Default_Ignorable_Code_Point"},
    919787: {"Other_Default_Ignorable_Code_Point"},
    919788: {"Other_Default_Ignorable_Code_Point"},
    919789: {"Other_Default_Ignorable_Code_Point"},
    919790: {"Other_Default_Ignorable_Code_Point"},
    919791: {"Other_Default_Ignorable_Code_Point"},
    919792: {"Other_Default_Ignorable_Code_Point"},
    919793: {"Other_Default_Ignorable_Code_Point"},
    919794: {"Other_Default_Ignorable_Code_Point"},
    919795: {"Other_Default_Ignorable_Code_Point"},
    919796: {"Other_Default_Ignorable_Code_Point"},
    919797: {"Other_Default_Ignorable_Code_Point"},
    919798: {"Other_Default_Ignorable_Code_Point"},
    919799: {"Other_Default_Ignorable_Code_Point"},
    919800: {"Other_Default_Ignorable_Code_Point"},
    919801: {"Other_Default_Ignorable_Code_Point"},
    919802: {"Other_Default_Ignorable_Code_Point"},
    919803: {"Other_Default_Ignorable_Code_Point"},
    919804: {"Other_Default_Ignorable_Code_Point"},
    919805: {"Other_Default_Ignorable_Code_Point"},
    919806: {"Other_Default_Ignorable_Code_Point"},
    919807: {"Other_Default_Ignorable_Code_Point"},
    919808: {"Other_Default_Ignorable_Code_Point"},
    919809: {"Other_Default_Ignorable_Code_Point"},
    919810: {"Other_Default_Ignorable_Code_Point"},
    919811: {"Other_Default_Ignorable_Code_Point"},
    919812: {"Other_Default_Ignorable_Code_Point"},
    919813: {"Other_Default_Ignorable_Code_Point"},
    919814: {"Other_Default_Ignorable_Code_Point"},
    919815: {"Other_Default_Ignorable_Code_Point"},
    919816: {"Other_Default_Ignorable_Code_Point"},
    919817: {"Other_Default_Ignorable_Code_Point"},
    919818: {"Other_Default_Ignorable_Code_Point"},
    919819: {"Other_Default_Ignorable_Code_Point"},
    919820: {"Other_Default_Ignorable_Code_Point"},
    919821: {"Other_Default_Ignorable_Code_Point"},
    919822: {"Other_Default_Ignorable_Code_Point"},
    919823: {"Other_Default_Ignorable_Code_Point"},
    919824: {"Other_Default_Ignorable_Code_Point"},
    919825: {"Other_Default_Ignorable_Code_Point"},
    919826: {"Other_Default_Ignorable_Code_Point"},
    919827: {"Other_Default_Ignorable_Code_Point"},
    919828: {"Other_Default_Ignorable_Code_Point"},
    919829: {"Other_Default_Ignorable_Code_Point"},
    919830: {"Other_Default_Ignorable_Code_Point"},
    919831: {"Other_Default_Ignorable_Code_Point"},
    919832: {"Other_Default_Ignorable_Code_Point"},
    919833: {"Other_Default_Ignorable_Code_Point"},
    919834: {"Other_Default_Ignorable_Code_Point"},
    919835: {"Other_Default_Ignorable_Code_Point"},
    919836: {"Other_Default_Ignorable_Code_Point"},
    919837: {"Other_Default_Ignorable_Code_Point"},
    919838: {"Other_Default_Ignorable_Code_Point"},
    919839: {"Other_Default_Ignorable_Code_Point"},
    919840: {"Other_Default_Ignorable_Code_Point"},
    919841: {"Other_Default_Ignorable_Code_Point"},
    919842: {"Other_Default_Ignorable_Code_Point"},
    919843: {"Other_Default_Ignorable_Code_Point"},
    919844: {"Other_Default_Ignorable_Code_Point"},
    919845: {"Other_Default_Ignorable_Code_Point"},
    919846: {"Other_Default_Ignorable_Code_Point"},
    919847: {"Other_Default_Ignorable_Code_Point"},
    919848: {"Other_Default_Ignorable_Code_Point"},
    919849: {"Other_Default_Ignorable_Code_Point"},
    919850: {"Other_Default_Ignorable_Code_Point"},
    919851: {"Other_Default_Ignorable_Code_Point"},
    919852: {"Other_Default_Ignorable_Code_Point"},
    919853: {"Other_Default_Ignorable_Code_Point"},
    919854: {"Other_Default_Ignorable_Code_Point"},
    919855: {"Other_Default_Ignorable_Code_Point"},
    919856: {"Other_Default_Ignorable_Code_Point"},
    919857: {"Other_Default_Ignorable_Code_Point"},
    919858: {"Other_Default_Ignorable_Code_Point"},
    919859: {"Other_Default_Ignorable_Code_Point"},
    919860: {"Other_Default_Ignorable_Code_Point"},
    919861: {"Other_Default_Ignorable_Code_Point"},
    919862: {"Other_Default_Ignorable_Code_Point"},
    919863: {"Other_Default_Ignorable_Code_Point"},
    919864: {"Other_Default_Ignorable_Code_Point"},
    919865: {"Other_Default_Ignorable_Code_Point"},
    919866: {"Other_Default_Ignorable_Code_Point"},
    919867: {"Other_Default_Ignorable_Code_Point"},
    919868: {"Other_Default_Ignorable_Code_Point"},
    919869: {"Other_Default_Ignorable_Code_Point"},
    919870: {"Other_Default_Ignorable_Code_Point"},
    919871: {"Other_Default_Ignorable_Code_Point"},
    919872: {"Other_Default_Ignorable_Code_Point"},
    919873: {"Other_Default_Ignorable_Code_Point"},
    919874: {"Other_Default_Ignorable_Code_Point"},
    919875: {"Other_Default_Ignorable_Code_Point"},
    919876: {"Other_Default_Ignorable_Code_Point"},
    919877: {"Other_Default_Ignorable_Code_Point"},
    919878: {"Other_Default_Ignorable_Code_Point"},
    919879: {"Other_Default_Ignorable_Code_Point"},
    919880: {"Other_Default_Ignorable_Code_Point"},
    919881: {"Other_Default_Ignorable_Code_Point"},
    919882: {"Other_Default_Ignorable_Code_Point"},
    919883: {"Other_Default_Ignorable_Code_Point"},
    919884: {"Other_Default_Ignorable_Code_Point"},
    919885: {"Other_Default_Ignorable_Code_Point"},
    919886: {"Other_Default_Ignorable_Code_Point"},
    919887: {"Other_Default_Ignorable_Code_Point"},
    919888: {"Other_Default_Ignorable_Code_Point"},
    919889: {"Other_Default_Ignorable_Code_Point"},
    919890: {"Other_Default_Ignorable_Code_Point"},
    919891: {"Other_Default_Ignorable_Code_Point"},
    919892: {"Other_Default_Ignorable_Code_Point"},
    919893: {"Other_Default_Ignorable_Code_Point"},
    919894: {"Other_Default_Ignorable_Code_Point"},
    919895: {"Other_Default_Ignorable_Code_Point"},
    919896: {"Other_Default_Ignorable_Code_Point"},
    919897: {"Other_Default_Ignorable_Code_Point"},
    919898: {"Other_Default_Ignorable_Code_Point"},
    919899: {"Other_Default_Ignorable_Code_Point"},
    919900: {"Other_Default_Ignorable_Code_Point"},
    919901: {"Other_Default_Ignorable_Code_Point"},
    919902: {"Other_Default_Ignorable_Code_Point"},
    919903: {"Other_Default_Ignorable_Code_Point"},
    919904: {"Other_Default_Ignorable_Code_Point"},
    919905: {"Other_Default_Ignorable_Code_Point"},
    919906: {"Other_Default_Ignorable_Code_Point"},
    919907: {"Other_Default_Ignorable_Code_Point"},
    919908: {"Other_Default_Ignorable_Code_Point"},
    919909: {"Other_Default_Ignorable_Code_Point"},
    919910: {"Other_Default_Ignorable_Code_Point"},
    919911: {"Other_Default_Ignorable_Code_Point"},
    919912: {"Other_Default_Ignorable_Code_Point"},
    919913: {"Other_Default_Ignorable_Code_Point"},
    919914: {"Other_Default_Ignorable_Code_Point"},
    919915: {"Other_Default_Ignorable_Code_Point"},
    919916: {"Other_Default_Ignorable_Code_Point"},
    919917: {"Other_Default_Ignorable_Code_Point"},
    919918: {"Other_Default_Ignorable_Code_Point"},
    919919: {"Other_Default_Ignorable_Code_Point"},
    919920: {"Other_Default_Ignorable_Code_Point"},
    919921: {"Other_Default_Ignorable_Code_Point"},
    919922: {"Other_Default_Ignorable_Code_Point"},
    919923: {"Other_Default_Ignorable_Code_Point"},
    919924: {"Other_Default_Ignorable_Code_Point"},
    919925: {"Other_Default_Ignorable_Code_Point"},
    919926: {"Other_Default_Ignorable_Code_Point"},
    919927: {"Other_Default_Ignorable_Code_Point"},
    919928: {"Other_Default_Ignorable_Code_Point"},
    919929: {"Other_Default_Ignorable_Code_Point"},
    919930: {"Other_Default_Ignorable_Code_Point"},
    919931: {"Other_Default_Ignorable_Code_Point"},
    919932: {"Other_Default_Ignorable_Code_Point"},
    919933: {"Other_Default_Ignorable_Code_Point"},
    919934: {"Other_Default_Ignorable_Code_Point"},
    919935: {"Other_Default_Ignorable_Code_Point"},
    919936: {"Other_Default_Ignorable_Code_Point"},
    919937: {"Other_Default_Ignorable_Code_Point"},
    919938: {"Other_Default_Ignorable_Code_Point"},
    919939: {"Other_Default_Ignorable_Code_Point"},
    919940: {"Other_Default_Ignorable_Code_Point"},
    919941: {"Other_Default_Ignorable_Code_Point"},
    919942: {"Other_Default_Ignorable_Code_Point"},
    919943: {"Other_Default_Ignorable_Code_Point"},
    919944: {"Other_Default_Ignorable_Code_Point"},
    919945: {"Other_Default_Ignorable_Code_Point"},
    919946: {"Other_Default_Ignorable_Code_Point"},
    919947: {"Other_Default_Ignorable_Code_Point"},
    919948: {"Other_Default_Ignorable_Code_Point"},
    919949: {"Other_Default_Ignorable_Code_Point"},
    919950: {"Other_Default_Ignorable_Code_Point"},
    919951: {"Other_Default_Ignorable_Code_Point"},
    919952: {"Other_Default_Ignorable_Code_Point"},
    919953: {"Other_Default_Ignorable_Code_Point"},
    919954: {"Other_Default_Ignorable_Code_Point"},
    919955: {"Other_Default_Ignorable_Code_Point"},
    919956: {"Other_Default_Ignorable_Code_Point"},
    919957: {"Other_Default_Ignorable_Code_Point"},
    919958: {"Other_Default_Ignorable_Code_Point"},
    919959: {"Other_Default_Ignorable_Code_Point"},
    919960: {"Other_Default_Ignorable_Code_Point"},
    919961: {"Other_Default_Ignorable_Code_Point"},
    919962: {"Other_Default_Ignorable_Code_Point"},
    919963: {"Other_Default_Ignorable_Code_Point"},
    919964: {"Other_Default_Ignorable_Code_Point"},
    919965: {"Other_Default_Ignorable_Code_Point"},
    919966: {"Other_Default_Ignorable_Code_Point"},
    919967: {"Other_Default_Ignorable_Code_Point"},
    919968: {"Other_Default_Ignorable_Code_Point"},
    919969: {"Other_Default_Ignorable_Code_Point"},
    919970: {"Other_Default_Ignorable_Code_Point"},
    919971: {"Other_Default_Ignorable_Code_Point"},
    919972: {"Other_Default_Ignorable_Code_Point"},
    919973: {"Other_Default_Ignorable_Code_Point"},
    919974: {"Other_Default_Ignorable_Code_Point"},
    919975: {"Other_Default_Ignorable_Code_Point"},
    919976: {"Other_Default_Ignorable_Code_Point"},
    919977: {"Other_Default_Ignorable_Code_Point"},
    919978: {"Other_Default_Ignorable_Code_Point"},
    919979: {"Other_Default_Ignorable_Code_Point"},
    919980: {"Other_Default_Ignorable_Code_Point"},
    919981: {"Other_Default_Ignorable_Code_Point"},
    919982: {"Other_Default_Ignorable_Code_Point"},
    919983: {"Other_Default_Ignorable_Code_Point"},
    919984: {"Other_Default_Ignorable_Code_Point"},
    919985: {"Other_Default_Ignorable_Code_Point"},
    919986: {"Other_Default_Ignorable_Code_Point"},
    919987: {"Other_Default_Ignorable_Code_Point"},
    919988: {"Other_Default_Ignorable_Code_Point"},
    919989: {"Other_Default_Ignorable_Code_Point"},
    919990: {"Other_Default_Ignorable_Code_Point"},
    919991: {"Other_Default_Ignorable_Code_Point"},
    919992: {"Other_Default_Ignorable_Code_Point"},
    919993: {"Other_Default_Ignorable_Code_Point"},
    919994: {"Other_Default_Ignorable_Code_Point"},
    919995: {"Other_Default_Ignorable_Code_Point"},
    919996: {"Other_Default_Ignorable_Code_Point"},
    919997: {"Other_Default_Ignorable_Code_Point"},
    919998: {"Other_Default_Ignorable_Code_Point"},
    919999: {"Other_Default_Ignorable_Code_Point"},
    920000: {"Other_Default_Ignorable_Code_Point"},
    920001: {"Other_Default_Ignorable_Code_Point"},
    920002: {"Other_Default_Ignorable_Code_Point"},
    920003: {"Other_Default_Ignorable_Code_Point"},
    920004: {"Other_Default_Ignorable_Code_Point"},
    920005: {"Other_Default_Ignorable_Code_Point"},
    920006: {"Other_Default_Ignorable_Code_Point"},
    920007: {"Other_Default_Ignorable_Code_Point"},
    920008: {"Other_Default_Ignorable_Code_Point"},
    920009: {"Other_Default_Ignorable_Code_Point"},
    920010: {"Other_Default_Ignorable_Code_Point"},
    920011: {"Other_Default_Ignorable_Code_Point"},
    920012: {"Other_Default_Ignorable_Code_Point"},
    920013: {"Other_Default_Ignorable_Code_Point"},
    920014: {"Other_Default_Ignorable_Code_Point"},
    920015: {"Other_Default_Ignorable_Code_Point"},
    920016: {"Other_Default_Ignorable_Code_Point"},
    920017: {"Other_Default_Ignorable_Code_Point"},
    920018: {"Other_Default_Ignorable_Code_Point"},
    920019: {"Other_Default_Ignorable_Code_Point"},
    920020: {"Other_Default_Ignorable_Code_Point"},
    920021: {"Other_Default_Ignorable_Code_Point"},
    920022: {"Other_Default_Ignorable_Code_Point"},
    920023: {"Other_Default_Ignorable_Code_Point"},
    920024: {"Other_Default_Ignorable_Code_Point"},
    920025: {"Other_Default_Ignorable_Code_Point"},
    920026: {"Other_Default_Ignorable_Code_Point"},
    920027: {"Other_Default_Ignorable_Code_Point"},
    920028: {"Other_Default_Ignorable_Code_Point"},
    920029: {"Other_Default_Ignorable_Code_Point"},
    920030: {"Other_Default_Ignorable_Code_Point"},
    920031: {"Other_Default_Ignorable_Code_Point"},
    920032: {"Other_Default_Ignorable_Code_Point"},
    920033: {"Other_Default_Ignorable_Code_Point"},
    920034: {"Other_Default_Ignorable_Code_Point"},
    920035: {"Other_Default_Ignorable_Code_Point"},
    920036: {"Other_Default_Ignorable_Code_Point"},
    920037: {"Other_Default_Ignorable_Code_Point"},
    920038: {"Other_Default_Ignorable_Code_Point"},
    920039: {"Other_Default_Ignorable_Code_Point"},
    920040: {"Other_Default_Ignorable_Code_Point"},
    920041: {"Other_Default_Ignorable_Code_Point"},
    920042: {"Other_Default_Ignorable_Code_Point"},
    920043: {"Other_Default_Ignorable_Code_Point"},
    920044: {"Other_Default_Ignorable_Code_Point"},
    920045: {"Other_Default_Ignorable_Code_Point"},
    920046: {"Other_Default_Ignorable_Code_Point"},
    920047: {"Other_Default_Ignorable_Code_Point"},
    920048: {"Other_Default_Ignorable_Code_Point"},
    920049: {"Other_Default_Ignorable_Code_Point"},
    920050: {"Other_Default_Ignorable_Code_Point"},
    920051: {"Other_Default_Ignorable_Code_Point"},
    920052: {"Other_Default_Ignorable_Code_Point"},
    920053: {"Other_Default_Ignorable_Code_Point"},
    920054: {"Other_Default_Ignorable_Code_Point"},
    920055: {"Other_Default_Ignorable_Code_Point"},
    920056: {"Other_Default_Ignorable_Code_Point"},
    920057: {"Other_Default_Ignorable_Code_Point"},
    920058: {"Other_Default_Ignorable_Code_Point"},
    920059: {"Other_Default_Ignorable_Code_Point"},
    920060: {"Other_Default_Ignorable_Code_Point"},
    920061: {"Other_Default_Ignorable_Code_Point"},
    920062: {"Other_Default_Ignorable_Code_Point"},
    920063: {"Other_Default_Ignorable_Code_Point"},
    920064: {"Other_Default_Ignorable_Code_Point"},
    920065: {"Other_Default_Ignorable_Code_Point"},
    920066: {"Other_Default_Ignorable_Code_Point"},
    920067: {"Other_Default_Ignorable_Code_Point"},
    920068: {"Other_Default_Ignorable_Code_Point"},
    920069: {"Other_Default_Ignorable_Code_Point"},
    920070: {"Other_Default_Ignorable_Code_Point"},
    920071: {"Other_Default_Ignorable_Code_Point"},
    920072: {"Other_Default_Ignorable_Code_Point"},
    920073: {"Other_Default_Ignorable_Code_Point"},
    920074: {"Other_Default_Ignorable_Code_Point"},
    920075: {"Other_Default_Ignorable_Code_Point"},
    920076: {"Other_Default_Ignorable_Code_Point"},
    920077: {"Other_Default_Ignorable_Code_Point"},
    920078: {"Other_Default_Ignorable_Code_Point"},
    920079: {"Other_Default_Ignorable_Code_Point"},
    920080: {"Other_Default_Ignorable_Code_Point"},
    920081: {"Other_Default_Ignorable_Code_Point"},
    920082: {"Other_Default_Ignorable_Code_Point"},
    920083: {"Other_Default_Ignorable_Code_Point"},
    920084: {"Other_Default_Ignorable_Code_Point"},
    920085: {"Other_Default_Ignorable_Code_Point"},
    920086: {"Other_Default_Ignorable_Code_Point"},
    920087: {"Other_Default_Ignorable_Code_Point"},
    920088: {"Other_Default_Ignorable_Code_Point"},
    920089: {"Other_Default_Ignorable_Code_Point"},
    920090: {"Other_Default_Ignorable_Code_Point"},
    920091: {"Other_Default_Ignorable_Code_Point"},
    920092: {"Other_Default_Ignorable_Code_Point"},
    920093: {"Other_Default_Ignorable_Code_Point"},
    920094: {"Other_Default_Ignorable_Code_Point"},
    920095: {"Other_Default_Ignorable_Code_Point"},
    920096: {"Other_Default_Ignorable_Code_Point"},
    920097: {"Other_Default_Ignorable_Code_Point"},
    920098: {"Other_Default_Ignorable_Code_Point"},
    920099: {"Other_Default_Ignorable_Code_Point"},
    920100: {"Other_Default_Ignorable_Code_Point"},
    920101: {"Other_Default_Ignorable_Code_Point"},
    920102: {"Other_Default_Ignorable_Code_Point"},
    920103: {"Other_Default_Ignorable_Code_Point"},
    920104: {"Other_Default_Ignorable_Code_Point"},
    920105: {"Other_Default_Ignorable_Code_Point"},
    920106: {"Other_Default_Ignorable_Code_Point"},
    920107: {"Other_Default_Ignorable_Code_Point"},
    920108: {"Other_Default_Ignorable_Code_Point"},
    920109: {"Other_Default_Ignorable_Code_Point"},
    920110: {"Other_Default_Ignorable_Code_Point"},
    920111: {"Other_Default_Ignorable_Code_Point"},
    920112: {"Other_Default_Ignorable_Code_Point"},
    920113: {"Other_Default_Ignorable_Code_Point"},
    920114: {"Other_Default_Ignorable_Code_Point"},
    920115: {"Other_Default_Ignorable_Code_Point"},
    920116: {"Other_Default_Ignorable_Code_Point"},
    920117: {"Other_Default_Ignorable_Code_Point"},
    920118: {"Other_Default_Ignorable_Code_Point"},
    920119: {"Other_Default_Ignorable_Code_Point"},
    920120: {"Other_Default_Ignorable_Code_Point"},
    920121: {"Other_Default_Ignorable_Code_Point"},
    920122: {"Other_Default_Ignorable_Code_Point"},
    920123: {"Other_Default_Ignorable_Code_Point"},
    920124: {"Other_Default_Ignorable_Code_Point"},
    920125: {"Other_Default_Ignorable_Code_Point"},
    920126: {"Other_Default_Ignorable_Code_Point"},
    920127: {"Other_Default_Ignorable_Code_Point"},
    920128: {"Other_Default_Ignorable_Code_Point"},
    920129: {"Other_Default_Ignorable_Code_Point"},
    920130: {"Other_Default_Ignorable_Code_Point"},
    920131: {"Other_Default_Ignorable_Code_Point"},
    920132: {"Other_Default_Ignorable_Code_Point"},
    920133: {"Other_Default_Ignorable_Code_Point"},
    920134: {"Other_Default_Ignorable_Code_Point"},
    920135: {"Other_Default_Ignorable_Code_Point"},
    920136: {"Other_Default_Ignorable_Code_Point"},
    920137: {"Other_Default_Ignorable_Code_Point"},
    920138: {"Other_Default_Ignorable_Code_Point"},
    920139: {"Other_Default_Ignorable_Code_Point"},
    920140: {"Other_Default_Ignorable_Code_Point"},
    920141: {"Other_Default_Ignorable_Code_Point"},
    920142: {"Other_Default_Ignorable_Code_Point"},
    920143: {"Other_Default_Ignorable_Code_Point"},
    920144: {"Other_Default_Ignorable_Code_Point"},
    920145: {"Other_Default_Ignorable_Code_Point"},
    920146: {"Other_Default_Ignorable_Code_Point"},
    920147: {"Other_Default_Ignorable_Code_Point"},
    920148: {"Other_Default_Ignorable_Code_Point"},
    920149: {"Other_Default_Ignorable_Code_Point"},
    920150: {"Other_Default_Ignorable_Code_Point"},
    920151: {"Other_Default_Ignorable_Code_Point"},
    920152: {"Other_Default_Ignorable_Code_Point"},
    920153: {"Other_Default_Ignorable_Code_Point"},
    920154: {"Other_Default_Ignorable_Code_Point"},
    920155: {"Other_Default_Ignorable_Code_Point"},
    920156: {"Other_Default_Ignorable_Code_Point"},
    920157: {"Other_Default_Ignorable_Code_Point"},
    920158: {"Other_Default_Ignorable_Code_Point"},
    920159: {"Other_Default_Ignorable_Code_Point"},
    920160: {"Other_Default_Ignorable_Code_Point"},
    920161: {"Other_Default_Ignorable_Code_Point"},
    920162: {"Other_Default_Ignorable_Code_Point"},
    920163: {"Other_Default_Ignorable_Code_Point"},
    920164: {"Other_Default_Ignorable_Code_Point"},
    920165: {"Other_Default_Ignorable_Code_Point"},
    920166: {"Other_Default_Ignorable_Code_Point"},
    920167: {"Other_Default_Ignorable_Code_Point"},
    920168: {"Other_Default_Ignorable_Code_Point"},
    920169: {"Other_Default_Ignorable_Code_Point"},
    920170: {"Other_Default_Ignorable_Code_Point"},
    920171: {"Other_Default_Ignorable_Code_Point"},
    920172: {"Other_Default_Ignorable_Code_Point"},
    920173: {"Other_Default_Ignorable_Code_Point"},
    920174: {"Other_Default_Ignorable_Code_Point"},
    920175: {"Other_Default_Ignorable_Code_Point"},
    920176: {"Other_Default_Ignorable_Code_Point"},
    920177: {"Other_Default_Ignorable_Code_Point"},
    920178: {"Other_Default_Ignorable_Code_Point"},
    920179: {"Other_Default_Ignorable_Code_Point"},
    920180: {"Other_Default_Ignorable_Code_Point"},
    920181: {"Other_Default_Ignorable_Code_Point"},
    920182: {"Other_Default_Ignorable_Code_Point"},
    920183: {"Other_Default_Ignorable_Code_Point"},
    920184: {"Other_Default_Ignorable_Code_Point"},
    920185: {"Other_Default_Ignorable_Code_Point"},
    920186: {"Other_Default_Ignorable_Code_Point"},
    920187: {"Other_Default_Ignorable_Code_Point"},
    920188: {"Other_Default_Ignorable_Code_Point"},
    920189: {"Other_Default_Ignorable_Code_Point"},
    920190: {"Other_Default_Ignorable_Code_Point"},
    920191: {"Other_Default_Ignorable_Code_Point"},
    920192: {"Other_Default_Ignorable_Code_Point"},
    920193: {"Other_Default_Ignorable_Code_Point"},
    920194: {"Other_Default_Ignorable_Code_Point"},
    920195: {"Other_Default_Ignorable_Code_Point"},
    920196: {"Other_Default_Ignorable_Code_Point"},
    920197: {"Other_Default_Ignorable_Code_Point"},
    920198: {"Other_Default_Ignorable_Code_Point"},
    920199: {"Other_Default_Ignorable_Code_Point"},
    920200: {"Other_Default_Ignorable_Code_Point"},
    920201: {"Other_Default_Ignorable_Code_Point"},
    920202: {"Other_Default_Ignorable_Code_Point"},
    920203: {"Other_Default_Ignorable_Code_Point"},
    920204: {"Other_Default_Ignorable_Code_Point"},
    920205: {"Other_Default_Ignorable_Code_Point"},
    920206: {"Other_Default_Ignorable_Code_Point"},
    920207: {"Other_Default_Ignorable_Code_Point"},
    920208: {"Other_Default_Ignorable_Code_Point"},
    920209: {"Other_Default_Ignorable_Code_Point"},
    920210: {"Other_Default_Ignorable_Code_Point"},
    920211: {"Other_Default_Ignorable_Code_Point"},
    920212: {"Other_Default_Ignorable_Code_Point"},
    920213: {"Other_Default_Ignorable_Code_Point"},
    920214: {"Other_Default_Ignorable_Code_Point"},
    920215: {"Other_Default_Ignorable_Code_Point"},
    920216: {"Other_Default_Ignorable_Code_Point"},
    920217: {"Other_Default_Ignorable_Code_Point"},
    920218: {"Other_Default_Ignorable_Code_Point"},
    920219: {"Other_Default_Ignorable_Code_Point"},
    920220: {"Other_Default_Ignorable_Code_Point"},
    920221: {"Other_Default_Ignorable_Code_Point"},
    920222: {"Other_Default_Ignorable_Code_Point"},
    920223: {"Other_Default_Ignorable_Code_Point"},
    920224: {"Other_Default_Ignorable_Code_Point"},
    920225: {"Other_Default_Ignorable_Code_Point"},
    920226: {"Other_Default_Ignorable_Code_Point"},
    920227: {"Other_Default_Ignorable_Code_Point"},
    920228: {"Other_Default_Ignorable_Code_Point"},
    920229: {"Other_Default_Ignorable_Code_Point"},
    920230: {"Other_Default_Ignorable_Code_Point"},
    920231: {"Other_Default_Ignorable_Code_Point"},
    920232: {"Other_Default_Ignorable_Code_Point"},
    920233: {"Other_Default_Ignorable_Code_Point"},
    920234: {"Other_Default_Ignorable_Code_Point"},
    920235: {"Other_Default_Ignorable_Code_Point"},
    920236: {"Other_Default_Ignorable_Code_Point"},
    920237: {"Other_Default_Ignorable_Code_Point"},
    920238: {"Other_Default_Ignorable_Code_Point"},
    920239: {"Other_Default_Ignorable_Code_Point"},
    920240: {"Other_Default_Ignorable_Code_Point"},
    920241: {"Other_Default_Ignorable_Code_Point"},
    920242: {"Other_Default_Ignorable_Code_Point"},
    920243: {"Other_Default_Ignorable_Code_Point"},
    920244: {"Other_Default_Ignorable_Code_Point"},
    920245: {"Other_Default_Ignorable_Code_Point"},
    920246: {"Other_Default_Ignorable_Code_Point"},
    920247: {"Other_Default_Ignorable_Code_Point"},
    920248: {"Other_Default_Ignorable_Code_Point"},
    920249: {"Other_Default_Ignorable_Code_Point"},
    920250: {"Other_Default_Ignorable_Code_Point"},
    920251: {"Other_Default_Ignorable_Code_Point"},
    920252: {"Other_Default_Ignorable_Code_Point"},
    920253: {"Other_Default_Ignorable_Code_Point"},
    920254: {"Other_Default_Ignorable_Code_Point"},
    920255: {"Other_Default_Ignorable_Code_Point"},
    920256: {"Other_Default_Ignorable_Code_Point"},
    920257: {"Other_Default_Ignorable_Code_Point"},
    920258: {"Other_Default_Ignorable_Code_Point"},
    920259: {"Other_Default_Ignorable_Code_Point"},
    920260: {"Other_Default_Ignorable_Code_Point"},
    920261: {"Other_Default_Ignorable_Code_Point"},
    920262: {"Other_Default_Ignorable_Code_Point"},
    920263: {"Other_Default_Ignorable_Code_Point"},
    920264: {"Other_Default_Ignorable_Code_Point"},
    920265: {"Other_Default_Ignorable_Code_Point"},
    920266: {"Other_Default_Ignorable_Code_Point"},
    920267: {"Other_Default_Ignorable_Code_Point"},
    920268: {"Other_Default_Ignorable_Code_Point"},
    920269: {"Other_Default_Ignorable_Code_Point"},
    920270: {"Other_Default_Ignorable_Code_Point"},
    920271: {"Other_Default_Ignorable_Code_Point"},
    920272: {"Other_Default_Ignorable_Code_Point"},
    920273: {"Other_Default_Ignorable_Code_Point"},
    920274: {"Other_Default_Ignorable_Code_Point"},
    920275: {"Other_Default_Ignorable_Code_Point"},
    920276: {"Other_Default_Ignorable_Code_Point"},
    920277: {"Other_Default_Ignorable_Code_Point"},
    920278: {"Other_Default_Ignorable_Code_Point"},
    920279: {"Other_Default_Ignorable_Code_Point"},
    920280: {"Other_Default_Ignorable_Code_Point"},
    920281: {"Other_Default_Ignorable_Code_Point"},
    920282: {"Other_Default_Ignorable_Code_Point"},
    920283: {"Other_Default_Ignorable_Code_Point"},
    920284: {"Other_Default_Ignorable_Code_Point"},
    920285: {"Other_Default_Ignorable_Code_Point"},
    920286: {"Other_Default_Ignorable_Code_Point"},
    920287: {"Other_Default_Ignorable_Code_Point"},
    920288: {"Other_Default_Ignorable_Code_Point"},
    920289: {"Other_Default_Ignorable_Code_Point"},
    920290: {"Other_Default_Ignorable_Code_Point"},
    920291: {"Other_Default_Ignorable_Code_Point"},
    920292: {"Other_Default_Ignorable_Code_Point"},
    920293: {"Other_Default_Ignorable_Code_Point"},
    920294: {"Other_Default_Ignorable_Code_Point"},
    920295: {"Other_Default_Ignorable_Code_Point"},
    920296: {"Other_Default_Ignorable_Code_Point"},
    920297: {"Other_Default_Ignorable_Code_Point"},
    920298: {"Other_Default_Ignorable_Code_Point"},
    920299: {"Other_Default_Ignorable_Code_Point"},
    920300: {"Other_Default_Ignorable_Code_Point"},
    920301: {"Other_Default_Ignorable_Code_Point"},
    920302: {"Other_Default_Ignorable_Code_Point"},
    920303: {"Other_Default_Ignorable_Code_Point"},
    920304: {"Other_Default_Ignorable_Code_Point"},
    920305: {"Other_Default_Ignorable_Code_Point"},
    920306: {"Other_Default_Ignorable_Code_Point"},
    920307: {"Other_Default_Ignorable_Code_Point"},
    920308: {"Other_Default_Ignorable_Code_Point"},
    920309: {"Other_Default_Ignorable_Code_Point"},
    920310: {"Other_Default_Ignorable_Code_Point"},
    920311: {"Other_Default_Ignorable_Code_Point"},
    920312: {"Other_Default_Ignorable_Code_Point"},
    920313: {"Other_Default_Ignorable_Code_Point"},
    920314: {"Other_Default_Ignorable_Code_Point"},
    920315: {"Other_Default_Ignorable_Code_Point"},
    920316: {"Other_Default_Ignorable_Code_Point"},
    920317: {"Other_Default_Ignorable_Code_Point"},
    920318: {"Other_Default_Ignorable_Code_Point"},
    920319: {"Other_Default_Ignorable_Code_Point"},
    920320: {"Other_Default_Ignorable_Code_Point"},
    920321: {"Other_Default_Ignorable_Code_Point"},
    920322: {"Other_Default_Ignorable_Code_Point"},
    920323: {"Other_Default_Ignorable_Code_Point"},
    920324: {"Other_Default_Ignorable_Code_Point"},
    920325: {"Other_Default_Ignorable_Code_Point"},
    920326: {"Other_Default_Ignorable_Code_Point"},
    920327: {"Other_Default_Ignorable_Code_Point"},
    920328: {"Other_Default_Ignorable_Code_Point"},
    920329: {"Other_Default_Ignorable_Code_Point"},
    920330: {"Other_Default_Ignorable_Code_Point"},
    920331: {"Other_Default_Ignorable_Code_Point"},
    920332: {"Other_Default_Ignorable_Code_Point"},
    920333: {"Other_Default_Ignorable_Code_Point"},
    920334: {"Other_Default_Ignorable_Code_Point"},
    920335: {"Other_Default_Ignorable_Code_Point"},
    920336: {"Other_Default_Ignorable_Code_Point"},
    920337: {"Other_Default_Ignorable_Code_Point"},
    920338: {"Other_Default_Ignorable_Code_Point"},
    920339: {"Other_Default_Ignorable_Code_Point"},
    920340: {"Other_Default_Ignorable_Code_Point"},
    920341: {"Other_Default_Ignorable_Code_Point"},
    920342: {"Other_Default_Ignorable_Code_Point"},
    920343: {"Other_Default_Ignorable_Code_Point"},
    920344: {"Other_Default_Ignorable_Code_Point"},
    920345: {"Other_Default_Ignorable_Code_Point"},
    920346: {"Other_Default_Ignorable_Code_Point"},
    920347: {"Other_Default_Ignorable_Code_Point"},
    920348: {"Other_Default_Ignorable_Code_Point"},
    920349: {"Other_Default_Ignorable_Code_Point"},
    920350: {"Other_Default_Ignorable_Code_Point"},
    920351: {"Other_Default_Ignorable_Code_Point"},
    920352: {"Other_Default_Ignorable_Code_Point"},
    920353: {"Other_Default_Ignorable_Code_Point"},
    920354: {"Other_Default_Ignorable_Code_Point"},
    920355: {"Other_Default_Ignorable_Code_Point"},
    920356: {"Other_Default_Ignorable_Code_Point"},
    920357: {"Other_Default_Ignorable_Code_Point"},
    920358: {"Other_Default_Ignorable_Code_Point"},
    920359: {"Other_Default_Ignorable_Code_Point"},
    920360: {"Other_Default_Ignorable_Code_Point"},
    920361: {"Other_Default_Ignorable_Code_Point"},
    920362: {"Other_Default_Ignorable_Code_Point"},
    920363: {"Other_Default_Ignorable_Code_Point"},
    920364: {"Other_Default_Ignorable_Code_Point"},
    920365: {"Other_Default_Ignorable_Code_Point"},
    920366: {"Other_Default_Ignorable_Code_Point"},
    920367: {"Other_Default_Ignorable_Code_Point"},
    920368: {"Other_Default_Ignorable_Code_Point"},
    920369: {"Other_Default_Ignorable_Code_Point"},
    920370: {"Other_Default_Ignorable_Code_Point"},
    920371: {"Other_Default_Ignorable_Code_Point"},
    920372: {"Other_Default_Ignorable_Code_Point"},
    920373: {"Other_Default_Ignorable_Code_Point"},
    920374: {"Other_Default_Ignorable_Code_Point"},
    920375: {"Other_Default_Ignorable_Code_Point"},
    920376: {"Other_Default_Ignorable_Code_Point"},
    920377: {"Other_Default_Ignorable_Code_Point"},
    920378: {"Other_Default_Ignorable_Code_Point"},
    920379: {"Other_Default_Ignorable_Code_Point"},
    920380: {"Other_Default_Ignorable_Code_Point"},
    920381: {"Other_Default_Ignorable_Code_Point"},
    920382: {"Other_Default_Ignorable_Code_Point"},
    920383: {"Other_Default_Ignorable_Code_Point"},
    920384: {"Other_Default_Ignorable_Code_Point"},
    920385: {"Other_Default_Ignorable_Code_Point"},
    920386: {"Other_Default_Ignorable_Code_Point"},
    920387: {"Other_Default_Ignorable_Code_Point"},
    920388: {"Other_Default_Ignorable_Code_Point"},
    920389: {"Other_Default_Ignorable_Code_Point"},
    920390: {"Other_Default_Ignorable_Code_Point"},
    920391: {"Other_Default_Ignorable_Code_Point"},
    920392: {"Other_Default_Ignorable_Code_Point"},
    920393: {"Other_Default_Ignorable_Code_Point"},
    920394: {"Other_Default_Ignorable_Code_Point"},
    920395: {"Other_Default_Ignorable_Code_Point"},
    920396: {"Other_Default_Ignorable_Code_Point"},
    920397: {"Other_Default_Ignorable_Code_Point"},
    920398: {"Other_Default_Ignorable_Code_Point"},
    920399: {"Other_Default_Ignorable_Code_Point"},
    920400: {"Other_Default_Ignorable_Code_Point"},
    920401: {"Other_Default_Ignorable_Code_Point"},
    920402: {"Other_Default_Ignorable_Code_Point"},
    920403: {"Other_Default_Ignorable_Code_Point"},
    920404: {"Other_Default_Ignorable_Code_Point"},
    920405: {"Other_Default_Ignorable_Code_Point"},
    920406: {"Other_Default_Ignorable_Code_Point"},
    920407: {"Other_Default_Ignorable_Code_Point"},
    920408: {"Other_Default_Ignorable_Code_Point"},
    920409: {"Other_Default_Ignorable_Code_Point"},
    920410: {"Other_Default_Ignorable_Code_Point"},
    920411: {"Other_Default_Ignorable_Code_Point"},
    920412: {"Other_Default_Ignorable_Code_Point"},
    920413: {"Other_Default_Ignorable_Code_Point"},
    920414: {"Other_Default_Ignorable_Code_Point"},
    920415: {"Other_Default_Ignorable_Code_Point"},
    920416: {"Other_Default_Ignorable_Code_Point"},
    920417: {"Other_Default_Ignorable_Code_Point"},
    920418: {"Other_Default_Ignorable_Code_Point"},
    920419: {"Other_Default_Ignorable_Code_Point"},
    920420: {"Other_Default_Ignorable_Code_Point"},
    920421: {"Other_Default_Ignorable_Code_Point"},
    920422: {"Other_Default_Ignorable_Code_Point"},
    920423: {"Other_Default_Ignorable_Code_Point"},
    920424: {"Other_Default_Ignorable_Code_Point"},
    920425: {"Other_Default_Ignorable_Code_Point"},
    920426: {"Other_Default_Ignorable_Code_Point"},
    920427: {"Other_Default_Ignorable_Code_Point"},
    920428: {"Other_Default_Ignorable_Code_Point"},
    920429: {"Other_Default_Ignorable_Code_Point"},
    920430: {"Other_Default_Ignorable_Code_Point"},
    920431: {"Other_Default_Ignorable_Code_Point"},
    920432: {"Other_Default_Ignorable_Code_Point"},
    920433: {"Other_Default_Ignorable_Code_Point"},
    920434: {"Other_Default_Ignorable_Code_Point"},
    920435: {"Other_Default_Ignorable_Code_Point"},
    920436: {"Other_Default_Ignorable_Code_Point"},
    920437: {"Other_Default_Ignorable_Code_Point"},
    920438: {"Other_Default_Ignorable_Code_Point"},
    920439: {"Other_Default_Ignorable_Code_Point"},
    920440: {"Other_Default_Ignorable_Code_Point"},
    920441: {"Other_Default_Ignorable_Code_Point"},
    920442: {"Other_Default_Ignorable_Code_Point"},
    920443: {"Other_Default_Ignorable_Code_Point"},
    920444: {"Other_Default_Ignorable_Code_Point"},
    920445: {"Other_Default_Ignorable_Code_Point"},
    920446: {"Other_Default_Ignorable_Code_Point"},
    920447: {"Other_Default_Ignorable_Code_Point"},
    920448: {"Other_Default_Ignorable_Code_Point"},
    920449: {"Other_Default_Ignorable_Code_Point"},
    920450: {"Other_Default_Ignorable_Code_Point"},
    920451: {"Other_Default_Ignorable_Code_Point"},
    920452: {"Other_Default_Ignorable_Code_Point"},
    920453: {"Other_Default_Ignorable_Code_Point"},
    920454: {"Other_Default_Ignorable_Code_Point"},
    920455: {"Other_Default_Ignorable_Code_Point"},
    920456: {"Other_Default_Ignorable_Code_Point"},
    920457: {"Other_Default_Ignorable_Code_Point"},
    920458: {"Other_Default_Ignorable_Code_Point"},
    920459: {"Other_Default_Ignorable_Code_Point"},
    920460: {"Other_Default_Ignorable_Code_Point"},
    920461: {"Other_Default_Ignorable_Code_Point"},
    920462: {"Other_Default_Ignorable_Code_Point"},
    920463: {"Other_Default_Ignorable_Code_Point"},
    920464: {"Other_Default_Ignorable_Code_Point"},
    920465: {"Other_Default_Ignorable_Code_Point"},
    920466: {"Other_Default_Ignorable_Code_Point"},
    920467: {"Other_Default_Ignorable_Code_Point"},
    920468: {"Other_Default_Ignorable_Code_Point"},
    920469: {"Other_Default_Ignorable_Code_Point"},
    920470: {"Other_Default_Ignorable_Code_Point"},
    920471: {"Other_Default_Ignorable_Code_Point"},
    920472: {"Other_Default_Ignorable_Code_Point"},
    920473: {"Other_Default_Ignorable_Code_Point"},
    920474: {"Other_Default_Ignorable_Code_Point"},
    920475: {"Other_Default_Ignorable_Code_Point"},
    920476: {"Other_Default_Ignorable_Code_Point"},
    920477: {"Other_Default_Ignorable_Code_Point"},
    920478: {"Other_Default_Ignorable_Code_Point"},
    920479: {"Other_Default_Ignorable_Code_Point"},
    920480: {"Other_Default_Ignorable_Code_Point"},
    920481: {"Other_Default_Ignorable_Code_Point"},
    920482: {"Other_Default_Ignorable_Code_Point"},
    920483: {"Other_Default_Ignorable_Code_Point"},
    920484: {"Other_Default_Ignorable_Code_Point"},
    920485: {"Other_Default_Ignorable_Code_Point"},
    920486: {"Other_Default_Ignorable_Code_Point"},
    920487: {"Other_Default_Ignorable_Code_Point"},
    920488: {"Other_Default_Ignorable_Code_Point"},
    920489: {"Other_Default_Ignorable_Code_Point"},
    920490: {"Other_Default_Ignorable_Code_Point"},
    920491: {"Other_Default_Ignorable_Code_Point"},
    920492: {"Other_Default_Ignorable_Code_Point"},
    920493: {"Other_Default_Ignorable_Code_Point"},
    920494: {"Other_Default_Ignorable_Code_Point"},
    920495: {"Other_Default_Ignorable_Code_Point"},
    920496: {"Other_Default_Ignorable_Code_Point"},
    920497: {"Other_Default_Ignorable_Code_Point"},
    920498: {"Other_Default_Ignorable_Code_Point"},
    920499: {"Other_Default_Ignorable_Code_Point"},
    920500: {"Other_Default_Ignorable_Code_Point"},
    920501: {"Other_Default_Ignorable_Code_Point"},
    920502: {"Other_Default_Ignorable_Code_Point"},
    920503: {"Other_Default_Ignorable_Code_Point"},
    920504: {"Other_Default_Ignorable_Code_Point"},
    920505: {"Other_Default_Ignorable_Code_Point"},
    920506: {"Other_Default_Ignorable_Code_Point"},
    920507: {"Other_Default_Ignorable_Code_Point"},
    920508: {"Other_Default_Ignorable_Code_Point"},
    920509: {"Other_Default_Ignorable_Code_Point"},
    920510: {"Other_Default_Ignorable_Code_Point"},
    920511: {"Other_Default_Ignorable_Code_Point"},
    920512: {"Other_Default_Ignorable_Code_Point"},
    920513: {"Other_Default_Ignorable_Code_Point"},
    920514: {"Other_Default_Ignorable_Code_Point"},
    920515: {"Other_Default_Ignorable_Code_Point"},
    920516: {"Other_Default_Ignorable_Code_Point"},
    920517: {"Other_Default_Ignorable_Code_Point"},
    920518: {"Other_Default_Ignorable_Code_Point"},
    920519: {"Other_Default_Ignorable_Code_Point"},
    920520: {"Other_Default_Ignorable_Code_Point"},
    920521: {"Other_Default_Ignorable_Code_Point"},
    920522: {"Other_Default_Ignorable_Code_Point"},
    920523: {"Other_Default_Ignorable_Code_Point"},
    920524: {"Other_Default_Ignorable_Code_Point"},
    920525: {"Other_Default_Ignorable_Code_Point"},
    920526: {"Other_Default_Ignorable_Code_Point"},
    920527: {"Other_Default_Ignorable_Code_Point"},
    920528: {"Other_Default_Ignorable_Code_Point"},
    920529: {"Other_Default_Ignorable_Code_Point"},
    920530: {"Other_Default_Ignorable_Code_Point"},
    920531: {"Other_Default_Ignorable_Code_Point"},
    920532: {"Other_Default_Ignorable_Code_Point"},
    920533: {"Other_Default_Ignorable_Code_Point"},
    920534: {"Other_Default_Ignorable_Code_Point"},
    920535: {"Other_Default_Ignorable_Code_Point"},
    920536: {"Other_Default_Ignorable_Code_Point"},
    920537: {"Other_Default_Ignorable_Code_Point"},
    920538: {"Other_Default_Ignorable_Code_Point"},
    920539: {"Other_Default_Ignorable_Code_Point"},
    920540: {"Other_Default_Ignorable_Code_Point"},
    920541: {"Other_Default_Ignorable_Code_Point"},
    920542: {"Other_Default_Ignorable_Code_Point"},
    920543: {"Other_Default_Ignorable_Code_Point"},
    920544: {"Other_Default_Ignorable_Code_Point"},
    920545: {"Other_Default_Ignorable_Code_Point"},
    920546: {"Other_Default_Ignorable_Code_Point"},
    920547: {"Other_Default_Ignorable_Code_Point"},
    920548: {"Other_Default_Ignorable_Code_Point"},
    920549: {"Other_Default_Ignorable_Code_Point"},
    920550: {"Other_Default_Ignorable_Code_Point"},
    920551: {"Other_Default_Ignorable_Code_Point"},
    920552: {"Other_Default_Ignorable_Code_Point"},
    920553: {"Other_Default_Ignorable_Code_Point"},
    920554: {"Other_Default_Ignorable_Code_Point"},
    920555: {"Other_Default_Ignorable_Code_Point"},
    920556: {"Other_Default_Ignorable_Code_Point"},
    920557: {"Other_Default_Ignorable_Code_Point"},
    920558: {"Other_Default_Ignorable_Code_Point"},
    920559: {"Other_Default_Ignorable_Code_Point"},
    920560: {"Other_Default_Ignorable_Code_Point"},
    920561: {"Other_Default_Ignorable_Code_Point"},
    920562: {"Other_Default_Ignorable_Code_Point"},
    920563: {"Other_Default_Ignorable_Code_Point"},
    920564: {"Other_Default_Ignorable_Code_Point"},
    920565: {"Other_Default_Ignorable_Code_Point"},
    920566: {"Other_Default_Ignorable_Code_Point"},
    920567: {"Other_Default_Ignorable_Code_Point"},
    920568: {"Other_Default_Ignorable_Code_Point"},
    920569: {"Other_Default_Ignorable_Code_Point"},
    920570: {"Other_Default_Ignorable_Code_Point"},
    920571: {"Other_Default_Ignorable_Code_Point"},
    920572: {"Other_Default_Ignorable_Code_Point"},
    920573: {"Other_Default_Ignorable_Code_Point"},
    920574: {"Other_Default_Ignorable_Code_Point"},
    920575: {"Other_Default_Ignorable_Code_Point"},
    920576: {"Other_Default_Ignorable_Code_Point"},
    920577: {"Other_Default_Ignorable_Code_Point"},
    920578: {"Other_Default_Ignorable_Code_Point"},
    920579: {"Other_Default_Ignorable_Code_Point"},
    920580: {"Other_Default_Ignorable_Code_Point"},
    920581: {"Other_Default_Ignorable_Code_Point"},
    920582: {"Other_Default_Ignorable_Code_Point"},
    920583: {"Other_Default_Ignorable_Code_Point"},
    920584: {"Other_Default_Ignorable_Code_Point"},
    920585: {"Other_Default_Ignorable_Code_Point"},
    920586: {"Other_Default_Ignorable_Code_Point"},
    920587: {"Other_Default_Ignorable_Code_Point"},
    920588: {"Other_Default_Ignorable_Code_Point"},
    920589: {"Other_Default_Ignorable_Code_Point"},
    920590: {"Other_Default_Ignorable_Code_Point"},
    920591: {"Other_Default_Ignorable_Code_Point"},
    920592: {"Other_Default_Ignorable_Code_Point"},
    920593: {"Other_Default_Ignorable_Code_Point"},
    920594: {"Other_Default_Ignorable_Code_Point"},
    920595: {"Other_Default_Ignorable_Code_Point"},
    920596: {"Other_Default_Ignorable_Code_Point"},
    920597: {"Other_Default_Ignorable_Code_Point"},
    920598: {"Other_Default_Ignorable_Code_Point"},
    920599: {"Other_Default_Ignorable_Code_Point"},
    920600: {"Other_Default_Ignorable_Code_Point"},
    920601: {"Other_Default_Ignorable_Code_Point"},
    920602: {"Other_Default_Ignorable_Code_Point"},
    920603: {"Other_Default_Ignorable_Code_Point"},
    920604: {"Other_Default_Ignorable_Code_Point"},
    920605: {"Other_Default_Ignorable_Code_Point"},
    920606: {"Other_Default_Ignorable_Code_Point"},
    920607: {"Other_Default_Ignorable_Code_Point"},
    920608: {"Other_Default_Ignorable_Code_Point"},
    920609: {"Other_Default_Ignorable_Code_Point"},
    920610: {"Other_Default_Ignorable_Code_Point"},
    920611: {"Other_Default_Ignorable_Code_Point"},
    920612: {"Other_Default_Ignorable_Code_Point"},
    920613: {"Other_Default_Ignorable_Code_Point"},
    920614: {"Other_Default_Ignorable_Code_Point"},
    920615: {"Other_Default_Ignorable_Code_Point"},
    920616: {"Other_Default_Ignorable_Code_Point"},
    920617: {"Other_Default_Ignorable_Code_Point"},
    920618: {"Other_Default_Ignorable_Code_Point"},
    920619: {"Other_Default_Ignorable_Code_Point"},
    920620: {"Other_Default_Ignorable_Code_Point"},
    920621: {"Other_Default_Ignorable_Code_Point"},
    920622: {"Other_Default_Ignorable_Code_Point"},
    920623: {"Other_Default_Ignorable_Code_Point"},
    920624: {"Other_Default_Ignorable_Code_Point"},
    920625: {"Other_Default_Ignorable_Code_Point"},
    920626: {"Other_Default_Ignorable_Code_Point"},
    920627: {"Other_Default_Ignorable_Code_Point"},
    920628: {"Other_Default_Ignorable_Code_Point"},
    920629: {"Other_Default_Ignorable_Code_Point"},
    920630: {"Other_Default_Ignorable_Code_Point"},
    920631: {"Other_Default_Ignorable_Code_Point"},
    920632: {"Other_Default_Ignorable_Code_Point"},
    920633: {"Other_Default_Ignorable_Code_Point"},
    920634: {"Other_Default_Ignorable_Code_Point"},
    920635: {"Other_Default_Ignorable_Code_Point"},
    920636: {"Other_Default_Ignorable_Code_Point"},
    920637: {"Other_Default_Ignorable_Code_Point"},
    920638: {"Other_Default_Ignorable_Code_Point"},
    920639: {"Other_Default_Ignorable_Code_Point"},
    920640: {"Other_Default_Ignorable_Code_Point"},
    920641: {"Other_Default_Ignorable_Code_Point"},
    920642: {"Other_Default_Ignorable_Code_Point"},
    920643: {"Other_Default_Ignorable_Code_Point"},
    920644: {"Other_Default_Ignorable_Code_Point"},
    920645: {"Other_Default_Ignorable_Code_Point"},
    920646: {"Other_Default_Ignorable_Code_Point"},
    920647: {"Other_Default_Ignorable_Code_Point"},
    920648: {"Other_Default_Ignorable_Code_Point"},
    920649: {"Other_Default_Ignorable_Code_Point"},
    920650: {"Other_Default_Ignorable_Code_Point"},
    920651: {"Other_Default_Ignorable_Code_Point"},
    920652: {"Other_Default_Ignorable_Code_Point"},
    920653: {"Other_Default_Ignorable_Code_Point"},
    920654: {"Other_Default_Ignorable_Code_Point"},
    920655: {"Other_Default_Ignorable_Code_Point"},
    920656: {"Other_Default_Ignorable_Code_Point"},
    920657: {"Other_Default_Ignorable_Code_Point"},
    920658: {"Other_Default_Ignorable_Code_Point"},
    920659: {"Other_Default_Ignorable_Code_Point"},
    920660: {"Other_Default_Ignorable_Code_Point"},
    920661: {"Other_Default_Ignorable_Code_Point"},
    920662: {"Other_Default_Ignorable_Code_Point"},
    920663: {"Other_Default_Ignorable_Code_Point"},
    920664: {"Other_Default_Ignorable_Code_Point"},
    920665: {"Other_Default_Ignorable_Code_Point"},
    920666: {"Other_Default_Ignorable_Code_Point"},
    920667: {"Other_Default_Ignorable_Code_Point"},
    920668: {"Other_Default_Ignorable_Code_Point"},
    920669: {"Other_Default_Ignorable_Code_Point"},
    920670: {"Other_Default_Ignorable_Code_Point"},
    920671: {"Other_Default_Ignorable_Code_Point"},
    920672: {"Other_Default_Ignorable_Code_Point"},
    920673: {"Other_Default_Ignorable_Code_Point"},
    920674: {"Other_Default_Ignorable_Code_Point"},
    920675: {"Other_Default_Ignorable_Code_Point"},
    920676: {"Other_Default_Ignorable_Code_Point"},
    920677: {"Other_Default_Ignorable_Code_Point"},
    920678: {"Other_Default_Ignorable_Code_Point"},
    920679: {"Other_Default_Ignorable_Code_Point"},
    920680: {"Other_Default_Ignorable_Code_Point"},
    920681: {"Other_Default_Ignorable_Code_Point"},
    920682: {"Other_Default_Ignorable_Code_Point"},
    920683: {"Other_Default_Ignorable_Code_Point"},
    920684: {"Other_Default_Ignorable_Code_Point"},
    920685: {"Other_Default_Ignorable_Code_Point"},
    920686: {"Other_Default_Ignorable_Code_Point"},
    920687: {"Other_Default_Ignorable_Code_Point"},
    920688: {"Other_Default_Ignorable_Code_Point"},
    920689: {"Other_Default_Ignorable_Code_Point"},
    920690: {"Other_Default_Ignorable_Code_Point"},
    920691: {"Other_Default_Ignorable_Code_Point"},
    920692: {"Other_Default_Ignorable_Code_Point"},
    920693: {"Other_Default_Ignorable_Code_Point"},
    920694: {"Other_Default_Ignorable_Code_Point"},
    920695: {"Other_Default_Ignorable_Code_Point"},
    920696: {"Other_Default_Ignorable_Code_Point"},
    920697: {"Other_Default_Ignorable_Code_Point"},
    920698: {"Other_Default_Ignorable_Code_Point"},
    920699: {"Other_Default_Ignorable_Code_Point"},
    920700: {"Other_Default_Ignorable_Code_Point"},
    920701: {"Other_Default_Ignorable_Code_Point"},
    920702: {"Other_Default_Ignorable_Code_Point"},
    920703: {"Other_Default_Ignorable_Code_Point"},
    920704: {"Other_Default_Ignorable_Code_Point"},
    920705: {"Other_Default_Ignorable_Code_Point"},
    920706: {"Other_Default_Ignorable_Code_Point"},
    920707: {"Other_Default_Ignorable_Code_Point"},
    920708: {"Other_Default_Ignorable_Code_Point"},
    920709: {"Other_Default_Ignorable_Code_Point"},
    920710: {"Other_Default_Ignorable_Code_Point"},
    920711: {"Other_Default_Ignorable_Code_Point"},
    920712: {"Other_Default_Ignorable_Code_Point"},
    920713: {"Other_Default_Ignorable_Code_Point"},
    920714: {"Other_Default_Ignorable_Code_Point"},
    920715: {"Other_Default_Ignorable_Code_Point"},
    920716: {"Other_Default_Ignorable_Code_Point"},
    920717: {"Other_Default_Ignorable_Code_Point"},
    920718: {"Other_Default_Ignorable_Code_Point"},
    920719: {"Other_Default_Ignorable_Code_Point"},
    920720: {"Other_Default_Ignorable_Code_Point"},
    920721: {"Other_Default_Ignorable_Code_Point"},
    920722: {"Other_Default_Ignorable_Code_Point"},
    920723: {"Other_Default_Ignorable_Code_Point"},
    920724: {"Other_Default_Ignorable_Code_Point"},
    920725: {"Other_Default_Ignorable_Code_Point"},
    920726: {"Other_Default_Ignorable_Code_Point"},
    920727: {"Other_Default_Ignorable_Code_Point"},
    920728: {"Other_Default_Ignorable_Code_Point"},
    920729: {"Other_Default_Ignorable_Code_Point"},
    920730: {"Other_Default_Ignorable_Code_Point"},
    920731: {"Other_Default_Ignorable_Code_Point"},
    920732: {"Other_Default_Ignorable_Code_Point"},
    920733: {"Other_Default_Ignorable_Code_Point"},
    920734: {"Other_Default_Ignorable_Code_Point"},
    920735: {"Other_Default_Ignorable_Code_Point"},
    920736: {"Other_Default_Ignorable_Code_Point"},
    920737: {"Other_Default_Ignorable_Code_Point"},
    920738: {"Other_Default_Ignorable_Code_Point"},
    920739: {"Other_Default_Ignorable_Code_Point"},
    920740: {"Other_Default_Ignorable_Code_Point"},
    920741: {"Other_Default_Ignorable_Code_Point"},
    920742: {"Other_Default_Ignorable_Code_Point"},
    920743: {"Other_Default_Ignorable_Code_Point"},
    920744: {"Other_Default_Ignorable_Code_Point"},
    920745: {"Other_Default_Ignorable_Code_Point"},
    920746: {"Other_Default_Ignorable_Code_Point"},
    920747: {"Other_Default_Ignorable_Code_Point"},
    920748: {"Other_Default_Ignorable_Code_Point"},
    920749: {"Other_Default_Ignorable_Code_Point"},
    920750: {"Other_Default_Ignorable_Code_Point"},
    920751: {"Other_Default_Ignorable_Code_Point"},
    920752: {"Other_Default_Ignorable_Code_Point"},
    920753: {"Other_Default_Ignorable_Code_Point"},
    920754: {"Other_Default_Ignorable_Code_Point"},
    920755: {"Other_Default_Ignorable_Code_Point"},
    920756: {"Other_Default_Ignorable_Code_Point"},
    920757: {"Other_Default_Ignorable_Code_Point"},
    920758: {"Other_Default_Ignorable_Code_Point"},
    920759: {"Other_Default_Ignorable_Code_Point"},
    920760: {"Other_Default_Ignorable_Code_Point"},
    920761: {"Other_Default_Ignorable_Code_Point"},
    920762: {"Other_Default_Ignorable_Code_Point"},
    920763: {"Other_Default_Ignorable_Code_Point"},
    920764: {"Other_Default_Ignorable_Code_Point"},
    920765: {"Other_Default_Ignorable_Code_Point"},
    920766: {"Other_Default_Ignorable_Code_Point"},
    920767: {"Other_Default_Ignorable_Code_Point"},
    920768: {"Other_Default_Ignorable_Code_Point"},
    920769: {"Other_Default_Ignorable_Code_Point"},
    920770: {"Other_Default_Ignorable_Code_Point"},
    920771: {"Other_Default_Ignorable_Code_Point"},
    920772: {"Other_Default_Ignorable_Code_Point"},
    920773: {"Other_Default_Ignorable_Code_Point"},
    920774: {"Other_Default_Ignorable_Code_Point"},
    920775: {"Other_Default_Ignorable_Code_Point"},
    920776: {"Other_Default_Ignorable_Code_Point"},
    920777: {"Other_Default_Ignorable_Code_Point"},
    920778: {"Other_Default_Ignorable_Code_Point"},
    920779: {"Other_Default_Ignorable_Code_Point"},
    920780: {"Other_Default_Ignorable_Code_Point"},
    920781: {"Other_Default_Ignorable_Code_Point"},
    920782: {"Other_Default_Ignorable_Code_Point"},
    920783: {"Other_Default_Ignorable_Code_Point"},
    920784: {"Other_Default_Ignorable_Code_Point"},
    920785: {"Other_Default_Ignorable_Code_Point"},
    920786: {"Other_Default_Ignorable_Code_Point"},
    920787: {"Other_Default_Ignorable_Code_Point"},
    920788: {"Other_Default_Ignorable_Code_Point"},
    920789: {"Other_Default_Ignorable_Code_Point"},
    920790: {"Other_Default_Ignorable_Code_Point"},
    920791: {"Other_Default_Ignorable_Code_Point"},
    920792: {"Other_Default_Ignorable_Code_Point"},
    920793: {"Other_Default_Ignorable_Code_Point"},
    920794: {"Other_Default_Ignorable_Code_Point"},
    920795: {"Other_Default_Ignorable_Code_Point"},
    920796: {"Other_Default_Ignorable_Code_Point"},
    920797: {"Other_Default_Ignorable_Code_Point"},
    920798: {"Other_Default_Ignorable_Code_Point"},
    920799: {"Other_Default_Ignorable_Code_Point"},
    920800: {"Other_Default_Ignorable_Code_Point"},
    920801: {"Other_Default_Ignorable_Code_Point"},
    920802: {"Other_Default_Ignorable_Code_Point"},
    920803: {"Other_Default_Ignorable_Code_Point"},
    920804: {"Other_Default_Ignorable_Code_Point"},
    920805: {"Other_Default_Ignorable_Code_Point"},
    920806: {"Other_Default_Ignorable_Code_Point"},
    920807: {"Other_Default_Ignorable_Code_Point"},
    920808: {"Other_Default_Ignorable_Code_Point"},
    920809: {"Other_Default_Ignorable_Code_Point"},
    920810: {"Other_Default_Ignorable_Code_Point"},
    920811: {"Other_Default_Ignorable_Code_Point"},
    920812: {"Other_Default_Ignorable_Code_Point"},
    920813: {"Other_Default_Ignorable_Code_Point"},
    920814: {"Other_Default_Ignorable_Code_Point"},
    920815: {"Other_Default_Ignorable_Code_Point"},
    920816: {"Other_Default_Ignorable_Code_Point"},
    920817: {"Other_Default_Ignorable_Code_Point"},
    920818: {"Other_Default_Ignorable_Code_Point"},
    920819: {"Other_Default_Ignorable_Code_Point"},
    920820: {"Other_Default_Ignorable_Code_Point"},
    920821: {"Other_Default_Ignorable_Code_Point"},
    920822: {"Other_Default_Ignorable_Code_Point"},
    920823: {"Other_Default_Ignorable_Code_Point"},
    920824: {"Other_Default_Ignorable_Code_Point"},
    920825: {"Other_Default_Ignorable_Code_Point"},
    920826: {"Other_Default_Ignorable_Code_Point"},
    920827: {"Other_Default_Ignorable_Code_Point"},
    920828: {"Other_Default_Ignorable_Code_Point"},
    920829: {"Other_Default_Ignorable_Code_Point"},
    920830: {"Other_Default_Ignorable_Code_Point"},
    920831: {"Other_Default_Ignorable_Code_Point"},
    920832: {"Other_Default_Ignorable_Code_Point"},
    920833: {"Other_Default_Ignorable_Code_Point"},
    920834: {"Other_Default_Ignorable_Code_Point"},
    920835: {"Other_Default_Ignorable_Code_Point"},
    920836: {"Other_Default_Ignorable_Code_Point"},
    920837: {"Other_Default_Ignorable_Code_Point"},
    920838: {"Other_Default_Ignorable_Code_Point"},
    920839: {"Other_Default_Ignorable_Code_Point"},
    920840: {"Other_Default_Ignorable_Code_Point"},
    920841: {"Other_Default_Ignorable_Code_Point"},
    920842: {"Other_Default_Ignorable_Code_Point"},
    920843: {"Other_Default_Ignorable_Code_Point"},
    920844: {"Other_Default_Ignorable_Code_Point"},
    920845: {"Other_Default_Ignorable_Code_Point"},
    920846: {"Other_Default_Ignorable_Code_Point"},
    920847: {"Other_Default_Ignorable_Code_Point"},
    920848: {"Other_Default_Ignorable_Code_Point"},
    920849: {"Other_Default_Ignorable_Code_Point"},
    920850: {"Other_Default_Ignorable_Code_Point"},
    920851: {"Other_Default_Ignorable_Code_Point"},
    920852: {"Other_Default_Ignorable_Code_Point"},
    920853: {"Other_Default_Ignorable_Code_Point"},
    920854: {"Other_Default_Ignorable_Code_Point"},
    920855: {"Other_Default_Ignorable_Code_Point"},
    920856: {"Other_Default_Ignorable_Code_Point"},
    920857: {"Other_Default_Ignorable_Code_Point"},
    920858: {"Other_Default_Ignorable_Code_Point"},
    920859: {"Other_Default_Ignorable_Code_Point"},
    920860: {"Other_Default_Ignorable_Code_Point"},
    920861: {"Other_Default_Ignorable_Code_Point"},
    920862: {"Other_Default_Ignorable_Code_Point"},
    920863: {"Other_Default_Ignorable_Code_Point"},
    920864: {"Other_Default_Ignorable_Code_Point"},
    920865: {"Other_Default_Ignorable_Code_Point"},
    920866: {"Other_Default_Ignorable_Code_Point"},
    920867: {"Other_Default_Ignorable_Code_Point"},
    920868: {"Other_Default_Ignorable_Code_Point"},
    920869: {"Other_Default_Ignorable_Code_Point"},
    920870: {"Other_Default_Ignorable_Code_Point"},
    920871: {"Other_Default_Ignorable_Code_Point"},
    920872: {"Other_Default_Ignorable_Code_Point"},
    920873: {"Other_Default_Ignorable_Code_Point"},
    920874: {"Other_Default_Ignorable_Code_Point"},
    920875: {"Other_Default_Ignorable_Code_Point"},
    920876: {"Other_Default_Ignorable_Code_Point"},
    920877: {"Other_Default_Ignorable_Code_Point"},
    920878: {"Other_Default_Ignorable_Code_Point"},
    920879: {"Other_Default_Ignorable_Code_Point"},
    920880: {"Other_Default_Ignorable_Code_Point"},
    920881: {"Other_Default_Ignorable_Code_Point"},
    920882: {"Other_Default_Ignorable_Code_Point"},
    920883: {"Other_Default_Ignorable_Code_Point"},
    920884: {"Other_Default_Ignorable_Code_Point"},
    920885: {"Other_Default_Ignorable_Code_Point"},
    920886: {"Other_Default_Ignorable_Code_Point"},
    920887: {"Other_Default_Ignorable_Code_Point"},
    920888: {"Other_Default_Ignorable_Code_Point"},
    920889: {"Other_Default_Ignorable_Code_Point"},
    920890: {"Other_Default_Ignorable_Code_Point"},
    920891: {"Other_Default_Ignorable_Code_Point"},
    920892: {"Other_Default_Ignorable_Code_Point"},
    920893: {"Other_Default_Ignorable_Code_Point"},
    920894: {"Other_Default_Ignorable_Code_Point"},
    920895: {"Other_Default_Ignorable_Code_Point"},
    920896: {"Other_Default_Ignorable_Code_Point"},
    920897: {"Other_Default_Ignorable_Code_Point"},
    920898: {"Other_Default_Ignorable_Code_Point"},
    920899: {"Other_Default_Ignorable_Code_Point"},
    920900: {"Other_Default_Ignorable_Code_Point"},
    920901: {"Other_Default_Ignorable_Code_Point"},
    920902: {"Other_Default_Ignorable_Code_Point"},
    920903: {"Other_Default_Ignorable_Code_Point"},
    920904: {"Other_Default_Ignorable_Code_Point"},
    920905: {"Other_Default_Ignorable_Code_Point"},
    920906: {"Other_Default_Ignorable_Code_Point"},
    920907: {"Other_Default_Ignorable_Code_Point"},
    920908: {"Other_Default_Ignorable_Code_Point"},
    920909: {"Other_Default_Ignorable_Code_Point"},
    920910: {"Other_Default_Ignorable_Code_Point"},
    920911: {"Other_Default_Ignorable_Code_Point"},
    920912: {"Other_Default_Ignorable_Code_Point"},
    920913: {"Other_Default_Ignorable_Code_Point"},
    920914: {"Other_Default_Ignorable_Code_Point"},
    920915: {"Other_Default_Ignorable_Code_Point"},
    920916: {"Other_Default_Ignorable_Code_Point"},
    920917: {"Other_Default_Ignorable_Code_Point"},
    920918: {"Other_Default_Ignorable_Code_Point"},
    920919: {"Other_Default_Ignorable_Code_Point"},
    920920: {"Other_Default_Ignorable_Code_Point"},
    920921: {"Other_Default_Ignorable_Code_Point"},
    920922: {"Other_Default_Ignorable_Code_Point"},
    920923: {"Other_Default_Ignorable_Code_Point"},
    920924: {"Other_Default_Ignorable_Code_Point"},
    920925: {"Other_Default_Ignorable_Code_Point"},
    920926: {"Other_Default_Ignorable_Code_Point"},
    920927: {"Other_Default_Ignorable_Code_Point"},
    920928: {"Other_Default_Ignorable_Code_Point"},
    920929: {"Other_Default_Ignorable_Code_Point"},
    920930: {"Other_Default_Ignorable_Code_Point"},
    920931: {"Other_Default_Ignorable_Code_Point"},
    920932: {"Other_Default_Ignorable_Code_Point"},
    920933: {"Other_Default_Ignorable_Code_Point"},
    920934: {"Other_Default_Ignorable_Code_Point"},
    920935: {"Other_Default_Ignorable_Code_Point"},
    920936: {"Other_Default_Ignorable_Code_Point"},
    920937: {"Other_Default_Ignorable_Code_Point"},
    920938: {"Other_Default_Ignorable_Code_Point"},
    920939: {"Other_Default_Ignorable_Code_Point"},
    920940: {"Other_Default_Ignorable_Code_Point"},
    920941: {"Other_Default_Ignorable_Code_Point"},
    920942: {"Other_Default_Ignorable_Code_Point"},
    920943: {"Other_Default_Ignorable_Code_Point"},
    920944: {"Other_Default_Ignorable_Code_Point"},
    920945: {"Other_Default_Ignorable_Code_Point"},
    920946: {"Other_Default_Ignorable_Code_Point"},
    920947: {"Other_Default_Ignorable_Code_Point"},
    920948: {"Other_Default_Ignorable_Code_Point"},
    920949: {"Other_Default_Ignorable_Code_Point"},
    920950: {"Other_Default_Ignorable_Code_Point"},
    920951: {"Other_Default_Ignorable_Code_Point"},
    920952: {"Other_Default_Ignorable_Code_Point"},
    920953: {"Other_Default_Ignorable_Code_Point"},
    920954: {"Other_Default_Ignorable_Code_Point"},
    920955: {"Other_Default_Ignorable_Code_Point"},
    920956: {"Other_Default_Ignorable_Code_Point"},
    920957: {"Other_Default_Ignorable_Code_Point"},
    920958: {"Other_Default_Ignorable_Code_Point"},
    920959: {"Other_Default_Ignorable_Code_Point"},
    920960: {"Other_Default_Ignorable_Code_Point"},
    920961: {"Other_Default_Ignorable_Code_Point"},
    920962: {"Other_Default_Ignorable_Code_Point"},
    920963: {"Other_Default_Ignorable_Code_Point"},
    920964: {"Other_Default_Ignorable_Code_Point"},
    920965: {"Other_Default_Ignorable_Code_Point"},
    920966: {"Other_Default_Ignorable_Code_Point"},
    920967: {"Other_Default_Ignorable_Code_Point"},
    920968: {"Other_Default_Ignorable_Code_Point"},
    920969: {"Other_Default_Ignorable_Code_Point"},
    920970: {"Other_Default_Ignorable_Code_Point"},
    920971: {"Other_Default_Ignorable_Code_Point"},
    920972: {"Other_Default_Ignorable_Code_Point"},
    920973: {"Other_Default_Ignorable_Code_Point"},
    920974: {"Other_Default_Ignorable_Code_Point"},
    920975: {"Other_Default_Ignorable_Code_Point"},
    920976: {"Other_Default_Ignorable_Code_Point"},
    920977: {"Other_Default_Ignorable_Code_Point"},
    920978: {"Other_Default_Ignorable_Code_Point"},
    920979: {"Other_Default_Ignorable_Code_Point"},
    920980: {"Other_Default_Ignorable_Code_Point"},
    920981: {"Other_Default_Ignorable_Code_Point"},
    920982: {"Other_Default_Ignorable_Code_Point"},
    920983: {"Other_Default_Ignorable_Code_Point"},
    920984: {"Other_Default_Ignorable_Code_Point"},
    920985: {"Other_Default_Ignorable_Code_Point"},
    920986: {"Other_Default_Ignorable_Code_Point"},
    920987: {"Other_Default_Ignorable_Code_Point"},
    920988: {"Other_Default_Ignorable_Code_Point"},
    920989: {"Other_Default_Ignorable_Code_Point"},
    920990: {"Other_Default_Ignorable_Code_Point"},
    920991: {"Other_Default_Ignorable_Code_Point"},
    920992: {"Other_Default_Ignorable_Code_Point"},
    920993: {"Other_Default_Ignorable_Code_Point"},
    920994: {"Other_Default_Ignorable_Code_Point"},
    920995: {"Other_Default_Ignorable_Code_Point"},
    920996: {"Other_Default_Ignorable_Code_Point"},
    920997: {"Other_Default_Ignorable_Code_Point"},
    920998: {"Other_Default_Ignorable_Code_Point"},
    920999: {"Other_Default_Ignorable_Code_Point"},
    921000: {"Other_Default_Ignorable_Code_Point"},
    921001: {"Other_Default_Ignorable_Code_Point"},
    921002: {"Other_Default_Ignorable_Code_Point"},
    921003: {"Other_Default_Ignorable_Code_Point"},
    921004: {"Other_Default_Ignorable_Code_Point"},
    921005: {"Other_Default_Ignorable_Code_Point"},
    921006: {"Other_Default_Ignorable_Code_Point"},
    921007: {"Other_Default_Ignorable_Code_Point"},
    921008: {"Other_Default_Ignorable_Code_Point"},
    921009: {"Other_Default_Ignorable_Code_Point"},
    921010: {"Other_Default_Ignorable_Code_Point"},
    921011: {"Other_Default_Ignorable_Code_Point"},
    921012: {"Other_Default_Ignorable_Code_Point"},
    921013: {"Other_Default_Ignorable_Code_Point"},
    921014: {"Other_Default_Ignorable_Code_Point"},
    921015: {"Other_Default_Ignorable_Code_Point"},
    921016: {"Other_Default_Ignorable_Code_Point"},
    921017: {"Other_Default_Ignorable_Code_Point"},
    921018: {"Other_Default_Ignorable_Code_Point"},
    921019: {"Other_Default_Ignorable_Code_Point"},
    921020: {"Other_Default_Ignorable_Code_Point"},
    921021: {"Other_Default_Ignorable_Code_Point"},
    921022: {"Other_Default_Ignorable_Code_Point"},
    921023: {"Other_Default_Ignorable_Code_Point"},
    921024: {"Other_Default_Ignorable_Code_Point"},
    921025: {"Other_Default_Ignorable_Code_Point"},
    921026: {"Other_Default_Ignorable_Code_Point"},
    921027: {"Other_Default_Ignorable_Code_Point"},
    921028: {"Other_Default_Ignorable_Code_Point"},
    921029: {"Other_Default_Ignorable_Code_Point"},
    921030: {"Other_Default_Ignorable_Code_Point"},
    921031: {"Other_Default_Ignorable_Code_Point"},
    921032: {"Other_Default_Ignorable_Code_Point"},
    921033: {"Other_Default_Ignorable_Code_Point"},
    921034: {"Other_Default_Ignorable_Code_Point"},
    921035: {"Other_Default_Ignorable_Code_Point"},
    921036: {"Other_Default_Ignorable_Code_Point"},
    921037: {"Other_Default_Ignorable_Code_Point"},
    921038: {"Other_Default_Ignorable_Code_Point"},
    921039: {"Other_Default_Ignorable_Code_Point"},
    921040: {"Other_Default_Ignorable_Code_Point"},
    921041: {"Other_Default_Ignorable_Code_Point"},
    921042: {"Other_Default_Ignorable_Code_Point"},
    921043: {"Other_Default_Ignorable_Code_Point"},
    921044: {"Other_Default_Ignorable_Code_Point"},
    921045: {"Other_Default_Ignorable_Code_Point"},
    921046: {"Other_Default_Ignorable_Code_Point"},
    921047: {"Other_Default_Ignorable_Code_Point"},
    921048: {"Other_Default_Ignorable_Code_Point"},
    921049: {"Other_Default_Ignorable_Code_Point"},
    921050: {"Other_Default_Ignorable_Code_Point"},
    921051: {"Other_Default_Ignorable_Code_Point"},
    921052: {"Other_Default_Ignorable_Code_Point"},
    921053: {"Other_Default_Ignorable_Code_Point"},
    921054: {"Other_Default_Ignorable_Code_Point"},
    921055: {"Other_Default_Ignorable_Code_Point"},
    921056: {"Other_Default_Ignorable_Code_Point"},
    921057: {"Other_Default_Ignorable_Code_Point"},
    921058: {"Other_Default_Ignorable_Code_Point"},
    921059: {"Other_Default_Ignorable_Code_Point"},
    921060: {"Other_Default_Ignorable_Code_Point"},
    921061: {"Other_Default_Ignorable_Code_Point"},
    921062: {"Other_Default_Ignorable_Code_Point"},
    921063: {"Other_Default_Ignorable_Code_Point"},
    921064: {"Other_Default_Ignorable_Code_Point"},
    921065: {"Other_Default_Ignorable_Code_Point"},
    921066: {"Other_Default_Ignorable_Code_Point"},
    921067: {"Other_Default_Ignorable_Code_Point"},
    921068: {"Other_Default_Ignorable_Code_Point"},
    921069: {"Other_Default_Ignorable_Code_Point"},
    921070: {"Other_Default_Ignorable_Code_Point"},
    921071: {"Other_Default_Ignorable_Code_Point"},
    921072: {"Other_Default_Ignorable_Code_Point"},
    921073: {"Other_Default_Ignorable_Code_Point"},
    921074: {"Other_Default_Ignorable_Code_Point"},
    921075: {"Other_Default_Ignorable_Code_Point"},
    921076: {"Other_Default_Ignorable_Code_Point"},
    921077: {"Other_Default_Ignorable_Code_Point"},
    921078: {"Other_Default_Ignorable_Code_Point"},
    921079: {"Other_Default_Ignorable_Code_Point"},
    921080: {"Other_Default_Ignorable_Code_Point"},
    921081: {"Other_Default_Ignorable_Code_Point"},
    921082: {"Other_Default_Ignorable_Code_Point"},
    921083: {"Other_Default_Ignorable_Code_Point"},
    921084: {"Other_Default_Ignorable_Code_Point"},
    921085: {"Other_Default_Ignorable_Code_Point"},
    921086: {"Other_Default_Ignorable_Code_Point"},
    921087: {"Other_Default_Ignorable_Code_Point"},
    921088: {"Other_Default_Ignorable_Code_Point"},
    921089: {"Other_Default_Ignorable_Code_Point"},
    921090: {"Other_Default_Ignorable_Code_Point"},
    921091: {"Other_Default_Ignorable_Code_Point"},
    921092: {"Other_Default_Ignorable_Code_Point"},
    921093: {"Other_Default_Ignorable_Code_Point"},
    921094: {"Other_Default_Ignorable_Code_Point"},
    921095: {"Other_Default_Ignorable_Code_Point"},
    921096: {"Other_Default_Ignorable_Code_Point"},
    921097: {"Other_Default_Ignorable_Code_Point"},
    921098: {"Other_Default_Ignorable_Code_Point"},
    921099: {"Other_Default_Ignorable_Code_Point"},
    921100: {"Other_Default_Ignorable_Code_Point"},
    921101: {"Other_Default_Ignorable_Code_Point"},
    921102: {"Other_Default_Ignorable_Code_Point"},
    921103: {"Other_Default_Ignorable_Code_Point"},
    921104: {"Other_Default_Ignorable_Code_Point"},
    921105: {"Other_Default_Ignorable_Code_Point"},
    921106: {"Other_Default_Ignorable_Code_Point"},
    921107: {"Other_Default_Ignorable_Code_Point"},
    921108: {"Other_Default_Ignorable_Code_Point"},
    921109: {"Other_Default_Ignorable_Code_Point"},
    921110: {"Other_Default_Ignorable_Code_Point"},
    921111: {"Other_Default_Ignorable_Code_Point"},
    921112: {"Other_Default_Ignorable_Code_Point"},
    921113: {"Other_Default_Ignorable_Code_Point"},
    921114: {"Other_Default_Ignorable_Code_Point"},
    921115: {"Other_Default_Ignorable_Code_Point"},
    921116: {"Other_Default_Ignorable_Code_Point"},
    921117: {"Other_Default_Ignorable_Code_Point"},
    921118: {"Other_Default_Ignorable_Code_Point"},
    921119: {"Other_Default_Ignorable_Code_Point"},
    921120: {"Other_Default_Ignorable_Code_Point"},
    921121: {"Other_Default_Ignorable_Code_Point"},
    921122: {"Other_Default_Ignorable_Code_Point"},
    921123: {"Other_Default_Ignorable_Code_Point"},
    921124: {"Other_Default_Ignorable_Code_Point"},
    921125: {"Other_Default_Ignorable_Code_Point"},
    921126: {"Other_Default_Ignorable_Code_Point"},
    921127: {"Other_Default_Ignorable_Code_Point"},
    921128: {"Other_Default_Ignorable_Code_Point"},
    921129: {"Other_Default_Ignorable_Code_Point"},
    921130: {"Other_Default_Ignorable_Code_Point"},
    921131: {"Other_Default_Ignorable_Code_Point"},
    921132: {"Other_Default_Ignorable_Code_Point"},
    921133: {"Other_Default_Ignorable_Code_Point"},
    921134: {"Other_Default_Ignorable_Code_Point"},
    921135: {"Other_Default_Ignorable_Code_Point"},
    921136: {"Other_Default_Ignorable_Code_Point"},
    921137: {"Other_Default_Ignorable_Code_Point"},
    921138: {"Other_Default_Ignorable_Code_Point"},
    921139: {"Other_Default_Ignorable_Code_Point"},
    921140: {"Other_Default_Ignorable_Code_Point"},
    921141: {"Other_Default_Ignorable_Code_Point"},
    921142: {"Other_Default_Ignorable_Code_Point"},
    921143: {"Other_Default_Ignorable_Code_Point"},
    921144: {"Other_Default_Ignorable_Code_Point"},
    921145: {"Other_Default_Ignorable_Code_Point"},
    921146: {"Other_Default_Ignorable_Code_Point"},
    921147: {"Other_Default_Ignorable_Code_Point"},
    921148: {"Other_Default_Ignorable_Code_Point"},
    921149: {"Other_Default_Ignorable_Code_Point"},
    921150: {"Other_Default_Ignorable_Code_Point"},
    921151: {"Other_Default_Ignorable_Code_Point"},
    921152: {"Other_Default_Ignorable_Code_Point"},
    921153: {"Other_Default_Ignorable_Code_Point"},
    921154: {"Other_Default_Ignorable_Code_Point"},
    921155: {"Other_Default_Ignorable_Code_Point"},
    921156: {"Other_Default_Ignorable_Code_Point"},
    921157: {"Other_Default_Ignorable_Code_Point"},
    921158: {"Other_Default_Ignorable_Code_Point"},
    921159: {"Other_Default_Ignorable_Code_Point"},
    921160: {"Other_Default_Ignorable_Code_Point"},
    921161: {"Other_Default_Ignorable_Code_Point"},
    921162: {"Other_Default_Ignorable_Code_Point"},
    921163: {"Other_Default_Ignorable_Code_Point"},
    921164: {"Other_Default_Ignorable_Code_Point"},
    921165: {"Other_Default_Ignorable_Code_Point"},
    921166: {"Other_Default_Ignorable_Code_Point"},
    921167: {"Other_Default_Ignorable_Code_Point"},
    921168: {"Other_Default_Ignorable_Code_Point"},
    921169: {"Other_Default_Ignorable_Code_Point"},
    921170: {"Other_Default_Ignorable_Code_Point"},
    921171: {"Other_Default_Ignorable_Code_Point"},
    921172: {"Other_Default_Ignorable_Code_Point"},
    921173: {"Other_Default_Ignorable_Code_Point"},
    921174: {"Other_Default_Ignorable_Code_Point"},
    921175: {"Other_Default_Ignorable_Code_Point"},
    921176: {"Other_Default_Ignorable_Code_Point"},
    921177: {"Other_Default_Ignorable_Code_Point"},
    921178: {"Other_Default_Ignorable_Code_Point"},
    921179: {"Other_Default_Ignorable_Code_Point"},
    921180: {"Other_Default_Ignorable_Code_Point"},
    921181: {"Other_Default_Ignorable_Code_Point"},
    921182: {"Other_Default_Ignorable_Code_Point"},
    921183: {"Other_Default_Ignorable_Code_Point"},
    921184: {"Other_Default_Ignorable_Code_Point"},
    921185: {"Other_Default_Ignorable_Code_Point"},
    921186: {"Other_Default_Ignorable_Code_Point"},
    921187: {"Other_Default_Ignorable_Code_Point"},
    921188: {"Other_Default_Ignorable_Code_Point"},
    921189: {"Other_Default_Ignorable_Code_Point"},
    921190: {"Other_Default_Ignorable_Code_Point"},
    921191: {"Other_Default_Ignorable_Code_Point"},
    921192: {"Other_Default_Ignorable_Code_Point"},
    921193: {"Other_Default_Ignorable_Code_Point"},
    921194: {"Other_Default_Ignorable_Code_Point"},
    921195: {"Other_Default_Ignorable_Code_Point"},
    921196: {"Other_Default_Ignorable_Code_Point"},
    921197: {"Other_Default_Ignorable_Code_Point"},
    921198: {"Other_Default_Ignorable_Code_Point"},
    921199: {"Other_Default_Ignorable_Code_Point"},
    921200: {"Other_Default_Ignorable_Code_Point"},
    921201: {"Other_Default_Ignorable_Code_Point"},
    921202: {"Other_Default_Ignorable_Code_Point"},
    921203: {"Other_Default_Ignorable_Code_Point"},
    921204: {"Other_Default_Ignorable_Code_Point"},
    921205: {"Other_Default_Ignorable_Code_Point"},
    921206: {"Other_Default_Ignorable_Code_Point"},
    921207: {"Other_Default_Ignorable_Code_Point"},
    921208: {"Other_Default_Ignorable_Code_Point"},
    921209: {"Other_Default_Ignorable_Code_Point"},
    921210: {"Other_Default_Ignorable_Code_Point"},
    921211: {"Other_Default_Ignorable_Code_Point"},
    921212: {"Other_Default_Ignorable_Code_Point"},
    921213: {"Other_Default_Ignorable_Code_Point"},
    921214: {"Other_Default_Ignorable_Code_Point"},
    921215: {"Other_Default_Ignorable_Code_Point"},
    921216: {"Other_Default_Ignorable_Code_Point"},
    921217: {"Other_Default_Ignorable_Code_Point"},
    921218: {"Other_Default_Ignorable_Code_Point"},
    921219: {"Other_Default_Ignorable_Code_Point"},
    921220: {"Other_Default_Ignorable_Code_Point"},
    921221: {"Other_Default_Ignorable_Code_Point"},
    921222: {"Other_Default_Ignorable_Code_Point"},
    921223: {"Other_Default_Ignorable_Code_Point"},
    921224: {"Other_Default_Ignorable_Code_Point"},
    921225: {"Other_Default_Ignorable_Code_Point"},
    921226: {"Other_Default_Ignorable_Code_Point"},
    921227: {"Other_Default_Ignorable_Code_Point"},
    921228: {"Other_Default_Ignorable_Code_Point"},
    921229: {"Other_Default_Ignorable_Code_Point"},
    921230: {"Other_Default_Ignorable_Code_Point"},
    921231: {"Other_Default_Ignorable_Code_Point"},
    921232: {"Other_Default_Ignorable_Code_Point"},
    921233: {"Other_Default_Ignorable_Code_Point"},
    921234: {"Other_Default_Ignorable_Code_Point"},
    921235: {"Other_Default_Ignorable_Code_Point"},
    921236: {"Other_Default_Ignorable_Code_Point"},
    921237: {"Other_Default_Ignorable_Code_Point"},
    921238: {"Other_Default_Ignorable_Code_Point"},
    921239: {"Other_Default_Ignorable_Code_Point"},
    921240: {"Other_Default_Ignorable_Code_Point"},
    921241: {"Other_Default_Ignorable_Code_Point"},
    921242: {"Other_Default_Ignorable_Code_Point"},
    921243: {"Other_Default_Ignorable_Code_Point"},
    921244: {"Other_Default_Ignorable_Code_Point"},
    921245: {"Other_Default_Ignorable_Code_Point"},
    921246: {"Other_Default_Ignorable_Code_Point"},
    921247: {"Other_Default_Ignorable_Code_Point"},
    921248: {"Other_Default_Ignorable_Code_Point"},
    921249: {"Other_Default_Ignorable_Code_Point"},
    921250: {"Other_Default_Ignorable_Code_Point"},
    921251: {"Other_Default_Ignorable_Code_Point"},
    921252: {"Other_Default_Ignorable_Code_Point"},
    921253: {"Other_Default_Ignorable_Code_Point"},
    921254: {"Other_Default_Ignorable_Code_Point"},
    921255: {"Other_Default_Ignorable_Code_Point"},
    921256: {"Other_Default_Ignorable_Code_Point"},
    921257: {"Other_Default_Ignorable_Code_Point"},
    921258: {"Other_Default_Ignorable_Code_Point"},
    921259: {"Other_Default_Ignorable_Code_Point"},
    921260: {"Other_Default_Ignorable_Code_Point"},
    921261: {"Other_Default_Ignorable_Code_Point"},
    921262: {"Other_Default_Ignorable_Code_Point"},
    921263: {"Other_Default_Ignorable_Code_Point"},
    921264: {"Other_Default_Ignorable_Code_Point"},
    921265: {"Other_Default_Ignorable_Code_Point"},
    921266: {"Other_Default_Ignorable_Code_Point"},
    921267: {"Other_Default_Ignorable_Code_Point"},
    921268: {"Other_Default_Ignorable_Code_Point"},
    921269: {"Other_Default_Ignorable_Code_Point"},
    921270: {"Other_Default_Ignorable_Code_Point"},
    921271: {"Other_Default_Ignorable_Code_Point"},
    921272: {"Other_Default_Ignorable_Code_Point"},
    921273: {"Other_Default_Ignorable_Code_Point"},
    921274: {"Other_Default_Ignorable_Code_Point"},
    921275: {"Other_Default_Ignorable_Code_Point"},
    921276: {"Other_Default_Ignorable_Code_Point"},
    921277: {"Other_Default_Ignorable_Code_Point"},
    921278: {"Other_Default_Ignorable_Code_Point"},
    921279: {"Other_Default_Ignorable_Code_Point"},
    921280: {"Other_Default_Ignorable_Code_Point"},
    921281: {"Other_Default_Ignorable_Code_Point"},
    921282: {"Other_Default_Ignorable_Code_Point"},
    921283: {"Other_Default_Ignorable_Code_Point"},
    921284: {"Other_Default_Ignorable_Code_Point"},
    921285: {"Other_Default_Ignorable_Code_Point"},
    921286: {"Other_Default_Ignorable_Code_Point"},
    921287: {"Other_Default_Ignorable_Code_Point"},
    921288: {"Other_Default_Ignorable_Code_Point"},
    921289: {"Other_Default_Ignorable_Code_Point"},
    921290: {"Other_Default_Ignorable_Code_Point"},
    921291: {"Other_Default_Ignorable_Code_Point"},
    921292: {"Other_Default_Ignorable_Code_Point"},
    921293: {"Other_Default_Ignorable_Code_Point"},
    921294: {"Other_Default_Ignorable_Code_Point"},
    921295: {"Other_Default_Ignorable_Code_Point"},
    921296: {"Other_Default_Ignorable_Code_Point"},
    921297: {"Other_Default_Ignorable_Code_Point"},
    921298: {"Other_Default_Ignorable_Code_Point"},
    921299: {"Other_Default_Ignorable_Code_Point"},
    921300: {"Other_Default_Ignorable_Code_Point"},
    921301: {"Other_Default_Ignorable_Code_Point"},
    921302: {"Other_Default_Ignorable_Code_Point"},
    921303: {"Other_Default_Ignorable_Code_Point"},
    921304: {"Other_Default_Ignorable_Code_Point"},
    921305: {"Other_Default_Ignorable_Code_Point"},
    921306: {"Other_Default_Ignorable_Code_Point"},
    921307: {"Other_Default_Ignorable_Code_Point"},
    921308: {"Other_Default_Ignorable_Code_Point"},
    921309: {"Other_Default_Ignorable_Code_Point"},
    921310: {"Other_Default_Ignorable_Code_Point"},
    921311: {"Other_Default_Ignorable_Code_Point"},
    921312: {"Other_Default_Ignorable_Code_Point"},
    921313: {"Other_Default_Ignorable_Code_Point"},
    921314: {"Other_Default_Ignorable_Code_Point"},
    921315: {"Other_Default_Ignorable_Code_Point"},
    921316: {"Other_Default_Ignorable_Code_Point"},
    921317: {"Other_Default_Ignorable_Code_Point"},
    921318: {"Other_Default_Ignorable_Code_Point"},
    921319: {"Other_Default_Ignorable_Code_Point"},
    921320: {"Other_Default_Ignorable_Code_Point"},
    921321: {"Other_Default_Ignorable_Code_Point"},
    921322: {"Other_Default_Ignorable_Code_Point"},
    921323: {"Other_Default_Ignorable_Code_Point"},
    921324: {"Other_Default_Ignorable_Code_Point"},
    921325: {"Other_Default_Ignorable_Code_Point"},
    921326: {"Other_Default_Ignorable_Code_Point"},
    921327: {"Other_Default_Ignorable_Code_Point"},
    921328: {"Other_Default_Ignorable_Code_Point"},
    921329: {"Other_Default_Ignorable_Code_Point"},
    921330: {"Other_Default_Ignorable_Code_Point"},
    921331: {"Other_Default_Ignorable_Code_Point"},
    921332: {"Other_Default_Ignorable_Code_Point"},
    921333: {"Other_Default_Ignorable_Code_Point"},
    921334: {"Other_Default_Ignorable_Code_Point"},
    921335: {"Other_Default_Ignorable_Code_Point"},
    921336: {"Other_Default_Ignorable_Code_Point"},
    921337: {"Other_Default_Ignorable_Code_Point"},
    921338: {"Other_Default_Ignorable_Code_Point"},
    921339: {"Other_Default_Ignorable_Code_Point"},
    921340: {"Other_Default_Ignorable_Code_Point"},
    921341: {"Other_Default_Ignorable_Code_Point"},
    921342: {"Other_Default_Ignorable_Code_Point"},
    921343: {"Other_Default_Ignorable_Code_Point"},
    921344: {"Other_Default_Ignorable_Code_Point"},
    921345: {"Other_Default_Ignorable_Code_Point"},
    921346: {"Other_Default_Ignorable_Code_Point"},
    921347: {"Other_Default_Ignorable_Code_Point"},
    921348: {"Other_Default_Ignorable_Code_Point"},
    921349: {"Other_Default_Ignorable_Code_Point"},
    921350: {"Other_Default_Ignorable_Code_Point"},
    921351: {"Other_Default_Ignorable_Code_Point"},
    921352: {"Other_Default_Ignorable_Code_Point"},
    921353: {"Other_Default_Ignorable_Code_Point"},
    921354: {"Other_Default_Ignorable_Code_Point"},
    921355: {"Other_Default_Ignorable_Code_Point"},
    921356: {"Other_Default_Ignorable_Code_Point"},
    921357: {"Other_Default_Ignorable_Code_Point"},
    921358: {"Other_Default_Ignorable_Code_Point"},
    921359: {"Other_Default_Ignorable_Code_Point"},
    921360: {"Other_Default_Ignorable_Code_Point"},
    921361: {"Other_Default_Ignorable_Code_Point"},
    921362: {"Other_Default_Ignorable_Code_Point"},
    921363: {"Other_Default_Ignorable_Code_Point"},
    921364: {"Other_Default_Ignorable_Code_Point"},
    921365: {"Other_Default_Ignorable_Code_Point"},
    921366: {"Other_Default_Ignorable_Code_Point"},
    921367: {"Other_Default_Ignorable_Code_Point"},
    921368: {"Other_Default_Ignorable_Code_Point"},
    921369: {"Other_Default_Ignorable_Code_Point"},
    921370: {"Other_Default_Ignorable_Code_Point"},
    921371: {"Other_Default_Ignorable_Code_Point"},
    921372: {"Other_Default_Ignorable_Code_Point"},
    921373: {"Other_Default_Ignorable_Code_Point"},
    921374: {"Other_Default_Ignorable_Code_Point"},
    921375: {"Other_Default_Ignorable_Code_Point"},
    921376: {"Other_Default_Ignorable_Code_Point"},
    921377: {"Other_Default_Ignorable_Code_Point"},
    921378: {"Other_Default_Ignorable_Code_Point"},
    921379: {"Other_Default_Ignorable_Code_Point"},
    921380: {"Other_Default_Ignorable_Code_Point"},
    921381: {"Other_Default_Ignorable_Code_Point"},
    921382: {"Other_Default_Ignorable_Code_Point"},
    921383: {"Other_Default_Ignorable_Code_Point"},
    921384: {"Other_Default_Ignorable_Code_Point"},
    921385: {"Other_Default_Ignorable_Code_Point"},
    921386: {"Other_Default_Ignorable_Code_Point"},
    921387: {"Other_Default_Ignorable_Code_Point"},
    921388: {"Other_Default_Ignorable_Code_Point"},
    921389: {"Other_Default_Ignorable_Code_Point"},
    921390: {"Other_Default_Ignorable_Code_Point"},
    921391: {"Other_Default_Ignorable_Code_Point"},
    921392: {"Other_Default_Ignorable_Code_Point"},
    921393: {"Other_Default_Ignorable_Code_Point"},
    921394: {"Other_Default_Ignorable_Code_Point"},
    921395: {"Other_Default_Ignorable_Code_Point"},
    921396: {"Other_Default_Ignorable_Code_Point"},
    921397: {"Other_Default_Ignorable_Code_Point"},
    921398: {"Other_Default_Ignorable_Code_Point"},
    921399: {"Other_Default_Ignorable_Code_Point"},
    921400: {"Other_Default_Ignorable_Code_Point"},
    921401: {"Other_Default_Ignorable_Code_Point"},
    921402: {"Other_Default_Ignorable_Code_Point"},
    921403: {"Other_Default_Ignorable_Code_Point"},
    921404: {"Other_Default_Ignorable_Code_Point"},
    921405: {"Other_Default_Ignorable_Code_Point"},
    921406: {"Other_Default_Ignorable_Code_Point"},
    921407: {"Other_Default_Ignorable_Code_Point"},
    921408: {"Other_Default_Ignorable_Code_Point"},
    921409: {"Other_Default_Ignorable_Code_Point"},
    921410: {"Other_Default_Ignorable_Code_Point"},
    921411: {"Other_Default_Ignorable_Code_Point"},
    921412: {"Other_Default_Ignorable_Code_Point"},
    921413: {"Other_Default_Ignorable_Code_Point"},
    921414: {"Other_Default_Ignorable_Code_Point"},
    921415: {"Other_Default_Ignorable_Code_Point"},
    921416: {"Other_Default_Ignorable_Code_Point"},
    921417: {"Other_Default_Ignorable_Code_Point"},
    921418: {"Other_Default_Ignorable_Code_Point"},
    921419: {"Other_Default_Ignorable_Code_Point"},
    921420: {"Other_Default_Ignorable_Code_Point"},
    921421: {"Other_Default_Ignorable_Code_Point"},
    921422: {"Other_Default_Ignorable_Code_Point"},
    921423: {"Other_Default_Ignorable_Code_Point"},
    921424: {"Other_Default_Ignorable_Code_Point"},
    921425: {"Other_Default_Ignorable_Code_Point"},
    921426: {"Other_Default_Ignorable_Code_Point"},
    921427: {"Other_Default_Ignorable_Code_Point"},
    921428: {"Other_Default_Ignorable_Code_Point"},
    921429: {"Other_Default_Ignorable_Code_Point"},
    921430: {"Other_Default_Ignorable_Code_Point"},
    921431: {"Other_Default_Ignorable_Code_Point"},
    921432: {"Other_Default_Ignorable_Code_Point"},
    921433: {"Other_Default_Ignorable_Code_Point"},
    921434: {"Other_Default_Ignorable_Code_Point"},
    921435: {"Other_Default_Ignorable_Code_Point"},
    921436: {"Other_Default_Ignorable_Code_Point"},
    921437: {"Other_Default_Ignorable_Code_Point"},
    921438: {"Other_Default_Ignorable_Code_Point"},
    921439: {"Other_Default_Ignorable_Code_Point"},
    921440: {"Other_Default_Ignorable_Code_Point"},
    921441: {"Other_Default_Ignorable_Code_Point"},
    921442: {"Other_Default_Ignorable_Code_Point"},
    921443: {"Other_Default_Ignorable_Code_Point"},
    921444: {"Other_Default_Ignorable_Code_Point"},
    921445: {"Other_Default_Ignorable_Code_Point"},
    921446: {"Other_Default_Ignorable_Code_Point"},
    921447: {"Other_Default_Ignorable_Code_Point"},
    921448: {"Other_Default_Ignorable_Code_Point"},
    921449: {"Other_Default_Ignorable_Code_Point"},
    921450: {"Other_Default_Ignorable_Code_Point"},
    921451: {"Other_Default_Ignorable_Code_Point"},
    921452: {"Other_Default_Ignorable_Code_Point"},
    921453: {"Other_Default_Ignorable_Code_Point"},
    921454: {"Other_Default_Ignorable_Code_Point"},
    921455: {"Other_Default_Ignorable_Code_Point"},
    921456: {"Other_Default_Ignorable_Code_Point"},
    921457: {"Other_Default_Ignorable_Code_Point"},
    921458: {"Other_Default_Ignorable_Code_Point"},
    921459: {"Other_Default_Ignorable_Code_Point"},
    921460: {"Other_Default_Ignorable_Code_Point"},
    921461: {"Other_Default_Ignorable_Code_Point"},
    921462: {"Other_Default_Ignorable_Code_Point"},
    921463: {"Other_Default_Ignorable_Code_Point"},
    921464: {"Other_Default_Ignorable_Code_Point"},
    921465: {"Other_Default_Ignorable_Code_Point"},
    921466: {"Other_Default_Ignorable_Code_Point"},
    921467: {"Other_Default_Ignorable_Code_Point"},
    921468: {"Other_Default_Ignorable_Code_Point"},
    921469: {"Other_Default_Ignorable_Code_Point"},
    921470: {"Other_Default_Ignorable_Code_Point"},
    921471: {"Other_Default_Ignorable_Code_Point"},
    921472: {"Other_Default_Ignorable_Code_Point"},
    921473: {"Other_Default_Ignorable_Code_Point"},
    921474: {"Other_Default_Ignorable_Code_Point"},
    921475: {"Other_Default_Ignorable_Code_Point"},
    921476: {"Other_Default_Ignorable_Code_Point"},
    921477: {"Other_Default_Ignorable_Code_Point"},
    921478: {"Other_Default_Ignorable_Code_Point"},
    921479: {"Other_Default_Ignorable_Code_Point"},
    921480: {"Other_Default_Ignorable_Code_Point"},
    921481: {"Other_Default_Ignorable_Code_Point"},
    921482: {"Other_Default_Ignorable_Code_Point"},
    921483: {"Other_Default_Ignorable_Code_Point"},
    921484: {"Other_Default_Ignorable_Code_Point"},
    921485: {"Other_Default_Ignorable_Code_Point"},
    921486: {"Other_Default_Ignorable_Code_Point"},
    921487: {"Other_Default_Ignorable_Code_Point"},
    921488: {"Other_Default_Ignorable_Code_Point"},
    921489: {"Other_Default_Ignorable_Code_Point"},
    921490: {"Other_Default_Ignorable_Code_Point"},
    921491: {"Other_Default_Ignorable_Code_Point"},
    921492: {"Other_Default_Ignorable_Code_Point"},
    921493: {"Other_Default_Ignorable_Code_Point"},
    921494: {"Other_Default_Ignorable_Code_Point"},
    921495: {"Other_Default_Ignorable_Code_Point"},
    921496: {"Other_Default_Ignorable_Code_Point"},
    921497: {"Other_Default_Ignorable_Code_Point"},
    921498: {"Other_Default_Ignorable_Code_Point"},
    921499: {"Other_Default_Ignorable_Code_Point"},
    921500: {"Other_Default_Ignorable_Code_Point"},
    921501: {"Other_Default_Ignorable_Code_Point"},
    921502: {"Other_Default_Ignorable_Code_Point"},
    921503: {"Other_Default_Ignorable_Code_Point"},
    921504: {"Other_Default_Ignorable_Code_Point"},
    921505: {"Other_Default_Ignorable_Code_Point"},
    921506: {"Other_Default_Ignorable_Code_Point"},
    921507: {"Other_Default_Ignorable_Code_Point"},
    921508: {"Other_Default_Ignorable_Code_Point"},
    921509: {"Other_Default_Ignorable_Code_Point"},
    921510: {"Other_Default_Ignorable_Code_Point"},
    921511: {"Other_Default_Ignorable_Code_Point"},
    921512: {"Other_Default_Ignorable_Code_Point"},
    921513: {"Other_Default_Ignorable_Code_Point"},
    921514: {"Other_Default_Ignorable_Code_Point"},
    921515: {"Other_Default_Ignorable_Code_Point"},
    921516: {"Other_Default_Ignorable_Code_Point"},
    921517: {"Other_Default_Ignorable_Code_Point"},
    921518: {"Other_Default_Ignorable_Code_Point"},
    921519: {"Other_Default_Ignorable_Code_Point"},
    921520: {"Other_Default_Ignorable_Code_Point"},
    921521: {"Other_Default_Ignorable_Code_Point"},
    921522: {"Other_Default_Ignorable_Code_Point"},
    921523: {"Other_Default_Ignorable_Code_Point"},
    921524: {"Other_Default_Ignorable_Code_Point"},
    921525: {"Other_Default_Ignorable_Code_Point"},
    921526: {"Other_Default_Ignorable_Code_Point"},
    921527: {"Other_Default_Ignorable_Code_Point"},
    921528: {"Other_Default_Ignorable_Code_Point"},
    921529: {"Other_Default_Ignorable_Code_Point"},
    921530: {"Other_Default_Ignorable_Code_Point"},
    921531: {"Other_Default_Ignorable_Code_Point"},
    921532: {"Other_Default_Ignorable_Code_Point"},
    921533: {"Other_Default_Ignorable_Code_Point"},
    921534: {"Other_Default_Ignorable_Code_Point"},
    921535: {"Other_Default_Ignorable_Code_Point"},
    921536: {"Other_Default_Ignorable_Code_Point"},
    921537: {"Other_Default_Ignorable_Code_Point"},
    921538: {"Other_Default_Ignorable_Code_Point"},
    921539: {"Other_Default_Ignorable_Code_Point"},
    921540: {"Other_Default_Ignorable_Code_Point"},
    921541: {"Other_Default_Ignorable_Code_Point"},
    921542: {"Other_Default_Ignorable_Code_Point"},
    921543: {"Other_Default_Ignorable_Code_Point"},
    921544: {"Other_Default_Ignorable_Code_Point"},
    921545: {"Other_Default_Ignorable_Code_Point"},
    921546: {"Other_Default_Ignorable_Code_Point"},
    921547: {"Other_Default_Ignorable_Code_Point"},
    921548: {"Other_Default_Ignorable_Code_Point"},
    921549: {"Other_Default_Ignorable_Code_Point"},
    921550: {"Other_Default_Ignorable_Code_Point"},
    921551: {"Other_Default_Ignorable_Code_Point"},
    921552: {"Other_Default_Ignorable_Code_Point"},
    921553: {"Other_Default_Ignorable_Code_Point"},
    921554: {"Other_Default_Ignorable_Code_Point"},
    921555: {"Other_Default_Ignorable_Code_Point"},
    921556: {"Other_Default_Ignorable_Code_Point"},
    921557: {"Other_Default_Ignorable_Code_Point"},
    921558: {"Other_Default_Ignorable_Code_Point"},
    921559: {"Other_Default_Ignorable_Code_Point"},
    921560: {"Other_Default_Ignorable_Code_Point"},
    921561: {"Other_Default_Ignorable_Code_Point"},
    921562: {"Other_Default_Ignorable_Code_Point"},
    921563: {"Other_Default_Ignorable_Code_Point"},
    921564: {"Other_Default_Ignorable_Code_Point"},
    921565: {"Other_Default_Ignorable_Code_Point"},
    921566: {"Other_Default_Ignorable_Code_Point"},
    921567: {"Other_Default_Ignorable_Code_Point"},
    921568: {"Other_Default_Ignorable_Code_Point"},
    921569: {"Other_Default_Ignorable_Code_Point"},
    921570: {"Other_Default_Ignorable_Code_Point"},
    921571: {"Other_Default_Ignorable_Code_Point"},
    921572: {"Other_Default_Ignorable_Code_Point"},
    921573: {"Other_Default_Ignorable_Code_Point"},
    921574: {"Other_Default_Ignorable_Code_Point"},
    921575: {"Other_Default_Ignorable_Code_Point"},
    921576: {"Other_Default_Ignorable_Code_Point"},
    921577: {"Other_Default_Ignorable_Code_Point"},
    921578: {"Other_Default_Ignorable_Code_Point"},
    921579: {"Other_Default_Ignorable_Code_Point"},
    921580: {"Other_Default_Ignorable_Code_Point"},
    921581: {"Other_Default_Ignorable_Code_Point"},
    921582: {"Other_Default_Ignorable_Code_Point"},
    921583: {"Other_Default_Ignorable_Code_Point"},
    921584: {"Other_Default_Ignorable_Code_Point"},
    921585: {"Other_Default_Ignorable_Code_Point"},
    921586: {"Other_Default_Ignorable_Code_Point"},
    921587: {"Other_Default_Ignorable_Code_Point"},
    921588: {"Other_Default_Ignorable_Code_Point"},
    921589: {"Other_Default_Ignorable_Code_Point"},
    921590: {"Other_Default_Ignorable_Code_Point"},
    921591: {"Other_Default_Ignorable_Code_Point"},
    921592: {"Other_Default_Ignorable_Code_Point"},
    921593: {"Other_Default_Ignorable_Code_Point"},
    921594: {"Other_Default_Ignorable_Code_Point"},
    921595: {"Other_Default_Ignorable_Code_Point"},
    921596: {"Other_Default_Ignorable_Code_Point"},
    921597: {"Other_Default_Ignorable_Code_Point"},
    921598: {"Other_Default_Ignorable_Code_Point"},
    921599: {"Other_Default_Ignorable_Code_Point"},
    983038: {"Noncharacter_Code_Point"},
    983039: {"Noncharacter_Code_Point"},
    1048574: {"Noncharacter_Code_Point"},
    1048575: {"Noncharacter_Code_Point"},
    1114110: {"Noncharacter_Code_Point"},
    1114111: {"Noncharacter_Code_Point"},
}
